(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  19323134,     563873]*)
(*NotebookOutlinePosition[  19420224,     566924]*)
(*  CellTagsIndexPosition[  19406340,     566494]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Eigenmode Analysis", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["4.1 Generalized Fourier Series", "Subtitle",
  CellTags->{"i:3", "c:2"}],

Cell["", "Text"],

Cell[TextData[{
  "\tIn Chapter ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  " we constructed solutions to several linear partial differential equations \
using the method of separation of variables.  The solutions were written in \
terms of an infinite sum of eigenmodes arising from an associated eigenvalue \
problem. Sometimes the eigenmodes were trigonometric functions, and the sums \
formed a Fourier series. In other examples the eigenmodes were Bessel \
functions, or associated Legendre functions. Nevertheless, in every case \
studied, these eigenmodes were orthogonal to one another, and it was only for \
this reason that they were useful in finding an analytic solution.  "
}], "Text"],

Cell[TextData[{
  "\tWhy did the eigenmodes in each of these problems form an orthogonal set? \
 In this section we answer this important question.  In short, the answer is \
that these eigenmodes spring from a particular type of eigenvalue problem:  \
a",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Sturm",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Sturm.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox["-",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Liouville",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Liouville.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" problem",
    FontSlant->"Italic"],
  ". The differential operators in Sturm-Liouville problems have the property \
that they are ",
  StyleBox[ButtonBox["Hermitian",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Hermite.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ",",
  " and this property implies that the eigenmodes of the operators form a \
complete orthogonal set. "
}], "Text",
  CellTags->"i:108"],

Cell[TextData[{
  "\tFirst, however, we need to generalize the idea of a Fourier series. \
There is nothing particularly special about trigonometric functions. One can \
describe a given function using an infinite series constructed from many \
orthogonal function sets, not just trigonometric Fourier modes. These series \
expansions are called ",
  StyleBox["generalized Fourier series",
    FontSlant->"Italic"],
  ".  We will examine the workings of these series, and discuss a general way \
to create orthogonal sets of functions for use in these series: the ",
  StyleBox["Gram-Schmidt method",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["4.1.1 Inner Products and Orthogonal Functions", "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{

Cell["Definition of an Inner Product", "Section",
  FontWeight->"Bold",
  CellTags->{"i:4", "c:5"}],

Cell[TextData[{
  "\tIn order to discuss generalized Fourier series, we must first extend our \
notion of orthogonality. This requires that we introduce the concept of an ",
  StyleBox["inner product",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe are all familiar with inner products through their use in linear \
algebra. The dot product of two ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-dimensional real vectors ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["g",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["g",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(\[Sum]\+\(i = 1\)\%N\), 
            RowBox[{\(f\_i\), " ", \(g\_i\), 
              StyleBox[" ",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ", is a type of inner product. For complex functions, an inner product acts \
on two",
  StyleBox[" ",
    FontSlant->"Italic"],
  "functions defined on a given interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  ", in general returning a complex number. The notation that we use for the \
inner product of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, g)\)\)]],
  ". One example of an inner product  for complex functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\((f, g)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\(\( f\^*\)(x)\) \(g(
            x)\)\ \[DifferentialD]x\)]],
  "."
}], "NE2",
  CellTags->"(4.1.1)"],

Cell[TextData[{
  "\t  In inner product notation, two functions are orthogonal when their \
inner product vanishes: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\((f, g)\) = 0\)\)\)]],
  " . This is like two vectors being perpendicular to one another. Using Eq. \
",
  ButtonBox["(4.1.1)",
    ButtonData:>"(4.1.1)",
    ButtonStyle->"Hyperlink"],
  " for our inner product, the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, g)\) = 0\)]],
  " is equivalent to the definition of orthogonality used in complex \
exponential Fourier series,  Eq. ",
  ButtonBox["(2.1.28)",
    ButtonData:>{"Chapter2.nb", "(2.1.28)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:1"],

Cell["\<\
\tIt is also possible to write down other inner products. However, \
all inner products must satisfy certain rules. First,\
\>", "Text",
  CellTags->"i:5"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, g)\) = \(\((g, f)\)\^*\)\)]],
  "."
}], "NE2",
  CellTags->"(4.1.2)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(4.1.2)",
    ButtonData:>"(4.1.2)",
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, f)\)\  = \ \(\((f, f)\)\^*\)\)]],
  ", so the inner product of a function with itself must be a real number. \
Another requirement for an inner product is that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\((f, f)\) \[GreaterEqual] \ 0\)]]], "NE2",
  CellTags->"(4.1.3)"],

Cell[TextData[{
  "with equality ",
  "only",
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  ". Also, the inner product must be linear in the second argument, so that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\ f, g + C\ h)\) = \ \((f, \ g)\) + 
          C\ \((f, h)\)\)]],
  ", "
}], "NE2",
  CellTags->"(4.1.4)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a constant. This implies that the inner product is ",
  StyleBox["antilinear",
    FontSlant->"Italic"],
  " in the first argument:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\ f + C\ h, 
          g)\) = \ \(\(\((g, 
                f + C\ h)\)\^*\) = \(\(\((g, f)\)\^*\) + \(\(\(C\^*\)(g, 
                    h)\)\^*\) = \((f, g)\) + \(C\^*\)(h, g)\)\)\)]],
  ","
}], "NE2",
  CellTags->"(4.1.5)"],

Cell[TextData[{
  "where in the first and last steps we used Eq.  ",
  ButtonBox["(4.1.2)",
    ButtonData:>"(4.1.2)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe inner product of Eq. ",
  ButtonBox["(4.1.1)",
    ButtonData:>"(4.1.1)",
    ButtonStyle->"Hyperlink"],
  " clearly satisfies these rules. Another inner product that does so is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), "=", 
          
          FormBox[\(\[Integral]\_a\%b\(\( f\^*\)(x)\) \(g(x)\)\ \(p(
                  x)\) \[DifferentialD]x\),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(4.1.6)"],

Cell[TextData[{
  "for some real function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  " that has the property that ",
  Cell[BoxData[
      \(TraditionalForm\`p(x) > \ 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`a < \ \ x < \ \ b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tObviously, functions that are orthogonal with respect to the inner \
product given by Eq. ",
  ButtonBox["(4.1.1)",
    ButtonData:>"(4.1.1)",
    ButtonStyle->"Hyperlink"],
  " will generally not be  orthogonal with respect to the inner product given \
by Eq. ",
  ButtonBox["(4.1.6)",
    ButtonData:>"(4.1.6)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sets of Orthogonal Functions. The Gram- Schmidt Method.", "Section",
  FontWeight->"Bold",
  CellTags->{"i:6", "c:6"}],

Cell[TextData[{
  "\tA set of functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_n\)(x)}\)]],
  " forms an ",
  StyleBox["orthogonal set",
    FontSlant->"Italic"],
  " with respect to some inner product if ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n, \[Psi]\_m)\) = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ m\)]],
  ". The trigonometric Fourier modes used in Fourier series are an example of \
an orthogonal set:  ",
  Cell[BoxData[
      \(TraditionalForm\`{\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ n\ \
x/\((b - a)\)\)}\)]],
  " forms an orthogonal set with respect to the inner product of Eq. ",
  ButtonBox["(4.1.1)",
    ButtonData:>"(4.1.1)",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text",
  CellTags->"i:7"],

Cell[TextData[{
  "\tIt is also possible to find completely different ",
  StyleBox["nontrigonometric ",
    FontSlant->"Italic"],
  "sets of functions that are orthogonal with respect to some inner product. \
We have already seen several examples of this in Chapter ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  For instance, Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>{"Chapter3.nb", "(3.2.55)"},
    ButtonStyle->"Hyperlink"],
  " implies that the set of Bessel functions  ",
  Cell[BoxData[
      \(TraditionalForm\`{\(J\_m\)(\(j\_\(m\ n\)\) r/a)}\)]],
  " form an orthogonal set with respect to the inner product defined by the \
integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a r \[DifferentialD]r\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tFor a given inner product, one can in fact find an ",
  "infinite number",
  " of different orthogonal sets of functions.  One way to create such sets \
is via the ",
  StyleBox["Gram-Schmidt",
    FontSlant->"Italic"],
  " method."
}], "Text"],

Cell[TextData[{
  "\tThe ",
  ButtonBox["Gram",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gram.html"],
       None},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["Schmidt",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Schmidt.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " method allows one to construct a set of orthogonal functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_n\)(x)}\)]],
  " out of a given set of functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(v\_n\)(x)}, \ n = 0, 1, 2, 
      3, \(\(...\)\(.\)\)\)]],
  ". There is almost no restriction on the functions chosen for the latter \
set, except that each function must be different than the previous functions. \
(More precisely, they must be linearly independent functions; one function \
cannot be written as a sum of the others. Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`{1, x, x\^2, x\^3,  ... }\)]],
  " is a good set, but ",
  Cell[BoxData[
      \(TraditionalForm\`{x, 2  x, 3  x, 4  x,  ... }\)]],
  "is not.) Also, the inner products of these functions with one another must \
not be singular."
}], "Text",
  CellTags->"i:112"],

Cell[TextData[{
  "\tThe method is analogous to the method of the same name used to create \
orthogonal sets of vectors in linear algebra. We will construct an orthogonal \
set of functions, ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_n\)(x)}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3,  ... \)]],
  ", by taking sums of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`v\_n\)]],
  ". To start, we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x) = \(v\_o\)(x)\)]],
  ". Next, we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_1\)(
          x)\  = \ \(a\_o\) \(\(v\_o\)(x)\) + \ \(v\_1\)(x)\)]],
  ", where the constant ",
  Cell[BoxData[
      \(TraditionalForm\`a\_o\)]],
  "is determined by imposing the requirement that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_1\)]],
  " be orthogonal with respect to the given inner product:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_o, \[Psi]\_1)\) = \(0 = \(a\_o\)(v\_o, 
              v\_o) + \((v\_o, v\_1)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This implies that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_o = \(-\((v\_o, v\_1)\)\)/\((v\_o, v\_o)\)\)]],
  ". Next, we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_2\)(
          x) = \(b\_o\) \(\(v\_o\)(x)\) + \(b\_1\) \(\(v\_1\)(x)\) + \(v\_2\)(
            x)\)]],
  ", and we determine the constants ",
  Cell[BoxData[
      \(TraditionalForm\`b\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  " by the requirement that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_2\)]],
  " be orthogonal to ",
  "both",
  StyleBox[" ",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_1\)]],
  ". This gives us two equations in the two unknowns ",
  Cell[BoxData[
      \(TraditionalForm\`b\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  ":"
}], "Text"],

Cell[TextData[{
  " \t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_o, \[Psi]\_2)\) = \(0 = \(b\_o\)(v\_o, 
              v\_o) + \(b\_1\)(v\_o, v\_1) + \((v\_o, v\_2)\)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_1, \[Psi]\_2)\) = \(0 = \(a\_o\) \(\(b\_o\
\)(v\_o, v\_o)\) + \(a\_o\) \(\(b\_1\)(v\_o, v\_1)\) + \(a\_o\)(v\_o, 
              v\_2) + \(b\_o\)(v\_1, v\_o) + \(b\_1\)(v\_1, v\_1) + \((v\_1, 
              v\_2)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  " After solving these coupled linear equations for ",
  Cell[BoxData[
      \(TraditionalForm\`b\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  ", we repeat the procedure",
  ",",
  " defining ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_3\)(
          x) = \(c\_o\) \(\(v\_o\)(x)\) + \(c\_1\) \(\(v\_1\)(
              x)\) + \(c\_2\) \(\(v\_2\)(x)\) + \(v\_3\)(x)\)]],
  ", and so on. "
}], "Text"],

Cell[TextData[{
  "\tIn fact, it is possible to automate this process in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", constructing any set of orthogonal functions that we wish, for any given \
inner product. (See the exercises.)"
}], "Text"],

Cell["\<\
\tAs an example of the Gram-Schmidt method, we will take the \
following inner product:\
\>", "Text",
  CellTags->"i:8"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_\(-1\)\%1\(\( f\^*\)(x)\)\ \(g(
              x)\) \[DifferentialD]x\)]],
  ","
}], "NE2",
  CellTags->"(4.1.7)"],

Cell[TextData[{
  " and we will construct an orthogonal set of functions using the set ",
  Cell[BoxData[
      \(TraditionalForm\`{1, x, x\^2, x\^3,  ... }\)]],
  " as our starting point. According to the method outlined previously, we \
take  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Psi]\_o\)(x)\  = \ 1\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_1\)(x)\  = \ \ a\_o + x\)]],
  ". In order to find ",
  Cell[BoxData[
      \(TraditionalForm\`a\_o\)]],
  " we require that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_1, \[Psi]\_o)\) = 0\)]],
  ", which implies that ",
  Cell[BoxData[
      \(TraditionalForm\`0 = \(a\_o\) \
\(\[Integral]\_\(-1\)\%1\[DifferentialD]x\) + \[Integral]\_\(-1\)\%1 
              x \[DifferentialD]x\)]],
  ". Therefore, we find ",
  Cell[BoxData[
      \(TraditionalForm\`a\_o = 0\)]],
  ", so ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_1\)(x)\  = \ x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Next, we set ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_2 = b\_o\  + \ b\_1\ x + x\^2\)]],
  ". The conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_2, \[Psi]\_1)\) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_2, \[Psi]\_o)\) = 0\)]],
  " lead to two equations for ",
  Cell[BoxData[
      \(TraditionalForm\`b\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_1\)]],
  ", which can be  solved using ",
  Cell[BoxData[
      \(TraditionalForm\`Mathematica\)]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][0, x_]\  = \ 1;\)\), "\n", 
    \(\(\[Psi][1, x_]\  = \ x;\)\), "\n", 
    \(\(\[Psi][2, x_]\  = \ b0\  + \ b1\ x\  + \ x^2;\)\), "\n", 
    \(\ \(sol\  = \ \(Solve[{Integrate[\[Psi][2, x]\ \[Psi][1, 
                      x], {x, \(-1\), 1}] \[Equal] 0, 
              Integrate[\[Psi][2, x]\ \[Psi][0, x], {x, \(-1\), 1}] \[Equal] 
                0}, {b0, b1}]\)[\([1]\)];\)\), "\n", 
    \(\[Psi][2, x]\  = \ \[Psi][2, x] /. sol\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.1"],

Cell[BoxData[
    \(\(-\(1\/3\)\) + x\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_2\)(x) = x\^2 - 1/3\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tNext, we set ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(\(3\)\(\ \)\) = \ 
        c\_o + \(c\_1\) x + \(c\_2\) x\^2\  + \ c\_3\ x\^3\)]],
  ", and solve the three coupled equations ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((\[Psi]\_3, \[Psi]\_2)\), "=", 
          
          FormBox[\(\((\[Psi]\_3, \[Psi]\_1)\) = \(\((\[Psi]\_3, \[Psi]\_0)\) \
= 0\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\[Psi][3, x_]\  = \ 
        c0\  + \ c1\ x\  + \ c2\ x^2\  + \ x^3;\)\), "\n", 
    \(\ \(sol\  = \ \(Solve[
            Table[Integrate[\[Psi][3, x]\ \[Psi][n, x], {x, \(-1\), 
                    1}] \[Equal] 0, {n, 0, 2}], {c0, c1, 
              c2}]\)[\([1]\)];\)\), "\n", 
    \(\[Psi][3, x]\  = \ \[Psi][3, x] /. sol\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.2"],

Cell[BoxData[
    \(\(-\(\(3\ x\)\/5\)\) + x\^3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_3\)(x)\  = \ \(-3\) x/5\  + \ x\^3\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIf we continue this process, the set of functions that we construct are \
proportional to ",
  StyleBox[ButtonBox["Legendre",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Legendre.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  "  ",
  StyleBox["polynomials ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`{\(P\_n\)(x)}\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "refers to these functions as ",
  StyleBox["LegendreP[n,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  We have already run across these polynomials, which are the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " cases of the associated Legendre functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_l\%m\)(x)\)]],
  " discussed in connection with solution of the Laplace equation in \
spherical coordinates. A few of these polynomials are listed below, and are \
plotted in Fig. ",
  ButtonBox["4.1",
    ButtonData:>"Fig. 4.1",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:9"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Do[Print[Subscript[P, n], "\<(x) = \>", LegendreP[n, x]], {n, 0, 
        4}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.3"],

Cell[BoxData[
    InterpretationBox[\(P\_0\[InvisibleSpace]"(x) = "\[InvisibleSpace]1\),
      SequenceForm[ 
        Subscript[ P, 0], "(x) = ", 1],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(P\_1\[InvisibleSpace]"(x) = "\[InvisibleSpace]x\),
      SequenceForm[ 
        Subscript[ P, 1], "(x) = ", x],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(P\_2\[InvisibleSpace]"(x) = \
"\[InvisibleSpace]\(\(-\(1\/2\)\) + \(3\ x\^2\)\/2\)\),
      SequenceForm[ 
        Subscript[ P, 2], "(x) = ", 
        Plus[ 
          Rational[ -1, 2], 
          Times[ 
            Rational[ 3, 2], 
            Power[ x, 2]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(P\_3\[InvisibleSpace]"(x) = "\[InvisibleSpace]\(\(-\(\
\(3\ x\)\/2\)\) + \(5\ x\^3\)\/2\)\),
      SequenceForm[ 
        Subscript[ P, 3], "(x) = ", 
        Plus[ 
          Times[ 
            Rational[ -3, 2], x], 
          Times[ 
            Rational[ 5, 2], 
            Power[ x, 3]]]],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\(P\_4\[InvisibleSpace]"(x) = "\[InvisibleSpace]\(3\/8 \
- \(15\ x\^2\)\/4 + \(35\ x\^4\)\/8\)\),
      SequenceForm[ 
        Subscript[ P, 4], "(x) = ", 
        Plus[ 
          Rational[ 3, 8], 
          Times[ 
            Rational[ -15, 4], 
            Power[ x, 2]], 
          Times[ 
            Rational[ 35, 8], 
            Power[ x, 4]]]],
      Editable->False]], "Print"]
}, Open  ]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -5 0 ]
[.5 .64303 5 12 ]
[.5 .63053 -79.625 0 ]
[.5 .63053 79.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -140.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Legendre) show
117.000 13.000 moveto
(Polynomials) show
189.000 13.000 moveto
(P) show
195.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
200.250 13.000 moveto
(H) show
206.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
212.250 13.000 moveto
(L) show
218.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.42237 .60332 L
.46172 .60332 L
.49955 .60332 L
.53984 .60332 L
.57861 .60332 L
.61984 .60332 L
.65954 .60332 L
.69774 .60332 L
.73838 .60332 L
.77751 .60332 L
.81909 .60332 L
.85916 .60332 L
.89771 .60332 L
.93871 .60332 L
.97619 .60332 L
s
[ .05 .05 ] 0 setdash
.02381 .01472 m
.06244 .03859 L
.10458 .06463 L
.14415 .08909 L
.18221 .11261 L
.22272 .13765 L
.26171 .16175 L
.30316 .18736 L
.34309 .21204 L
.3815 .23578 L
.42237 .26104 L
.46172 .28536 L
.49955 .30874 L
.53984 .33364 L
.57861 .3576 L
.61984 .38308 L
.65954 .40762 L
.69774 .43123 L
.73838 .45635 L
.77751 .48053 L
.81909 .50623 L
.85916 .53099 L
.89771 .55482 L
.93871 .58016 L
.97619 .60332 L
s
[ ] 0 setdash
.02381 .60332 m
.06244 .53459 L
.10458 .46626 L
.14415 .40839 L
.18221 .35848 L
.22272 .31155 L
.26171 .27241 L
.30316 .2373 L
.34309 .2098 L
.3815 .1892 L
.40095 .18097 L
.42237 .1736 L
.44268 .16826 L
.45178 .16639 L
.46172 .16472 L
.4671 .16397 L
.4721 .16338 L
.47727 .16287 L
.48196 .1625 L
.48658 .16222 L
.4887 .16211 L
.49093 .16203 L
.49332 .16195 L
.49438 .16193 L
.49552 .16191 L
.49675 .16189 L
.49789 .16187 L
.49859 .16187 L
.49925 .16187 L
.50049 .16187 L
.50163 .16187 L
.50286 .16188 L
.50401 .1619 L
.50508 .16192 L
.50754 .16198 L
.51014 .16207 L
.51268 .16218 L
.51504 .16231 L
.5204 .16268 L
.5293 .16354 L
.53882 .1648 L
.54906 .16655 L
.56016 .16891 L
.58032 .17442 L
.60019 .18141 L
.62123 .19048 L
.65912 .21116 L
.69946 .23932 L
.73829 .27241 L
.77956 .31402 L
Mistroke
.81932 .36038 L
.85757 .41078 L
.89827 .47066 L
.93745 .53441 L
.97619 .60332 L
Mfstroke
[ .05 .05 ] 0 setdash
.02381 .01472 m
.06244 .14385 L
.10458 .25431 L
.14415 .33187 L
.18221 .38494 L
.20178 .40476 L
.22272 .42081 L
.23293 .42681 L
.24402 .43203 L
.25449 .43579 L
.26416 .43827 L
.26882 .43915 L
.27139 .43954 L
.27383 .43986 L
.27609 .4401 L
.27856 .44032 L
.27965 .44039 L
.2808 .44046 L
.28182 .44051 L
.28289 .44056 L
.28355 .44058 L
.28428 .4406 L
.28556 .44062 L
.28629 .44063 L
.28706 .44063 L
.28779 .44063 L
.28846 .44062 L
.28975 .4406 L
.29048 .44058 L
.29115 .44056 L
.29247 .44051 L
.29371 .44044 L
.29597 .44029 L
.29846 .44008 L
.30351 .43948 L
.30821 .43875 L
.31334 .43774 L
.3237 .43512 L
.3422 .42853 L
.36181 .41914 L
.38276 .40672 L
.42426 .37627 L
.46424 .34186 L
.50271 .30651 L
.54363 .26914 L
.58303 .23594 L
.62092 .20897 L
.642 .19689 L
.66126 .1881 L
.67079 .18463 L
Mistroke
.68117 .18158 L
.68592 .18045 L
.69098 .17943 L
.69541 .1787 L
.70008 .17811 L
.70264 .17786 L
.704 .17775 L
.70545 .17764 L
.70679 .17757 L
.70801 .17751 L
.70923 .17746 L
.71039 .17743 L
.71103 .17742 L
.71174 .17741 L
.71248 .1774 L
.71317 .1774 L
.7144 .17741 L
.7151 .17742 L
.71573 .17743 L
.71708 .17748 L
.71856 .17754 L
.7201 .17763 L
.72153 .17773 L
.72417 .17796 L
.72665 .17823 L
.7313 .17891 L
.7363 .17986 L
.74171 .18116 L
.7512 .18415 L
.76163 .1885 L
.78269 .20088 L
.80217 .21689 L
.82308 .23929 L
.86441 .30092 L
.90422 .38432 L
.94252 .48923 L
.97619 .60332 L
Mfstroke
[ ] 0 setdash
.02381 .60332 m
.04262 .4971 L
.06244 .40543 L
.08255 .33166 L
.10458 .27057 L
.12415 .23154 L
.13511 .21527 L
.14509 .20363 L
.15504 .1948 L
.16424 .18895 L
.16904 .18671 L
.17432 .18486 L
.17698 .18417 L
.17985 .1836 L
.18123 .18338 L
.18255 .18321 L
.18373 .18309 L
.18502 .18299 L
.18566 .18295 L
.18635 .18292 L
.18757 .18289 L
.18889 .18289 L
.18963 .18291 L
.19033 .18293 L
.19159 .18299 L
.19275 .18308 L
.19408 .18321 L
.19534 .18336 L
.19766 .18372 L
.19982 .18414 L
.20469 .18538 L
.20953 .18699 L
.21486 .1892 L
.22566 .19492 L
.24501 .20879 L
.26587 .22783 L
.30701 .27284 L
.34663 .31875 L
.38474 .35914 L
.40599 .37832 L
.4253 .393 L
.44538 .40509 L
.45441 .40937 L
.46435 .41323 L
.47407 .41612 L
.47938 .41732 L
.48436 .41819 L
.48674 .41853 L
.48901 .41879 L
.49106 .41899 L
Mistroke
.49326 .41916 L
.4945 .41923 L
.49563 .41929 L
.49676 .41933 L
.49783 .41936 L
.49908 .41938 L
.50022 .41938 L
.50148 .41937 L
.50212 .41936 L
.50281 .41934 L
.50412 .4193 L
.50533 .41924 L
.50807 .41906 L
.51048 .41885 L
.51304 .41855 L
.51747 .4179 L
.52236 .41695 L
.53316 .41406 L
.54329 .41035 L
.56351 .40016 L
.58203 .38777 L
.6217 .35278 L
.65986 .31135 L
.70048 .26422 L
.73958 .22252 L
.75953 .20517 L
.77003 .19764 L
.78113 .19114 L
.79106 .18678 L
.7967 .18499 L
.7994 .18431 L
.80197 .18379 L
.80429 .18342 L
.80551 .18326 L
.80681 .18312 L
.8079 .18303 L
.8091 .18295 L
.8102 .18291 L
.81123 .18289 L
.81244 .18289 L
.81372 .18293 L
.81481 .18298 L
.816 .18307 L
.81729 .18319 L
.81867 .18337 L
.82116 .18378 L
.82374 .18434 L
.82648 .1851 L
.83139 .18689 L
.83667 .18943 L
Mistroke
.84248 .19302 L
.85288 .20161 L
.86263 .21237 L
.87302 .22697 L
.88289 .24405 L
.90142 .28531 L
.92124 .34419 L
.93963 .41411 L
.97619 .60332 L
Mfstroke
gsave
.59524 .5886 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69048 .45617 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80952 .39731 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88095 .35316 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.95238 .33845 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00
W`3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0_03oool00:40oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`00UP3oool6000000D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`004@3oool2000008h0oooo00<000000?oo
o`3oool01@3oool300000;`0oooo000A0?ooo`040000003oool00000000008`0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`004@3oool01@000000oooo0?ooo`3oool00000
08/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?ooo`004P3oool010000000
oooo0?ooo`3oool2000008T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2l0?oo
o`004P3oool00`000000oooo0?ooo`030?ooo`800000Q@3oool205EEE@030000003oool0oooo00D0
oooo00<000000?ooo`3oool0_03oool00180oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0;`0oooo000C0?ooo`030000003oool0oooo00D0oooo0P00
002<0?ooo`030000003oool0oooo0;`0oooo000C0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`2l0?ooo`004`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0_03oool001@0oooo00<000000?ooo`3o
ool0TP3oool200000;d0oooo000D0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
_03oool001@0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2l0?ooo`005@3oool0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0;`0oooo000E0?ooo`030000003oool0oooo
0940oooo00<000000?ooo`3oool0_03oool001D0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`2l0?ooo`005P3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo0;`0oooo
000F0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0_03oool002`0oooo0P00001k
0?ooo`030000003oool0oooo0;`0oooo000^0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0_03oool002l0oooo0P00001h0?ooo`800000_@3oool00340oooo0P00001f0?ooo`030000
003oool0oooo0;`0oooo000c0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0_03o
ool003@0oooo0P00001c0?ooo`030000003oool0oooo0;`0oooo000f0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0_03oool003L0oooo0P00001`0?ooo`030000003oool0oooo0;`0
oooo000i0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0_03oool00:T0oooo00<0
00000?ooo`3oool0_03oool00:T0oooo00<000000?ooo`3oool0_03oool00:T0oooo0P00002m0?oo
o`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00Z@3oool00`000000oooo0?ooo`2l0?ooo`00Z@3o
ool00`000000oooo0?ooo`2l0?ooo`006P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0;`0oooo000J0?ooo`030000003oool0oooo02X0oooo0P00001P0?ooo`030000003oool0oooo
0;`0oooo000K0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0G@3oool00`000000
oooo0?ooo`2l0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`800000G@3oool00`000000oooo
0?ooo`2l0?ooo`006`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0_03oool001`0oooo00<000000?ooo`3oool0;P3oool2000005X0oooo0P00002m
0?ooo`00703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0_03oool001`0oooo00<000000?ooo`3oool0<@3oool2000005L0oooo00<000000?ooo`3o
ool0_03oool001d0oooo00<000000?ooo`3oool0<P3oool2000005D0oooo00<000000?ooo`3oool0
_03oool001d0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0;`0oooo000M0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`2l0?ooo`007P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;`0oooo000N0?ooo`030000003oool0oooo06d0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?oo
o`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0_03oool0
01h0oooo00<000000?ooo`3oool0K@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0_03oool001l0oooo00<000000?oo
o`3oool0I03oool600000080oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0_03oool001l0oooo00<000000?ooo`3oool0K03oool01@00
0000oooo0?ooo`3oool0000000/0oooo5`00002c0?ooo`00SP3oool01@000000oooo0?ooo`3oool0
000000D0oooo1P0000001P3oool00000028R8P000000<c<c0<c<c0D0oooo00<000000?ooo`3oool0
2@3oool600000:d0oooo002>0?ooo`05014A4@3oool0oooo0?ooo`0A4A400P3oool3000000L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`@00000Z@3oool00680oooo0P00
000Z0?ooo`0407MgM`2IVIT0oooo09VIV@<000002P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01<0oooo0`00002V0?ooo`00I03oool00`000000oooo0?ooo`0W0?ooo`@0000000<0
k^k^0?ooo`3oool02P3oool4000000H0oooo00<000000?ooo`3oool05P3oool300000:<0oooo001U
0?ooo`800000903oool3000001/0oooo00<000000?ooo`3oool06@3oool3000001d0oooo3000001g
0?ooo`00I`3oool2000001l0oooo0`00000N0?ooo`030000003oool0oooo01`0oooo0`00000G0?oo
o`<00000P`3oool00400oooo3000000M0?ooo`030000003oool0oooo01X0oooo0P00000Q0?ooo`03
0000003oool0oooo01l0oooo0P00000C0?ooo`8000009@3oool<000005D0oooo000m0?ooo`<00000
303oool2000001`0oooo0P00000H0?ooo`8000008`3oool00`000000oooo0?ooo`0Q0?ooo`800000
=P3oool2000000`0oooo00<000000?ooo`3oool0DP3oool003`0oooo00<000000?ooo`3oool03`3o
ool3000001/0oooo00<000000?ooo`3oool04`3oool2000002D0oooo0P00000T0?ooo`800000<@3o
ool3000000l0oooo0P00001B0?ooo`00>P3oool2000001D0oooo0P00000J0?ooo`8000004@3oool2
000002L0oooo00<000000?ooo`3oool09@3oool2000002`0oooo0`00000D0?ooo`030000003oool0
oooo04l0oooo000i0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0<0?ooo`800000:@3oool00`000000oooo0?ooo`0W0?ooo`800000:P3oool01000
0000oooo00000000000D0?ooo`030000003oool0oooo04h0oooo000h0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`090?ooo`800000:`3oool00`00
0000oooo0?ooo`0Y0?ooo`8000009`3oool00`000000oooo0?ooo`020?ooo`8000004`3oool00`00
0000oooo0?ooo`1=0?ooo`00=`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0280
oooo0P00000]0?ooo`030000003oool0oooo02H0oooo0P0000030?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`800000C@3oool003L0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0O0?ooo`800000;`3oool00`000000oooo
0?ooo`0T0?ooo`8000001P3oool200000240oooo0P0000090?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0BP3oool002D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0N0?ooo`8000007@3oool200000340oooo00<000000?ooo`3oool08P3oool2000000X0oooo0P00
000N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`190?ooo`009@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0303oool2000001X0oooo0P00000>0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0B03oool002H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01H0oooo0P00000d0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`180?ooo`009P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo01h0oooo0P00000C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04L0oooo000V0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`800000
=`3oool2000001h0oooo00<000000?ooo`3oool0503oool2000001<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04H0oooo000W0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00/0oooo0P00000Z0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`160?ooo`009`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0>0?ooo`800000:03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04D0oooo000W0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`8000004`3oool20000
02H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0K0?ooo`8000003@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo04D0oooo000X0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0
oooo0P00000T0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo04@0oooo000X0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`060?ooo`8000006P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo04<0oooo000X0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo0P00
000Q0?ooo`030000003oool0oooo03`0oooo0P0000060?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool0@`3oool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07P3oool2000001l0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0@P3oool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0a0?oo
o`040000003oool0oooo000002<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0o
0?ooo`050000003oool0oooo0?ooo`000000<`3oool00`000000oooo0?ooo`120?ooo`00:@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0oooo0P00000U0?ooo`030000003oool0
oooo01/0oooo0P0000110?ooo`<00000=@3oool00`000000oooo0?ooo`110?ooo`00:P3oool01000
0000oooo0?ooo`00000e0?ooo`<00000@`3oool00`000000oooo0?ooo`110?ooo`800000=@3oool0
0`000000oooo0?ooo`110?ooo`00:`3oool00`000000oooo0000000d0?ooo`050000003oool0oooo
0?ooo`000000@P3oool00`000000oooo0?ooo`100?ooo`040000003oool0oooo000003D0oooo00<0
00000?ooo`3oool0@03oool002`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0@03oool002`0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00@0oooo0P00000c0?oo
o`030000003oool0oooo03l0oooo000[0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0o0?ooo`004`3oool400000003014A4@3oool0oooo0140oooo
00<000000?ooo`3oool0:03oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00@000000?ooo`0R
8R808R8R1@3oool01@14A4@00000000000000000gMgM03d0oooo00<000000?ooo`3oool02P3oool2
00000340oooo00H000000>k^kP0c<c<0000003<c<`3^k^h50?ooo`030000000R8R80oooo00@0oooo
00D0A4A4000000000000<c<c0=gMg@0E0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool05P3oool400000003014A4@3oool0oooo0280oooo000E0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0:@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg0080oooo00<000000?ooo`3o
ool00P0R8R880?ooo`0307MgM`000000oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0`0?ooo`070000003oool0MgMg09VIV@3oool0VIVI07MgM`050?ooo`03028R8P000000
oooo00L0oooo00<0MgMg03<c<`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0903oool000X0oooo1P0000050?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool08@3oool600000080oooo00L04A4A0?ooo`3oool0oooo014A4@3o
ool0000000h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0300oooo00@000000?ooo`3oool04A4A0`3oool00`0A4A40oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0903oool001D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo0?ooo`8000003P3oool00`1gMgL0<c<c
0000000[0?ooo`8000003`3oool2000000P0oooo00<000000?ooo`3oool0<03oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`03
07MgM`0c<c<0oooo01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo02@0oooo000E0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
:P3oool01@000000oooo0?ooo`3oool0000000`0oooo00L00000028R8P000000<c<c0<c<c03oool0
000002`0oooo0`00000<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000002@3oool020000000oooo0?oo
o`0000008R8R0000000c<c<0c<c<603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0903oool001D0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0Z0?ooo`05014A4@3oool0oooo0000000A4A40303oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo02`0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`030?ooo`05014A4@3oool0oooo0?ooo`0A4A402P3oool0
0`000000oooo0000000M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0T0?ooo`005@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02/0oooo00D0MgMg09VIV@000000VIVI07MgM`0<0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3o
ool2000001h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02@0oooo000C0?ooo`80EEEE00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0[
0?ooo`050>k^kP000000000003<c<`3^k^h0303oool4000000D0oooo00<000000?ooo`3oool0;@3o
ool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00D0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000006`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01<0oooo0P1EEED00`000000oooo0?ooo`0T0?ooo`00:03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0k0?ooo`009`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0;P3oool2000000@0oooo00D000000?ooo`3oool0oooo0000
000c0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo03/0oooo000W0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0300oooo00D00000
0?ooo`3oool0oooo0000000f0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo0P0000020?ooo`8000003P3o
ool002H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0<03oool010000000oooo0?ooo`00000e0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02H0oooo00H0k^k^028R8P28R8P0c<c<0000003<c<`>0?ooo`009P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool0103MgMd00000
0000003<c<`?0?ooo`002@3ooooo000004400000303oool0103^k^h08R8R0000003^k^h?0?ooo`00
4@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0000000<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000
3P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00D0k^k^028R8P1gMgL0
MgMg03<c<`0?0?ooo`004@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0403oool200000080oooo0P00000>0?ooo`009@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo03T0oooo000T0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0>03oool002@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0h0?oo
o`00903oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0T0?ooo`8000001P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0903oool00`000000oooo014A4@0200000004
0?ooo`0000000000014A4@X0oooo0P0000000`0A4A40oooo0?ooo`0S0?ooo`008`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0903oool00`000000
oooo000000030?ooo`030000003oool0oooo00H00000103oool00`000000oooo0?ooo`0T0?ooo`00
8`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool2000001l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01`3oool5000002D0oooo000S0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0203oool2000000`0oooo0P00000L0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool08P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00H0000000D0oooo04A4A03MgMd0oooo0000000V0?ooo`008P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool08`3oool20000000408R8R03o
ool0ZZZZ000000T0oooo00@0gMgM05EEE@3oool000009P3oool00280oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo0P00000G0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0100A4A4000000000003oool200000003
014A4@3oool0oooo00H0oooo00D0VIVI014A4@000000<c<c0<c<c0030?ooo`80000000@0MgMg0000
00000000VIVI2P3oool00`1gMgL0c<c<0000000V0?ooo`008P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0100oooo0P00000D0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02`3oool01@000000oooo0?ooo`3oool000000080oooo1P0000001P3oool04A4A0;^k^`3o
ool0MgMg03<c<`<0oooo00<000000?ooo`3oool03@3oool00`3^k^h0A4A40000000V0?ooo`008P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo
000000070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`03
07MgM`000000oooo02D0oooo000Q0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
4`3oool2000000h0oooo0P00000l0?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`H00000103oool00`2ZZZX04A4A0?ooo`030?ooo`030000003oool0oooo03D0
oooo000Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0203oool01@000000R8R8
0?ooo`2ZZZX0000000P0oooo00H000000?ooo`3oool04A4A0000002k^k/40?ooo`030000003oool0
oooo03D0oooo000Q0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0?P3oool20000
0140oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool01P3oool00`0A4A40000007MgM`020000000309VIV@3oool0oooo
00H0oooo00H000000?ooo`3oool0oooo0;^k^`0R8R840?ooo`030000003oool0oooo03D0oooo000Q
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo01D0oooo00D0000009VIV@3oool0^k^k000000050?ooo`030000003o
ool0oooo03@0oooo000P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0D0?ooo`050000000A4A400000014A4@2ZZZX01@3oool00`000000oooo0?oo
o`0d0?ooo`00803oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool07P3oool2000001h0oooo0P0000160?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0d0?ooo`00803oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo03@0oooo000P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0<`3oool001l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`190?ooo`800000
703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03<0oooo000O0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01`3oool2000004<0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03<0oooo000O0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool00`3oool2000004T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<`3oool0
01l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`8000003P3oool20000
02d0oooo00@04A4A000000000000oooo0P0000000`0A4A40oooo0?ooo`060?ooo`H00000503oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo000N0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`800000;03oool01@00
0000oooo0?ooo`3oool000000080oooo1P000000203oool0VIVI028R8P3^k^h0oooo04A4A03oool0
00004`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0380oooo000N0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`800000
1`3oool2000001H0oooo00<000000?ooo`3oool04`3oool2000001D0oooo00<000000?ooo`3oool0
:@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<0VIVI028R8P3^k^h00`3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<P3oool001h0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool02@3oool2000001@0oooo0P00000C0?ooo`030000003oool0oooo01H0oooo
0P00000Y0?ooo`050000003oool0oooo0?ooo`0000000P3oool6000000<0oooo00<0VIVI028R8P3^
k^h00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0<@3oool001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03T0oooo0P00000>0?ooo`8000004P3oool00`000000oooo0?ooo`0@0?ooo`800000
6`3oool2000002L0oooo00D0000008R8R03oool0ZZZZ0000000<0?ooo`0307MgM`1VIVH0oooo0080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0a0?ooo`007@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00h0oooo0P00000h0?ooo`030000003oool0oooo0100oooo
0P00000@0?ooo`030000003oool0oooo00h0oooo0P00000O0?ooo`030000003oool0oooo02<0oooo
00<04A4A0000001gMgL00P0000000`2IVIT0oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0a0?ooo`007@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3oool2000001D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`8000008P3oool00`000000oooo0?oo
o`0a0?ooo`050000002k^k/0oooo09VIV@0A4A401@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0340oooo000M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01H0oooo0`00000<0?ooo`030000003o
ool0oooo00T0oooo0`00000T0?ooo`030000003oool0oooo0340oooo00D0VIVI014A4@0000008R8R
0<c<c0060?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<03oool001d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02h0oooo0P00
000L0?ooo`<000002@3oool00`000000oooo0?ooo`060?ooo`<00000IP3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo0300oooo000L0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01l0oooo10000005
0?ooo`030000003oool0oooo00<0oooo0`00001Z0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0<03oool001`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`140?oo
o`8000009P3oool;000006h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0`0?oo
o`00703oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo000L0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0LP3oool2000007<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0_0?ooo`00703oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo07<0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo02l0oooo000K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0M03oool0
0`000000oooo0?ooo`1c0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0;`3oool0
01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
03h0oooo0P00000d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;`3oool001/0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0Y0?ooo`<000002@3oool5000003/0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0;`3oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0]0?ooo`T00000@03oool00`000000oooo0?ooo`110?ooo`800000<`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02h0oooo000K0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`130?ooo`800000<@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;P3oool001X0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1L0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3o
ool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo02l0oooo
00@04A4A000000000000oooo0P0000000`0A4A40oooo0?ooo`070?ooo`@0000000<04A4A0?ooo`00
0000<@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;P3oool001X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1M0?ooo`0507Mg
M`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000
oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`0000000P3oool6000000@0oooo00<000000?oo
o`3oool00P3oool200000300oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo02h0oooo000J0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0GP3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02h0oooo000J0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0GP3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool3
00000300oooo00D000000?ooo`3oool0oooo000000020?ooo`H00000103oool00`000000oooo0?oo
o`050?ooo`800000;P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0;@3oool001X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1O
0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00D0oooo
00<000000?ooo`3oool0<03oool01@000000R8R80?ooo`2ZZZX0000000`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0]0?ooo`006@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0600oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0;`3oool00`0A4A40000007MgM`020000000309VIV@3oool0oooo00X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`006@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0640oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0640oooo00D0k^k^03<c<`000000
<c<c0>k^kP0<0?ooo`@000001P3oool00`000000oooo0?ooo`0o0?ooo`80EEEE00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000;`3oool001T0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02`0
oooo000I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0/0?ooo`00603oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`000000
;P3oool001P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo07h0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000002h0oooo
000H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0O`3oool200000800oooo00<0
00000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000002h0oooo000H0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`1I0?ooo`800000903o
ool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`000000;@3oool001P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo05/0oooo0P00
000S0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000]0?ooo`005`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:`3o
ool001L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`220?ooo`030000003oool0
oooo05h0oooo0P00000Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool0
01L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo
0600oooo0P00000O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:`3oool001L0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02X0
oooo000G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`1S0?ooo`8000007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo
000F0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`1U0?ooo`800000703oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo000F
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z
0?ooo`005P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo08D0oooo0P0000250?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:P3oool001H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0Y0?ooo`005P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02T0oooo000E0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3o
ool001D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`005@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo000E0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0:03oool001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0000000Z0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0M03oool2000001<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
000Z0?ooo`00503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08X0oooo0P00001g
0?ooo`8000004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000002X0oooo000D0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1h0?oo
o`800000403oool00`000000oooo0?ooo`030?ooo`800000:P3oool001@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo07X0oooo0P00000?0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000:@3oool001@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo07`0oooo0P00000=0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000:@3oool001@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool02`3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000:@3oool001@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo07l0oooo0P00000;0?ooo`030000
003oool0oooo0080oooo0P00000Y0?ooo`004`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo0?ooo`800000:@3oool001<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool02@3oool01P000000oooo0?oo
o`000000oooo000002P0oooo000C0?ooo`050000003oool0oooo0?ooo`000000T@3oool00`000000
oooo0?ooo`2>0?ooo`060000003oool0oooo0000003oool00000:03oool001<0oooo00D000000?oo
o`3oool0oooo0000002A0?ooo`800000T03oool00`000000oooo0?ooo`02000002P0oooo000C0?oo
o`040000003oool0oooo00000980oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`02
000002P0oooo000B0?ooo`050000003oool0oooo0?ooo`000000TP3oool00`000000oooo0?ooo`0A
0?ooo`04014A4@00000000000?ooo`80000000<04A4A0?ooo`3oool01P3oool01@3^k^h0<c<c0000
000c<c<0k^k^06/0oooo00@000000?ooo`0000000000:03oool00180oooo00@000000?ooo`3oool0
0000T`3oool00`000000oooo0?ooo`0B0?ooo`060000003oool0oooo0?ooo`000000oooo1P000002
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0K03oool2000000030?ooo`000000oooo02H0oooo000B
0?ooo`040000003oool0oooo000009<0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?oo
o`3oool0000000T0oooo00D04A4A0?ooo`3oool0oooo014A4@1/0?ooo`040000003oool000000000
02L0oooo000B0?ooo`030000003oool0000009@0oooo00<000000?ooo`3oool04P3oool01P000000
oooo0?ooo`3oool000000?ooo`H000000P3oool01@000000oooo0?ooo`3oool0000006d0oooo0`00
000W0?ooo`004P3oool2000009D0oooo00<000000?ooo`3oool04P3oool01@000000R8R80?ooo`2Z
ZZX0000000T0oooo00D000000?ooo`3oool0oooo0000001]0?ooo`030000003oool0000002L0oooo
000B0?ooo`800000R`3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool04@3o
ool00`0A4A40000007MgM`020000000309VIV@3oool0oooo00L0oooo00D04A4A0?ooo`3oool0oooo
014A4@1Z0?ooo`8000000P3oool2000002L0oooo000A0?ooo`800000SP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0200oooo00D0MgMg09VIV@3oool0VIVI07MgM`1/0?ooo`800000
00<0oooo0000000000009P3oool00140oooo0P00002>0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0803oool01@3^k^h0<c<c0000000c<c<0k^k^06h0oooo0`00000V0?ooo`004@3o
oooo0000038000009P3oool00:40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2l
0?ooo`00X@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;`0oooo002Q0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0_03oool009l0oooo0P1EEED00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0;`0oooo002Y0?ooo`030000003oool0oooo0;`0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo001J0?ooo`05028R8P00
0000000004A4A03MgMd0A03oool300000003014A4@3oool0oooo0;l0oooo001M0?ooo`0307MgM`0c
<c<0oooo04D0oooo00<08R8R0;^k^`3oool0A@3oool010000000oooo0?ooo`0000070?ooo`0307Mg
M`1VIVH0oooo00P0oooo00<0IVIV07MgM`3oool0HP3oool005h0oooo00<000000?ooo`3oool0A03o
ool00`2IVIT0<c<c0?ooo`150?ooo`040000003oool0oooo000000H0oooo00<0gMgM014A4@3^k^h0
2@3oool00`3^k^h04A4A0=gMg@1R0?ooo`00B03oool00`0A4A4000000000000400000080oooo00H0
k^k^05EEE@000000000004A4A02k^k/20?ooo`060>k^kP1EEED00000014A4@3<c<`000000P3oool0
1P3^k^h0EEEE000000000000A4A40;^k^`80oooo00@04A4A000000000000oooo0P000000100A4A40
oooo0>k^kP1EEED20000000409VIV@0000004A4A014A4@D000000`3oool01P3^k^h0EEEE00000000
0000A4A40;^k^`D0oooo0`0000000`0A4A40oooo0?ooo`020?ooo`060>k^kP1EEED000000000001E
EED0k^k^0P3oool5000000@0oooo00<0gMgM0000002k^k/0103oool0100A4A4000000000003oool2
00000004014A4@3oool0k^k^05EEE@80000000<0EEEE0>k^kP3oool00P0000020?ooo`060000003o
ool0oooo0000000A4A40oooo1@0000020?ooo`0609VIV@000000000007MgM`0A4A4000000P3oool5
000000<0oooo00H04A4A03<c<`0000000000014A4@2ZZZX40?ooo`<0000000D04A4A0?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00@0oooo00<0EEEE09VIV@3oool00P3oool200000080
oooo0P0000020?ooo`0308R8R01VIVH0oooo0640oooo001:0?ooo`050000003oool0oooo0?ooo`00
00000P3oool01P1EEED0MgMg0?ooo`3^k^h0MgMg014A4@80oooo00H0EEEE07MgM`3oool0k^k^05EE
E@0000020?ooo`0605EEE@1gMgL0oooo0>k^kP1gMgL04A4A0`3oool01@000000oooo0?ooo`3oool0
00000080oooo00H0EEEE07MgM`3oool0k^k^05EEE@0000030?ooo`030000003oool0oooo00@0oooo
00H0EEEE07MgM`3oool0k^k^07MgM`0A4A460?ooo`030000003oool0oooo00@0oooo00H0EEEE07Mg
M`3oool0oooo07MgM`1EEED40?ooo`030000003oool0oooo00@0oooo00<0EEEE07MgM`0c<c<01@3o
ool01@000000oooo0?ooo`3oool000000080oooo00H0EEEE07MgM`3oool0oooo07MgM`1EEED20?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`050000003<c<`0k^k^08R8R00000001@3oool00`000000oooo0?ooo`030?ooo`060000002Z
ZZX0oooo0?ooo`2k^k/000001@3oool00`000000oooo0?ooo`030?ooo`<000001`3oool00`000000
oooo0?ooo`020?ooo`060>k^kP0R8R80R8R80<c<c0000000c<c<0P3oool00`3^k^h000000?ooo`1Q
0?ooo`00BP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01@3oool0
1P000000oooo0?ooo`3oool0k^k^00000080oooo00<000000?ooo`3oool01P3oool01@000000oooo
0?ooo`3oool000000080oooo00H000000?ooo`3oool0oooo0>k^kP0000030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050=gMg@0A4A40
oooo028R8P3<c<`0103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool01@0A4A40R8R80?ooo`3^k^h0000000D0oooo00<000000?ooo`3oool0103oool0
1@2k^k/0R8R806IVIP1VIVH04A4A00D0oooo00<000000?ooo`3oool03@3oool00`0c<c<0oooo0?oo
o`030?ooo`040=gMg@00000000000<c<c0@0oooo00<000000?ooo`3oool0H03oool004X0oooo00<0
00000?ooo`3oool0103oool600000080oooo00H000000?ooo`3oool0oooo0>k^kP0000020?ooo`H0
00000`3oool01@000000oooo0?ooo`3oool000000080oooo00H000000?ooo`3oool0oooo0>k^kP00
00030?ooo`030000003oool0oooo00@0oooo1P0000060?ooo`<0000000D08R8R0<c<c03oool0oooo
000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@1VIVH0R8R8
0?ooo`2IVIT0EEEE00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo00<0^k^k014A4@0000000P0000050?ooo`030000003oool0oooo00<0oooo00H0
<c<c028R8P1gMgL0MgMg08R8R03^k^h50?ooo`<0000000<08R8R0<c<c03oool02P3oool00`0c<c<0
oooo0?ooo`030?ooo`040>k^kP0R8R8000000>k^kP@0oooo00<000000?ooo`3oool0H03oool004X0
oooo00<000000?ooo`3oool0103oool01P1EEED0R8R80>k^kP3oool0R8R803<c<`80oooo00H0EEEE
07MgM`3oool0k^k^05EEE@0000020?ooo`0605EEE@28R8P0k^k^0?ooo`28R8P0<c<c0`3oool01@00
0000R8R80?ooo`2ZZZX000000080oooo00H0IVIV07MgM`3oool0k^k^05EEE@0000030?ooo`030000
000c<c<0gMgM00@0oooo00H0EEEE08R8R03^k^h0oooo08R8R00c<c<60?ooo`050000003oool0oooo
08R8R00A4A400P3oool01P1EEED0MgMg0?ooo`3oool0MgMg05EEE@@0oooo00<000000?ooo`3oool0
0P3oool00`3^k^h000000>k^kP020?ooo`030000003MgMd0oooo0080oooo00D0000008R8R03oool0
ZZZZ000000020?ooo`0605EEE@1gMgL0oooo0?ooo`1gMgL0EEEE0P3oool01`000000c<c<0<c<c000
0000ZZZZ0=gMg@0R8R80103oool00`000000oooo0?ooo`050?ooo`030<c<c0000000oooo00@0oooo
00<000000?ooo`3oool00`3oool01P000000^k^k0?ooo`3^k^h0MgMg000000D0oooo00D000000?oo
o`3oool0R8R8014A4@0;0?ooo`030000003^k^h0oooo0080oooo00D0k^k^028R8P1gMgL0MgMg03<c
<`030?ooo`030>k^kP000000oooo0640oooo001:0?ooo`030000003oool0oooo00@0oooo00H0k^k^
05EEE@000000000004A4A03^k^h20?ooo`0:0>k^kP1EEED00000028R8P2ZZZX00000014A4@3oool0
k^k^05EEE@80000000L0A4A40>k^kP3oool0oooo014A4@000000MgMg0080000000T0VIVI0?ooo`3o
ool0k^k^05EEE@0000004A4A0<c<c00000000P3oool2000000040:ZZZP0R8R800000028R8P80oooo
00H0k^k^05EEE@000000000004A4A03^k^h60?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1P3^k^h0EEEE000000000000EEEE0>k^kP@0oooo00<000000?ooo`3oool00P3oool0100A4A400000
0000003oool200000006014A4@3oool0oooo014A4@000000MgMg0P0000001@2IVIT0oooo0?ooo`3^
k^h0EEEE0080000000/0EEEE0>k^kP3oool04A4A0000000R8R80000007MgM`0A4A4000000:ZZZP02
0?ooo`03014A4@000000000000D0oooo00@0<c<c000000000000VIVI1@3oool00`000000oooo0?oo
o`030?ooo`060:ZZZP0R8R8000000000000c<c<04A4A1@3oool01@000000oooo0?ooo`3oool00000
00/0oooo00<0EEEE07MgM`3oool00P3oool200000080oooo0P0000020?ooo`0307MgM`1EEED0oooo
0640oooo001:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0503oool01@000000
oooo0?ooo`28R8P04A4A00`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0>0?oo
o`050000003oool0oooo08R8R00A4A402`3oool00`3MgMd04A4A0>k^kP090?ooo`030>k^kP0A4A40
gMgM0680oooo00180?ooo`05014A4@00000000000000000A4A40:@3oool00`000000oooo0?ooo`0C
0?ooo`@0000000<08R8R0<c<c03oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool400000003028R8P3<c<`0oooo00/0oooo00<0MgMg
06IVIP3oool0203oool00`1VIVH0MgMg0?ooo`1R0?ooo`00M@3oool2000002D0oooo0`00000X0?oo
o`03014A4@3oool0oooo00X0oooo0`00002A0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-1, -1, 0, 0}}],

Cell[TextData[{
  "Fig. 4.1  The first five Legendre polynomials. The odd polynomials (",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " odd) are shown with dashed lines, the even polynomials (",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " even) with solid lines."
}], "Caption",
  CellTags->"Fig. 4.1"],

Cell[TextData[{
  "\tOne can verify that these polynomials form an orthogonal set with \
respect to the inner product of Eq. ",
  ButtonBox["(4.1.7)",
    ButtonData:>"(4.1.7)",
    ButtonStyle->"Hyperlink"],
  ". In fact, these polynomials satisfy"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\(P\_n\)(x), \(P\_m\)(
            x))\) = \(\[Delta]\_\(n\ m\)\) \(\(2/\((2  n + 
                1)\)\)\(\ \)\)\)]],
  ","
}], "NE2",
  CellTags->"(4.1.8)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_\(n\ m\)\)]],
  ", the Kronecker \[Delta]-function, is defined by Eq. (",
  ButtonBox["1.6.22",
    ButtonData:>{"Chapter1.nb", "(1.6.22)"},
    ButtonStyle->"Hyperlink"],
  ").  The following is a matrix of inner products over a set of the first \
five Legendre polynomials:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[
      Table[Integrate[LegendreP[n, x]\ LegendreP[m, x], {x, \(-1\), 1}], {n, 
          0, 4}, {m, 0, 4}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2", "0", "0", "0", "0"},
            {"0", \(2\/3\), "0", "0", "0"},
            {"0", "0", \(2\/5\), "0", "0"},
            {"0", "0", "0", \(2\/7\), "0"},
            {"0", "0", "0", "0", \(2\/9\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The matrix is diagonal, as expected from orthogonality, and the values on \
the diagonal agree with Eq. ",
  ButtonBox["(4.1.8)",
    ButtonData:>"(4.1.8)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell["\<\
\t Orthogonal polynomials such as the Legendre polynomials are \
useful because of their simplicity. One can easily integrate over them, or \
take their derivatives analytically.\
\>", "Text"],

Cell[TextData[{
  "\t Using the Gram-Schmidt method, we can construct other orthogonal sets \
by starting with a different set of functions  ",
  Cell[BoxData[
      \(TraditionalForm\`{\(v\_n\)(x)}\)]],
  ". We will see examples of this in the exercises."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.2 Series of Orthogonal Functions", "Subsubtitle",
  CellTags->"c:7"],

Cell[TextData[{
  "Now that we have a set of orthogonal functions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(\[Psi]\_n\)(x)}\)]],
  ",  we will create a ",
  StyleBox["generalized Fourier series",
    FontSlant->"Italic"],
  " in order to represent some function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " defined on a given interval, ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  ". To do so, we write"
}], "Text",
  CellTags->"i:10"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(f(
        x)\  = \ \[Sum]\+n\%\[Infinity]\( c\_n\) \(\(\[Psi]\_n\)(
            x)\)\)\(,\)\)\)]]], "NE2",
  CellTags->"(4.1.9)"],

Cell[TextData[{
  "where the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  "'s are constant coefficients that need to be determined.  These \
coefficients are called ",
  StyleBox["generalized Fourier coefficients",
    FontSlant->"Italic"],
  "; but to save space we will usually refer to them as just Fourier \
coefficients. To find these coefficients, we take an inner product of any one \
of the orthogonal functions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_m\)]],
  ",",
  " with respect to both sides of Eq. ",
  ButtonBox["(4.1.9)",
    ButtonData:>"(4.1.9)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:21"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, 
          f)\) = \[Sum]\+n\%\[Infinity]\( c\_n\)(\[Psi]\_m, \[Psi]\_n)\)]],
  "."
}], "NE2",
  CellTags->"(4.1.10)"],

Cell[TextData[{
  "Orthogonality then implies that all terms in the sum are zero except for \
the term  ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  ", so we obtain an equation for the ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "th coefficient:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\_m = \((\[Psi]\_m, 
            f)\)/\((\[Psi]\_m, \[Psi]\_m)\)\)]],
  "."
}], "NE2",
  CellTags->"(4.1.11)"],

Cell[TextData[{
  "By calculating the required inner products with respect to each function \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_m\)]],
  " in the set, Eq. ",
  ButtonBox["(4.1.11)",
    ButtonData:>"(4.1.11)",
    ButtonStyle->"Hyperlink"],
  " provides us with all of the Fourier coefficients required to construct \
the generalized Fourier series representation of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSay, for example, we wish to represent the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          x)\  = \ \(\(\[ExponentialE]\^\(-x\)\)\(\ \ \)\(sin\)\(\ \)\(3\)  \
\(x\)\(\ \)\)\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < x < 1\)]],
  ". We can do so using the Legendre polynomials, since they form an \
orthogonal set on this interval with respect to the inner product of Eq. ",
  ButtonBox["(4.1.7)",
    ButtonData:>"(4.1.7)",
    ButtonStyle->"Hyperlink"],
  ". First we evaluate the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " using Eq. ",
  ButtonBox["(4.1.11)",
    ButtonData:>"(4.1.11)",
    ButtonStyle->"Hyperlink"],
  ". The required integrals could be found analytically, but the results are \
quite complicated. It is better just to evaluate the integrals numerically:"
}], "Text"],

Cell[BoxData[
    \(c[n_]\  := \(c[n]\  = \ 
        NIntegrate[LegendreP[n, x]\ Exp[\(-x\)]\ Sin[3  x], {x, \(-1\), 1}]/
          Integrate[LegendreP[n, x]^2, {x, \(-1\), 1}]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.5"],

Cell[TextData[{
  "Here we have used the trick of applying two sets of equal signs",
  ",",
  " so as to cause ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to remember these integrals, evaluating each one only once. Next, we \
construct an approximation to the full series, keeping only the first ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " terms:"
}], "Text"],

Cell[BoxData[
    \(f\_approx[x_, M_]\  := \ 
      Sum[c[n]\ LegendreP[n, x], {n, 0, M}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.6"],

Cell[TextData[{
  "We can plot this series and compare it with the exact function, keeping \
increasing numbers of terms, as shown in Cell ",
  ButtonBox["4.7",
    ButtonData:>"Cell 4.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Graphics`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[{Evaluate[f\_approx[x, M]], Sin[3  x]\ Exp[\(-x\)]}, {x, \(-1\), 
            1}, PlotStyle \[Rule] {{Red, Thickness[0.008]}, Blue}, 
          PlotLabel \[Rule] "\<M = \>" <> ToString[M]], {M, 2, 8, 
          2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.7"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.458516 0.23146 [
[.02381 .44602 -6 -9 ]
[.02381 .44602 6 0 ]
[.2619 .44602 -12 -9 ]
[.2619 .44602 12 0 ]
[.7381 .44602 -9 -9 ]
[.7381 .44602 9 0 ]
[.97619 .44602 -3 -9 ]
[.97619 .44602 3 0 ]
[.4875 .11133 -24 -4.5 ]
[.4875 .11133 0 4.5 ]
[.4875 .22706 -12 -4.5 ]
[.4875 .22706 0 4.5 ]
[.4875 .34279 -24 -4.5 ]
[.4875 .34279 0 4.5 ]
[.4875 .57425 -18 -4.5 ]
[.4875 .57425 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45852 m
.02381 .46477 L
s
[(-1)] .02381 .44602 0 1 Mshowa
.2619 .45852 m
.2619 .46477 L
s
[(-0.5)] .2619 .44602 0 1 Mshowa
.7381 .45852 m
.7381 .46477 L
s
[(0.5)] .7381 .44602 0 1 Mshowa
.97619 .45852 m
.97619 .46477 L
s
[(1)] .97619 .44602 0 1 Mshowa
.125 Mabswid
.07143 .45852 m
.07143 .46227 L
s
.11905 .45852 m
.11905 .46227 L
s
.16667 .45852 m
.16667 .46227 L
s
.21429 .45852 m
.21429 .46227 L
s
.30952 .45852 m
.30952 .46227 L
s
.35714 .45852 m
.35714 .46227 L
s
.40476 .45852 m
.40476 .46227 L
s
.45238 .45852 m
.45238 .46227 L
s
.54762 .45852 m
.54762 .46227 L
s
.59524 .45852 m
.59524 .46227 L
s
.64286 .45852 m
.64286 .46227 L
s
.69048 .45852 m
.69048 .46227 L
s
.78571 .45852 m
.78571 .46227 L
s
.83333 .45852 m
.83333 .46227 L
s
.88095 .45852 m
.88095 .46227 L
s
.92857 .45852 m
.92857 .46227 L
s
.25 Mabswid
0 .45852 m
1 .45852 L
s
.5 .11133 m
.50625 .11133 L
s
[(-1.5)] .4875 .11133 1 0 Mshowa
.5 .22706 m
.50625 .22706 L
s
[(-1)] .4875 .22706 1 0 Mshowa
.5 .34279 m
.50625 .34279 L
s
[(-0.5)] .4875 .34279 1 0 Mshowa
.5 .57425 m
.50625 .57425 L
s
[(0.5)] .4875 .57425 1 0 Mshowa
.125 Mabswid
.5 .01874 m
.50375 .01874 L
s
.5 .04189 m
.50375 .04189 L
s
.5 .06504 m
.50375 .06504 L
s
.5 .08818 m
.50375 .08818 L
s
.5 .13447 m
.50375 .13447 L
s
.5 .15762 m
.50375 .15762 L
s
.5 .18076 m
.50375 .18076 L
s
.5 .20391 m
.50375 .20391 L
s
.5 .2502 m
.50375 .2502 L
s
.5 .27335 m
.50375 .27335 L
s
.5 .29649 m
.50375 .29649 L
s
.5 .31964 m
.50375 .31964 L
s
.5 .36593 m
.50375 .36593 L
s
.5 .38908 m
.50375 .38908 L
s
.5 .41222 m
.50375 .41222 L
s
.5 .43537 m
.50375 .43537 L
s
.5 .48166 m
.50375 .48166 L
s
.5 .50481 m
.50375 .50481 L
s
.5 .52795 m
.50375 .52795 L
s
.5 .5511 m
.50375 .5511 L
s
.5 .59739 m
.50375 .59739 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .01472 m
.06244 .0536 L
.10458 .09456 L
.14415 .13165 L
.18221 .16605 L
.22272 .20131 L
.26171 .23392 L
.30316 .26716 L
.34309 .2978 L
.3815 .32599 L
.42237 .35459 L
.46172 .38078 L
.49955 .40472 L
.53984 .42886 L
.57861 .45078 L
.61984 .47268 L
.65954 .4924 L
.69774 .5101 L
.73838 .52757 L
.77751 .54305 L
.81909 .55806 L
.85916 .57113 L
.89771 .58241 L
.93871 .59302 L
.97619 .60145 L
s
0 0 1 r
.5 Mabswid
.02381 .36973 m
.06244 .24064 L
.08255 .1862 L
.10458 .13697 L
.12507 .10097 L
.14415 .0758 L
.15465 .06533 L
.16457 .05755 L
.17348 .0523 L
.1785 .05004 L
.18314 .04839 L
.1878 .04716 L
.19042 .04665 L
.19281 .0463 L
.19389 .04618 L
.19503 .04607 L
.19629 .04598 L
.19746 .04592 L
.19865 .04589 L
.19977 .04588 L
.20078 .04589 L
.20187 .04592 L
.20316 .04599 L
.20436 .04608 L
.20568 .04621 L
.20709 .04638 L
.20998 .04684 L
.21261 .04739 L
.21769 .04878 L
.2225 .05049 L
.23215 .05506 L
.24241 .06149 L
.26083 .07682 L
.29858 .12116 L
.33878 .18255 L
.37747 .24968 L
.41861 .32379 L
.45823 .39279 L
.49634 .45314 L
.5369 .50786 L
.57595 .54937 L
.59586 .56599 L
.61744 .58046 L
.62755 .58598 L
.63824 .59096 L
.64827 .59483 L
.65742 .59771 L
.66686 .60004 L
.67171 .60099 L
.677 .60183 L
Mistroke
.68187 .60244 L
.68425 .60268 L
.68639 .60286 L
.68847 .60301 L
.69071 .60314 L
.69195 .60319 L
.69308 .60323 L
.69415 .60327 L
.69531 .60329 L
.69658 .60331 L
.69778 .60332 L
.69895 .60332 L
.70003 .60331 L
.70119 .60329 L
.70248 .60326 L
.70382 .60322 L
.70507 .60317 L
.70736 .60306 L
.70946 .60293 L
.71417 .60253 L
.71899 .60199 L
.72425 .60124 L
.73485 .59928 L
.74515 .59679 L
.7545 .59408 L
.77546 .58655 L
.8155 .56762 L
.85402 .54549 L
.89499 .51988 L
.93444 .49511 L
.97238 .47266 L
.97619 .47053 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.223101,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`005P3oool20?l009/0oooo00<000000?ooo`3oool0/P3oool001H0oooo0`3o002J0?oo
o`800000/`3oool001L0oooo0`3o002I0?ooo`030000003oool0oooo0;80oooo000H0?ooo`<0o`00
V03oool00`000000oooo0?ooo`2b0?ooo`006@3oool30?l009L0oooo00<000000?ooo`3oool0/P3o
ool001X0oooo0`3o002F0?ooo`030000003oool0oooo0;80oooo000K0?ooo`<0o`00U@3oool00`00
0000oooo0?ooo`2b0?ooo`00703oool30?l009@0oooo00<000000?ooo`3oool0/P3oool001d0oooo
0`3o002C0?ooo`030000003oool0oooo0;80oooo000N0?ooo`<0o`00TP3oool200000;<0oooo000O
0?ooo`<0o`00;03oool70000oeh0oooo00<000000?ooo`3oool0/P3oool00200oooo0`3o000X0?oo
o`<0003o1`3oool30000oe/0oooo00<000000?ooo`3oool0/P3oool00240oooo0`3o000S0?ooo`@0
003o3@3oool30000oeP0oooo00<000000?ooo`3oool0/P3oool00280oooo103o000P0?ooo`030000
o`3oool0oooo0180oooo0P000?mF0?ooo`030000003oool0oooo0;80oooo000S0?ooo`@0o`007P3o
ool00`000?l0oooo0?ooo`0E0?ooo`80003oE03oool00`000000oooo0?ooo`2b0?ooo`009@3oool3
0?l001`0oooo00<0003o0?ooo`3oool0603oool20000oe80oooo00<000000?ooo`3oool0/P3oool0
02H0oooo0`3o000J0?ooo`030000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool0C`3oool20000
0;<0oooo000W0?ooo`<0o`00603oool00`000?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo04h0
oooo00<000000?ooo`3oool0/P3oool002P0oooo0`3o000F0?ooo`030000o`3oool0oooo01l0oooo
00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`2b0?ooo`00:@3oool30?l001@0oooo00<0
003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0;80oooo000Z
0?ooo`<0o`004P3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3oool0oooo04/0oooo00<00000
0?ooo`3oool0/P3oool002/0oooo0`3o000A0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?oo
o`3oool0B`3oool00`000000oooo0?ooo`2b0?ooo`00;03oool30?l000l0oooo00<0003o0?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo0;80oooo000]0?ooo`<0o`00
3@3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0
/P3oool002h0oooo0`3o000;0?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0B03o
ool200000;<0oooo000_0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0
oooo04L0oooo00<000000?ooo`3oool0/P3oool00300oooo103o00060?ooo`030000o`3oool0oooo
02`0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`2b0?ooo`00<@3oool40?l000@0
oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo0;80
oooo000c0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo04D0oooo
00<000000?ooo`3oool0/P3oool003@0oooo0`3o00000`3oool0003o0?ooo`0b0?ooo`030000o`3o
ool0oooo02X0oooo1@0000040?ooo`8000001@3oool4000000H0oooo00<000000?ooo`3oool0/P3o
ool003D0oooo0P3o00000`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo02/0oooo00<00000
0?ooo`3oool0103oool2000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b
0?ooo`00=P3oool00`3o0000003o0?l0000d0?ooo`030000o`3oool0oooo0200oooo1P0000050?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?oo
o`00=P3oool010000?l0o`000?l0003o000d0?ooo`030000o`3oool0oooo02X0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`030?ooo`<00000/P3oool003H0oooo00<0003o0?ooo`3o
00000P3o000d0?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool02`3oool4000000H0
oooo00<000000?ooo`3oool0/P3oool003D0oooo00@0003o0?ooo`3oool0oooo0`3o000d0?ooo`03
0000o`3oool0oooo02P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0;80oooo000e0?ooo`030000o`3oool0oooo0080oooo0`3o000d0?ooo`030000
o`3oool0oooo02L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0;80oooo000d0?ooo`030000o`3oool0oooo00@0oooo0`3o000c0?ooo`030000o`3o
ool0oooo02D0oooo0`00000=0?ooo`@000001P3oool00`000000oooo0?ooo`2b0?ooo`00=03oool0
0`000?l0oooo0?ooo`050?ooo`<0o`00<`3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0
oooo0;80oooo000c0?ooo`030000o`3oool0oooo00L0oooo103o000b0?ooo`030000o`3oool0oooo
03d0oooo00<000000?ooo`3oool0/P3oool003<0oooo00<0003o0?ooo`3oool0203oool40?l00340
oooo00<0003o0?ooo`3oool0?@3oool200000;<0oooo000b0?ooo`030000o`3oool0oooo00/0oooo
0`3o000a0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0/P3oool00380oooo00<0
003o0?ooo`3oool0303oool30?l00340oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`2b0?ooo`00<@3oool00`000?l0oooo0?ooo`0>0?ooo`<0o`00<03oool00`000?l0oooo0?ooo`0k
0?ooo`030000003oool0oooo0;80oooo000a0?ooo`030000o`3oool0oooo00l0oooo0`3o000`0?oo
o`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0/P3oool00300oooo00<0003o0?ooo`3o
ool04@3oool30?l00300oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`2b0?ooo`00
<03oool00`000?l0oooo0?ooo`0B0?ooo`<0o`00;`3oool00`000?l0oooo0?ooo`0i0?ooo`030000
003oool0oooo0;80oooo000_0?ooo`030000o`3oool0oooo01@0oooo0`3o000_0?ooo`030000o`3o
ool0oooo03P0oooo00<000000?ooo`3oool0/P3oool002l0oooo00<0003o0?ooo`3oool05@3oool3
0?l002h0oooo00<0003o0?ooo`3oool0>03oool200000;<0oooo000^0?ooo`030000o`3oool0oooo
01L0oooo0`3o000^0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0/P3oool002h0
oooo00<0003o0?ooo`3oool0603oool40?l002d0oooo00<0003o0?ooo`3oool0=P3oool00`000000
oooo0?ooo`2b0?ooo`00;@3oool00`000?l0oooo0?ooo`0J0?ooo`@0o`00;03oool00`000?l0oooo
0?ooo`0f0?ooo`030000003oool0oooo0;80oooo000]0?ooo`030000o`3oool0oooo01`0oooo0`3o
000/0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0/P3oool002`0oooo00<0003o
0?ooo`3oool07P3oool30?l002`0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`2b
0?ooo`00;03oool00`000?l0oooo0?ooo`0O0?ooo`<0o`00:`3oool00`000?l0oooo0?ooo`0d0?oo
o`030000003oool0oooo0;80oooo000[0?ooo`030000o`3oool0oooo0240oooo0`3o000[0?ooo`03
0000o`3oool0oooo03<0oooo0P00002c0?ooo`00:`3oool00`000?l0oooo0?ooo`0R0?ooo`<0o`00
:`3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0;80oooo000Z0?ooo`030000o`3o
ool0oooo02@0oooo0`3o000Z0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0/P3o
ool002X0oooo00<0003o0?ooo`3oool09@3oool30?l002X0oooo00<0003o0?ooo`3oool0<@3oool0
0`000000oooo0?ooo`2b0?ooo`00:@3oool00`000?l0oooo0?ooo`0W0?ooo`<0o`00:@3oool00`00
0?l0oooo0?ooo`0a0?ooo`030000003oool0oooo0;80oooo000Y0?ooo`030000o`3oool0oooo02P0
oooo0`3o000Y0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0/P3oool002T0oooo
00<0003o0?ooo`3oool0:@3oool30?l002T0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo
0?ooo`2b0?ooo`00:03oool00`000?l0oooo0?ooo`0[0?ooo`@0o`009`3oool00`000?l0oooo0?oo
o`0_0?ooo`030000003oool0oooo0;80oooo000X0?ooo`030000o`3oool0oooo02`0oooo103o000W
0?ooo`030000o`3oool0oooo02h0oooo0P00002c0?ooo`00:03oool00`000?l0oooo0?ooo`0^0?oo
o`<0o`009P3oool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo0;80oooo000W0?ooo`03
0000o`3oool0oooo0300oooo0`3o000V0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3o
ool0/P3oool002L0oooo00<0003o0?ooo`3oool0<@3oool30?l002H0oooo00<0003o0?ooo`3oool0
;03oool00`000000oooo0?ooo`2b0?ooo`009`3oool00`000?l0oooo0?ooo`0b0?ooo`@0o`00903o
ool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000o`3oool0
oooo03@0oooo103o000T0?ooo`030000o`3oool0oooo0240oooo1@0000050?ooo`030000003oool0
oooo0;80oooo000V0?ooo`030000o`3oool0oooo03H0oooo0`3o000S0?ooo`030000o`3oool0oooo
02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`009P3oool00`000?l0
oooo0?ooo`0g0?ooo`<0o`008`3oool00`000?l0oooo0?ooo`0G0?ooo`H000001@3oool00`000000
oooo0?ooo`050?ooo`<00000/P3oool002D0oooo00<0003o0?ooo`3oool0>@3oool30?l002<0oooo
00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo
000U0?ooo`030000o`3oool0oooo03X0oooo0`3o000R0?ooo`030000o`3oool0oooo0240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`009@3oool00`000?l0oooo0?ooo`0k
0?ooo`@0o`008@3oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0?@3oool40?l00200oooo00<0003o0?oo
o`3oool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo000T0?ooo`03
0000o`3oool0oooo03l0oooo0`3o000P0?ooo`030000o`3oool0oooo01d0oooo0`0000070?ooo`03
0000003oool0oooo0;80oooo000T0?ooo`030000o`3oool0oooo0400oooo0`3o000P0?ooo`030000
o`3oool0oooo02H0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0@@3o
ool40?l001h0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`2b0?ooo`008`3oool0
0`000?l0oooo0?ooo`130?ooo`@0o`007P3oool00`000?l0oooo0?ooo`0U0?ooo`800000/`3oool0
02<0oooo00<0003o0?ooo`3oool0A@3oool30?l001d0oooo00<0003o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`2b0?ooo`008`3oool00`000?l0oooo0?ooo`160?ooo`@0o`00703oool00`000?l0
oooo0?ooo`0T0?ooo`030000003oool0oooo0;80oooo000R0?ooo`030000o`3oool0oooo04P0oooo
103o000K0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0
003o0?ooo`3oool0BP3oool30?l001/0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?oo
o`2b0?ooo`008P3oool00`000?l0oooo0?ooo`1;0?ooo`<0o`006P3oool00`000?l0oooo0?ooo`0S
0?ooo`030000003oool0oooo0;80oooo000Q0?ooo`030000o`3oool0oooo04d0oooo103o000I0?oo
o`030000o`3oool0oooo0280oooo00<000000?ooo`3oool0/P3oool00240oooo00<0003o0?ooo`3o
ool0CP3oool40?l001T0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`2b0?ooo`00
8@3oool00`000?l0oooo0?ooo`1@0?ooo`<0o`00603oool00`000?l0oooo0?ooo`0Q0?ooo`800000
/`3oool00200oooo00<0003o0?ooo`3oool0DP3oool40?l001L0oooo00<0003o0?ooo`3oool0803o
ool00`000000oooo0?ooo`2b0?ooo`00803oool00`000?l0oooo0?ooo`1C0?ooo`@0o`005P3oool0
0`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo0;80oooo000P0?ooo`030000o`3oool0oooo
05D0oooo0`3o000F0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool00200
oooo00<0003o0?ooo`3oool0EP3oool30?l001D0oooo00<0003o0?ooo`3oool07`3oool00`000000
oooo0?ooo`2b0?ooo`007`3oool00`000?l0oooo0?ooo`1H0?ooo`@0o`00503oool00`000?l0oooo
0?ooo`0N0?ooo`030000003oool0oooo0;80oooo000O0?ooo`030000o`3oool0oooo05T0oooo103o
000C0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool0/P3oool001l0oooo00<0003o
0?ooo`3oool0F`3oool30?l001<0oooo00<0003o0?ooo`3oool07@3oool200000;<0oooo000N0?oo
o`030000o`3oool0oooo05d0oooo103o000A0?ooo`030000o`3oool0oooo01d0oooo00<000000?oo
o`3oool0/P3oool001h0oooo00<0003o0?ooo`3oool0GP3oool40?l00140oooo00<0003o0?ooo`3o
ool0703oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`000?l0oooo0?ooo`1P0?ooo`<0o`00
403oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0;80oooo000M0?ooo`030000o`3o
ool0oooo0680oooo103o000?0?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0/P3o
ool001d0oooo00<0003o0?ooo`3oool0H`3oool40?l000l0oooo00<0003o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`2b0?ooo`007@3oool00`000?l0oooo0?ooo`1U0?ooo`<0o`003P3oool00`00
0?l0oooo0?ooo`0J0?ooo`030000003oool0oooo0;80oooo000L0?ooo`030000o`3oool0oooo06L0
oooo103o000=0?ooo`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool0/P3oool001`0oooo
00<0003o0?ooo`3oool0J03oool40?l000`0oooo00<0003o0?ooo`3oool06@3oool200000;<0oooo
000L0?ooo`030000o`3oool0oooo06X0oooo0`3o000<0?ooo`030000o`3oool0oooo01P0oooo00<0
00000?ooo`3oool0/P3oool001/0oooo00<0003o0?ooo`3oool0K03oool40?l000X0oooo00<0003o
0?ooo`3oool0603oool00`000000oooo0?ooo`2b0?ooo`006`3oool00`000?l0oooo0?ooo`1]0?oo
o`@0o`002P3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo0;80oooo000K0?ooo`03
0000o`3oool0oooo06l0oooo103o00080?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3o
ool0/P3oool001/0oooo00<0003o0?ooo`3oool0L03oool40?l000L0oooo00<000000000o`000000
1P3oool2000000D0oooo100000060?ooo`030000003oool0oooo0;80oooo000J0?ooo`030000o`3o
ool0oooo07<0oooo103o00040?ooo`050000003oool0oooo0000o`0000001@3oool2000000T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`006P3oool00`000?l0oooo0?oo
o`1c0?ooo`030000003o0000o`0000<0o`000P3oool01@000000oooo0?ooo`000?l000000100oooo
00<000000?ooo`3oool00`3oool300000;80oooo000J0?ooo`030000o`3oool0oooo07H0oooo103o
00000`3oool000000?ooo`020?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2b0?ooo`006@3oool00`000?l0oooo0?ooo`1i0?ooo`@0o`000`3oool0
0`000?l0oooo0?ooo`0:0?ooo`@000001P3oool00`000000oooo0?ooo`2b0?ooo`006@3oool00`00
0?l0oooo0?ooo`1j0?ooo`@0o`000P3oool00`000000003o0?ooo`0:0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0/P3oool001T0oooo00<0003o0?ooo`3oool0O03oool40?l00003
000000000?l0oooo00X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
603oool00`000?l0oooo0?ooo`1n0?ooo`@0o`0000<0oooo0000o`3oool02@3oool4000000H0oooo
00<000000?ooo`3oool0/P3oool001P0oooo00<0003o0?ooo`3oool0P03oool30?l000030?ooo`00
0?l0oooo0180oooo00<000000?ooo`3oool0/P3oool001P0oooo00<0003o0?ooo`3oool0P@3oool3
0?l000030000o`3oool0oooo0140oooo00<000000?ooo`3oool0/P3oool001L0oooo00<0003o0?oo
o`3oool0P`3oool30?l000030000o`3oool0oooo0100oooo0P00002c0?ooo`005`3oool00`000?l0
oooo0?ooo`250?ooo`030?l000000?l0o`000140oooo00<000000?ooo`3oool0/P3oool00:00oooo
00@0o`000000o`3o0000o`003`3oool00`000000oooo0?ooo`2b0?ooo`00X@3oool010000?l0o`00
0?l0003o000>0?ooo`030000003oool0oooo0;80oooo002R0?ooo`040000o`3o0000o`000?l000d0
oooo00<000000?ooo`3oool0/P3oool00:80oooo00<0003o0?ooo`3o00000`3o000;0?ooo`030000
003oool0oooo0;80oooo002S0?ooo`030000o`3oool0o`0000<0o`002P3oool00`000000oooo0?oo
o`2b0?ooo`00Y03oool00`000?l0oooo0?ooo`040?l000P0oooo0P00002c0?ooo`00Y03oool01000
0?l0oooo0?ooo`3oool50?l000H0oooo00<000000?ooo`3oool0/P3oool00:D0oooo00<0003o0?oo
o`3oool00P3oool40?l000D0oooo00<000000?ooo`3oool0/P3oool00:D0oooo00<0003o0?ooo`3o
ool0103oool40?l000<0oooo00<000000?ooo`3oool0/P3oool00:H0oooo00<0003o0?ooo`3oool0
103oool50?l000030?ooo`000000oooo0;<0oooo002W0?ooo`030000o`3oool0oooo00D0oooo103o
00000`000000oooo0?ooo`2b0?ooo`00Y`3oool00`000?l0oooo0?ooo`070?ooo`@0o`00/`3oool0
0:P0oooo00<0003o0?ooo`3oool01`3oool50?l00;40oooo002Y0?ooo`030000o`3oool0oooo00L0
oooo00<000000?l0003o00000`3o002_0?ooo`00Z@3oool00`000?l0oooo0?ooo`070?ooo`030000
003oool0oooo00D0o`00[@3oool001T0oooo1@0000110?ooo`<000001P3oool2000000D0oooo1000
000g0?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool00P3oool40?l003/0oooo0`00
00060?ooo`8000001@3oool400000480oooo1@00000F0?ooo`006`3oool00`000000oooo0?ooo`10
0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000T0oooo00<000000?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo103o000h0?ooo`050000003o
ool0oooo0?ooo`0000001@3oool2000000T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0F0?ooo`00403oool6000000D0oooo00<000000?ooo`3oool0>03oool600000080oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`D0o`00=P3oool01@000000oooo0?ooo`3oool000000100
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo
0?ooo`100?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0f0?ooo`03
0000o`3oool0oooo00@0oooo00<000000?ooo`3oool01`3oool50?l003@0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool05P3oool001/0
oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000`0oooo1000000j0?oo
o`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool02@3oool40?l003<0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`@00000A03oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`00
0000oooo0?ooo`100?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0l
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool02`3oool40?l00340oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool05P3o
ool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000`0oooo00<0
00000?ooo`3oool0?03oool00`000?l0oooo0?ooo`020?ooo`8000003@3oool50?l002l0oooo00D0
00000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
5P3oool001T0oooo0`0000130?ooo`<000003@3oool4000003`0oooo00D0003o0?ooo`3oool0oooo
0000000@0?ooo`@0o`00;`3oool3000000d0oooo100000120?ooo`<00000603oool00;00oooo00@0
003o0?ooo`3oool000004P3oool40?l009h0oooo002`0?ooo`040000o`3oool0oooo000001<0oooo
1@3o002L0?ooo`00/@3oool00`000?l0oooo0000000E0?ooo`@0o`00V`3oool00;80oooo00<0003o
0000003oool05P3oool40?l009T0oooo002b0?ooo`030000o`000000oooo01L0oooo1@3o002G0?oo
o`003`3ooonT000000030000o`000000000001P000001@3o002500000100oooo000G0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000000o`3oool03@3oool00`000000oooo0?ooo`0:0?ooo`D0o`00
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo000G0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0000o`0L0?ooo`@0o`00:`3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01H0oooo002c0?ooo`030000003oool0
003o01h0oooo103o002@0?ooo`00/`3oool010000000oooo0?ooo`000?lN0?ooo`D0o`00M@3oool0
0`000?l0oooo0?ooo`0F0?ooo`00/`3oool01@000000oooo0?ooo`3oool0003o01l0oooo1@3o001a
0?ooo`80003o6@3oool00;<0oooo00D000000?ooo`3oool0oooo0000o`0Q0?ooo`D0o`00K@3oool2
0000oa/0oooo002c0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0803oool50?l0
06T0oooo0P000?lM0?ooo`00/`3oool2000000@0oooo00<0003o0?ooo`3oool08@3oool60?l006@0
oooo0P000?lO0?ooo`00/`3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0280oooo
1P3o001Q0?ooo`030000o`3oool0oooo01l0oooo002c0?ooo`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool09@3oool50?l005d0oooo0P000?lR0?ooo`00/`3oool00`000000oooo0?ooo`05
0?ooo`030000o`3oool0oooo02H0oooo1@3o001I0?ooo`80003o903oool00;<0oooo00<000000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0W0?ooo`D0o`00E@3oool20000obH0oooo002c0?ooo`03
0000003oool0oooo00H0oooo00<0003o0?ooo`3oool0:@3oool50?l00580oooo00<0003o0?ooo`3o
ool09P3oool00;<0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`H0o`00
C@3oool20000obT0oooo002c0?ooo`8000002@3oool00`000?l0oooo0?ooo`0[0?ooo`H0o`00B@3o
ool20000ob/0oooo002c0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0;@3oool5
0?l004H0oooo00<0003o0?ooo`3oool0:`3oool00;<0oooo00<000000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0_0?ooo`D0o`00@P3oool20000obh0oooo002c0?ooo`030000003oool0oooo00X0
oooo00<0003o0?ooo`3oool0<03oool50?l003h0oooo0P000?l`0?ooo`00/`3oool00`000000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo0340oooo1@3o000k0?ooo`030000o`3oool0oooo0300oooo
002c0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0<P3oool60?l003H0oooo0P00
0?lc0?ooo`00/`3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo03<0oooo1P3o000c
0?ooo`030000o`3oool0oooo03<0oooo002c0?ooo`030000003oool0oooo00h0oooo00<0003o0?oo
o`3oool0=@3oool50?l002l0oooo0P000?lf0?ooo`00/`3oool200000100oooo00<0003o0?ooo`3o
ool0=P3oool50?l002`0oooo00<0003o0?ooo`3oool0=P3oool00;<0oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0g0?ooo`H0o`009`3oool20000ocT0oooo002c0?ooo`030000003o
ool0oooo0140oooo00<0003o0?ooo`3oool0>03oool70?l002<0oooo00<0003o0?ooo`3oool0>@3o
ool00;<0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0j0?ooo`H0o`00803oool0
0`000?l0oooo0?ooo`0j0?ooo`00/`3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
03`0oooo1P3o000K0?ooo`80003o?@3oool00;<0oooo00<000000?ooo`3oool0503oool00`000?l0
oooo0?ooo`0m0?ooo`H0o`00603oool00`000?l0oooo0?ooo`0m0?ooo`00/`3oool00`000000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo03l0oooo1P3o000C0?ooo`80003o@03oool00;<0oooo0P00
000G0?ooo`80003o@@3oool70?l000h0oooo0P000?m20?ooo`00/`3oool00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo0440oooo1P3o000:0?ooo`80003oA03oool00;<0oooo00<000000?oo
o`3oool06@3oool00`000?l0oooo0?ooo`130?ooo`H0o`001@3oool20000odH0oooo002c0?ooo`03
0000003oool0oooo01X0oooo00<0003o0?ooo`3oool0A03oool70?l000030?ooo`000?l0oooo04L0
oooo002c0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0AP3oool30?l00080003o
0P3o00170?ooo`00/`3oool00`000000oooo0?ooo`0L0?ooo`80003oA`3oool20000o`P0o`00@`3o
ool009T0oooo0`0000060?ooo`8000001@3oool4000000H0oooo00<000000?ooo`3oool07P3oool0
0`000?l0oooo0?ooo`120?ooo`80003o1@3oool80?l00400oooo002H0?ooo`050000003oool0oooo
0?ooo`0000001@3oool2000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O
0?ooo`80003o@03oool20000o`/0oooo203o000l0?ooo`00V03oool01@000000oooo0?ooo`3oool0
00000100oooo00<000000?ooo`3oool00`3oool300000240oooo00<0003o0?ooo`3oool0>`3oool2
0000oa00oooo203o000i0?ooo`00V03oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03L0oooo0`000?lF
0?ooo`L0o`00=P3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`@000001P3oool0
0`000000oooo0?ooo`0S0?ooo`80003o=@3oool20000oa`0oooo1`3o000c0?ooo`00V03oool01@00
0000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U
0?ooo`80003o<@3oool20000ob40oooo1`3o000`0?ooo`00V03oool01@000000oooo0?ooo`3oool0
000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`80003o;@3oool2
0000obH0oooo2@3o000[0?ooo`00V@3oool3000000d0oooo100000060?ooo`030000003oool0oooo
02T0oooo00<0003o0?ooo`3oool09`3oool30000ob/0oooo2`3o000V0?ooo`00/`3oool00`000000
oooo0?ooo`0Z0?ooo`<0003o903oool20000oc<0oooo2P3o000R0?ooo`00/`3oool00`000000oooo
0?ooo`0]0?ooo`@0003o6`3oool50000ocX0oooo2@3o000N0?ooo`00/`3oool200000380oooo0`00
0?lD0?ooo`@0003o@`3oool90?l001X0oooo002c0?ooo`030000003oool0oooo03@0oooo20000?l6
0?ooo`H0003oB`3oool70?l001P0oooo002c0?ooo`030000003oool0oooo03/0oooo1`000?mE0?oo
o`<0o`00603oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool0
0?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00:00oooo0`0000020?ooo`<000005`3o
ool500000:@0oooo002Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool6
000000X0oooo00@000000?ooo`3oool00000Y03oool00:40oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0:@0oooo002Q0?ooo`060000003oool00000
0000003oool000002@3oool6000000`0oooo00<000000?ooo`3oool0X`3oool00:40oooo00H00000
0?ooo`00000000000?ooo`00000L0?ooo`030000003oool0oooo0:80oooo002Q0?ooo`8000000P3o
ool2000001`0oooo00<000000?ooo`3oool0XP3oool00:40oooo0P0000020?ooo`800000603oool0
1@000000oooo0?ooo`3oool000000:@0oooo002P0?ooo`800000103oool2000001P0oooo0`00002U
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.98099, \
0.00802014, 0.0165001}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.448762 0.242649 [
[.02381 .43626 -6 -9 ]
[.02381 .43626 6 0 ]
[.2619 .43626 -12 -9 ]
[.2619 .43626 12 0 ]
[.7381 .43626 -9 -9 ]
[.7381 .43626 9 0 ]
[.97619 .43626 -3 -9 ]
[.97619 .43626 3 0 ]
[.4875 .08479 -24 -4.5 ]
[.4875 .08479 0 4.5 ]
[.4875 .20611 -12 -4.5 ]
[.4875 .20611 0 4.5 ]
[.4875 .32744 -24 -4.5 ]
[.4875 .32744 0 4.5 ]
[.4875 .57009 -18 -4.5 ]
[.4875 .57009 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .44876 m
.02381 .45501 L
s
[(-1)] .02381 .43626 0 1 Mshowa
.2619 .44876 m
.2619 .45501 L
s
[(-0.5)] .2619 .43626 0 1 Mshowa
.7381 .44876 m
.7381 .45501 L
s
[(0.5)] .7381 .43626 0 1 Mshowa
.97619 .44876 m
.97619 .45501 L
s
[(1)] .97619 .43626 0 1 Mshowa
.125 Mabswid
.07143 .44876 m
.07143 .45251 L
s
.11905 .44876 m
.11905 .45251 L
s
.16667 .44876 m
.16667 .45251 L
s
.21429 .44876 m
.21429 .45251 L
s
.30952 .44876 m
.30952 .45251 L
s
.35714 .44876 m
.35714 .45251 L
s
.40476 .44876 m
.40476 .45251 L
s
.45238 .44876 m
.45238 .45251 L
s
.54762 .44876 m
.54762 .45251 L
s
.59524 .44876 m
.59524 .45251 L
s
.64286 .44876 m
.64286 .45251 L
s
.69048 .44876 m
.69048 .45251 L
s
.78571 .44876 m
.78571 .45251 L
s
.83333 .44876 m
.83333 .45251 L
s
.88095 .44876 m
.88095 .45251 L
s
.92857 .44876 m
.92857 .45251 L
s
.25 Mabswid
0 .44876 m
1 .44876 L
s
.5 .08479 m
.50625 .08479 L
s
[(-1.5)] .4875 .08479 1 0 Mshowa
.5 .20611 m
.50625 .20611 L
s
[(-1)] .4875 .20611 1 0 Mshowa
.5 .32744 m
.50625 .32744 L
s
[(-0.5)] .4875 .32744 1 0 Mshowa
.5 .57009 m
.50625 .57009 L
s
[(0.5)] .4875 .57009 1 0 Mshowa
.125 Mabswid
.5 .10905 m
.50375 .10905 L
s
.5 .13332 m
.50375 .13332 L
s
.5 .15758 m
.50375 .15758 L
s
.5 .18185 m
.50375 .18185 L
s
.5 .23038 m
.50375 .23038 L
s
.5 .25464 m
.50375 .25464 L
s
.5 .27891 m
.50375 .27891 L
s
.5 .30317 m
.50375 .30317 L
s
.5 .3517 m
.50375 .3517 L
s
.5 .37597 m
.50375 .37597 L
s
.5 .40023 m
.50375 .40023 L
s
.5 .4245 m
.50375 .4245 L
s
.5 .47303 m
.50375 .47303 L
s
.5 .49729 m
.50375 .49729 L
s
.5 .52156 m
.50375 .52156 L
s
.5 .54582 m
.50375 .54582 L
s
.5 .06052 m
.50375 .06052 L
s
.5 .03626 m
.50375 .03626 L
s
.5 .01199 m
.50375 .01199 L
s
.5 .59435 m
.50375 .59435 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .38666 m
.04262 .29757 L
.06244 .21913 L
.08426 .14971 L
.10458 .09959 L
.12297 .06527 L
.14264 .03911 L
.15285 .02949 L
.15823 .02544 L
.16394 .02189 L
.16892 .01939 L
.17441 .01728 L
.17682 .01656 L
.17941 .01592 L
.18185 .01544 L
.18408 .01511 L
.18537 .01496 L
.18658 .01486 L
.18767 .01479 L
.18885 .01474 L
.19013 .01472 L
.19078 .01472 L
.19149 .01473 L
.19275 .01477 L
.19393 .01483 L
.19511 .01493 L
.19623 .01504 L
.19834 .01531 L
.2006 .0157 L
.20307 .01622 L
.20829 .01769 L
.21383 .01976 L
.22379 .02476 L
.23316 .03085 L
.24326 .03884 L
.26154 .05666 L
.30268 .10974 L
.3423 .17279 L
.38041 .23939 L
.42097 .31198 L
.46002 .37957 L
.50152 .44533 L
.5415 .49999 L
.57997 .5426 L
.59945 .56005 L
.62088 .57587 L
.64124 .58757 L
.66029 .59555 L
.67069 .59872 L
.67582 .59997 L
Mistroke
.68057 .60095 L
.68523 .60175 L
.68944 .60232 L
.69413 .60281 L
.69669 .60301 L
.69911 .60315 L
.70028 .6032 L
.70153 .60325 L
.70271 .60328 L
.70378 .6033 L
.70504 .60332 L
.70575 .60332 L
.70641 .60332 L
.70762 .60331 L
.7089 .60329 L
.71012 .60326 L
.71144 .60321 L
.71381 .6031 L
.71664 .60291 L
.71923 .60269 L
.72354 .60222 L
.72824 .60157 L
.73771 .5998 L
.74802 .59721 L
.75736 .59431 L
.77833 .58597 L
.81836 .56415 L
.85688 .53817 L
.89785 .50876 L
.93731 .48287 L
.97525 .4647 L
.97619 .46437 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35568 m
.06244 .22035 L
.08255 .16328 L
.10458 .11167 L
.12507 .07393 L
.14415 .04755 L
.15465 .03656 L
.16457 .02842 L
.17348 .02291 L
.1785 .02054 L
.18314 .01881 L
.1878 .01752 L
.19042 .01699 L
.19281 .01662 L
.19389 .01649 L
.19503 .01637 L
.19629 .01628 L
.19746 .01622 L
.19865 .01618 L
.19977 .01617 L
.20078 .01619 L
.20187 .01622 L
.20316 .0163 L
.20436 .01639 L
.20568 .01652 L
.20709 .01671 L
.20998 .01719 L
.21261 .01776 L
.21769 .01922 L
.2225 .02101 L
.23215 .0258 L
.24241 .03254 L
.26083 .04861 L
.29858 .0951 L
.33878 .15946 L
.37747 .22983 L
.41861 .30753 L
.45823 .37986 L
.49634 .44312 L
.5369 .50049 L
.57595 .54401 L
.59586 .56143 L
.61744 .5766 L
.62755 .58238 L
.63824 .5876 L
.64827 .59166 L
.65742 .59469 L
.66686 .59713 L
.67171 .59812 L
.677 .59901 L
Mistroke
.68187 .59965 L
.68425 .59989 L
.68639 .60009 L
.68847 .60024 L
.69071 .60037 L
.69195 .60043 L
.69308 .60047 L
.69415 .60051 L
.69531 .60054 L
.69658 .60056 L
.69778 .60056 L
.69895 .60056 L
.70003 .60055 L
.70119 .60054 L
.70248 .60051 L
.70382 .60046 L
.70507 .60041 L
.70736 .60029 L
.70946 .60015 L
.71417 .59974 L
.71899 .59917 L
.72425 .59839 L
.73485 .59632 L
.74515 .59372 L
.7545 .59088 L
.77546 .58299 L
.8155 .56314 L
.85402 .53994 L
.89499 .51309 L
.93444 .48712 L
.97238 .46359 L
.97619 .46136 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.223101,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo0019
0?ooo`H0o`0010000?l00`3o0000oooo0?ooo`1M0?ooo`030000003oool0oooo0;80oooo00150?oo
o`H0o`001@000?l30?l000D0003oF`3oool00`000000oooo0?ooo`2b0?ooo`00@`3oool60?l00080
003o203oool50?l00080003oF@3oool00`000000oooo0?ooo`2b0?ooo`00@P3oool40?l000030?oo
o`000?l0003o00/0oooo1P3o00000`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo0;80oooo
00110?ooo`<0o`0000<0oooo0000o`000?l0403oool40?l00080003oEP3oool00`000000oooo0?oo
o`2b0?ooo`00@03oool30?l000030?ooo`000?l0oooo01@0oooo0`3o00020000oe@0oooo00<00000
0?ooo`3oool0/P3oool003l0oooo0`3o00000`3oool0003o0?ooo`0F0?ooo`<0o`0000<0oooo0000
o`000?l0DP3oool00`000000oooo0?ooo`2b0?ooo`00?P3oool30?l000030?ooo`000?l0oooo01P0
oooo0`3o00020?ooo`030000o`3oool0oooo04l0oooo0P00002c0?ooo`00?@3oool30?l00080oooo
00<0003o0?ooo`3oool0603oool30?l00080oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo
0?ooo`2b0?ooo`00?@3oool20?l00080oooo00<0003o0?ooo`3oool06P3oool30?l00080oooo00<0
003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`2b0?ooo`00?03oool30?l000030?ooo`000?l0
oooo01d0oooo0`3o00020?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0/P3oool0
03/0oooo0`3o00000`3oool0003o0?ooo`0O0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`1;0?oo
o`030000003oool0oooo0;80oooo000j0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0O0?ooo`<0
o`0000<0oooo0000o`3oool0C03oool00`000000oooo0?ooo`2b0?ooo`00>P3oool20?l00080oooo
00<0003o0?ooo`3oool08@3oool30?l000030?ooo`000?l0oooo04/0oooo00<000000?ooo`3oool0
/P3oool003T0oooo0`3o00000`3oool0003o0?ooo`0T0?ooo`<0o`0000<0oooo0000o`3oool0BP3o
ool00`000000oooo0?ooo`2b0?ooo`00>03oool30?l000030?ooo`000?l0oooo02H0oooo0P3o0002
0?ooo`030000o`3oool0oooo04P0oooo0P00002c0?ooo`00=`3oool30?l000030?ooo`000?l0oooo
02L0oooo0`3o00020?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0/P3oool003L0
oooo0P3o00000`3oool0003o0?ooo`0Y0?ooo`<0o`0000<0oooo0000o`3oool0B03oool00`000000
oooo0?ooo`2b0?ooo`00=P3oool30?l000030000o`3oool0oooo02X0oooo0`3o00000`3oool0003o
0?ooo`170?ooo`030000003oool0oooo0;80oooo000f0?ooo`80o`0000<0003o0?ooo`3oool0;03o
ool20?l00080oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00=@3oool3
0?l000030000o`3oool0oooo02`0oooo0`3o00020?ooo`030000o`3oool0oooo02X0oooo1@000004
0?ooo`8000001@3oool4000000H0oooo00<000000?ooo`3oool0/P3oool003D0oooo0P3o00000`00
0?l0oooo0?ooo`0^0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo
00@0oooo0P0000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool003@0
oooo0`3o00000`000?l0oooo0?ooo`0_0?ooo`<0o`0000<0oooo0000o`3oool08@3oool6000000D0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80
oooo000d0?ooo`80o`0000<0003o0?ooo`3oool0<@3oool30?l000030?ooo`000?l0oooo02/0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`030?ooo`<00000/P3oool003<0oooo0`3o
00000`000?l0oooo0?ooo`0b0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo000c0?ooo`80o`0000<0003o
0?ooo`3oool0<`3oool30?l00080oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0/P3oool00380oooo0`3o00000`00
0?l0oooo0?ooo`0d0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00<P3oool20?l00003
0?ooo`000?l0oooo03H0oooo0`3o00000`3oool0003o0?ooo`0V0?ooo`<000003@3oool4000000H0
oooo00<000000?ooo`3oool0/P3oool00340oooo0`3o00000`000?l0oooo0?ooo`0g0?ooo`80o`00
0P3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000a0?ooo`80o`0000<0
oooo0000o`3oool0>03oool30?l00080oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?oo
o`2b0?ooo`00<03oool30?l000030000o`3oool0oooo03T0oooo0`3o00000`3oool0003o0?ooo`0n
0?ooo`030000003oool0oooo0;80oooo000`0?ooo`80o`0000<0oooo0000o`3oool0>`3oool30?l0
00030?ooo`000?l0oooo03d0oooo0P00002c0?ooo`00;`3oool30?l000030000o`3oool0oooo03`0
oooo0P3o00000`3oool0003o0?ooo`0m0?ooo`030000003oool0oooo0;80oooo000_0?ooo`80o`00
00<0oooo0000o`3oool0?@3oool30?l000030?ooo`000?l0oooo03`0oooo00<000000?ooo`3oool0
/P3oool002l0oooo0P3o00000`000?l0oooo0?ooo`0n0?ooo`<0o`0000<0oooo0000o`3oool0>`3o
ool00`000000oooo0?ooo`2b0?ooo`00;P3oool30?l000030000o`3oool0oooo03l0oooo0P3o0000
0`3oool0003o0?ooo`0k0?ooo`030000003oool0oooo0;80oooo000^0?ooo`80o`0000<0003o0?oo
o`3oool0@03oool30?l000030?ooo`000?l0oooo03X0oooo00<000000?ooo`3oool0/P3oool002d0
oooo0`3o00000`000?l0oooo0?ooo`110?ooo`80o`000P3oool00`000?l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo0;80oooo000]0?ooo`80o`0000<0003o0?ooo`3oool0@P3oool30?l000030?oo
o`000?l0oooo03T0oooo00<000000?ooo`3oool0/P3oool002`0oooo0`3o00000`000?l0oooo0?oo
o`130?ooo`<0o`0000<0oooo0000o`3oool0>03oool200000;<0oooo000/0?ooo`80o`0000<0003o
0?ooo`3oool0A@3oool20?l000030?ooo`000?l0oooo03P0oooo00<000000?ooo`3oool0/P3oool0
02`0oooo0P3o00000`000?l0oooo0?ooo`150?ooo`<0o`0000<0oooo0000o`3oool0=`3oool00`00
0000oooo0?ooo`2b0?ooo`00:`3oool30?l000030000o`3oool0oooo04H0oooo0`3o00000`3oool0
003o0?ooo`0f0?ooo`030000003oool0oooo0;80oooo000[0?ooo`80o`0000<0003o0?ooo`3oool0
B03oool20?l000030?ooo`000?l0oooo03H0oooo00<000000?ooo`3oool0/P3oool002X0oooo0`3o
00000`000?l0oooo0?ooo`180?ooo`<0o`0000<0oooo0000o`3oool0=@3oool00`000000oooo0?oo
o`2b0?ooo`00:P3oool20?l000030000o`3oool0oooo04X0oooo0P3o00000`3oool0003o0?ooo`0e
0?ooo`030000003oool0oooo0;80oooo000Z0?ooo`80o`0000<0003o0?ooo`3oool0BP3oool30?l0
00030?ooo`000?l0oooo03@0oooo00<000000?ooo`3oool0/P3oool002T0oooo0P3o00000`000?l0
oooo0?ooo`1<0?ooo`<0o`0000<0oooo0000o`3oool0<`3oool200000;<0oooo000Y0?ooo`80o`00
00<0003o0?ooo`3oool0C@3oool20?l000030?ooo`000?l0oooo03<0oooo00<000000?ooo`3oool0
/P3oool002T0oooo00<0o`000000o`3oool0C`3oool30?l000030?ooo`000?l0oooo0380oooo00<0
00000?ooo`3oool0/P3oool002P0oooo0P3o00000`000?l0oooo0?ooo`1?0?ooo`80o`0000<0oooo
0000o`3oool0<P3oool00`000000oooo0?ooo`2b0?ooo`00:03oool00`3o0000003o0?ooo`1A0?oo
o`<0o`0000<0oooo0000o`3oool0<@3oool00`000000oooo0?ooo`2b0?ooo`00:03oool00`3o0000
003o0?ooo`1B0?ooo`<0o`0000<0oooo0000o`3oool0<03oool00`000000oooo0?ooo`2b0?ooo`00
9`3oool20?l000030000o`3oool0oooo0580oooo0P3o00000`3oool0003o0?ooo`0`0?ooo`030000
003oool0oooo0;80oooo000W0?ooo`030?l000000?l0oooo05@0oooo0`3o00000`3oool0003o0?oo
o`0_0?ooo`030000003oool0oooo0;80oooo000W0?ooo`030?l000000?l0oooo05D0oooo0`3o0000
0`000?l0oooo0?ooo`0^0?ooo`800000/`3oool002H0oooo0P3o00000`000?l0oooo0?ooo`1E0?oo
o`80o`0000<0oooo0000o`3oool0;P3oool00`000000oooo0?ooo`2b0?ooo`009P3oool00`3o0000
003o0?ooo`1G0?ooo`<0o`0000<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`2b0?ooo`00
9P3oool00`3o0000003o0?ooo`1H0?ooo`80o`0000<0oooo0000o`3oool0;@3oool00`000000oooo
0?ooo`2b0?ooo`009P3oool00`3o0000003o0?ooo`1H0?ooo`<0o`0000<0oooo0000o`3oool0;03o
ool00`000000oooo0?ooo`2b0?ooo`009@3oool00`3o0000003o0?l0001J0?ooo`<0o`0000<0003o
0?ooo`3oool08@3oool5000000D0oooo00<000000?ooo`3oool0/P3oool002D0oooo00<0o`000000
o`3oool0F`3oool20?l000030?ooo`000?l0oooo02<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`2b0?ooo`009@3oool00`3o0000003o0?ooo`1K0?ooo`<0o`0000<0003o0?ooo`3o
ool05`3oool6000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00
903oool00`3o0000003o0?l0001M0?ooo`<0o`0000<0003o0?ooo`3oool08@3oool00`000000oooo
0?ooo`050?ooo`<00000/P3oool002@0oooo00<0o`000000o`3oool0GP3oool20?l000030000o`3o
ool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00903oool0
0`3o0000003o0?ooo`1N0?ooo`<0o`0000<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030?l000000?l0o`000600oooo0P3o00000`00
0?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002<0
oooo00<0o`000000o`3oool0H03oool30?l000030000o`3oool0oooo01d0oooo0`0000070?ooo`03
0000003oool0oooo0;80oooo000S0?ooo`030?l000000?l0oooo0640oooo0`3o00000`000?l0oooo
0?ooo`0V0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030?l000000?l0oooo0680oooo0P3o
00000`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo0;80oooo000R0?ooo`030?l000000?l0
o`0006<0oooo0`3o00000`000?l0oooo0?ooo`0U0?ooo`030000003oool0oooo0;80oooo000R0?oo
o`030?l000000?l0oooo06@0oooo0P3o00000`000?l0oooo0?ooo`0U0?ooo`800000/`3oool00280
oooo00<0o`000000o`3oool0I03oool30?l000030000o`3oool0oooo02@0oooo00<000000?ooo`3o
ool0/P3oool00280oooo00<0003o0?l0003oool0I@3oool20?l000030000o`3oool0oooo02@0oooo
00<000000?ooo`3oool0/P3oool00240oooo00<0o`000000o`3o0000I`3oool20?l000030000o`3o
ool0oooo02<0oooo00<000000?ooo`3oool0/P3oool00240oooo00<0o`000000o`3oool0I`3oool2
0?l000030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0/P3oool00240oooo00<0o`000000
o`3oool0J03oool20?l000030000o`3oool0oooo0280oooo00<000000?ooo`3oool0/P3oool00200
oooo00<0o`000000o`3o0000J@3oool20?l000030000o`3oool0oooo0280oooo00<000000?ooo`3o
ool0/P3oool00200oooo00<0o`000000o`3oool0JP3oool20?l000030000o`3oool0oooo0240oooo
0P00002c0?ooo`00803oool00`3o0000003o0?ooo`1Z0?ooo`80o`0000<0003o0?ooo`3oool08@3o
ool00`000000oooo0?ooo`2b0?ooo`00803oool00`000?l0o`000?ooo`1[0?ooo`80o`0000<0003o
0?ooo`3oool0803oool00`000000oooo0?ooo`2b0?ooo`007`3oool00`3o0000003o0?l0001]0?oo
o`030?l000000?l0oooo0240oooo00<000000?ooo`3oool0/P3oool001l0oooo00<0o`000000o`3o
ool0K@3oool20?l000030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool001l0oooo
00<0o`000000o`3oool0KP3oool00`3o0000003o0?ooo`0P0?ooo`030000003oool0oooo0;80oooo
000O0?ooo`030000o`3o0000oooo06h0oooo0P3o00000`000?l0oooo0?ooo`0N0?ooo`030000003o
ool0oooo0;80oooo000N0?ooo`030?l000000?l0o`000700oooo00<0o`000000o`3oool07`3oool0
0`000000oooo0?ooo`2b0?ooo`007P3oool00`3o0000003o0?ooo`1`0?ooo`80o`0000<0003o0?oo
o`3oool07@3oool200000;<0oooo000N0?ooo`030000o`3o0000oooo0740oooo00<0o`000000o`3o
ool07P3oool00`000000oooo0?ooo`2b0?ooo`007@3oool00`3o0000003o0?l0001b0?ooo`80o`00
00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`2b0?ooo`007@3oool00`3o0000003o0?oo
o`1c0?ooo`030?l000000?l0oooo01d0oooo00<000000?ooo`3oool0/P3oool001d0oooo00<0003o
0?l0003oool0L`3oool20?l000030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0/P3oool0
01d0oooo00<0003o0?l0003oool0M03oool00`3o0000003o0?ooo`0L0?ooo`030000003oool0oooo
0;80oooo000L0?ooo`030?l000000?l0o`0007D0oooo0P3o00000`000?l0oooo0?ooo`0J0?ooo`03
0000003oool0oooo0;80oooo000L0?ooo`030?l000000?l0oooo07H0oooo00<0o`000000o`3o0000
6`3oool00`000000oooo0?ooo`2b0?ooo`00703oool00`000?l0o`000?ooo`1g0?ooo`030?l00000
0?l0oooo01X0oooo0P00002c0?ooo`00703oool00`000?l0o`000?ooo`1g0?ooo`030?l000000?l0
o`0001X0oooo00<000000?ooo`3oool0/P3oool001/0oooo00<0o`000000o`3o0000N@3oool00`3o
0000003o0?ooo`0I0?ooo`030000003oool0oooo0;80oooo000K0?ooo`030000o`3o0000oooo07T0
oooo00<0o`000000o`3o00006@3oool00`000000oooo0?ooo`2b0?ooo`006`3oool00`000?l0o`00
0?ooo`1j0?ooo`030?l000000?l0oooo01P0oooo00<000000?ooo`3oool0/P3oool001/0oooo00<0
003o0?l0003oool0NP3oool00`3o0000003o0?l0000H0?ooo`030000003oool0oooo0;80oooo000K
0?ooo`030000o`3o0000oooo07/0oooo00<0o`000000o`0000001P3oool2000000D0oooo10000006
0?ooo`030000003oool0oooo0;80oooo000J0?ooo`030000o`3o0000o`0007/0oooo00D000000?l0
003o0000003o000000050?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0;80oooo000J0?ooo`030000o`3o0000oooo07<0oooo1P0000020?ooo`050000003oool0o`00
0000o`3o0000403oool00`000000oooo0?ooo`030?ooo`<00000/P3oool001X0oooo00<0003o0?l0
003oool0N`3oool01@000000oooo0?ooo`3o0000003o0100oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2b0?ooo`006@3oool00`000?l0o`000?l0001l0?ooo`060000003oool0oooo
0?l000000?l0o`002`3oool4000000H0oooo00<000000?ooo`3oool0/P3oool001T0oooo00<0003o
0?l0003o0000O03oool01P000000oooo0?ooo`3oool0o`000000o`/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`2b0?ooo`006@3oool00`000?l0o`000?l0001l0?ooo`070000003o
ool0oooo0?ooo`3o0000003o0?l0000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0/P3oool001T0oooo00<0003o0?l0003oool0O@3oool3000000040?ooo`3o0000003o0?l000T0
oooo100000060?ooo`030000003oool0oooo0;80oooo000H0?ooo`030000o`3o0000o`0008<0oooo
00<0o`000000o`3oool04P3oool00`000000oooo0?ooo`2b0?ooo`00603oool00`000?l0o`000?l0
00230?ooo`030?l000000?l0o`000180oooo00<000000?ooo`3oool0/P3oool001P0oooo00<0003o
0?l0003o0000Q03oool00`3o0000003o0?ooo`0A0?ooo`800000/`3oool001L0oooo00@0003o0?l0
003o0000o`00Q03oool00`3o0000003o0?l0000A0?ooo`030000003oool0oooo0;80oooo000G0?oo
o`030000o`3o0000o`0008H0oooo00<0o`000000o`3o0000403oool00`000000oooo0?ooo`2b0?oo
o`00603oool20?l008L0oooo00<0003o0?l0003oool03`3oool00`000000oooo0?ooo`2b0?ooo`00
603oool20?l008L0oooo00<0o`000000o`3o00003`3oool00`000000oooo0?ooo`2b0?ooo`00603o
ool20?l008P0oooo00<0003o0?l0003oool03P3oool00`000000oooo0?ooo`2b0?ooo`005`3oool3
0?l008P0oooo00<0o`000000o`3o00003P3oool00`000000oooo0?ooo`2b0?ooo`005`3oool20?l0
08X0oooo00<0o`000000o`3o00003@3oool00`000000oooo0?ooo`2b0?ooo`005`3oool20?l008/0
oooo00<0003o0?l0003oool0303oool200000;<0oooo000G0?ooo`80o`00R`3oool00`3o0000003o
0?l0000<0?ooo`030000003oool0oooo0;80oooo000G0?ooo`80o`00S03oool00`000?l0o`000?oo
o`0;0?ooo`030000003oool0oooo0;80oooo000F0?ooo`<0o`00S03oool00`3o0000003o0?l0000;
0?ooo`030000003oool0oooo0;80oooo000F0?ooo`80o`00SP3oool00`3o0000003o0?ooo`0:0?oo
o`030000003oool0oooo0;80oooo000F0?ooo`80o`00SP3oool00`3o0000003o0?l0000:0?ooo`03
0000003oool0oooo0;80oooo002W0?ooo`030?l000000?l0o`0000T0oooo00<000000?ooo`3oool0
/P3oool00:P0oooo00<0003o0?l0003oool0203oool00`000000oooo0?ooo`2b0?ooo`00Z03oool0
0`3o0000003o0?l000080?ooo`800000/`3oool00:T0oooo00<0o`000000o`3oool01`3oool00`00
0000oooo0?ooo`2b0?ooo`00Z@3oool00`3o0000003o0?l000070?ooo`030000003oool0oooo0;80
oooo000I0?ooo`D00000@@3oool3000000H0oooo0P0000050?ooo`@00000=`3oool00`3o0000003o
0?l000060?ooo`030000003oool0oooo0440oooo0`0000060?ooo`8000001@3oool400000480oooo
1@00000F0?ooo`006`3oool00`000000oooo0?ooo`100?ooo`050000003oool0oooo0?ooo`000000
1@3oool2000000T0oooo00<000000?ooo`3oool0=@3oool00`3o0000003o0?ooo`050?ooo`030000
003oool0oooo0400oooo00D000000?ooo`3oool0oooo000000050?ooo`8000002@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo01H0oooo000@0?ooo`H000001@3oool00`000000oooo
0?ooo`0h0?ooo`H000000P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3o
ool0=@3oool00`3o0000003o0?l000050?ooo`030000003oool0oooo0400oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool05P3oool001/0
oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool000000100oooo00<000000?oo
o`3oool0=P3oool00`3o0000003o0?ooo`040?ooo`030000003oool0oooo0400oooo00D000000?oo
o`3oool0oooo0000000@0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool05P3oool0
01/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000`0oooo1000000i
0?ooo`030?l000000?l0o`0000@0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3o
ool0000000`0oooo100000140?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003oool0
oooo0400oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo03/0oooo00<0
o`000000o`3o00000`3oool200000440oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03o
ool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0?03oool00`3o0000003o
0?ooo`020?ooo`030000003oool0oooo0400oooo00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool05P3oool001T0oooo0`0000130?ooo`<00000
3@3oool4000003/0oooo00<0o`000000o`3o00000P3oool00`000000oooo0?ooo`110?ooo`<00000
3@3oool400000480oooo0`00000H0?ooo`00[`3oool01@3o0000003o0?ooo`3oool000000;@0oooo
002_0?ooo`050?l000000?l0o`000?ooo`000000]03oool00;00oooo00@0o`000000o`3o00000000
]03oool00;40oooo00<0o`000000o`000000]03oool00;40oooo00<0o`000000o`3o0000]03oool0
00l0ooooX`0000000`3o0000003o0000002S00000100oooo000G0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo0P3o00000`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo000G0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`3o0000003o0?l0001;0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool05P3oool00;<0oooo00@000000?l000000?l0o`00
/@3oool00;<0oooo00D000000?ooo`3o0000003o0?l0002G0?ooo`030000o`3oool0oooo01H0oooo
002c0?ooo`050000003oool0oooo0000o`3o0000U@3oool20000o`030?l0003oool0oooo01H0oooo
002c0?ooo`060000003oool0oooo0?l000000?l0o`00TP3oool00`3o0000003o0?l000020?l001P0
oooo002c0?ooo`070000003oool0oooo0?ooo`3o0000003o0?l0002?0?ooo`030?l000000?l0003o
0080o`006P3oool00;<0oooo0P0000030?ooo`030?l000000?l0o`0008/0oooo0P3o00020000o`80
o`00703oool00;<0oooo00<000000?ooo`3oool00`3oool00`000?l0o`000?ooo`280?ooo`<0o`00
00<0003o0?l0003o00007P3oool00;<0oooo00<000000?ooo`3oool00`3oool00`3o0000003o0?l0
00260?ooo`<0o`000P000?lQ0?ooo`00/`3oool00`000000oooo0?ooo`040?ooo`030?l000000?l0
o`0008<0oooo0`3o00020000ob<0oooo002c0?ooo`030000003oool0oooo00D0oooo00<0003o0?l0
003o0000P@3oool30?l000030000o`3oool0oooo02<0oooo002c0?ooo`030000003oool0oooo00H0
oooo00<0003o0?l0003o0000OP3oool30?l00080003o9P3oool00;<0oooo00<000000?ooo`3oool0
1`3oool00`000?l0o`000?ooo`1l0?ooo`<0o`0000<0003o0?ooo`3oool09P3oool00;<0oooo00<0
00000?ooo`3oool01`3oool00`000?l0o`000?l0001j0?ooo`<0o`000P000?lY0?ooo`00/`3oool2
000000T0oooo00<0003o0?l0003o0000N03oool20?l00080003o:`3oool00;<0oooo00<000000?oo
o`3oool02@3oool00`000?l0o`000?l0001f0?ooo`80o`0000<0003o0?ooo`3oool0:`3oool00;<0
oooo00<000000?ooo`3oool02@3oool00`000?l0o`000?l0001d0?ooo`80o`000P000?l^0?ooo`00
/`3oool00`000000oooo0?ooo`0:0?ooo`030000o`3o0000o`000780oooo00@0o`000000o`000?l0
o`00;`3oool00;<0oooo00<000000?ooo`3oool02`3oool00`000?l0o`000?l0001_0?ooo`80o`00
00<0003o0?l0003oool0<03oool00;<0oooo00<000000?ooo`3oool0303oool00`000?l0o`000?l0
001]0?ooo`040?l000000?l0003o0?l00380oooo002c0?ooo`030000003oool0oooo00d0oooo00<0
003o0?l0003o0000JP3oool20?l000030000o`3o0000oooo03<0oooo002c0?ooo`030000003oool0
oooo00h0oooo00<0003o0?l0003o0000J03oool0103o0000003o0000o`3o000e0?ooo`00/`3oool2
00000100oooo00<0003o0?l0003o0000I@3oool20?l000030000o`3o0000oooo03H0oooo002c0?oo
o`030000003oool0oooo0100oooo00<0003o0?l0003oool0H`3oool0103o0000003o0000o`3o000h
0?ooo`00/`3oool00`000000oooo0?ooo`0@0?ooo`030?l000000?l0o`000680oooo00<0o`000000
o`3o0000>P3oool00;<0oooo00<000000?ooo`3oool04@3oool00`3o0000003o0?l0001O0?ooo`80
o`0000<0003o0?l0003oool0>P3oool00;<0oooo00<000000?ooo`3oool04P3oool00`3o0000003o
0?l0001M0?ooo`040?l000000?l0003o0?l003`0oooo002c0?ooo`030000003oool0oooo01<0oooo
00<0o`000000o`3o0000FP3oool20?l000030000o`3o0000oooo03d0oooo002c0?ooo`030000003o
ool0oooo01@0oooo00<0o`000000o`3o0000F03oool0103o0000003o0000o`3o000o0?ooo`00/`3o
ool00`000000oooo0?ooo`0E0?ooo`040?l000000?l0o`000?l005@0oooo00@0o`000000o`000?l0
o`00@@3oool00;<0oooo0P00000G0?ooo`040?l000000?l0o`000?l00580oooo0P000?l20?l00480
oooo002c0?ooo`030000003oool0oooo01P0oooo00@0003o0?l0003o0000o`00CP3oool20000o`80
o`00A03oool00;<0oooo00<000000?ooo`3oool06@3oool010000?l0o`000?l0003o001<0?ooo`04
0000o`3o0000o`000?l004D0oooo002c0?ooo`030000003oool0oooo01X0oooo00@0003o0?l0003o
0000o`00B@3oool20000o`80o`00A`3oool00;<0oooo00<000000?ooo`3oool06`3oool00`000?l0
o`000?l000020?l004D0oooo0P000?l30?l004P0oooo002I0?ooo`<000001P3oool2000000D0oooo
100000060?ooo`030000003oool0oooo01`0oooo0P000?l30?l00480oooo0P000?l40?l004T0oooo
002H0?ooo`050000003oool0oooo0?ooo`0000001@3oool2000000T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0N0?ooo`040000o`3o0000o`000?l003l0oooo0P000?l40?l004/0
oooo002H0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01l0oooo0P000?l20?l003`0oooo0P000?l50?l004`0oooo002H0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?ooo`<000008@3oool00`000?l0
o`000?l0000i0?ooo`80003o1@3o001>0?ooo`00V03oool01@000000oooo0?ooo`3oool0000000`0
oooo100000060?ooo`030000003oool0oooo0280oooo00<0003o0?l0003o0000=`3oool00`000?l0
o`000?l000030?l00500oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo0P000?l20?l003<0oooo0P000?l40?l00580
oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo02@0oooo00<0o`000000o`000?l00P3o000_0?ooo`80003o103o001D0?ooo`00
V@3oool3000000d0oooo100000060?ooo`030000003oool0oooo02H0oooo00D0o`000000o`000?l0
003o0?l0000[0?ooo`80003o1@3o001E0?ooo`00/`3oool00`000000oooo0?ooo`0X0?ooo`80o`00
0P000?l00`3o0000oooo0?ooo`0T0?ooo`<0003o1@3o001G0?ooo`00/`3oool00`000000oooo0?oo
o`0Z0?ooo`80o`000P000?l00`3o0000oooo0?ooo`0P0?ooo`80003o1P3o001I0?ooo`00/`3oool0
0`000000oooo0?ooo`0/0?ooo`80o`000`000?lK0?ooo`D0003o1P3o001K0?ooo`00/`3oool20000
02l0oooo0`3o00030000oa@0oooo10000?l30?ooo`D0o`00GP3oool00;<0oooo00<000000?ooo`3o
ool0<03oool40?l000H0003o2@3oool50000o`030?ooo`3o0000o`0000L0o`00H03oool00;<0oooo
00<000000?ooo`3oool0<`3oool70?l000T0003o3@3o001R0?ooo`00/`3oool00`000000oooo0?oo
o`0g0?oooa<0o`00J03oool00;<0oooo00<000000?ooo`3oool0?@3oool70?l006h0oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002P0?ooo`<0
00000P3oool3000001T0oooo0`00002T0?ooo`00X@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo1P00000<0?ooo`030000003oool0oooo0:<0oooo002Q0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool05P3oool500000:@0oooo002Q0?ooo`060000003oool0
00000000003oool000002@3oool6000000T0oooo00@000000?ooo`3oool00000Y@3oool00:40oooo
00H000000?ooo`00000000000?ooo`00000I0?ooo`030000003oool000000:D0oooo002Q0?ooo`80
00000P3oool2000001T0oooo00<000000?ooo`000000Y@3oool00:40oooo0P0000020?ooo`800000
6P3oool200000:D0oooo002P0?ooo`800000103oool2000001X0oooo00<000000?ooo`3oool0X`3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.84944, \
0.00802014, 0.0157393}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.450362 0.244365 [
[.02381 .43786 -6 -9 ]
[.02381 .43786 6 0 ]
[.2619 .43786 -12 -9 ]
[.2619 .43786 12 0 ]
[.7381 .43786 -9 -9 ]
[.7381 .43786 9 0 ]
[.97619 .43786 -3 -9 ]
[.97619 .43786 3 0 ]
[.4875 .08381 -24 -4.5 ]
[.4875 .08381 0 4.5 ]
[.4875 .206 -12 -4.5 ]
[.4875 .206 0 4.5 ]
[.4875 .32818 -24 -4.5 ]
[.4875 .32818 0 4.5 ]
[.4875 .57254 -18 -4.5 ]
[.4875 .57254 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45036 m
.02381 .45661 L
s
[(-1)] .02381 .43786 0 1 Mshowa
.2619 .45036 m
.2619 .45661 L
s
[(-0.5)] .2619 .43786 0 1 Mshowa
.7381 .45036 m
.7381 .45661 L
s
[(0.5)] .7381 .43786 0 1 Mshowa
.97619 .45036 m
.97619 .45661 L
s
[(1)] .97619 .43786 0 1 Mshowa
.125 Mabswid
.07143 .45036 m
.07143 .45411 L
s
.11905 .45036 m
.11905 .45411 L
s
.16667 .45036 m
.16667 .45411 L
s
.21429 .45036 m
.21429 .45411 L
s
.30952 .45036 m
.30952 .45411 L
s
.35714 .45036 m
.35714 .45411 L
s
.40476 .45036 m
.40476 .45411 L
s
.45238 .45036 m
.45238 .45411 L
s
.54762 .45036 m
.54762 .45411 L
s
.59524 .45036 m
.59524 .45411 L
s
.64286 .45036 m
.64286 .45411 L
s
.69048 .45036 m
.69048 .45411 L
s
.78571 .45036 m
.78571 .45411 L
s
.83333 .45036 m
.83333 .45411 L
s
.88095 .45036 m
.88095 .45411 L
s
.92857 .45036 m
.92857 .45411 L
s
.25 Mabswid
0 .45036 m
1 .45036 L
s
.5 .08381 m
.50625 .08381 L
s
[(-1.5)] .4875 .08381 1 0 Mshowa
.5 .206 m
.50625 .206 L
s
[(-1)] .4875 .206 1 0 Mshowa
.5 .32818 m
.50625 .32818 L
s
[(-0.5)] .4875 .32818 1 0 Mshowa
.5 .57254 m
.50625 .57254 L
s
[(0.5)] .4875 .57254 1 0 Mshowa
.125 Mabswid
.5 .10825 m
.50375 .10825 L
s
.5 .13269 m
.50375 .13269 L
s
.5 .15712 m
.50375 .15712 L
s
.5 .18156 m
.50375 .18156 L
s
.5 .23043 m
.50375 .23043 L
s
.5 .25487 m
.50375 .25487 L
s
.5 .27931 m
.50375 .27931 L
s
.5 .30374 m
.50375 .30374 L
s
.5 .35262 m
.50375 .35262 L
s
.5 .37705 m
.50375 .37705 L
s
.5 .40149 m
.50375 .40149 L
s
.5 .42593 m
.50375 .42593 L
s
.5 .4748 m
.50375 .4748 L
s
.5 .49923 m
.50375 .49923 L
s
.5 .52367 m
.50375 .52367 L
s
.5 .54811 m
.50375 .54811 L
s
.5 .05938 m
.50375 .05938 L
s
.5 .03494 m
.50375 .03494 L
s
.5 .0105 m
.50375 .0105 L
s
.5 .59698 m
.50375 .59698 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .35797 m
.06244 .22005 L
.08255 .16226 L
.10458 .11024 L
.12507 .0724 L
.14415 .04607 L
.15465 .03516 L
.16457 .02709 L
.17348 .02167 L
.1785 .01934 L
.18314 .01766 L
.1878 .01642 L
.19042 .01591 L
.19166 .01571 L
.19281 .01556 L
.19398 .01543 L
.19503 .01533 L
.19621 .01526 L
.19746 .0152 L
.19855 .01518 L
.19973 .01518 L
.20084 .0152 L
.20187 .01524 L
.20306 .01532 L
.20434 .01543 L
.20665 .01571 L
.2094 .01616 L
.2119 .0167 L
.21734 .01825 L
.2225 .02019 L
.23215 .02504 L
.24241 .03183 L
.26083 .04797 L
.29858 .09449 L
.33878 .15886 L
.37747 .22937 L
.41861 .30745 L
.45823 .38042 L
.49634 .44446 L
.5369 .5027 L
.57595 .54688 L
.59729 .56567 L
.61744 .57984 L
.62716 .58544 L
.63746 .59051 L
.6471 .59446 L
.65591 .59742 L
.66535 .5999 L
.6702 .6009 L
.67548 .6018 L
Mistroke
.68036 .60243 L
.68273 .60268 L
.68488 .60287 L
.68695 .60302 L
.6892 .60315 L
.69043 .6032 L
.69157 .60324 L
.69265 .60327 L
.6938 .6033 L
.69502 .60331 L
.69571 .60332 L
.69635 .60332 L
.69753 .60331 L
.69877 .6033 L
.69988 .60327 L
.70092 .60324 L
.7033 .60315 L
.70586 .60301 L
.7082 .60284 L
.71347 .60233 L
.71775 .60179 L
.72242 .60107 L
.73182 .59923 L
.75147 .59382 L
.77243 .58601 L
.81398 .56567 L
.85402 .54211 L
.89254 .5176 L
.93351 .4905 L
.97296 .4628 L
.97619 .4604 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35662 m
.06244 .22034 L
.08255 .16286 L
.10458 .11088 L
.12507 .07288 L
.14415 .04631 L
.15465 .03525 L
.16457 .02704 L
.17348 .0215 L
.1785 .01911 L
.18314 .01737 L
.1878 .01607 L
.19042 .01553 L
.19281 .01516 L
.19389 .01503 L
.19503 .01492 L
.19629 .01482 L
.19746 .01476 L
.19865 .01472 L
.19977 .01472 L
.20078 .01473 L
.20187 .01476 L
.20316 .01484 L
.20436 .01493 L
.20568 .01507 L
.20709 .01525 L
.20998 .01574 L
.21261 .01631 L
.21769 .01778 L
.2225 .01959 L
.23215 .02441 L
.24241 .0312 L
.26083 .04738 L
.29858 .0942 L
.33878 .15901 L
.37747 .22988 L
.41861 .30813 L
.45823 .38097 L
.49634 .44468 L
.5369 .50246 L
.57595 .54628 L
.59586 .56382 L
.61744 .5791 L
.62755 .58493 L
.63824 .59019 L
.64827 .59428 L
.65742 .59732 L
.66686 .59978 L
.67171 .60078 L
.677 .60167 L
Mistroke
.68187 .60231 L
.68425 .60256 L
.68639 .60276 L
.68847 .60291 L
.69071 .60304 L
.69195 .6031 L
.69308 .60315 L
.69415 .60318 L
.69531 .60321 L
.69658 .60323 L
.69778 .60324 L
.69895 .60324 L
.70003 .60323 L
.70119 .60321 L
.70248 .60318 L
.70382 .60314 L
.70507 .60308 L
.70736 .60296 L
.70946 .60282 L
.71417 .6024 L
.71899 .60183 L
.72425 .60105 L
.73485 .59897 L
.74515 .59635 L
.7545 .59348 L
.77546 .58554 L
.8155 .56555 L
.85402 .54219 L
.89499 .51515 L
.93444 .48899 L
.97238 .4653 L
.97619 .46305 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.223101,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo001;
0?ooo`030?l000000?l0003o00T0003oG03oool00`000000oooo0?ooo`2b0?ooo`00B03oool0103o
0000003o0000o`000?l;0?l000030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0/P3oool0
04H0oooo00<0o`000000o`000?l00`3o00080?ooo`@0o`000`000?mH0?ooo`030000003oool0oooo
0;80oooo00150?ooo`040?l000000?l0o`000?l000h0oooo103o00020000oeH0oooo00<000000?oo
o`3oool0/P3oool004@0oooo00<0o`000000o`3o00004`3oool30?l00080003oE03oool00`000000
oooo0?ooo`2b0?ooo`00@`3oool00`3o0000003o0?l0000F0?ooo`<0o`0000<0003o0?ooo`3oool0
D@3oool00`000000oooo0?ooo`2b0?ooo`00@P3oool00`3o0000003o0?l0000H0?ooo`<0o`0000<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`2b0?ooo`00@@3oool00`3o0000003o0?l0000J
0?ooo`<0o`0000<0003o0?ooo`3oool0C`3oool200000;<0oooo00100?ooo`030?l000000?l0o`00
01d0oooo0P3o00000`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo0;80oooo000o0?ooo`03
0?l000000?l0o`0001l0oooo0P3o00000`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo0;80
oooo000n0?ooo`030?l000000?l0o`000240oooo0P3o00000`000?l0oooo0?ooo`1<0?ooo`030000
003oool0oooo0;80oooo000n0?ooo`030?l000000?l0oooo0280oooo0P3o00000`000?l0oooo0?oo
o`1;0?ooo`030000003oool0oooo0;80oooo000m0?ooo`030?l000000?l0o`0002@0oooo00<0o`00
0000o`3oool0C03oool00`000000oooo0?ooo`2b0?ooo`00?03oool00`3o0000003o0?l0000U0?oo
o`80o`0000<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`2b0?ooo`00>`3oool00`3o0000
003o0?l0000W0?ooo`80o`0000<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`2b0?ooo`00
>P3oool00`3o0000003o0?l0000Y0?ooo`80o`0000<0003o0?ooo`3oool0B03oool200000;<0oooo
000j0?ooo`030?l000000?l0oooo02X0oooo0P3o00000`000?l0oooo0?ooo`170?ooo`030000003o
ool0oooo0;80oooo000i0?ooo`030?l000000?l0o`0002`0oooo00<0o`000000o`3oool0B03oool0
0`000000oooo0?ooo`2b0?ooo`00>03oool00`3o0000003o0?l0000]0?ooo`80o`0000<0003o0?oo
o`3oool0AP3oool00`000000oooo0?ooo`2b0?ooo`00=`3oool00`3o0000003o0?l0000_0?ooo`80
o`0000<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00=`3oool00`3o0000003o
0?ooo`0`0?ooo`80o`0000<0003o0?ooo`3oool0:P3oool5000000@0oooo0P0000050?ooo`@00000
1P3oool00`000000oooo0?ooo`2b0?ooo`00=P3oool00`3o0000003o0?l0000b0?ooo`80o`0000<0
003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`8000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0;80oooo000f0?ooo`030?l000000?l0oooo03<0oooo00<0o`00
0000o`3oool08@3oool6000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0;80oooo000e0?ooo`030?l000000?l0o`0003@0oooo0P3o00000`00
0?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool30000
0;80oooo000e0?ooo`030?l000000?l0oooo03D0oooo0P3o00000`000?l0oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo000d0?ooo`030?l0
00000?l0o`0003L0oooo0P3o00000`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00=03oool00`3o0000003o0?oo
o`0h0?ooo`80o`0000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0/P3oool003<0oooo00<0o`000000o`3o0000>P3oool0
0`3o0000003o0?ooo`0V0?ooo`<000003@3oool4000000H0oooo00<000000?ooo`3oool0/P3oool0
03<0oooo00<0o`000000o`3oool0>P3oool20?l000030000o`3oool0oooo03h0oooo00<000000?oo
o`3oool0/P3oool00380oooo00<0o`000000o`3o0000?03oool20?l000030000o`3oool0oooo03d0
oooo00<000000?ooo`3oool0/P3oool00380oooo00<0o`000000o`3oool0?@3oool00`3o0000003o
0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000a0?ooo`030?l000000?l0o`0003h0oooo0P3o
00000`000?l0oooo0?ooo`0l0?ooo`800000/`3oool00340oooo00<0o`000000o`3oool0?`3oool0
0`3o0000003o0?ooo`0m0?ooo`030000003oool0oooo0;80oooo000`0?ooo`030?l000000?l0o`00
0400oooo0P3o00000`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0;80oooo000`0?ooo`03
0?l000000?l0oooo0440oooo0P3o00000`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0;80
oooo000_0?ooo`030?l000000?l0o`0004<0oooo00<0o`000000o`3oool0>`3oool00`000000oooo
0?ooo`2b0?ooo`00;`3oool00`3o0000003o0?ooo`130?ooo`80o`0000<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`3o0000003o0?l000150?ooo`80o`0000<0003o
0?ooo`3oool0>03oool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`3o0000003o0?ooo`160?oo
o`030?l000000?l0oooo03T0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0o`000000o`3o
0000A`3oool20?l000030000o`3oool0oooo03L0oooo0P00002c0?ooo`00;@3oool00`3o0000003o
0?ooo`180?ooo`030?l000000?l0oooo03P0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0
o`000000o`3oool0B03oool20?l000030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0/P3o
ool002`0oooo00<0o`000000o`3o0000BP3oool20?l000030000o`3oool0oooo03D0oooo00<00000
0?ooo`3oool0/P3oool002`0oooo00<0o`000000o`3oool0B`3oool00`3o0000003o0?ooo`0f0?oo
o`030000003oool0oooo0;80oooo000[0?ooo`030?l000000?l0o`0004`0oooo0P3o00000`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo0;80oooo000[0?ooo`030?l000000?l0oooo04d0oooo
00<0o`000000o`3oool0=@3oool00`000000oooo0?ooo`2b0?ooo`00:P3oool00`3o0000003o0?l0
001>0?ooo`80o`0000<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`2b0?ooo`00:P3oool0
0`3o0000003o0?ooo`1?0?ooo`80o`0000<0003o0?ooo`3oool0<P3oool200000;<0oooo000Y0?oo
o`030?l000000?l0o`000540oooo00<0o`000000o`3oool0<`3oool00`000000oooo0?ooo`2b0?oo
o`00:@3oool00`3o0000003o0?ooo`1A0?ooo`80o`0000<0003o0?ooo`3oool0<@3oool00`000000
oooo0?ooo`2b0?ooo`00:@3oool00`3o0000003o0?ooo`1B0?ooo`030?l000000?l0oooo0380oooo
00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000o`3o0000D`3oool20?l000030000o`3o
ool0oooo0300oooo00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000o`3oool0E03oool2
0?l000030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000
o`3oool0E@3oool00`3o0000003o0?ooo`0`0?ooo`030000003oool0oooo0;80oooo000W0?ooo`03
0?l000000?l0o`0005H0oooo0P3o00000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo0;80
oooo000W0?ooo`030?l000000?l0oooo05L0oooo00<0o`000000o`3oool0;`3oool200000;<0oooo
000W0?ooo`030?l000000?l0oooo05L0oooo0P3o00000`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo0;80oooo000V0?ooo`030?l000000?l0o`0005T0oooo00<0o`000000o`3oool0;P3oool0
0`000000oooo0?ooo`2b0?ooo`009P3oool00`3o0000003o0?ooo`1I0?ooo`80o`0000<0003o0?oo
o`3oool0;03oool00`000000oooo0?ooo`2b0?ooo`009P3oool00`3o0000003o0?ooo`1J0?ooo`80
o`0000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`2b0?ooo`009@3oool00`3o0000003o
0?l0001L0?ooo`030?l000000?l0oooo0280oooo1@0000050?ooo`030000003oool0oooo0;80oooo
000U0?ooo`030?l000000?l0oooo05`0oooo0P3o00000`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002D0oooo00<0o`000000o`3oool0G@3oool0
0`3o0000003o0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;80oooo000T0?ooo`030?l000000?l0o`0005h0oooo0P3o00000`000?l0oooo0?ooo`0Q0?oo
o`030000003oool0oooo00D0oooo0`00002b0?ooo`00903oool00`3o0000003o0?ooo`1O0?ooo`03
0?l000000?l0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00
903oool00`3o0000003o0?ooo`1O0?ooo`80o`0000<0003o0?ooo`3oool0803oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0;80oooo000S0?ooo`030?l000000?l0o`000640oooo00<0
o`000000o`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo000S
0?ooo`030?l000000?l0oooo0640oooo0P3o00000`000?l0oooo0?ooo`0M0?ooo`<000001`3oool0
0`000000oooo0?ooo`2b0?ooo`008`3oool00`3o0000003o0?ooo`1R0?ooo`80o`0000<0003o0?oo
o`3oool09P3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`3o0000003o0?ooo`1S0?ooo`03
0?l000000?l0oooo02L0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0o`000000o`3o0000
I03oool20?l000030000o`3oool0oooo02D0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0
o`000000o`3oool0I@3oool00`3o0000003o0?ooo`0V0?ooo`800000/`3oool00280oooo00<0o`00
0000o`3oool0I@3oool20?l000030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool0
0240oooo00<0o`000000o`3o0000I`3oool00`3o0000003o0?ooo`0U0?ooo`030000003oool0oooo
0;80oooo000Q0?ooo`030?l000000?l0oooo06L0oooo0P3o00000`000?l0oooo0?ooo`0S0?ooo`03
0000003oool0oooo0;80oooo000Q0?ooo`030?l000000?l0oooo06P0oooo00<0o`000000o`3oool0
903oool00`000000oooo0?ooo`2b0?ooo`008@3oool00`3o0000003o0?ooo`1X0?ooo`80o`0000<0
003o0?ooo`3oool08P3oool00`000000oooo0?ooo`2b0?ooo`00803oool00`3o0000003o0?l0001Z
0?ooo`030?l000000?l0oooo02<0oooo00<000000?ooo`3oool0/P3oool00200oooo00<0o`000000
o`3oool0JP3oool20?l000030000o`3oool0oooo0240oooo00<000000?ooo`3oool0/P3oool00200
oooo00<0o`000000o`3oool0J`3oool00`3o0000003o0?ooo`0R0?ooo`800000/`3oool001l0oooo
00<0o`000000o`3o0000K03oool20?l000030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
/P3oool001l0oooo00<0o`000000o`3oool0K@3oool00`3o0000003o0?ooo`0Q0?ooo`030000003o
ool0oooo0;80oooo000O0?ooo`030?l000000?l0oooo06d0oooo0P3o00000`000?l0oooo0?ooo`0O
0?ooo`030000003oool0oooo0;80oooo000O0?ooo`030?l000000?l0oooo06h0oooo00<0o`000000
o`3oool0803oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`3o0000003o0?l0001_0?ooo`80
o`0000<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`3o0000003o
0?ooo`1`0?ooo`030?l000000?l0oooo01l0oooo00<000000?ooo`3oool0/P3oool001h0oooo00<0
o`000000o`3oool0L03oool20?l000030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0/P3o
ool001d0oooo00<0o`000000o`3o0000LP3oool00`3o0000003o0?ooo`0N0?ooo`800000/`3oool0
01d0oooo00<0o`000000o`3oool0LP3oool20?l000030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool0/P3oool001d0oooo00<0o`000000o`3oool0L`3oool00`3o0000003o0?ooo`0M0?ooo`03
0000003oool0oooo0;80oooo000L0?ooo`030?l000000?l0o`0007@0oooo0P3o00000`000?l0oooo
0?ooo`0K0?ooo`030000003oool0oooo0;80oooo000L0?ooo`030?l000000?l0oooo07D0oooo00<0
o`000000o`3oool0703oool00`000000oooo0?ooo`2b0?ooo`00703oool00`3o0000003o0?ooo`1e
0?ooo`80o`0000<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`2b0?ooo`00703oool00`3o
0000003o0?ooo`1f0?ooo`030?l000000?l0oooo01/0oooo00<000000?ooo`3oool0/P3oool001/0
oooo00<0o`000000o`3o0000M`3oool20?l000030000o`3oool0oooo01T0oooo00<000000?ooo`3o
ool0/P3oool001/0oooo00<0o`000000o`3oool0N03oool00`3o0000003o0?ooo`0J0?ooo`800000
/`3oool001/0oooo00<0o`000000o`3oool0N03oool20?l000030000o`3oool0oooo01P0oooo00<0
00000?ooo`3oool0/P3oool001X0oooo00<0o`000000o`3o0000NP3oool00`3o0000003o0?ooo`0I
0?ooo`030000003oool0oooo0;80oooo000J0?ooo`030?l000000?l0oooo07X0oooo0P3o00000`00
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo0;80oooo000J0?ooo`030?l000000?l0oooo07/0
oooo00<0o`000000o`3oool0603oool00`000000oooo0?ooo`2b0?ooo`006P3oool00`3o0000003o
0?ooo`1k0?ooo`80o`0000<0003o0000003oool01@3oool2000000D0oooo100000060?ooo`030000
003oool0oooo0;80oooo000I0?ooo`030?l000000?l0o`0007`0oooo00D000000?l000000?l0oooo
000000050?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo
000I0?ooo`030?l000000?l0oooo07@0oooo1P0000020?ooo`050000003o0000o`000000o`000000
403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo000I0?ooo`030?l00000
0?l0oooo07`0oooo00D000000?ooo`3o0000o`000000o`0@0?ooo`030000003oool0oooo00<0oooo
0`00002b0?ooo`00603oool00`3o0000003o0?l0001m0?ooo`050000003oool0oooo0?l000000?l0
303oool4000000H0oooo00<000000?ooo`3oool0/P3oool001P0oooo00<0o`000000o`3oool0O@3o
ool00`000000oooo0?ooo`020?l000030000o`3oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`2b0?ooo`00603oool00`3o0000003o0?ooo`1m0?ooo`060000003oool0
oooo0?ooo`3o0000003o2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000H0?ooo`030?l000000?l0oooo07h0oooo0`0000020?l000030000o`3oool0oooo00P0oooo1000
00060?ooo`030000003oool0oooo0;80oooo000G0?ooo`030?l000000?l0o`0008<0oooo00<0o`00
0000o`3oool04`3oool00`000000oooo0?ooo`2b0?ooo`005`3oool00`3o0000003o0?ooo`230?oo
o`80o`0000<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`2b0?ooo`005`3oool00`3o0000
003o0?ooo`240?ooo`030?l000000?l0oooo0180oooo00<000000?ooo`3oool0/P3oool001H0oooo
00<0o`000000o`3o0000Q@3oool20?l000030000o`3oool0oooo0100oooo0P00002c0?ooo`005P3o
ool00`3o0000003o0?ooo`260?ooo`030?l000000?l0oooo0140oooo00<000000?ooo`3oool0/P3o
ool001H0oooo0P3o00270?ooo`80o`0000<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`2b
0?ooo`00X03oool00`3o0000003o0?ooo`0@0?ooo`030000003oool0oooo0;80oooo002P0?ooo`80
o`0000<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`2b0?ooo`00X@3oool20?l000030000
o`3oool0oooo00d0oooo00<000000?ooo`3oool0/P3oool00:80oooo00<0o`000000o`3oool03P3o
ool00`000000oooo0?ooo`2b0?ooo`00XP3oool20?l000030000o`3oool0oooo00`0oooo00<00000
0?ooo`3oool0/P3oool00:<0oooo00<0o`000000o`3oool03@3oool200000;<0oooo002S0?ooo`80
o`0000<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`2b0?ooo`00Y03oool00`3o0000003o
0?ooo`0<0?ooo`030000003oool0oooo0;80oooo002T0?ooo`80o`0000<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`2b0?ooo`00Y@3oool20?l000030000o`3oool0oooo00T0oooo00<00000
0?ooo`3oool0/P3oool00:H0oooo00<0o`000000o`3oool02P3oool00`000000oooo0?ooo`2b0?oo
o`00YP3oool20?l000030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0/P3oool00:L0oooo
00<0o`000000o`3oool02@3oool00`000000oooo0?ooo`2b0?ooo`00Y`3oool20?l000030000o`3o
ool0oooo00L0oooo0P00002c0?ooo`00Z03oool20?l000030000o`3oool0oooo00H0oooo00<00000
0?ooo`3oool0/P3oool001T0oooo1@0000110?ooo`<000001P3oool2000000D0oooo1000000f0?oo
o`030?l000000?l0oooo00L0oooo00<000000?ooo`3oool0@@3oool3000000H0oooo0P0000050?oo
o`@00000@P3oool5000001H0oooo000K0?ooo`030000003oool0oooo0400oooo00D000000?ooo`3o
ool0oooo000000050?ooo`8000002@3oool00`000000oooo0?ooo`0c0?ooo`80o`0000<0003o0?oo
o`3oool01@3oool00`000000oooo0?ooo`100?ooo`050000003oool0oooo0?ooo`0000001@3oool2
000000T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`00403oool60000
00D0oooo00<000000?ooo`3oool0>03oool600000080oooo00D000000?ooo`3oool0oooo0000000@
0?ooo`030000003oool0oooo03@0oooo0P3o00000`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo0400oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool0=@3oool00`3o0000003o0?ooo`050?ooo`030000003o
ool0oooo0400oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?oo
o`3oool0000000`0oooo1000000h0?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`000000oooo
0?ooo`100?ooo`050000003oool0oooo0?ooo`000000303oool4000004@0oooo00<000000?ooo`3o
ool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool0>P3oool00`3o0000003o0?ooo`040?ooo`030000003oool0oooo0400
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool0>P3oool20?l000030000o`3oool0oooo0080oooo0P0000110?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01H0oooo000I0?ooo`<00000@`3oool3000000d0oooo1000000j0?ooo`80o`0000D0003o0?oo
o`3oool0oooo000000130?ooo`<000003@3oool400000480oooo0`00000H0?ooo`00[P3oool00`3o
0000003o0?ooo`020?ooo`030000003oool0oooo0;80oooo002^0?ooo`80o`0000@0003o0?ooo`3o
ool00000]03oool00:l0oooo00D0o`000000o`3oool0oooo0000002d0?ooo`00[`3oool20?l00003
0000o`3oool000000;@0oooo002`0?ooo`80o`0000<0003o0000003oool0/`3oool00;40oooo00<0
o`000000o`000000]03oool000l0ooooXP0000020?l000030000o`00000000000:800000403oool0
01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool20?l000030000o`3oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool05P3oool001L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03
0?l000000?l0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0F0?ooo`00
/`3oool20?l000030000o`3oool0oooo09H0oooo0P3o000H0?ooo`00/`3oool010000000o`000?l0
00000?nE0?ooo`040?l000000?l0003o0000oaP0oooo002c0?ooo`040000003oool0o`000000oi@0
oooo00@0o`000000o`3o0000o`006@3oool00;<0oooo00D000000?ooo`3o0000o`000000o`2A0?oo
o`040?l000000?l0003o0?l001/0oooo002c0?ooo`030000003oool0oooo0080o`0000<0003o0?oo
o`3oool0S@3oool20000o`80o`00703oool00;<0oooo0P0000020?ooo`80o`0000<0003o0?ooo`3o
ool0RP3oool0103o0000003o0?l0003o000N0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`03
0?l000000?l0oooo08X0oooo0P000?l20?l001l0oooo002c0?ooo`030000003oool0oooo0080oooo
0P3o00000`000?l0oooo0?ooo`260?ooo`80003o0P3o000Q0?ooo`00/`3oool00`000000oooo0?oo
o`030?ooo`80o`0000<0003o0?ooo`3oool0Q03oool010000?l0o`000?l0003o000R0?ooo`00/`3o
ool00`000000oooo0?ooo`040?ooo`030?l000000?l0oooo08<0oooo0P000?l30?l002<0oooo002c
0?ooo`030000003oool0oooo00@0oooo0P3o00000`000?l0oooo0?ooo`200?ooo`040000o`3o0000
o`000?l002D0oooo002c0?ooo`030000003oool0oooo00D0oooo0P3o00000`000?l0oooo0?ooo`1m
0?ooo`80003o0`3o000V0?ooo`00/`3oool00`000000oooo0?ooo`060?ooo`030?l000000?l0oooo
07d0oooo00@0003o0?l0003o0000o`00:03oool00;<0oooo0P0000070?ooo`80o`0000<0003o0?oo
o`3oool0N@3oool20000o`<0o`00:@3oool00;<0oooo00<000000?ooo`3oool01`3oool20?l00003
0000o`3oool0oooo07L0oooo00@0003o0?l0003o0000o`00:`3oool00;<0oooo00<000000?ooo`3o
ool0203oool00`3o0000003o0?ooo`1f0?ooo`030?l000000?l0o`000080o`00;03oool00;<0oooo
00<000000?ooo`3oool0203oool20?l000030000o`3oool0oooo07<0oooo0P000?l20?l002h0oooo
002c0?ooo`030000003oool0oooo00T0oooo0P3o00000`000?l0oooo0?ooo`1`0?ooo`040?l00000
0?l0o`000?l00300oooo002c0?ooo`030000003oool0oooo00X0oooo0P3o00000`000?l0oooo0?oo
o`1^0?ooo`80003o0P3o000a0?ooo`00/`3oool00`000000oooo0?ooo`0;0?ooo`80o`0000<0003o
0?ooo`3oool0J`3oool0103o0000003o0?l0003o000c0?ooo`00/`3oool00`000000oooo0?ooo`0<
0?ooo`80o`0000<0003o0?ooo`3oool0J@3oool20000o`80o`00=03oool00;<0oooo0P00000>0?oo
o`80o`0000<0003o0?ooo`3oool0IP3oool0103o0000003o0?l0003o000f0?ooo`00/`3oool00`00
0000oooo0?ooo`0>0?ooo`80o`0000<0003o0?ooo`3oool0I03oool20000o`80o`00=`3oool00;<0
oooo00<000000?ooo`3oool03`3oool20?l000030000o`3oool0oooo0640oooo00@0o`000000o`3o
0000o`00>@3oool00;<0oooo00<000000?ooo`3oool0403oool20?l000030000o`3oool0oooo05l0
oooo00@0o`000000o`3o0000o`00>P3oool00;<0oooo00<000000?ooo`3oool04@3oool20?l00003
0000o`3oool0oooo05`0oooo00@0o`000000o`000?l0o`00?03oool00;<0oooo00<000000?ooo`3o
ool04P3oool20?l000030000o`3oool0oooo05X0oooo00@0o`000000o`3o0000o`00?@3oool00;<0
oooo00<000000?ooo`3oool04`3oool20?l000030000o`3oool0oooo05L0oooo00@0o`000000o`00
0?l0o`00?`3oool00;<0oooo00<000000?ooo`3oool0503oool20?l000030000o`3o0000oooo05@0
oooo00<0o`000000o`000?l00P3o00100?ooo`00/`3oool2000001H0oooo0P3o00000`000?l0o`00
0?ooo`1A0?ooo`030?l000000?l0003o0080o`00@P3oool00;<0oooo00<000000?ooo`3oool05`3o
ool00`3o0000003o0?l0001?0?ooo`030?l000000?l0003o0080o`00A03oool00;<0oooo00<00000
0?ooo`3oool0603oool00`3o0000003o0?l0001=0?ooo`040?l000000?l0o`000?l004H0oooo002c
0?ooo`030000003oool0oooo01T0oooo00<0o`000000o`3o0000BP3oool0103o0000003o0000o`3o
00180?ooo`00/`3oool00`000000oooo0?ooo`0J0?ooo`030?l000000?l0o`0004L0oooo00<0o`00
0000o`000?l00P3o00190?ooo`00V@3oool3000000H0oooo0P0000050?ooo`@000001P3oool00`00
0000oooo0?ooo`0K0?ooo`040?l000000?l0003o0?l004<0oooo00<0o`000000o`000?l00P3o001;
0?ooo`00V03oool01@000000oooo0?ooo`3oool0000000D0oooo0P0000090?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0703oool20?l000030000o`3o0000oooo03l0oooo00<0o`00
0000o`000?l00P3o001=0?ooo`00V03oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030?l000000?l0003o03d0oooo00<0o`00
0000o`000?l00P3o001?0?ooo`00V03oool01@000000oooo0?ooo`3oool000000100oooo00<00000
0?ooo`3oool00`3oool3000001l0oooo0P3o00000`000?l0oooo0?ooo`0h0?ooo`030?l000000?l0
003o0080o`00D@3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`@000001P3oool0
0`000000oooo0?ooo`0P0?ooo`80o`0000<0003o0?ooo`3oool0=@3oool20?l000030000o`3o0000
o`0005<0oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0240oooo0P3o00020000oc<0oooo0P3o00020000o`030?l0003oool0
oooo05<0oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0280oooo0`3o00020000obl0oooo0P3o00020000o`030?l0003oool0
oooo05D0oooo002I0?ooo`<000003@3oool4000000H0oooo00<000000?ooo`3oool0903oool30?l0
00<0003o:@3oool20?l000<0003o00<0o`000?ooo`3oool0E`3oool00;<0oooo00<000000?ooo`3o
ool09P3oool40?l00080003o903oool20?l000<0003o0P3o001K0?ooo`00/`3oool00`000000oooo
0?ooo`0Y0?ooo`<0o`000P000?lO0?ooo`80o`000`000?l20?l005h0oooo002c0?ooo`030000003o
ool0oooo02/0oooo0`3o00030000oaT0oooo0P3o00030000o`80o`00H@3oool00;<0oooo0P00000]
0?ooo`D0o`0010000?lB0?ooo`030?l000000?l0003o0080003o0P3o001T0?ooo`00/`3oool00`00
0000oooo0?ooo`0_0?ooo`H0o`001`000?l30?ooo`80o`001`000?l30?l006L0oooo002c0?ooo`03
0000003oool0oooo03@0oooo203o00050000o`L0o`00JP3oool00;<0oooo00<000000?ooo`3oool0
>P3oool70?l00740oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo002P0?ooo`<000000P3oool3000001P0oooo0`00002U0?ooo`00X@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1P0000090?ooo`050000003oool0oooo
0?ooo`000000Y03oool00:40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?oo
o`050000003oool0oooo0?ooo`000000Y03oool00:40oooo00H000000?ooo`00000000000?ooo`00
00090?ooo`H000002@3oool01@000000oooo0?ooo`3oool000000:@0oooo002Q0?ooo`060000003o
ool000000000003oool00000603oool400000:D0oooo002Q0?ooo`8000000P3oool2000001P0oooo
00<000000?ooo`3oool0YP3oool00:40oooo0P0000020?ooo`8000006@3oool00`000000oooo0?oo
o`2U0?ooo`00X03oool2000000@0oooo0P00000I0?ooo`<00000Y03oool00?l0ooooJ@3oool00?l0
ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.843, \
0.00802014, 0.0156287}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.450425 0.244394 [
[.02381 .43792 -6 -9 ]
[.02381 .43792 6 0 ]
[.2619 .43792 -12 -9 ]
[.2619 .43792 12 0 ]
[.7381 .43792 -9 -9 ]
[.7381 .43792 9 0 ]
[.97619 .43792 -3 -9 ]
[.97619 .43792 3 0 ]
[.4875 .08383 -24 -4.5 ]
[.4875 .08383 0 4.5 ]
[.4875 .20603 -12 -4.5 ]
[.4875 .20603 0 4.5 ]
[.4875 .32823 -24 -4.5 ]
[.4875 .32823 0 4.5 ]
[.4875 .57262 -18 -4.5 ]
[.4875 .57262 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45042 m
.02381 .45667 L
s
[(-1)] .02381 .43792 0 1 Mshowa
.2619 .45042 m
.2619 .45667 L
s
[(-0.5)] .2619 .43792 0 1 Mshowa
.7381 .45042 m
.7381 .45667 L
s
[(0.5)] .7381 .43792 0 1 Mshowa
.97619 .45042 m
.97619 .45667 L
s
[(1)] .97619 .43792 0 1 Mshowa
.125 Mabswid
.07143 .45042 m
.07143 .45417 L
s
.11905 .45042 m
.11905 .45417 L
s
.16667 .45042 m
.16667 .45417 L
s
.21429 .45042 m
.21429 .45417 L
s
.30952 .45042 m
.30952 .45417 L
s
.35714 .45042 m
.35714 .45417 L
s
.40476 .45042 m
.40476 .45417 L
s
.45238 .45042 m
.45238 .45417 L
s
.54762 .45042 m
.54762 .45417 L
s
.59524 .45042 m
.59524 .45417 L
s
.64286 .45042 m
.64286 .45417 L
s
.69048 .45042 m
.69048 .45417 L
s
.78571 .45042 m
.78571 .45417 L
s
.83333 .45042 m
.83333 .45417 L
s
.88095 .45042 m
.88095 .45417 L
s
.92857 .45042 m
.92857 .45417 L
s
.25 Mabswid
0 .45042 m
1 .45042 L
s
.5 .08383 m
.50625 .08383 L
s
[(-1.5)] .4875 .08383 1 0 Mshowa
.5 .20603 m
.50625 .20603 L
s
[(-1)] .4875 .20603 1 0 Mshowa
.5 .32823 m
.50625 .32823 L
s
[(-0.5)] .4875 .32823 1 0 Mshowa
.5 .57262 m
.50625 .57262 L
s
[(0.5)] .4875 .57262 1 0 Mshowa
.125 Mabswid
.5 .10827 m
.50375 .10827 L
s
.5 .13271 m
.50375 .13271 L
s
.5 .15715 m
.50375 .15715 L
s
.5 .18159 m
.50375 .18159 L
s
.5 .23047 m
.50375 .23047 L
s
.5 .25491 m
.50375 .25491 L
s
.5 .27935 m
.50375 .27935 L
s
.5 .30379 m
.50375 .30379 L
s
.5 .35267 m
.50375 .35267 L
s
.5 .37711 m
.50375 .37711 L
s
.5 .40155 m
.50375 .40155 L
s
.5 .42599 m
.50375 .42599 L
s
.5 .47486 m
.50375 .47486 L
s
.5 .4993 m
.50375 .4993 L
s
.5 .52374 m
.50375 .52374 L
s
.5 .54818 m
.50375 .54818 L
s
.5 .05939 m
.50375 .05939 L
s
.5 .03496 m
.50375 .03496 L
s
.5 .01052 m
.50375 .01052 L
s
.5 .59706 m
.50375 .59706 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .35651 m
.06244 .22044 L
.08255 .16293 L
.10458 .1109 L
.12507 .07286 L
.14415 .04627 L
.15465 .03521 L
.16457 .02701 L
.17348 .02147 L
.1785 .01909 L
.18314 .01735 L
.1878 .01606 L
.19042 .01552 L
.19281 .01515 L
.19389 .01502 L
.19503 .01491 L
.19629 .01482 L
.19746 .01476 L
.19865 .01472 L
.19977 .01472 L
.20078 .01473 L
.20187 .01477 L
.20316 .01484 L
.20436 .01494 L
.20568 .01507 L
.20709 .01526 L
.20998 .01575 L
.21261 .01633 L
.21769 .0178 L
.2225 .01961 L
.23215 .02445 L
.24241 .03125 L
.26083 .04745 L
.29858 .09426 L
.33878 .15905 L
.37747 .22989 L
.41861 .30813 L
.45823 .38099 L
.49634 .44474 L
.5369 .50256 L
.57595 .5464 L
.59586 .56394 L
.61744 .57921 L
.62755 .58503 L
.63824 .59028 L
.64827 .59436 L
.65742 .5974 L
.66686 .59984 L
.67171 .60084 L
.677 .60173 L
Mistroke
.68187 .60237 L
.68425 .60262 L
.68639 .60281 L
.68847 .60296 L
.69071 .60309 L
.69195 .60315 L
.69308 .60319 L
.69417 .60323 L
.69531 .60325 L
.69654 .60327 L
.69723 .60328 L
.69787 .60328 L
.69904 .60328 L
.70029 .60327 L
.7014 .60325 L
.70244 .60322 L
.70358 .60318 L
.70482 .60313 L
.7074 .603 L
.71013 .60281 L
.71499 .60235 L
.71953 .60179 L
.72376 .60116 L
.73334 .59934 L
.74389 .59673 L
.75383 .59374 L
.77243 .58686 L
.81095 .56819 L
.85192 .54365 L
.89138 .51765 L
.92932 .49234 L
.96971 .46704 L
.97619 .46328 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35667 m
.06244 .22038 L
.08255 .16289 L
.10458 .11091 L
.12507 .0729 L
.14415 .04633 L
.15465 .03526 L
.16457 .02706 L
.17348 .02151 L
.1785 .01912 L
.18314 .01739 L
.1878 .01608 L
.19042 .01555 L
.19281 .01517 L
.19389 .01504 L
.19503 .01493 L
.19629 .01483 L
.19746 .01477 L
.19865 .01474 L
.19977 .01473 L
.20078 .01474 L
.20187 .01478 L
.20316 .01485 L
.20436 .01494 L
.20568 .01508 L
.20709 .01526 L
.20998 .01575 L
.21261 .01632 L
.21769 .01779 L
.2225 .0196 L
.23215 .02442 L
.24241 .03121 L
.26083 .0474 L
.29858 .09422 L
.33878 .15904 L
.37747 .22992 L
.41861 .30817 L
.45823 .38102 L
.49634 .44474 L
.5369 .50253 L
.57595 .54636 L
.59586 .5639 L
.61744 .57918 L
.62755 .58501 L
.63824 .59027 L
.64827 .59436 L
.65742 .5974 L
.66686 .59986 L
.67171 .60086 L
.677 .60175 L
Mistroke
.68187 .60239 L
.68425 .60264 L
.68639 .60284 L
.68847 .60299 L
.69071 .60313 L
.69195 .60318 L
.69308 .60323 L
.69415 .60326 L
.69531 .60329 L
.69658 .60331 L
.69778 .60332 L
.69895 .60332 L
.70003 .60331 L
.70119 .60329 L
.70248 .60326 L
.70382 .60322 L
.70507 .60316 L
.70736 .60304 L
.70946 .6029 L
.71417 .60249 L
.71899 .60191 L
.72425 .60113 L
.73485 .59905 L
.74515 .59643 L
.7545 .59356 L
.77546 .58562 L
.8155 .56563 L
.85402 .54226 L
.89499 .51522 L
.93444 .48906 L
.97238 .46536 L
.97619 .46311 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.223101,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo001;
0?ooo`030?l000000?l0003o00T0003oG03oool00`000000oooo0?ooo`2b0?ooo`00B03oool0103o
0000003o0000o`000?l;0?l000030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0/P3oool0
04H0oooo00<0o`000000o`000?l00`3o000:0?ooo`80o`000`000?mH0?ooo`030000003oool0oooo
0;80oooo00150?ooo`040?l000000?l0o`000?l000h0oooo103o00020000oeH0oooo00<000000?oo
o`3oool0/P3oool004@0oooo00<0o`000000o`3o00004`3oool30?l00080003oE03oool00`000000
oooo0?ooo`2b0?ooo`00@`3oool00`3o0000003o0?l0000F0?ooo`<0o`0000<0003o0?ooo`3oool0
D@3oool00`000000oooo0?ooo`2b0?ooo`00@P3oool00`3o0000003o0?l0000I0?ooo`80o`0000<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`2b0?ooo`00@@3oool00`3o0000003o0?l0000K
0?ooo`80o`0000<0003o0?ooo`3oool0C`3oool200000;<0oooo00100?ooo`030?l000000?l0o`00
01d0oooo0P3o00000`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo0;80oooo000o0?ooo`03
0?l000000?l0o`0001l0oooo0P3o00000`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo0;80
oooo000n0?ooo`030?l000000?l0o`000240oooo0P3o00000`000?l0oooo0?ooo`1<0?ooo`030000
003oool0oooo0;80oooo000n0?ooo`030?l000000?l0oooo0280oooo0P3o00000`000?l0oooo0?oo
o`1;0?ooo`030000003oool0oooo0;80oooo000m0?ooo`030?l000000?l0o`0002@0oooo00<0o`00
0000o`3oool0C03oool00`000000oooo0?ooo`2b0?ooo`00?03oool00`3o0000003o0?l0000U0?oo
o`80o`0000<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`2b0?ooo`00>`3oool00`3o0000
003o0?l0000W0?ooo`80o`0000<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`2b0?ooo`00
>P3oool00`3o0000003o0?l0000Y0?ooo`80o`0000<0003o0?ooo`3oool0B03oool200000;<0oooo
000j0?ooo`030?l000000?l0oooo02X0oooo0P3o00000`000?l0oooo0?ooo`170?ooo`030000003o
ool0oooo0;80oooo000i0?ooo`030?l000000?l0o`0002`0oooo00<0o`000000o`3oool0B03oool0
0`000000oooo0?ooo`2b0?ooo`00>03oool00`3o0000003o0?l0000]0?ooo`80o`0000<0003o0?oo
o`3oool0AP3oool00`000000oooo0?ooo`2b0?ooo`00=`3oool00`3o0000003o0?l0000_0?ooo`80
o`0000<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00=`3oool00`3o0000003o
0?ooo`0`0?ooo`80o`0000<0003o0?ooo`3oool0:P3oool5000000@0oooo0P0000050?ooo`@00000
1P3oool00`000000oooo0?ooo`2b0?ooo`00=P3oool00`3o0000003o0?l0000b0?ooo`80o`0000<0
003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`8000002@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0;80oooo000f0?ooo`030?l000000?l0oooo03<0oooo00<0o`00
0000o`3oool08@3oool6000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0;80oooo000e0?ooo`030?l000000?l0o`0003@0oooo0P3o00000`00
0?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool30000
0;80oooo000e0?ooo`030?l000000?l0oooo03D0oooo0P3o00000`000?l0oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo000d0?ooo`030?l0
00000?l0o`0003L0oooo0P3o00000`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00=03oool00`3o0000003o0?oo
o`0h0?ooo`80o`0000<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0/P3oool003<0oooo00<0o`000000o`3o0000>P3oool0
0`3o0000003o0?ooo`0V0?ooo`<000003@3oool4000000H0oooo00<000000?ooo`3oool0/P3oool0
03<0oooo00<0o`000000o`3oool0>P3oool20?l000030000o`3oool0oooo03h0oooo00<000000?oo
o`3oool0/P3oool00380oooo00<0o`000000o`3o0000?03oool20?l000030000o`3oool0oooo03d0
oooo00<000000?ooo`3oool0/P3oool00380oooo00<0o`000000o`3oool0?@3oool00`3o0000003o
0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000a0?ooo`030?l000000?l0o`0003h0oooo0P3o
00000`000?l0oooo0?ooo`0l0?ooo`800000/`3oool00340oooo00<0o`000000o`3oool0?`3oool0
0`3o0000003o0?ooo`0m0?ooo`030000003oool0oooo0;80oooo000`0?ooo`030?l000000?l0o`00
0400oooo0P3o00000`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0;80oooo000`0?ooo`03
0?l000000?l0oooo0440oooo0P3o00000`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0;80
oooo000_0?ooo`030?l000000?l0o`0004<0oooo00<0o`000000o`3oool0>`3oool00`000000oooo
0?ooo`2b0?ooo`00;`3oool00`3o0000003o0?ooo`130?ooo`80o`0000<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`3o0000003o0?l000150?ooo`80o`0000<0003o
0?ooo`3oool0>03oool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`3o0000003o0?ooo`160?oo
o`030?l000000?l0oooo03T0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0o`000000o`3o
0000A`3oool20?l000030000o`3oool0oooo03L0oooo0P00002c0?ooo`00;@3oool00`3o0000003o
0?ooo`180?ooo`030?l000000?l0oooo03P0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0
o`000000o`3oool0B03oool20?l000030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0/P3o
ool002`0oooo00<0o`000000o`3o0000BP3oool20?l000030000o`3oool0oooo03D0oooo00<00000
0?ooo`3oool0/P3oool002`0oooo00<0o`000000o`3oool0B`3oool00`3o0000003o0?ooo`0f0?oo
o`030000003oool0oooo0;80oooo000[0?ooo`030?l000000?l0o`0004`0oooo0P3o00000`000?l0
oooo0?ooo`0d0?ooo`030000003oool0oooo0;80oooo000[0?ooo`030?l000000?l0oooo04d0oooo
00<0o`000000o`3oool0=@3oool00`000000oooo0?ooo`2b0?ooo`00:P3oool00`3o0000003o0?l0
001>0?ooo`80o`0000<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`2b0?ooo`00:P3oool0
0`3o0000003o0?ooo`1?0?ooo`80o`0000<0003o0?ooo`3oool0<P3oool200000;<0oooo000Y0?oo
o`030?l000000?l0o`000540oooo00<0o`000000o`3oool0<`3oool00`000000oooo0?ooo`2b0?oo
o`00:@3oool00`3o0000003o0?ooo`1A0?ooo`80o`0000<0003o0?ooo`3oool0<@3oool00`000000
oooo0?ooo`2b0?ooo`00:@3oool00`3o0000003o0?ooo`1B0?ooo`030?l000000?l0oooo0380oooo
00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000o`3o0000D`3oool20?l000030000o`3o
ool0oooo0300oooo00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000o`3oool0E03oool2
0?l000030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0/P3oool002P0oooo00<0o`000000
o`3oool0E@3oool00`3o0000003o0?ooo`0`0?ooo`030000003oool0oooo0;80oooo000W0?ooo`03
0?l000000?l0o`0005H0oooo0P3o00000`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo0;80
oooo000W0?ooo`030?l000000?l0oooo05L0oooo00<0o`000000o`3oool0;`3oool200000;<0oooo
000W0?ooo`030?l000000?l0oooo05L0oooo0P3o00000`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo0;80oooo000V0?ooo`030?l000000?l0o`0005T0oooo00<0o`000000o`3oool0;P3oool0
0`000000oooo0?ooo`2b0?ooo`009P3oool00`3o0000003o0?ooo`1I0?ooo`80o`0000<0003o0?oo
o`3oool0;03oool00`000000oooo0?ooo`2b0?ooo`009P3oool00`3o0000003o0?ooo`1J0?ooo`80
o`0000<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`2b0?ooo`009@3oool00`3o0000003o
0?l0001L0?ooo`030?l000000?l0oooo0280oooo1@0000050?ooo`030000003oool0oooo0;80oooo
000U0?ooo`030?l000000?l0oooo05`0oooo0P3o00000`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002D0oooo00<0o`000000o`3oool0G@3oool0
0`3o0000003o0?ooo`0H0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;80oooo000T0?ooo`030?l000000?l0o`0005h0oooo0P3o00000`000?l0oooo0?ooo`0Q0?oo
o`030000003oool0oooo00D0oooo0`00002b0?ooo`00903oool00`3o0000003o0?ooo`1O0?ooo`03
0?l000000?l0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00
903oool00`3o0000003o0?ooo`1O0?ooo`80o`0000<0003o0?ooo`3oool0803oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0;80oooo000S0?ooo`030?l000000?l0o`000640oooo00<0
o`000000o`3oool08@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo000S
0?ooo`030?l000000?l0oooo0640oooo0P3o00000`000?l0oooo0?ooo`0M0?ooo`<000001`3oool0
0`000000oooo0?ooo`2b0?ooo`008`3oool00`3o0000003o0?ooo`1R0?ooo`80o`0000<0003o0?oo
o`3oool09P3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`3o0000003o0?ooo`1S0?ooo`03
0?l000000?l0oooo02L0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0o`000000o`3o0000
I03oool20?l000030000o`3oool0oooo02D0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0
o`000000o`3oool0I@3oool00`3o0000003o0?ooo`0V0?ooo`800000/`3oool00280oooo00<0o`00
0000o`3oool0I@3oool20?l000030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool0
0240oooo00<0o`000000o`3o0000I`3oool00`3o0000003o0?ooo`0U0?ooo`030000003oool0oooo
0;80oooo000Q0?ooo`030?l000000?l0oooo06L0oooo0P3o00000`000?l0oooo0?ooo`0S0?ooo`03
0000003oool0oooo0;80oooo000Q0?ooo`030?l000000?l0oooo06P0oooo00<0o`000000o`3oool0
903oool00`000000oooo0?ooo`2b0?ooo`008@3oool00`3o0000003o0?ooo`1X0?ooo`80o`0000<0
003o0?ooo`3oool08P3oool00`000000oooo0?ooo`2b0?ooo`00803oool00`3o0000003o0?l0001Z
0?ooo`030?l000000?l0oooo02<0oooo00<000000?ooo`3oool0/P3oool00200oooo00<0o`000000
o`3oool0JP3oool20?l000030000o`3oool0oooo0240oooo00<000000?ooo`3oool0/P3oool00200
oooo00<0o`000000o`3oool0J`3oool00`3o0000003o0?ooo`0R0?ooo`800000/`3oool001l0oooo
00<0o`000000o`3o0000K03oool20?l000030000o`3oool0oooo0200oooo00<000000?ooo`3oool0
/P3oool001l0oooo00<0o`000000o`3oool0K@3oool00`3o0000003o0?ooo`0Q0?ooo`030000003o
ool0oooo0;80oooo000O0?ooo`030?l000000?l0oooo06d0oooo0P3o00000`000?l0oooo0?ooo`0O
0?ooo`030000003oool0oooo0;80oooo000O0?ooo`030?l000000?l0oooo06h0oooo00<0o`000000
o`3oool0803oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`3o0000003o0?l0001_0?ooo`80
o`0000<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`2b0?ooo`007P3oool00`3o0000003o
0?ooo`1`0?ooo`030?l000000?l0oooo01l0oooo00<000000?ooo`3oool0/P3oool001h0oooo00<0
o`000000o`3oool0L03oool20?l000030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0/P3o
ool001d0oooo00<0o`000000o`3o0000LP3oool00`3o0000003o0?ooo`0N0?ooo`800000/`3oool0
01d0oooo00<0o`000000o`3oool0LP3oool20?l000030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool0/P3oool001d0oooo00<0o`000000o`3oool0L`3oool00`3o0000003o0?ooo`0M0?ooo`03
0000003oool0oooo0;80oooo000L0?ooo`030?l000000?l0o`0007@0oooo0P3o00000`000?l0oooo
0?ooo`0K0?ooo`030000003oool0oooo0;80oooo000L0?ooo`030?l000000?l0oooo07D0oooo00<0
o`000000o`3oool0703oool00`000000oooo0?ooo`2b0?ooo`00703oool00`3o0000003o0?ooo`1e
0?ooo`80o`0000<0003o0?ooo`3oool06P3oool00`000000oooo0?ooo`2b0?ooo`00703oool00`3o
0000003o0?ooo`1f0?ooo`030?l000000?l0oooo01/0oooo00<000000?ooo`3oool0/P3oool001/0
oooo00<0o`000000o`3o0000M`3oool20?l000030000o`3oool0oooo01T0oooo00<000000?ooo`3o
ool0/P3oool001/0oooo00<0o`000000o`3oool0N03oool00`3o0000003o0?ooo`0J0?ooo`800000
/`3oool001/0oooo00<0o`000000o`3oool0N03oool20?l000030000o`3oool0oooo01P0oooo00<0
00000?ooo`3oool0/P3oool001X0oooo00<0o`000000o`3o0000NP3oool00`3o0000003o0?ooo`0I
0?ooo`030000003oool0oooo0;80oooo000J0?ooo`030?l000000?l0oooo07X0oooo0P3o00000`00
0?l0oooo0?ooo`0G0?ooo`030000003oool0oooo0;80oooo000J0?ooo`030?l000000?l0oooo07/0
oooo00<0o`000000o`3oool0603oool00`000000oooo0?ooo`2b0?ooo`006P3oool00`3o0000003o
0?ooo`1k0?ooo`80o`0000<0003o0000003oool01@3oool2000000D0oooo100000060?ooo`030000
003oool0oooo0;80oooo000I0?ooo`030?l000000?l0o`0007`0oooo00D000000?l000000?l0oooo
000000050?ooo`8000002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo
000I0?ooo`030?l000000?l0oooo07@0oooo1P0000020?ooo`050000003o0000o`000000o`000000
403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo000I0?ooo`030?l00000
0?l0oooo07`0oooo00D000000?ooo`3o0000o`000000o`0@0?ooo`030000003oool0oooo00<0oooo
0`00002b0?ooo`00603oool00`3o0000003o0?l0001m0?ooo`050000003oool0oooo0?l000000?l0
303oool4000000H0oooo00<000000?ooo`3oool0/P3oool001P0oooo00<0o`000000o`3oool0O@3o
ool00`000000oooo0?ooo`020?l000030000o`3oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`2b0?ooo`00603oool00`3o0000003o0?ooo`1m0?ooo`060000003oool0
oooo0?ooo`3o0000003o2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000H0?ooo`030?l000000?l0oooo07h0oooo0`0000020?l000030000o`3oool0oooo00P0oooo1000
00060?ooo`030000003oool0oooo0;80oooo000G0?ooo`030?l000000?l0o`0008<0oooo00<0o`00
0000o`3oool04`3oool00`000000oooo0?ooo`2b0?ooo`005`3oool00`3o0000003o0?ooo`230?oo
o`80o`0000<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`2b0?ooo`005`3oool00`3o0000
003o0?ooo`240?ooo`030?l000000?l0oooo0180oooo00<000000?ooo`3oool0/P3oool001H0oooo
00<0o`000000o`3o0000Q@3oool20?l000030000o`3oool0oooo0100oooo0P00002c0?ooo`005P3o
ool00`3o0000003o0?ooo`260?ooo`030?l000000?l0oooo0140oooo00<000000?ooo`3oool0/P3o
ool001H0oooo0P3o00270?ooo`80o`0000<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`2b
0?ooo`00X03oool00`3o0000003o0?ooo`0@0?ooo`030000003oool0oooo0;80oooo002P0?ooo`80
o`0000<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`2b0?ooo`00X@3oool20?l000030000
o`3oool0oooo00d0oooo00<000000?ooo`3oool0/P3oool00:80oooo00<0o`000000o`3oool03P3o
ool00`000000oooo0?ooo`2b0?ooo`00XP3oool20?l000030000o`3oool0oooo00`0oooo00<00000
0?ooo`3oool0/P3oool00:<0oooo00<0o`000000o`3oool03@3oool200000;<0oooo002S0?ooo`80
o`0000<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`2b0?ooo`00Y03oool00`3o0000003o
0?ooo`0<0?ooo`030000003oool0oooo0;80oooo002T0?ooo`80o`0000<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`2b0?ooo`00Y@3oool20?l000030000o`3oool0oooo00T0oooo00<00000
0?ooo`3oool0/P3oool00:H0oooo00<0o`000000o`3oool02P3oool00`000000oooo0?ooo`2b0?oo
o`00YP3oool20?l000030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0/P3oool00:L0oooo
00<0o`000000o`3oool02@3oool00`000000oooo0?ooo`2b0?ooo`00Y`3oool20?l000030000o`3o
ool0oooo00L0oooo0P00002c0?ooo`00Z03oool20?l000030000o`3oool0oooo00H0oooo00<00000
0?ooo`3oool0/P3oool001T0oooo1@0000110?ooo`<000001P3oool2000000D0oooo1000000f0?oo
o`030?l000000?l0oooo00L0oooo00<000000?ooo`3oool0@@3oool3000000H0oooo0P0000050?oo
o`@00000@P3oool5000001H0oooo000K0?ooo`030000003oool0oooo0400oooo00D000000?ooo`3o
ool0oooo000000050?ooo`8000002@3oool00`000000oooo0?ooo`0c0?ooo`80o`0000<0003o0?oo
o`3oool01@3oool00`000000oooo0?ooo`100?ooo`050000003oool0oooo0?ooo`0000001@3oool2
000000T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0F0?ooo`00403oool60000
00D0oooo00<000000?ooo`3oool0>03oool600000080oooo00D000000?ooo`3oool0oooo0000000@
0?ooo`030000003oool0oooo03@0oooo0P3o00000`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo0400oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3o
ool000000100oooo00<000000?ooo`3oool0=@3oool00`3o0000003o0?ooo`050?ooo`030000003o
ool0oooo0400oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?oo
o`3oool0000000`0oooo1000000h0?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`000000oooo
0?ooo`100?ooo`050000003oool0oooo0?ooo`000000303oool4000004@0oooo00<000000?ooo`3o
ool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool0000000`0
oooo00<000000?ooo`3oool0>P3oool00`3o0000003o0?ooo`040?ooo`030000003oool0oooo0400
oooo00D000000?ooo`3oool0oooo0000000<0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool0>P3oool20?l000030000o`3oool0oooo0080oooo0P0000110?oo
o`050000003oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01H0oooo000I0?ooo`<00000@`3oool3000000d0oooo1000000j0?ooo`80o`0000D0003o0?oo
o`3oool0oooo000000130?ooo`<000003@3oool400000480oooo0`00000H0?ooo`00[P3oool00`3o
0000003o0?ooo`020?ooo`030000003oool0oooo0;80oooo002^0?ooo`80o`0000@0003o0?ooo`3o
ool00000]03oool00:l0oooo00D0o`000000o`3oool0oooo0000002d0?ooo`00[`3oool20?l00003
0000o`3oool000000;@0oooo002`0?ooo`80o`0000<0003o0000003oool0/`3oool00;40oooo00<0
o`000000o`000000]03oool000l0ooooXP0000020?l000030000o`00000000000:800000403oool0
01L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool20?l000030000o`3oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool05P3oool001L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03
0?l000000?l0oooo04/0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0F0?ooo`00
/`3oool20?l000030000o`3oool0oooo0;00oooo002c0?ooo`040000003o0000o`000000oiH0oooo
0`000?lH0?ooo`00/`3oool010000000oooo0?l000000?nD0?ooo`030?l000000?l0o`000080o`00
603oool00;<0oooo00D000000?ooo`3o0000o`000000o`2B0?ooo`80003o0P3o000J0?ooo`00/`3o
ool00`000000oooo0?ooo`020?l000030000o`3oool0oooo08d0oooo0P000?l20?l001`0oooo002c
0?ooo`8000000P3oool20?l000030000o`3oool0oooo08X0oooo00<0o`000000o`3o00000P3o000M
0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`030?l000000?l0oooo08X0oooo0P000?l20?l0
01l0oooo002c0?ooo`030000003oool0oooo0080oooo0P3o00000`000?l0oooo0?ooo`260?ooo`80
003o0P3o000Q0?ooo`00/`3oool00`000000oooo0?ooo`030?ooo`80o`0000<0003o0?ooo`3oool0
P`3oool00`3o0000003o0?l000020?l00280oooo002c0?ooo`030000003oool0oooo00@0oooo00<0
o`000000o`3oool0P`3oool20000o`80o`00903oool00;<0oooo00<000000?ooo`3oool0103oool2
0?l000030000o`3oool0oooo07l0oooo00@0o`000000o`3o0000o`009P3oool00;<0oooo00<00000
0?ooo`3oool01@3oool20?l000030000o`3oool0oooo07d0oooo0P000?l20?l002L0oooo002c0?oo
o`030000003oool0oooo00H0oooo00<0o`000000o`3oool0O03oool0103o0000003o0?l0003o000Y
0?ooo`00/`3oool2000000L0oooo0P3o00000`000?l0oooo0?ooo`1i0?ooo`80003o0P3o000Z0?oo
o`00/`3oool00`000000oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3oool0MP3oool0103o0000
003o0?l0003o000/0?ooo`00/`3oool00`000000oooo0?ooo`080?ooo`030?l000000?l0oooo07H0
oooo00@0o`000000o`3o0000o`00;@3oool00;<0oooo00<000000?ooo`3oool0203oool20?l00003
0000o`3oool0oooo07<0oooo0P000?l00`3o0000oooo0?ooo`0]0?ooo`00/`3oool00`000000oooo
0?ooo`090?ooo`80o`0000<0003o0?ooo`3oool0L03oool0103o0000003o0?l0003o000`0?ooo`00
/`3oool00`000000oooo0?ooo`0:0?ooo`80o`0000<0003o0?ooo`3oool0KP3oool20000o`80o`00
<@3oool00;<0oooo00<000000?ooo`3oool02`3oool20?l000030000o`3oool0oooo06/0oooo00@0
o`000000o`3o0000o`00<`3oool00;<0oooo00<000000?ooo`3oool0303oool20?l000030000o`3o
ool0oooo06T0oooo0P000?l20?l003@0oooo002c0?ooo`8000003P3oool20?l000030000o`3oool0
oooo06H0oooo00@0o`000000o`3o0000o`00=P3oool00;<0oooo00<000000?ooo`3oool03P3oool2
0?l000030000o`3oool0oooo06<0oooo00<0o`000000o`000?l00P3o000g0?ooo`00/`3oool00`00
0000oooo0?ooo`0?0?ooo`80o`0000<0003o0?ooo`3oool0H@3oool0103o0000003o0?l0003o000i
0?ooo`00/`3oool00`000000oooo0?ooo`0@0?ooo`80o`0000<0003o0?ooo`3oool0GP3oool20?l0
00030000o`3o0000oooo03X0oooo002c0?ooo`030000003oool0oooo0140oooo0P3o00000`000?l0
oooo0?ooo`1K0?ooo`80o`000P000?l00`3o0000oooo0?ooo`0j0?ooo`00/`3oool00`000000oooo
0?ooo`0B0?ooo`80o`0000<0003o0?ooo`3oool0F@3oool20?l000030000o`3o0000oooo03d0oooo
002c0?ooo`030000003oool0oooo01<0oooo0P3o00000`000?l0oooo0?ooo`1F0?ooo`80o`000P00
0?m00?ooo`00/`3oool00`000000oooo0?ooo`0D0?ooo`80o`0000<0003o0?ooo`3oool0E03oool0
103o0000003o0000o`3o00110?ooo`00/`3oool2000001H0oooo0P3o00000`000?l0oooo0?ooo`1A
0?ooo`040?l000000?l0003o0?l004<0oooo002c0?ooo`030000003oool0oooo01H0oooo0P3o0000
0`000?l0oooo0?ooo`1>0?ooo`030?l000000?l0003o0080o`00A03oool00;<0oooo00<000000?oo
o`3oool05`3oool20?l000030000o`3oool0oooo04`0oooo00@0o`000000o`3o0000o`00AP3oool0
0;<0oooo00<000000?ooo`3oool0603oool20?l000030000o`3oool0oooo04T0oooo00@0o`000000
o`000?l0o`00B03oool00;<0oooo00<000000?ooo`3oool06@3oool20?l000030000o`3oool0oooo
04H0oooo00<0o`000000o`000?l00P3o00190?ooo`00V@3oool3000000H0oooo0P0000050?ooo`@0
00001P3oool00`000000oooo0?ooo`0J0?ooo`80o`000P000?m50?ooo`80003o0P3o001;0?ooo`00
V03oool01@000000oooo0?ooo`3oool0000000D0oooo0P0000090?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool06`3oool30?l000030000o`3oool0oooo0400oooo0P000?l20?l004d0
oooo002H0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01d0oooo0P3o00020000och0oooo0P000?l30?l004h0oooo002H0?ooo`050000
003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`030?ooo`<000007P3oool30?l00003
0000o`3oool0oooo03T0oooo0P000?l30?l00500oooo002H0?ooo`050000003oool0oooo0?ooo`00
0000303oool4000000H0oooo00<000000?ooo`3oool0803oool20?l000030000o`3oool0oooo03D0
oooo0P3o000010000?l0o`000?l0003o001B0?ooo`00V03oool01@000000oooo0?ooo`3oool00000
00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`80o`000P000?lc0?oo
o`80o`000P000?l20?l005@0oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0280oooo0`3o00020000obl0oooo0P3o00020000
o`030?l0003oool0oooo05D0oooo002I0?ooo`<000003@3oool4000000H0oooo00<000000?ooo`3o
ool0903oool30?l000<0003o:P3oool01@3o0000003o0000o`000?l0o`0005T0oooo002c0?ooo`03
0000003oool0oooo02H0oooo103o00020000obD0oooo00@0o`000000o`000?l0003o0P3o001K0?oo
o`00/`3oool00`000000oooo0?ooo`0Y0?ooo`<0o`000P000?lP0?ooo`040?l000000?l0003o0000
o`<0o`00G@3oool00;<0oooo00<000000?ooo`3oool0:`3oool30?l000<0003o6@3oool20?l000<0
003o0`3o001P0?ooo`00/`3oool2000002h0oooo103o00040000oa80oooo00<0o`000000o`000?l0
0P000?l30?l006<0oooo002c0?ooo`030000003oool0oooo0300oooo1@3o00070000o`@0oooo00<0
o`000000o`000?l01@000?l30?l006L0oooo002c0?ooo`030000003oool0oooo03@0oooo1`3o0006
0000o`L0o`00JP3oool00;<0oooo00<000000?ooo`3oool0>P3oool70?l00740oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002P0?ooo`<00000
0P3oool3000001P0oooo0`00002U0?ooo`00X@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo1P0000090?ooo`050000003oool0oooo0?ooo`000000Y03oool00:40oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`000000
Y03oool00:40oooo00H000000?ooo`00000000000?ooo`0000090?ooo`H000002@3oool01@000000
oooo0?ooo`3oool000000:@0oooo002Q0?ooo`060000003oool000000000003oool000006@3oool3
00000:D0oooo002Q0?ooo`8000000P3oool2000001P0oooo00D000000?ooo`3oool0oooo0000002T
0?ooo`00X@3oool200000080oooo0P00000H0?ooo`050000003oool0oooo0?ooo`000000Y03oool0
0:00oooo0P0000040?ooo`800000603oool300000:D0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.84304, \
0.00802014, 0.0156269}}]
}, Open  ]]
}, Open  ]],

Cell["\<\
Only six or so  terms are required in order to achieve excellent \
convergence to the exact function (shown by the thin line). Of course, just \
as with trigonometric series, the more rapidly varying the function is, the \
more terms are needed in the series to obtain good convergence.\
\>", "Text"],

Cell[TextData[{
  "\tLet's try the same problem of constructing a generalized Fourier series \
for the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \ \[ExponentialE]\^\(-x\)\ sin\ 3\ x\)]],
  ",  but with a different set of orthogonal functions on [-1,1]: the set of \
",
  StyleBox["even",
    FontSlant->"Italic"],
  " Legendre polynomials,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = \(P\_\(2  n\)\)(x)\)]],
  ". If we now try to expand the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[ExponentialE]\^\(-x\)\) sin\ 3  x\)]],
  " in this set, the expansion does not work, as seen in Cell ",
  ButtonBox["4.8",
    ButtonData:>"Cell 4.8",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Psi][n_, x_]\  = \ LegendreP[2\ n, x];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Clear[c];\)\), "\[IndentingNewLine]", 
    \(\(\(c[n_]\  := \(c[n]\  = \ 
          NIntegrate[\[Psi][n, x]\ Exp[\(-x\)]\ Sin[3  x], {x, \(-1\), 1}]/
            Integrate[\[Psi][n, x]^2, {x, \(-1\), 1}]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(f\_approx[x_, M_]\  := \ Sum[c[n] \[Psi][n, x], {n, 0, M}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[{Evaluate[f\_approx[x, M]], Sin[3  x]\ Exp[\(-x\)]}, {x, \(-1\), 
            1}, PlotStyle \[Rule] {{Red, Thickness[0.008]}, Blue}, 
          PlotLabel \[Rule] "\<M = \>" <> ToString[M]], {M, 2, 6, 
          2}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.8"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.450422 0.244399 [
[.02381 .43792 -6 -9 ]
[.02381 .43792 6 0 ]
[.2619 .43792 -12 -9 ]
[.2619 .43792 12 0 ]
[.7381 .43792 -9 -9 ]
[.7381 .43792 9 0 ]
[.97619 .43792 -3 -9 ]
[.97619 .43792 3 0 ]
[.4875 .08382 -24 -4.5 ]
[.4875 .08382 0 4.5 ]
[.4875 .20602 -12 -4.5 ]
[.4875 .20602 0 4.5 ]
[.4875 .32822 -24 -4.5 ]
[.4875 .32822 0 4.5 ]
[.4875 .57262 -18 -4.5 ]
[.4875 .57262 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45042 m
.02381 .45667 L
s
[(-1)] .02381 .43792 0 1 Mshowa
.2619 .45042 m
.2619 .45667 L
s
[(-0.5)] .2619 .43792 0 1 Mshowa
.7381 .45042 m
.7381 .45667 L
s
[(0.5)] .7381 .43792 0 1 Mshowa
.97619 .45042 m
.97619 .45667 L
s
[(1)] .97619 .43792 0 1 Mshowa
.125 Mabswid
.07143 .45042 m
.07143 .45417 L
s
.11905 .45042 m
.11905 .45417 L
s
.16667 .45042 m
.16667 .45417 L
s
.21429 .45042 m
.21429 .45417 L
s
.30952 .45042 m
.30952 .45417 L
s
.35714 .45042 m
.35714 .45417 L
s
.40476 .45042 m
.40476 .45417 L
s
.45238 .45042 m
.45238 .45417 L
s
.54762 .45042 m
.54762 .45417 L
s
.59524 .45042 m
.59524 .45417 L
s
.64286 .45042 m
.64286 .45417 L
s
.69048 .45042 m
.69048 .45417 L
s
.78571 .45042 m
.78571 .45417 L
s
.83333 .45042 m
.83333 .45417 L
s
.88095 .45042 m
.88095 .45417 L
s
.92857 .45042 m
.92857 .45417 L
s
.25 Mabswid
0 .45042 m
1 .45042 L
s
.5 .08382 m
.50625 .08382 L
s
[(-1.5)] .4875 .08382 1 0 Mshowa
.5 .20602 m
.50625 .20602 L
s
[(-1)] .4875 .20602 1 0 Mshowa
.5 .32822 m
.50625 .32822 L
s
[(-0.5)] .4875 .32822 1 0 Mshowa
.5 .57262 m
.50625 .57262 L
s
[(0.5)] .4875 .57262 1 0 Mshowa
.125 Mabswid
.5 .10826 m
.50375 .10826 L
s
.5 .1327 m
.50375 .1327 L
s
.5 .15714 m
.50375 .15714 L
s
.5 .18158 m
.50375 .18158 L
s
.5 .23046 m
.50375 .23046 L
s
.5 .2549 m
.50375 .2549 L
s
.5 .27934 m
.50375 .27934 L
s
.5 .30378 m
.50375 .30378 L
s
.5 .35266 m
.50375 .35266 L
s
.5 .3771 m
.50375 .3771 L
s
.5 .40154 m
.50375 .40154 L
s
.5 .42598 m
.50375 .42598 L
s
.5 .47486 m
.50375 .47486 L
s
.5 .4993 m
.50375 .4993 L
s
.5 .52374 m
.50375 .52374 L
s
.5 .54818 m
.50375 .54818 L
s
.5 .05938 m
.50375 .05938 L
s
.5 .03494 m
.50375 .03494 L
s
.5 .0105 m
.50375 .0105 L
s
.5 .59706 m
.50375 .59706 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .42701 m
.04262 .38605 L
.06244 .35188 L
.08255 .32569 L
.09396 .31426 L
.10458 .30566 L
.11508 .29896 L
.125 .29415 L
.1339 .29103 L
.13893 .28973 L
.14357 .28881 L
.14596 .28844 L
.14823 .28815 L
.15085 .2879 L
.15201 .28781 L
.15324 .28773 L
.15442 .28767 L
.15549 .28763 L
.15656 .28761 L
.15757 .28759 L
.15875 .28759 L
.15984 .2876 L
.16104 .28763 L
.1623 .28768 L
.16358 .28774 L
.16475 .28781 L
.16738 .28802 L
.16982 .28828 L
.17213 .28858 L
.1773 .28943 L
.18292 .29063 L
.19232 .29322 L
.2027 .29687 L
.22371 .30642 L
.26391 .3305 L
.3026 .35733 L
.34374 .38585 L
.38336 .41021 L
.42147 .42853 L
.44108 .43549 L
.45198 .43855 L
.46203 .44084 L
.47227 .44263 L
.47767 .44335 L
.48338 .44395 L
.48577 .44415 L
.48833 .44433 L
.49055 .44445 L
.49297 .44456 L
.49444 .44461 L
Mistroke
.4958 .44464 L
.4971 .44467 L
.49783 .44468 L
.49849 .44469 L
.49974 .44469 L
.50044 .44469 L
.50108 .44469 L
.50227 .44468 L
.50353 .44466 L
.50475 .44463 L
.50608 .44459 L
.5085 .4445 L
.51086 .44437 L
.51303 .44423 L
.51797 .44382 L
.5232 .44325 L
.53193 .44196 L
.54155 .44008 L
.56094 .43486 L
.58181 .4272 L
.623 .40662 L
.66268 .38155 L
.70084 .3549 L
.74145 .32698 L
.78055 .30428 L
.79082 .29953 L
.80193 .29514 L
.81243 .29182 L
.8221 .28954 L
.82679 .28874 L
.82937 .28838 L
.83182 .2881 L
.83409 .2879 L
.83529 .28781 L
.83656 .28773 L
.83763 .28768 L
.83881 .28764 L
.83989 .28761 L
.8409 .2876 L
.8421 .28759 L
.84342 .28761 L
.84409 .28762 L
.8448 .28764 L
.84608 .2877 L
.84736 .28777 L
.84857 .28785 L
.85083 .28805 L
.85351 .28837 L
.85597 .28873 L
.86155 .28984 L
Mistroke
.86622 .29106 L
.87123 .2927 L
.88029 .29654 L
.89107 .30267 L
.90092 .30988 L
.91992 .32849 L
.94065 .35664 L
.95786 .38698 L
.97619 .42701 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35667 m
.06244 .22037 L
.08255 .16288 L
.10458 .1109 L
.12507 .07289 L
.14415 .04632 L
.15465 .03525 L
.16457 .02705 L
.17348 .0215 L
.1785 .01911 L
.18314 .01737 L
.1878 .01607 L
.19042 .01553 L
.19281 .01516 L
.19389 .01503 L
.19503 .01492 L
.19629 .01482 L
.19746 .01476 L
.19865 .01472 L
.19977 .01472 L
.20078 .01473 L
.20187 .01476 L
.20316 .01484 L
.20436 .01493 L
.20568 .01507 L
.20709 .01525 L
.20998 .01574 L
.21261 .01631 L
.21769 .01778 L
.2225 .01959 L
.23215 .02441 L
.24241 .0312 L
.26083 .04739 L
.29858 .09421 L
.33878 .15903 L
.37747 .22991 L
.41861 .30817 L
.45823 .38102 L
.49634 .44474 L
.5369 .50253 L
.57595 .54636 L
.59586 .5639 L
.61744 .57918 L
.62755 .58501 L
.63824 .59027 L
.64827 .59436 L
.65742 .5974 L
.66686 .59986 L
.67171 .60086 L
.677 .60175 L
Mistroke
.68187 .60239 L
.68425 .60264 L
.68639 .60284 L
.68847 .60299 L
.69071 .60313 L
.69195 .60318 L
.69308 .60323 L
.69415 .60326 L
.69531 .60329 L
.69658 .60331 L
.69778 .60332 L
.69895 .60332 L
.70003 .60331 L
.70119 .60329 L
.70248 .60326 L
.70382 .60322 L
.70507 .60316 L
.70736 .60304 L
.70946 .6029 L
.71417 .60249 L
.71899 .60191 L
.72425 .60113 L
.73485 .59905 L
.74515 .59643 L
.7545 .59356 L
.77546 .58562 L
.8155 .56563 L
.85402 .54226 L
.89499 .51522 L
.93444 .48906 L
.97238 .46536 L
.97619 .46311 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo001<
0?ooo`/0003oG03oool00`000000oooo0?ooo`2b0?ooo`00B@3oool30000o`/0oooo00<0003o0?oo
o`3oool0F@3oool00`000000oooo0?ooo`2b0?ooo`00A`3oool20000o`l0oooo0`000?mH0?ooo`03
0000003oool0oooo0;80oooo00160?ooo`030000o`3oool0oooo0180oooo0P000?mF0?ooo`030000
003oool0oooo0;80oooo00150?ooo`030000o`3oool0oooo01D0oooo0P000?mD0?ooo`030000003o
ool0oooo0;80oooo00140?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0D@3oool0
0`000000oooo0?ooo`2b0?ooo`00@`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0/P3oool00480oooo00<0003o0?ooo`3oool0703oool00`000?l0
oooo0?ooo`1?0?ooo`800000/`3oool00440oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo0;80oooo00100?ooo`030000o`3oool0oooo0200oooo00<0
003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`2b0?ooo`00?`3oool00`000?l0oooo0?ooo`0R
0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0/P3oool003l0oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0;80oooo000n0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`2b0?ooo`00
?@3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0
/P3oool003`0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`190?ooo`030000003o
ool0oooo0;80oooo000k0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0B03oool2
00000;<0oooo000k0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`2b0?ooo`00>P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool0/P3oool003T0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo
0?ooo`160?ooo`030000003oool0oooo0;80oooo000h0?ooo`030000o`3oool0oooo0300oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00>03oool00`000?l0oooo0?ooo`0a
0?ooo`030000o`3oool0oooo02X0oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool0
1@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`0P0?ooo`H000001@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool003H0oooo00<0003o0?ooo`3o
ool0=@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3o
ool0103oool300000;80oooo000f0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0
:@3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000
oooo0?ooo`2b0?ooo`00=@3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo02P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000e0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o
0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0U0?ooo`80EEEE00<000000?ooo`3oool02`3oool4
000000H0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o0?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000c0?ooo`030000o`3oool0oooo03d0
oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`2b0?ooo`00<`3oool00`000?l0oooo
0?ooo`0m0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0/P3oool00380oooo00<0
003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`800000/`3oool00380oooo00<0003o
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo0;80oooo000a0?oo
o`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`2b0?oo
o`00<@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0/P3oool00300oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo0;80oooo000`0?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2b0?ooo`00;`3oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0
oooo03P0oooo00<000000?ooo`3oool0/P3oool002l0oooo00<0003o0?ooo`3oool0AP3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0;80oooo000^0?ooo`030000o`3oool0oooo04P0
oooo00<0003o0?ooo`3oool0=`3oool200000;<0oooo000^0?ooo`030000o`3oool0oooo04P0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`000?l0oooo0?oo
o`190?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0003o
0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0;80oooo000]0?oo
o`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`2b0?oo
o`00;03oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3o
ool0/P3oool002`0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0d0?ooo`030000
003oool0oooo0;80oooo000[0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool0<`3o
ool00`000000oooo0?ooo`2b0?ooo`00:`3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0
oooo0380oooo0P00002c0?ooo`00:P3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo
0380oooo00<000000?ooo`3oool0/P3oool002X0oooo00<0003o0?ooo`3oool0DP3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo0;80oooo000Z0?ooo`030000o`3oool0oooo0580oooo
00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`2b0?ooo`00:@3oool00`000?l0oooo0?oo
o`1D0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0/P3oool002T0oooo00<0003o
0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo0;80oooo000Y0?oo
o`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`2b0?oo
o`00:03oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3o
ool0/P3oool002P0oooo00<0003o0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0^0?ooo`800000
/`3oool002P0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo0;80oooo000W0?ooo`030000o`3oool0oooo05T0oooo00<0003o0?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2b0?ooo`009`3oool00`000?l0oooo0?ooo`1J0?ooo`030000o`3oool0oooo
02`0oooo00<000000?ooo`3oool0/P3oool002L0oooo00<0003o0?ooo`3oool0F`3oool00`000?l0
oooo0?ooo`0[0?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000o`3oool0oooo05`0oooo
00<0003o0?ooo`3oool08@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0
/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`0G0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;80oooo000U0?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool08@3oool00`00
0000oooo0?ooo`050?ooo`<00000/P3oool002D0oooo00<0003o0?ooo`3oool0G`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002D0oooo
00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?oo
o`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o
0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0M0?ooo`80EEEE00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2b0?ooo`00903oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo
02H0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H`3oool00`000?l0
oooo0?ooo`0V0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030000o`3oool0oooo06D0oooo
00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`000?l0oooo0?oo
o`1U0?ooo`030000o`3oool0oooo02D0oooo0P00002c0?ooo`008`3oool00`000?l0oooo0?ooo`1V
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0003o0?oo
o`3oool0I`3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo0;80oooo000R0?ooo`03
0000o`3oool0oooo06P0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`2b0?ooo`00
8P3oool00`000?l0oooo0?ooo`1X0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0
/P3oool00280oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo0;80oooo000Q0?ooo`030000o`3oool0oooo06X0oooo00<0003o0?ooo`3oool08P3oool0
0`000000oooo0?ooo`2b0?ooo`008@3oool00`000?l0oooo0?ooo`1[0?ooo`030000o`3oool0oooo
0240oooo00<000000?ooo`3oool0/P3oool00240oooo00<0003o0?ooo`3oool0J`3oool00`000?l0
oooo0?ooo`0Q0?ooo`800000/`3oool00200oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0P0?ooo`030000003oool0oooo0;80oooo000P0?ooo`030000o`3oool0oooo06d0oooo00<0
003o0?ooo`3oool0803oool00`000000oooo0?ooo`2b0?ooo`00803oool00`000?l0oooo0?ooo`1^
0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool00200oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0;80oooo000O0?ooo`03
0000o`3oool0oooo0700oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`2b0?ooo`00
7`3oool00`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool0
/P3oool001l0oooo00<0003o0?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003o
ool0oooo0;80oooo000N0?ooo`030000o`3oool0oooo0780oooo00<0003o0?ooo`3oool07@3oool2
00000;<0oooo000N0?ooo`030000o`3oool0oooo07<0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`2b0?ooo`007P3oool00`000?l0oooo0?ooo`0N0?ooo`T0o`00C03oool00`000?l0
oooo0?ooo`0L0?ooo`030000003oool0oooo06T0oooo203o00110?ooo`007@3oool00`000?l0oooo
0?ooo`0I0?oooaD0o`00A`3oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo06@0oooo
4`3o000k0?ooo`007@3oool00`000?l0oooo0?ooo`0F0?ooo`X0o`001`3oool:0?l004@0oooo00<0
003o0?ooo`3oool06`3oool00`000000oooo0?ooo`1Q0?ooo`T0o`001P3oool90?l003T0oooo000M
0?ooo`030000o`3oool0oooo01D0oooo1@3o000C0?ooo`L0o`00@P3oool00`000?l0oooo0?ooo`0J
0?ooo`030000003oool0oooo05d0oooo203o000A0?ooo`D0o`00=`3oool001d0oooo00<0003o0?oo
o`3oool04`3oool40?l001T0oooo1`3o000o0?ooo`030000o`3oool0oooo01X0oooo00<000000?oo
o`3oool0FP3oool80?l001H0oooo1@3o000e0?ooo`00703oool00`000?l0oooo0?ooo`0C0?ooo`@0
o`007@3oool60?l003h0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`1I0?ooo`D0
o`00703oool40?l003@0oooo000L0?ooo`030000o`3oool0oooo0140oooo103o000R0?ooo`D0o`00
?03oool00`000?l0oooo0?ooo`0I0?ooo`800000F03oool40?l00240oooo0`3o000c0?ooo`00703o
ool00`000?l0oooo0?ooo`0@0?ooo`@0o`009@3oool40?l003`0oooo00<0003o0?ooo`3oool0603o
ool00`000000oooo0?ooo`1E0?ooo`D0o`008`3oool30?l00380oooo000K0?ooo`030000o`3oool0
oooo0100oooo0`3o000Y0?ooo`@0o`00>P3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0
oooo05<0oooo1@3o000V0?ooo`<0o`00<@3oool001/0oooo00<0003o0?ooo`3oool03`3oool30?l0
02/0oooo1@3o000i0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool0D@3oool50?l0
02T0oooo0`3o000`0?ooo`006`3oool00`000?l0oooo0?ooo`0>0?ooo`<0o`00;P3oool40?l003P0
oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1@0?ooo`@0o`00;03oool30?l002l0
oooo000K0?ooo`030000o`3oool0oooo00d0oooo0`3o000a0?ooo`@0o`00=@3oool01@3^k^h0<c<c
0000o`0c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`00
0000oooo0?ooo`1>0?ooo`@0o`00;`3oool30?l002h0oooo000J0?ooo`030000o`3oool0oooo00d0
oooo0`3o000c0?ooo`D0o`00<`3oool01@1gMgL0VIVI0000o`2IVIT0MgMg00D0oooo0P0R8R880?oo
o`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0C03oool50?l00340oooo0`3o000]0?oo
o`006P3oool00`000?l0oooo0?ooo`0<0?ooo`<0o`00=P3oool40?l002X0oooo1P0000020?ooo`05
014A4@3oool0oooo0000o`0A4A40403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
04X0oooo1@3o000d0?ooo`<0o`00;03oool001X0oooo00<0003o0?ooo`3oool0303oool20?l003T0
oooo103o000`0?ooo`050000003oool0oooo0?ooo`000?l03`3oool00`1gMgL0<c<c0?ooo`040?oo
o`<00000B@3oool40?l003L0oooo0`3o000[0?ooo`006@3oool00`000?l0oooo0?ooo`0<0?ooo`<0
o`00>P3oool40?l002l0oooo00D000000?ooo`3oool0oooo0000o`0<0?ooo`050000000R8R800000
03<c<`3<c<`01@3oool00`000000oooo0?ooo`170?ooo`@0o`00>P3oool20?l002/0oooo000I0?oo
o`030000o`3oool0oooo00/0oooo0`3o000m0?ooo`<0o`00;P3oool01P0A4A40oooo0?ooo`3oool0
4A4A0000o`/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`160?ooo`@0o`00>`3o
ool30?l002X0oooo000I0?ooo`030000o`3oool0oooo00X0oooo0`3o000o0?ooo`@0o`00;03oool0
1P1gMgL0VIVI0?ooo`2IVIT0MgMg0000o`/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`140?ooo`@0o`00?P3oool30?l002T0oooo000I0?ooo`030000o`3oool0oooo00X0oooo0P3o
00110?ooo`@0o`00:`3oool01`3^k^h0<c<c0000000c<c<0k^k^0?ooo`000?l02P3oool4000000H0
oooo00<000000?ooo`3oool0@`3oool40?l00400oooo0`3o000X0?ooo`00603oool00`000?l0oooo
0?ooo`0:0?ooo`<0o`00@`3oool30?l00300oooo00<0003o0?ooo`3oool04P3oool00`000000oooo
0?ooo`120?ooo`<0o`00@`3oool30?l002L0oooo000H0?ooo`030000o`3oool0oooo00T0oooo0`3o
00150?ooo`@0o`00;`3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo0400oooo103o
00150?ooo`80o`009`3oool001P0oooo00<0003o0?ooo`3oool0203oool30?l004L0oooo103o000^
0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0?`3oool40?l004H0oooo0`3o000V
0?ooo`005`3oool00`000?l0oooo0?ooo`090?ooo`80o`00BP3oool30?l002h0oooo00<0003o0?oo
o`3oool0403oool2000003h0oooo103o00190?ooo`<0o`009@3oool001L0oooo00<0003o0?ooo`3o
ool0203oool30?l004/0oooo103o000/0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3o
ool0?03oool40?l004/0oooo0`3o000T0?ooo`008@3oool30?l004d0oooo103o000/0?ooo`030000
o`3oool0oooo00l0oooo00<000000?ooo`3oool0>P3oool40?l004h0oooo0P3o000T0?ooo`008@3o
ool20?l00500oooo103o000Z0?ooo`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0>@3o
ool40?l004l0oooo0`3o000S0?ooo`00803oool30?l00540oooo103o000Z0?ooo`030000o`3oool0
oooo00h0oooo00<000000?ooo`3oool0=`3oool40?l00580oooo0`3o000R0?ooo`007`3oool30?l0
05@0oooo103o000Y0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0=P3oool40?l0
05@0oooo0P3o000R0?ooo`007`3oool20?l005H0oooo1@3o000W0?ooo`030000o`3oool0oooo00d0
oooo00<000000?ooo`3oool0=@3oool30?l005H0oooo0`3o000Q0?ooo`007P3oool30?l005P0oooo
103o000W0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0<`3oool40?l005P0oooo
0P3o000Q0?ooo`007P3oool20?l005/0oooo103o000U0?ooo`030000o`3oool0oooo00`0oooo0P00
000c0?ooo`@0o`00F@3oool30?l00200oooo000M0?ooo`<0o`00G03oool40?l002D0oooo00<0003o
0?ooo`3oool02`3oool00`000000oooo0?ooo`0`0?ooo`@0o`00G03oool30?l001l0oooo000L0?oo
o`<0o`00G`3oool40?l002<0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0_0?oo
o`@0o`00GP3oool20?l001l0oooo000L0?ooo`80o`00H@3oool40?l002<0oooo00<0003o0?ooo`3o
ool02P3oool00`000000oooo0?ooo`0]0?ooo`@0o`00H03oool30?l001h0oooo000K0?ooo`<0o`00
H`3oool40?l00280oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`D0o`00
HP3oool20?l001h0oooo000K0?ooo`80o`00I@3oool50?l00200oooo00<0003o0?ooo`3oool02@3o
ool00`000000oooo0?ooo`0Z0?ooo`@0o`00I03oool30?l001d0oooo000J0?ooo`<0o`00I`3oool4
0?l00200oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`@0o`00I`3oool2
0?l001d0oooo000J0?ooo`80o`00JP3oool40?l001h0oooo00<0003o0?ooo`3oool0203oool00`00
0000oooo0?ooo`0V0?ooo`D0o`00J03oool30?l001`0oooo000J0?ooo`80o`00J`3oool50?l001d0
oooo00<0003o0?ooo`3oool01`3oool2000002H0oooo103o001[0?ooo`80o`00703oool001T0oooo
0`3o001]0?ooo`@0o`007@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo02<0oooo
103o001]0?ooo`<0o`006`3oool001T0oooo0P3o000200000003014A4@3oool0oooo03h0oooo00D0
k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM01L0
oooo103o000K0?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool08@3oool50?l001X0
oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM03l0oooo0P3o000400000003014A4@3oool0oooo01@0oooo000H0?ooo`<0o`0000<000000?oo
o`3oool0@03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0
oooo01L0oooo1@3o000J0?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool07`3oool5
0?l001`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?oo
o`0n0?ooo`80o`000P3oool00`000000oooo0?ooo`0F0?ooo`00403oool600000080oooo0P3o0000
0`3oool000000?ooo`0i0?ooo`H000000P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<0
00000?ooo`3oool0603oool50?l001T0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?oo
o`0M0?ooo`D0o`007P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool0
?@3oool30?l000030?ooo`000000oooo01L0oooo000G0?ooo`<0o`0000<0oooo0000003oool0@@3o
ool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool06`3oool50?l001L0oooo
00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0L0?ooo`@0o`00803oool01@000000oooo
0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0?`3oool20?l000030?ooo`000000oooo01L0
oooo000G0?ooo`80o`000P3oool00`000000oooo0?ooo`100?ooo`050000003oool0oooo0?ooo`00
0000303oool01@0000008R8R0000000c<c<0c<c<01h0oooo1@3o000F0?ooo`030000o`3oool0oooo
00<0oooo00<000000?ooo`3oool06P3oool40?l00280oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`050000000R8R80000003<c<`3<c<`0@03oool30?l000030000003oool0oooo01H0oooo000G
0?ooo`80o`000P3oool00`000000oooo0?ooo`100?ooo`05014A4@3oool0oooo0?ooo`0A4A40303o
ool00`000000oooo0?ooo`0R0?ooo`D0o`00503oool00`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo01P0oooo1@3o000S0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo
0?ooo`130?ooo`80o`0000<000000?ooo`3oool05P3oool001H0oooo0`3o00020?ooo`030000003o
ool0oooo0400oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo02@0oooo
1@3o000C0?ooo`030000o`3oool0oooo0080oooo0P00000F0?ooo`H0o`009@3oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool0@`3oool30?l001P0oooo000F0?ooo`80o`00
00@0oooo05EEE@1EEED00000@P3oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000000U0?oo
o`H0o`004@3oool01@000?l0oooo0?ooo`3oool0000001@0oooo1`3o000W0?ooo`050>k^kP0c<c<0
000003<c<`3^k^h0303oool400000480oooo00<0EEEE0?l0003o0000603oool009X0oooo1P3o000?
0?ooo`050000o`3oool0oooo0?ooo`0000004@3oool70?l009`0oooo002M0?ooo`H0o`003@3oool0
10000?l0oooo0?ooo`00000>0?ooo`L0o`00W`3oool009l0oooo2`3o00060?ooo`040000o`3oool0
oooo000000X0oooo203o002R0?ooo`00XP3oool=0?l00080oooo00<0003o0?ooo`0000000`3oool<
0?l00:D0oooo002Y0?ooo`T0o`0000<0003o0?l0003o00002P3o002Y0?ooo`00[P3oool40?l00003
0000o`3o0000o`0000<0o`00/03oool000l0ooooY00000000`000?l000000000002R00000100oooo
000G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000000o`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0F0?ooo`005`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo04/0oooo00<00000
0000o`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo01H0oooo002c0?oo
o`030000003oool0003o0;80oooo002c0?ooo`040000003oool0oooo0000oiH0oooo0`000?lH0?oo
o`00/`3oool010000000oooo0?ooo`000?nE0?ooo`030000o`3oool0oooo01T0oooo002c0?ooo`05
0000003oool0oooo0?ooo`000?l0TP3oool20000oa`0oooo002c0?ooo`030000003oool0oooo0080
oooo00<0003o0?ooo`3oool0S@3oool20000oah0oooo002c0?ooo`800000103oool00`000?l0oooo
0?ooo`2;0?ooo`030000o`3oool0oooo01h0oooo002c0?ooo`030000003oool0oooo00<0oooo00<0
003o0?ooo`3oool0R@3oool20000ob40oooo002c0?ooo`030000003oool0oooo00@0oooo00<0003o
0?ooo`3oool0QP3oool20000ob<0oooo002c0?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool0Q03oool00`000?l0oooo0?ooo`0S0?ooo`00/`3oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0880oooo0P000?lV0?ooo`00/`3oool00`000000oooo0?ooo`060?ooo`030000
o`3oool0oooo0800oooo00<0003o0?ooo`3oool09P3oool00;<0oooo00<000000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`1m0?ooo`80003o:@3oool00;<0oooo00<000000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`1l0?ooo`030000o`3oool0oooo02T0oooo002c0?ooo`8000002@3oool00`00
0?l0oooo0?ooo`1i0?ooo`80003o;03oool00;<0oooo00<000000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`1g0?ooo`030000o`3oool0oooo02`0oooo002c0?ooo`030000003oool0oooo00T0oooo
00<0003o0?ooo`3oool0MP3oool00`000?l0oooo0?ooo`0]0?ooo`00/`3oool00`000000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo07<0oooo0P000?l`0?ooo`00/`3oool00`000000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0740oooo00<0003o0?ooo`3oool0<03oool00;<0oooo00<000000?oo
o`3oool0303oool00`000?l0oooo0?ooo`1^0?ooo`80003o<`3oool00;<0oooo00<000000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`1/0?ooo`030000o`3oool0oooo03<0oooo002c0?ooo`030000
003oool0oooo00h0oooo00<0003o0?ooo`3oool0J@3oool20000ocH0oooo002c0?ooo`800000403o
ool00`000?l0oooo0?ooo`1W0?ooo`030000o`3oool0oooo03H0oooo002c0?ooo`030000003oool0
oooo0100oooo00<0003o0?ooo`3oool0I03oool20000ocT0oooo002c0?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0i0?ooo`00/`3oool00`000000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo0600oooo00<0003o0?ooo`3oool0>P3oool00;<0oooo
00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`1M0?ooo`80003o?@3oool00;<0oooo00<0
00000?ooo`3oool0503oool00`000?l0oooo0?ooo`1K0?ooo`030000o`3oool0oooo03d0oooo002c
0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0F03oool20000od00oooo002c0?oo
o`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool0E@3oool20000od80oooo002c0?ooo`80
0000603oool00`000?l0oooo0?ooo`1B0?ooo`80003oA03oool00;<0oooo00<000000?ooo`3oool0
603oool00`000?l0oooo0?ooo`1?0?ooo`80003oAP3oool00;<0oooo00<000000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo04H0oooo002c0?ooo`030000003oool0
oooo01X0oooo00<0003o0?ooo`3oool0BP3oool20000odT0oooo002c0?ooo`030000003oool0oooo
01/0oooo00<0003o0?ooo`3oool0A`3oool20000od/0oooo002H0?ooo`050>k^kP0c<c<0000003<c
<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0
oooo01`0oooo0P000?m50?ooo`80003oC@3oool009P0oooo00D0MgMg09VIV@3oool0VIVI07MgM`05
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool0@03oool20000odl0oooo002H0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo0P000?ln0?ooo`80003oD@3oool0
09P0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00000Q
0?ooo`030000o`3oool0oooo03T0oooo0P000?mC0?ooo`00V03oool01@000000oooo0?ooo`3oool0
000000`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`1C0?ooo`00V03oool01@0A4A40oooo0?ooo`3o
ool04A4A00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`80003o=@3o
ool20000oeH0oooo002H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02D0oooo0P000?la0?ooo`80003oF03oool009P0oooo00D0k^k^
03<c<`000000<c<c0>k^kP0<0?ooo`@000001P3oool00`000000oooo0?ooo`0W0?ooo`<0003o:`3o
ool30000oeX0oooo002c0?ooo`030000003oool0oooo02X0oooo0P000?lV0?ooo`<0003oG@3oool0
0;<0oooo00<000000?ooo`3oool0;03oool20000ob40oooo0`000?mP0?ooo`00/`3oool00`000000
oooo0?ooo`0^0?ooo`<0003o6`3oool30000of<0oooo002c0?ooo`800000<P3oool40000oa<0oooo
10000?mV0?ooo`00/`3oool00`000000oooo0?ooo`0e0?ooo`L0003o1@3oool70000ofX0oooo002c
0?ooo`030000003oool0oooo03/0oooo1P000?ma0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00
X03oool200000006014A4@3oool0oooo014A4@0000004A4A5`3oool500000:@0oooo002Q0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool6000000T0oooo00D0VIVI028R8P3^
k^h0oooo04A4A02T0?ooo`00X@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0
oooo00<0VIVI028R8P3^k^h0Y@3oool00:40oooo00H000000?ooo`14A4@0<c<c0?ooo`0000090?oo
o`H000002`3oool00`2IVIT08R8R0>k^kP2T0?ooo`00X@3oool01P000000gMgM03<c<`1EEED0gMgM
000001/0oooo00<0MgMg06IVIP3oool0X`3oool00:40oooo00H0000008R8R02ZZZX0^k^k05EEE@00
000L0?ooo`030000003oool0oooo0:80oooo002Q0?ooo`060000000c<c<0oooo0?ooo`0c<c<00000
603oool01@000000^k^k0?ooo`2IVIT04A4A0:@0oooo002P0?ooo`03014A4@000000R8R80080oooo
00<0R8R80000000A4A405`3oool01@2IVIT04A4A0000000R8R80c<c<0:@0oooo003o0?ooofT0oooo
003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.84299, \
0.00802014, 0.0156266}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.450422 0.244399 [
[.02381 .43792 -6 -9 ]
[.02381 .43792 6 0 ]
[.2619 .43792 -12 -9 ]
[.2619 .43792 12 0 ]
[.7381 .43792 -9 -9 ]
[.7381 .43792 9 0 ]
[.97619 .43792 -3 -9 ]
[.97619 .43792 3 0 ]
[.4875 .08382 -24 -4.5 ]
[.4875 .08382 0 4.5 ]
[.4875 .20602 -12 -4.5 ]
[.4875 .20602 0 4.5 ]
[.4875 .32822 -24 -4.5 ]
[.4875 .32822 0 4.5 ]
[.4875 .57262 -18 -4.5 ]
[.4875 .57262 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45042 m
.02381 .45667 L
s
[(-1)] .02381 .43792 0 1 Mshowa
.2619 .45042 m
.2619 .45667 L
s
[(-0.5)] .2619 .43792 0 1 Mshowa
.7381 .45042 m
.7381 .45667 L
s
[(0.5)] .7381 .43792 0 1 Mshowa
.97619 .45042 m
.97619 .45667 L
s
[(1)] .97619 .43792 0 1 Mshowa
.125 Mabswid
.07143 .45042 m
.07143 .45417 L
s
.11905 .45042 m
.11905 .45417 L
s
.16667 .45042 m
.16667 .45417 L
s
.21429 .45042 m
.21429 .45417 L
s
.30952 .45042 m
.30952 .45417 L
s
.35714 .45042 m
.35714 .45417 L
s
.40476 .45042 m
.40476 .45417 L
s
.45238 .45042 m
.45238 .45417 L
s
.54762 .45042 m
.54762 .45417 L
s
.59524 .45042 m
.59524 .45417 L
s
.64286 .45042 m
.64286 .45417 L
s
.69048 .45042 m
.69048 .45417 L
s
.78571 .45042 m
.78571 .45417 L
s
.83333 .45042 m
.83333 .45417 L
s
.88095 .45042 m
.88095 .45417 L
s
.92857 .45042 m
.92857 .45417 L
s
.25 Mabswid
0 .45042 m
1 .45042 L
s
.5 .08382 m
.50625 .08382 L
s
[(-1.5)] .4875 .08382 1 0 Mshowa
.5 .20602 m
.50625 .20602 L
s
[(-1)] .4875 .20602 1 0 Mshowa
.5 .32822 m
.50625 .32822 L
s
[(-0.5)] .4875 .32822 1 0 Mshowa
.5 .57262 m
.50625 .57262 L
s
[(0.5)] .4875 .57262 1 0 Mshowa
.125 Mabswid
.5 .10826 m
.50375 .10826 L
s
.5 .1327 m
.50375 .1327 L
s
.5 .15714 m
.50375 .15714 L
s
.5 .18158 m
.50375 .18158 L
s
.5 .23046 m
.50375 .23046 L
s
.5 .2549 m
.50375 .2549 L
s
.5 .27934 m
.50375 .27934 L
s
.5 .30378 m
.50375 .30378 L
s
.5 .35266 m
.50375 .35266 L
s
.5 .3771 m
.50375 .3771 L
s
.5 .40154 m
.50375 .40154 L
s
.5 .42598 m
.50375 .42598 L
s
.5 .47486 m
.50375 .47486 L
s
.5 .4993 m
.50375 .4993 L
s
.5 .52374 m
.50375 .52374 L
s
.5 .54818 m
.50375 .54818 L
s
.5 .05938 m
.50375 .05938 L
s
.5 .03494 m
.50375 .03494 L
s
.5 .0105 m
.50375 .0105 L
s
.5 .59706 m
.50375 .59706 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .40989 m
.04262 .38033 L
.06244 .3537 L
.08426 .3299 L
.10458 .31291 L
.12297 .30177 L
.13327 .29722 L
.14264 .29411 L
.14747 .29288 L
.15259 .29185 L
.15697 .29118 L
.15945 .29088 L
.16178 .29067 L
.16306 .29057 L
.16446 .29048 L
.16578 .29042 L
.16701 .29037 L
.16823 .29034 L
.16933 .29033 L
.1706 .29033 L
.1718 .29034 L
.17311 .29037 L
.17377 .29039 L
.17449 .29042 L
.17697 .29055 L
.17837 .29065 L
.17986 .29077 L
.18257 .29105 L
.18785 .29178 L
.19274 .29267 L
.20381 .29542 L
.21356 .29863 L
.22393 .30278 L
.26168 .32324 L
.30188 .35118 L
.34057 .38008 L
.38171 .40883 L
.40223 .42123 L
.42133 .43113 L
.44093 .43937 L
.45944 .44515 L
.46926 .44738 L
.47443 .44831 L
.4799 .44912 L
.4845 .44965 L
.48695 .44987 L
.48957 .45007 L
.49198 .45021 L
.49418 .45031 L
.49523 .45035 L
Mistroke
.49639 .45038 L
.49748 .4504 L
.49849 .45041 L
.49978 .45042 L
.50043 .45042 L
.50114 .45042 L
.5024 .4504 L
.50358 .45038 L
.50429 .45036 L
.50497 .45034 L
.50624 .4503 L
.50908 .45015 L
.51156 .44999 L
.51386 .4498 L
.51905 .44925 L
.52335 .44866 L
.52808 .44788 L
.53767 .44587 L
.55705 .4401 L
.57792 .43148 L
.61912 .4083 L
.65879 .38055 L
.69695 .35204 L
.73757 .32372 L
.75634 .31255 L
.77666 .30252 L
.7878 .29814 L
.79805 .29489 L
.80785 .29255 L
.81279 .29168 L
.81539 .2913 L
.81821 .29096 L
.82093 .2907 L
.82212 .29061 L
.82344 .29052 L
.8246 .29046 L
.82585 .2904 L
.82716 .29036 L
.8284 .29034 L
.82953 .29033 L
.83076 .29033 L
.83205 .29035 L
.83325 .29038 L
.83438 .29043 L
.8354 .29048 L
.8377 .29063 L
.84038 .29087 L
.84285 .29115 L
.84845 .29203 L
.85338 .29308 L
Mistroke
.8586 .29447 L
.86803 .29773 L
.87815 .30233 L
.89646 .31366 L
.91761 .33171 L
.9377 .35389 L
.97592 .40943 L
.97619 .40989 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35667 m
.06244 .22037 L
.08255 .16288 L
.10458 .1109 L
.12507 .07289 L
.14415 .04632 L
.15465 .03525 L
.16457 .02705 L
.17348 .0215 L
.1785 .01911 L
.18314 .01737 L
.1878 .01607 L
.19042 .01553 L
.19281 .01516 L
.19389 .01503 L
.19503 .01492 L
.19629 .01482 L
.19746 .01476 L
.19865 .01472 L
.19977 .01472 L
.20078 .01473 L
.20187 .01476 L
.20316 .01484 L
.20436 .01493 L
.20568 .01507 L
.20709 .01525 L
.20998 .01574 L
.21261 .01631 L
.21769 .01778 L
.2225 .01959 L
.23215 .02441 L
.24241 .0312 L
.26083 .04739 L
.29858 .09421 L
.33878 .15903 L
.37747 .22991 L
.41861 .30817 L
.45823 .38102 L
.49634 .44474 L
.5369 .50253 L
.57595 .54636 L
.59586 .5639 L
.61744 .57918 L
.62755 .58501 L
.63824 .59027 L
.64827 .59436 L
.65742 .5974 L
.66686 .59986 L
.67171 .60086 L
.677 .60175 L
Mistroke
.68187 .60239 L
.68425 .60264 L
.68639 .60284 L
.68847 .60299 L
.69071 .60313 L
.69195 .60318 L
.69308 .60323 L
.69415 .60326 L
.69531 .60329 L
.69658 .60331 L
.69778 .60332 L
.69895 .60332 L
.70003 .60331 L
.70119 .60329 L
.70248 .60326 L
.70382 .60322 L
.70507 .60316 L
.70736 .60304 L
.70946 .6029 L
.71417 .60249 L
.71899 .60191 L
.72425 .60113 L
.73485 .59905 L
.74515 .59643 L
.7545 .59356 L
.77546 .58562 L
.8155 .56563 L
.85402 .54226 L
.89499 .51522 L
.93444 .48906 L
.97238 .46536 L
.97619 .46311 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo001<
0?ooo`/0003oG03oool00`000000oooo0?ooo`2b0?ooo`00B@3oool30000o`/0oooo00<0003o0?oo
o`3oool0F@3oool00`000000oooo0?ooo`2b0?ooo`00A`3oool20000o`l0oooo0`000?mH0?ooo`03
0000003oool0oooo0;80oooo00160?ooo`030000o`3oool0oooo0180oooo0P000?mF0?ooo`030000
003oool0oooo0;80oooo00150?ooo`030000o`3oool0oooo01D0oooo0P000?mD0?ooo`030000003o
ool0oooo0;80oooo00140?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0D@3oool0
0`000000oooo0?ooo`2b0?ooo`00@`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0/P3oool00480oooo00<0003o0?ooo`3oool0703oool00`000?l0
oooo0?ooo`1?0?ooo`800000/`3oool00440oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo0;80oooo00100?ooo`030000o`3oool0oooo0200oooo00<0
003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`2b0?ooo`00?`3oool00`000?l0oooo0?ooo`0R
0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0/P3oool003l0oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0;80oooo000n0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`2b0?ooo`00
?@3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0
/P3oool003`0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`190?ooo`030000003o
ool0oooo0;80oooo000k0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0B03oool2
00000;<0oooo000k0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`2b0?ooo`00>P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool0/P3oool003T0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo
0?ooo`160?ooo`030000003oool0oooo0;80oooo000h0?ooo`030000o`3oool0oooo0300oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00>03oool00`000?l0oooo0?ooo`0a
0?ooo`030000o`3oool0oooo02X0oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool0
1@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`0P0?ooo`H000001@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool003H0oooo00<0003o0?ooo`3o
ool0=@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3o
ool0103oool300000;80oooo000f0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0
:@3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000
oooo0?ooo`2b0?ooo`00=@3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo02P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000e0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o
0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0U0?ooo`80EEEE00<000000?ooo`3oool02`3oool4
000000H0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o0?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000c0?ooo`030000o`3oool0oooo03d0
oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`2b0?ooo`00<`3oool00`000?l0oooo
0?ooo`0m0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0/P3oool00380oooo00<0
003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`800000/`3oool00380oooo00<0003o
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo0;80oooo000a0?oo
o`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`2b0?oo
o`00<@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0/P3oool00300oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo0;80oooo000`0?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2b0?ooo`00;`3oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0
oooo03P0oooo00<000000?ooo`3oool0/P3oool002l0oooo00<0003o0?ooo`3oool0AP3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0;80oooo000^0?ooo`030000o`3oool0oooo04P0
oooo00<0003o0?ooo`3oool0=`3oool200000;<0oooo000^0?ooo`030000o`3oool0oooo04P0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`000?l0oooo0?oo
o`190?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0003o
0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0;80oooo000]0?oo
o`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`2b0?oo
o`00;03oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3o
ool0/P3oool002`0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0d0?ooo`030000
003oool0oooo0;80oooo000[0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool0<`3o
ool00`000000oooo0?ooo`2b0?ooo`00:`3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0
oooo0380oooo0P00002c0?ooo`00:P3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo
0380oooo00<000000?ooo`3oool0/P3oool002X0oooo00<0003o0?ooo`3oool0DP3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo0;80oooo000Z0?ooo`030000o`3oool0oooo0580oooo
00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`2b0?ooo`00:@3oool00`000?l0oooo0?oo
o`1D0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0/P3oool002T0oooo00<0003o
0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo0;80oooo000Y0?oo
o`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`2b0?oo
o`00:03oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3o
ool0/P3oool002P0oooo00<0003o0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0^0?ooo`800000
/`3oool002P0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo0;80oooo000W0?ooo`030000o`3oool0oooo05T0oooo00<0003o0?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2b0?ooo`009`3oool00`000?l0oooo0?ooo`1J0?ooo`030000o`3oool0oooo
02`0oooo00<000000?ooo`3oool0/P3oool002L0oooo00<0003o0?ooo`3oool0F`3oool00`000?l0
oooo0?ooo`0[0?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000o`3oool0oooo05`0oooo
00<0003o0?ooo`3oool08@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0
/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`0G0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;80oooo000U0?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool08@3oool00`00
0000oooo0?ooo`050?ooo`<00000/P3oool002D0oooo00<0003o0?ooo`3oool0G`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002D0oooo
00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?oo
o`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o
0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0M0?ooo`80EEEE00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2b0?ooo`00903oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo
02H0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H`3oool00`000?l0
oooo0?ooo`0V0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030000o`3oool0oooo06D0oooo
00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`000?l0oooo0?oo
o`1U0?ooo`030000o`3oool0oooo02D0oooo0P00002c0?ooo`008`3oool00`000?l0oooo0?ooo`1V
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0003o0?oo
o`3oool0I`3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo0;80oooo000R0?ooo`03
0000o`3oool0oooo06P0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`2b0?ooo`00
8P3oool00`000?l0oooo0?ooo`1X0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0
/P3oool00280oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo0;80oooo000Q0?ooo`030000o`3oool0oooo06X0oooo00<0003o0?ooo`3oool08P3oool0
0`000000oooo0?ooo`2b0?ooo`008@3oool00`000?l0oooo0?ooo`1[0?ooo`030000o`3oool0oooo
0240oooo00<000000?ooo`3oool0/P3oool00240oooo00<0003o0?ooo`3oool0J`3oool00`000?l0
oooo0?ooo`0Q0?ooo`800000/`3oool00200oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0P0?ooo`030000003oool0oooo0;80oooo000P0?ooo`030000o`3oool0oooo06d0oooo00<0
003o0?ooo`3oool0803oool00`000000oooo0?ooo`2b0?ooo`00803oool00`000?l0oooo0?ooo`1^
0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool00200oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0;80oooo000O0?ooo`03
0000o`3oool0oooo0700oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`2b0?ooo`00
7`3oool00`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool0
/P3oool001l0oooo00<0003o0?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003o
ool0oooo0;80oooo000N0?ooo`030000o`3oool0oooo0780oooo00<0003o0?ooo`3oool07@3oool2
00000;<0oooo000N0?ooo`030000o`3oool0oooo07<0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`2b0?ooo`007P3oool00`000?l0oooo0?ooo`1c0?ooo`030000o`3oool0oooo01`0
oooo00<000000?ooo`3oool0/P3oool001d0oooo00<0003o0?ooo`3oool08@3oool<0?l004P0oooo
00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`1S0?ooo``0o`00@`3oool001d0oooo00<0
003o0?ooo`3oool0703ooolE0?l004@0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?oo
o`1P0?oooa80o`00@03oool001d0oooo00<0003o0?ooo`3oool06@3oool90?l000X0oooo2@3o0011
0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0G03oool80?l000X0oooo1`3o000m
0?ooo`007@3oool00`000?l0oooo0?ooo`0H0?ooo`D0o`004`3oool80?l003h0oooo00<0003o0?oo
o`3oool06P3oool00`000000oooo0?ooo`1I0?ooo`P0o`00403oool70?l003X0oooo000L0?ooo`03
0000o`3oool0oooo01L0oooo103o000J0?ooo`L0o`00?03oool00`000?l0oooo0?ooo`0I0?ooo`03
0000003oool0oooo05H0oooo1`3o000G0?ooo`L0o`00=`3oool001`0oooo00<0003o0?ooo`3oool0
5P3oool40?l001h0oooo1P3o000j0?ooo`030000o`3oool0oooo01T0oooo0P00001D0?ooo`L0o`00
7@3oool50?l003H0oooo000L0?ooo`030000o`3oool0oooo01@0oooo103o000S0?ooo`@0o`00>P3o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo0540oooo1P3o000S0?ooo`@0o`00=03o
ool001/0oooo00<0003o0?ooo`3oool0503oool40?l002H0oooo103o000h0?ooo`030000o`3oool0
oooo01P0oooo00<000000?ooo`3oool0C`3oool50?l002L0oooo103o000c0?ooo`006`3oool00`00
0?l0oooo0?ooo`0B0?ooo`@0o`00:@3oool50?l003L0oooo00<0003o0?ooo`3oool05`3oool00`00
0000oooo0?ooo`1>0?ooo`@0o`00:`3oool40?l00340oooo000K0?ooo`030000o`3oool0oooo0140
oooo103o000/0?ooo`@0o`00=P3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo04`0
oooo103o000^0?ooo`@0o`00<03oool001/0oooo00<0003o0?ooo`3oool03`3oool40?l00300oooo
103o000c0?ooo`050>k^kP0c<c<0003o03<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A400000000
0000<c<c0=gMg@050?ooo`030000003oool0oooo04/0oooo103o000a0?ooo`<0o`00;`3oool001X0
oooo00<0003o0?ooo`3oool03`3oool40?l00380oooo1@3o000a0?ooo`0507MgM`2IVIT0003o09VI
V@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`190?oo
o`@0o`00=03oool30?l002h0oooo000J0?ooo`030000o`3oool0oooo00h0oooo0`3o000f0?ooo`@0
o`00:03oool600000080oooo00D04A4A0?ooo`3oool0003o014A4@0@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0B03oool40?l003H0oooo0`3o000]0?ooo`006P3oool00`000?l0
oooo0?ooo`0=0?ooo`<0o`00>@3oool40?l002h0oooo00D000000?ooo`3oool0oooo0000o`0?0?oo
o`0307MgM`0c<c<0oooo00@0oooo0`0000160?ooo`@0o`00>@3oool30?l002`0oooo000I0?ooo`03
0000o`3oool0oooo00h0oooo0P3o000k0?ooo`@0o`00;@3oool01@000000oooo0?ooo`3oool0003o
00`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo04D0oooo103o000k
0?ooo`<0o`00:`3oool001T0oooo00<0003o0?ooo`3oool03@3oool30?l003d0oooo103o000[0?oo
o`06014A4@3oool0oooo0?ooo`0A4A40003o2`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04<0oooo103o000n0?ooo`80o`00:`3oool001T0oooo00<0003o0?ooo`3oool0303oool3
0?l003l0oooo103o000Z0?ooo`0607MgM`2IVIT0oooo09VIV@1gMgL0003o2`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0440oooo1@3o000o0?ooo`<0o`00:P3oool001T0oooo00<0
003o0?ooo`3oool02`3oool30?l00480oooo0`3o000Y0?ooo`070>k^kP0c<c<0000003<c<`3^k^h0
oooo0000o`0:0?ooo`@000001P3oool00`000000oooo0?ooo`100?ooo`@0o`00@P3oool30?l002T0
oooo000H0?ooo`030000o`3oool0oooo00/0oooo0`3o00140?ooo`@0o`00;@3oool00`000?l0oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo103o00150?ooo`<0o`00:03oool001P0oooo00<0
003o0?ooo`3oool02P3oool30?l004H0oooo103o000]0?ooo`030000o`3oool0oooo0140oooo00<0
00000?ooo`3oool0?@3oool40?l004L0oooo0`3o000W0?ooo`00603oool00`000?l0oooo0?ooo`09
0?ooo`<0o`00B@3oool40?l002/0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0k
0?ooo`@0o`00BP3oool30?l002H0oooo000G0?ooo`030000o`3oool0oooo00T0oooo0`3o001;0?oo
o`@0o`00:`3oool00`000?l0oooo0?ooo`0@0?ooo`800000>`3oool40?l004`0oooo0`3o000U0?oo
o`005`3oool00`000?l0oooo0?ooo`090?ooo`80o`00CP3oool30?l002X0oooo00<0003o0?ooo`3o
ool0403oool00`000000oooo0?ooo`0i0?ooo`<0o`00C`3oool20?l002D0oooo000R0?ooo`<0o`00
C`3oool40?l002T0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0h0?ooo`<0o`00
D03oool30?l002@0oooo000Q0?ooo`<0o`00D@3oool40?l002P0oooo00<0003o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0g0?ooo`<0o`00DP3oool30?l002<0oooo000P0?ooo`<0o`00E03oool3
0?l002P0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0e0?ooo`@0o`00E03oool3
0?l00280oooo000O0?ooo`<0o`00EP3oool30?l002P0oooo00<0003o0?ooo`3oool03@3oool00`00
0000oooo0?ooo`0d0?ooo`@0o`00EP3oool20?l00280oooo000O0?ooo`80o`00F03oool40?l002H0
oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`<0o`00F03oool30?l00240
oooo000N0?ooo`<0o`00F@3oool40?l002H0oooo00<0003o0?ooo`3oool0303oool00`000000oooo
0?ooo`0b0?ooo`<0o`00FP3oool30?l00200oooo000M0?ooo`<0o`00G03oool30?l002D0oooo00<0
003o0?ooo`3oool0303oool200000380oooo0`3o001L0?ooo`80o`00803oool001`0oooo0`3o001N
0?ooo`@0o`00903oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02l0oooo103o001M
0?ooo`<0o`007`3oool001`0oooo0P3o001P0?ooo`@0o`008`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000003oool0oooo02h0oooo103o001O0?ooo`<0o`007P3oool001/0oooo0`3o001R0?ooo`@0
o`008P3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo103o001R0?ooo`<0
o`007@3oool001X0oooo0`3o001T0?ooo`@0o`008P3oool00`000?l0oooo0?ooo`090?ooo`030000
003oool0oooo02/0oooo103o001T0?ooo`80o`007@3oool001X0oooo0P3o001W0?ooo`@0o`00803o
ool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo103o001V0?ooo`<0o`00703o
ool001T0oooo0`3o001X0?ooo`@0o`00803oool00`000?l0oooo0?ooo`080?ooo`030000003oool0
oooo02P0oooo103o001X0?ooo`<0o`006`3oool001P0oooo0`3o001[0?ooo`<0o`007`3oool00`00
0?l0oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo0`3o001[0?ooo`80o`006`3oool001P0
oooo0P3o001]0?ooo`@0o`007P3oool00`000?l0oooo0?ooo`070?ooo`8000009P3oool40?l006`0
oooo0`3o000J0?ooo`005`3oool30?l006h0oooo103o000N0?ooo`030000o`3oool0oooo00H0oooo
00<000000?ooo`3oool0903oool40?l006h0oooo0`3o000I0?ooo`005P3oool30?l000@0000000<0
4A4A0?ooo`3oool0?P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd05P3oool40?l001`0oooo00<0003o0?ooo`3oool01P3oool00`000000
oooo0?ooo`0R0?ooo`@0o`006P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd0@@3oool30?l000030000000A4A40oooo01D0oooo000F0?oo
o`80o`000`3oool00`000000oooo0?ooo`100?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2
028R8PP0oooo00<0MgMg03<c<`3oool05P3oool50?l001/0oooo00<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0P0?ooo`D0o`006`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R
8R880?ooo`0307MgM`0c<c<0oooo0440oooo0P3o000H0?ooo`00403oool6000000D0oooo00<00000
0?ooo`3oool0>03oool600000080oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003o
ool0oooo01L0oooo103o000K0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool07P3o
ool50?l001d0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?oo
o`3oool0000000l0oooo00<0MgMg03<c<`3oool06P3oool40?l001T0oooo00<0003o0?ooo`3oool0
103oool00`000000oooo0?ooo`0L0?ooo`D0o`007`3oool01@000000oooo0?ooo`3oool0000000l0
oooo00<0MgMg03<c<`3oool0@P3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo
0?ooo`100?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<
01`0oooo1@3o000H0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool06`3oool40?l0
0240oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`0@`3o
ool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`100?ooo`05014A4@3oool0
oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`0P0?ooo`D0o`005P3oool00`000?l0oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo103o000S0?ooo`05014A4@3oool0oooo0?ooo`0A4A40
303oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003o
ool0oooo0400oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo0280oooo
1@3o000E0?ooo`030000o`3oool0oooo0080oooo0P00000H0?ooo`D0o`00903oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0F0?ooo`00
6@3oool205EEE@030000003oool0oooo0400oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@0
00008`3oool50?l001@0oooo00D0003o0?ooo`3oool0oooo0000000G0?ooo`D0o`009P3oool01@3^
k^h0<c<c0000000c<c<0k^k^00`0oooo100000120?ooo`80EEEE00<000000?ooo`3oool05P3oool0
09P0oooo1P3o000A0?ooo`050000o`3oool0oooo0?ooo`000000503oool60?l009X0oooo002J0?oo
o`H0o`00403oool010000?l0oooo0?ooo`00000B0?ooo`H0o`00W03oool009d0oooo1P3o000=0?oo
o`040000o`3oool0oooo000000l0oooo1P3o002O0?ooo`00W`3oool70?l000/0oooo00<0003o0?oo
o`000000303oool70?l00:40oooo002R0?ooo`L0o`002@3oool00`000?l000000?ooo`080?ooo`L0
o`00Y03oool00:D0oooo303o0000103oool0003o0000003oool<0?l00:L0oooo000?0?oooiT00000
2`3o00000`000?l0o`000?l000080?l009X00000403oool001L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3o
ool40?l000030000o`3o0000oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool001L0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03000000000?l0oooo04/0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0F0?ooo`00/`3oool00`000000oooo0000o`2b0?oo
o`00/`3oool010000000oooo0?ooo`000?nF0?ooo`<0003o603oool00;<0oooo00@000000?ooo`3o
ool0003oU@3oool00`000?l0oooo0?ooo`0I0?ooo`00/`3oool01@000000oooo0?ooo`3oool0003o
0980oooo0P000?lL0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo08d0
oooo0P000?lN0?ooo`00/`3oool2000000@0oooo00<0003o0?ooo`3oool0R`3oool00`000?l0oooo
0?ooo`0N0?ooo`00/`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08T0oooo0P00
0?lQ0?ooo`00/`3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08H0oooo0P000?lS
0?ooo`00/`3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo08@0oooo00<0003o0?oo
o`3oool08`3oool00;<0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`220?ooo`80
003o9P3oool00;<0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`200?ooo`030000
o`3oool0oooo02H0oooo002c0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0O@3o
ool20000obT0oooo002c0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0O03oool0
0`000?l0oooo0?ooo`0Y0?ooo`00/`3oool2000000T0oooo00<0003o0?ooo`3oool0N@3oool20000
ob`0oooo002c0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0M`3oool00`000?l0
oooo0?ooo`0/0?ooo`00/`3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo07H0oooo
00<0003o0?ooo`3oool0;@3oool00;<0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`1c0?ooo`80003o<03oool00;<0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1a
0?ooo`030000o`3oool0oooo0300oooo002c0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool0KP3oool20000oc<0oooo002c0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`0c0?ooo`00/`3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo06T0oooo0P000?lf0?ooo`00/`3oool200000100oooo00<0003o0?ooo`3oool0I`3o
ool00`000?l0oooo0?ooo`0f0?ooo`00/`3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo06@0oooo0P000?li0?ooo`00/`3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0680oooo00<0003o0?ooo`3oool0>@3oool00;<0oooo00<000000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`1P0?ooo`030000o`3oool0oooo03X0oooo002c0?ooo`030000003oool0oooo01<0oooo
00<0003o0?ooo`3oool0G@3oool20000ocd0oooo002c0?ooo`030000003oool0oooo01@0oooo00<0
003o0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0m0?ooo`00/`3oool00`000000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo05P0oooo0P000?m00?ooo`00/`3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo05D0oooo0P000?m20?ooo`00/`3oool2000001P0oooo00<0003o0?ooo`3o
ool0DP3oool20000od@0oooo002c0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
C`3oool20000odH0oooo002c0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`160?ooo`00/`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo04X0oooo0P000?m90?ooo`00/`3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
04L0oooo0P000?m;0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0L0?ooo`80003oA@3oool2
0000odd0oooo002H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg
03<c<`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0400oooo0P000?m?
0?ooo`00V03oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0O0?ooo`80003o?P3oool20000oe40oooo002H0?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<000008@3oool00`000?l0oooo0?ooo`0i
0?ooo`80003oD`3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80
000003<c<`3<c<`01@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03L0oooo00<0
003o0?ooo`3oool0D`3oool009P0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08`3oool20000ocD0oooo0P000?mF0?ooo`00V03oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0U0?ooo`80003o<@3oool20000oeP0oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303o
ool4000000H0oooo00<000000?ooo`3oool09`3oool30000ob/0oooo0`000?mJ0?ooo`00/`3oool0
0`000000oooo0?ooo`0Z0?ooo`80003o9P3oool30000oed0oooo002c0?ooo`030000003oool0oooo
02`0oooo0P000?lQ0?ooo`<0003oH03oool00;<0oooo00<000000?ooo`3oool0;P3oool30000oa/0
oooo0`000?mS0?ooo`00/`3oool200000380oooo10000?lC0?ooo`@0003oIP3oool00;<0oooo00<0
00000?ooo`3oool0=@3oool70000o`D0oooo1`000?mZ0?ooo`00/`3oool00`000000oooo0?ooo`0k
0?ooo`H0003oL@3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00:00oooo0P0000001P0A4A40oooo
0?ooo`0A4A400000014A4AT0oooo0P0000000`0A4A40oooo0?ooo`2R0?ooo`00X@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1P00000<0?ooo`030000003oool0oooo0:<0
oooo002Q0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool500000:@0oooo
002Q0?ooo`060000003oool0A4A403<c<`3oool000002@3oool6000000T0oooo00@0A4A40=gMg@3o
ool00000Y@3oool00:40oooo00H000000=gMg@0c<c<0EEEE0=gMg@00000H0?ooo`040=gMg@1EEED0
oooo00000:D0oooo002Q0?ooo`0600000028R8P0ZZZZ0;^k^`1EEED000006@3oool00`1gMgL0c<c<
0000002U0?ooo`00X@3oool01P000000<c<c0?ooo`3oool0<c<c000001T0oooo00<0k^k^04A4A000
0000Y@3oool00:00oooo00<04A4A00000028R8P00P3oool00`28R8P00000014A4@0I0?ooo`0307Mg
M`000000oooo0:@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.84299, \
0.00802014, 0.0156266}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.450422 0.244399 [
[.02381 .43792 -6 -9 ]
[.02381 .43792 6 0 ]
[.2619 .43792 -12 -9 ]
[.2619 .43792 12 0 ]
[.7381 .43792 -9 -9 ]
[.7381 .43792 9 0 ]
[.97619 .43792 -3 -9 ]
[.97619 .43792 3 0 ]
[.4875 .08382 -24 -4.5 ]
[.4875 .08382 0 4.5 ]
[.4875 .20602 -12 -4.5 ]
[.4875 .20602 0 4.5 ]
[.4875 .32822 -24 -4.5 ]
[.4875 .32822 0 4.5 ]
[.4875 .57262 -18 -4.5 ]
[.4875 .57262 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .45042 m
.02381 .45667 L
s
[(-1)] .02381 .43792 0 1 Mshowa
.2619 .45042 m
.2619 .45667 L
s
[(-0.5)] .2619 .43792 0 1 Mshowa
.7381 .45042 m
.7381 .45667 L
s
[(0.5)] .7381 .43792 0 1 Mshowa
.97619 .45042 m
.97619 .45667 L
s
[(1)] .97619 .43792 0 1 Mshowa
.125 Mabswid
.07143 .45042 m
.07143 .45417 L
s
.11905 .45042 m
.11905 .45417 L
s
.16667 .45042 m
.16667 .45417 L
s
.21429 .45042 m
.21429 .45417 L
s
.30952 .45042 m
.30952 .45417 L
s
.35714 .45042 m
.35714 .45417 L
s
.40476 .45042 m
.40476 .45417 L
s
.45238 .45042 m
.45238 .45417 L
s
.54762 .45042 m
.54762 .45417 L
s
.59524 .45042 m
.59524 .45417 L
s
.64286 .45042 m
.64286 .45417 L
s
.69048 .45042 m
.69048 .45417 L
s
.78571 .45042 m
.78571 .45417 L
s
.83333 .45042 m
.83333 .45417 L
s
.88095 .45042 m
.88095 .45417 L
s
.92857 .45042 m
.92857 .45417 L
s
.25 Mabswid
0 .45042 m
1 .45042 L
s
.5 .08382 m
.50625 .08382 L
s
[(-1.5)] .4875 .08382 1 0 Mshowa
.5 .20602 m
.50625 .20602 L
s
[(-1)] .4875 .20602 1 0 Mshowa
.5 .32822 m
.50625 .32822 L
s
[(-0.5)] .4875 .32822 1 0 Mshowa
.5 .57262 m
.50625 .57262 L
s
[(0.5)] .4875 .57262 1 0 Mshowa
.125 Mabswid
.5 .10826 m
.50375 .10826 L
s
.5 .1327 m
.50375 .1327 L
s
.5 .15714 m
.50375 .15714 L
s
.5 .18158 m
.50375 .18158 L
s
.5 .23046 m
.50375 .23046 L
s
.5 .2549 m
.50375 .2549 L
s
.5 .27934 m
.50375 .27934 L
s
.5 .30378 m
.50375 .30378 L
s
.5 .35266 m
.50375 .35266 L
s
.5 .3771 m
.50375 .3771 L
s
.5 .40154 m
.50375 .40154 L
s
.5 .42598 m
.50375 .42598 L
s
.5 .47486 m
.50375 .47486 L
s
.5 .4993 m
.50375 .4993 L
s
.5 .52374 m
.50375 .52374 L
s
.5 .54818 m
.50375 .54818 L
s
.5 .05938 m
.50375 .05938 L
s
.5 .03494 m
.50375 .03494 L
s
.5 .0105 m
.50375 .0105 L
s
.5 .59706 m
.50375 .59706 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.008 w
.02381 .40989 m
.04262 .38033 L
.06244 .3537 L
.08426 .3299 L
.10458 .31291 L
.12297 .30176 L
.13327 .29722 L
.14264 .29411 L
.14747 .29288 L
.15259 .29184 L
.15697 .29118 L
.15945 .29088 L
.16178 .29067 L
.16306 .29057 L
.16446 .29048 L
.16578 .29042 L
.16701 .29037 L
.16823 .29034 L
.16933 .29033 L
.1706 .29033 L
.1718 .29034 L
.17311 .29037 L
.17377 .29039 L
.17449 .29042 L
.17697 .29055 L
.17837 .29065 L
.17986 .29077 L
.18257 .29105 L
.18785 .29178 L
.19274 .29267 L
.20381 .29542 L
.21356 .29863 L
.22393 .30278 L
.26168 .32324 L
.30188 .35118 L
.34057 .38007 L
.38171 .40883 L
.40223 .42123 L
.42133 .43113 L
.44093 .43937 L
.45944 .44515 L
.46926 .44738 L
.47443 .44831 L
.4799 .44912 L
.4845 .44965 L
.48695 .44987 L
.48957 .45007 L
.49198 .45021 L
.49418 .45031 L
.49523 .45035 L
Mistroke
.49639 .45038 L
.49748 .4504 L
.49849 .45041 L
.49978 .45042 L
.50043 .45042 L
.50114 .45042 L
.5024 .4504 L
.50358 .45038 L
.50429 .45036 L
.50497 .45034 L
.50624 .4503 L
.50908 .45016 L
.51156 .44999 L
.51386 .4498 L
.51905 .44925 L
.52335 .44866 L
.52808 .44788 L
.53767 .44587 L
.55705 .4401 L
.57792 .43148 L
.61912 .40829 L
.65879 .38055 L
.69695 .35204 L
.73757 .32372 L
.75634 .31255 L
.77666 .30252 L
.7878 .29814 L
.79805 .29489 L
.80785 .29255 L
.81279 .29168 L
.81539 .2913 L
.81821 .29096 L
.82093 .2907 L
.82212 .29061 L
.82344 .29052 L
.8246 .29046 L
.82585 .2904 L
.82716 .29036 L
.8284 .29034 L
.82953 .29033 L
.83076 .29033 L
.83205 .29035 L
.83325 .29038 L
.83438 .29043 L
.8354 .29048 L
.8377 .29063 L
.84038 .29087 L
.84285 .29115 L
.84845 .29203 L
.85338 .29308 L
Mistroke
.8586 .29447 L
.86803 .29772 L
.87815 .30233 L
.89646 .31366 L
.91761 .33171 L
.9377 .35389 L
.97592 .40943 L
.97619 .40989 L
Mfstroke
0 0 1 r
.5 Mabswid
.02381 .35667 m
.06244 .22037 L
.08255 .16288 L
.10458 .1109 L
.12507 .07289 L
.14415 .04632 L
.15465 .03525 L
.16457 .02705 L
.17348 .0215 L
.1785 .01911 L
.18314 .01737 L
.1878 .01607 L
.19042 .01553 L
.19281 .01516 L
.19389 .01503 L
.19503 .01492 L
.19629 .01482 L
.19746 .01476 L
.19865 .01472 L
.19977 .01472 L
.20078 .01473 L
.20187 .01476 L
.20316 .01484 L
.20436 .01493 L
.20568 .01507 L
.20709 .01525 L
.20998 .01574 L
.21261 .01631 L
.21769 .01778 L
.2225 .01959 L
.23215 .02441 L
.24241 .0312 L
.26083 .04739 L
.29858 .09421 L
.33878 .15903 L
.37747 .22991 L
.41861 .30817 L
.45823 .38102 L
.49634 .44474 L
.5369 .50253 L
.57595 .54636 L
.59586 .5639 L
.61744 .57918 L
.62755 .58501 L
.63824 .59027 L
.64827 .59436 L
.65742 .5974 L
.66686 .59986 L
.67171 .60086 L
.677 .60175 L
Mistroke
.68187 .60239 L
.68425 .60264 L
.68639 .60284 L
.68847 .60299 L
.69071 .60313 L
.69195 .60318 L
.69308 .60323 L
.69415 .60326 L
.69531 .60329 L
.69658 .60331 L
.69778 .60332 L
.69895 .60332 L
.70003 .60331 L
.70119 .60329 L
.70248 .60326 L
.70382 .60322 L
.70507 .60316 L
.70736 .60304 L
.70946 .6029 L
.71417 .60249 L
.71899 .60191 L
.72425 .60113 L
.73485 .59905 L
.74515 .59643 L
.7545 .59356 L
.77546 .58562 L
.8155 .56563 L
.85402 .54226 L
.89499 .51522 L
.93444 .48906 L
.97238 .46536 L
.97619 .46311 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo001<
0?ooo`/0003oG03oool00`000000oooo0?ooo`2b0?ooo`00B@3oool30000o`/0oooo00<0003o0?oo
o`3oool0F@3oool00`000000oooo0?ooo`2b0?ooo`00A`3oool20000o`l0oooo0`000?mH0?ooo`03
0000003oool0oooo0;80oooo00160?ooo`030000o`3oool0oooo0180oooo0P000?mF0?ooo`030000
003oool0oooo0;80oooo00150?ooo`030000o`3oool0oooo01D0oooo0P000?mD0?ooo`030000003o
ool0oooo0;80oooo00140?ooo`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0D@3oool0
0`000000oooo0?ooo`2b0?ooo`00@`3oool00`000?l0oooo0?ooo`0J0?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0/P3oool00480oooo00<0003o0?ooo`3oool0703oool00`000?l0
oooo0?ooo`1?0?ooo`800000/`3oool00440oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo0;80oooo00100?ooo`030000o`3oool0oooo0200oooo00<0
003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`2b0?ooo`00?`3oool00`000?l0oooo0?ooo`0R
0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0/P3oool003l0oooo00<0003o0?oo
o`3oool08`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo0;80oooo000n0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`2b0?ooo`00
?@3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0
/P3oool003`0oooo00<0003o0?ooo`3oool0:03oool00`000?l0oooo0?ooo`190?ooo`030000003o
ool0oooo0;80oooo000k0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3oool0B03oool2
00000;<0oooo000k0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`2b0?ooo`00>P3oool00`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool0/P3oool003T0oooo00<0003o0?ooo`3oool0;P3oool00`000?l0oooo
0?ooo`160?ooo`030000003oool0oooo0;80oooo000h0?ooo`030000o`3oool0oooo0300oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`2b0?ooo`00>03oool00`000?l0oooo0?ooo`0a
0?ooo`030000o`3oool0oooo02X0oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool0
1@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo0P0R8R88
0?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool003L0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`0P0?ooo`H000001@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool003H0oooo00<0003o0?ooo`3o
ool0=@3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo00h0oooo00<0MgMg03<c<`3o
ool0103oool300000;80oooo000f0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool0
:@3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000
oooo0?ooo`2b0?ooo`00=@3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo02P0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo
000e0?ooo`030000o`3oool0oooo03T0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o
0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0U0?ooo`80EEEE00<000000?ooo`3oool02`3oool4
000000H0oooo00<000000?ooo`3oool0/P3oool003@0oooo00<0003o0?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0;80oooo000c0?ooo`030000o`3oool0oooo03d0
oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`2b0?ooo`00<`3oool00`000?l0oooo
0?ooo`0m0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0/P3oool00380oooo00<0
003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`800000/`3oool00380oooo00<0003o
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo0;80oooo000a0?oo
o`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`2b0?oo
o`00<@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0/P3oool00300oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo0;80oooo000`0?ooo`030000o`3oool0oooo04@0oooo00<0003o0?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2b0?ooo`00;`3oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0
oooo03P0oooo00<000000?ooo`3oool0/P3oool002l0oooo00<0003o0?ooo`3oool0AP3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0;80oooo000^0?ooo`030000o`3oool0oooo04P0
oooo00<0003o0?ooo`3oool0=`3oool200000;<0oooo000^0?ooo`030000o`3oool0oooo04P0oooo
00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`2b0?ooo`00;P3oool00`000?l0oooo0?oo
o`190?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0/P3oool002d0oooo00<0003o
0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo0;80oooo000]0?oo
o`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`2b0?oo
o`00;03oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3o
ool0/P3oool002`0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0d0?ooo`030000
003oool0oooo0;80oooo000[0?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool0<`3o
ool00`000000oooo0?ooo`2b0?ooo`00:`3oool00`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0
oooo0380oooo0P00002c0?ooo`00:P3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo
0380oooo00<000000?ooo`3oool0/P3oool002X0oooo00<0003o0?ooo`3oool0DP3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo0;80oooo000Z0?ooo`030000o`3oool0oooo0580oooo
00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`2b0?ooo`00:@3oool00`000?l0oooo0?oo
o`1D0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0/P3oool002T0oooo00<0003o
0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo0;80oooo000Y0?oo
o`030000o`3oool0oooo05D0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`2b0?oo
o`00:03oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3o
ool0/P3oool002P0oooo00<0003o0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`0^0?ooo`800000
/`3oool002P0oooo00<0003o0?ooo`3oool0F03oool00`000?l0oooo0?ooo`0]0?ooo`030000003o
ool0oooo0;80oooo000W0?ooo`030000o`3oool0oooo05T0oooo00<0003o0?ooo`3oool0;@3oool0
0`000000oooo0?ooo`2b0?ooo`009`3oool00`000?l0oooo0?ooo`1J0?ooo`030000o`3oool0oooo
02`0oooo00<000000?ooo`3oool0/P3oool002L0oooo00<0003o0?ooo`3oool0F`3oool00`000?l0
oooo0?ooo`0[0?ooo`030000003oool0oooo0;80oooo000V0?ooo`030000o`3oool0oooo05`0oooo
00<0003o0?ooo`3oool08@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0
/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002H0oooo00<0003o0?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`0G0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;80oooo000U0?ooo`030000o`3oool0oooo05l0oooo00<0003o0?ooo`3oool08@3oool00`00
0000oooo0?ooo`050?ooo`<00000/P3oool002D0oooo00<0003o0?ooo`3oool0G`3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002D0oooo
00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?oo
o`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o
0?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0M0?ooo`80EEEE00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2b0?ooo`00903oool00`000?l0oooo0?ooo`1S0?ooo`030000o`3oool0oooo
02H0oooo00<000000?ooo`3oool0/P3oool002@0oooo00<0003o0?ooo`3oool0H`3oool00`000?l0
oooo0?ooo`0V0?ooo`030000003oool0oooo0;80oooo000S0?ooo`030000o`3oool0oooo06D0oooo
00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`2b0?ooo`008`3oool00`000?l0oooo0?oo
o`1U0?ooo`030000o`3oool0oooo02D0oooo0P00002c0?ooo`008`3oool00`000?l0oooo0?ooo`1V
0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0/P3oool00280oooo00<0003o0?oo
o`3oool0I`3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo0;80oooo000R0?ooo`03
0000o`3oool0oooo06P0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`2b0?ooo`00
8P3oool00`000?l0oooo0?ooo`1X0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0
/P3oool00280oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0R0?ooo`030000003o
ool0oooo0;80oooo000Q0?ooo`030000o`3oool0oooo06X0oooo00<0003o0?ooo`3oool08P3oool0
0`000000oooo0?ooo`2b0?ooo`008@3oool00`000?l0oooo0?ooo`1[0?ooo`030000o`3oool0oooo
0240oooo00<000000?ooo`3oool0/P3oool00240oooo00<0003o0?ooo`3oool0J`3oool00`000?l0
oooo0?ooo`0Q0?ooo`800000/`3oool00200oooo00<0003o0?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`0P0?ooo`030000003oool0oooo0;80oooo000P0?ooo`030000o`3oool0oooo06d0oooo00<0
003o0?ooo`3oool0803oool00`000000oooo0?ooo`2b0?ooo`00803oool00`000?l0oooo0?ooo`1^
0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0/P3oool00200oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo0;80oooo000O0?ooo`03
0000o`3oool0oooo0700oooo00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`2b0?ooo`00
7`3oool00`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool0
/P3oool001l0oooo00<0003o0?ooo`3oool0L@3oool00`000?l0oooo0?ooo`0M0?ooo`030000003o
ool0oooo0;80oooo000N0?ooo`030000o`3oool0oooo0780oooo00<0003o0?ooo`3oool07@3oool2
00000;<0oooo000N0?ooo`030000o`3oool0oooo07<0oooo00<0003o0?ooo`3oool0703oool00`00
0000oooo0?ooo`2b0?ooo`007P3oool00`000?l0oooo0?ooo`1c0?ooo`030000o`3oool0oooo01`0
oooo00<000000?ooo`3oool0/P3oool001d0oooo00<0003o0?ooo`3oool08@3oool<0?l004P0oooo
00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`1S0?ooo``0o`00@`3oool001d0oooo00<0
003o0?ooo`3oool0703ooolE0?l004@0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?oo
o`1P0?oooa80o`00@03oool001d0oooo00<0003o0?ooo`3oool06@3oool90?l000X0oooo2@3o0011
0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0G03oool80?l000X0oooo1`3o000m
0?ooo`007@3oool00`000?l0oooo0?ooo`0H0?ooo`D0o`004`3oool80?l003h0oooo00<0003o0?oo
o`3oool06P3oool00`000000oooo0?ooo`1I0?ooo`P0o`00403oool70?l003X0oooo000L0?ooo`03
0000o`3oool0oooo01L0oooo103o000J0?ooo`L0o`00?03oool00`000?l0oooo0?ooo`0I0?ooo`03
0000003oool0oooo05H0oooo1`3o000G0?ooo`L0o`00=`3oool001`0oooo00<0003o0?ooo`3oool0
5P3oool40?l001h0oooo1P3o000j0?ooo`030000o`3oool0oooo01T0oooo0P00001D0?ooo`L0o`00
7@3oool50?l003H0oooo000L0?ooo`030000o`3oool0oooo01@0oooo103o000S0?ooo`@0o`00>P3o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo0540oooo1P3o000S0?ooo`@0o`00=03o
ool001/0oooo00<0003o0?ooo`3oool0503oool40?l002H0oooo103o000h0?ooo`030000o`3oool0
oooo01P0oooo00<000000?ooo`3oool0C`3oool50?l002L0oooo103o000c0?ooo`006`3oool00`00
0?l0oooo0?ooo`0B0?ooo`@0o`00:@3oool50?l003L0oooo00<0003o0?ooo`3oool05`3oool00`00
0000oooo0?ooo`1>0?ooo`@0o`00:`3oool40?l00340oooo000K0?ooo`030000o`3oool0oooo0140
oooo103o000/0?ooo`@0o`00=P3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo04`0
oooo103o000^0?ooo`@0o`00<03oool001/0oooo00<0003o0?ooo`3oool03`3oool40?l00300oooo
103o000c0?ooo`050>k^kP0c<c<0003o03<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A400000000
0000<c<c0=gMg@050?ooo`030000003oool0oooo04/0oooo103o000a0?ooo`<0o`00;`3oool001X0
oooo00<0003o0?ooo`3oool03`3oool40?l00380oooo1@3o000a0?ooo`0507MgM`2IVIT0003o09VI
V@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`190?oo
o`@0o`00=03oool30?l002h0oooo000J0?ooo`030000o`3oool0oooo00h0oooo0`3o000f0?ooo`@0
o`00:03oool600000080oooo00D04A4A0?ooo`3oool0003o014A4@0@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0B03oool40?l003H0oooo0`3o000]0?ooo`006P3oool00`000?l0
oooo0?ooo`0=0?ooo`<0o`00>@3oool40?l002h0oooo00D000000?ooo`3oool0oooo0000o`0?0?oo
o`0307MgM`0c<c<0oooo00@0oooo0`0000160?ooo`@0o`00>@3oool30?l002`0oooo000I0?ooo`03
0000o`3oool0oooo00h0oooo0P3o000k0?ooo`@0o`00;@3oool01@000000oooo0?ooo`3oool0003o
00`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`030000003oool0oooo04D0oooo103o000k
0?ooo`<0o`00:`3oool001T0oooo00<0003o0?ooo`3oool03@3oool30?l003d0oooo103o000[0?oo
o`06014A4@3oool0oooo0?ooo`0A4A40003o2`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo04<0oooo103o000n0?ooo`80o`00:`3oool001T0oooo00<0003o0?ooo`3oool0303oool3
0?l003l0oooo103o000Z0?ooo`0607MgM`2IVIT0oooo09VIV@1gMgL0003o2`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0440oooo1@3o000o0?ooo`<0o`00:P3oool001T0oooo00<0
003o0?ooo`3oool02`3oool30?l00480oooo0`3o000Y0?ooo`070>k^kP0c<c<0000003<c<`3^k^h0
oooo0000o`0:0?ooo`@000001P3oool00`000000oooo0?ooo`100?ooo`@0o`00@P3oool30?l002T0
oooo000H0?ooo`030000o`3oool0oooo00/0oooo0`3o00140?ooo`@0o`00;@3oool00`000?l0oooo
0?ooo`0B0?ooo`030000003oool0oooo03h0oooo103o00150?ooo`<0o`00:03oool001P0oooo00<0
003o0?ooo`3oool02P3oool30?l004H0oooo103o000]0?ooo`030000o`3oool0oooo0140oooo00<0
00000?ooo`3oool0?@3oool40?l004L0oooo0`3o000W0?ooo`00603oool00`000?l0oooo0?ooo`09
0?ooo`<0o`00B@3oool40?l002/0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0k
0?ooo`@0o`00BP3oool30?l002H0oooo000G0?ooo`030000o`3oool0oooo00T0oooo0`3o001;0?oo
o`@0o`00:`3oool00`000?l0oooo0?ooo`0@0?ooo`800000>`3oool40?l004`0oooo0`3o000U0?oo
o`005`3oool00`000?l0oooo0?ooo`090?ooo`80o`00CP3oool30?l002X0oooo00<0003o0?ooo`3o
ool0403oool00`000000oooo0?ooo`0i0?ooo`<0o`00C`3oool20?l002D0oooo000R0?ooo`<0o`00
C`3oool40?l002T0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0h0?ooo`<0o`00
D03oool30?l002@0oooo000Q0?ooo`<0o`00D@3oool40?l002P0oooo00<0003o0?ooo`3oool03`3o
ool00`000000oooo0?ooo`0g0?ooo`<0o`00DP3oool30?l002<0oooo000P0?ooo`<0o`00E03oool3
0?l002P0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0e0?ooo`@0o`00E03oool3
0?l00280oooo000O0?ooo`<0o`00EP3oool30?l002P0oooo00<0003o0?ooo`3oool03@3oool00`00
0000oooo0?ooo`0d0?ooo`@0o`00EP3oool20?l00280oooo000O0?ooo`80o`00F03oool40?l002H0
oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0c0?ooo`<0o`00F03oool30?l00240
oooo000N0?ooo`<0o`00F@3oool40?l002H0oooo00<0003o0?ooo`3oool0303oool00`000000oooo
0?ooo`0b0?ooo`<0o`00FP3oool30?l00200oooo000M0?ooo`<0o`00G03oool30?l002D0oooo00<0
003o0?ooo`3oool0303oool200000380oooo0`3o001L0?ooo`80o`00803oool001`0oooo0`3o001N
0?ooo`@0o`00903oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo02l0oooo103o001M
0?ooo`<0o`007`3oool001`0oooo0P3o001P0?ooo`@0o`008`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000003oool0oooo02h0oooo103o001O0?ooo`<0o`007P3oool001/0oooo0`3o001R0?ooo`@0
o`008P3oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo02`0oooo103o001R0?ooo`<0
o`007@3oool001X0oooo0`3o001T0?ooo`@0o`008P3oool00`000?l0oooo0?ooo`090?ooo`030000
003oool0oooo02/0oooo103o001T0?ooo`80o`007@3oool001X0oooo0P3o001W0?ooo`@0o`00803o
ool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02T0oooo103o001V0?ooo`<0o`00703o
ool001T0oooo0`3o001X0?ooo`@0o`00803oool00`000?l0oooo0?ooo`080?ooo`030000003oool0
oooo02P0oooo103o001X0?ooo`<0o`006`3oool001P0oooo0`3o001[0?ooo`<0o`007`3oool00`00
0?l0oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo0`3o001[0?ooo`80o`006`3oool001P0
oooo0P3o001]0?ooo`@0o`007P3oool00`000?l0oooo0?ooo`070?ooo`8000009P3oool40?l006`0
oooo0`3o000J0?ooo`005`3oool30?l006h0oooo103o000N0?ooo`030000o`3oool0oooo00H0oooo
00<000000?ooo`3oool0903oool40?l006h0oooo0`3o000I0?ooo`005P3oool30?l000@0000000<0
4A4A0?ooo`3oool0?P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd05P3oool40?l001`0oooo00<0003o0?ooo`3oool01P3oool00`000000
oooo0?ooo`0R0?ooo`@0o`006P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd0@@3oool30?l000030000000A4A40oooo01D0oooo000F0?oo
o`80o`000`3oool00`000000oooo0?ooo`100?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2
028R8PP0oooo00<0MgMg03<c<`3oool05P3oool50?l001/0oooo00<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`0P0?ooo`D0o`006`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R
8R880?ooo`0307MgM`0c<c<0oooo0440oooo0P3o000H0?ooo`00403oool6000000D0oooo00<00000
0?ooo`3oool0>03oool600000080oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003o
ool0oooo01L0oooo103o000K0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool07P3o
ool50?l001d0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool05P3oool001/0oooo00<000000?ooo`3oool0@03oool01@000000oooo0?oo
o`3oool0000000l0oooo00<0MgMg03<c<`3oool06P3oool40?l001T0oooo00<0003o0?ooo`3oool0
103oool00`000000oooo0?ooo`0L0?ooo`D0o`007`3oool01@000000oooo0?ooo`3oool0000000l0
oooo00<0MgMg03<c<`3oool0@P3oool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo
0?ooo`100?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<
01`0oooo1@3o000H0?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool06`3oool40?l0
0240oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`0@`3o
ool00`000000oooo0?ooo`0F0?ooo`006`3oool00`000000oooo0?ooo`100?ooo`05014A4@3oool0
oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`0P0?ooo`D0o`005P3oool00`000?l0oooo0?oo
o`030?ooo`030000003oool0oooo01T0oooo103o000S0?ooo`05014A4@3oool0oooo0?ooo`0A4A40
303oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01H0oooo000K0?ooo`030000003o
ool0oooo0400oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo0280oooo
1@3o000E0?ooo`030000o`3oool0oooo0080oooo0P00000H0?ooo`D0o`00903oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0F0?ooo`00
6@3oool205EEE@030000003oool0oooo0400oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@0
00008`3oool50?l001@0oooo00D0003o0?ooo`3oool0oooo0000000G0?ooo`D0o`009P3oool01@3^
k^h0<c<c0000000c<c<0k^k^00`0oooo100000120?ooo`80EEEE00<000000?ooo`3oool05P3oool0
09P0oooo1P3o000A0?ooo`050000o`3oool0oooo0?ooo`000000503oool60?l009X0oooo002J0?oo
o`H0o`00403oool010000?l0oooo0?ooo`00000B0?ooo`H0o`00W03oool009d0oooo1P3o000=0?oo
o`040000o`3oool0oooo000000l0oooo1P3o002O0?ooo`00W`3oool70?l000/0oooo00<0003o0?oo
o`000000303oool70?l00:40oooo002R0?ooo`L0o`002@3oool00`000?l000000?ooo`080?ooo`L0
o`00Y03oool00:D0oooo303o0000103oool0003o0000003oool<0?l00:L0oooo000?0?oooiT00000
2`3o00000`000?l0o`000?l000080?l009X00000403oool001L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3o
ool40?l000030000o`3o0000oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool001L0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`03000000000?l0oooo04/0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0F0?ooo`00/`3oool00`000000oooo0000o`2b0?oo
o`00/`3oool010000000oooo0?ooo`000?nF0?ooo`<0003o603oool00;<0oooo00@000000?ooo`3o
ool0003oU@3oool00`000?l0oooo0?ooo`0I0?ooo`00/`3oool01@000000oooo0?ooo`3oool0003o
0980oooo0P000?lL0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo08d0
oooo0P000?lN0?ooo`00/`3oool2000000@0oooo00<0003o0?ooo`3oool0R`3oool00`000?l0oooo
0?ooo`0N0?ooo`00/`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo08T0oooo0P00
0?lQ0?ooo`00/`3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo08H0oooo0P000?lS
0?ooo`00/`3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo08@0oooo00<0003o0?oo
o`3oool08`3oool00;<0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`220?ooo`80
003o9P3oool00;<0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`200?ooo`030000
o`3oool0oooo02H0oooo002c0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0O@3o
ool20000obT0oooo002c0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0O03oool0
0`000?l0oooo0?ooo`0Y0?ooo`00/`3oool2000000T0oooo00<0003o0?ooo`3oool0N@3oool20000
ob`0oooo002c0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0M`3oool00`000?l0
oooo0?ooo`0/0?ooo`00/`3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo07H0oooo
00<0003o0?ooo`3oool0;@3oool00;<0oooo00<000000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`1c0?ooo`80003o<03oool00;<0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1a
0?ooo`030000o`3oool0oooo0300oooo002c0?ooo`030000003oool0oooo00`0oooo00<0003o0?oo
o`3oool0KP3oool20000oc<0oooo002c0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`0c0?ooo`00/`3oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo06T0oooo0P000?lf0?ooo`00/`3oool200000100oooo00<0003o0?ooo`3oool0I`3o
ool00`000?l0oooo0?ooo`0f0?ooo`00/`3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo06@0oooo0P000?li0?ooo`00/`3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0680oooo00<0003o0?ooo`3oool0>@3oool00;<0oooo00<000000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`1P0?ooo`030000o`3oool0oooo03X0oooo002c0?ooo`030000003oool0oooo01<0oooo
00<0003o0?ooo`3oool0G@3oool20000ocd0oooo002c0?ooo`030000003oool0oooo01@0oooo00<0
003o0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0m0?ooo`00/`3oool00`000000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo05P0oooo0P000?m00?ooo`00/`3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo05D0oooo0P000?m20?ooo`00/`3oool2000001P0oooo00<0003o0?ooo`3o
ool0DP3oool20000od@0oooo002c0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
C`3oool20000odH0oooo002c0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`160?ooo`00/`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo04X0oooo0P000?m90?ooo`00/`3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
04L0oooo0P000?m;0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`0L0?ooo`80003oA@3oool2
0000odd0oooo002H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg
03<c<`3oool0103oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0400oooo0P000?m?
0?ooo`00V03oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0O0?ooo`80003o?P3oool20000oe40oooo002H0?ooo`050000003oool0oooo
0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<000008@3oool00`000?l0oooo0?ooo`0i
0?ooo`80003oD`3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80
000003<c<`3<c<`01@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03L0oooo00<0
003o0?ooo`3oool0D`3oool009P0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool08`3oool20000ocD0oooo0P000?mF0?ooo`00V03oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0U0?ooo`80003o<@3oool20000oeP0oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303o
ool4000000H0oooo00<000000?ooo`3oool09`3oool30000ob/0oooo0`000?mJ0?ooo`00/`3oool0
0`000000oooo0?ooo`0Z0?ooo`80003o9P3oool30000oed0oooo002c0?ooo`030000003oool0oooo
02`0oooo0P000?lQ0?ooo`<0003oH03oool00;<0oooo00<000000?ooo`3oool0;P3oool30000oa/0
oooo0`000?mS0?ooo`00/`3oool200000380oooo10000?lC0?ooo`@0003oIP3oool00;<0oooo00<0
00000?ooo`3oool0=@3oool70000o`D0oooo1`000?mZ0?ooo`00/`3oool00`000000oooo0?ooo`0k
0?ooo`H0003oL@3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00:00oooo0P0000001P0A4A40oooo
0?ooo`0A4A400000014A4AL0oooo00D0k^k^03<c<`0000004A4A0<c<c02T0?ooo`00X@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1P0000090?ooo`0505EEE@1gMgL0oooo
09VIV@0R8R80Y03oool00:40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?oo
o`050000003oool0oooo0?ooo`000000Y03oool00:40oooo00H000000?ooo`14A4@0<c<c0?ooo`00
00090?ooo`H000002@3oool01@000000VIVI0?ooo`2IVIT08R8R0:@0oooo002Q0?ooo`060000003M
gMd0<c<c05EEE@3MgMd00000603oool01@000000EEEE0000000A4A40c<c<0:@0oooo002Q0?ooo`06
00000028R8P0ZZZZ0;^k^`1EEED00000603oool00`1EEED0R8R80?ooo`2V0?ooo`00X@3oool01P00
0000<c<c0?ooo`3oool0<c<c000001P0oooo00<0gMgM014A4@2IVIT0YP3oool00:00oooo00<04A4A
00000028R8P00P3oool00`28R8P00000014A4@0H0?ooo`040<c<c014A4@00000014A4J@0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.15169, -1.84299, \
0.00802014, 0.0156266}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Only the ",
  "even",
  " part of the function is properly represented by this set, because the \
orthogonal functions used in the series are all even in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". The odd part of the function cannot be represented by these even \
polynomials."
}], "Text"],

Cell[TextData[{
  "\tThus, we cannot choose ",
  StyleBox["any ",
    FontSlant->"Italic"],
  "set of orthogonal functions that we wish when making a generalized Fourier \
series  expansion. The set of functions must be ",
  StyleBox["complete",
    FontSlant->"Italic"],
  ". That is, a linear combination of these functions must be able to \
represent any given function in the range of interest, ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  "."
}], "Text",
  CellTags->"i:11"],

Cell[TextData[{
  "\t In the next section, we will discuss how to find sets of orthogonal \
functions that are guaranteed to be complete. These functions are eigenmodes \
of the spatial operators that appear in the linear PDEs we studied in Chapter \
",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  ". As such, they are just the thing for describing solutions to the PDEs in \
terms of generalized Fourier series."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.3 Eigenmodes of Hermitian Operators", "Subsubtitle",
  CellTags->"c:8"],

Cell[CellGroupData[{

Cell["Hermitian Operators and Sturm-Liouville Problems", "Section",
  CellTags->{"i:13", "c:9"}],

Cell[TextData[{
  "An operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is defined to be ",
  StyleBox["Hermitian",
    FontSlant->"Italic"],
  " with respect to a given inner product on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  ", and with respect to some  set of functions",
  ",",
  " if, for any two functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g\)\(\ \)\)\)]],
  " taken from this set, ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " satisfies the following equation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"f", ",", " ", 
              RowBox[{
                FormBox[\(L\&^\),
                  "TraditionalForm"], " ", "g"}]}], ")"}], "=", 
          " ", \((\(L\&^\) f, g)\)}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(4.1.12)"],

Cell["\<\
An operator can be Hermitian only with respect to a given set of \
functions and a given inner product. \
\>", "Text"],

Cell["\<\
\tAs an example of a Hermitian operator consider the following \
second-order linear differential operator:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \ \(1\/\(p(
                  x)\)\) \(\[DifferentialD]\/\[DifferentialD]x\)[\(r(
                  x)\) \[DifferentialD]\/\[DifferentialD]x] + q(x)\)]],
  " . "
}], "NE2",
  CellTags->"(4.1.13)"],

Cell[TextData[{
  "on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ \ x \[LessEqual] \ \ b\)]],
  ". The functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p(x)\)\(,\)\(\ \)\(q(x)\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r(x)\)]],
  "  are assumed to be real, and also ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r(x)\)]],
  "  are required to be positive-definite on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  " . "
}], "Text"],

Cell[TextData[{
  "\tThis operator is called a ",
  ButtonBox["Sturm",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Sturm.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["Liouville",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Liouville.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " operator. Second-order operators of this type crop up regularly in \
mathematical physics. In fact, this kind of operator appeared in every \
eigenvalue problem that we encountered in Chapter ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  ". These eigenvalues problems are called ",
  StyleBox["Sturm-Liouville problems",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:14"],

Cell["\<\
\tThe Sturm-Liouville operator is Hermitian with respect to  the \
inner product\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\((f, g)\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\(\( f\^*\)(x)\) \(g(x)\)\ \(p(
            x)\) \[DifferentialD]x\)]],
  ","
}], "NE2",
  CellTags->"(4.1.14)"],

Cell[TextData[{
  "[where the weight function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  " is the same as that which appears in Eq. ",
  ButtonBox["(4.1.13)",
    ButtonData:>"(4.1.13)",
    ButtonStyle->"Hyperlink"],
  "] and with respect to functions that satisfy a broad class of homogeneous \
boundary conditions. Recall that homogeneous boundary conditions are such \
that one solution to the eigenvalue problem ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi] = \[Lambda]\ \[Psi]\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  ". "
}], "Text",
  CellTags->"i:115"],

Cell["\<\
\tFor a  Sturm-Liouville operator to be Hermitian, these \
homogeneous boundary conditions can take several forms:\
\>", "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r \[NotEqual] \ 0\)]],
  " at the endpoints ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ",  the boundary conditions on the functions can be either homogeneous \
mixed, von Neumann, or Dirichlet. The boundary conditions can be of different \
types at each end: e.g. Dirichlet at one end, and ",
  "von Neumann",
  " at the other."
}], "Text"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " at one or both ends of the interval, then at these ends the functions and \
their first derivatives need merely be finite. "
}], "Text"],

Cell[TextData[{
  "The functions can also satisfy ",
  StyleBox["periodic boundary conditions",
    FontSlant->"Italic"],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`r(a) = r(b)\)]],
  " (see the exercises). "
}], "Text"],

Cell[TextData[{
  "\tFor these classes of functions, it is easy to show that the \
Sturm-Liouville operator is Hermitian with respect to the inner product of \
Eq. ",
  ButtonBox["(4.1.14)",
    ButtonData:>"(4.1.14)",
    ButtonStyle->"Hyperlink"],
  ". Starting with the inner product ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{"f", ",", " ", 
            RowBox[{
              FormBox[\(L\&^\),
                "TraditionalForm"], " ", "g"}]}], ")"}], TraditionalForm]]],
  ", two integrations by parts yield"
}], "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"(", 
          RowBox[{"f", ",", " ", 
            RowBox[{
              FormBox[\(L\&^\),
                "TraditionalForm"], " ", "g"}]}], ")"}], "=", 
        RowBox[{
          SubsuperscriptBox[
            StyleBox["\[Integral]",
              FontSize->9], "a", 
            "b"], \(\(\(f\^*\)(
              x)\)\ \((\(1\/\(p(
                        x)\)\) \(\[DifferentialD]\/\[DifferentialD]x\)[\(r(
                        x)\) \(\[DifferentialD]\/\[DifferentialD]x\) \(g(
                        x)\)] + \ \(q(x)\) \(g(x)\))\) \(p(
              x)\) \[DifferentialD]x\)}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"=", 
        RowBox[{
          RowBox[{"r", " ", \(f\^*\), 
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], "g"}], 
          SubsuperscriptBox[
            StyleBox["|",
              FontSize->10], \(x = a\), \(x = b\)], 
          RowBox[{"-", 
            RowBox[{
              SubsuperscriptBox[
                StyleBox["\[Integral]",
                  FontSize->9], "a", 
                "b"], \(\((r \(\[DifferentialD]\(f\^*\)\/\[DifferentialD]x\) \
\[DifferentialD]g\/\[DifferentialD]x + 
                    q\ p\ \(f\^*\) g)\) \[DifferentialD]x\)}]}]}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"=", 
        RowBox[{
          RowBox[{"r", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(f\^*\), 
                  FractionBox["\[PartialD]", \(\[PartialD]x\),
                    MultilineFunction->None], "g"}], "-", 
                RowBox[{"g", 
                  FractionBox["\[PartialD]", \(\[PartialD]x\),
                    MultilineFunction->None], \(f\^*\)}]}], ")"}]}], 
          SubsuperscriptBox[
            StyleBox["|",
              FontSize->14], \(x = a\), \(x = 
              b\)], \(+\(\[Integral]\_a\%b 
                  g\ [\(\[DifferentialD]\/\[DifferentialD]x\) \((r \(\
\[DifferentialD]\/\[DifferentialD]x\) \(f\^*\))\) + \ 
                    q\ p\ \(f\^*\)] \[DifferentialD]x\)\)}]}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"=", 
        RowBox[{
          RowBox[{"r", "(", 
            RowBox[{
              RowBox[{\(f\^*\), 
                FractionBox["\[PartialD]", \(\[PartialD]x\),
                  MultilineFunction->None], "g"}], "-", 
              RowBox[{"g", 
                FractionBox["\[PartialD]", \(\[PartialD]x\),
                  MultilineFunction->None], \(f\^*\)}]}], ")"}], 
          SubsuperscriptBox[
            StyleBox["|",
              FontSize->14], \(x = a\), \(x = b\)], 
          RowBox[{"+", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    FormBox[\(L\&^\),
                      "TraditionalForm"], " ", "f"}], ",", "g"}], ")"}], 
              "."}]}]}]}], TraditionalForm]}]]], "NE2",
  CellTags->"(4.1.15)"],

Cell[TextData[{
  "However, the boundary terms vanish because of the restriction to the sets \
of functions that satisfy  the listed boundary conditions. Therefore, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{"f", ",", " ", 
              RowBox[{
                FormBox[\(L\&^\),
                  "TraditionalForm"], " ", "g"}]}], ")"}], "=", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{
                FormBox[\(L\&^\),
                  "TraditionalForm"], " ", "f"}], ",", "g"}], ")"}]}], 
        TraditionalForm]]],
  ", so the Sturm-Liouville operator is Hermitian for these sets of functions \
and this inner product."
}], "Text"],

Cell[TextData[{
  "\t Many second-order operators that do not appear to be of Sturm-Liouville \
form can be put in this form. For  instance, the operator for damped harmonic \
motion, ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \ \
\[DifferentialD]\^2\(\(/\)\(\[DifferentialD]x\^2\)\) + \[Nu]\ \
\[DifferentialD]\(\(/\)\(\[DifferentialD]x\)\)\  + \ \[Omega]\_o\%2\)]],
  ", can be written  as"
}], "Text",
  CellTags->"i:116"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \
\(1\/\[ExponentialE]\^\(\(\[VeryThinSpace]\)\(\[Nu]\ x\)\)\) \(\
\[DifferentialD]\/\[DifferentialD]x\) \((\(\[ExponentialE]\^\(\[Nu]\ x\)\) \
\[DifferentialD]\/\[DifferentialD]x)\) + \ \[Omega]\_o\%2\)]],
  "."
}], "NE2",
  CellTags->"(4.1.16)"],

Cell[TextData[{
  "Since this operator is of Sturm-Liouville form with ",
  Cell[BoxData[
      \(TraditionalForm\`p(x) = \[ExponentialE]\^\(\[Nu]\ x\)\)]],
  ",  it is Hermitian with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b\( \[ExponentialE]\^\(\(\[VeryThinSpace]\ \
\)\(\[Nu]\ x\)\)\) \(f\^*\) g \[DifferentialD]x\)]],
  ", and with respect to functions that satisfy any of the homogeneous \
boundary conditions discussed with respect to Eqs. ",
  ButtonBox["(4.1.13)",
    ButtonData:>"(4.1.13)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.1.14)",
    ButtonData:>"(4.1.14)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\t More generally, the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \ \
\[DifferentialD]\^2\(\(/\)\(\[DifferentialD]x\^2\)\) + \(\(u\_1\)(
              x)\)\ \[DifferentialD]\(\(/\)\(\[DifferentialD]x\)\)\  + \ \
\(u\_o\)(x)\)]],
  " can also be put in Sturm-Liouville form:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \
\(1\/\[ExponentialE]\^\(\(\[VeryThinSpace]\)\(\[Integral]\^x\(\( u\_1\)(y)\) \
\[DifferentialD]y\)\)\) \(\[DifferentialD]\/\[DifferentialD]x\) \((\(\
\[ExponentialE]\^\(\[Integral]\^x\(\( u\_1\)(
                          y)\) \[DifferentialD]y\)\) \[DifferentialD]\/\
\[DifferentialD]x)\) + \ \(u\_o\)(x)\)]],
  "."
}], "NE2",
  CellTags->"(4.1.17)"],

Cell[TextData[{
  "\tSome higher-order operators are also Hermitian. For instance, the \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^4\(\(/\)\(\[DifferentialD]x\
\^4\)\)\)]],
  " can be shown to be Hermitian with respect to the inner product  ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b\( f\^*\) g \[DifferentialD]x\)]],
  " for functions that vanish, along with their first derivatives,  at the \
ends of the interval. (See the exercises.) However, other operators are not \
Hermitian. One simple example is ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          
          FormBox[\(L\&^ = \[DifferentialD]\^3\(\(/\)\(\[DifferentialD]x\^3\)\
\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Another is ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2\(\(/\)\(\[DifferentialD]x\^2\)\) \
+ \[Nu]\ \ \[DifferentialD]\(\(/\)\(\[DifferentialD]x\)\)\  + b\)]],
  " for ",
  StyleBox["complex constants",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenmodes", "Section",
  CellTags->{"i:12", "c:10"}],

Cell[TextData[{
  "\tWhy should we care that an operator is Hermitian? Because the eigenmodes \
of Hermitian operators form an orthogonal set. Also, the eigenvalues of such \
operators are real. Consider the set of eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_n}\)]],
  " of an  operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " . Each eigenfunction satisfies  the ODE"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]]], \
"NE2",
  CellTags->"(4.1.18)"],

Cell[TextData[{
  "on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  ". Let us assume that this operator is Hermitian with respect to a set of \
functions that includes these eigenfunctions,  and with respect to some  \
inner product. Then the following theorem holds:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox[\(Theorem\ 4  .1\),
              FontWeight->"Bold"]},
          {
            RowBox[{
              RowBox[{"Any", " ", "two", " ", "eigenfunctions", 
                FormBox[
                  StyleBox[\(\[Psi]\_n\),
                    FontFamily->"Times"],
                  "TraditionalForm"], "and", 
                FormBox[
                  StyleBox[\(\[Psi]\_m\),
                    FontFamily->"Times"],
                  "TraditionalForm"], "of", " ", "a", " ", "Hermitian", " ", 
                "operator", 
                StyleBox[
                  FormBox[
                    OverscriptBox[
                      StyleBox["L",
                        FontFamily->"Times"], "^"],
                    "TraditionalForm"],
                  FontFamily->"Times"], 
                StyleBox[" ",
                  FontFamily->"Times"], "are", " ", "orthogonal", " ", 
                "provided", " ", "that", " ", "the", " ", "associated"}], 
              "\[IndentingNewLine]", " ", 
              RowBox[{
                RowBox[{"eigenvalues", 
                  FormBox[
                    StyleBox[\(\[Lambda]\_n\),
                      FontFamily->"Times"],
                    "TraditionalForm"], "and", 
                  FormBox[
                    StyleBox[\(\[Lambda]\_m\),
                      FontFamily->"Times"],
                    "TraditionalForm"], "are", " ", "not", 
                  " ", \(equal . \ Furthermore\)}], ",", 
                RowBox[{"all", " ", "the", " ", "eigenvalues", " ", "of", 
                  StyleBox[
                    FormBox[
                      OverscriptBox[
                        StyleBox["L",
                          FontFamily->"Times"], "^"],
                      "TraditionalForm"],
                    FontFamily->"Times"], "are", 
                  " ", \(\(real\)\(.\)\)}]}]}]}
          },
        ColumnAlignments->{Left}],
      FontFamily->"Times"]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:15"],

Cell[TextData[{
  "\t The proof is as follows. Consider the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\[Psi]\_m, \ \(L\&^\) \[Psi]\_n)\)\(.\)\)\)]],
  " According to Eq ",
  ButtonBox["(4.1.18)",
    ButtonData:>"(4.1.18)",
    ButtonStyle->"Hyperlink"],
  " we can write this quantity  as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, \ \(L\&^\) \[Psi]\_n)\) = \
\(\((\[Psi]\_m, \(\[Lambda]\_n\) \[Psi]\_n)\) = \(\[Lambda]\_n\)(\[Psi]\_m, \
\[Psi]\_n)\)\)]],
  ", "
}], "NE2",
  CellTags->"(4.1.19)"],

Cell[TextData[{
  "where the last step follows from linearity of the inner product, Eq. ",
  ButtonBox["(4.1.4)",
    ButtonData:>"(4.1.4)",
    ButtonStyle->"Hyperlink"],
  ". However, according to the Hermitian property, Eq. ",
  ButtonBox["(4.1.12)",
    ButtonData:>"(4.1.12)",
    ButtonStyle->"Hyperlink"],
  ", we can also write this quantity as "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, \ \(L\&^\) \[Psi]\_n)\) = \
\(\(\((\[Psi]\_n, \ \(L\&^\) \[Psi]\_m)\)\^*\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "If we then apply Eq. ",
  ButtonBox["(4.1.18)",
    ButtonData:>"(4.1.18)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, \ \(L\&^\) \[Psi]\_n)\) = \
\(\(\((\[Psi]\_n, \ \(\[Lambda]\_m\) \[Psi]\_m)\)\^*\) = \(\(\(\(\[Lambda]\_m\
\^*\)(\[Psi]\_n, \[Psi]\_m)\)\^*\) = \(\[Lambda]\_m\^*\)(\[Psi]\_m, \
\[Psi]\_n)\)\)\)]],
  ","
}], "NE2",
  CellTags->"(4.1.20)"],

Cell[TextData[{
  "where in the last step we used Eq. ",
  ButtonBox["(4.1.2)",
    ButtonData:>"(4.1.2)",
    ButtonStyle->"Hyperlink"],
  " and in the next to last step we used Eq. ",
  ButtonBox["(4.1.4)",
    ButtonData:>"(4.1.4)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFinally, equating Eq. ",
  ButtonBox["(4.1.19)",
    ButtonData:>"(4.1.19)",
    ButtonStyle->"Hyperlink"],
  " to Eq. ",
  ButtonBox["(4.1.20)",
    ButtonData:>"(4.1.20)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Lambda]\_n - \(\[Lambda]\_m\^*\))\) \
\((\[Psi]\_m, \[Psi]\_n)\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(4.1.21)"],

Cell[TextData[{
  "Now, if ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  ", then Eq. ",
  ButtonBox["(4.1.21)",
    ButtonData:>"(4.1.21)",
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Lambda]\_n - \(\[Lambda]\_n\^*\))\) \
\((\[Psi]\_n, \[Psi]\_n)\) = 0\)]],
  ". But ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n, \[Psi]\_n)\) > 0\)]],
  " for nontrivial ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ", so we find that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n - \(\[Lambda]\_n\^*\) = 0\)]],
  ". Therefore, eigenvalues of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " must be real numbers."
}], "Text"],

Cell[TextData[{
  "\tSince the eigenvalues are real, we can drop the complex conjugation from \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_m\)]],
  " in Eq. ",
  ButtonBox["(4.1.21)",
    ButtonData:>"(4.1.21)",
    ButtonStyle->"Hyperlink"],
  ". Then we have ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Lambda]\_n - \[Lambda]\_m)\) \((\[Psi]\_m, \
\[Psi]\_n)\) = 0. \)]],
  " Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, \[Psi]\_n)\) = 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_m \[NotEqual] \ \[Lambda]\_n\)]],
  ", proving that eigenfunctions associated with distinct eigenvalues are \
orthogonal."
}], "Text"],

Cell[TextData[{
  "\tWe have finally solved the mystery  encountered in the PDE problems of \
Chapter ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  ", of why the eigenmodes in these problems always formed orthogonal sets. \
We can now see that this occurred because in each case, the operators were of \
Sturm-Liouville form, so that the operators were Hermitian with respect  to \
the inner product of Eq. ",
  ButtonBox["(4.1.6)",
    ButtonData:>"(4.1.6)",
    ButtonStyle->"Hyperlink"],
  ", and with respect to functions that satisfied the homogeneous boundary \
conditions of the associated eigenvalue problem.  In fact, Hermitian \
operators, and Sturm-Liouville operators in particular,  dominate \
mathematical physics (especially at the introductory level.)."
}], "Text"],

Cell[TextData[{
  "\tFor example, the set of Bessel eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`{\(J\_m\)(\(j\_\(m, \ n\)\) r/a)}\)]],
  ", encountered in Sec. ",
  ButtonBox["3.2.5",
    ButtonData:>{"Chapter3.nb", "c:39"},
    ButtonStyle->"Hyperlink"],
  ", satisfied the Sturm-Liouville problem on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < a\)]],
  " given by Eq. ",
  ButtonBox["(3.2.46)",
    ButtonData:>{"Chapter3.nb", "(3.2.46)"},
    ButtonStyle->"Hyperlink"],
  ", "
}], "Text",
  CellTags->"i:34"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\t\t\)\(\(1\/r\) \(\(\(\[PartialD]\)\(\ \)\)\/\
\[PartialD]r\) \((r \[PartialD]\ \[Psi]\_n\/\[PartialD]r)\) - \(m\^2\/r\^2\) \
\[Psi]\_n + \ \[Kappa]\ \[Psi]\_n\  = \ 0\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  " with Dirichlet boundary conditions at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ". At ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " the eigenfunctions need only be finite. According to Eq. ",
  ButtonBox["(4.1.14)",
    ButtonData:>"(4.1.14)",
    ButtonStyle->"Hyperlink"],
  ", these eigenmodes must form an orthogonal set with respect to the inner \
product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_0\%a\(\( f\^*\)(r)\) \(g(r)\)\ \(p(
              r)\) \[DifferentialD]r\)]],
  ",  with ",
  Cell[BoxData[
      \(TraditionalForm\`p(r) = r\)]],
  ". This corresponds to our previous result, Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>{"Chapter3.nb", "(3.2.55)"},
    ButtonStyle->"Hyperlink"],
  ", that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a\(\( J\_m\)(\(j\_\(m, n\&_\)\) 
                r/a)\) \(\(J\_m\)(\(j\_\(m, n\)\) r/a)\) 
            r \[DifferentialD]r = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ n\&_\)]],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Completeness", "Section",
  CellTags->"c:11"],

Cell[TextData[{
  "\tThe fact that the eigenmodes of a Hermitian operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " form an orthogonal set means that they can be used in the generalized \
Fourier series representation of a function, Eq. ",
  ButtonBox["(4.1.9)",
    ButtonData:>"(4.1.9)",
    ButtonStyle->"Hyperlink"],
  ". However, there is still the question as to whether these eigenmodes are \
complete.  The answer to this question is that eigenfunctions of a Hermitian \
operator ",
  StyleBox["do",
    FontSlant->"Italic"],
  " form a complete set, under very general conditions.  The proof can be \
found in ",
  ButtonBox["Courant and Hilbert (1953, Chapters 2 and 4)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:16"],

Cell["\<\
\tTo be precise, the following completeness theorem holds for \
eigenmodes of a Hermitian operator: \
\>", "Text"],

Cell[TextData[Cell[BoxData[
    StyleBox[GridBox[{
          {
            StyleBox[\(Theorem\ 4  .2\),
              FontWeight->"Bold"]},
          {
            RowBox[{
              RowBox[{
                RowBox[{"Given", " ", "any", " ", "function", 
                  FormBox[
                    StyleBox[\(f(x)\),
                      FontFamily->"Times"],
                    "TraditionalForm"]}], 
                ",", \(described\ by\ a\ generalized\ Fourier\ series\ of\ \
eigenmodes\ of\ a\ Hermitian\ operator\), ",", " ", \(the\ error\)}], " ", 
              "\[IndentingNewLine]", 
              
              RowBox[{\(between\ the\ function\ and\ the\ generalized\ \
Fourier\ series\), ",", 
                FormBox[
                  
                  StyleBox[\(\(E\_M\)(x)\  = \ 
                      f(x) - \[Sum]\+\(n = 0\)\%M\( c\_n\) \(\(\[Psi]\_n\)(
                              x)\)\),
                    FontFamily->"Times"],
                  "TraditionalForm"], ",", " ", 
                RowBox[{"approaches", " ", "zero", " ", "as", 
                  FormBox[
                    StyleBox[\(M \[Rule] \ \[Infinity]\),
                      FontFamily->"Times"],
                    "TraditionalForm"]}]}], 
              "\[IndentingNewLine]", \(in\ the\ following\ average\ \(\(sense\
\)\(:\)\)\)}]}
          },
        ColumnAlignments->{Left}],
      FontFamily->"Times"]]]], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(M \[Rule] \ \[Infinity]\)\((\(E\_M\)(
              x), \(E\_M\)(x))\) = 0\)]],
  "."
}], "NE2",
  CellTags->"(4.1.22)"],

Cell[TextData[{
  "This is called ",
  StyleBox["convergence in the mean",
    FontSlant->"Italic"],
  ". If we write out the inner product using Eq. ",
  ButtonBox["(4.1.6)",
    ButtonData:>"(4.1.6)",
    ButtonStyle->"Hyperlink"],
  ", we see that the error is averaged over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(,\)\(\ \)\)\)]],
  "weighted by the function ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  ":"
}], "Text",
  CellTags->"i:2"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(M \[Rule] \ \[Infinity]\)\[Integral]\_a\%b | \
\(E\_M\)(x)\( | \^2\)\(p(x)\) \[DifferentialD]x = 0\)]],
  "."
}], "NE2",
  CellTags->"(4.1.23)"],

Cell[TextData[{
  "Convergence in the mean is less restrictive than the uniform convergence \
discussed previously for Fourier series of functions that satisfy the \
conditions of Theorem 2.1. For example, Eq. ",
  ButtonBox["(4.1.23)",
    ButtonData:>"(4.1.23)",
    ButtonStyle->"Hyperlink"],
  " still holds for series that exhibit the Gibbs phenomenon. Also, for \
series using weight functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(p(x)\)\(\ \)\)\)]],
  "that are small over certain ranges of the interval [such as for the \
Laguerre and Hermite polynomials at large ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "; see Exercises (5)(a) and (b)], there can be large differences between \
the series and ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " that are not revealed by Eq. ",
  ButtonBox["(4.1.23)",
    ButtonData:>"(4.1.23)",
    ButtonStyle->"Hyperlink"],
  ". Nevertheless, this sort of convergence is usually all that is needed in \
applications."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1.4 Eigenmodes of Non-Hermitian Operators", "Subsubtitle",
  CellTags->{"i:17", "c:12"}],

Cell[TextData[{
  "\tFrom time to time, one will run into a problem where a linear operator \
is not Hermitian with respect to some given inner product and/or  set of \
functions. One example that we already mentioned is the operator ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\&^\)\(\ \)\(=\)\(\ \)\(\[PartialD]\^3\/\
\[PartialD]x\^3\)\(\ \)\)\)]],
  " on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  ". Eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  "of this operator do not form an orthogonal set with respect to the inner \
product defined by  ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b\( f\^*\)\ g\ \(p(
              x)\) \[DifferentialD]x\)]],
  ", for any ",
  Cell[BoxData[
      \(TraditionalForm\`p(x)\)]],
  ". Nevertheless, we may want to expand some function in terms of these \
eigenmodes.  For instance, we may  need to solve a PDE involving ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ",",
  " such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z/\[PartialD]t = \[PartialD]\^3 
            z/\[PartialD]x\^3\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFortunately, we can generalize our Fourier expansion techniques to allow \
series expansions in terms of eigenfunctions of non-Hermitian operators. To \
make the expansion work, we must first introduce the notion of the ",
  StyleBox["adjoint",
    FontSlant->"Italic"],
  " of an operator. "
}], "Text"],

Cell[TextData[{
  "\tThe adjoint of an operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "  is another operator ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(L\&^\^\[Dagger]\),
            "TraditionalForm"]}], TraditionalForm]]],
  " that is defined by the following equation:"
}], "Text",
  CellTags->"i:18"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\((f, \ L\&^\ g)\) = \((\(L\&^\^\[Dagger]\) f, 
          g)\)\)]]
}], "NE2",
  CellTags->"(4.1.24)"],

Cell[TextData[{
  "for some given inner product, where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " are any two functions from some given set of functions. For instance, for \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\&^\)\(\ \)\(=\)\(\ \)\(\[PartialD]\^3\/\
\[PartialD]x\^3\)\(\ \)\)\)]],
  ", the adjoint with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b\( f\^*\)\ g \[DifferentialD]x\)]],
  ",",
  " and with respect to functions that satisfy homogeneous boundary \
conditions of various types, is simply  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\[Dagger] = \(\(-\ \(\[PartialD]\^3\/\
\[PartialD]x\^3\)\)\(\ \)\)\)]],
  ". This follows from three applications of integration by parts to Eq. ",
  ButtonBox["(4.1.24)",
    ButtonData:>"(4.1.24)",
    ButtonStyle->"Hyperlink"],
  ", dropping the boundary terms because of the homogeneous boundary \
conditions."
}], "Text"],

Cell[TextData[{
  "\tComparing Eq. ",
  ButtonBox["(4.1.24)",
    ButtonData:>"(4.1.24)",
    ButtonStyle->"Hyperlink"],
  " to Eq. ",
  ButtonBox["(4.1.12)",
    ButtonData:>"(4.1.12)",
    ButtonStyle->"Hyperlink"],
  ", we see that a Hermitian operator satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\[Dagger] = \ L\&^\)]],
  ": a Hermitian operator is its own adjoint. For this reason, Hermitian \
operators are also referred to as ",
  StyleBox["self-adjoint",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:19"],

Cell[TextData[{
  "\tWe will expand a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " in terms of the eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\)]],
  " of the non-Hermitian operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", writing"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \[Sum]\+n\( c\_n\) \(\(\[Psi]\_n\)(x)\)\)]],
  ". "
}], "NE2",
  CellTags->"(4.1.25)"],

Cell["These eigenmodes satisfy the usual equation,", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Psi]\_n = \(\[Lambda]\_n\) \[Psi]\_n\)]],
  "."
}], "NE2",
  CellTags->"(4.1.26)"],

Cell[TextData[{
  "However, as we have already stated, ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_m, \[Psi]\_n)\)\  \[NotEqual] \ 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ n\)]],
  ", so our previous technique for finding the ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  "'s does not work. What to do?"
}], "Text"],

Cell[TextData[{
  "\t Consider the eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\^\[Dagger]\)(x)\)]],
  " of the ",
  StyleBox["adjoint",
    FontSlant->"Italic"],
  " operator. These eigenmodes satisfy the equation"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\[Dagger]\) \[Psi]\_n\^\[Dagger] = \(\
\[Lambda]\_n\^\[Dagger]\) \[Psi]\_n\^\[Dagger]\)]],
  ", "
}], "NE2",
  CellTags->"(4.1.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\^\[Dagger]\)]],
  " is the associated eigenvalue. One can then prove the following : "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Lambda]\_n\^\[Dagger] = \(\[Lambda]\_n\^*\)\)]]], \
"NE2",
  CellTags->"(4.1.28)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n\^\[Dagger], \[Psi]\_m)\) = 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Lambda]\_n\^*\)\  \[NotEqual] \ \
\[Lambda]\_m\)]],
  " ."
}], "NE2",
  CellTags->{"i:20", "(4.1.29)"}],

Cell["\<\
The proof is almost identical to that given for Theorem 4.1, and is \
left to the exercises. \
\>", "Text"],

Cell[TextData[{
  "\tSince the adjoint eigenmodes form an orthogonal set with respect to the \
set ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_n}\)]],
  ", we now take an inner product of Eq. ",
  ButtonBox["(4.1.25)",
    ButtonData:>"(4.1.25)",
    ButtonStyle->"Hyperlink"],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\^\[Dagger]\)]],
  ". This kills all terms in the sum except for the one involving ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  ", and yields the result"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\_n = \((\[Psi]\_n\^\[Dagger], f)\)\/\((\[Psi]\_n\^\
\[Dagger], \[Psi]\_n)\)\)]],
  " ."
}], "NE2",
  CellTags->"(4.1.30)"],

Cell[TextData[{
  "However, there is no guarantee that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n\^\[Dagger], \[Psi]\_n)\)\)]],
  " is nonzero, because ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi]\_n\^\[Dagger]\)\(\ \)\(\[NotEqual]\)\(\
\[Psi]\_n\)\(\ \)\)\)]],
  " in general. In fact, if this inner product vanishes for some value(s) of \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", then  Eq. ",
  ButtonBox["(4.1.30)",
    ButtonData:>"(4.1.30)",
    ButtonStyle->"Hyperlink"],
  " implies that an expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " in terms of eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is not possible,  unless ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n\^\[Dagger], f)\)\)]],
  " also happens to equal zero for these ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  " values."
}], "Text"],

Cell[TextData[{
  "\tAlso, even if ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n\^\[Dagger], \[Psi]\_n)\)\)]],
  " is nonzero for all ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", there is generally no guarantee that the eigenmodes form a complete set, \
as there is with Hermitian operators. Nevertheless, this kind of eigenmode \
expansion can still be useful for those rare cases where non-Hermitian \
operators arise in a problem."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 4.1", "Subsubtitle",
  CellTags->"c:13"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Perform Gram-Schmidt orthogonalization by hand for the first three \
orthogonal polynomials extracted from the set {",
  Cell[BoxData[
      \(TraditionalForm\`x\^n\)]],
  "}, ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ 0\)]],
  ", for the given inner products:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_0\%\[Infinity]\( f\^*\) 
            g\ \(\[ExponentialE]\^\(-x\)\) \[DifferentialD]x\)]],
  "   (these will be proportional to ",
  ButtonBox["Laguerre",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laguerre.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " polynomials)."
}], "Text",
  CellTags->"i:22"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f\^*\) 
            g\ \(\[ExponentialE]\^\(-x\^2\)\) \[DifferentialD]x\)]],
  " (these will be proportional to ",
  ButtonBox["Hermite",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Hermite.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " polynomials)."
}], "Text",
  CellTags->"i:26"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-1\)\%1\( f\^*\) 
            g \[DifferentialD]x\/\((1 - x\^2)\)\^\(1/2\)\)]],
  " (these will be proportional to ",
  ButtonBox["Chebyshev",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Chebyshev.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " polynomials of the first kind)."
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_\(-1\)\%1\( 
                f\^*\) \(\(g(1 - x\^2)\)\^\(1/2\)\) \[DifferentialD]x\)]],
  " (these will be proportional to Chebyshev polynomials of the second \
kind)."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Perform Gram-Schmidt orthogonalization by hand for the first three \
orthogonal functions from the set ",
  Cell[BoxData[
      \(TraditionalForm\`{\[ExponentialE]\^\(\(-n\)\ x\)}\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... \)]],
  ". Take for the inner product  ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_0\%\[Infinity] \[ExponentialE]\^\(-x\)\ \(f\
\^*\) g\ \[DifferentialD]x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Create a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " module called gschmidt[M] that automatically performs Gram-Schmidt \
orthogonalization for the first ",
  StyleBox["M",
    FontSlant->"Italic"],
  " orthogonal functions taken from a given set of pre-defined functions ",
  Cell[BoxData[
      \(TraditionalForm\`v(n, x)\)]],
  " and for a given predefined inner product. Run this ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " module for the orthogonal functions of Exercises (1) and (2), determining \
the first six orthogonal functions in each set. "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Find a generalized Fourier series representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^2\) \[ExponentialE]\^\(\(-2\) x\)\)]],
  " using the orthogonal functions derived in Exercise (3). Plot the result \
along with the exact function keeping ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2, 4, 6\)]],
  " terms. "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  "  Find a generalized Fourier series representation for the following \
functions using the given orthogonal polynomials. Plot the resulting series \
for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 5, \ 10, \ and\ 15\)]],
  ", along with the functions. In each case, evaluate Eq. ",
  ButtonBox["(4.1.23)",
    ButtonData:>"(4.1.23)",
    ButtonStyle->"Hyperlink"],
  " for the different ",
  Cell[BoxData[
      \(TraditionalForm\`M\ values\)]],
  " to see whether convergence in the mean is being achieved."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ 
        x/\((1 + x\^2)\)\ on\ 0 < x < \[Infinity]\)]],
  ", using Laguerre polynomials. Plot on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 5\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(
          x)\  = \ \ \(sin\ x\)\/x\ \ on\  - \[Infinity] < 
          x < \[Infinity]\)\(,\)\)\)]],
  " using Hermite polynomials. Plot on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-8\) < x < 8\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\  = \ 
        Sin\ \[Pi]\ t\ on\  - 1 \[LessEqual] \ t \[LessEqual] \ 
          1\)\(,\)\)\)]],
  " using Legendre polynomials."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\  = \ 
        t\ \((1 - t)\)\ /\((2 - t)\)\ \ on\  - 1 \[LessEqual] \ 
          t \[LessEqual] \ 1\)\(,\)\(\ \)\)\)]],
  " using Chebyshev polynomials of the first kind."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(
          t)\  = \(\[ExponentialE]\^\(-t\)\) \@\(t + 1\)\ \ \ on\  - 
            1 \[LessEqual] \ t \[LessEqual] \ 1\)\(,\)\(\ \)\)\)]],
  " using Chebyshev polynomials of the second  kind."
}], "Text"],

Cell[TextData[{
  "(Hint 1: These polynomials are already ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  intrinsic functions. You can find their definition and syntax in the \
help browser. Hint 2: The series representation may not converge well in \
every case.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)(a)",
    FontWeight->"Bold"],
  " Prove that the generalized Fourier expansion of a polynomial of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " in terms of orthogonal polynomials is a finite series, involving only \
orthogonal polynomials of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " and lower."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Expand ",
  Cell[BoxData[
      \(TraditionalForm\`x\^4\)]],
  " in terms of Hermite polynomials"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Expand ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2\)]],
  " in terms of Legendre polynomials"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Expand ",
  Cell[BoxData[
      \(TraditionalForm\`x\^6\)]],
  " in terms of Chebyshev polynomials of the second kind."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Prove that the Sturm-Liouville operator  ",
  ButtonBox["(4.1.13)",
    ButtonData:>"(4.1.13)",
    ButtonStyle->"Hyperlink"],
  " is Hermitian with respect to the inner product given by Eq. ",
  ButtonBox["(4.1.14)",
    ButtonData:>"(4.1.14)",
    ButtonStyle->"Hyperlink"],
  " and with respect to functions that satisfy mixed boundary conditions."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Find an inner product for which the following operators are Hermitian \
with respect to functions that satisfy the given conditions:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^2\/\[DifferentialD]x\^2 - 
          2  x \[DifferentialD]\/\[DifferentialD]x\)]],
  ", for functions on ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-\[Infinity]\), \[Infinity]]\)\)]],
  " that go to \[Infinity] more slowly than ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(x\^2/2\)\)]],
  "as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \ \[Infinity]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = 
        x \[DifferentialD]\^2\/\[DifferentialD]x\^2 + \((1 - 
                x)\) \[DifferentialD]\/\[DifferentialD]x\)]],
  ", for functions on ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, \[Infinity]]\)\)]],
  " that go to \[Infinity] more slowly than ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(x/2\)\)]],
  " and that are finite at the origin"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \ \(\[DifferentialD]\/\[DifferentialD]x\) \
\((1 - x\^2)\) \[DifferentialD]\/\[DifferentialD]x\)]],
  ", for functions on ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  " that are finite at the end points."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^2\/\[DifferentialD]x\^2 + \
\[DifferentialD]\/\[DifferentialD]x + x\^2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-2\), 2]\)\)]],
  ", for functions that are zero at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]2\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(L\&^ = \[DifferentialD]\^4\/\
\[DifferentialD]x\^4 + \[DifferentialD]\^2\/\[DifferentialD]x\^2 + 1\)\)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([0, 3]\)\(,\)\)\)]],
  " for functions that satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\[DoublePrime] = 0\)]],
  " at the end points."
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^2\/\[DifferentialD]x\^2 + \ \
\(h(x)\) \[DifferentialD]\/\[DifferentialD]x\)]],
  ", on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\([\(-1\), 1]\)\(\ \)\(,\)\)\)]],
  "for functions that satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`f = 0\)]],
  " at the end points,  and where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " is the Heaviside step function."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Show by substitution,",
  StyleBox[" ",
    FontWeight->"Bold"],
  "using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  " that the first five Hermite polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`\(H\_n\)(x)\)]],
  " are eigenfunctions of the operator  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " given in Exercise (8)(a), with eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \(-2\) n\)]],
  "."
}], "Text",
  CellTags->"i:25"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Show by substitution, using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  "  that the first five Laguerre polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_n\)(x)\)]],
  " are eigenfunctions of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " given  in Exercise (8)(b), with eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \(-n\)\)]],
  "."
}], "Text",
  CellTags->"i:23"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " Show by substitution, using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  "  that the first five Legendre polynomials",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\(P\_n\)(x)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " are eigenfunctions of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " given  in Exercise (8)(c), with eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \(-\(n(n + 1)\)\)\)]],
  "."
}], "Text",
  CellTags->"i:24"],

Cell[TextData[{
  "(12) Prove that the Sturm-Liouville operator ",
  ButtonBox["(4.1.13)",
    ButtonData:>"(4.1.13)",
    ButtonStyle->"Hyperlink"],
  " is Hermitian with respect to the inner product given by Eq. ",
  ButtonBox["(4.1.14)",
    ButtonData:>"(4.1.14)",
    ButtonStyle->"Hyperlink"],
  " and with respect to functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " defined on ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ x \[LessEqual] \ b\)]],
  "  that satisfy ",
  "periodic boundary conditions",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = f(x\  + b - a)\)]],
  ",  ",
  "provided that",
  StyleBox[" ",
    FontSlant->"Italic"],
  "the function ",
  Cell[BoxData[
      \(TraditionalForm\`r(x)\)]],
  " satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`r(a) = r(b)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " Find the eigenfunctions and eigenvalues for the following operators. If \
the operators are Hermitian with respect to some inner product, show directly \
that the eigenfunctions are orthogonal with respect to that inner product."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^2\/\[DifferentialD]x\^2 + \
\[DifferentialD]\/\[DifferentialD]x + 1\)]],
  " with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[Prime]\)(\(-1\)) = \
\(\(\[Phi]\^\[Prime]\)(1) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " and boundary conditions given in Exercise (8)(e)."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " and boundary conditions given in Exercise (8)(f). (Hint: Match solutions \
for",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x < 0\)\)\)]],
  " to those for",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(x > 0\)\)\)]],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[DifferentialD]\^2\/\[DifferentialD]x\^2 - 
          1\)]],
  " with periodic boundary conditions on [0,1]. [See Exercise (12).]"
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " Use the eigenfunctions obtained from the following operators in order to \
create a generalized Fourier series expansion of the following functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " on the given interval. In each case, plot the series and calculate the \
average error ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(E\_M\)(x), \(E\_M\)(x))\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 5, 10, 15, 20\)]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`f(x) = x\ sin\ 5  x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  ", using the eigenfunctions from Exercise (13)(a)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \(\[ExponentialE]\^\(\(-x\)/3\)\) sin\ x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 3]\)\)]],
  ", using the eigenfunctions from the operator of Exercise (8)(e)."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = \ x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\([\(-1\), 1]\)\)]],
  ", using the eigenfunctions of the operator of Exercise (8)(f)."
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A quantum particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is confined in a 1-dimensional box with potential"
}], "Text",
  CellTags->"i:33"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V(x)\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(0, \ \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\), \)},
                    {\(\[Infinity], \ \
\(\(|\)\(x\)\(|\)\(\(>\)\(\(a\)\(.\)\)\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)], " "}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "The energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " of the particle can be found by solving the time-independent ",
  StyleBox["Schr\[ODoubleDot]dinger",
    FontSlant->"Italic"],
  StyleBox[" equation",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:28"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(H\&^\ \[Psi]\_n = \(E\_n\) \
\[Psi]\_n\)\(,\)\)\)]]], "NE2",
  CellTags->"(4.1.31)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H\&^\)\(\ \)\)\)]],
  " is the Hamiltonian operator ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = \(\(\(-\(\[HBar]\^2\/\(2  
                    m\)\)\)\ \[DifferentialD]\^2\/\[DifferentialD]x\^2\)\(+\)\
\(V(x)\)\(\ \)\)\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[HBar]", "=", 
          RowBox[{"1.055", "\[Cross]", 
            FormBox[
              RowBox[{\(10\^\(-34\)\), " ", 
                StyleBox["J",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontSlant->"Plain"], 
                StyleBox["s",
                  FontSlant->"Plain"]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  " is Planck's constant divided by ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ".  For this problem the infinite potential at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]a\)\)]],
  " implies that the wave functions vanish at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]a\)\)]],
  ".  This provides homogeneous boundary conditions for the equation, which \
can be seen to be an eigenvalue problem of Sturm-Liouville form. The \
eigenvalues  are the quantum energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " and the eigenfunctions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Psi]\_n\)(x)\)\(\ \)\)\)]],
  "are the  quantum wave functions corresponding to each energy level.   \
Solve for the energy levels and energy eigenfunctions  for this potential. \
Plot the three eigenfunctions with the lowest energies.  (See problem 13 of \
Sec. ",
  ButtonBox["3.1",
    ButtonData:>{"Chapter3.nb", "c:23"},
    ButtonStyle->"Hyperlink"],
  ", which solves an inital value problem using these eigenmodes)."
}], "Text",
  CellTags->"i:106"],

Cell[TextData[{
  StyleBox["(16)(a)",
    FontWeight->"Bold"],
  " A quantum particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is confined in a one-dimensional harmonic potential, "
}], "Text",
  CellTags->"i:29"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ \(1\/2\) m\ \(\[Omega]\_o\%2\) x\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Now the boundary conditions are that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n \[Rule] \ 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \(\[PlusMinus]\[Infinity]\)\)]],
  ".  Show that the energy levels are given by ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \(\[HBar]\[Omega]\_o\)(n + 1/2)\)]],
  ", and that the eigenfunctions are given by  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\[ExponentialE]\^\(\(-x\^2\)/2  a\^2\)\) \(\(H\_n\)(
            x/a)\)\)]],
  ","
}], "NE2",
  CellTags->"(4.1.32)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`H\_n\)]],
  " is a Hermite polynomial and ",
  Cell[BoxData[
      \(TraditionalForm\`a = \@\(\[HBar]/m\ \[Omega]\_o\)\)]],
  "is the spatial scale of the eigenfunctions. [Hint: Substitute the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          x)\  = \ \(\[ExponentialE]\^\(\(-x\^2\)/2  a\^2\)\) \(\(f\_n\)(
            x/a)\)\)]],
  " into the eigenmode equation ",
  ButtonBox["(4.1.31)",
    ButtonData:>"(4.1.31)",
    ButtonStyle->"Hyperlink"],
  " and show that ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  " satisfies the Hermite polynomial ODE; see Exercises (8)(a) and (9). Plot \
the three eigenfunctions with lowest energies, ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, and\ 2\)]],
  "."
}], "Text",
  CellTags->"i:30"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the eigenfunctions found in part (a) to solve the following initial \
value problem: ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi](x, 
          0) = \[ExponentialE]\^\(\(-2\) \((x - 1)\)\^2\)\)]],
  ". Take ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar] = \(m = \(\[Omega]\_o = 1\)\)\)]],
  " and animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[CapitalPsi](x, t)\)\( | \^2\)\)\)]],
  " using a table of plots for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4  \[Pi]\)]],
  ".  [Hint: Recall that the wavefunction ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi]\)]],
  " satisfies the time-dependent Schr\[ODoubleDot]dinger equation ",
  ButtonBox["(3.1.81)",
    ButtonData:>{"Chapter3.nb", "(3.1.81)"},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " A quantum particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " moves in a one-dimensional periodic harmonic potential with period ",
  Cell[BoxData[
      \(TraditionalForm\`2  a\)]],
  ",  given by the following periodic \[Delta]-function:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\  = \ 
        a\ \(V\_o\) \(\[Delta](
            x)\), \ \(\(|\)\(x\)\(|\)\(\(<\)\(a\)\)\), \[IndentingNewLine]V(
          x + 2  a)\  = \(\(V(x)\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Find the energy levels of a particle in this periodic potential (a model \
for the interaction of an electron with a periodic lattice of ions). Show \
that the modes break into two classes: those that are even in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", and those that are odd. For the odd modes, show that  the energy levels  \
are given by ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \(\[HBar]\^2\) k\_n\%2/2\ m\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_n = n\ \[Pi]/a\)]],
  " is the wavenumber, and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is a positive integer. For the even modes, show that the wavenumbers \
satisfy the transcendental equation  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(k\_n\) a\ tan\ \(k\_n\) a\  = \ 
        m\ V\ a\^2/\[HBar]\^2\)\)\)]],
  ", where the energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " is still related to the by ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \(\[HBar]\^2\) k\_n\%2/2\ m\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`m\ V\ a\^2/\[HBar]\^2 = 1\)]],
  ", find the smallest three values of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_n\) a\)]],
  " numerically and plot the corresponding eigenmodes on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-a\) < x < a\)]],
  "."
}], "Text",
  CellTags->"i:32"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " A quantum particle is confined to ",
  Cell[BoxData[
      \(TraditionalForm\`x > 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is now the vertical direction. The particle moves under the influence of \
a gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x) = m\ g\ x\)]],
  ". Find an equation for the energy levels (which must be solved \
numerically) and find the corresponding energy eigenfunctions. Plot the \
lowest three energy eigenfunctions and find numerical values (up to the \
unknown constants) for their energies. Find the mean height of the particle \
above the surface ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " in each of the three energy levels. The mean height is given by "
}], "Text",
  CellTags->"i:31"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]x\[RightAngleBracket]\  = \ \
\[Integral]x\  | \[CapitalPsi]\( | \^2\)\[DifferentialD]x/\[Integral] | \
\[CapitalPsi]\( | \^2\)\[DifferentialD]x\)]],
  "."
}], "Text"],

Cell["\<\
(Hint: The eigenfunctions will be in terms of Airy \
functions.)\
\>", "Text"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  "  Prove Eqs. ",
  ButtonBox["(4.1.28)",
    ButtonData:>"(4.1.28)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.1.29)",
    ButtonData:>"(4.1.29)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " Find the adjoint operator for the given operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ", inner product, and set of functions:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[PartialD]\^2\(\(/\)\(\[PartialD]\(\(x\)\(\ \
\)\)\^2\)\)\)]],
  " with inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b x\ \(f\^*\) g \[DifferentialD]x\)]],
  " and functions that obey ",
  Cell[BoxData[
      \(TraditionalForm\`f(a) = \(f(b) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \(1\/x\) \(\[PartialD]\/\[PartialD]x\) 
          x \[PartialD]\/\[PartialD]x\)]],
  " with inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_0\%b x\^2\ \(f\^*\) g \[DifferentialD]x\)]],
  " and functions that obey ",
  Cell[BoxData[
      \(TraditionalForm\`f(b) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(0)\)\(\ \)\)\)]],
  " finite."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \(p(
              x)\) \[PartialD]\^2\/\[PartialD]x\^2 + \ \(q(
              x)\) \[PartialD]\/\[PartialD]x + r(x)\)]],
  " with inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_a\%b\( f\^*\) g \[DifferentialD]x\)]],
  " and functions that obey ",
  Cell[BoxData[
      \(TraditionalForm\`f(a) = \(f(b) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(21)",
    FontWeight->"Bold"],
  " Find the eigenfunctions and eigenvalues of the adjoint operator  for "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Exercise (20)(a),"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Exercise (20)(b)."
}], "Text"],

Cell[TextData[{
  "Show that these eigenfunctions form an orthogonal set with respect to the \
eigenmodes of  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " and the given inner products."
}], "Text"],

Cell[TextData[{
  StyleBox["(22)",
    FontWeight->"Bold"],
  " Find the first three eigenfunctions and eigenvalues of the operator  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \
\[PartialD]\^3\(\(/\)\(\[PartialD]x\^3\)\)\)]],
  " and it's adjoint with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_0\%1\ \(f\^*\) g \[DifferentialD]x\)]],
  " and with respect to functions that satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`f(0) = \(f(1) = \(\(f\^\[Prime]\)(0) = 0\)\)\)]],
  ". Show directly that the eigenfunctions of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " are orthogonal with respect to the adjoint eigenfunctions. (Hint: For \
both the operator and its adjoint, the eigenvalues satisfy a transcendental \
equation that must be solved numerically.)"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
4.2 Beyond Separation of Variables: The General Solution of the 1D \
Wave and Heat Equations\
\>", "Subtitle",
  CellTags->"c:14"],

Cell["", "Text"],

Cell[TextData[{
  "In this section we will obtain general solutions to the 1D wave and heat \
equations for ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " boundary conditions and ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  "  source functions. The analysis involves two steps: first, the PDE is put \
into ",
  StyleBox["standard form,",
    FontSlant->"Italic"],
  " by transforming away the inhomogeneous boundary conditions, turning them \
into an extra source term in the PDE. The standard-form PDE then has ",
  "homogeneous boundary conditions",
  ", and the solution to this PDE is obtained in terms of a ",
  "generalized Fourier series of eigenmodes."
}], "Text",
  CellTags->"i:37"],

Cell["\<\
\tIn later sections we will  apply the same methods to other linear \
PDEs, including Poisson's equation and the wave and heat equations in more \
than one dimension.\
\>", "Text"],

Cell[CellGroupData[{

Cell["4.2.1 Standard Form for the PDE", "Subsubtitle",
  CellTags->"c:16"],

Cell[TextData[{
  "Let us consider the heat equation in one dimension on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[PartialD]T\/\[PartialD]t = \(1\/\(\(C(
                  x)\)\(\ \)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(\[Kappa](
                  x)\) \[PartialD]T\/\[PartialD]x)\) + S(x, t)\)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.1)"],

Cell[TextData[{
  "subject to general, possibly time-dependent boundary conditions of either \
the Dirichlet, von Neumann, or mixed type as given by Eqs. ",
  ButtonBox["(3.1.45)",
    ButtonData:>{"Chapter3.nb", "(3.1.45)"},
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(3.1.47)",
    ButtonData:>{"Chapter3.nb", "(3.1.47)"},
    ButtonStyle->"Hyperlink"],
  ". In order to solve this PDE, we will first put it into ",
  StyleBox["standard form",
    FontSlant->"Italic"],
  " with ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " boundary conditions. To do so, we write the solution for the temperature \
",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " as"
}], "Text",
  CellTags->"i:118"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(T(x, t)\), " ", "=", " ", 
          RowBox[{\(u(x, t)\), " ", "+", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(4.2.2)"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  " is chosen to satisfy the inhomogeneous boundary conditions, but it is \
otherwise ",
  "arbitrary",
  ". For example, if the boundary conditions are of the Dirichlet form ",
  ButtonBox["(3.1.45)",
    ButtonData:>{"Chapter3.nb", "(3.1.45)"},
    ButtonStyle->"Hyperlink"],
  ", we choose ",
  StyleBox["any function",
    FontSlant->"Italic"],
  " that satisfies"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`u(0, t)\  = \(T\_1\)(t), \[IndentingNewLine]u(L, 
          t)\  = \ \(\(\(T\_2\)(t)\)\(.\)\)\)]]
}], "Text"],

Cell["One choice might be", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, 
          t)\  = \ \(T\_1\)(t)\  + \ \([\(T\_2\)(t) - \(T\_1\)(t)]\) x/L\)]],
  ", "
}], "NE3",
  CellTags->"(4.2.3)"],

Cell[TextData[{
  "but many others can also be used. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, 
          t)\  = \ \(T\_1\)(
            t)\  + \ \([\(T\_2\)(t) - \(T\_1\)(t)]\) \((x/L)\)\^n\)]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  " also works.  However, we will soon see that it is best to choose a \
function with the ",
  "slowest possible spatial variation",
  ", and especially try to avoid spatial discontinuities if at all possible. \
"
}], "Text"],

Cell[TextData[{
  "\tIf, on the other hand, the boundary conditions are of the von Neumann \
form ",
  ButtonBox["(3.1.46)",
    ButtonData:>{"Chapter3.nb", "(3.1.46)"},
    ButtonStyle->"Hyperlink"],
  ", we choose some function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  " that satisfies"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]u\/\[PartialD]x\) \((0, 
            t)\)\  = \ \(-\(\(\(\[CapitalGamma]\_\(x\ 1\)\)(
                t)\)\/\[Kappa]\)\), \[IndentingNewLine]\(\[PartialD]u\/\
\[PartialD]x\) \((L, 
            t)\)\  = \ \(-\(\(\(\(\[CapitalGamma]\_\(x\ 2\)\)(
                  t)\)\/\[Kappa]\)\(.\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "Similarly, for mixed boundary conditions ",
  ButtonBox["(3.1.47)",
    ButtonData:>{"Chapter3.nb", "(3.1.47)"},
    ButtonStyle->"Hyperlink"],
  ", we choose a function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " that satisfies"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] \(\[PartialD]u\/\[PartialD]x\) \((0, t)\) = 
        a\ \((u(0, t) - \ \(T\_1\)(
                t))\), \[IndentingNewLine]\[Kappa]\ \(\[PartialD]u\/\
\[PartialD]x\) \((L, t)\) = \(-\(\(b(u(L, t) - \ \(T\_2\)(t))\)\(.\)\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\tThe remainder, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ", then satisfies ",
  StyleBox["homogeneous ",
    FontSlant->"Italic"],
  "boundary conditions that are either Dirichlet,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(0, t\), ")"}], "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(L, t\), ")"}], "=", 
            "0"}]}], ","}], TraditionalForm]]]], "NE3",
  CellTags->"(4.2.4)"],

Cell["von Neumann, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[
              RowBox[{"\[PartialD]", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["T",
                      FontSlant->"Italic"]}]]}], \(\[PartialD]x\)], \((0, 
              t)\)}], "=", 
          RowBox[{
            RowBox[{
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["T",
                        FontSlant->"Italic"]}]]}], \(\[PartialD]x\)], \((L, 
                t)\)}], "=", "0"}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(4.2.5)"],

Cell["or mixed,", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"\[Kappa]", 
            FractionBox[
              RowBox[{"\[PartialD]", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["T",
                      FontSlant->"Italic"]}]]}], \(\[PartialD]x\)], \((0, 
              t)\)}], "-", 
          RowBox[{"a", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(0, t\), ")"}]}]}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"\[Kappa]", 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["T",
                        FontSlant->"Italic"]}]]}], \(\[PartialD]x\)], \((L, 
                t)\)}], "+", 
            RowBox[{"b", " ", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["T",
                      FontSlant->"Italic"]}]], "(", \(L, t\), ")"}]}]}], "=", 
          "0."}]}], TraditionalForm]]]], "NE3",
  CellTags->"(4.2.6)"],

Cell[TextData[{
  "\tThe function ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " satisfies an inhomogeneous heat equation PDE that follows from applying \
Eq. ",
  ButtonBox["(4.2.2)",
    ButtonData:>"(4.2.2)",
    ButtonStyle->"Hyperlink"],
  " to Eq. ",
  ButtonBox["(4.2.1)",
    ButtonData:>"(4.2.1)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[PartialD]", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]]}], \(\[PartialD]t\)], "=", 
          RowBox[{
            RowBox[{\(1\/C\), \(\[PartialD]\/\[PartialD]x\), 
              RowBox[{"(", 
                RowBox[{"\[Kappa]", 
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["T",
                            FontSlant->"Italic"]}]]}], \(\[PartialD]x\)]}], 
                ")"}]}], "+", \(\(S\&_\)(x, t)\)}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(4.2.7)"],

Cell[TextData[{
  " where the new source function ",
  Cell[BoxData[
      \(TraditionalForm\`S\&_\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t) = 
        S(x, t)\  + 
          1\/C\ \(\[PartialD]\/\[PartialD]x\) \((\[Kappa] \[PartialD]u\/\
\[PartialD]x)\) - \ \ \[PartialD]u\/\[PartialD]t\)]],
  "."
}], "NE3",
  CellTags->"(4.2.8)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(4.2.7)",
    ButtonData:>"(4.2.7)",
    ButtonStyle->"Hyperlink"],
  " with ",
  ButtonBox["(4.2.8)",
    ButtonData:>"(4.2.8)",
    ButtonStyle->"Hyperlink"],
  " and homogeneous boundary conditions, is called the ",
  StyleBox["standard form",
    FontSlant->"Italic"],
  " for the PDE. This approach to  the problem bears  some resemblance to the \
method of subtracting out the equilibrium solution, discussed in Sec. ",
  ButtonBox["3.1.2",
    ButtonData:>{"Chapter3.nb", "c:11"},
    ButtonStyle->"Hyperlink"],
  ". Here, however, there need be no equilibrium solution, and we do not \
necessarily remove the source term in the equation by this technique. The \
main point is that we have made the boundary conditions homogeneous, so as to \
allow a generalized Fourier series expansion of eigenmodes to determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:35"],

Cell["\<\
\tThe same technique can be applied to the general wave equation \
with arbitrary boundary conditions and arbitrary time-dependent external \
transverse forces, \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\) + 
          S(x, t)\)]],
  " ."
}], "NE3",
  CellTags->"(4.2.9)"],

Cell["We write", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(x, t)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], " ", "+", 
            " ", \(u(x, t)\)}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(4.2.10)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  " is ",
  "any",
  " function chosen to satisfy the inhomogeneous boundary conditions, and \
where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  "  satisfies"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], "=", 
        RowBox[{
          RowBox[{\(1\/\(\[Rho](x)\)\), 
            RowBox[{\(\[PartialD]\/\[PartialD]x\), "[", 
              RowBox[{\(T(x)\), " ", \(\[PartialD]\/\[PartialD]x\), " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], 
              "]"}]}], "+", " ", \(\(S\&_\)(x, t)\)}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(4.2.11)"],

Cell[TextData[{
  "with homogeneous boundary conditions, and the new source function ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t)\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, t) = 
        S(x, t)\  + \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \(\[PartialD]\/\[PartialD]x\) \(u(x, 
                  t)\))\) - \(\[PartialD]\^2\/\[PartialD]t\^2\) \(u(x, 
              t)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.12)"],

Cell[TextData[{
  "By putting the wave and heat equations into standard form, we have once \
again shown that inhomogeneous boundary conditions are equivalent to a source \
term in the differential equation, just as in the discussion of ODE \
boundary-value problems in Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>{"Chapter2.nb", "c:48"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2.2 Generalized Fourier Series Expansion for the Solution", \
"Subsubtitle",
  CellTags->"c:17"],

Cell[CellGroupData[{

Cell["General Solution for the Wave Equation", "Section",
  CellTags->"c:18"],

Cell[TextData[{
  "The general solutions for the standard form of the wave  or heat equations \
follow the same route, so we will consider only the solution to the wave \
equation. The standard form of this equation, Eq. ",
  ButtonBox["(4.2.11)",
    ButtonData:>"(4.2.11)",
    ButtonStyle->"Hyperlink"],
  ", can be written as"
}], "Text",
  CellTags->"i:38"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], "=", 
          RowBox[{
            RowBox[{\(L\&^\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], "+", 
            " ", \(\(S\&_\)(x, t)\)}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(4.2.13)"],

Cell[TextData[{
  "where the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(L\&^\), 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}], "=", 
          RowBox[{\(1\/\(\[Rho](x)\)\), \(\[PartialD]\/\[PartialD]x\), 
            RowBox[{"(", 
              RowBox[{\(T(x)\), " ", \(\[PartialD]\/\[PartialD]x\), 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}], 
              ")"}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(4.2.14)"],

Cell[TextData[{
  "The eigenmodes ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " of this operator satisfy"
}], "Text",
  CellTags->"i:105"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(\(\[Psi]\_n\)(
            x)\) = \(-\[Omega]\_n\%2\)\ \ \(\(\[Psi]\_n\)(x)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.15)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " is the corresponding eigenfrequency. A generalized Fourier series \
solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], " "}], 
        TraditionalForm]]],
  " can then be constructed from these eigenmodes:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], " ", 
        "=", \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\( c\_n\)(
              t)\) \(\(\(\[Psi]\_n\)(x)\)\(.\)\)\)}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(4.2.16)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) \[GreaterEqual] \ 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T(x) \[GreaterEqual] \ 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is a Sturm-Liouville operator with eigenmodes that are orthogonal with \
respect to the inner product"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\)\  = \ \[Integral]\_0\%L\( \[Rho](x)\) \(\(f\^*\)(x)\) \(g(
              x)\) \[DifferentialD]x\)]],
  "."
}], "NE3",
  CellTags->"(4.2.17)"],

Cell[TextData[{
  "Therefore, the time dependence of the Fourier amplitudes, ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  ", can be easily determined in the usual way. Substitution of Eq. ",
  ButtonBox["(4.2.16)",
    ButtonData:>"(4.2.16)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(4.2.11)",
    ButtonData:>"(4.2.11)",
    ButtonStyle->"Hyperlink"],
  "  yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity]\(\( \[Psi]\_n\)(
              x)\) \(\[DifferentialD]\^2\/\[DifferentialD]t\^2\) \(\(c\_n\)(
              t)\)\  = \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\( c\_n\)(
                  t)\) \(L\&^\) \(\(\[Psi]\_n\)(x)\)\  + \ \(S\&_\)(x, 
              t)\  = \(\(-\(\[Sum]\+\(n = 1\)\%\[Infinity]\(\( c\_n\)(
                    t)\)\ \(\[Omega]\_n\%2\) \(\(\[Psi]\_n\)(
                    x)\)\)\)\(+\)\(\(S\&_\)(x, t)\)\(\ \)\)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.18)"],

Cell[TextData[{
  "where in the last step we have applied Eq. ",
  ButtonBox["(4.2.15)",
    ButtonData:>"(4.2.15)",
    ButtonStyle->"Hyperlink"],
  ". We then extract a single ODE for ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " by taking an inner product of both sides of Eq. ",
  ButtonBox["(4.2.18)",
    ButtonData:>"(4.2.18)",
    ButtonStyle->"Hyperlink"],
  " with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ", The result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]\^2\/\[DifferentialD]t\^2\) \
\(\(c\_n\)(t)\) = \(\(\(-\[Omega]\_n\%2\)\ \ \(\(c\_n\)(
              t)\)\)\(\ \)\(+\)\(\((\[Psi]\_n, \(S\&_\)(x, 
                  t))\)\/\((\[Psi]\_n, \[Psi]\_n)\)\)\(\ \)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.19)"],

Cell["The  general solution to this equation is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(
          t)\  = \ \(A\_n\) cos\ \(\[Omega]\_n\) t + \(B\_n\) 
            sin\ \(\[Omega]\_n\) t + \ \(c\_\(p\ n\)\)(t)\)]],
  ", "
}], "NE3",
  CellTags->"(4.2.20)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(p\ n\)\)(t)\)]],
  " is a particular solution to Eq. ",
  ButtonBox["(4.2.19)",
    ButtonData:>"(4.2.19)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell["\<\
 \tA particular solution can be obtained in terms of the Green's \
function for the equation,\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(g(t)\), "=", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(\((sin\ \(\[Omega]\_\(\(n\)\(\ \)\)\) 
                          t)\)/\[Omega]\_n, \ \ t > 0, \)},
                  {\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ t \[LessEqual] \ 0\)}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NE3",
  CellTags->"(4.2.21)"],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(2.3.77)",
    ButtonData:>{"Chapter2.nb", "(2.3.77)"},
    ButtonStyle->"Hyperlink"],
  "]. The particular solution is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(p\ n\)\)(
          t)\  = \[Integral]\_0\%t\( g(
              t - t\_o)\)\ \(\((\(\[Psi]\_n\)(x), 
                  S(x, t\_o))\)\/\((\[Psi]\_n, \[Psi]\_n)\)\) \
\[DifferentialD]t\_o\)]],
  "."
}], "NE3",
  CellTags->"(4.2.22)"],

Cell[TextData[{
  "Combining Eqs. ",
  ButtonBox["(4.2.16)",
    ButtonData:>"(4.2.16)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(4.2.20)",
    ButtonData:>"(4.2.20)",
    ButtonStyle->"Hyperlink"],
  ",  ",
  ButtonBox["(4.2.22)",
    ButtonData:>"(4.2.22)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(4.2.10)",
    ButtonData:>"(4.2.10)",
    ButtonStyle->"Hyperlink"],
  ", we arrive at the general solution to the wave equation in one spatial \
dimension, with arbitrary boundary  and initial conditions and an arbitrary \
source function: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\  = 
        u(x, t) + \[Sum]\+\(n = 1\)\%\[Infinity]\ \((\(A\_n\) 
                    cos\ \(\[Omega]\_n\) t + \(B\_n\) sin\ \(\[Omega]\_n\) 
                    t\  + \(c\_\(p\ n\)\)(t))\) \(\(\[Psi]\_n\)(x)\)\)]],
  ","
}], "NE3",
  CellTags->{"i:36", "(4.2.23)"}],

Cell[TextData[{
  "Any initial condition can be realized  through appropriate choices of the \
constants ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  ". In order to determine the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "'s",
  ",",
  " we apply the initial condition that ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = \(y\_o\)(x)\)]],
  "  for some function ",
  Cell[BoxData[
      \(TraditionalForm\`y\_o\)]],
  ",  and we evaluate Eq. ",
  ButtonBox["(4.2.23)",
    ButtonData:>"(4.2.23)",
    ButtonStyle->"Hyperlink"],
  "  at the initial time, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0)\  = \(\(u(x, 
              0) + \[Sum]\+\(n = 1\)\%\[Infinity]\( A\_n\) \(\(\[Psi]\_n\)(
                  x)\)\)\(\ \)\(=\)\(\(y\_o\)(x)\)\(\ \)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.24)"],

Cell[TextData[{
  "where we he have recognized that ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\(p\ n\)\)(0) = 0\)]],
  " according to Eq. ",
  ButtonBox["(4.2.22)",
    ButtonData:>"(4.2.22)",
    ButtonStyle->"Hyperlink"],
  ". The Fourier  coefficients are determined in the usual fashion, by taking \
an inner product of both sides of the equation with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " and using orthogonality of the eigenmodes:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_n = \((\[Psi]\_n, \ y\_o - u(x, \
0))\)\/\((\[Psi]\_n, \[Psi]\_n)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.25)"],

Cell[TextData[{
  "The coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " can be found in a similar way, using the second initial condition on ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ", that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 0)\) = \(v\_o\)(
          x)\)]],
  ".  According to Eq. ",
  ButtonBox["(4.2.23)",
    ButtonData:>"(4.2.23)",
    ButtonStyle->"Hyperlink"],
  ", the initial time rate of change of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 
            0)\)\  = \(\(\[PartialD]u\/\[PartialD]t\) \((x, 
                0)\)\  + \ \[Sum]\+\(n = 1\)\%\[Infinity]\([\(\[Omega]\_n\) 
                      B\_n + \ \(c\_\(p\ n\)\^\[Prime]\)(
                      0)]\)\ \ \(\(\[Psi]\_n\)(x)\) = \(v\_o\)(x)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.26)"],

Cell[TextData[{
  " Taking the inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`B\_n = \((\[Psi]\_n, 
              v\_o - \(\[PartialD]u\/\[PartialD]t\) \((x, 
                    0)\))\)/\([\[Omega]\_n\ \((\[Psi]\_n, \[Psi]\_n)\)]\) - \ \
\(\(c\_\(p\ n\)\^\[Prime]\)(0)\)/\[Omega]\_n\)]],
  "."
}], "NE3",
  CellTags->"(4.2.27)"],

Cell[TextData[{
  "Our general solution to the wave equation, Eq. ",
  ButtonBox["(4.2.23)",
    ButtonData:>"(4.2.23)",
    ButtonStyle->"Hyperlink"],
  ", satisfies the boundary conditions, because ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u(x, t)\)\(\ \)\)\)]],
  " is specifically chosen to satisfy these conditions and the eigenmodes \
satisfy homogeneous conditions.  The solution also satisfies the initial \
conditions, since we have chosen the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "'s and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  "'s to create a generalized Fourier series that sums to the correct initial \
conditions. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave Energy", "Section",
  CellTags->"c:19"],

Cell["\<\
\tThere is no dissipation in the wave equation: the system \
oscillates forever when excited.  Therefore, we expect that energy is a \
conserved quantity, provided that there are no time-dependent sources or \
boundary conditions. \
\>", "Text",
  CellTags->"i:39"],

Cell[TextData[{
  "\tOne can separate out static sources or boundary conditions by \
subtracting out an equilibrium solution to the string shape. The remaining \
perturbation satisfies the general wave equation ",
  ButtonBox["(4.2.9)",
    ButtonData:>"(4.2.9)",
    ButtonStyle->"Hyperlink"],
  ", with homogeneous boundary conditions and no source.    In this case \
energy conservation can be proven using the following argument. Multiply both \
sides of this equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Rho](x)\)\ \[PartialD]y\/\[PartialD]t\)]],
  ", and integrate over the string length:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_0\%L\[DifferentialD]x\ \(\[Rho](
            x)\)\ \(\[PartialD]y\/\[PartialD]t\) \[PartialD]\^2 \
y\/\[PartialD]t\^2 = \[Integral]\_0\%L\[DifferentialD]x\ \(\[Rho](
            x)\)\ \(\[PartialD]y\/\[PartialD]t\) \(1\/\(\[Rho](
                x)\)\) \(\[PartialD]\/\[PartialD]x\) \(\((T\ \[PartialD]y\/\
\[PartialD]x)\)\(\ \)\(.\)\(\ \)\)\)]]], "NE3",
  CellTags->"(4.2.28)"],

Cell[TextData[{
  "The  integrals in Eq. ",
  ButtonBox["(4.2.28)",
    ButtonData:>"(4.2.28)",
    ButtonStyle->"Hyperlink"],
  " can be written as  time derivatives  The ",
  "left-hand",
  " integral is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_0\%L\[DifferentialD]x\ \(\[Rho](
                x)\)\ \(\[PartialD]y\/\[PartialD]t\) \[PartialD]\^2 y\/\
\[PartialD]t\^2\), "=", 
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              RowBox[{\(\[Integral]\_0\%L\), 
                
                RowBox[{\(\[DifferentialD]x\), " ", \(1\/2\), \(\[Rho](x)\), 
                  " ", 
                  StyleBox[
                    SuperscriptBox[
                      StyleBox[\((\[PartialD]y\/\[PartialD]t)\),
                        FontWeight->"Plain"], 
                      StyleBox["2",
                        FontWeight->"Plain"]],
                    "Subsubsection"]}]}]}], 
            "=", \(\[PartialD]\(K(t)\)\/\[PartialD]t\)}]}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(K(t)\), "=", 
          RowBox[{\(\[Integral]\_0\%L\), 
            
            RowBox[{\(\[DifferentialD]x\), " ", \(1\/2\), \(\[Rho](x)\), " ", 
              
              StyleBox[
                SuperscriptBox[
                  StyleBox[\((\[PartialD]y\/\[PartialD]t)\),
                    FontWeight->"Plain"], 
                  StyleBox["2",
                    FontWeight->"Plain"]],
                "Subsubsection"]}]}]}], TraditionalForm]]],
  " is the kinetic energy associated with the vibrations. Similarly, one can \
cancel the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  "'s in the right-hand side and integrate by parts, using the homogeneous \
boundary conditions, to obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\[DifferentialD]x\ \(\[Rho](
              x)\)\ \(\[PartialD]y\/\[PartialD]t\) \(1\/\(\[Rho](
                  x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                  x)\)\ \[PartialD]y\/\[PartialD]x)\) = \(\(-\(\[Integral]\_0\
\%L\[DifferentialD]x\ \(T(
                  x)\)\ \(\[PartialD]y\/\[PartialD]x\) \(\[PartialD]\/\
\[PartialD]x\) \((\ \[PartialD]y\/\[PartialD]t)\)\)\) = \(\(-\(\[PartialD]\/\
\[PartialD]t\)\) \(\[Integral]\_0\%L\[DifferentialD]x\ \(T(
                    x)\)\ \((\[PartialD]y\/\[PartialD]x)\)\^2\) = \(-\(\
\[PartialD]\(U(t)\)\/\[PartialD]t\)\)\)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`U(
          t) = \[Integral]\_0\%L\[DifferentialD]x\ \(T(
              x)\)\ \((\[PartialD]y\/\[PartialD]x)\)\^2\)]],
  " . Then Eq. ",
  ButtonBox["(4.2.28)",
    ButtonData:>"(4.2.28)",
    ButtonStyle->"Hyperlink"],
  " implies that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\)[K(t)\  + \ U(t)] = 
        0\)]],
  ","
}], "NE3",
  CellTags->"(4.2.29)"],

Cell[TextData[{
  "so ",
  Cell[BoxData[
      \(TraditionalForm\`K + U\)]],
  " is a constant of the string motion. Since ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " is the kinetic energy, we identify ",
  Cell[BoxData[
      \(TraditionalForm\`U(t)\)]],
  " as the potential energy of the system, and the quantity ",
  Cell[BoxData[
      \(TraditionalForm\`E = K + U\)]],
  " as the total energy. "
}], "Text"],

Cell[TextData[{
  "\tThe energy can also be written in terms of the normal modes of \
oscillation as follows. Since ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  "is real, ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(y\^*\)\)]],
  "and we can write ",
  Cell[BoxData[
      \(TraditionalForm\`\((y\& . )\)\^2 = \(y\& . \^*\) y\& . \)]],
  ", and similarly ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]y\/\[PartialD]x)\)\^2 = \
\(\[PartialD]\(y\^*\)\/\[PartialD]x\) \[PartialD]y\/\[PartialD]x\)]],
  ".   If we substitute the Fourier expansion ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t)\  = \[Sum]\+\(n = 1\)\%\[Infinity]\(\( c\_n\)(
              t)\) \(\(\[Psi]\_n\)(x)\)\)]],
  " into the expressions for ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ",  we find that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\)\(\ \)\)\)]],
  "can be written as"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"E", "=", 
          RowBox[{
            UnderscriptBox[
              StyleBox["\[Sum]",
                FontSize->9], "n"], 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  FontSize->9], "m"], 
              RowBox[{"(", 
                
                RowBox[{\(1\/2\ \(\(c\& . \_n\^*\)(t)\) \(\(c\& . \_m\)(
                      t)\)\ \((\[Psi]\_n, \[Psi]\_m)\)\), "+", 
                  
                  RowBox[{\(1\/2\), \(\(c\_n\^*\)(t)\), " ", \(\(c\_m\)(t)\), 
                    
                    RowBox[{
                      SubsuperscriptBox[
                        StyleBox["\[Integral]",
                          FontSize->10], "0", 
                        "L"], \(\[DifferentialD]x\ \(T(
                          x)\)\ \(\[PartialD]\(\[Psi]\_n\^*\)\/\[PartialD]x\) \
\[PartialD]\[Psi]\_m\/\[PartialD]x\)}]}]}], ")"}]}]}]}], TraditionalForm]]],
  ",  "
}], "Text"],

Cell[TextData[{
  "where we have written the  kinetic energy integral in terms of an inner \
product, using Eq. ",
  ButtonBox["(4.2.17)",
    ButtonData:>"(4.2.17)",
    ButtonStyle->"Hyperlink"],
  ". Integrating by parts  in the second term, we find that the integral in \
the second term can be written as ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\[Integral]\_0\%L\[DifferentialD]x\ \(\[Psi]\_n\
\^*\) \(\[PartialD]\/\[PartialD]x\)[\(T(
                    x)\)\ \[PartialD]\[Psi]\_m\/\[PartialD]x]\)\) = \
\[Omega]\_m\%2\ \((\[Psi]\_n, \[Psi]\_m)\)\)]],
  ", where we have used Eqs. ",
  ButtonBox["(4.2.14)",
    ButtonData:>"(4.2.14)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(4.2.15)",
    ButtonData:>"(4.2.15)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(4.2.17)",
    ButtonData:>"(4.2.17)",
    ButtonStyle->"Hyperlink"],
  ". Then orthogonality of the eigenmodes implies that the energy is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"E", "=", 
          RowBox[{
            FormBox[\(\[Sum]\+n\),
              
              "TraditionalForm"], \(\([1\/2 | \(c\& . \_n\)(
                    t)\( | \^2\)\(+\(1\/2\)\) \[Omega]\_n\%2 | \(c\_n\)(
                    t)\( | \^2\)]\) \((\[Psi]\_n, \[Psi]\_n)\)\)}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(4.2.30)"],

Cell[TextData[{
  " Equation ",
  ButtonBox["(4.2.30)",
    ButtonData:>"(4.2.30)",
    ButtonStyle->"Hyperlink"],
  " shows that the total energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " is a sum over the energies ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " of each normal mode, where\t\t"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \([1\/2 | \(c\& . \_n\)(
                t)\( | \^2\)\(+\(1\/2\)\) \[Omega]\_n\%2 | \(c\_n\)(
                t)\( | \^2\)]\) \((\[Psi]\_n, \[Psi]\_n)\)\)]],
  " ."
}], "Text"],

Cell[TextData[{
  " \tOne can see that ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " is the energy of a harmonic oscillator of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " and effective mass ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_n, \[Psi]\_n)\)\)]],
  ". Therefore,  ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " is also a conserved quantity. This follows from the fact that each mode \
amplitude satisfies the harmonic oscillator equation ",
  ButtonBox["(4.2.19)",
    ButtonData:>"(4.2.19)",
    ButtonStyle->"Hyperlink"],
  " (assuming no forcing). Thus, the total energy ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\)\(\ \)\)\)]],
  "is a sum of the energies ",
  Cell[BoxData[
      \(TraditionalForm\`E\_n\)]],
  " of each normal mode, each of which is separately conserved. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1: Temperature Oscillations", "Section",
  CellTags->"c:20"],

Cell[TextData[{
  "Consider a slab of material of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ",  and with uniform thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ", initially at uniform temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = T\_o\)]],
  ". The left-hand side of the slab at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " has fixed temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = T\_o\)]],
  "; but the ",
  "right-hand",
  " side of the slab  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " has an oscillating temperature, ",
  Cell[BoxData[
      \(TraditionalForm\`T(L, t) = T\_o + T\_1\ sin\ \(\[Omega]\_o\) t\)]],
  ". Our task is to determine the evolution of the temperature within the \
slab of material, ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  ". "
}], "Text",
  CellTags->"i:119"],

Cell[TextData[{
  "\tFirst,we write down the equation for ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ": it is the diffusion equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[PartialD]T\/\[PartialD]t = \[Chi] \
\[PartialD]\^2 T\/\[PartialD]x\^2\)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.31)"],

Cell[TextData[{
  "The boundary conditions on the equation are of Dirichlet form, \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = T\_o\)]],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(L, t) = T\_o + T\_1\ sin\ \(\[Omega]\_o\) t\)]],
  ",\nand the initial condition is ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = T\_o\)]],
  ". This information provides us with all we need to solve the problem. \
First, we put Eq. ",
  ButtonBox["(4.2.31)",
    ButtonData:>"(4.2.31)",
    ButtonStyle->"Hyperlink"],
  " into standard form by choosing a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  " that satisfies the boundary conditions. We choose"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\  = \ 
        T\_o\  + \ x\/L\ T\_1\ sin\ \(\[Omega]\_o\) t\)]],
  ". "
}], "NE3",
  CellTags->"(4.2.32)"],

Cell[TextData[{
  "We next write  the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " as ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T(x, t)\), " ", "=", " ", 
          RowBox[{\(u(x, t)\), " ", "+", " ", 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}]}], 
        TraditionalForm]]],
  ", which implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " is determined by the PDE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[PartialD]", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]]}], \(\[PartialD]t\)], "=", 
          RowBox[{
            RowBox[{"\[Chi]", 
              FractionBox[
                RowBox[{\(\[PartialD]\^2\), 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["T",
                        FontSlant->"Italic"]}]]}], \(\[PartialD]x\^2\)]}], 
            "+", " ", \(\(S\&_\)(x, t)\)}]}], TraditionalForm]]],
  ", "
}], "NE3",
  CellTags->"(4.2.33)"],

Cell[TextData[{
  "with homogeneous Dirichlet boundary conditions, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(0, t\), ")"}], "=", 
            RowBox[{
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["T",
                      FontSlant->"Italic"]}]], "(", \(L, t\), ")"}], "=", 
              "0"}]}], ","}], TraditionalForm]]],
  " and where the source term is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(S\&_\)(x, 
          t) = \(\[Chi] \[PartialD]\^2 u\/\[PartialD]x\^2 - \[PartialD]u\/\
\[PartialD]t = \(-\ \(x\/L\)\)\ \(\[Omega]\_o\) T\_1\ cos\ \(\[Omega]\_o\) 
            t\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.34)"],

Cell[TextData[{
  "Next, we determine the eigenmodes of the spatial operator appearing in Eq. \
",
  ButtonBox["(4.2.33)",
    ButtonData:>"(4.2.33)",
    ButtonStyle->"Hyperlink"],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^ = \[Chi] \[PartialD]\^2\/\[PartialD]x\^2\)]],
  ". These eigenmodes satisfy"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] \(\[PartialD]\^2\/\[PartialD]x\^2\) \
\(\(\[Psi]\_n\)(x)\) = \(\[Lambda]\_n\) \(\(\[Psi]\_n\)(x)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.35)"],

Cell[TextData[{
  "with homogeneous Dirichlet boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(0) = \(\(\[Psi]\_n\)(L) = 0\)\)]],
  ".  We have already seen this eigenvalue problem several times, in Chapter \
",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  ". The eigenmodes are "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\  = \ sin(n\ \[Pi]\ x/L)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.36)"],

Cell["and the eigenvalues are", "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \(-\[Chi]\)\ \((n\ \[Pi]/L)\)\^2\)], 
    "NE3"], "NE3"],
  StyleBox[", ", "NE3"],
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  "."
}], "NE3",
  CellTags->"(4.2.37)"],

Cell[TextData[{
  "Next, we construct a generalized Fourier series solution for the function \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], " ", 
        "=", \(\[Sum]\+n\(\( c\_n\)(
              t)\) \(\(\(\[Psi]\_n\)(x)\)\(\ \ \)\(.\)\)\)}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(4.2.38)"],

Cell[TextData[{
  "Equations for each Fourier coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " are determined by substituting Eq. ",
  ButtonBox["(4.2.38)",
    ButtonData:>"(4.2.38)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(4.2.33)",
    ButtonData:>"(4.2.33)",
    ButtonStyle->"Hyperlink"],
  ", then taking an inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ". Using Eqs. ",
  ButtonBox["(4.2.34)",
    ButtonData:>"(4.2.34)",
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(4.2.32)",
    ButtonData:>"(4.2.32)",
    ButtonStyle->"Hyperlink"],
  " for the source function,  we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
            t)\)\  = \(\[Lambda]\_n\) \(\(c\_n\)(
              t)\)\ \  - \(\((\[Psi]\_n, 
                  x/L)\)\/\((\[Psi]\_n, \[Psi]\_n)\)\) \(\[Omega]\_o\) 
            T\_1\ cos\ \(\[Omega]\_o\) t\)]],
  "."
}], "NE3",
  CellTags->"(4.2.39)"],

Cell[TextData[{
  "The inner products appearing in this equation can be evaluated \
analytically. Since the medium is uniform, according to Eq. ",
  ButtonBox["(4.2.15)",
    ButtonData:>"(4.2.15)",
    ButtonStyle->"Hyperlink"],
  " these inner products are simply integrals from ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Psi][n_, x_]\  = \ Sin[n\ Pi\ x/L];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(Integrate[\[Psi][n, x]\ x/L, {x, 0, L}]/
        Integrate[\[Psi][n, x]^2, {x, 0, L}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Simplify[%, n \[Element] Integers]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.9"],

Cell[BoxData[
    \(\(-\(\(2\ \((\(-1\))\)\^n\)\/\(n\ \[Pi]\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, Eq. ",
  ButtonBox["(4.2.39)",
    ButtonData:>"(4.2.39)",
    ButtonStyle->"Hyperlink"],
  " becomes "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(\(c\_n\)(
            t)\)\  = \(\[Lambda]\_n\) \(\(c\_n\)(
              t)\)\ \  + \(\(2\ \((\(-1\))\)\^n\)\/\(n\ \[Pi]\)\) \
\(\[Omega]\_o\) T\_1\ cos\ \(\[Omega]\_o\) t\)]],
  "."
}], "NE3",
  CellTags->"(4.2.40)"],

Cell["\<\
The general solution to this ODE is given by a linear combination  \
of a homogeneous and a particular solution.\
\>", "Text"],

Cell[TextData[{
  "\tThere are two ways to proceed now. We can either simply apply ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to find the solution to Eq. ",
  ButtonBox["(4.2.40)",
    ButtonData:>"(4.2.40)",
    ButtonStyle->"Hyperlink"],
  ", or we can write the particular solution in integral form using the  \
Green's function for this first-order ODE:"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_m\)(t)\  = \ 
        A\_m\ \[ExponentialE]\^\(\[Lambda]\_m\ t\) + \(\(2\ \((\(-1\))\)\^n\)\
\/\(n\ \[Pi]\)\) \(\[Omega]\_o\) \(T\_1\) \(\[Integral]\_0\%t \[ExponentialE]\
\^\(\(\[Lambda]\_m\)(t - t\&_)\)\ cos\ \(\[Omega]\_o\) \(t\&_\) \
\[DifferentialD]t\&_\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  " The integration can be performed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[n_, t_]\  = \ \(\(A[n]\ \[ExponentialE]\^\(\[Lambda][n]\ t\)\  + 
        FullSimplify[\(\(2\ \((\(-1\))\)\^n\)\/\(n\ \[Pi]\)\) \(\[Omega]\_o\) 
            T\_1\ \ Integrate[\[ExponentialE]\^\(\[Lambda][n]\ \((t - t\&_)\)\
\)\ Cos\ [\(\[Omega]\_o\) t\&_], {t\&_, 0, t}]]\)\(\n\)
      \)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.10"],

Cell[BoxData[
    \(\[ExponentialE]\^\(t\ \[Lambda][n]\)\ A[
          n] + \(2\ \((\(-1\))\)\^n\ T\_1\ \[Omega]\_o\ \((Sin[t\ \
\[Omega]\_o]\ \[Omega]\_o + \((\[ExponentialE]\^\(t\ \[Lambda][n]\) - Cos[t\ \
\[Omega]\_o])\)\ \[Lambda][n])\)\)\/\(n\ \[Pi]\ \((\[Omega]\_o\%2 + \
\[Lambda][n]\^2)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "With this result, the solution for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["T",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is obtained using Eq. ",
  ButtonBox["(4.2.38)",
    ButtonData:>"(4.2.38)",
    ButtonStyle->"Hyperlink"],
  "",
  ",",
  " keeping 20 terms in the sum over the Fourier modes:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 20;\)\), "\n", 
    \(\(\[CapitalDelta]T[x_, t_]\  = \ 
        Sum[c[n, t]\ \[Psi][n, x], {n, 1, M}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.11"],

Cell[TextData[{
  "However, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  " still depends on the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  ", which are determined by matching to the initial condition.  These \
initial conditions are  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, 0\), ")"}], " ", "=", 
          " ", \(T(x, 0) - u(x, 0) = \(T\_o - T\_o = 0\)\)}], 
        TraditionalForm]]],
  ". Thus, at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", we have that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(x, 0\), ")"}], 
          "=", \(\[Sum]\+n A\_n\ \(\(\[Psi]\_n\)(x)\) = 0\)}], 
        TraditionalForm]]],
  ", so the solution for the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  "'s is simply  ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n = 0\)]],
  ": "
}], "Text"],

Cell[BoxData[
    \(\(A[n_]\  = \ 0;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.12"],

Cell[TextData[{
  "By adding  the function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, t)\)]],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(x, t\), ")"}], 
        TraditionalForm]]],
  ", we obtain the full solution for the temperature evolution:"
}], "Text"],

Cell[BoxData[{
    \(\(\(u[x_, t_]\  = \ 
        T\_o + T\_1\ Sin[\(\[Omega]\_o\) t]\ x/L;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(T[x_, t_]\  = \ u[x, t]\  + \ \[CapitalDelta]T[x, t];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.13"],

Cell[TextData[{
  "The resulting function is displayed in Cell ",
  ButtonBox["4.14",
    ButtonData:>"Cell 4.14",
    ButtonStyle->"Hyperlink"],
  " as a series of plots. To evaluate this function numerically, we must \
choose values for ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", \[Chi], ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  ". We must also define the eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n\)]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(\[Lambda][
          n_]\  = \ \(-\[Chi]\)\ \((n\ Pi/L)\)\^2;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(L = \ 4; \[Chi]\  = \ 1/8; \[Omega]\_o = 1; T\_o\  = \ 2; 
    T\_1\  = \ 1;\[IndentingNewLine]\), "\n", 
    \(\(Table[
        Plot[T[x, t], {x, 0, L}, PlotRange \[Rule] {{0, L}, {0, 3}}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<T[x,t], t=\>" <> ToString[t]], {t, 0, 
          15,  .25}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.14"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -35 0 ]
[.5 .63053 35 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -96 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41202 L
.08481 .41202 L
.12636 .41202 L
.16632 .41202 L
.20885 .41202 L
.2498 .41202 L
.29331 .41202 L
.33524 .41202 L
.37557 .41202 L
.41848 .41202 L
.4598 .41202 L
.49953 .41202 L
.54183 .41202 L
.58254 .41202 L
.62583 .41202 L
.66752 .41202 L
.70762 .41202 L
.7503 .41202 L
.79139 .41202 L
.83505 .41202 L
.87712 .41202 L
.9176 .41202 L
.96065 .41202 L
1 .41202 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00>@3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd06@3oool400000003014A4@3oool0oooo01L0oooo10000000
0`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM01P0oooo1@00
000I0?ooo`D000001@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0H0?ooo`0509VI
V@0A4A40000003<c<`3<c<`06@3oool01@2IVIT04A4A0000000c<c<0c<c<00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd06P3oool200000003014A4@3oool0oooo01H0oooo000i0?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool06P3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo0P0R8R880?ooo`0307MgM`0c<c<0
oooo01L0oooo00D0VIVI028R8P3^k^h0oooo04A4A00I0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0
1@3oool2028R8PP0oooo00<0MgMg03<c<`3oool05`3oool01@0A4A40^k^k0?ooo`1gMgL0<c<c01T0
oooo00D04A4A0;^k^`3oool0MgMg03<c<`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`0J0?oo
o`030000003oool0oooo01L0oooo000i0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0G0?ooo`0309VIV@0R8R80k^k^01/0oooo00<0VIVI028R8P3^k^h04@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0F0?ooo`D00000603oool003T0oooo00D000000?ooo`3oool0oooo0000000?0?oo
o`0307MgM`0c<c<0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0>0?oo
o`0307MgM`0c<c<0oooo01T0oooo00<0VIVI028R8P3^k^h06`3oool00`2IVIT08R8R0>k^kP0?0?oo
o`0307MgM`0c<c<0oooo01X0oooo00<0ZZZZ014A4@3oool06`3oool00`2ZZZX04A4A0?ooo`0>0?oo
o`0307MgM`0c<c<0oooo01L0oooo00@0A4A40=gMg@3oool000006@3oool003T0oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`06`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00/0oooo00D00000028R8P000000<c<c0<c<c00K0?ooo`0307Mg
M`1VIVH0oooo01/0oooo00<0MgMg06IVIP3oool02`3oool01@0000008R8R0000000c<c<0c<c<01X0
oooo00<04A4A0000002k^k/06`3oool00`0A4A4000000;^k^`0<0?ooo`050000000R8R80000003<c
<`3<c<`0603oool0103MgMd0EEEE0?ooo`00000I0?ooo`00>@3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`2k^k/08R8R0?ooo`0K0?ooo`030;^k^`0R8R80
oooo00/0oooo00<000000?ooo`3oool06`3oool00`1gMgL0c<c<0000000I0?ooo`00>@3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06P3oool01@000000^k^k0?ooo`2I
VIT04A4A01T0oooo00D000000;^k^`3oool0VIVI014A4@0<0?ooo`030000003oool0oooo01X0oooo
00D04A4A09VIV@3oool0^k^k0000000I0?ooo`05014A4@2IVIT0oooo0;^k^`000000303oool00`00
0000oooo0?ooo`0K0?ooo`030>k^kP14A4@0000001T0oooo000i0?ooo`050>k^kP0c<c<0000003<c
<`3^k^h0303oool4000001X0oooo0P1EEED00`000000oooo0?ooo`0I0?ooo`80EEEE00<000000?oo
o`3oool02`3oool4000001T0oooo00D0VIVI014A4@0000008R8R0<c<c00I0?ooo`0509VIV@0A4A40
0000028R8P3<c<`0303oool4000001T0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP0I0?ooo`050:ZZ
ZP0A4A400000014A4@2ZZZX0303oool4000001/0oooo00<0MgMg0000003oool0603oool00?l0oooo
J@3oool00?l0ooooJ@3oool00?l0ooooFP3oool200000080oooo0P0000090?ooo`00o`3ooomJ0?oo
o`060>k^kP0R8R80R8R80<c<c0000000c<c<2@3oool00?l0ooooF`3oool0103MgMd000000000003<
c<`:0?ooo`007P3ooooo0000038000002`3oool0103^k^h08R8R0000003^k^h:0?ooo`007P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00D0k^k^028R8P1gMgL0MgMg03<c
<`0:0?ooo`007P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0203oool200000080oooo0P0000090?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
odP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`007P3oool300000?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo0`00003o0?oo
odP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool300000?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000
o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00103oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0103oool0
0`000000oooo0?ooo`3o0?ooodP0oooo00040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2
028R8PP0oooo00<0MgMg03<c<`3oool00`3oool00`000000oooo0?ooo`3o0?ooodP0oooo00040?oo
o`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`020?ooo`<00000o`3ooom8
0?ooo`00103oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool00`3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo00040?ooo`050000003oool0oooo0?ooo`000000303oool0
1@0000008R8R0000000c<c<0c<c<00@0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00103oool0
1@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo00040?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0?l0ooooB03oool000@0oooo00D0k^k^03<c<`000000<c<c0>k^
kP0<0?ooo`@000001@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool300000?l0ooooB03oool001h0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000
003oool0oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000E0?ooo`@0000000<04A4A0?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooodP0oooo000G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3o
oom80?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooooB03oool0
01L0oooo00<000000?ooo`3oool0103oool300000?l0ooooB03oool001L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`3o0?ooodP0oooo000G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0o`3ooom80?ooo`005`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0?l0ooooB03oool001D0oooo0P1EEED00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool300000?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000
o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo0`00
003o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000
003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool000D0oooo1000
00000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00@0oooo
00<000000?ooo`3oool0o`3ooom80?ooo`001`3oool00`000000oooo0?ooo`040?ooo`808R8R203o
ool00`1gMgL0<c<c0?ooo`030?ooo`030000003oool0oooo0?l0ooooB03oool000L0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0ooooB03oool0
00L0oooo00<000000?ooo`3oool03P3oool00`1gMgL0<c<c0?ooo`030?ooo`<00000o`3ooom80?oo
o`001`3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`0103oool00`00
0000oooo0?ooo`3o0?ooodP0oooo00070?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00070?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00050?ooo`80EEEE00<0
00000?ooo`3oool02`3oool4000000D0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<0
00000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?oo
o`030000003oool0oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000
003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?oo
o`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03o
ool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000D0?ooo`D000001@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000D0?ooo`0509VIV@0R8R80
k^k^0?ooo`14A4@01@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000E0?ooo`0309VIV@0R8R80
k^k^00H0ooooo`00000b000001T0oooo000F0?ooo`0309VIV@0R8R80k^k^00D0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`005`3oool00`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo0?l0
ooooB03oool001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000D0?ooo`050000002k^k/0oooo09VIV@0A4A401@3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000D0?ooo`0509VIV@0A4A400000028R8P3<c<`01@3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?oo
o`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03o
ool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool300000?l0ooooB03oool001h0
oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo
000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000o`3ooom80?ooo`00
7P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03o
ool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?oo
odP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo
000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo00040?ooo`D000001@3oool2028R8PD0
oooo00D0A4A4000000000000<c<c0=gMg@040?ooo`030000003oool0oooo0?l0ooooB03oool000@0
oooo00D0VIVI028R8P3^k^h0oooo04A4A0050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`030?oo
o`030000003oool0oooo0?l0ooooB03oool000D0oooo00<0VIVI028R8P3^k^h04@3oool00`000000
oooo0?ooo`020?ooo`<00000o`3ooom80?ooo`001P3oool00`2IVIT08R8R0>k^kP0?0?ooo`0307Mg
M`0c<c<0oooo00<0oooo00<000000?ooo`3oool0o`3ooom80?ooo`001`3oool00`1gMgL0IVIV0?oo
o`0;0?ooo`050000000R8R80000003<c<`3<c<`0103oool00`000000oooo0?ooo`3o0?ooodP0oooo
00080?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo00040?ooo`050000002k^k/0oooo09VIV@0A4A40303oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0?l0ooooB03oool000@0oooo00D0VIVI014A4@0000008R8R0<c<
c00<0?ooo`@000001@3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0
ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool300000?l0ooooB03oool001h0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000N0?ooo`<00000o`3ooom80?ooo`007P3oool00`000000oooo0?oo
o`3o0?ooodP0oooo000N0?ooo`030000003oool0oooo0?l0ooooB03oool001h0oooo00<000000?oo
o`3oool0o`3ooom80?ooo`007P3oool00`000000oooo0?ooo`3o0?ooodP0oooo000N0?ooo`030000
003oool0oooo0?l0ooooB03oool001h0oooo0`00003o0?ooodP0oooo000N0?ooo`030000003oool0
oooo0?l0ooooB03oool001h0oooo00<000000?ooo`3oool0o`3ooom80?ooo`007P3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000D0?ooo`0509VIV@0A4A40000003<c<`3<c<`01@3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000D0?ooo`05014A4@2k^k/0oooo07MgM`0c<c<01@3oool00`000000
oooo0?ooo`3o0?ooodP0oooo000H0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3ooom80?ooo`005`3oool00`2ZZZX04A4A0?ooo`040?ooo`<00000o`3ooom80?ooo`005P3oool0
0`0A4A4000000;^k^`3o0?oooe00oooo000G0?ooo`030;^k^`0R8R80oooo0?l0ooooC`3oool001@0
oooo00D04A4A09VIV@3oool0^k^k0000003o0?oooe00oooo000D0?ooo`050:ZZZP0A4A400000014A
4@2ZZZX0o`3ooom@0?ooo`00o`3ooomY0?ooo`00V03oool2000000/0oooo00<04A4A0;^k^`3oool0
303oool2000000H0oooo00<04A4A0;^k^`3oool0Z@3oool009P0oooo00<000000?ooo`3oool02P3o
ool203<c<`h0oooo00<000000?ooo`3oool0103oool203<c<jX0oooo002>0?ooo`05014A4@000000
00000000000A4A401@3oool00`000000oooo0?ooo`020?ooo`8000000P3oool200000080oooo00<0
R8R80000002ZZZX01@3oool01@2IVIT0000000000014A4@0^k^k00<0oooo00<000000?ooo`3oool0
103oool00`28R8P000000:ZZZP0<0?ooo`0509VIV@000000000004A4A02k^k/02@3oool01@3^k^h0
<c<c0000000c<c<0k^k^08X0oooo002@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool01P3^k^h08R8R08R8R03<c<`000000<c<c080oooo00<0c<c<0000000A4A401@3oool0
1@0A4A40^k^k0>k^kP1gMgL04A4A00<0oooo00<000000?ooo`3oool0103oool00`3<c<`00000014A
4@0<0?ooo`06014A4@2k^k/0k^k^07MgM`0A4A40oooo1P0000020?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL0RP3oool00900oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`04
0=gMg@00000000000<c<c0/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00/0oooo00D04A4A0?ooo`3oool0oooo014A4@2:0?ooo`00T03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00@0k^k^028R8P000000k^k^2`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00`3oool6
00000080oooo00D000000?ooo`3oool0oooo0000002:0?ooo`00T03oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00D0k^k^028R8P1gMgL0MgMg03<c<`0;0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`050000003o
ool0oooo0?ooo`000000RP3oool008d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`800000203oool00`0A4A400000
00000003000000@0oooo00<000000?ooo`3oool04@3oool00`0A4A40000000000003000000X0oooo
00D04A4A0?ooo`3oool0oooo014A4@2:0?ooo`00S@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
08X0oooo002=0?ooo`L00000103oool2000001<0oooo00<000000?ooo`3oool0103oool2000001D0
oooo00<000000?ooo`3oool02`3oool01@3^k^h0<c<c0000000c<c<0k^k^08X0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41205 L
.00942 .41208 L
.01441 .4121 L
.01721 .41211 L
.01842 .41211 L
.01975 .41211 L
.02104 .41212 L
.02242 .41212 L
.02369 .41212 L
.02488 .41212 L
.0256 .41212 L
.02628 .41212 L
.02756 .41212 L
.02894 .41211 L
.03045 .41211 L
.03299 .4121 L
.0357 .41209 L
.04057 .41207 L
.05251 .412 L
.05838 .41197 L
.06095 .41195 L
.06377 .41194 L
.06631 .41194 L
.06753 .41193 L
.06868 .41193 L
.07 .41193 L
.07119 .41193 L
.07248 .41193 L
.0732 .41193 L
.07388 .41193 L
.07518 .41193 L
.0764 .41193 L
.07773 .41193 L
.07918 .41193 L
.08212 .41194 L
.08481 .41195 L
.09523 .41201 L
.10096 .41204 L
.10636 .41208 L
.1114 .4121 L
.11425 .41211 L
.1156 .41211 L
.11687 .41212 L
.11793 .41212 L
.11908 .41212 L
.12035 .41212 L
.1215 .41212 L
.12271 .41212 L
.12402 .41212 L
Mistroke
.12526 .41212 L
.12641 .41212 L
.12773 .41211 L
.12893 .41211 L
.13165 .4121 L
.13659 .41208 L
.14579 .41202 L
.15095 .41199 L
.15647 .41196 L
.15915 .41195 L
.16168 .41194 L
.16396 .41193 L
.16523 .41193 L
.16643 .41193 L
.16757 .41193 L
.1688 .41192 L
.17017 .41192 L
.17142 .41192 L
.17266 .41192 L
.17401 .41193 L
.17469 .41193 L
.17541 .41193 L
.17672 .41193 L
.17929 .41194 L
.18171 .41195 L
.18623 .41197 L
.19679 .41204 L
.20256 .41207 L
.20537 .41209 L
.20794 .4121 L
.21026 .41211 L
.21279 .41212 L
.21417 .41212 L
.21545 .41212 L
.21668 .41212 L
.21798 .41212 L
.21928 .41212 L
.22001 .41212 L
.22068 .41212 L
.22191 .41212 L
.22322 .41212 L
.22465 .41212 L
.22598 .41212 L
.229 .4121 L
.23391 .41208 L
.23837 .41206 L
.24839 .41199 L
.25347 .41196 L
.25625 .41195 L
.25885 .41194 L
Mistroke
.26107 .41193 L
.26221 .41192 L
.26345 .41192 L
.2648 .41192 L
.26609 .41192 L
.26735 .41192 L
.26851 .41192 L
.26988 .41192 L
.27065 .41192 L
.27136 .41192 L
.27267 .41192 L
.27405 .41193 L
.27645 .41193 L
.27908 .41194 L
.2849 .41197 L
.29034 .41201 L
.2956 .41205 L
.30132 .41208 L
.30394 .4121 L
.30672 .41211 L
.3091 .41212 L
.31038 .41212 L
.31172 .41213 L
.31293 .41213 L
.31425 .41213 L
.31545 .41213 L
.31656 .41213 L
.31788 .41213 L
.31908 .41213 L
.32047 .41213 L
.32178 .41213 L
.32413 .41212 L
.3263 .41211 L
.33121 .41209 L
.34153 .41202 L
.34721 .41198 L
.3526 .41194 L
.35503 .41193 L
.35761 .41192 L
.35909 .41192 L
.36044 .41191 L
.36179 .41191 L
.36306 .41191 L
.36422 .41191 L
.36545 .41191 L
.3665 .41191 L
.36765 .41191 L
.36889 .41191 L
.37021 .41191 L
.37147 .41192 L
Mistroke
.37261 .41192 L
.3777 .41194 L
.38241 .41197 L
.39306 .41205 L
.39791 .41208 L
.40245 .41211 L
.40493 .41212 L
.40719 .41213 L
.40839 .41213 L
.4097 .41214 L
.41109 .41214 L
.41241 .41214 L
.41309 .41214 L
.4138 .41214 L
.41509 .41214 L
.41647 .41214 L
.41725 .41214 L
.41798 .41214 L
.41931 .41214 L
.42052 .41213 L
.42324 .41212 L
.42828 .4121 L
.43306 .41206 L
.44373 .41198 L
.44958 .41194 L
.45244 .41192 L
.45507 .41191 L
.4574 .4119 L
.45857 .4119 L
.45985 .4119 L
.46114 .4119 L
.46252 .41189 L
.46382 .4119 L
.465 .4119 L
.46569 .4119 L
.46641 .4119 L
.46771 .4119 L
.46911 .41191 L
.47064 .41191 L
.47597 .41194 L
.48078 .41197 L
.48596 .41202 L
.49531 .41209 L
.49798 .41211 L
.50082 .41213 L
.50328 .41214 L
.50457 .41215 L
.50594 .41215 L
.50672 .41215 L
.50757 .41216 L
Mistroke
.50835 .41216 L
.50907 .41216 L
.50981 .41216 L
.5106 .41216 L
.51133 .41216 L
.51202 .41216 L
.51339 .41216 L
.51466 .41216 L
.51532 .41216 L
.51605 .41215 L
.51753 .41215 L
.52027 .41214 L
.52277 .41212 L
.52842 .41208 L
.53863 .41199 L
.54362 .41195 L
.54636 .41193 L
.54895 .41191 L
.55136 .4119 L
.55263 .41189 L
.55397 .41188 L
.5551 .41188 L
.55635 .41188 L
.55748 .41188 L
.55853 .41187 L
.55988 .41187 L
.56064 .41187 L
.56135 .41187 L
.56264 .41188 L
.56402 .41188 L
.56524 .41188 L
.5664 .41189 L
.56902 .4119 L
.57185 .41192 L
.57444 .41193 L
.58028 .41199 L
.58987 .41208 L
.59514 .41213 L
.59773 .41215 L
.60012 .41216 L
.60294 .41218 L
.60443 .41218 L
.60518 .41218 L
.60601 .41219 L
.60734 .41219 L
.60809 .41219 L
.60877 .41219 L
.6101 .41219 L
.61136 .41219 L
.61262 .41218 L
Mistroke
.61396 .41218 L
.61637 .41217 L
.61924 .41215 L
.62184 .41213 L
.6325 .41202 L
.63832 .41196 L
.64376 .4119 L
.6484 .41187 L
.64973 .41186 L
.651 .41185 L
.65212 .41185 L
.65337 .41184 L
.65464 .41184 L
.65599 .41184 L
.65725 .41184 L
.65842 .41184 L
.6598 .41184 L
.66107 .41184 L
.66245 .41185 L
.66392 .41185 L
.66646 .41187 L
.66876 .41189 L
.67394 .41194 L
.68325 .41205 L
.68848 .41212 L
.69122 .41215 L
.69413 .41218 L
.69668 .4122 L
.69803 .41221 L
.69948 .41222 L
.70081 .41222 L
.70202 .41223 L
.70324 .41223 L
.7044 .41223 L
.70572 .41223 L
.70645 .41223 L
.70713 .41223 L
.70838 .41223 L
.7097 .41223 L
.71089 .41222 L
.71199 .41222 L
.7145 .4122 L
.71722 .41218 L
.71969 .41215 L
.72525 .41208 L
.73462 .41194 L
.73976 .41187 L
.74457 .41182 L
.74696 .4118 L
.74819 .41179 L
Mistroke
.74954 .41179 L
.75029 .41178 L
.751 .41178 L
.75173 .41178 L
.75239 .41178 L
.75366 .41178 L
.75501 .41178 L
.75625 .41178 L
.75739 .41178 L
.75865 .41179 L
.75997 .41179 L
.7622 .41181 L
.76465 .41183 L
.7701 .4119 L
.77593 .412 L
.78647 .41218 L
.78915 .41222 L
.79201 .41226 L
.79448 .41229 L
.79714 .41231 L
.79862 .41232 L
.79998 .41233 L
.80128 .41233 L
.80266 .41234 L
.80338 .41234 L
.80416 .41234 L
.8049 .41233 L
.80557 .41233 L
.80635 .41233 L
.8072 .41233 L
.80875 .41232 L
.81129 .4123 L
.81409 .41226 L
.81974 .41218 L
.82987 .41198 L
.83534 .41189 L
.83803 .41185 L
.83934 .41183 L
.84053 .41182 L
.84161 .41181 L
.84279 .4118 L
.84402 .4118 L
.84519 .41179 L
.84648 .41179 L
.84784 .4118 L
.849 .4118 L
.85027 .41181 L
.85175 .41183 L
.85314 .41184 L
.85575 .41189 L
Mistroke
.85856 .41196 L
.86162 .41205 L
.86712 .41227 L
.8722 .41252 L
.89349 .4139 L
.90391 .41465 L
.91346 .41541 L
.92277 .41639 L
.92744 .41704 L
.93256 .41793 L
.93771 .41908 L
.94322 .42064 L
.95313 .42451 L
.95873 .42739 L
.9639 .43052 L
.97556 .43926 L
.99673 .45959 L
1 .46299 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooooooo`0000oo0000??ooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooo`cooooo2_l0000boooo
o`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?oooooo5_ooool7o`0002_o
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolMooooo`?o0000
:?ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?oooooo
8?ooool00ol0003oooooooooo`0Uooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0oooooolQooooo`;o00009Oooool001kooooo0ol0003oooooob?ooooo0_l0
000Sooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000ooooooooool08?ooool0
01kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03
o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003ooooo
ooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooo
oolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool0
0ol0003oooooooooo`0Kooooo`007_ooool3o`000?oooooo:oooool00ol0003oooooooooo`0Joooo
o`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo
00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oo
oooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000F
ooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?oooo
o`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@
o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_oo
ool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003ooooo
ooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo
00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0Nooo
ool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool0N_ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_oo
ool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`00
0?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007gooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41205 L
.00942 .41207 L
.01441 .41209 L
.01721 .4121 L
.01842 .4121 L
.01975 .41211 L
.02104 .41211 L
.02242 .41211 L
.02369 .41211 L
.02488 .41211 L
.0256 .41211 L
.02628 .41211 L
.02756 .41211 L
.02894 .41211 L
.03045 .4121 L
.03299 .4121 L
.0357 .41209 L
.04057 .41207 L
.05251 .412 L
.05838 .41197 L
.06095 .41196 L
.06377 .41195 L
.06631 .41194 L
.06753 .41194 L
.06868 .41194 L
.07 .41194 L
.07119 .41194 L
.07248 .41193 L
.0732 .41193 L
.07388 .41193 L
.07518 .41194 L
.0764 .41194 L
.07773 .41194 L
.07918 .41194 L
.08212 .41195 L
.08481 .41196 L
.09523 .41201 L
.10096 .41204 L
.10636 .41207 L
.1114 .41209 L
.11425 .4121 L
.1156 .4121 L
.11687 .41211 L
.11793 .41211 L
.11908 .41211 L
.12035 .41211 L
.1215 .41211 L
.12271 .41211 L
.12402 .41211 L
Mistroke
.12526 .41211 L
.12641 .41211 L
.12773 .41211 L
.12893 .4121 L
.13165 .41209 L
.13659 .41207 L
.14579 .41202 L
.15095 .41199 L
.15647 .41197 L
.15915 .41196 L
.16168 .41195 L
.16396 .41194 L
.16523 .41194 L
.16643 .41193 L
.16757 .41193 L
.1688 .41193 L
.17017 .41193 L
.17142 .41193 L
.17266 .41193 L
.17401 .41193 L
.17469 .41194 L
.17541 .41194 L
.17672 .41194 L
.17929 .41195 L
.18171 .41195 L
.18623 .41197 L
.19679 .41203 L
.20256 .41207 L
.20537 .41208 L
.20794 .41209 L
.21026 .4121 L
.21279 .41211 L
.21417 .41211 L
.21545 .41211 L
.21668 .41211 L
.21798 .41212 L
.21928 .41212 L
.22001 .41212 L
.22068 .41212 L
.22191 .41211 L
.22322 .41211 L
.22465 .41211 L
.22598 .41211 L
.229 .4121 L
.23391 .41208 L
.23837 .41205 L
.24839 .41199 L
.25347 .41197 L
.25625 .41195 L
.25885 .41194 L
Mistroke
.26107 .41194 L
.26221 .41193 L
.26345 .41193 L
.2648 .41193 L
.26609 .41193 L
.26735 .41193 L
.26851 .41193 L
.26988 .41193 L
.27065 .41193 L
.27136 .41193 L
.27267 .41193 L
.27405 .41193 L
.27645 .41194 L
.27908 .41195 L
.2849 .41198 L
.29034 .41201 L
.2956 .41204 L
.30132 .41208 L
.30394 .41209 L
.30672 .4121 L
.3091 .41211 L
.31038 .41211 L
.31172 .41212 L
.31293 .41212 L
.31425 .41212 L
.31545 .41212 L
.31656 .41212 L
.31788 .41212 L
.31908 .41212 L
.32047 .41212 L
.32178 .41212 L
.32413 .41211 L
.3263 .4121 L
.33121 .41208 L
.34153 .41202 L
.34721 .41198 L
.3526 .41195 L
.35503 .41194 L
.35761 .41193 L
.35909 .41193 L
.36044 .41192 L
.36179 .41192 L
.36306 .41192 L
.36422 .41192 L
.36545 .41192 L
.3665 .41192 L
.36765 .41192 L
.36889 .41192 L
.37021 .41192 L
.37147 .41193 L
Mistroke
.37261 .41193 L
.3777 .41195 L
.38241 .41198 L
.39306 .41205 L
.39791 .41208 L
.40245 .4121 L
.40493 .41211 L
.40719 .41212 L
.40839 .41213 L
.4097 .41213 L
.41109 .41213 L
.41241 .41213 L
.41309 .41213 L
.4138 .41213 L
.41509 .41213 L
.41647 .41213 L
.41725 .41213 L
.41798 .41213 L
.41931 .41213 L
.42052 .41212 L
.42324 .41211 L
.42828 .41209 L
.43306 .41206 L
.44373 .41198 L
.44958 .41195 L
.45244 .41193 L
.45507 .41192 L
.4574 .41191 L
.45857 .41191 L
.45985 .41191 L
.46114 .41191 L
.46252 .41191 L
.46382 .41191 L
.465 .41191 L
.46569 .41191 L
.46641 .41191 L
.46771 .41191 L
.46911 .41192 L
.47064 .41192 L
.47597 .41195 L
.48078 .41198 L
.48596 .41202 L
.49531 .41209 L
.49798 .4121 L
.50082 .41212 L
.50328 .41213 L
.50457 .41214 L
.50594 .41214 L
.50672 .41214 L
.50757 .41214 L
Mistroke
.50835 .41215 L
.50907 .41215 L
.50981 .41215 L
.5106 .41215 L
.51133 .41215 L
.51202 .41215 L
.51339 .41215 L
.51466 .41215 L
.51532 .41214 L
.51605 .41214 L
.51753 .41214 L
.52027 .41213 L
.52277 .41212 L
.52842 .41208 L
.53863 .41199 L
.54362 .41195 L
.54636 .41194 L
.54895 .41192 L
.55136 .41191 L
.55263 .4119 L
.55397 .4119 L
.5551 .41189 L
.55635 .41189 L
.55748 .41189 L
.55853 .41189 L
.55988 .41189 L
.56064 .41189 L
.56135 .41189 L
.56264 .41189 L
.56402 .41189 L
.56524 .41189 L
.5664 .4119 L
.56902 .41191 L
.57185 .41192 L
.57444 .41194 L
.58028 .41199 L
.58987 .41208 L
.59514 .41212 L
.59773 .41214 L
.60012 .41215 L
.60294 .41216 L
.60443 .41217 L
.60518 .41217 L
.60601 .41217 L
.60734 .41217 L
.60809 .41217 L
.60877 .41217 L
.6101 .41217 L
.61136 .41217 L
.61262 .41217 L
Mistroke
.61396 .41216 L
.61637 .41215 L
.61924 .41214 L
.62184 .41212 L
.6325 .41202 L
.63832 .41196 L
.64376 .41191 L
.6484 .41188 L
.64973 .41187 L
.651 .41187 L
.65212 .41186 L
.65337 .41186 L
.65464 .41186 L
.65599 .41186 L
.65725 .41185 L
.65842 .41186 L
.6598 .41186 L
.66107 .41186 L
.66245 .41186 L
.66392 .41187 L
.66646 .41189 L
.66876 .4119 L
.67394 .41195 L
.68325 .41205 L
.6886 .41212 L
.69426 .41217 L
.69659 .41219 L
.69909 .41221 L
.70052 .41221 L
.70184 .41222 L
.70315 .41222 L
.7044 .41223 L
.70568 .41223 L
.70683 .41223 L
.70816 .41223 L
.70941 .41222 L
.71057 .41222 L
.71164 .41222 L
.71404 .41221 L
.71648 .41219 L
.71916 .41217 L
.72455 .41211 L
.73043 .41204 L
.73598 .41198 L
.74097 .41193 L
.74379 .41191 L
.74504 .4119 L
.74639 .41189 L
.74767 .41189 L
.74884 .41188 L
Mistroke
.75001 .41188 L
.75113 .41188 L
.75243 .41188 L
.75363 .41189 L
.75495 .41189 L
.75636 .4119 L
.75773 .41191 L
.75921 .41192 L
.7619 .41195 L
.76692 .41203 L
.77249 .41214 L
.77837 .41228 L
.7889 .41255 L
.80974 .41302 L
.81884 .41317 L
.82364 .41326 L
.82874 .41337 L
.8342 .41354 L
.83925 .41375 L
.84398 .41401 L
.84921 .41438 L
.85466 .41488 L
.86053 .41555 L
.87116 .41716 L
.8812 .41912 L
.89219 .42173 L
.90379 .42501 L
.91434 .42855 L
.9242 .43257 L
.93491 .43803 L
.94622 .44553 L
.9569 .45464 L
.97775 .4786 L
.99984 .51054 L
1 .51079 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooooio`00057ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0m_ooool@o`00047ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0ooooool7ooooo`Ko0000>oooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooo`gooooo0ol0000hooooo`005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0ooooool@ooooo`Co0000
=?ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo
5?ooool3o`00037ooooo000Nooooo`?o0000oooooolGooooo`;o0000;oooool001kooooo00?o0000
ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo000Nooooo`03o`000?oooooooooo
0?oooooo6_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo0?oooooo7?ooool2o`0002[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_oo
ool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000
ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`?o0000oooooolQoooo
o`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003o
ooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool0
8oooool001kooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000N
ooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0
003oooooooooo`3oooooobGooooo00?o0000ooooooooool08?ooool001kooooo0ol0003oooooobKo
oooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`00
0?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooooooo
o`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool0
01kooooo00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03
o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool3o`000?oooooo
:_ooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o
0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0Ioooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000F
ooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?oooo
o`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@
o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooooooo
ool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0POoo
ool008Sooooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00;ooooo1_l000001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo083ooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`1oooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool03Oooool00omgMgOo<S8booooo`20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c021ooooo`00QOooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000
o`000003o`0000[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo08?o
oooo0025ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`23oooo
o`00QOooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03
o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000P_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41205 L
.00942 .41206 L
.01441 .41208 L
.01721 .41209 L
.01842 .41209 L
.01975 .41209 L
.02104 .41209 L
.02242 .4121 L
.02369 .4121 L
.02488 .4121 L
.0256 .4121 L
.02628 .4121 L
.02756 .4121 L
.02894 .41209 L
.03045 .41209 L
.03299 .41209 L
.0357 .41208 L
.04057 .41206 L
.05251 .412 L
.05838 .41198 L
.06095 .41197 L
.06377 .41196 L
.06631 .41196 L
.06753 .41195 L
.06868 .41195 L
.07 .41195 L
.07119 .41195 L
.07248 .41195 L
.0732 .41195 L
.07388 .41195 L
.07518 .41195 L
.0764 .41195 L
.07773 .41195 L
.07918 .41195 L
.08212 .41196 L
.08481 .41197 L
.09523 .41201 L
.10096 .41204 L
.10636 .41206 L
.1114 .41208 L
.11425 .41209 L
.1156 .41209 L
.11687 .41209 L
.11793 .4121 L
.11908 .4121 L
.12035 .4121 L
.1215 .4121 L
.12271 .4121 L
.12402 .4121 L
Mistroke
.12526 .4121 L
.12641 .41209 L
.12773 .41209 L
.12893 .41209 L
.13165 .41208 L
.13659 .41207 L
.14579 .41202 L
.15095 .412 L
.15647 .41198 L
.15915 .41197 L
.16168 .41196 L
.16396 .41195 L
.16523 .41195 L
.16643 .41195 L
.16757 .41195 L
.1688 .41195 L
.17017 .41195 L
.17142 .41195 L
.17266 .41195 L
.17401 .41195 L
.17469 .41195 L
.17541 .41195 L
.17672 .41195 L
.17929 .41196 L
.18171 .41197 L
.18623 .41198 L
.19679 .41203 L
.20256 .41206 L
.20537 .41207 L
.20794 .41208 L
.21026 .41209 L
.21279 .41209 L
.21417 .4121 L
.21545 .4121 L
.21668 .4121 L
.21798 .4121 L
.21928 .4121 L
.22001 .4121 L
.22068 .4121 L
.22191 .4121 L
.22322 .4121 L
.22465 .4121 L
.22598 .41209 L
.229 .41209 L
.23391 .41207 L
.23837 .41205 L
.24839 .412 L
.25347 .41197 L
.25625 .41196 L
.25885 .41196 L
Mistroke
.26107 .41195 L
.26221 .41195 L
.26345 .41195 L
.2648 .41194 L
.26609 .41194 L
.26735 .41194 L
.26851 .41194 L
.26988 .41194 L
.27065 .41194 L
.27136 .41194 L
.27267 .41195 L
.27405 .41195 L
.27645 .41195 L
.27908 .41196 L
.2849 .41199 L
.29034 .41201 L
.2956 .41204 L
.30132 .41207 L
.30394 .41208 L
.30672 .41209 L
.3091 .4121 L
.31038 .4121 L
.31172 .4121 L
.31293 .4121 L
.31425 .41211 L
.31545 .41211 L
.31656 .41211 L
.31788 .41211 L
.31908 .41211 L
.32047 .4121 L
.32178 .4121 L
.32413 .4121 L
.3263 .41209 L
.33121 .41207 L
.34153 .41202 L
.34721 .41199 L
.3526 .41196 L
.35503 .41195 L
.35761 .41195 L
.35909 .41194 L
.36044 .41194 L
.36179 .41194 L
.36306 .41194 L
.36422 .41193 L
.36545 .41193 L
.3665 .41194 L
.36765 .41194 L
.36889 .41194 L
.37021 .41194 L
.37147 .41194 L
Mistroke
.37261 .41194 L
.3777 .41196 L
.38241 .41198 L
.39306 .41204 L
.39791 .41207 L
.40245 .41209 L
.40493 .4121 L
.40719 .41211 L
.40839 .41211 L
.4097 .41211 L
.41109 .41211 L
.41241 .41211 L
.41309 .41212 L
.4138 .41212 L
.41509 .41212 L
.41647 .41211 L
.41725 .41211 L
.41798 .41211 L
.41931 .41211 L
.42052 .41211 L
.42324 .4121 L
.42828 .41208 L
.43306 .41205 L
.44373 .41199 L
.44958 .41196 L
.45244 .41194 L
.45507 .41194 L
.4574 .41193 L
.45857 .41193 L
.45985 .41193 L
.46114 .41192 L
.46252 .41192 L
.46382 .41192 L
.465 .41193 L
.46569 .41193 L
.46641 .41193 L
.46771 .41193 L
.46911 .41193 L
.47064 .41194 L
.47597 .41196 L
.48078 .41198 L
.48596 .41202 L
.49531 .41208 L
.49798 .41209 L
.50082 .41211 L
.50328 .41211 L
.50457 .41212 L
.50594 .41212 L
.50672 .41212 L
.50757 .41213 L
Mistroke
.50835 .41213 L
.50907 .41213 L
.50981 .41213 L
.5106 .41213 L
.51133 .41213 L
.51202 .41213 L
.51339 .41213 L
.51466 .41213 L
.51532 .41213 L
.51605 .41212 L
.51753 .41212 L
.52027 .41211 L
.52277 .4121 L
.52842 .41207 L
.53863 .412 L
.54362 .41197 L
.54636 .41195 L
.54895 .41194 L
.55136 .41193 L
.55263 .41192 L
.55397 .41192 L
.5551 .41191 L
.55635 .41191 L
.55748 .41191 L
.55853 .41191 L
.55988 .41191 L
.56064 .41191 L
.56135 .41191 L
.56264 .41191 L
.56402 .41191 L
.56524 .41191 L
.5664 .41192 L
.56902 .41193 L
.57185 .41194 L
.57444 .41196 L
.58028 .412 L
.58987 .41207 L
.59514 .41211 L
.59773 .41212 L
.60012 .41213 L
.60294 .41215 L
.60443 .41215 L
.60519 .41215 L
.60601 .41215 L
.60732 .41215 L
.60856 .41215 L
.60931 .41216 L
.61002 .41215 L
.61136 .41215 L
.61262 .41215 L
Mistroke
.61396 .41215 L
.61523 .41215 L
.61637 .41214 L
.61919 .41213 L
.62184 .41211 L
.63116 .41205 L
.64114 .41197 L
.64409 .41195 L
.64687 .41193 L
.64938 .41192 L
.65079 .41192 L
.6521 .41192 L
.65331 .41191 L
.65446 .41191 L
.65571 .41191 L
.65706 .41191 L
.6584 .41192 L
.65907 .41192 L
.65981 .41192 L
.66233 .41193 L
.66374 .41193 L
.66507 .41194 L
.66757 .41196 L
.67317 .41201 L
.68327 .41213 L
.69401 .41226 L
.69989 .41232 L
.70276 .41234 L
.70539 .41236 L
.7077 .41237 L
.71021 .41238 L
.71159 .41238 L
.71287 .41239 L
.7141 .41239 L
.7154 .41239 L
.71614 .41239 L
.71683 .41239 L
.71758 .41239 L
.71837 .41239 L
.71971 .41239 L
.72047 .41239 L
.72118 .41239 L
.7225 .41239 L
.7237 .41239 L
.72501 .41239 L
.72641 .41239 L
.72759 .41239 L
.72889 .41239 L
.73007 .41239 L
.73118 .41239 L
Mistroke
.73248 .41239 L
.73368 .41239 L
.73505 .41239 L
.73637 .4124 L
.73749 .4124 L
.7387 .41241 L
.74087 .41242 L
.74345 .41244 L
.74578 .41246 L
.74822 .41249 L
.75089 .41254 L
.7563 .41265 L
.7613 .4128 L
.76597 .41297 L
.77652 .41346 L
.78783 .41413 L
.81011 .41575 L
.82035 .41666 L
.83123 .41785 L
.84116 .41927 L
.85212 .42136 L
.86209 .42384 L
.87145 .42672 L
.89262 .43524 L
.91205 .44559 L
.9319 .45955 L
.95363 .48105 L
.9742 .50908 L
.99619 .54577 L
1 .55245 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooooo/o`0005kooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0jOooool=o`00057ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0m_ooool:o`0004Oooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0ooooool1ooooo`?o0000A?ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?oooooo1?ooool3o`00047ooooo
000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooo`Oooooo
0ol0000nooooo`007_ooool3o`000?oooooo2_ooool3o`0003_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo3Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool2o`00
03Oooooo000Nooooo`03o`000?oooooooooo0?oooooo4Oooool2o`0003Gooooo000Nooooo`03o`00
0?oooooooooo0?oooooo4oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo0?oooooo5Ooo
ool00ol0003oooooooooo`0`ooooo`007_ooool00ol0003oooooooooo`3ooooooaKooooo00?o0000
ooooooooool0;oooool001kooooo0ol0003ooooooaOooooo00?o0000ooooooooool0;_ooool001ko
oooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`00
0?oooooooooo0?oooooo6Oooool2o`0002gooooo000Nooooo`03o`000?oooooooooo0?oooooo6ooo
ool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`3ooooooacooooo00?o0000
ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo
02Sooooo000Nooooo`?o0000oooooolNooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003ooooooooo
o`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooooolP
ooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0
003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000oooooooo
ool08oooool001kooooo0ol0003oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o
0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3ooooo
obCooooo00?o0000ooooooooool08Oooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo
023ooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool000Go
oooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolVooooo`03
o`000?oooooooooo01oooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool000Oooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooolXooooo`03o`000?oooooooooo01gooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Ooo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo0004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oo
oooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0K
ooooo`007_ooool3o`000?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003o
ooooooooo`3oooooob_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0
ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo;Ooo
ool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobgooooo00?o0000
ooooooooool06?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo
01Oooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@
4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool0
1Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003ooooooooo
o`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^
ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01loooo
o`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0
003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo
410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`00
0?oooooooooo07kooooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?oo
ool2o`0001Gooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
1Ol00004ooooo`Co0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41204 L
.00942 .41205 L
.01441 .41207 L
.01721 .41207 L
.01842 .41207 L
.01975 .41208 L
.02104 .41208 L
.02242 .41208 L
.02369 .41208 L
.02488 .41208 L
.0256 .41208 L
.02628 .41208 L
.02756 .41208 L
.02894 .41208 L
.03045 .41207 L
.03299 .41207 L
.0357 .41206 L
.04057 .41205 L
.05251 .41201 L
.05838 .41199 L
.06095 .41198 L
.06377 .41198 L
.06631 .41197 L
.06753 .41197 L
.06868 .41197 L
.07 .41197 L
.07119 .41197 L
.07248 .41197 L
.0732 .41197 L
.07388 .41197 L
.07518 .41197 L
.0764 .41197 L
.07773 .41197 L
.07918 .41197 L
.08212 .41198 L
.08481 .41198 L
.09523 .41201 L
.10096 .41204 L
.10636 .41205 L
.1114 .41207 L
.11425 .41207 L
.1156 .41207 L
.11687 .41208 L
.11793 .41208 L
.11908 .41208 L
.12035 .41208 L
.1215 .41208 L
.12271 .41208 L
.12402 .41208 L
Mistroke
.12526 .41208 L
.12641 .41208 L
.12773 .41208 L
.12893 .41207 L
.13165 .41207 L
.13659 .41206 L
.14579 .41202 L
.15095 .412 L
.15647 .41199 L
.15915 .41198 L
.16168 .41197 L
.16396 .41197 L
.16523 .41197 L
.16643 .41197 L
.16757 .41197 L
.1688 .41197 L
.17017 .41197 L
.17142 .41197 L
.17266 .41197 L
.17401 .41197 L
.17469 .41197 L
.17541 .41197 L
.17672 .41197 L
.17929 .41197 L
.18171 .41198 L
.18623 .41199 L
.19679 .41203 L
.20256 .41205 L
.20537 .41206 L
.20794 .41207 L
.21026 .41207 L
.21279 .41208 L
.21417 .41208 L
.21545 .41208 L
.21668 .41208 L
.21798 .41208 L
.21928 .41208 L
.22001 .41208 L
.22068 .41208 L
.22191 .41208 L
.22322 .41208 L
.22465 .41208 L
.22598 .41208 L
.229 .41207 L
.23391 .41206 L
.23837 .41204 L
.24839 .412 L
.25347 .41199 L
.25625 .41198 L
.25885 .41197 L
Mistroke
.26107 .41197 L
.26221 .41197 L
.26345 .41196 L
.2648 .41196 L
.26609 .41196 L
.26735 .41196 L
.26851 .41196 L
.26988 .41196 L
.27065 .41196 L
.27136 .41196 L
.27267 .41196 L
.27405 .41197 L
.27645 .41197 L
.27908 .41198 L
.2849 .41199 L
.29034 .41202 L
.2956 .41204 L
.30132 .41206 L
.30394 .41207 L
.30672 .41207 L
.3091 .41208 L
.31038 .41208 L
.31172 .41208 L
.31293 .41208 L
.31425 .41209 L
.31545 .41209 L
.31656 .41209 L
.31788 .41209 L
.31908 .41209 L
.32047 .41208 L
.32178 .41208 L
.32413 .41208 L
.3263 .41207 L
.33121 .41206 L
.34153 .41202 L
.34721 .412 L
.3526 .41198 L
.35503 .41197 L
.35761 .41196 L
.35909 .41196 L
.36044 .41196 L
.36179 .41196 L
.36306 .41196 L
.36422 .41196 L
.36545 .41196 L
.3665 .41196 L
.36765 .41196 L
.36889 .41196 L
.37021 .41196 L
.37147 .41196 L
Mistroke
.37261 .41196 L
.3777 .41198 L
.38241 .41199 L
.39306 .41204 L
.39791 .41206 L
.40245 .41207 L
.40493 .41208 L
.40719 .41209 L
.40839 .41209 L
.4097 .41209 L
.41109 .41209 L
.41241 .41209 L
.41309 .41209 L
.4138 .41209 L
.41509 .41209 L
.41647 .41209 L
.41725 .41209 L
.41798 .41209 L
.41931 .41209 L
.42052 .41209 L
.42324 .41208 L
.42828 .41206 L
.43306 .41205 L
.44373 .412 L
.44958 .41197 L
.45244 .41196 L
.45507 .41196 L
.4574 .41195 L
.45857 .41195 L
.45985 .41195 L
.46114 .41195 L
.46252 .41195 L
.46382 .41195 L
.465 .41195 L
.46569 .41195 L
.46641 .41195 L
.46771 .41195 L
.46911 .41196 L
.47064 .41196 L
.47597 .41197 L
.48078 .41199 L
.48596 .41202 L
.49531 .41206 L
.49798 .41208 L
.50082 .41209 L
.50328 .41209 L
.50594 .4121 L
.50673 .4121 L
.50757 .4121 L
.50835 .4121 L
Mistroke
.50907 .4121 L
.50975 .4121 L
.51048 .4121 L
.51128 .4121 L
.51202 .4121 L
.51338 .4121 L
.51414 .4121 L
.51485 .4121 L
.51615 .4121 L
.51753 .4121 L
.52002 .41209 L
.52271 .41208 L
.52757 .41207 L
.53863 .41201 L
.5435 .41199 L
.5487 .41197 L
.55169 .41196 L
.55311 .41195 L
.55441 .41195 L
.55572 .41195 L
.55641 .41195 L
.55713 .41195 L
.55836 .41195 L
.55971 .41195 L
.56042 .41195 L
.56119 .41195 L
.56192 .41195 L
.5626 .41195 L
.56387 .41195 L
.56523 .41195 L
.56805 .41196 L
.57116 .41197 L
.57668 .412 L
.58187 .41203 L
.59217 .4121 L
.59779 .41213 L
.60053 .41214 L
.60303 .41215 L
.60533 .41216 L
.60751 .41217 L
.6087 .41217 L
.6098 .41217 L
.61101 .41217 L
.6123 .41217 L
.6135 .41217 L
.61479 .41217 L
.61601 .41217 L
.61713 .41217 L
.61843 .41217 L
.61985 .41216 L
Mistroke
.62245 .41216 L
.63309 .41212 L
.63563 .41212 L
.63831 .41211 L
.6406 .4121 L
.6419 .4121 L
.64311 .4121 L
.64383 .4121 L
.64451 .4121 L
.64579 .4121 L
.64716 .4121 L
.64794 .4121 L
.64866 .4121 L
.65004 .4121 L
.65083 .4121 L
.65157 .4121 L
.65306 .41211 L
.65466 .41211 L
.65732 .41213 L
.66012 .41215 L
.66513 .41219 L
.67039 .41226 L
.67516 .41233 L
.68587 .41252 L
.70515 .41291 L
.71577 .41313 L
.727 .41337 L
.73659 .41364 L
.74714 .41406 L
.75721 .41461 L
.76802 .41543 L
.78754 .41749 L
.80978 .42072 L
.82001 .42258 L
.83089 .42494 L
.84183 .42783 L
.85173 .43102 L
.87105 .43914 L
.89131 .45054 L
.91319 .46635 L
.93417 .48576 L
.9563 .51258 L
.99624 .5785 L
1 .58538 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooooIo`00077ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0e_oooolDo`0005gooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0j_ooool7o`0005Kooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0lOooool8o`0004kooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3iooooo`Co0000B_ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?gooooo0ol00017ooooo`007_oo
ool3o`000?oooooo0Oooool3o`0004Cooooo000Nooooo`03o`000?oooooooooo0?oooooo1?ooool3
o`00047ooooo000Nooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003oooooo000Nooooo`03
o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`0looooo`007_ooool00ol0003ooooo
ooooo`3oooooo`[ooooo0_l0000looooo`007_ooool00ol0003oooooooooo`3oooooo`cooooo00?o
0000ooooooooool0>Oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`;o0000>Oooool0
01kooooo0ol0003oooooo`oooooo00?o0000ooooooooool0=_ooool001kooooo00?o0000oooooooo
ool0ooooool@ooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo0?oooooo
4Oooool00ol0003oooooooooo`0dooooo`007_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o
0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0oooooolCooooo`;o0000<oooool0
01kooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo033ooooo000Nooooo`?o
0000oooooolFooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`000?oooooooooo0?oooooo
5oooool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3ooooooaSooooo00?o
0000ooooooooool0;Oooool001kooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oooooo
oooo02cooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[oooo
o`007_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool001kooooo
0ol0003ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool0oooo
oolLooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool0
0ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000oooo
ooooool09oooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo02Kooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3oooooob3ooooo00?o0000ooooooooool09Oooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolQooooo`03o`000?oooooooooo02Co
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolRooooo`03o`00
0?oooooooooo02?ooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooob?ooooo00?o0000ooooooooool08_ooool000Cooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolSooooo`03o`000?oooooooooo02;ooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo027ooooo000N
ooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool3o`00
0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobKo
oooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`00
0?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooooooo
o`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool0
01kooooo00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`?o
0000oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo
:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo00?o
0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooo
oooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Joooo
o`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo
0ol0003oooooobcooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0oooo
ool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool0
0ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobkooooo00?o0000oooo
ooooool05oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0
003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8HOooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000oooooooo
ooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0003oooooooooo`04oooo
o`;o8B4QQoooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0SOooool008cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1_l00004oooo
o`03o`000?oooooooooo08gooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08gooooo0029ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2
o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@
ooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`2=ooooo`00ROooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`2=ooooo`00ROooool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo
00Gooooo0_l0000Dooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l00000Soooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41203 L
.00942 .41204 L
.01441 .41205 L
.01721 .41205 L
.01842 .41205 L
.01975 .41206 L
.02104 .41206 L
.02242 .41206 L
.02369 .41206 L
.02488 .41206 L
.0256 .41206 L
.02628 .41206 L
.02756 .41206 L
.02894 .41206 L
.03045 .41205 L
.03299 .41205 L
.0357 .41205 L
.04057 .41204 L
.05251 .41201 L
.05838 .412 L
.06095 .412 L
.06377 .41199 L
.06631 .41199 L
.06753 .41199 L
.06868 .41199 L
.07 .41199 L
.07119 .41199 L
.07248 .41199 L
.0732 .41199 L
.07388 .41199 L
.07518 .41199 L
.0764 .41199 L
.07773 .41199 L
.07918 .41199 L
.08212 .41199 L
.08481 .412 L
.09523 .41202 L
.10096 .41203 L
.10636 .41204 L
.1114 .41205 L
.11425 .41205 L
.1156 .41205 L
.11687 .41206 L
.11793 .41206 L
.11908 .41206 L
.12035 .41206 L
.1215 .41206 L
.12271 .41206 L
.12402 .41206 L
Mistroke
.12526 .41206 L
.12641 .41206 L
.12773 .41205 L
.12893 .41205 L
.13165 .41205 L
.13659 .41204 L
.14579 .41202 L
.15095 .41201 L
.15647 .412 L
.15915 .412 L
.16168 .41199 L
.16396 .41199 L
.16523 .41199 L
.16643 .41199 L
.16757 .41199 L
.1688 .41199 L
.17017 .41199 L
.17142 .41199 L
.17266 .41199 L
.17401 .41199 L
.17469 .41199 L
.17541 .41199 L
.17672 .41199 L
.17929 .41199 L
.18171 .412 L
.18623 .412 L
.19679 .41203 L
.20256 .41204 L
.20537 .41205 L
.20794 .41205 L
.21026 .41205 L
.21279 .41206 L
.21417 .41206 L
.21545 .41206 L
.21668 .41206 L
.21798 .41206 L
.21928 .41206 L
.22001 .41206 L
.22068 .41206 L
.22191 .41206 L
.22322 .41206 L
.22465 .41206 L
.22598 .41206 L
.229 .41205 L
.23391 .41204 L
.23837 .41203 L
.24839 .41201 L
.25347 .412 L
.25625 .412 L
.25885 .41199 L
Mistroke
.26107 .41199 L
.26221 .41199 L
.26345 .41199 L
.2648 .41199 L
.26609 .41199 L
.26735 .41199 L
.26851 .41199 L
.26988 .41199 L
.27065 .41199 L
.27136 .41199 L
.27267 .41199 L
.27405 .41199 L
.27645 .41199 L
.27908 .41199 L
.2849 .41201 L
.29034 .41202 L
.2956 .41203 L
.30132 .41204 L
.30394 .41205 L
.30672 .41205 L
.3091 .41206 L
.31038 .41206 L
.31172 .41206 L
.31293 .41206 L
.31425 .41206 L
.31545 .41206 L
.31656 .41206 L
.31788 .41206 L
.31908 .41206 L
.32047 .41206 L
.32178 .41206 L
.32413 .41206 L
.3263 .41205 L
.33121 .41205 L
.34153 .41202 L
.34721 .41201 L
.3526 .412 L
.35503 .41199 L
.35761 .41199 L
.35909 .41199 L
.36044 .41198 L
.36179 .41198 L
.36306 .41198 L
.36422 .41198 L
.36545 .41198 L
.3665 .41198 L
.36765 .41198 L
.36889 .41198 L
.37021 .41198 L
.37261 .41199 L
Mistroke
.37527 .41199 L
.37774 .41199 L
.38332 .41201 L
.39344 .41203 L
.39819 .41205 L
.40265 .41205 L
.40507 .41206 L
.40729 .41206 L
.40847 .41206 L
.40976 .41206 L
.41112 .41206 L
.41241 .41207 L
.41309 .41207 L
.4138 .41207 L
.41509 .41207 L
.41647 .41207 L
.41725 .41206 L
.41798 .41206 L
.41931 .41206 L
.42052 .41206 L
.42324 .41206 L
.42565 .41205 L
.42828 .41205 L
.43306 .41204 L
.44352 .41201 L
.44908 .412 L
.452 .41199 L
.45359 .41199 L
.45507 .41199 L
.45647 .41198 L
.45774 .41198 L
.45915 .41198 L
.45992 .41198 L
.46066 .41198 L
.46193 .41198 L
.46311 .41198 L
.46441 .41198 L
.46578 .41198 L
.46697 .41198 L
.46825 .41198 L
.47056 .41199 L
.47331 .41199 L
.47583 .412 L
.48727 .41203 L
.49284 .41205 L
.49788 .41206 L
.50027 .41207 L
.50286 .41208 L
.5051 .41208 L
.50755 .41208 L
Mistroke
.5089 .41208 L
.51016 .41208 L
.51149 .41209 L
.51224 .41209 L
.51291 .41209 L
.51413 .41209 L
.51545 .41209 L
.51669 .41209 L
.51785 .41208 L
.51909 .41208 L
.52044 .41208 L
.52287 .41208 L
.52841 .41207 L
.53422 .41205 L
.53962 .41204 L
.54449 .41203 L
.54721 .41203 L
.54842 .41203 L
.54969 .41202 L
.55036 .41202 L
.5511 .41202 L
.55241 .41202 L
.55314 .41202 L
.55393 .41202 L
.55467 .41202 L
.55535 .41202 L
.55666 .41202 L
.5574 .41203 L
.55809 .41203 L
.56069 .41203 L
.56196 .41203 L
.56332 .41204 L
.56579 .41204 L
.57143 .41206 L
.57739 .41209 L
.58286 .41213 L
.60437 .41227 L
.62441 .41237 L
.62918 .41239 L
.63434 .41242 L
.64373 .41249 L
.64935 .41255 L
.65454 .41262 L
.66438 .41279 L
.67454 .41304 L
.68405 .41333 L
.70571 .41418 L
.71661 .4147 L
.72697 .41529 L
.74643 .41676 L
Mistroke
.7565 .4178 L
.76723 .41916 L
.78654 .42236 L
.80902 .42741 L
.83021 .43379 L
.85129 .4424 L
.87069 .4529 L
.89046 .46648 L
.91216 .48489 L
.95462 .53397 L
.99548 .59963 L
1 .60752 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooooo=o`0007gooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0b_oooolDo`0006Wooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0g_ooool<o`0005gooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0j_ooool5o`0005Sooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3_ooooo`?o0000EOooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?;ooooo1?l0001Aooooo`007_oo
ool3o`000?Kooooo0ol0001>ooooo`007_ooool00ol0003oooooooooo`3iooooo`?o0000Boooool0
01kooooo00?o0000ooooooooool0o?ooool3o`0004Sooooo000Nooooo`03o`000?oooooooooo0?oo
oooo0ol00015ooooo`007_ooool00ol0003oooooooooo`3oooooo`?ooooo00?o0000ooooooooool0
@_ooool001kooooo00?o0000ooooooooool0ooooool4ooooo`;o0000@_ooool001kooooo00?o0000
ooooooooool0ooooool6ooooo`03o`000?oooooooooo03oooooo000Nooooo`?o0000ooooool7oooo
o`;o0000?oooool001kooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo03co
oooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool2o`0003cooooo000Nooooo`03o`000?oo
oooooooo0?oooooo3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003oooooooooo`3o
ooooo`gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000oooo
ooooool0=_ooool001kooooo0ol0003ooooooa3ooooo00?o0000ooooooooool0=Oooool001kooooo
00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo03Cooooo000Nooooo`03o`000?oo
oooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3o
oooooa?ooooo00?o0000ooooooooool0<_ooool001kooooo00?o0000ooooooooool0oooooolCoooo
o`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003o
ooooooooo`0aooooo`007_ooool3o`000?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_oo
ool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0;oooool001kooooo00?o0000
ooooooooool0oooooolGooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo
0?oooooo6?ooool00ol0003oooooooooo`0]ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooaWooooo00?o0000oooo
ooooool0;?ooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[oooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003ooooooa[o
oooo00?o0000ooooooooool0:oooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo6oooool00ol0003oooooooooo`0Zooooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool000Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003ooooooooo
o`0Xooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool000Cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003oooooooooo`3ooooooaoooooo00?o
0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooo
oooo02Gooooo000Nooooo`?o0000oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`03
o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003ooooo
ooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooo
oolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool0
0ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3oooooob?ooooo00?o0000oooo
ooooool08_ooool001kooooo0ol0003oooooobCooooo00?o0000ooooooooool08Oooool001kooooo
00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3o
ooooobKooooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolVoooo
o`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`0Nooooo`007_ooool3o`000?oooooo:?ooool00ol0003oooooooooo`0Mooooo`007_oo
ool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000
ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo
0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`3oooooob[o
oooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0ooooool[ooooo`03o`00
0?oooooooooo01[ooooo000Nooooo`?o0000ooooool[ooooo`03o`000?oooooooooo01[ooooo000N
ooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0
003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo00?o0000oooooooo
ool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001Cooooo
00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool0
01Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o0000
0?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWo
oooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zj
ooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool0
0oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ooooooooo
o`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Go
oooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000oooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07cooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000E
ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l0001mooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41203 L
.00942 .41203 L
.01441 .41203 L
.01721 .41203 L
.01842 .41203 L
.01975 .41203 L
.02104 .41203 L
.02242 .41203 L
.02369 .41203 L
.02488 .41203 L
.0256 .41203 L
.02628 .41203 L
.02756 .41203 L
.02894 .41203 L
.03045 .41203 L
.03299 .41203 L
.0357 .41203 L
.04057 .41203 L
.05251 .41202 L
.05838 .41202 L
.06095 .41202 L
.06377 .41201 L
.06631 .41201 L
.06753 .41201 L
.06868 .41201 L
.07 .41201 L
.07119 .41201 L
.07248 .41201 L
.0732 .41201 L
.07388 .41201 L
.07518 .41201 L
.0764 .41201 L
.07773 .41201 L
.07918 .41201 L
.08212 .41201 L
.08481 .41202 L
.09523 .41202 L
.10096 .41202 L
.10636 .41203 L
.1114 .41203 L
.11425 .41203 L
.1156 .41203 L
.11687 .41203 L
.11793 .41203 L
.11908 .41203 L
.12035 .41203 L
.1215 .41203 L
.12271 .41203 L
.12402 .41203 L
Mistroke
.12526 .41203 L
.12641 .41203 L
.12773 .41203 L
.12893 .41203 L
.13165 .41203 L
.13659 .41203 L
.14579 .41202 L
.15095 .41202 L
.15647 .41202 L
.15915 .41201 L
.16168 .41201 L
.16396 .41201 L
.16523 .41201 L
.16643 .41201 L
.16757 .41201 L
.1688 .41201 L
.17017 .41201 L
.17142 .41201 L
.17266 .41201 L
.17401 .41201 L
.17469 .41201 L
.17541 .41201 L
.17672 .41201 L
.17929 .41201 L
.18171 .41201 L
.18623 .41202 L
.19679 .41202 L
.20256 .41203 L
.20537 .41203 L
.20794 .41203 L
.21026 .41203 L
.21279 .41203 L
.21417 .41203 L
.21545 .41203 L
.21668 .41203 L
.21798 .41203 L
.21928 .41203 L
.22001 .41203 L
.22068 .41203 L
.22191 .41203 L
.22322 .41203 L
.22465 .41203 L
.22598 .41203 L
.229 .41203 L
.23391 .41203 L
.23837 .41203 L
.24839 .41202 L
.25347 .41202 L
.25625 .41201 L
.25885 .41201 L
Mistroke
.26107 .41201 L
.26221 .41201 L
.26345 .41201 L
.2648 .41201 L
.26609 .41201 L
.26735 .41201 L
.26851 .41201 L
.26988 .41201 L
.27065 .41201 L
.27136 .41201 L
.27267 .41201 L
.27405 .41201 L
.27645 .41201 L
.27908 .41201 L
.2849 .41202 L
.29034 .41202 L
.2956 .41203 L
.30132 .41203 L
.30394 .41203 L
.30672 .41203 L
.3091 .41203 L
.31038 .41203 L
.31172 .41203 L
.31293 .41203 L
.31425 .41203 L
.31545 .41203 L
.31656 .41203 L
.31788 .41203 L
.31908 .41203 L
.32047 .41203 L
.32178 .41203 L
.32413 .41203 L
.3263 .41203 L
.33121 .41203 L
.34153 .41202 L
.34721 .41202 L
.3526 .41202 L
.35503 .41201 L
.35761 .41201 L
.35909 .41201 L
.36044 .41201 L
.36179 .41201 L
.36306 .41201 L
.36422 .41201 L
.36545 .41201 L
.3665 .41201 L
.36765 .41201 L
.36889 .41201 L
.37021 .41201 L
.37261 .41201 L
Mistroke
.37527 .41201 L
.37774 .41202 L
.38332 .41202 L
.39344 .41203 L
.40265 .41203 L
.40729 .41204 L
.40856 .41204 L
.40993 .41204 L
.41121 .41204 L
.41241 .41204 L
.41308 .41204 L
.4138 .41204 L
.41507 .41204 L
.41579 .41204 L
.41655 .41204 L
.41791 .41204 L
.41916 .41204 L
.42034 .41204 L
.42163 .41204 L
.42301 .41204 L
.42612 .41204 L
.42907 .41204 L
.43459 .41203 L
.43986 .41203 L
.44481 .41203 L
.44751 .41203 L
.44998 .41202 L
.45131 .41202 L
.45272 .41202 L
.45345 .41202 L
.45413 .41202 L
.45488 .41202 L
.45568 .41202 L
.45636 .41202 L
.45709 .41202 L
.45838 .41202 L
.4591 .41202 L
.45978 .41202 L
.46131 .41203 L
.46265 .41203 L
.46387 .41203 L
.46663 .41203 L
.47173 .41203 L
.47658 .41204 L
.49591 .41207 L
.51698 .4121 L
.52615 .41212 L
.53606 .41213 L
.54161 .41214 L
.54672 .41215 L
Mistroke
.55675 .41219 L
.56186 .41221 L
.56746 .41224 L
.57878 .41232 L
.59929 .41252 L
.62127 .41281 L
.63197 .413 L
.6436 .41325 L
.65458 .41356 L
.66474 .41391 L
.68436 .41483 L
.70601 .41625 L
.72635 .41811 L
.74826 .4209 L
.76934 .42464 L
.7915 .43 L
.81226 .43661 L
.83156 .44445 L
.8726 .46812 L
.89504 .48586 L
.91621 .50598 L
.95664 .55409 L
.99965 .61698 L
1 .61752 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_ooooo3o`0008Oooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0`?oooolHo`0006oooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0f?ooool6o`0006Wooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0g_ooool7o`0006;ooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3Uooooo`Go0000GOooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0>[ooooo0ol0001Jooooo`007_oo
ool3o`000>gooooo1?l0001Fooooo`007_ooool00ol0003oooooooooo`3aooooo`?o0000Doooool0
01kooooo00?o0000ooooooooool0m?ooool3o`00053ooooo000Nooooo`03o`000?oooooooooo0?Oo
oooo0ol0001=ooooo`007_ooool00ol0003oooooooooo`3jooooo`;o0000Boooool001kooooo00?o
0000ooooooooool0o?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo0?kooooo00?o0000
ooooooooool0A_ooool001kooooo0ol0003oooooo`;o0000A_ooool001kooooo00?o0000oooooooo
ool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0ooooool4ooooo`03o`00
0?oooooooooo047ooooo000Nooooo`03o`000?oooooooooo0?oooooo1Oooool2o`00047ooooo000N
ooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo
0?oooooo2Oooool00ol0003oooooooooo`0looooo`007_ooool3o`000?oooooo2_ooool00ol0003o
ooooooooo`0kooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool0
>_ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`03o`000?oooooooooo03Wooooo000N
ooooo`03o`000?oooooooooo0?oooooo3Oooool00ol0003oooooooooo`0hooooo`007_ooool00ol0
003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0=oooool001kooooo00?o0000oooooooo
ool0ooooool?ooooo`03o`000?oooooooooo03Kooooo000Nooooo`?o0000ooooool@ooooo`03o`00
0?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003ooooooooo
o`0dooooo`007_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0<oooool0
01kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo0004ooooo`Go
00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
0?oooooo5?ooool00ol0003oooooooooo`0aooooo`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooolDoooo
o`03o`000?oooooooooo037ooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool3o`000?oooooo5Oooool00ol0003oooooooooo`0`ooooo`001_ooool00onHV9So8B4Q
onk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooolFooooo`03o`00
0?oooooooooo02oooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolHooooo`03o`000?oooooooooo02gooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003ooooooooo
o`0/ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oo
oooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`3o
oooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo0ol0003ooooooacooooo00?o0000oooo
ooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02So
oooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_oo
ool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000
ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo
0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool3o`000?oooooo8Oooool00ol0003o
ooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool0
8oooool001kooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000N
ooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0
003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000oooooooo
ool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`?o0000oooooolUooooo`03o`00
0?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003ooooooooo
o`0Oooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool0
01kooooo00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03
o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003ooooo
ooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo0ol0003oooooob[ooooo00?o
0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooo
oooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Joooo
o`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003o
ooooooooo`0Iooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooobkooooo00?o0000ooooooooool05oooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool0097ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0;7ooooo002Aooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:booooo`00Q_ooool01Ol@413o0000o`000?l0
003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@21ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6
o`0000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0P?ooool0
08Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@
olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1oooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6
o`0000Cooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`20ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0POooool008Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo
00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
Poooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`23ooooo`00QOoo
ool7o`0000Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oo
oooooooo00cooooo00?oEEEEofIVI_l000003Oooool4o`0008;ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41202 L
.00942 .41201 L
.01441 .41201 L
.01721 .41201 L
.01842 .41201 L
.01975 .41201 L
.02104 .41201 L
.02242 .41201 L
.02369 .41201 L
.02488 .41201 L
.0256 .41201 L
.02628 .41201 L
.02756 .41201 L
.02894 .41201 L
.03045 .41201 L
.03299 .41201 L
.0357 .41201 L
.04057 .41202 L
.05251 .41203 L
.05838 .41203 L
.06095 .41203 L
.06377 .41203 L
.06631 .41204 L
.06753 .41204 L
.06868 .41204 L
.07 .41204 L
.07119 .41204 L
.07248 .41204 L
.0732 .41204 L
.07388 .41204 L
.07518 .41204 L
.0764 .41204 L
.07773 .41204 L
.07918 .41204 L
.08212 .41203 L
.08481 .41203 L
.09523 .41202 L
.10096 .41202 L
.10636 .41201 L
.1114 .41201 L
.11425 .41201 L
.1156 .41201 L
.11687 .41201 L
.11793 .41201 L
.11908 .41201 L
.12035 .41201 L
.1215 .41201 L
.12271 .41201 L
.12402 .41201 L
Mistroke
.12526 .41201 L
.12641 .41201 L
.12773 .41201 L
.12893 .41201 L
.13165 .41201 L
.13659 .41201 L
.14579 .41202 L
.15095 .41203 L
.15647 .41203 L
.15915 .41203 L
.16168 .41204 L
.16396 .41204 L
.16523 .41204 L
.16643 .41204 L
.16757 .41204 L
.1688 .41204 L
.17017 .41204 L
.17142 .41204 L
.17266 .41204 L
.17401 .41204 L
.17469 .41204 L
.17541 .41204 L
.17672 .41204 L
.17929 .41204 L
.18171 .41203 L
.18623 .41203 L
.19679 .41202 L
.20256 .41202 L
.20537 .41201 L
.20794 .41201 L
.21026 .41201 L
.21279 .41201 L
.21417 .41201 L
.21545 .41201 L
.21668 .41201 L
.21798 .41201 L
.21928 .41201 L
.22001 .41201 L
.22068 .41201 L
.22191 .41201 L
.22322 .41201 L
.22465 .41201 L
.22598 .41201 L
.229 .41201 L
.23391 .41201 L
.23837 .41202 L
.24839 .41203 L
.25347 .41203 L
.25625 .41203 L
.25885 .41204 L
Mistroke
.26107 .41204 L
.26221 .41204 L
.26345 .41204 L
.2648 .41204 L
.26609 .41204 L
.26735 .41204 L
.26851 .41204 L
.26988 .41204 L
.27065 .41204 L
.27136 .41204 L
.27267 .41204 L
.27405 .41204 L
.27645 .41204 L
.27908 .41204 L
.2849 .41203 L
.29034 .41203 L
.2956 .41202 L
.30132 .41201 L
.30394 .41201 L
.30672 .41201 L
.3091 .41201 L
.31038 .41201 L
.31172 .41201 L
.31293 .41201 L
.31425 .41201 L
.31545 .41201 L
.31656 .41201 L
.31788 .41201 L
.31908 .41201 L
.32047 .41201 L
.32178 .41201 L
.32413 .41201 L
.3263 .41201 L
.33121 .41201 L
.34153 .41203 L
.34721 .41203 L
.3526 .41204 L
.35761 .41204 L
.35898 .41204 L
.36044 .41204 L
.3617 .41204 L
.36306 .41204 L
.3644 .41204 L
.36564 .41204 L
.36682 .41204 L
.36807 .41204 L
.36919 .41204 L
.37023 .41204 L
.37138 .41204 L
.37261 .41204 L
Mistroke
.37527 .41204 L
.37774 .41204 L
.38332 .41204 L
.39344 .41203 L
.39819 .41202 L
.40052 .41202 L
.40265 .41202 L
.40372 .41202 L
.40488 .41202 L
.40612 .41202 L
.40729 .41202 L
.40858 .41202 L
.40994 .41202 L
.41124 .41202 L
.41241 .41202 L
.41367 .41202 L
.41485 .41202 L
.41752 .41202 L
.42013 .41202 L
.42293 .41203 L
.42799 .41203 L
.43261 .41204 L
.44396 .41206 L
.45446 .41208 L
.46418 .4121 L
.46908 .4121 L
.47449 .41211 L
.48003 .41211 L
.48586 .41212 L
.49084 .41212 L
.49629 .41213 L
.50137 .41214 L
.50681 .41215 L
.51193 .41217 L
.51659 .41219 L
.52786 .41225 L
.53849 .41233 L
.55771 .4125 L
.56864 .41261 L
.57887 .41273 L
.59973 .41306 L
.61037 .4133 L
.62182 .41363 L
.64404 .41448 L
.66515 .41561 L
.68597 .4171 L
.70529 .419 L
.72687 .4219 L
.74642 .42538 L
.76666 .42998 L
Mistroke
.78853 .43636 L
.8095 .44422 L
.83163 .45469 L
.87154 .4799 L
.91402 .51677 L
.95492 .56143 L
.99839 .61282 L
1 .61473 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooondo`0009Kooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0/OoooolKo`0007_ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0c?ooool<o`0006oooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0f?ooool6o`0006Wooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3Nooooo`Go0000I?ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0>?ooooo0ol0001Qooooo`007_oo
ool3o`000>Kooooo0ol0001Nooooo`007_ooool00ol0003oooooooooo`3Yooooo`?o0000Foooool0
01kooooo00?o0000ooooooooool0k?ooool4o`0005Oooooo000Nooooo`03o`000?oooooooooo0?3o
oooo0ol0001Dooooo`007_ooool00ol0003oooooooooo`3cooooo`;o0000D_ooool001kooooo00?o
0000ooooooooool0mOooool3o`0004oooooo000Nooooo`03o`000?oooooooooo0?Sooooo0_l0001=
ooooo`007_ooool3o`000?[ooooo0_l0001;ooooo`007_ooool00ol0003oooooooooo`3looooo`03
o`000?oooooooooo04Sooooo000Nooooo`03o`000?oooooooooo0?gooooo0_l00018ooooo`007_oo
ool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oooooo
oooo0?oooooo0Oooool2o`0004Gooooo000Nooooo`03o`000?oooooooooo0?oooooo0oooool00ol0
003oooooooooo`12ooooo`007_ooool3o`000?oooooo1?ooool2o`0004;ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo1_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003ooooooooo
o`3oooooo`Oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`3oooooo`Wooooo00?o0000
ooooooooool0??ooool001kooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooooooo
03_ooooo000Nooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003oooooooooo`0jooooo`00
7_ooool3o`000?oooooo3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003ooooooooo
o`3oooooo`gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000
ooooooooool0=_ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo
03Gooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0dooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooolBooooo`03o`000?oooooooooo03?ooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?oooooo4oooool00ol0003oooooooooo`0booooo`00
1_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooolDooooo`03o`000?oooooooooo037ooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003ooooo
ooooo`0aooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolEooooo`03o`000?oooooooooo033ooooo0004ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5_oo
ool00ol0003oooooooooo`0_ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool0
0ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0;Oooool001kooooo0ol0003ooooo
oaWooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0oooooolJooooo`03
o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003ooooo
ooooo`0[ooooo`007_ooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_oo
ool001kooooo00?o0000ooooooooool0oooooolLooooo`03o`000?oooooooooo02Wooooo000Noooo
o`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool3o`000?oo
oooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo
00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oo
oooooooo02Gooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0U
ooooo`007_ooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool001ko
oooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`?o0000
oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?oo
ool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000
ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo
01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool001kooooo0ol0
003oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolY
ooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0
003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000oooooooo
ool06_ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo;?ooool00ol0003oooooooooo`0Iooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@
4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj
^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03
oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07[ooooo0025ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko
00001Oooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_oo
ool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q
8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@
413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`00
00gooooo00?o0000ooooooooool03Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
07kooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooc8b<P04
ooooo`03o`000?oooooooooo07kooooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000oooo
ooooool01?ooool2o`0001Gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00000<oooo
o`Go00001?ooool4o`0007gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41201 L
.00942 .412 L
.01441 .41199 L
.01721 .41199 L
.01842 .41199 L
.01975 .41199 L
.02104 .41199 L
.02242 .41198 L
.02369 .41198 L
.02488 .41198 L
.0256 .41198 L
.02628 .41198 L
.02756 .41199 L
.02894 .41199 L
.03045 .41199 L
.03299 .41199 L
.0357 .41199 L
.04057 .412 L
.05251 .41203 L
.05838 .41205 L
.06095 .41205 L
.06377 .41205 L
.06631 .41206 L
.06753 .41206 L
.06868 .41206 L
.07 .41206 L
.07119 .41206 L
.07248 .41206 L
.0732 .41206 L
.07388 .41206 L
.07518 .41206 L
.0764 .41206 L
.07773 .41206 L
.07918 .41206 L
.08212 .41205 L
.08481 .41205 L
.09523 .41203 L
.10096 .41201 L
.10636 .412 L
.1114 .41199 L
.11425 .41199 L
.1156 .41199 L
.11687 .41199 L
.11793 .41199 L
.11908 .41198 L
.12035 .41198 L
.1215 .41198 L
.12271 .41198 L
.12402 .41198 L
Mistroke
.12526 .41198 L
.12641 .41199 L
.12773 .41199 L
.12893 .41199 L
.13165 .41199 L
.13659 .412 L
.14579 .41202 L
.15095 .41203 L
.15647 .41205 L
.15915 .41205 L
.16168 .41206 L
.16396 .41206 L
.16523 .41206 L
.16643 .41206 L
.16757 .41206 L
.1688 .41206 L
.17017 .41206 L
.17142 .41206 L
.17266 .41206 L
.17401 .41206 L
.17469 .41206 L
.17541 .41206 L
.17672 .41206 L
.17929 .41206 L
.18171 .41205 L
.18623 .41204 L
.19679 .41202 L
.20256 .412 L
.20537 .412 L
.20794 .41199 L
.21026 .41199 L
.21279 .41199 L
.21417 .41198 L
.21545 .41198 L
.21668 .41198 L
.21798 .41198 L
.21928 .41198 L
.22001 .41198 L
.22068 .41198 L
.22191 .41198 L
.22322 .41198 L
.22465 .41198 L
.22598 .41199 L
.229 .41199 L
.23391 .412 L
.23837 .41201 L
.24839 .41204 L
.25347 .41205 L
.25625 .41205 L
.25885 .41206 L
Mistroke
.26107 .41206 L
.26221 .41206 L
.26345 .41206 L
.2648 .41206 L
.26609 .41207 L
.26735 .41207 L
.26851 .41207 L
.26988 .41207 L
.27065 .41207 L
.27136 .41206 L
.27267 .41206 L
.27405 .41206 L
.27645 .41206 L
.27908 .41206 L
.2849 .41204 L
.29034 .41203 L
.2956 .41202 L
.30132 .412 L
.30394 .412 L
.30672 .41199 L
.3091 .41199 L
.31038 .41199 L
.31172 .41199 L
.31293 .41198 L
.31425 .41198 L
.31545 .41198 L
.31656 .41198 L
.31788 .41198 L
.31908 .41198 L
.32047 .41199 L
.32178 .41199 L
.32413 .41199 L
.3263 .41199 L
.33121 .412 L
.34153 .41203 L
.34721 .41205 L
.3526 .41206 L
.35761 .41208 L
.35898 .41208 L
.36044 .41208 L
.3617 .41208 L
.36306 .41208 L
.3644 .41208 L
.36564 .41208 L
.36682 .41208 L
.36807 .41208 L
.36919 .41208 L
.37023 .41208 L
.37138 .41208 L
.37261 .41208 L
Mistroke
.37527 .41208 L
.37774 .41207 L
.38332 .41206 L
.39344 .41204 L
.39819 .41203 L
.40052 .41203 L
.40265 .41202 L
.40372 .41202 L
.40488 .41202 L
.40612 .41202 L
.40729 .41202 L
.40858 .41202 L
.40994 .41202 L
.41124 .41202 L
.41241 .41202 L
.41367 .41202 L
.41485 .41202 L
.41752 .41203 L
.42013 .41203 L
.42293 .41204 L
.43261 .41208 L
.45446 .41218 L
.45964 .4122 L
.46514 .41222 L
.46801 .41222 L
.47117 .41223 L
.47676 .41224 L
.48212 .41225 L
.48778 .41225 L
.4926 .41226 L
.49534 .41227 L
.49788 .41227 L
.50302 .41229 L
.5077 .41232 L
.51309 .41236 L
.51819 .4124 L
.52869 .41253 L
.54008 .41269 L
.56053 .41304 L
.57138 .41324 L
.58303 .41348 L
.5942 .41375 L
.6044 .41407 L
.62439 .41495 L
.64436 .41619 L
.66613 .4179 L
.68682 .41998 L
.70885 .42298 L
.73136 .42719 L
.75255 .43227 L
Mistroke
.79307 .44544 L
.81404 .45471 L
.83617 .46666 L
.87608 .49323 L
.91857 .52877 L
.95946 .56663 L
1 .59935 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooonXo`000:;ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0YOoooolQo`00087ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0a_ooool6o`0007_ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0c?ooool6o`0007Gooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3Booooo`Oo0000K_ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0=Wooooo1ol0001Wooooo`007_oo
ool3o`000>3ooooo1Ol0001Rooooo`007_ooool00ol0003oooooooooo`3Uooooo`?o0000Goooool0
01kooooo00?o0000ooooooooool0j?ooool3o`0005cooooo000Nooooo`03o`000?oooooooooo0>_o
oooo0ol0001Iooooo`007_ooool00ol0003oooooooooo`3^ooooo`;o0000Eoooool001kooooo00?o
0000ooooooooool0l?ooool2o`0005Gooooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0001C
ooooo`007_ooool3o`000?Cooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`3fooooo`;o
0000Coooool001kooooo00?o0000ooooooooool0n?ooool00ol0003oooooooooo`1<ooooo`007_oo
ool00ol0003oooooooooo`3iooooo`;o0000C?ooool001kooooo00?o0000ooooooooool0noooool2
o`0004[ooooo000Nooooo`03o`000?oooooooooo0?gooooo00?o0000ooooooooool0Aoooool001ko
oooo0ol0003nooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0ooooool1ooooo`03o`00
0?oooooooooo04Cooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0004Cooooo000N
ooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0
003oooooooooo`3oooooo`Gooooo0_l00011ooooo`007_ooool00ol0003oooooooooo`3oooooo`Oo
oooo00?o0000ooooooooool0?_ooool001kooooo0ol0003oooooo`Sooooo0_l0000nooooo`007_oo
ool00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0>oooool001kooooo00?o0000
ooooooooool0ooooool;ooooo`03o`000?oooooooooo03[ooooo000Nooooo`03o`000?oooooooooo
0?oooooo3?ooool00ol0003oooooooooo`0iooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooo`gooooo00?o0000oooo
ooooool0>?ooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo3_ooool2o`0003Sooooo0005ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?oooooo4?ooool00ol0003o
ooooooooo`0eooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo03Cooooo0007ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo
4_ooool00ol0003oooooooooo`0cooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo5?ooool00ol0003oooooooooo`0aooooo`001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo5Oooool2o`00037ooooo000N
ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool3o`00
0?oooooo6?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3ooooooaWo
oooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0oooooolJooooo`03o`00
0?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002_ooooo000N
ooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0
003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool001kooooo0ol0003ooooooaoo
oooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolPooooo`03o`00
0?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003ooooooooo
o`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo0_l0000Tooooo`007_ooool00ol0
003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000oooooooo
ool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`?o0000oooooolVooooo`03o`00
0?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooooooo
o`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo0_l0000Nooooo`007_ooool00ol0
003oooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000oooooooo
ool0ooooool[ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo
;?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`000?oooooo;Oooool00ol0003ooooooooo
o`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o0000o`000?l@41001_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo1Ol00005ooooo`;o8B4QQoooool008co
oooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B67ooooo`00S?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?oo
ool00onHV9So8B4Qonk^kP2?ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0S_oo
ool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00kooooo00?oMgMgofIVI_ooool0SOooool008Wooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l00000
0ol0000>ooooo`03o`000?oooooooooo08cooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
4100S_ooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000
5?ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0S_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .412 L
.00942 .41199 L
.01441 .41198 L
.01721 .41197 L
.01842 .41197 L
.01975 .41197 L
.02104 .41196 L
.02242 .41196 L
.02369 .41196 L
.02488 .41196 L
.0256 .41196 L
.02628 .41196 L
.02756 .41196 L
.02894 .41197 L
.03045 .41197 L
.03299 .41197 L
.0357 .41198 L
.04057 .41199 L
.05251 .41204 L
.05838 .41206 L
.06095 .41207 L
.06377 .41207 L
.06631 .41208 L
.06753 .41208 L
.06868 .41208 L
.07 .41208 L
.07119 .41208 L
.07248 .41208 L
.0732 .41208 L
.07388 .41208 L
.07518 .41208 L
.0764 .41208 L
.07773 .41208 L
.07918 .41208 L
.08212 .41207 L
.08481 .41207 L
.09523 .41203 L
.10096 .41201 L
.10636 .41199 L
.1114 .41198 L
.11425 .41197 L
.1156 .41197 L
.11687 .41197 L
.11793 .41196 L
.11908 .41196 L
.12035 .41196 L
.1215 .41196 L
.12271 .41196 L
.12402 .41196 L
Mistroke
.12526 .41196 L
.12641 .41196 L
.12773 .41197 L
.12893 .41197 L
.13165 .41197 L
.13659 .41199 L
.14579 .41202 L
.15095 .41204 L
.15647 .41206 L
.15915 .41207 L
.16168 .41207 L
.16396 .41208 L
.16523 .41208 L
.16643 .41208 L
.16757 .41208 L
.1688 .41208 L
.17017 .41208 L
.17142 .41208 L
.17266 .41208 L
.17401 .41208 L
.17469 .41208 L
.17541 .41208 L
.17672 .41208 L
.17929 .41208 L
.18171 .41207 L
.18623 .41206 L
.19679 .41202 L
.20256 .41199 L
.20537 .41198 L
.20794 .41198 L
.21026 .41197 L
.21279 .41197 L
.21417 .41196 L
.21545 .41196 L
.21668 .41196 L
.21798 .41196 L
.21928 .41196 L
.22001 .41196 L
.22068 .41196 L
.22191 .41196 L
.22322 .41196 L
.22465 .41196 L
.22598 .41197 L
.229 .41197 L
.23391 .41199 L
.23837 .412 L
.24839 .41205 L
.25347 .41206 L
.25625 .41207 L
.25885 .41208 L
Mistroke
.26107 .41208 L
.26221 .41209 L
.26345 .41209 L
.2648 .41209 L
.26609 .41209 L
.26735 .41209 L
.26851 .41209 L
.26988 .41209 L
.27065 .41209 L
.27136 .41209 L
.27267 .41209 L
.27405 .41209 L
.27645 .41208 L
.27908 .41208 L
.2849 .41206 L
.29034 .41204 L
.2956 .41202 L
.30132 .41199 L
.30394 .41199 L
.30672 .41198 L
.3091 .41197 L
.31045 .41197 L
.31172 .41197 L
.31286 .41197 L
.31411 .41197 L
.31541 .41197 L
.31662 .41197 L
.31775 .41197 L
.31879 .41197 L
.31998 .41197 L
.3211 .41197 L
.32363 .41198 L
.32595 .41198 L
.33121 .412 L
.34153 .41205 L
.34721 .41208 L
.3526 .4121 L
.35761 .41212 L
.36044 .41213 L
.36179 .41213 L
.36306 .41213 L
.36422 .41213 L
.36549 .41213 L
.36663 .41213 L
.36768 .41213 L
.36883 .41213 L
.37008 .41213 L
.37139 .41213 L
.37261 .41213 L
.37389 .41213 L
Mistroke
.37509 .41213 L
.37778 .41212 L
.38267 .41211 L
.39183 .41208 L
.39699 .41207 L
.39951 .41206 L
.40182 .41206 L
.40306 .41205 L
.40425 .41205 L
.40549 .41205 L
.40686 .41205 L
.40759 .41205 L
.40825 .41205 L
.40901 .41205 L
.40974 .41205 L
.41102 .41205 L
.41174 .41205 L
.41241 .41206 L
.41499 .41206 L
.41734 .41207 L
.42005 .41208 L
.42262 .41209 L
.43216 .41215 L
.44268 .41224 L
.45386 .41233 L
.46379 .4124 L
.46944 .41242 L
.47475 .41244 L
.48399 .41247 L
.48887 .41248 L
.49409 .41251 L
.49943 .41254 L
.50441 .41258 L
.5101 .41264 L
.51527 .4127 L
.52526 .41288 L
.5347 .4131 L
.57508 .4142 L
.59594 .41492 L
.60645 .41543 L
.61803 .41613 L
.63844 .41775 L
.66037 .41994 L
.6811 .42244 L
.7037 .42597 L
.72535 .43054 L
.74543 .43586 L
.78656 .44974 L
.80908 .45967 L
.83027 .47091 L
Mistroke
.87079 .49598 L
.91388 .52647 L
.93536 .54232 L
.95538 .55525 L
.97466 .56445 L
.98546 .5682 L
.9953 .57104 L
1 .57231 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooonSo`000:Oooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0X?oooolMo`0008[ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0_Oooool7o`0008?ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0a?ooool=o`0007Kooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3Aooooo`Go0000LOooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0=Kooooo0ol0001^ooooo`007_oo
ool3o`000=Wooooo1Ol0001Yooooo`007_ooool00ol0003oooooooooo`3Nooooo`Co0000IOooool0
01kooooo00?o0000ooooooooool0h_ooool3o`0006;ooooo000Nooooo`03o`000?oooooooooo0>Go
oooo0_l0001Pooooo`007_ooool00ol0003oooooooooo`3Wooooo`;o0000G_ooool001kooooo00?o
0000ooooooooool0jOooool3o`0005_ooooo000Nooooo`03o`000?oooooooooo0>cooooo0_l0001I
ooooo`007_ooool3o`000>kooooo0ol0001Fooooo`007_ooool00ol0003oooooooooo`3aooooo`;o
0000E?ooool001kooooo00?o0000ooooooooool0loooool2o`0005;ooooo000Nooooo`03o`000?oo
oooooooo0?Gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`3gooooo`;o0000C_ooool0
01kooooo00?o0000ooooooooool0nOooool2o`0004cooooo000Nooooo`?o0000noooool00ol0003o
ooooooooo`19ooooo`007_ooool00ol0003oooooooooo`3looooo`;o0000BOooool001kooooo00?o
0000ooooooooool0o_ooool2o`0004Oooooo000Nooooo`03o`000?oooooooooo0?oooooo0Oooool0
0ol0003oooooooooo`14ooooo`007_ooool00ol0003oooooooooo`3oooooo`;ooooo0_l00014oooo
o`007_ooool00ol0003oooooooooo`3oooooo`Cooooo0_l00012ooooo`007_ooool3o`000?oooooo
1_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0
000oooooo`007_ooool00ol0003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool0??ooool0
01kooooo00?o0000ooooooooool0ooooool:ooooo`;o0000??ooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0ooooool<oooo
o`03o`000?oooooooooo03Wooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooo`gooooo0_l0000ioooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooo`oo
oooo00?o0000ooooooooool0=_ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0eooooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l0000eooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo5?ooool2o`0003;ooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo02oooooo000N
ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool3o`00
0?oooooo6?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3ooooooaWo
oooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0oooooolJooooo`;o0000
;?ooool001kooooo00?o0000ooooooooool0oooooolLooooo`03o`000?oooooooooo02Wooooo000N
ooooo`03o`000?oooooooooo0?oooooo7Oooool2o`0002Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool3o`000?oooooo8?ooool3o`0002Go
oooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool3o`0002;ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo9_ooool2o`00023ooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool0
0ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooobWooooo1Ol0000Joooo
o`007_ooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool0
01Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o0000
0?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWo
oooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zj
ooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`Go00001Oooool2ob4Q8@Cooooo1Ol00004ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0
003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo07[ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP0=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?oMgMg
ofIVI_ooool03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0O?oo
ool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o
0000ooooooooool04Oooool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07kooooo0022ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41002oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool0O_ooool008;ooooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o0000
5Oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l0001mooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .412 L
.00942 .41198 L
.01441 .41196 L
.01721 .41195 L
.01842 .41195 L
.01975 .41195 L
.02104 .41195 L
.02242 .41195 L
.02369 .41195 L
.02488 .41195 L
.0256 .41195 L
.02628 .41195 L
.02756 .41195 L
.02894 .41195 L
.03045 .41195 L
.03299 .41196 L
.0357 .41197 L
.04057 .41198 L
.05251 .41204 L
.05838 .41207 L
.06095 .41208 L
.06377 .41209 L
.06631 .41209 L
.06753 .4121 L
.06868 .4121 L
.07 .4121 L
.07119 .4121 L
.07248 .4121 L
.0732 .4121 L
.07388 .4121 L
.07518 .4121 L
.0764 .4121 L
.07773 .4121 L
.07918 .41209 L
.08212 .41209 L
.08481 .41208 L
.09523 .41203 L
.10096 .41201 L
.10636 .41198 L
.1114 .41196 L
.11425 .41195 L
.1156 .41195 L
.11687 .41195 L
.11793 .41195 L
.11908 .41195 L
.12035 .41195 L
.1215 .41194 L
.12271 .41194 L
.12402 .41195 L
Mistroke
.12526 .41195 L
.12641 .41195 L
.12773 .41195 L
.12893 .41195 L
.13165 .41196 L
.13659 .41198 L
.14579 .41202 L
.15095 .41205 L
.15647 .41207 L
.15915 .41208 L
.16168 .41209 L
.16396 .4121 L
.16523 .4121 L
.16643 .4121 L
.16757 .4121 L
.1688 .4121 L
.17017 .4121 L
.17142 .4121 L
.17266 .4121 L
.17401 .4121 L
.17469 .4121 L
.17541 .4121 L
.17672 .4121 L
.17929 .41209 L
.18171 .41208 L
.18623 .41207 L
.19679 .41201 L
.20256 .41199 L
.20537 .41197 L
.20794 .41196 L
.21026 .41196 L
.21279 .41195 L
.21417 .41195 L
.21545 .41195 L
.21668 .41195 L
.21798 .41194 L
.21928 .41194 L
.22001 .41194 L
.22068 .41195 L
.22191 .41195 L
.22322 .41195 L
.22465 .41195 L
.22598 .41195 L
.229 .41196 L
.23391 .41198 L
.23837 .412 L
.24839 .41206 L
.25347 .41208 L
.25625 .41209 L
.25885 .4121 L
Mistroke
.26125 .41211 L
.26345 .41211 L
.2647 .41212 L
.26589 .41212 L
.26714 .41212 L
.26851 .41212 L
.26922 .41212 L
.26999 .41212 L
.27072 .41212 L
.27138 .41212 L
.27265 .41212 L
.27399 .41211 L
.27677 .41211 L
.27983 .4121 L
.28527 .41208 L
.29034 .41205 L
.2956 .41202 L
.30132 .412 L
.30394 .41199 L
.30672 .41198 L
.3091 .41197 L
.31045 .41197 L
.31172 .41197 L
.31286 .41197 L
.31411 .41197 L
.31541 .41197 L
.31662 .41197 L
.31775 .41197 L
.31879 .41197 L
.31998 .41197 L
.3211 .41197 L
.32363 .41198 L
.32595 .41199 L
.33121 .41202 L
.34153 .41208 L
.34721 .41212 L
.3526 .41215 L
.35761 .41218 L
.36044 .41219 L
.36306 .4122 L
.36431 .4122 L
.36549 .4122 L
.36654 .4122 L
.36768 .4122 L
.36893 .41221 L
.37025 .41221 L
.37137 .41221 L
.37261 .4122 L
.37389 .4122 L
.37461 .4122 L
Mistroke
.37528 .4122 L
.37782 .4122 L
.38012 .41219 L
.38256 .41218 L
.38806 .41217 L
.39321 .41215 L
.39761 .41214 L
.39888 .41213 L
.40008 .41213 L
.40116 .41213 L
.40234 .41213 L
.40367 .41213 L
.40487 .41213 L
.40626 .41213 L
.40756 .41213 L
.40877 .41213 L
.40989 .41213 L
.41111 .41214 L
.41241 .41214 L
.41508 .41215 L
.41761 .41216 L
.42235 .4122 L
.42746 .41224 L
.43302 .4123 L
.45227 .41254 L
.47302 .41274 L
.48363 .4128 L
.4892 .41284 L
.49507 .41289 L
.50016 .41294 L
.50573 .41302 L
.51551 .41321 L
.52545 .41347 L
.5347 .41377 L
.57568 .41537 L
.58643 .41585 L
.59809 .41647 L
.61924 .41805 L
.6401 .42023 L
.66219 .42302 L
.68297 .42608 L
.70196 .42956 L
.72237 .43434 L
.74431 .44067 L
.78604 .45533 L
.82619 .47409 L
.86891 .49759 L
.91004 .5202 L
.93104 .53093 L
.93679 .53343 L
Mistroke
.94287 .53574 L
.94812 .5374 L
.95101 .53817 L
.95374 .5388 L
.95635 .5393 L
.95918 .53974 L
.96043 .5399 L
.96175 .54004 L
.9629 .54015 L
.96413 .54024 L
.96537 .54031 L
.96651 .54035 L
.9676 .54038 L
.96874 .54039 L
.97 .54038 L
.97117 .54035 L
.97245 .54029 L
.97382 .54021 L
.97531 .5401 L
.97668 .53997 L
.97977 .53961 L
.98537 .53869 L
.99585 .53635 L
1 .53531 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooonMo`000:gooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0V_oooolHo`0009Gooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0/_ooool<o`0008Wooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0__ooool6o`0008?ooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`34ooooo`_o0000N?ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0<oooooo0ol0001eooooo`007_oo
ool3o`000=;ooooo1Ol0001`ooooo`007_ooool00ol0003oooooooooo`3Gooooo`Go0000Joooool0
01kooooo00?o0000ooooooooool0g?ooool3o`0006Sooooo000Nooooo`03o`000?oooooooooo0=oo
oooo0ol0001Uooooo`007_ooool00ol0003oooooooooo`3Rooooo`?o0000H_ooool001kooooo00?o
0000ooooooooool0iOooool3o`0005oooooo000Nooooo`03o`000?oooooooooo0>Sooooo0ol0001L
ooooo`007_ooool3o`000>_ooooo0ol0001Iooooo`007_ooool00ol0003oooooooooo`3^ooooo`;o
0000Eoooool001kooooo00?o0000ooooooooool0l?ooool2o`0005Gooooo000Nooooo`03o`000?oo
oooooooo0?;ooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`3dooooo`;o0000DOooool0
01kooooo00?o0000ooooooooool0m_ooool2o`0004oooooo000Nooooo`?o0000n?ooool2o`0004go
oooo000Nooooo`03o`000?oooooooooo0?[ooooo0_l0001;ooooo`007_ooool00ol0003ooooooooo
o`3looooo`;o0000BOooool001kooooo00?o0000ooooooooool0o_ooool2o`0004Oooooo000Noooo
o`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`14ooooo`007_ooool00ol0003o
ooooooooo`3oooooo`;ooooo0_l00014ooooo`007_ooool3o`000?oooooo1?ooool2o`0004;ooooo
000Nooooo`03o`000?oooooooooo0?oooooo1_ooool2o`00043ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo2?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool2o`00
03cooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?oooooo3?ooool2o`0003[ooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooo
o`kooooo00?o0000ooooooooool0=oooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`02ooooo`?o0000ooooool?ooooo`;o0000=oooool000Kooooo00?oV9RHob4Q8Oo^k^h0
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo4Oooool2o`0003Gooooo
0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0?oooooo4oooool2o`0003?ooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaGooooo0_l0000aooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3ooooooaOooooo0_l0000_ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?oooooo6Oooool2o`0002gooooo000Nooooo`03o`000?oooooo
oooo0?oooooo6oooool00ol0003oooooooooo`0Zooooo`007_ooool3o`000?oooooo7?ooool4o`00
00_ooooo1?l0000Iooooo`007_ooool00ol0003oooooooooo`3oooooob3ooooo2ol0000Mooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0POooool008Sooooo00?o0000ooooooooool01_ooool02_l0
003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Co
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^
k^koooooodA4A0Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo083ooooo0028ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool0Ooooool008Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03oiRH
V?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0P?ooool008Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool0
2oooool01Ol0003o8B4Qo`000?lb<S;oc<c<087ooooo0025ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o0000
00?o00003_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08?ooooo0025ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`23ooooo`00QOooool7o`00
00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oooooooooo
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co0000P_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41199 L
.00942 .41197 L
.01441 .41195 L
.01721 .41194 L
.01842 .41194 L
.01975 .41194 L
.02104 .41194 L
.02242 .41193 L
.02369 .41193 L
.02488 .41193 L
.0256 .41193 L
.02628 .41193 L
.02756 .41193 L
.02894 .41194 L
.03045 .41194 L
.03299 .41195 L
.0357 .41196 L
.04057 .41198 L
.05251 .41204 L
.05838 .41208 L
.06095 .41209 L
.06377 .4121 L
.06631 .4121 L
.06753 .41211 L
.06868 .41211 L
.07 .41211 L
.07119 .41211 L
.07248 .41211 L
.0732 .41211 L
.07388 .41211 L
.07518 .41211 L
.0764 .41211 L
.07773 .41211 L
.07918 .41211 L
.08212 .4121 L
.08481 .41209 L
.09523 .41204 L
.10096 .412 L
.10636 .41197 L
.1114 .41195 L
.11425 .41194 L
.1156 .41194 L
.11687 .41194 L
.11793 .41194 L
.11908 .41193 L
.12035 .41193 L
.1215 .41193 L
.12271 .41193 L
.12402 .41193 L
Mistroke
.12526 .41193 L
.12641 .41194 L
.12773 .41194 L
.12893 .41194 L
.13165 .41195 L
.13659 .41197 L
.14579 .41202 L
.15095 .41205 L
.15647 .41208 L
.15915 .41209 L
.16168 .4121 L
.16396 .41211 L
.16523 .41211 L
.16643 .41212 L
.16757 .41212 L
.1688 .41212 L
.17017 .41212 L
.17142 .41212 L
.17266 .41212 L
.17401 .41212 L
.17469 .41212 L
.17541 .41211 L
.17672 .41211 L
.17929 .41211 L
.18171 .4121 L
.18623 .41208 L
.19679 .41202 L
.20256 .41198 L
.20537 .41197 L
.20794 .41196 L
.21026 .41195 L
.21279 .41194 L
.21417 .41194 L
.21545 .41194 L
.21668 .41194 L
.21798 .41194 L
.21928 .41194 L
.22001 .41194 L
.22068 .41194 L
.22191 .41194 L
.22322 .41194 L
.22465 .41194 L
.22598 .41195 L
.229 .41196 L
.23391 .41198 L
.23837 .41201 L
.24839 .41207 L
.25347 .4121 L
.25625 .41211 L
.25885 .41213 L
Mistroke
.26125 .41213 L
.26345 .41214 L
.2647 .41214 L
.26589 .41214 L
.26714 .41215 L
.26851 .41215 L
.26922 .41215 L
.26999 .41215 L
.27072 .41215 L
.27138 .41215 L
.27265 .41214 L
.27399 .41214 L
.27543 .41214 L
.27677 .41214 L
.27983 .41213 L
.2849 .4121 L
.29034 .41207 L
.29552 .41205 L
.30103 .41202 L
.3039 .41201 L
.30543 .412 L
.30707 .412 L
.30857 .41199 L
.30995 .41199 L
.31127 .41199 L
.31265 .41199 L
.31398 .41199 L
.31518 .41199 L
.31585 .41199 L
.31657 .41199 L
.31789 .41199 L
.31912 .41199 L
.32042 .412 L
.32275 .412 L
.32547 .41202 L
.32801 .41203 L
.33379 .41207 L
.34324 .41215 L
.35331 .41223 L
.35629 .41225 L
.3591 .41227 L
.36183 .41228 L
.36434 .41229 L
.36674 .4123 L
.36794 .4123 L
.36926 .41231 L
.37059 .41231 L
.37133 .41231 L
.37201 .41231 L
.37333 .41231 L
Mistroke
.37457 .41231 L
.37585 .41231 L
.37658 .41231 L
.37726 .41231 L
.38012 .4123 L
.38259 .4123 L
.38524 .41229 L
.39118 .41227 L
.3941 .41227 L
.39553 .41227 L
.39682 .41226 L
.39814 .41226 L
.39937 .41226 L
.40068 .41226 L
.40141 .41226 L
.40209 .41226 L
.40343 .41226 L
.40418 .41226 L
.40489 .41226 L
.40632 .41227 L
.40785 .41227 L
.41055 .41228 L
.41312 .4123 L
.41793 .41233 L
.42275 .41238 L
.42806 .41245 L
.43883 .41262 L
.45817 .41295 L
.48018 .41323 L
.48982 .41334 L
.49492 .41341 L
.50037 .4135 L
.51061 .41373 L
.52015 .41403 L
.54098 .41494 L
.56187 .41602 L
.58454 .41726 L
.59514 .41796 L
.60637 .41886 L
.6265 .42098 L
.66627 .42667 L
.6884 .43053 L
.70862 .43491 L
.74937 .44681 L
.7911 .46162 L
.83125 .4793 L
.87397 .49824 L
.89374 .50557 L
.9151 .51238 L
.9208 .51387 L
Mistroke
.92683 .51519 L
.93197 .51605 L
.93489 .51642 L
.93761 .51666 L
.93893 .51675 L
.93967 .51678 L
.94036 .51681 L
.94163 .51684 L
.94297 .51685 L
.94416 .51684 L
.94529 .5168 L
.94652 .51674 L
.94784 .51665 L
.94917 .51653 L
.95063 .51636 L
.95356 .51591 L
.95628 .51536 L
.9588 .51473 L
.96412 .51302 L
.96987 .5106 L
.98031 .50482 L
.99984 .49077 L
1 .49065 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooon@o`000;[ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0SOoooolPo`0009[ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0[Oooool<o`0008kooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0^Oooool6o`0008Sooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`2oooooo`Oo0000POooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0<Kooooo1_l0001kooooo`007_oo
ool3o`000<cooooo1_l0001eooooo`007_ooool00ol0003oooooooooo`3Booooo`Go0000L?ooool0
01kooooo00?o0000ooooooooool0eoooool3o`0006gooooo000Nooooo`03o`000?oooooooooo0=[o
oooo0ol0001Zooooo`007_ooool00ol0003oooooooooo`3Mooooo`?o0000Ioooool001kooooo00?o
0000ooooooooool0h?ooool4o`0006?ooooo000Nooooo`03o`000?oooooooooo0>Cooooo0ol0001P
ooooo`007_ooool3o`000>Oooooo0ol0001Mooooo`007_ooool00ol0003oooooooooo`3Zooooo`?o
0000F_ooool001kooooo00?o0000ooooooooool0kOooool2o`0005Sooooo000Nooooo`03o`000?oo
oooooooo0>oooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`3aooooo`;o0000E?ooool0
01kooooo00?o0000ooooooooool0loooool3o`00057ooooo000Nooooo`?o0000m_ooool2o`0004oo
oooo000Nooooo`03o`000?oooooooooo0?Sooooo0_l0001=ooooo`007_ooool00ol0003ooooooooo
o`3jooooo`;o0000Boooool001kooooo00?o0000ooooooooool0o?ooool3o`0004Sooooo000Noooo
o`03o`000?oooooooooo0?oooooo0ol00015ooooo`007_ooool00ol0003oooooooooo`3oooooo`?o
oooo0_l0000Xooooo`;o00006Oooool001kooooo0ol0003oooooo`Gooooo0ol0000Tooooo`03o`00
0?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00023ooooo0_l0
000Looooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo0_l0000Mooooo`03o`000?oooooo
oooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo3?ooool2o`0001Wooooo0_l0000Ooooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3oooooo`kooooo0ol0000Eooooo`03o`000?oooooooooo01oooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3ooooooa7ooooo0ol0000@ooooo`;o00008_ooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolDooooo`Go00002?ooool3o`0002Co
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3ooooooaWooooo2Ol0000Vooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00SOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo
00?o0000okZj^_ooool0]?ooool008gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool01?ooool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o0000o`000?l@41001Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1looooo`00QOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2
ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oo
oooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo
00Oooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h03_ooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07[ooooo0025ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00001?ooool00onH
V9So8B4Qonk^kP0>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Noooool008Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b
<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00kooooo00?oMgMgofIVI_ooool03Oooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000kooooo00?o0000
ooooooooool03?ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo07kooooo0022oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool0O_ooool008;ooooo1ol00004ooooo`;o00004oooool00ol0003ooooooooo
o`04ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
2oooool5o`0000Cooooo1?l0001mooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41199 L
.00942 .41197 L
.01441 .41195 L
.01721 .41194 L
.01842 .41193 L
.01975 .41193 L
.02104 .41193 L
.02242 .41193 L
.02369 .41193 L
.02488 .41193 L
.0256 .41193 L
.02628 .41193 L
.02756 .41193 L
.02894 .41193 L
.03045 .41193 L
.03299 .41194 L
.0357 .41195 L
.04057 .41197 L
.05251 .41205 L
.05838 .41208 L
.06095 .41209 L
.06377 .4121 L
.06631 .41211 L
.06753 .41211 L
.06868 .41212 L
.07 .41212 L
.07119 .41212 L
.07248 .41212 L
.0732 .41212 L
.07388 .41212 L
.07518 .41212 L
.0764 .41212 L
.07773 .41212 L
.07918 .41211 L
.08212 .41211 L
.08481 .41209 L
.09523 .41204 L
.10096 .412 L
.10636 .41197 L
.1114 .41195 L
.11425 .41194 L
.1156 .41193 L
.11687 .41193 L
.11793 .41193 L
.11908 .41193 L
.12035 .41193 L
.1215 .41193 L
.12271 .41193 L
.12402 .41193 L
Mistroke
.12526 .41193 L
.12641 .41193 L
.12893 .41194 L
.13165 .41195 L
.13659 .41197 L
.14579 .41203 L
.15095 .41206 L
.15647 .41209 L
.15915 .4121 L
.16168 .41211 L
.16396 .41212 L
.16523 .41212 L
.16643 .41213 L
.16763 .41213 L
.16895 .41213 L
.17024 .41213 L
.17163 .41213 L
.17285 .41213 L
.17414 .41213 L
.17524 .41213 L
.17643 .41212 L
.17919 .41212 L
.18212 .41211 L
.1874 .41208 L
.19893 .41201 L
.20398 .41198 L
.20685 .41197 L
.20954 .41196 L
.21206 .41195 L
.21348 .41195 L
.21478 .41194 L
.21614 .41194 L
.21691 .41194 L
.21762 .41194 L
.21893 .41194 L
.21959 .41194 L
.22032 .41194 L
.22105 .41194 L
.22183 .41194 L
.22321 .41195 L
.2247 .41195 L
.22634 .41195 L
.22927 .41197 L
.23199 .41198 L
.24215 .41205 L
.25316 .41212 L
.25595 .41214 L
.2589 .41215 L
.26163 .41217 L
.26297 .41217 L
Mistroke
.26419 .41217 L
.26534 .41218 L
.26659 .41218 L
.2679 .41218 L
.26916 .41218 L
.27053 .41218 L
.27129 .41218 L
.27199 .41218 L
.27334 .41218 L
.27462 .41218 L
.27575 .41218 L
.27699 .41217 L
.2795 .41216 L
.28399 .41215 L
.29413 .41209 L
.29964 .41206 L
.30235 .41205 L
.30485 .41204 L
.30712 .41204 L
.30827 .41204 L
.30954 .41203 L
.3108 .41203 L
.31216 .41203 L
.31345 .41203 L
.31463 .41203 L
.31591 .41204 L
.31728 .41204 L
.31857 .41204 L
.31974 .41205 L
.32262 .41206 L
.32533 .41208 L
.33074 .41212 L
.33659 .41217 L
.34647 .41227 L
.35707 .41237 L
.36019 .4124 L
.36315 .41242 L
.36603 .41243 L
.3687 .41244 L
.37122 .41245 L
.37263 .41245 L
.37391 .41245 L
.37531 .41246 L
.3761 .41246 L
.37683 .41246 L
.37817 .41246 L
.37884 .41246 L
.37958 .41246 L
.38091 .41246 L
.38167 .41246 L
Mistroke
.38236 .41246 L
.38364 .41246 L
.385 .41246 L
.38737 .41245 L
.38993 .41245 L
.39066 .41245 L
.39135 .41245 L
.39265 .41245 L
.39387 .41245 L
.3952 .41245 L
.39596 .41245 L
.39666 .41245 L
.39746 .41245 L
.39821 .41245 L
.39955 .41246 L
.40101 .41246 L
.40342 .41247 L
.40606 .41248 L
.40882 .41249 L
.4114 .41251 L
.41602 .41256 L
.42097 .41262 L
.43165 .41281 L
.44327 .41306 L
.46439 .41352 L
.48473 .41388 L
.49554 .41409 L
.5072 .41441 L
.51828 .41483 L
.52845 .41533 L
.54841 .41652 L
.56996 .41792 L
.59001 .41936 L
.60934 .42117 L
.63001 .42381 L
.67357 .43097 L
.71554 .44018 L
.75591 .45235 L
.79886 .46662 L
.84022 .482 L
.861 .48857 L
.87009 .49083 L
.87999 .49285 L
.89046 .4945 L
.89568 .49514 L
.9004 .49561 L
.90305 .49583 L
.90591 .49602 L
.90749 .49611 L
.90894 .49617 L
Mistroke
.91032 .49622 L
.91109 .49624 L
.91178 .49626 L
.91304 .49628 L
.91439 .49629 L
.91564 .49629 L
.91682 .49628 L
.91819 .49625 L
.91946 .4962 L
.92086 .49614 L
.92234 .49605 L
.92484 .49585 L
.92748 .49556 L
.9322 .49482 L
.93483 .49428 L
.93727 .49368 L
.94281 .49196 L
.94768 .49 L
.9521 .48782 L
.96202 .48146 L
.97151 .47345 L
.98025 .46458 L
1 .4411 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooon6o`000<Cooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0PooooolOo`000:Gooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0X_oooolBo`0009?ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0]?ooool7o`0008cooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`2kooooo`Ko0000Q_ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0<7ooooo1ol0001oooooo`007_oo
ool3o`000<Sooooo1Ol0001jooooo`007_ooool00ol0003oooooooooo`3=ooooo`Go0000MOooool0
01kooooo00?o0000ooooooooool0d_ooool4o`00077ooooo000Nooooo`03o`000?oooooooooo0=Ko
oooo1?l0001Cooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0=[ooooo
1?l0001?ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0=kooooo1?l0
001:ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0>;ooooo0ol00016
ooooo`03o`000?oooooooooo01Wooooo000Nooooo`?o0000iOooool3o`0004;ooooo00?o0000oooo
ooooool06_ooool001kooooo00?o0000ooooooooool0j?ooool3o`0003kooooo00?o0000oooooooo
ool06oooool001kooooo00?o0000ooooooooool0joooool2o`0003_ooooo00?o0000ooooooooool0
7?ooool001kooooo00?o0000ooooooooool0kOooool3o`0003Oooooo00?o0000ooooooooool07Ooo
ool001kooooo00?o0000ooooooooool0l?ooool3o`0003?ooooo00?o0000ooooooooool07_ooool0
01kooooo00?o0000ooooooooool0loooool3o`0002oooooo00?o0000ooooooooool07oooool001ko
oooo0ol0003fooooo`?o0000:_ooool2o`0002;ooooo000Nooooo`03o`000?oooooooooo0?Wooooo
0ol0000Vooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?cooooo0ol0
000Qooooo`;o00009Oooool001kooooo00?o0000ooooooooool0ooooool3o`0001gooooo00?o0000
ooooooooool09Oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`?o00006Oooool00ol0
003oooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`3oooooo`Kooooo0ol0000Cooooo`?o
0000:Oooool001kooooo0ol0003oooooo`Wooooo1ol00009ooooo`?o0000;?ooool001kooooo00?o
0000ooooooooool0ooooool@ooooo`Wo0000;oooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003o
ooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool0
0ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Co
oooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooom@ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00GoV9RHoa0@
4?l0003o<S8bolc<c005ooooo`;o8B4QQoooool008cooooo00?o0000ooooooooool01_ooool02_l0
003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Co
oooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_oooooo410@okZj^_oo
ooooMgMgoc8b<PGooooo0_lQ8B67ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2<ooooo`00S?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1?ooool6o`0000Cooooo00?oZJVYoa0@4?ooool0SOooool008cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o410@o`000?nj^[X0
S_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03
o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000=ooooo`03okZj^_lQ8B7ooooo08go
oooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?nHV9SooooookZj^_l00000S_ooool008Wooooo1ol00005ooooo`;o
00004_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41199 L
.00942 .41197 L
.01441 .41194 L
.01721 .41194 L
.01842 .41193 L
.01975 .41193 L
.02104 .41193 L
.02242 .41193 L
.02369 .41193 L
.02488 .41193 L
.0256 .41193 L
.02628 .41193 L
.02756 .41193 L
.02894 .41193 L
.03045 .41193 L
.03299 .41194 L
.0357 .41195 L
.04057 .41197 L
.05251 .41205 L
.05838 .41208 L
.06095 .41209 L
.06377 .41211 L
.06631 .41211 L
.06753 .41212 L
.06868 .41212 L
.07 .41212 L
.07119 .41212 L
.07248 .41212 L
.0732 .41212 L
.07388 .41212 L
.07518 .41212 L
.0764 .41212 L
.07773 .41212 L
.07918 .41212 L
.08212 .41211 L
.08481 .4121 L
.09523 .41204 L
.10096 .412 L
.10636 .41197 L
.1114 .41195 L
.11425 .41194 L
.1156 .41194 L
.11687 .41193 L
.11793 .41193 L
.11908 .41193 L
.12035 .41193 L
.1215 .41193 L
.12271 .41193 L
.12402 .41193 L
Mistroke
.12526 .41193 L
.12641 .41193 L
.12893 .41194 L
.13165 .41195 L
.13659 .41197 L
.14579 .41203 L
.15095 .41206 L
.15647 .4121 L
.15915 .41211 L
.16168 .41212 L
.16396 .41213 L
.16643 .41214 L
.16763 .41214 L
.16895 .41214 L
.17033 .41214 L
.17163 .41214 L
.17284 .41214 L
.17394 .41214 L
.17516 .41214 L
.17643 .41213 L
.17915 .41213 L
.18168 .41212 L
.1874 .41209 L
.1988 .41202 L
.20439 .41199 L
.20684 .41198 L
.20954 .41197 L
.21079 .41197 L
.21213 .41196 L
.21329 .41196 L
.21456 .41196 L
.2153 .41196 L
.21598 .41196 L
.21734 .41196 L
.21856 .41196 L
.21987 .41196 L
.22119 .41196 L
.22193 .41196 L
.22261 .41196 L
.22519 .41197 L
.22805 .41198 L
.23106 .412 L
.24038 .41206 L
.25059 .41214 L
.25613 .41218 L
.25885 .41219 L
.26136 .4122 L
.2636 .41221 L
.26606 .41222 L
.26734 .41222 L
Mistroke
.26853 .41222 L
.2698 .41223 L
.27115 .41223 L
.27186 .41223 L
.27262 .41223 L
.27397 .41223 L
.2748 .41222 L
.27558 .41222 L
.27704 .41222 L
.27973 .41221 L
.28264 .41221 L
.29314 .41216 L
.29797 .41214 L
.30062 .41213 L
.30313 .41212 L
.30456 .41212 L
.3053 .41212 L
.3061 .41211 L
.30677 .41211 L
.30751 .41211 L
.3088 .41211 L
.31012 .41211 L
.31086 .41211 L
.31153 .41211 L
.31278 .41211 L
.31409 .41212 L
.31548 .41212 L
.31674 .41212 L
.31957 .41214 L
.32219 .41215 L
.32466 .41217 L
.33622 .41228 L
.37663 .41266 L
.3865 .41268 L
.38911 .41269 L
.39194 .41269 L
.39444 .4127 L
.3971 .41271 L
.40026 .41273 L
.40318 .41275 L
.40874 .41279 L
.41168 .41283 L
.41445 .41286 L
.41961 .41295 L
.42999 .41317 L
.43952 .41341 L
.46101 .41401 L
.48251 .41455 L
.493 .41482 L
.50255 .41514 L
Mistroke
.51246 .41555 L
.52184 .41604 L
.54249 .41741 L
.58281 .42056 L
.60363 .42258 L
.62571 .42549 L
.66542 .43221 L
.70771 .44092 L
.74841 .45208 L
.79168 .46414 L
.8133 .47016 L
.83337 .47549 L
.84335 .47771 L
.85277 .47936 L
.85798 .48004 L
.86072 .48033 L
.86361 .48058 L
.86606 .48074 L
.86735 .48082 L
.86874 .48088 L
.87001 .48093 L
.87118 .48096 L
.87235 .48099 L
.87345 .481 L
.87465 .48101 L
.87594 .48101 L
.87715 .481 L
.87827 .48097 L
.87951 .48094 L
.88086 .4809 L
.88358 .48076 L
.88628 .48059 L
.88916 .48035 L
.89435 .47978 L
.89956 .47903 L
.90448 .47815 L
.91369 .47599 L
.92389 .47263 L
.93469 .4676 L
.94392 .46176 L
.95406 .45333 L
.97447 .42948 L
.99641 .39565 L
1 .38973 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000N
ooooo`?o0000ooooool^ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobgo
oooo00?o0000ooooooooool06?ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`00
0?oooooooooo01Wooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3oooooob_ooooo00?o
0000ooooooooool06_ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`005Oooool00onHV9So8B4Qonk^kP06
oooooh?o0000ZOooool00ol0003oooooooooo`0Kooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo083ooooo8?l00028ooooo`03o`000?oooooooooo01cooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0X?ooool9o`0007kooooo00?o0000oooooooo
ool07Oooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Yoooooa3o0000
K_ooool00ol0003oooooooooo`0Mooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0^Oooool6o`0006Oooooo00?o0000ooooooooool07_ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0;oooooo1_l0001Pooooo`03o`00
0?oooooooooo01oooooo000Nooooo`?o0000aOooool5o`0005_ooooo00?o0000ooooooooool07ooo
ool001kooooo00?o0000ooooooooool0b_ooool5o`0005Gooooo00?o0000ooooooooool08?ooool0
01kooooo00?o0000ooooooooool0coooool4o`00053ooooo00?o0000ooooooooool08Oooool001ko
oooo00?o0000ooooooooool0doooool4o`0004_ooooo00?o0000ooooooooool08_ooool001kooooo
00?o0000ooooooooool0eoooool4o`0004Oooooo00?o0000ooooooooool08_ooool001kooooo00?o
0000ooooooooool0foooool4o`0004;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000
ooooooooool0goooool4o`0003gooooo00?o0000ooooooooool09?ooool001kooooo0ol0003Soooo
o`?o0000>?ooool2o`0002Oooooo000Nooooo`03o`000?oooooooooo0>Kooooo1?l0000cooooo`03
o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo0>[ooooo0ol0000^ooooo`;o0000
:_ooool001kooooo00?o0000ooooooooool0kOooool4o`0002Wooooo00?o0000ooooooooool0:_oo
ool001kooooo00?o0000ooooooooool0lOooool3o`0002Cooooo0_l0000]ooooo`007_ooool00ol0
003oooooooooo`3dooooo`Co00007oooool00ol0003oooooooooo`0]ooooo`007_ooool3o`000?So
oooo1Ol0000Hooooo`;o0000<?ooool001kooooo00?o0000ooooooooool0oOooool3o`0000oooooo
1_l0000booooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo3ol0000hooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;o
oooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@
4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool0
08Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^ko
MgMgoa0@4?ooool6o`0000;ooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02_ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo07[ooooo0025
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^
k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`Ko00001Oooool00onYZJWo410@ooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00gooooo00?o410@o`000?nj^[X03_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000
o`000003o`0000gooooo00?o^[Zjob4Q8Oooool03_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo07kooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nHV9SooooookZj^_l000002oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0O_ooool008;ooooo1ol00004ooooo`;o
00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001m
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41199 L
.00942 .41197 L
.01441 .41195 L
.01585 .41194 L
.01721 .41194 L
.01842 .41194 L
.01975 .41193 L
.02105 .41193 L
.02227 .41193 L
.02355 .41193 L
.02494 .41193 L
.02622 .41193 L
.02744 .41193 L
.02854 .41193 L
.02973 .41194 L
.03245 .41194 L
.03535 .41195 L
.04057 .41198 L
.05251 .41205 L
.05838 .41208 L
.06095 .41209 L
.06377 .4121 L
.06631 .41211 L
.06753 .41211 L
.06868 .41212 L
.07 .41212 L
.07119 .41212 L
.07248 .41212 L
.0732 .41212 L
.07388 .41212 L
.07518 .41212 L
.0764 .41212 L
.07773 .41212 L
.07918 .41211 L
.08212 .41211 L
.08481 .4121 L
.09523 .41204 L
.10096 .41201 L
.10636 .41198 L
.1114 .41196 L
.11278 .41195 L
.11425 .41195 L
.11551 .41195 L
.11687 .41194 L
.1181 .41194 L
.11922 .41194 L
.12034 .41194 L
.12141 .41194 L
.12266 .41194 L
Mistroke
.12381 .41194 L
.12507 .41194 L
.12641 .41195 L
.12773 .41195 L
.12912 .41195 L
.13162 .41196 L
.13723 .41199 L
.14741 .41205 L
.15253 .41208 L
.15737 .41211 L
.16171 .41213 L
.16416 .41214 L
.16643 .41214 L
.16762 .41215 L
.16873 .41215 L
.16995 .41215 L
.17127 .41215 L
.17258 .41215 L
.17395 .41215 L
.17512 .41215 L
.17641 .41215 L
.17781 .41214 L
.17909 .41214 L
.18194 .41213 L
.18709 .41211 L
.19645 .41206 L
.20157 .41203 L
.20635 .41201 L
.20877 .412 L
.21001 .412 L
.21136 .412 L
.21213 .412 L
.21284 .41199 L
.2135 .41199 L
.21424 .41199 L
.21551 .41199 L
.21686 .41199 L
.21811 .41199 L
.21926 .41199 L
.22052 .412 L
.22185 .412 L
.22409 .412 L
.22654 .41201 L
.23201 .41204 L
.23785 .41208 L
.24839 .41217 L
.2536 .41221 L
.25913 .41224 L
.26201 .41226 L
.26519 .41227 L
Mistroke
.26658 .41228 L
.26807 .41228 L
.26938 .41228 L
.27078 .41229 L
.27151 .41229 L
.27218 .41229 L
.27349 .41229 L
.27422 .41229 L
.27501 .41229 L
.27575 .41229 L
.27644 .41229 L
.27769 .41229 L
.27906 .41229 L
.28049 .41228 L
.28182 .41228 L
.2867 .41227 L
.29193 .41225 L
.29711 .41224 L
.29973 .41223 L
.30122 .41223 L
.30262 .41223 L
.30336 .41223 L
.30414 .41222 L
.3048 .41222 L
.30553 .41222 L
.30631 .41222 L
.30715 .41222 L
.30794 .41223 L
.30866 .41223 L
.31004 .41223 L
.31082 .41223 L
.31153 .41223 L
.31425 .41224 L
.31677 .41225 L
.31914 .41227 L
.32451 .41231 L
.32975 .41236 L
.33538 .41243 L
.37874 .41293 L
.38924 .41299 L
.395 .41303 L
.40042 .41308 L
.40549 .41313 L
.41096 .41321 L
.42051 .4134 L
.4307 .41367 L
.44145 .41401 L
.46069 .41465 L
.4816 .41532 L
.50063 .41603 L
Mistroke
.51119 .41654 L
.52117 .41714 L
.54315 .4188 L
.58348 .42235 L
.62637 .4277 L
.66768 .43483 L
.70739 .4427 L
.74968 .45296 L
.79038 .46164 L
.81107 .46534 L
.822 .46703 L
.828 .46782 L
.83365 .46843 L
.8363 .46867 L
.8391 .46888 L
.84056 .46897 L
.84216 .46905 L
.84364 .46912 L
.84498 .46916 L
.8463 .4692 L
.84755 .46922 L
.84887 .46922 L
.84961 .46922 L
.8503 .46922 L
.85144 .46921 L
.85271 .46918 L
.85402 .46914 L
.85526 .46909 L
.85772 .46895 L
.8603 .46876 L
.86492 .46827 L
.86989 .46755 L
.87533 .46652 L
.88611 .46376 L
.89591 .46043 L
.90736 .45552 L
.91791 .44986 L
.93804 .43493 L
.94865 .42414 L
.95988 .41003 L
.99965 .34045 L
1 .33976 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooobkooooo00?o
0000ooooooooool05oooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooo
oooo01Oooooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hoooo
o`007_ooool3o`000?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003ooooo
ooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0oooo
ool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool0
0ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo00?o0000oooo
ooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_o
oooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_oo
ool3o`000?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`3o
ooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolXoooo
o`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003o
ooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool0
7_ooool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo000N
ooooo`?o0000oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo
0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobCo
oooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`00
0?oooooooooo027ooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3oooooob?ooooo00?o
0000ooooooooool08_ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooog[o0000Z_ooool00ol0003oooooooooo`0Sooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo07Oooooo8Ol00028ooooo`03o`000?oooooooooo02Cooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0V?oooolAo`0007Kooooo00?o0000oooooooo
ool09Oooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Yooooo`Wo0000
K?ooool00ol0003oooooooooo`0Vooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0/_ooool7o`0006Cooooo00?o0000ooooooooool09oooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0;Wooooo1_l0001Mooooo`03o`00
0?oooooooooo02Sooooo000Nooooo`?o0000_oooool7o`0005Gooooo00?o0000ooooooooool0:Ooo
ool001kooooo00?o0000ooooooooool0a_ooool5o`0004kooooo0_l0000/ooooo`007_ooool00ol0
003oooooooooo`3;ooooo`Co0000BOooool00ol0003oooooooooo`0/ooooo`007_ooool00ol0003o
ooooooooo`3?ooooo`Co0000A?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003ooooo
ooooo`3Cooooo`Co0000?oooool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003ooooooooo
o`3Gooooo`Go0000>Oooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003oooooooooo`3L
ooooo`Co0000<oooool2o`0003;ooooo000Nooooo`?o0000h?ooool5o`0002_ooooo0ol0000doooo
o`007_ooool00ol0003oooooooooo`3Uooooo`Ko00008oooool2o`0003Oooooo000Nooooo`03o`00
0?oooooooooo0>_ooooo1_l0000Kooooo`;o0000>Oooool001kooooo00?o0000ooooooooool0lOoo
ool5o`0001?ooooo0ol0000kooooo`007_ooool00ol0003oooooooooo`3fooooo`So00001?ooool7
o`0003kooooo000Nooooo`03o`000?oooooooooo0?gooooo1Ol00015ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h0
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooom8ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?oo
ool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3ooooo
odoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo
410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool0097ooooo0_l0000;ooooo`03o`00
0?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;7ooooo002Aooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:booooo`00Q_ooool0
1Ol@413o0000o`000?l0003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
0oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003o
ooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@21ooooo`00R?ooool00ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000_ooool6o`000006ooooool@413o^[ZjoooooomgMgOo<S8b1Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool0P?ooool008Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1oooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?oZJVYoa0@4?ooool03_ooool00omgMgOo
<S8booooo`20ooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`0POooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005
ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000=ooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool0Poooool008Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00Go410@oiRHV?oooooo^[Zjo`00
000<ooooo`03o`000?oooooooooo08?ooooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0001Cooooo00?o0000ooooooooool02oooool01OnYZJWo410@o`000?l@
413oZJVY00cooooo1?l00022ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .412 L
.00942 .41198 L
.01441 .41196 L
.01585 .41195 L
.01721 .41195 L
.01842 .41195 L
.01975 .41195 L
.02105 .41194 L
.02227 .41194 L
.02355 .41194 L
.02494 .41194 L
.02622 .41194 L
.02744 .41194 L
.02854 .41195 L
.02973 .41195 L
.03245 .41195 L
.03535 .41196 L
.04057 .41199 L
.05251 .41205 L
.05838 .41208 L
.06095 .41209 L
.06377 .4121 L
.06631 .41211 L
.06868 .41211 L
.07 .41211 L
.07119 .41211 L
.07257 .41211 L
.07388 .41211 L
.0752 .41211 L
.07586 .41211 L
.0766 .41211 L
.07789 .41211 L
.07911 .41211 L
.08185 .4121 L
.08481 .41209 L
.09478 .41205 L
.10544 .412 L
.10859 .41198 L
.11156 .41197 L
.11423 .41197 L
.11574 .41197 L
.11713 .41196 L
.11843 .41196 L
.11965 .41196 L
.12098 .41196 L
.12173 .41196 L
.12241 .41196 L
.12379 .41196 L
.12456 .41196 L
Mistroke
.12528 .41196 L
.1267 .41197 L
.12801 .41197 L
.13063 .41198 L
.13345 .41199 L
.13858 .41201 L
.14816 .41207 L
.15352 .4121 L
.15926 .41213 L
.16204 .41214 L
.16468 .41215 L
.16704 .41215 L
.16838 .41216 L
.16961 .41216 L
.17075 .41216 L
.17197 .41216 L
.17312 .41216 L
.17418 .41216 L
.17536 .41216 L
.17664 .41216 L
.17798 .41216 L
.17922 .41215 L
.18181 .41215 L
.18415 .41214 L
.18942 .41212 L
.19491 .4121 L
.20072 .41207 L
.20568 .41206 L
.20704 .41205 L
.2085 .41205 L
.20986 .41205 L
.21113 .41205 L
.21238 .41205 L
.21372 .41204 L
.21506 .41204 L
.21583 .41205 L
.21655 .41205 L
.21783 .41205 L
.21902 .41205 L
.22031 .41205 L
.22168 .41205 L
.22406 .41206 L
.22628 .41207 L
.23131 .4121 L
.24187 .41218 L
.25316 .41227 L
.25838 .41231 L
.2639 .41234 L
.26679 .41235 L
.26996 .41236 L
Mistroke
.27135 .41237 L
.27285 .41237 L
.27416 .41237 L
.27555 .41237 L
.27629 .41237 L
.27696 .41238 L
.27826 .41238 L
.27899 .41238 L
.27978 .41238 L
.28053 .41238 L
.28122 .41238 L
.28246 .41238 L
.28383 .41238 L
.28452 .41238 L
.28526 .41238 L
.2866 .41237 L
.2915 .41237 L
.29279 .41237 L
.29418 .41237 L
.2955 .41237 L
.2967 .41237 L
.29799 .41237 L
.29934 .41237 L
.30007 .41237 L
.30074 .41237 L
.30147 .41237 L
.30226 .41237 L
.30364 .41237 L
.30495 .41237 L
.3074 .41238 L
.30881 .41238 L
.3103 .41239 L
.31297 .4124 L
.31585 .41242 L
.31902 .41244 L
.32429 .41249 L
.32994 .41256 L
.34015 .41271 L
.38351 .4133 L
.39402 .41341 L
.39978 .41349 L
.40519 .41358 L
.41574 .4138 L
.42528 .41406 L
.46546 .41556 L
.48481 .41633 L
.50602 .41735 L
.52701 .41877 L
.54915 .42068 L
.59167 .42486 L
Mistroke
.6326 .43047 L
.6761 .43782 L
.71801 .44558 L
.75834 .45328 L
.77916 .45615 L
.78966 .45723 L
.79559 .45773 L
.80123 .45815 L
.80632 .45845 L
.809 .45859 L
.81187 .45871 L
.81452 .4588 L
.81692 .45886 L
.81807 .45889 L
.81933 .45891 L
.82051 .45892 L
.8216 .45892 L
.82287 .45892 L
.82423 .45892 L
.82551 .4589 L
.82668 .45888 L
.82805 .45885 L
.82955 .45881 L
.83226 .45869 L
.8351 .45852 L
.83811 .45829 L
.84352 .45771 L
.84865 .45696 L
.85335 .45608 L
.86396 .45338 L
.8733 .45013 L
.88315 .44582 L
.90387 .43376 L
.92315 .41851 L
.94462 .3951 L
.96413 .36587 L
1 .29427 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003ooooo
ooooo`0Gooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool0
6?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool000Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo;?ooool0
0ol0003oooooooooo`0Iooooo`001oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0003oooooobcooooo00?o0000ooooooooool06Oooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0ooooool[oooo
o`03o`000?oooooooooo01[ooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool06_ooool000Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
:_ooool00ol0003oooooooooo`0Kooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000
ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`?o0000oooooolYoooo
o`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003o
ooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool0
7Oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000N
ooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0
003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo0ol0003oooooobKo
oooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`00
0?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003ooooooooo
o`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool0
01kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo027ooooo000Nooooo`03
o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003ooooo
ooooo`3oooooob?ooooo00?o0000ooooooooool08_ooool001kooooo0ol0003oooooob;ooooo00?o
0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooo
oooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Toooo
o`007_ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo
00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oo
oooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool3o`000?oooooo7_ooool0
0ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo00?o0000oooo
ooooool0:?ooool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02So
oooo000Nooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0oooooolKooooo`03o`000?oooooooooo02[ooooo000D
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3ooooooa[ooooo00?o
0000ooooooooool0:oooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooom`o`000:_ooooo00?o0000
ooooooooool0;?ooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`1]oooo
obSo0000P_ooool00ol0003oooooooooo`0]ooooo`005oooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo09Gooooo3Ol0001cooooo`;o0000<?ooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Rooooo`[o0000J?ooool00ol0003oooooooooo`0`ooooo`005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0[?ooool9o`0005kooooo
00?o0000ooooooooool0<Oooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo0;Gooooo1_l0001Gooooo`03o`000?oooooooooo03;ooooo000Nooooo`?o0000^ooo
ool7o`0004oooooo00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0`_ooool7
o`0004Kooooo0_l0000fooooo`007_ooool00ol0003oooooooooo`39ooooo`Ko0000?Oooool3o`00
03Sooooo000Nooooo`03o`000?oooooooooo0<oooooo1_l0000eooooo`;o0000>oooool001kooooo
00?o0000ooooooooool0eOooool5o`0002kooooo0_l0000mooooo`007_ooool00ol0003ooooooooo
o`3Jooooo`Co0000:Oooool00ol0003oooooooooo`0mooooo`007_ooool00ol0003oooooooooo`3N
ooooo`Co00008oooool2o`00043ooooo000Nooooo`?o0000h_ooool6o`0001[ooooo0ol00012oooo
o`007_ooool00ol0003oooooooooo`3Xoooooa[o0000AOooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h0
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooom8ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?oo
ool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3ooooo
odoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo
410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool008gooooo0_l0000;ooooo`03o`00
0?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;Cooooo002=ooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:eooooo`00Poooool0
1Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l0
0002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`00
0?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wo
oooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@
4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<
c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00Go410@okZj
^_ooooooMgMgoc8b<P05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;o
oooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oM
gMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool0
0ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?oZJVYoa0@4?ooool03Oooool0
0olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03oa0@4?l0003o
^[Zj00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07cooooo0022
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oo
oooooooo017ooooo00?o410@o`000?l000000ol0000=ooooo`03okZj^_lQ8B7ooooo00gooooo00?o
ZJVYogMgMoooool00oooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol@413oV9RHoooo
oonj^[[o000000_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo07ko
oooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Gooooo
00?o0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00_ooooo1Ol00004ooooo`Co
0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .412 L
.00942 .41199 L
.01441 .41197 L
.01585 .41197 L
.01721 .41197 L
.01842 .41196 L
.01975 .41196 L
.02105 .41196 L
.02227 .41196 L
.02355 .41196 L
.02494 .41196 L
.02622 .41196 L
.02744 .41196 L
.02854 .41196 L
.02973 .41197 L
.03245 .41197 L
.03535 .41198 L
.04057 .412 L
.05251 .41205 L
.05838 .41207 L
.06095 .41208 L
.06377 .41209 L
.06631 .4121 L
.06868 .4121 L
.07 .4121 L
.07119 .4121 L
.07257 .41211 L
.07388 .41211 L
.0752 .41211 L
.07586 .41211 L
.0766 .4121 L
.07789 .4121 L
.07911 .4121 L
.08054 .4121 L
.08185 .4121 L
.08481 .41209 L
.09523 .41206 L
.10096 .41203 L
.10636 .41201 L
.10881 .41201 L
.1114 .412 L
.11276 .412 L
.11425 .412 L
.1156 .41199 L
.11687 .41199 L
.1181 .41199 L
.11927 .41199 L
.12032 .41199 L
.12147 .41199 L
Mistroke
.12271 .41199 L
.12404 .41199 L
.12528 .412 L
.12641 .412 L
.12893 .412 L
.13158 .41201 L
.13632 .41203 L
.14703 .41208 L
.15225 .41211 L
.15718 .41213 L
.16199 .41215 L
.16643 .41217 L
.16875 .41217 L
.16992 .41217 L
.17121 .41218 L
.1725 .41218 L
.17323 .41218 L
.17389 .41218 L
.17512 .41218 L
.17641 .41218 L
.17769 .41218 L
.17905 .41218 L
.18034 .41218 L
.18151 .41217 L
.18438 .41217 L
.18709 .41216 L
.19627 .41214 L
.20113 .41213 L
.20386 .41212 L
.20635 .41212 L
.20765 .41212 L
.20839 .41212 L
.20907 .41212 L
.21032 .41212 L
.21164 .41212 L
.21286 .41212 L
.21399 .41212 L
.21524 .41212 L
.21659 .41212 L
.2179 .41212 L
.21934 .41213 L
.22223 .41214 L
.22741 .41216 L
.23226 .41219 L
.23745 .41223 L
.2468 .4123 L
.25754 .41239 L
.26319 .41242 L
.26918 .41246 L
.27442 .41248 L
Mistroke
.28019 .4125 L
.28543 .41251 L
.29034 .41252 L
.29555 .41253 L
.29831 .41254 L
.30125 .41255 L
.30662 .41257 L
.31161 .4126 L
.31687 .41265 L
.32182 .4127 L
.33107 .41282 L
.37157 .41351 L
.39211 .41383 L
.40299 .41404 L
.41464 .41433 L
.4361 .41508 L
.45612 .41594 L
.47694 .41688 L
.49957 .41804 L
.52132 .41952 L
.54143 .42125 L
.58268 .42532 L
.62234 .43023 L
.66458 .43667 L
.70522 .44277 L
.72586 .44589 L
.73678 .44743 L
.74844 .44887 L
.75425 .44947 L
.75974 .44995 L
.76508 .45033 L
.77001 .45061 L
.77468 .4508 L
.77704 .45087 L
.77963 .45093 L
.78099 .45095 L
.78223 .45097 L
.78292 .45098 L
.78366 .45098 L
.78502 .45099 L
.78629 .45098 L
.78764 .45098 L
.78891 .45097 L
.79006 .45095 L
.79133 .45093 L
.79252 .45091 L
.7952 .45083 L
.79782 .45074 L
.80063 .45062 L
.80571 .45032 L
Mistroke
.81033 .44997 L
.81572 .44945 L
.82157 .44873 L
.83221 .44693 L
.84211 .44458 L
.85303 .44107 L
.86443 .43623 L
.87511 .43054 L
.89636 .41582 L
.9158 .39827 L
.93573 .37532 L
.95748 .34266 L
1 .25611 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool0
ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`?o0000ooooool]ooooo`03o`000?oo
oooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0I
ooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001ko
oooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003ooooooooo
o`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZ
ooooo`03o`000?oooooooooo01_ooooo000Nooooo`?o0000oooooolYooooo`03o`000?oooooooooo
01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`00
7_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool000Gooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01gooooo0007ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooo
oolWooooo`03o`000?oooooooooo01kooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool0
00Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolVoooo
o`03o`000?oooooooooo01oooooo0007ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Ooooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolUooooo`03o`000?oooooooooo023ooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000ooooooooool0
8?ooool000Gooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolTooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool0
0ol0003oooooooooo`0Qooooo`007_ooool3o`000?oooooo8oooool00ol0003oooooooooo`0Roooo
o`007_ooool00ol0003oooooooooo`3oooooob?ooooo00?o0000ooooooooool08_ooool001kooooo
00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo8_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`3o
ooooob7ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool0oooooolQoooo
o`03o`000?oooooooooo02Cooooo000Nooooo`?o0000oooooolPooooo`03o`000?oooooooooo02Go
oooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_oo
ool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000
ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3ooooooaco
oooo00?o0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolLooooo`03o`00
0?oooooooooo02Wooooo000Nooooo`?o0000oooooolKooooo`03o`000?oooooooooo02[ooooo000N
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0
003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool001kooooo00?o0000oooooooo
ool0oooooolIooooo`03o`000?oooooooooo02cooooo000Nooooo`03o`000?oooooooooo0?oooooo
6?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3ooooooaOooooo00?o
0000ooooooooool0;_ooool001kooooo0ol0003ooooooaKooooo00?o0000ooooooooool0;oooool0
01kooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo033ooooo000Nooooo`03
o`000?oooooooooo0?oooooo4oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo0?oooooo
4_ooool00ol0003oooooooooo`0cooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0oooo
oolAooooo`03o`000?oooooooooo03Cooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0=Oooool001Gooooo00?oV9RH
ob4Q8Oo^k^h01_oooom/o`000:Gooooo00?o0000ooooooooool0=_ooool001Kooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`1Yooooob?o0000P?ooool2o`0003Wooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0S?oooolDo`0006_ooooo00?o0000oooooooo
ool0>Oooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Pooooo`Wo0000
HOooool00ol0003oooooooooo`0jooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0ZOooool9o`0005Oooooo00?o0000ooooooooool0>oooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0;;ooooo1_l0001@ooooo`03o`00
0?oooooooooo03cooooo000Nooooo`?o0000^?ooool6o`0004Sooooo0_l0000oooooo`007_ooool0
0ol0003oooooooooo`2nooooo`Oo0000@?ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0
003oooooooooo`35ooooo`Ko0000=oooool3o`0004;ooooo000Nooooo`03o`000?oooooooooo0<_o
oooo1_l0000^ooooo`?o0000AOooool001kooooo00?o0000ooooooooool0dOooool<o`0001oooooo
0ol00018ooooo`007_ooool00ol0003oooooooooo`3Mooooo`Go00005?ooool6o`0004_ooooo000N
ooooo`03o`000?oooooooooo0>;ooooo5?l0001Aooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003o
ooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool0
0ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Co
oooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooom@ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo0_l000000ol@
413oooooooooo`03ooooo`;o8B4QQoooool008cooooo00?o0000ooooooooool01_ooool02_l0003o
ooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B67ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool5o`0008kooooo002<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Ko000000GoooooodA4
A?oMgMgoooooo`00002?ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02oooool01?oMgMgoEEEEooooool0002?ooooo`00ROooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
4?ooool00ol@413o0000o`000003o`0000_ooooo00?oMgMgolc<c?l00000Soooool008Wooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo
00?ok^k^odA4A?l00000Soooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003ooooooooo
o`05ooooo`;o00005?ooool00ol0003oooooooooo`0=ooooo`03ogMgMol0003ooooo08kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41201 L
.00942 .412 L
.01199 .41199 L
.01441 .41199 L
.01575 .41199 L
.01721 .41199 L
.01853 .41198 L
.01975 .41198 L
.02094 .41198 L
.02223 .41198 L
.02345 .41198 L
.02456 .41198 L
.02586 .41198 L
.02659 .41198 L
.02727 .41198 L
.02985 .41199 L
.03125 .41199 L
.03257 .41199 L
.03504 .412 L
.04057 .41201 L
.0509 .41205 L
.05655 .41206 L
.06182 .41208 L
.06481 .41208 L
.06753 .41209 L
.06898 .41209 L
.07055 .41209 L
.07142 .41209 L
.07222 .41209 L
.07298 .4121 L
.07379 .4121 L
.07509 .4121 L
.07582 .4121 L
.07649 .4121 L
.07773 .4121 L
.07903 .4121 L
.07972 .41209 L
.08046 .41209 L
.08179 .41209 L
.08481 .41209 L
.09496 .41207 L
.10052 .41206 L
.10572 .41204 L
.10865 .41204 L
.11133 .41204 L
.11286 .41203 L
.11356 .41203 L
.11431 .41203 L
.1151 .41203 L
Mistroke
.11584 .41203 L
.11672 .41203 L
.11751 .41203 L
.11819 .41203 L
.11891 .41203 L
.1202 .41203 L
.12159 .41203 L
.12311 .41204 L
.12584 .41204 L
.12838 .41205 L
.13383 .41206 L
.13899 .41208 L
.14866 .41212 L
.15919 .41217 L
.1645 .41218 L
.16756 .41219 L
.17036 .4122 L
.1729 .4122 L
.17557 .4122 L
.17696 .41221 L
.17825 .41221 L
.17898 .41221 L
.17966 .41221 L
.18045 .41221 L
.18117 .41221 L
.1824 .41221 L
.18371 .41221 L
.18482 .41221 L
.18604 .41221 L
.18735 .41221 L
.18876 .41221 L
.19131 .41221 L
.1938 .4122 L
.1965 .4122 L
.19774 .4122 L
.19906 .4122 L
.20019 .4122 L
.20143 .4122 L
.20262 .4122 L
.20372 .4122 L
.20492 .4122 L
.20619 .4122 L
.2073 .4122 L
.20833 .4122 L
.21066 .41221 L
.21342 .41221 L
.21595 .41222 L
.22169 .41224 L
.22676 .41226 L
.23212 .4123 L
Mistroke
.25163 .41245 L
.29137 .4127 L
.30183 .41277 L
.31177 .41285 L
.32322 .41299 L
.3337 .41316 L
.37382 .41394 L
.39622 .41442 L
.41652 .415 L
.43769 .41583 L
.45763 .41677 L
.49813 .41896 L
.51908 .42044 L
.5412 .42235 L
.58109 .42628 L
.62356 .43125 L
.66443 .43664 L
.68525 .43914 L
.70788 .44159 L
.71843 .44262 L
.72963 .44358 L
.73919 .44422 L
.74463 .4445 L
.74728 .4446 L
.74974 .44468 L
.75213 .44474 L
.75346 .44477 L
.75468 .44478 L
.75601 .4448 L
.75676 .4448 L
.75745 .44481 L
.75873 .44481 L
.76008 .44481 L
.76137 .4448 L
.76275 .44478 L
.76406 .44476 L
.76525 .44473 L
.76818 .44465 L
.77095 .44454 L
.77578 .44427 L
.78025 .44395 L
.79038 .44293 L
.79574 .44222 L
.80152 .44132 L
.81199 .4393 L
.82218 .43679 L
.83155 .43392 L
.85137 .42567 L
.86261 .41945 L
.87308 .41254 L
Mistroke
.91401 .37499 L
.93637 .34654 L
.95752 .31303 L
.99784 .2323 L
1 .22764 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooobkooooo00?o0000oooooooo
ool05oooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo
000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool0
0ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool001kooooo00?o0000oooo
ooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?oo
oooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`000?oooooo:oooool00ol0003ooooo
ooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool06_oo
ool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Noooo
o`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003o
ooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0
oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`?o0000oooooolXooooo`03o`000?oo
oooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0M
ooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool001ko
oooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`00
0?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003ooooooooo
o`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolU
ooooo`03o`000?oooooooooo023ooooo000Nooooo`?o0000oooooolUooooo`03o`000?oooooooooo
023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`00
7_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool000Gooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo0007ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooo
oolSooooo`03o`000?oooooooooo02;ooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool0
00Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolRoooo
o`03o`000?oooooooooo02?ooooo0007ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Toooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolQooooo`03o`000?oooooooooo02Cooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0
9Oooool000Gooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolOooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool0
0ol0003oooooooooo`0Vooooo`007_ooool3o`000?oooooo7_ooool00ol0003oooooooooo`0Woooo
o`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool001kooooo
00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oo
oooooooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`007_ooool00ol0003oooooooooo`3o
oooooacooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolKoooo
o`03o`000?oooooooooo02[ooooo000Nooooo`?o0000oooooolKooooo`03o`000?oooooooooo02[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_oo
ool00ol0003oooooooooo`3ooooooaWooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000
ooooooooool0oooooolHooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`000?oooooooooo
0?oooooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3ooooooaOo
oooo00?o0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolFooooo`03o`00
0?oooooooooo02oooooo000Nooooo`?o0000oooooolEooooo`03o`000?oooooooooo033ooooo000N
ooooo`03o`000?oooooooooo0?oooooo4oooool2o`0003?ooooo000Nooooo`03o`000?oooooooooo
0?oooooo4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa7o
oooo00?o0000ooooooooool0=?ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`03o`00
0?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003ooooooooo
o`0fooooo`007_ooool3o`000?oooooo3Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003oooooooooo`3oooooo`_o
oooo00?o0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0ooooool:ooooo`03o`00
0?oooooooooo03_ooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3oooooo`Wooooo00?o
0000ooooooooool0??ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?oooooo2?ooool00ol0003oooooooooo`0mooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooofGo0000Xoooool2o`00043ooooo000Fooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooo
ooooool0H_oooolTo`0007kooooo00?o0000ooooooooool0@?ooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`26oooooa?o0000JOooool2o`0004?ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0VOooool=o`0005_ooooo00?o0000ooooooooool0
@oooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0:Kooooo
1_l0001Cooooo`;o0000A_ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo0:cooooo2_l00017ooooo`;o0000B?ooool001kooooo0ol0002fooooo`Wo0000??oo
ool2o`0004[ooooo000Nooooo`03o`000?oooooooooo0;oooooo1_l0000dooooo`;o0000C?ooool0
01kooooo00?o0000ooooooooool0aOooool=o`00027ooooo1_l0001>ooooo`007_ooool00ol0003o
ooooooooo`3Booooo`So00005?ooool5o`0005Cooooo000Nooooo`03o`000?oooooooooo0=[ooooo
5?l0001Iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooo
odSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool008gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0;Cooooo002=ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Cooooo0_lb<S:eooooo`00Poooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo0_l000000ol@413oooooooooo`03ooooo`;o
8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@1looooo`00QOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2
ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oo
oooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo1Ol0000<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool0N_ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`04odA4A?oMgMgooooo
o`0000kooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool0
1?oMgMgoEEEEooooool0000?ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c01looooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o0000
1?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00002oooool00omgMgOoc<c<
o`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool008;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
00?ok^k^odA4A?l000003?ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool0O_ooool008;ooooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o0000
5Oooool00ol0003oooooooooo`0=ooooo`03ogMgMol0003ooooo00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00488 .41202 L
.00942 .41201 L
.01204 .41201 L
.01441 .41201 L
.01573 .41201 L
.01647 .41201 L
.01716 .41201 L
.01841 .41201 L
.01975 .41201 L
.02104 .41201 L
.02221 .41201 L
.02357 .41201 L
.02486 .41201 L
.02715 .41201 L
.02966 .41201 L
.03239 .41202 L
.03531 .41202 L
.04057 .41203 L
.05151 .41205 L
.05727 .41206 L
.06335 .41208 L
.06868 .41208 L
.0717 .41209 L
.07315 .41209 L
.07453 .41209 L
.07577 .41209 L
.07712 .41209 L
.07835 .41209 L
.07949 .41209 L
.08071 .41209 L
.08207 .41209 L
.08275 .41209 L
.08348 .41209 L
.08481 .41209 L
.08614 .41209 L
.08755 .41209 L
.09011 .41209 L
.0959 .41208 L
.09879 .41208 L
.10191 .41208 L
.10335 .41208 L
.10486 .41208 L
.10616 .41208 L
.1069 .41208 L
.10759 .41208 L
.10826 .41208 L
.109 .41208 L
.11034 .41208 L
.11165 .41208 L
Mistroke
.11286 .41208 L
.1143 .41208 L
.11561 .41208 L
.11853 .41209 L
.12099 .41209 L
.12365 .41209 L
.12847 .4121 L
.13848 .41213 L
.14945 .41216 L
.17158 .41223 L
.19382 .41228 L
.19893 .41229 L
.20435 .4123 L
.21408 .41233 L
.21887 .41235 L
.22415 .41238 L
.2351 .41245 L
.25499 .41261 L
.27705 .4128 L
.29726 .41298 L
.31708 .41322 L
.33793 .41358 L
.378 .41448 L
.40036 .41509 L
.42064 .4158 L
.4617 .41773 L
.50373 .42027 L
.54418 .42354 L
.5872 .42765 L
.62862 .43205 L
.66846 .43614 L
.68892 .43778 L
.70032 .4385 L
.71087 .43902 L
.71604 .43921 L
.72154 .43937 L
.72438 .43943 L
.72568 .43945 L
.72705 .43946 L
.72778 .43947 L
.72858 .43948 L
.72932 .43948 L
.72999 .43949 L
.73078 .43949 L
.73162 .43949 L
.73241 .43949 L
.73315 .43949 L
.73437 .43949 L
.73571 .43947 L
.73638 .43947 L
Mistroke
.73711 .43946 L
.73842 .43944 L
.74096 .43939 L
.74328 .43932 L
.74597 .43922 L
.74891 .43909 L
.75427 .43878 L
.75985 .43834 L
.76511 .43782 L
.77494 .43655 L
.78552 .43471 L
.79697 .43214 L
.81792 .42568 L
.82847 .42142 L
.84004 .41586 L
.86054 .40336 L
.88251 .38579 L
.92596 .33744 L
.96782 .27189 L
1 .21064 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooobgooooo00?o0000
ooooooooool06?ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo
01Wooooo000Nooooo`?o0000ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`00
0?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003ooooooooo
o`3oooooob_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0oooooolZ
ooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0
003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000oooooooo
ool07?ooool001kooooo0ol0003oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o
0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooo
oooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3ooooo
obOooooo00?o0000ooooooooool07_ooool001kooooo00?o0000ooooooooool0oooooolVooooo`03
o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003ooooo
ooooo`0Oooooo`007_ooool3o`000?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool0
0ol0003oooooooooo`3oooooobGooooo00?o0000ooooooooool08?ooool001kooooo00?o0000oooo
ooooool0oooooolTooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3oooooob?ooooo
00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0S
ooooo`007_ooool3o`000?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003o
ooooooooo`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0
oooooolPooooo`03o`000?oooooooooo02Gooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
7oooool00ol0003oooooooooo`0Vooooo`001oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003ooooooooo
o`0Wooooo`001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?oooooo7Oooool00ol0003oooooooooo`0Xoooo
o`001oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool000Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003o
ooooooooo`0Yooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolKooooo`03o`000?oooooooooo02[ooooo0005ooooo`03oeEEEOmV
IVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo6oooool00ol0003ooooooooo
o`0Zooooo`007_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool0
01kooooo0ol0003ooooooaWooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000oooooooo
ool0oooooolIooooo`03o`000?oooooooooo02cooooo000Nooooo`03o`000?oooooooooo0?oooooo
6?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3ooooooaOooooo00?o
0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolGooooo`03o`000?oooooo
oooo02kooooo000Nooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0_oooo
o`007_ooool3o`000?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_ooool00ol0003ooooo
ooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool001kooooo00?o0000ooooooooool0oooo
oolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo4_ooool0
0ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000oooo
ooooool0=?ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo03Go
oooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0fooooo`007_oo
ool3o`000?oooooo3_ooool00ol0003oooooooooo`0gooooo`007_ooool00ol0003oooooooooo`3o
ooooo`gooooo00?o0000ooooooooool0>?ooool001kooooo00?o0000ooooooooool0ooooool<oooo
o`03o`000?oooooooooo03Wooooo000Nooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003o
ooooooooo`0jooooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0
>oooool001kooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo03cooooo000N
ooooo`?o0000ooooool8ooooo`03o`000?oooooooooo03gooooo000Nooooo`03o`000?oooooooooo
0?oooooo1oooool00ol0003oooooooooo`0nooooo`007_ooool00ol0003oooooooooo`3oooooo`Ko
oooo00?o0000ooooooooool0?oooool001kooooo00?o0000ooooooooool0ooooool5ooooo`03o`00
0?oooooooooo043ooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3oooooo`?ooooo0_l0
0013ooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooo
ool3o`0004Gooooo000Eooooo`03oiRHV?lQ8B7ok^k^00KoooooGol0002Qooooo`;o0000B?ooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`1LooooobSo0000Moooool2o`00
04[ooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0Q?ooool=o`0006Wo
oooo00?o0000ooooooooool0B_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`2Aooooo`go0000F_ooool2o`0004gooooo000Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
1Oooool00ol0003oooooooooo`2Nooooo`go0000BOooool4o`0004oooooo000Dooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`2[ooooo`co0000>_ooool3o`0005?ooooo
000Nooooo`?o0000]oooool9o`0002kooooo0ol0001Fooooo`007_ooool00ol0003oooooooooo`30
ooooo`Ko00009Oooool3o`0005Wooooo000Nooooo`03o`000?oooooooooo0<Kooooo4ol00005oooo
o`go0000G?ooool001kooooo00?o0000ooooooooool0fOooool5o`0006Wooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;o
oooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02oooool2o`000003oa0@4?oooooooooo
00?ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0POooool008Sooooo00?o0000oooo
ooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo083ooooo0028oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`Go00004?ooool00ol0003oooooooooo`1oooooo`00R?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`000005oooooom4A4Co
gMgMooooool000004?ooool00omgMgOo<S8booooo`20ooooo`00R?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool01?oMgMgoEEEEoooo
ool0000=ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0POooool008Gooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`00
0?l000000ol0000;ooooo`03ogMgMoo<c<co000000gooooo00?o0000ooooooooool0Poooool008Go
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00cooooo00?ok^k^odA4A?l000003Oooool00ol0003oooooooooo`23ooooo`00QOooool7o`0000Go
oooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oooooooooo00go
oooo00?oMgMgo`000?ooool03?ooool4o`0008;ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41205 L
.06168 .41207 L
.08481 .4121 L
.10632 .41213 L
.12636 .41216 L
.1478 .41221 L
.1673 .41227 L
.18741 .41234 L
.20923 .41245 L
.23006 .41257 L
.25214 .41274 L
.29187 .41317 L
.31224 .41347 L
.33417 .41387 L
.35486 .41432 L
.37745 .41493 L
.41915 .41639 L
.46182 .41844 L
.50291 .42101 L
.54657 .42437 L
.58864 .42805 L
.62912 .43158 L
.64964 .43313 L
.66052 .43384 L
.67217 .43447 L
.67793 .43472 L
.68339 .43491 L
.68829 .43505 L
.69082 .43511 L
.69362 .43516 L
.69487 .43518 L
.69622 .4352 L
.69738 .43521 L
.69866 .43522 L
.70002 .43522 L
.70076 .43523 L
.70145 .43523 L
.70269 .43523 L
.70401 .43522 L
.70526 .43522 L
.70661 .43521 L
.70788 .43519 L
.70906 .43518 L
.71128 .43514 L
.71364 .43509 L
.71881 .43493 L
.72354 .43472 L
.729 .43441 L
.73419 .43404 L
Mistroke
.74339 .43318 L
.75342 .43192 L
.76428 .43014 L
.77411 .42811 L
.79615 .42192 L
.8164 .41391 L
.83827 .40236 L
.85925 .38809 L
.88138 .36932 L
.92131 .32521 L
.96381 .26469 L
1 .20616 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`00
5oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003ooooo
ooooo`0Hooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;?oo
ool00ol0003oooooooooo`0Iooooo`005Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooo
oooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3ooooo
ob_ooooo00?o0000ooooooooool06_ooool001kooooo0ol0003oooooob[ooooo00?o0000oooooooo
ool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo
000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool0
0ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000oooo
ooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oo
oooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool3o`000?oooooo9oooool00ol0003ooooo
ooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07ooo
ool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Noooo
o`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003o
ooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0
oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`?o0000oooooolSooooo`03o`000?oo
oooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0S
ooooo`007_ooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool001ko
oooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`00
0?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003ooooooooo
o`3ooooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolO
ooooo`03o`000?oooooooooo02Kooooo000Nooooo`?o0000oooooolNooooo`03o`000?oooooooooo
02Oooooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`00
7_ooool00ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool000Gooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolLooooo`03o`000?oooooooooo02Wooooo0007ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooo
oolKooooo`03o`000?oooooooooo02[ooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool0
00Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolJoooo
o`03o`000?oooooooooo02_ooooo0007ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003oooooooooo`0/oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolHooooo`03o`000?oooooooooo02gooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0
;Oooool000Gooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolGooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo0?oooooo5_ooool0
0ol0003oooooooooo`0_ooooo`007_ooool3o`000?oooooo5_ooool00ol0003oooooooooo`0_oooo
o`007_ooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool0<?ooool001kooooo
00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo037ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo4oooool00ol0003oooooooooo`0booooo`007_ooool00ol0003oooooooooo`3o
oooooa;ooooo00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0oooooolAoooo
o`03o`000?oooooooooo03Cooooo000Nooooo`?o0000ooooool@ooooo`03o`000?oooooooooo03Go
oooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0fooooo`007_oo
ool00ol0003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0=oooool001kooooo00?o0000
ooooooooool0ooooool=ooooo`03o`000?oooooooooo03Sooooo000Nooooo`03o`000?oooooooooo
0?oooooo3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003oooooooooo`3oooooo`_o
oooo00?o0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0ooooool9ooooo`;o0000
?Oooool001kooooo0ol0003oooooo`Sooooo00?o0000ooooooooool0?Oooool001kooooo00?o0000
ooooooooool0ooooool7ooooo`03o`000?oooooooooo03kooooo000Nooooo`03o`000?oooooooooo
0?oooooo1_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`3oooooo`Go
oooo00?o0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0ooooool4ooooo`03o`00
0?oooooooooo047ooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0004Cooooo000N
ooooo`?o0000ooooool1ooooo`03o`000?oooooooooo04Cooooo000Nooooo`03o`000?oooooooooo
0?kooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo04Oo
oooo000Nooooo`03o`000?oooooooooo0?_ooooo0_l0001:ooooo`005?ooool5o`0000Gooooo00?o
0000ooooooooool0nOooool2o`0004cooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool00ol0003oooooooooo`3hooooo`03o`000?oooooooooo04cooooo000Eooooo`03oiRHV?lQ8B7o
k^k^00KoooooE?l0002Uooooo`;o0000Coooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0
003oooooooooo`1AooooobOo0000O?ooool2o`00057ooooo000Gooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0N?oooolIo`00063ooooo0ol0001Cooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo097ooooo3Ol0001?ooooo`Co0000E_ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo09kooooo3Ol0000oooooo`?o0000
F_ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0:_ooooo
3?l0000`ooooo`?o0000GOooool001kooooo0ol0002gooooo`[o00008?ooool6o`00063ooooo000N
ooooo`03o`000?oooooooooo0<7ooooo8?l0001Vooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooo
odSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool008gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0;Cooooo002=ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Cooooo0_lb<S:eooooo`00Poooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo0_l000000ol@413oooooooooo`03ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000ooo
ool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMg
oa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool5o`0000gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00CoA4A4omgMgOoo
oooo00003oooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`04omgMgOmEEEGoooooo`0000oooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<07cooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol0
0004ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000;ooooo`03ogMgMoo<
c<co000000oooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1nooooo`00P_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?oo
ool00oo^k^koA4A4o`00000<ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooo
ooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0
000Eooooo`03o`000?oooooooooo00gooooo00?oMgMgo`000?ooool02oooool5o`0000Cooooo1?l0
001mooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41205 L
.01483 .41206 L
.01975 .41207 L
.02225 .41207 L
.02496 .41207 L
.02644 .41207 L
.02782 .41208 L
.02922 .41208 L
.03053 .41208 L
.03164 .41208 L
.03285 .41208 L
.03418 .41208 L
.0354 .41208 L
.03667 .41208 L
.03805 .41208 L
.03935 .41208 L
.04057 .41208 L
.04586 .41208 L
.04865 .41207 L
.05159 .41207 L
.05417 .41207 L
.05488 .41207 L
.05564 .41207 L
.057 .41207 L
.05834 .41207 L
.05961 .41207 L
.06074 .41207 L
.06198 .41207 L
.06272 .41207 L
.06341 .41207 L
.065 .41207 L
.06654 .41208 L
.0682 .41208 L
.0712 .41208 L
.07395 .41208 L
.07924 .41209 L
.08481 .41211 L
.10577 .41218 L
.11491 .41221 L
.12482 .41224 L
.13541 .41226 L
.14541 .41227 L
.15097 .41228 L
.15686 .41229 L
.16188 .41231 L
.16741 .41233 L
.17808 .41238 L
.18783 .41244 L
.20977 .4126 L
Mistroke
.23143 .41276 L
.25152 .41292 L
.27097 .41313 L
.29167 .41344 L
.33539 .41428 L
.35734 .41479 L
.37752 .41539 L
.41805 .41695 L
.45957 .41891 L
.49949 .42139 L
.54199 .42435 L
.5829 .4274 L
.60374 .42891 L
.62638 .43028 L
.63695 .43078 L
.64816 .4312 L
.65773 .43148 L
.66035 .43154 L
.66317 .43159 L
.66585 .43164 L
.66828 .43167 L
.6708 .43169 L
.67219 .4317 L
.6735 .43171 L
.67471 .43171 L
.67583 .43171 L
.67706 .43171 L
.67835 .43171 L
.67966 .4317 L
.68039 .4317 L
.68106 .43169 L
.6836 .43166 L
.68501 .43164 L
.68655 .43162 L
.68936 .43156 L
.69494 .43139 L
.69776 .43128 L
.70087 .43113 L
.70606 .43083 L
.71153 .43044 L
.72211 .42944 L
.73182 .42823 L
.7424 .42656 L
.75371 .42436 L
.77441 .41909 L
.79369 .41247 L
.81607 .40222 L
.83723 .38977 L
.87758 .3584 L
.92051 .31354 L
Mistroke
.96185 .26216 L
1 .21447 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool^ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Noooo
o`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`000?oo
oooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo
00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oo
oooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0L
ooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001ko
oooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`?o0000
oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9_oo
ool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000
ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo
027ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`00
7_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0
003oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolQ
ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0
003oooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo00?o0000oooooooo
ool09_ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo
000Nooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool0
0ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool001kooooo0ol0003ooooo
oacooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolKooooo`03
o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003ooooo
ooooo`0[ooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0
:oooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3ooooooaWooooo00?o0000ooooooooool0;?ooool000Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo6?ooool0
0ol0003oooooooooo`0]ooooo`001oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0003ooooooaOooooo00?o0000ooooooooool0;_ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFoooo
o`03o`000?oooooooooo02oooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0;oooool000Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
5Oooool00ol0003oooooooooo`0`ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool001kooooo00?o0000
ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`?o0000oooooolBoooo
o`03o`000?oooooooooo03?ooooo000Nooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003o
ooooooooo`0dooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0
=Oooool001kooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo03Kooooo000N
ooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`0gooooo`007_ooool00ol0
003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0>?ooool001kooooo0ol0003oooooo`co
oooo00?o0000ooooooooool0>Oooool001kooooo00?o0000ooooooooool0ooooool;ooooo`03o`00
0?oooooooooo03[ooooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003ooooooooo
o`0kooooo`007_ooool00ol0003oooooooooo`3oooooo`Sooooo0_l0000nooooo`007_ooool00ol0
003oooooooooo`3oooooo`Oooooo00?o0000ooooooooool0?_ooool001kooooo00?o0000oooooooo
ool0ooooool5ooooo`;o0000@Oooool001kooooo00?o0000ooooooooool0ooooool4ooooo`03o`00
0?oooooooooo047ooooo000Nooooo`?o0000ooooool2ooooo`;o0000A?ooool001kooooo00?o0000
ooooooooool0ooooool1ooooo`03o`000?oooooooooo04Cooooo000Nooooo`03o`000?oooooooooo
0?oooooo00?o0000ooooooooool0AOooool001kooooo00?o0000ooooooooool0oOooool2o`0004So
oooo000Nooooo`03o`000?oooooooooo0?cooooo00?o0000ooooooooool0B?ooool001kooooo00?o
0000ooooooooool0n_ooool2o`0004_ooooo000Nooooo`?o0000nOooool00ol0003oooooooooo`1;
ooooo`007_ooool00ol0003oooooooooo`3gooooo`;o0000C_ooool001kooooo00?o0000oooooooo
ool0m_ooool00ol0003oooooooooo`1>ooooo`007_ooool00ol0003oooooooooo`3dooooo`;o0000
DOooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0?7ooooo0ol0001Cooooo`005?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0koooool2o`0005Kooooo000E
ooooo`03oiRHV?lQ8B7ok^k^00KoooooDOl0002Oooooo`;o0000F?ooool001Kooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`1>ooooobWo0000Loooool3o`0005[ooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0MooooolIo`0005Oooooo0ol0001Mooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo093ooooo3Ol00017ooooo`?o0000
H?ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo09gooooo
3?l0000hooooo`?o0000Hoooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo0:Wooooo4?l0000Nooooo`[o0000I_ooool001kooooo0ol0002ioooooako0000L?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooo
odSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool009Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`00
0?nj^[[ooooo0:gooooo002Eooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00?ooooo0_lb<S:^ooooo`00R_ooool01Ol@413o0000o`000?l0003o410@00Kooooo00Co
0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRH
V?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00co
oooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2
ob4Q8HOooooo002<ooooo`03o`000?oooooooooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ
8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj
^_o^k^koMgMgoa0@4002ooooo`Ko00001Oooool00omgMgOo<S8booooo`03ooooo`;o8B4QQoooool0
08cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@
olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Roooool008cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1_l00005ooooo`03ogMgMolb<S;o
oooo08cooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0SOooool008Wooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo
00?o410@o`000?l000000ol0000;ooooo`03o`000?oooooooooo08oooooo0029ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo08oooooo0029ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool2o`0001Cooooo00?o0000ooooooooool03?ooool4o`0008kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41206 L
.01483 .41208 L
.01975 .4121 L
.02243 .4121 L
.02496 .41211 L
.02634 .41211 L
.02763 .41211 L
.02903 .41211 L
.02974 .41211 L
.03053 .41211 L
.03183 .41211 L
.03302 .41211 L
.0344 .41211 L
.03571 .41211 L
.03691 .41211 L
.03803 .41211 L
.04057 .41211 L
.04586 .4121 L
.05159 .41209 L
.05422 .41209 L
.057 .41208 L
.05815 .41208 L
.05938 .41208 L
.06072 .41208 L
.06198 .41208 L
.06278 .41208 L
.06352 .41208 L
.06433 .41208 L
.0652 .41208 L
.06594 .41208 L
.06664 .41208 L
.06824 .41208 L
.06968 .41209 L
.07099 .41209 L
.07395 .41209 L
.07648 .4121 L
.07924 .41211 L
.08481 .41213 L
.10712 .41225 L
.11225 .41227 L
.11767 .4123 L
.1227 .41231 L
.1274 .41233 L
.13222 .41234 L
.13477 .41234 L
.13752 .41234 L
.14314 .41235 L
.14849 .41236 L
.15346 .41236 L
Mistroke
.15628 .41237 L
.15889 .41237 L
.16349 .41239 L
.1684 .41241 L
.17404 .41244 L
.17922 .41248 L
.19092 .41258 L
.21211 .4128 L
.2336 .41298 L
.24408 .41306 L
.25363 .41314 L
.26354 .41325 L
.27291 .41338 L
.29355 .41377 L
.33385 .41463 L
.35425 .41511 L
.37673 .41581 L
.41801 .4175 L
.46028 .41943 L
.50096 .42189 L
.54421 .4245 L
.56581 .42579 L
.58587 .42699 L
.60526 .42797 L
.61084 .42819 L
.6161 .42837 L
.62119 .42851 L
.62594 .42861 L
.63082 .42869 L
.6334 .42873 L
.63617 .42875 L
.63757 .42876 L
.63908 .42877 L
.63977 .42877 L
.64051 .42878 L
.64183 .42878 L
.6431 .42878 L
.64429 .42878 L
.64559 .42878 L
.64632 .42878 L
.647 .42877 L
.64812 .42877 L
.64933 .42876 L
.6515 .42875 L
.65409 .42872 L
.65644 .42869 L
.66155 .4286 L
.66638 .42849 L
.67123 .42835 L
.67657 .42814 L
Mistroke
.68178 .4279 L
.68737 .42757 L
.69737 .4268 L
.70674 .42582 L
.71736 .42439 L
.72895 .4224 L
.75005 .41765 L
.77072 .41156 L
.79275 .40316 L
.81524 .39201 L
.83643 .37897 L
.87693 .34828 L
.92 .30778 L
.96148 .2664 L
1 .23507 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool]ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Noooo
o`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003o
ooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo0ol0003oooooobWooooo
00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0oooooolWooooo`;o00007ooo
ool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo000Noooo
o`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003o
ooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0
oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`?o0000oooooolRooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0S
ooooo`007_ooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool001ko
oooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`00
0?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003ooooooooo
o`3ooooooakooooo00?o0000ooooooooool09oooool001kooooo00?o0000ooooooooool0oooooolM
ooooo`03o`000?oooooooooo02Sooooo000Nooooo`?o0000oooooolLooooo`03o`000?oooooooooo
02Wooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool00ol0003oooooooooo`0Zooooo`00
7_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool000Gooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo0007ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooo
oolHooooo`03o`000?oooooooooo02gooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0;_ooool0
00Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolEoooo
o`;o0000<Oooool000Oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo037ooooo0007ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa?o
oooo00?o0000ooooooooool0<_ooool000Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`001Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o
0000ooooooooool0=?ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooo
oooo03Gooooo000Nooooo`?o0000ooooool>ooooo`;o0000>?ooool001kooooo00?o0000oooooooo
ool0ooooool=ooooo`03o`000?oooooooooo03Sooooo000Nooooo`03o`000?oooooooooo0?oooooo
3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo00?o
0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooo
oooo03_ooooo000Nooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`0loooo
o`007_ooool3o`000?oooooo1oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo0?oooooo
1_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`3oooooo`Gooooo00?o
0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0ooooool3ooooo`;o0000@oooool0
01kooooo00?o0000ooooooooool0ooooool2ooooo`03o`000?oooooooooo04?ooooo000Nooooo`03
o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`14ooooo`007_ooool00ol0003ooooo
ooooo`3nooooo`;o0000Aoooool001kooooo0ol0003mooooo`03o`000?oooooooooo04Oooooo000N
ooooo`03o`000?oooooooooo0?cooooo00?o0000ooooooooool0B?ooool001kooooo00?o0000oooo
ooooool0n_ooool2o`0004_ooooo000Nooooo`03o`000?oooooooooo0?Wooooo00?o0000oooooooo
ool0Boooool001kooooo00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`000?oo
oooooooo0?Kooooo00?o0000ooooooooool0C_ooool001kooooo0ol0003dooooo`;o0000DOooool0
01kooooo00?o0000ooooooooool0l_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo0?7o
oooo00?o0000ooooooooool0Doooool001kooooo00?o0000ooooooooool0koooool2o`0005Kooooo
000Dooooo`Go00001Oooool00ol0003oooooooooo`3/ooooo`?o0000F?ooool001Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0>Wooooo0ol0001Kooooo`005Oooool0
0onHV9So8B4Qonk^kP06oooood[o0000Woooool3o`0005kooooo000Fooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?o0000ooooooooool0Aoooool`o`0006cooooo0ol0001Qooooo`005oooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo07Oooooo6Ol0001>ooooo`Go0000I?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2@ooooo`go0000??ooool5o`0006Wooooo
000Dooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`2Moooooa3o0000
9_ooool6o`0006kooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`2]ooooobKo0000M?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001Oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRH
V?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo
0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_oooooo
MgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0
003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q
8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Co
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002=ooooo`;o0000
2oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2dooooo`00SOoo
ool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b]Ooo
ool008?ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
0oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0:ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@
4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<
c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Kooooo00?oMgMgoc8b
<_ooool00oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oM
gMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?oV9RHob4Q8Oo^k^h02Oooool0
0ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00oooool6o`0000Kooooo00?oMgMgoc8b<_ooool02oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`03Oooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo
00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07kooooo0022ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo07ko
oooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Gooooo
00?o0000ooooooooool03?ooool4o`0000_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41208 L
.01483 .41211 L
.01975 .41212 L
.02243 .41213 L
.02496 .41214 L
.02634 .41214 L
.02763 .41214 L
.02835 .41214 L
.02903 .41214 L
.02974 .41214 L
.03053 .41214 L
.03182 .41214 L
.03305 .41214 L
.03416 .41214 L
.03536 .41214 L
.03667 .41214 L
.03806 .41214 L
.04057 .41214 L
.04631 .41212 L
.05251 .41211 L
.05537 .41211 L
.05692 .4121 L
.05838 .4121 L
.05972 .4121 L
.06095 .4121 L
.06231 .4121 L
.06306 .4121 L
.06377 .4121 L
.06498 .4121 L
.06631 .4121 L
.06698 .4121 L
.0677 .4121 L
.069 .4121 L
.07024 .4121 L
.07153 .4121 L
.07385 .41211 L
.07656 .41212 L
.07908 .41213 L
.08481 .41216 L
.10448 .4123 L
.11484 .41237 L
.12006 .4124 L
.12581 .41242 L
.12871 .41243 L
.13183 .41243 L
.13478 .41244 L
.13747 .41244 L
.14011 .41244 L
.14298 .41244 L
Mistroke
.14568 .41244 L
.14822 .41245 L
.15101 .41245 L
.15354 .41245 L
.15626 .41246 L
.1592 .41246 L
.16178 .41247 L
.1645 .41248 L
.16938 .41251 L
.1746 .41255 L
.17936 .41259 L
.19004 .4127 L
.2093 .41295 L
.23108 .41317 L
.24065 .41324 L
.2512 .41333 L
.26129 .41345 L
.27075 .41359 L
.2915 .41402 L
.33217 .41497 L
.35284 .41545 L
.37543 .41617 L
.41709 .41791 L
.45973 .41973 L
.50078 .42203 L
.54441 .42416 L
.56629 .4251 L
.5759 .42551 L
.58645 .42593 L
.59135 .4261 L
.59661 .42626 L
.60115 .42637 L
.6061 .42647 L
.60751 .42649 L
.609 .42651 L
.61038 .42652 L
.61168 .42653 L
.61289 .42654 L
.6142 .42655 L
.6149 .42655 L
.61564 .42655 L
.61697 .42655 L
.61816 .42655 L
.61942 .42654 L
.62062 .42654 L
.62171 .42653 L
.62437 .42651 L
.62689 .42647 L
.63174 .42638 L
.63708 .42625 L
Mistroke
.64788 .42587 L
.65788 .42539 L
.66725 .42484 L
.67816 .42402 L
.68852 .42303 L
.69783 .42191 L
.70798 .42038 L
.72865 .4162 L
.75068 .41023 L
.77166 .4032 L
.79436 .39384 L
.83645 .37016 L
.87952 .33998 L
.92101 .30735 L
.94026 .29252 L
.95086 .28538 L
.9609 .27965 L
.9707 .27513 L
.98136 .27136 L
1 .26667 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000ooooool]ooooo`;o00006Ooo
ool001kooooo00?o0000ooooooooool0oooooolZooooo`?o00006oooool001kooooo00?o0000oooo
ooooool0oooooolWooooo`?o00007_ooool001kooooo00?o0000ooooooooool0oooooolTooooo`?o
00008Oooool001kooooo00?o0000ooooooooool0oooooolQooooo`?o00009?ooool001kooooo00?o
0000ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooo
oooo0?oooooo7_ooool2o`0002Sooooo000Nooooo`?o0000oooooolMooooo`03o`000?oooooooooo
02Sooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool2o`0002_ooooo000Nooooo`03o`00
0?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`001Oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooo
ooooo`3ooooooaSooooo0_l0000^ooooo`001oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003ooooooooo
o`0^ooooo`001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooolEooooo`;o0000<Oooool000Oooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`03ooooo`?o0000oooooolDooooo`03o`000?oooooooooo037ooooo0007ooooo`03
o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
0?oooooo4oooool00ol0003oooooooooo`0booooo`001oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolAooooo`;o0000=Oooool000Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0eooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0=_ooool001kooooo00?o0000
ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000Nooooo`?o0000ooooool<oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo03[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0kooooo`007_oo
ool00ol0003oooooooooo`3oooooo`Sooooo0_l0000nooooo`007_ooool00ol0003oooooooooo`3o
ooooo`Oooooo00?o0000ooooooooool0?_ooool001kooooo00?o0000ooooooooool0ooooool5oooo
o`;o0000@Oooool001kooooo0ol0003oooooo`Cooooo00?o0000ooooooooool0@Oooool001kooooo
00?o0000ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0oooo
ool1ooooo`03o`000?oooooooooo04Cooooo000Nooooo`03o`000?oooooooooo0?oooooo00?o0000
ooooooooool0AOooool001kooooo00?o0000ooooooooool0oOooool2o`0004Sooooo000Nooooo`03
o`000?oooooooooo0?cooooo00?o0000ooooooooool0B?ooool001kooooo00?o0000ooooooooool0
n_ooool2o`0004_ooooo000Nooooo`?o0000nOooool00ol0003oooooooooo`1;ooooo`007_ooool0
0ol0003oooooooooo`3gooooo`;o0000C_ooool001kooooo00?o0000ooooooooool0mOooool2o`00
053ooooo000Nooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0D?ooool001kooooo
00?o0000ooooooooool0l_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo0?3ooooo0_l0
001Eooooo`007_ooool3o`000>oooooo00?o0000ooooooooool0EOooool001kooooo00?o0000oooo
ooooool0kOooool2o`0005Sooooo000Nooooo`03o`000?oooooooooo0>_ooooo0_l0001Jooooo`00
7_ooool00ol0003oooooooooo`3Yooooo`;o0000G?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0>Kooooo0ol0001Nooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0hoooool3o`00067ooooo000Eooooo`03oiRHV?lQ8B7ok^k^00KoooooAOl0002L
ooooo`Go0000I?ooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`12oooo
ocGo0000H_ooool5o`0006Wooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0Moooool=o`0005;ooooo0ol0001^ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo08Cooooo6Ol0000cooooo`Ko0000LOooool001Cooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo09gooooo5Ol0000?ooooo`oo0000Moooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0;;ooooo3ol00026ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool0097ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0;7ooooo002Aooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:booooo`00Q_ooool01Ol@413o0000o`000?l0
003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@21ooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool6o`0000Gooooo00?oMgMgoc8b<_ooool00oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0P?oo
ool008Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1oooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?oo
ool6o`0000Gooooo00?oMgMgoc8b<_ooool03Oooool00omgMgOo<S8booooo`20ooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c021ooooo`00
QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooo
ooooool04?ooool00ol@413o0000o`000003o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`23ooooo`00QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
08?ooooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Co
oooo00?o0000ooooooooool03?ooool4o`0000cooooo1?l00022ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41209 L
.01483 .41213 L
.01975 .41215 L
.02243 .41216 L
.02496 .41217 L
.02634 .41217 L
.02763 .41217 L
.02903 .41217 L
.02974 .41217 L
.03053 .41217 L
.03183 .41218 L
.03302 .41218 L
.0344 .41217 L
.03571 .41217 L
.03691 .41217 L
.03803 .41217 L
.04057 .41217 L
.04586 .41215 L
.05159 .41214 L
.05422 .41213 L
.057 .41213 L
.05815 .41213 L
.05938 .41212 L
.06072 .41212 L
.06198 .41212 L
.06278 .41212 L
.06352 .41212 L
.06433 .41212 L
.0652 .41212 L
.06594 .41212 L
.06664 .41212 L
.06741 .41212 L
.06824 .41213 L
.06969 .41213 L
.07122 .41213 L
.07395 .41214 L
.07664 .41215 L
.07914 .41216 L
.08481 .4122 L
.10448 .41237 L
.11484 .41246 L
.12006 .41249 L
.12581 .41252 L
.12871 .41253 L
.13183 .41253 L
.13334 .41254 L
.13478 .41254 L
.13608 .41254 L
.13747 .41254 L
Mistroke
.14014 .41254 L
.14261 .41255 L
.14553 .41255 L
.14822 .41255 L
.14956 .41255 L
.15097 .41255 L
.15251 .41255 L
.15394 .41256 L
.15651 .41256 L
.15932 .41257 L
.16187 .41258 L
.16418 .41259 L
.16938 .41262 L
.17444 .41266 L
.17982 .41272 L
.18946 .41284 L
.21127 .41316 L
.23176 .41339 L
.25096 .41356 L
.26131 .41368 L
.2722 .41386 L
.29164 .41431 L
.33171 .41531 L
.35407 .41583 L
.37435 .41647 L
.41541 .41819 L
.45744 .41979 L
.49789 .42179 L
.51839 .4227 L
.53003 .42309 L
.54091 .42339 L
.56257 .42394 L
.57283 .42419 L
.58233 .42439 L
.5872 .42448 L
.58968 .42451 L
.59237 .42454 L
.59376 .42455 L
.59504 .42456 L
.59626 .42456 L
.59755 .42457 L
.59824 .42457 L
.59897 .42457 L
.60029 .42457 L
.6011 .42457 L
.60186 .42457 L
.60254 .42456 L
.60329 .42456 L
.60452 .42455 L
.60568 .42454 L
Mistroke
.6083 .42451 L
.61087 .42447 L
.61362 .42441 L
.6186 .42427 L
.62315 .4241 L
.6335 .4236 L
.6431 .42299 L
.66487 .42119 L
.67598 .42004 L
.68643 .41874 L
.70598 .41553 L
.72707 .41066 L
.74647 .40498 L
.78796 .38969 L
.82785 .36945 L
.87032 .34416 L
.91119 .32017 L
.93201 .30915 L
.93771 .30666 L
.94377 .3044 L
.94894 .30283 L
.95172 .30215 L
.95464 .30155 L
.95723 .30113 L
.9586 .30095 L
.96006 .30079 L
.96141 .30067 L
.96264 .30059 L
.96387 .30053 L
.96504 .3005 L
.96639 .30049 L
.96708 .30049 L
.96783 .30051 L
.96917 .30055 L
.97041 .30062 L
.97188 .30073 L
.97322 .30085 L
.97624 .30123 L
.98121 .3021 L
.98663 .30336 L
.9965 .30621 L
1 .30731 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
8Oooool6o`00027ooooo0007ooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0oooooolNooooo`Co00001Oooool6o`0001_ooooo0007
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
oooooa[ooooo1?l0000?ooooo`;o00006Oooool000Oooooo00?o0000ooooooooool03_ooool00omg
MgOo<S8booooo`03ooooo`?o0000oooooolHooooo`;o0000;_ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFoooo
o`;o0000<?ooool000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo5?ooool2o`0003;ooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa;ooooo0_l0000dooooo`001Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003oooooooooo`3ooooooa7ooooo00?o
0000ooooooooool0=?ooool001kooooo00?o0000ooooooooool0ooooool?ooooo`;o0000=oooool0
01kooooo0ol0003oooooo`gooooo0_l0000iooooo`007_ooool00ol0003oooooooooo`3oooooo`co
oooo00?o0000ooooooooool0>Oooool001kooooo00?o0000ooooooooool0ooooool:ooooo`;o0000
??ooool001kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000?_ooool001kooooo00?o0000
ooooooooool0ooooool7ooooo`03o`000?oooooooooo03kooooo000Nooooo`03o`000?oooooooooo
0?oooooo1Oooool2o`00047ooooo000Nooooo`?o0000ooooool3ooooo`;o0000@oooool001kooooo
00?o0000ooooooooool0ooooool2ooooo`03o`000?oooooooooo04?ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`3mooooo`;o0000B?ooool0
01kooooo00?o0000ooooooooool0o?ooool00ol0003oooooooooo`18ooooo`007_ooool00ol0003o
ooooooooo`3jooooo`;o0000Boooool001kooooo00?o0000ooooooooool0n?ooool2o`0004gooooo
000Nooooo`?o0000m_ooool2o`0004oooooo000Nooooo`03o`000?oooooooooo0?Cooooo0_l0001A
ooooo`007_ooool00ol0003oooooooooo`3aooooo`?o0000Doooool001kooooo00?o0000oooooooo
ool0koooool2o`0005Kooooo000Nooooo`03o`000?oooooooooo0>gooooo0_l0001Hooooo`007_oo
ool00ol0003oooooooooo`3[ooooo`;o0000F_ooool001kooooo0ol0003Xooooo`?o0000G?ooool0
01kooooo00?o0000ooooooooool0i_ooool2o`0005oooooo000Nooooo`03o`000?oooooooooo0>Co
oooo0_l0001Qooooo`007_ooool00ol0003oooooooooo`3Qooooo`?o0000Hoooool001Cooooo1Ol0
0005ooooo`03o`000?oooooooooo0=oooooo0_l0001Vooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0g?ooool3o`0006Sooooo000Eooooo`03oiRHV?lQ8B7o
k^k^00Kooooo?_l0002Looooo`Go0000Joooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0
003oooooooooo`0koooooc;o0000I?ooool6o`00073ooooo000Gooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0KOoooolFo`0004[ooooo1?l0001fooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08?ooooo6ol0000Vooooo`Wo0000N_ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo09kooooo9_l00023ooooo`005?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool008gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0;Cooooo002=ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:eooooo`00Poooool01Ol@413o0000o`000?l0
003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo
00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Kooooo00?oMgMgoc8b<_ooool00oooool2ob4Q
8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0N_ooool008Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^
kP_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo1_l00006ooooo`03ogMgMolb<S;ooooo00cooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00gooooo00?oEEEE
olc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07cooooo0022ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo017ooooo00?o
410@o`000?l000000ol0000;ooooo`03o`000?oooooooooo00oooooo00?oZJVYogMgMoooool00ooo
ool00ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`05oa0@4?oo
oooooooooooooolb<S801?ooool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0
000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo1?l0
000;ooooo`Go00001?ooool4o`0007gooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41211 L
.01483 .41214 L
.01975 .41217 L
.02243 .41218 L
.02496 .41219 L
.02625 .4122 L
.02763 .4122 L
.02834 .4122 L
.02913 .4122 L
.02985 .4122 L
.03053 .4122 L
.03183 .4122 L
.03302 .41221 L
.03431 .41221 L
.03504 .4122 L
.03571 .4122 L
.03694 .4122 L
.03806 .4122 L
.04057 .4122 L
.05151 .41217 L
.05451 .41216 L
.05615 .41216 L
.05768 .41216 L
.05898 .41216 L
.05965 .41216 L
.06038 .41216 L
.06118 .41216 L
.06193 .41216 L
.06267 .41216 L
.06335 .41216 L
.06458 .41216 L
.0659 .41216 L
.06715 .41216 L
.06829 .41216 L
.07095 .41217 L
.07229 .41217 L
.07375 .41218 L
.07948 .41221 L
.08481 .41225 L
.10448 .41245 L
.11484 .41255 L
.12006 .41259 L
.12581 .41262 L
.12871 .41263 L
.13183 .41264 L
.13478 .41265 L
.13747 .41265 L
.14011 .41265 L
.14298 .41266 L
Mistroke
.14822 .41266 L
.15101 .41266 L
.15354 .41267 L
.15645 .41268 L
.1592 .41269 L
.16175 .4127 L
.16409 .41271 L
.16938 .41274 L
.17433 .41279 L
.17963 .41285 L
.18918 .41299 L
.2109 .41335 L
.23324 .41362 L
.2435 .41371 L
.25438 .41382 L
.26434 .41396 L
.27533 .41417 L
.29468 .41468 L
.33695 .41574 L
.35639 .41618 L
.37763 .41688 L
.39871 .41775 L
.42088 .41861 L
.46352 .42002 L
.48323 .42085 L
.50457 .42173 L
.51026 .42192 L
.51626 .42209 L
.52183 .42222 L
.52703 .42232 L
.53712 .42246 L
.54246 .42251 L
.5482 .42255 L
.55887 .42263 L
.56449 .42266 L
.56758 .42268 L
.57048 .42269 L
.57319 .4227 L
.57438 .42271 L
.57569 .42271 L
.57703 .42271 L
.57777 .42271 L
.57845 .42271 L
.57921 .42271 L
.5799 .42271 L
.58069 .42271 L
.58144 .42271 L
.58267 .42271 L
.58397 .42271 L
.58509 .4227 L
Mistroke
.58631 .4227 L
.58763 .42269 L
.58904 .42268 L
.5916 .42265 L
.59426 .42261 L
.5971 .42256 L
.60222 .42244 L
.60829 .42224 L
.6138 .42199 L
.62467 .42134 L
.6349 .42053 L
.65421 .4186 L
.6754 .41599 L
.69635 .41262 L
.71848 .4077 L
.76094 .39459 L
.80182 .37872 L
.84527 .35768 L
.88713 .33938 L
.90627 .33258 L
.91717 .32931 L
.9225 .32797 L
.92739 .32696 L
.93227 .32619 L
.93472 .32591 L
.93609 .32578 L
.93739 .32569 L
.93807 .32565 L
.93881 .32562 L
.94009 .32557 L
.94082 .32556 L
.9416 .32556 L
.94298 .32557 L
.94426 .32561 L
.94545 .32568 L
.94676 .32578 L
.94817 .32591 L
.951 .3263 L
.95409 .32688 L
.957 .3276 L
.9597 .32841 L
.97023 .33291 L
.97829 .3377 L
.98586 .34307 L
1 .35446 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo5oooool:
o`0002Oooooo000Nooooo`?o0000oooooolCooooo`Co00002_ooool4o`0002?ooooo000Nooooo`03
o`000?oooooooooo0?oooooo4?ooool3o`0001;ooooo00?o0000ooooooooool08?ooool001kooooo
00?o0000ooooooooool0ooooool=ooooo`?o00005_ooool00ol0003oooooooooo`0Oooooo`007_oo
ool00ol0003oooooooooo`3oooooo`_ooooo0_l0000Jooooo`?o00007_ooool001kooooo00?o0000
ooooooooool0ooooool9ooooo`;o00007oooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0
003oooooooooo`3oooooo`Oooooo0_l0000Rooooo`03o`000?oooooooooo01[ooooo000Nooooo`?o
0000ooooool4ooooo`?o00009Oooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo0_l0000Yooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oo
oooooooo0?oooooo0_l0000/ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooo
oooo0?gooooo0_l00018ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o0000B_ooool001ko
oooo00?o0000ooooooooool0nOooool2o`0004cooooo000Nooooo`03o`000?oooooooooo0?Kooooo
0ol0001>ooooo`007_ooool3o`000?Cooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`3b
ooooo`;o0000Doooool001kooooo00?o0000ooooooooool0l?ooool2o`0005Gooooo000Nooooo`03
o`000?oooooooooo0>gooooo0ol0001Gooooo`007_ooool00ol0003oooooooooo`3Zooooo`?o0000
F_ooool001kooooo00?o0000ooooooooool0j?ooool2o`0005gooooo000Nooooo`?o0000iOooool3
o`0005oooooo000Nooooo`03o`000?oooooooooo0>;ooooo0ol0001Rooooo`007_ooool00ol0003o
ooooooooo`3Oooooo`?o0000IOooool001kooooo00?o0000ooooooooool0g?ooool3o`0006Sooooo
000Dooooo`Go00001Oooool00ol0003oooooooooo`3Iooooo`?o0000Joooool001Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0=Cooooo1Ol0001^ooooo`005Oooool0
0onHV9So8B4Qonk^kP06ooooocko0000Toooool6o`0007?ooooo000Fooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?o0000ooooooooool0>ooooolco`0005Wooooo1ol0001iooooo`005oooool00omgMgOo
IVIVooooo`04ooooo`03o`000?oooooooooo06kooooo5ol0000looooo`Ko0000P?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`25ooooocco0000Q_ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0
003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;o
oooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Gooooo0_lQ8B67ooooo`00S?ooool00ol0003oooooooooo`06ooooo`0:o`000?oooooooooo
ooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@400<oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`000006oooooomEEEGoMgMgoooooonHV9So8B4Q
1Oooool2ob4Q8HOooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000S_ooool008cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Co
oooo1_l000001_oooooo0000oiRHV?ooooooV9RHob4Q8Hkooooo002<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`0S_ooool008Wooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000:ooooo`03oeEE
EOn7QhOooooo093ooooo0029ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0;ooooo`03omgMgOl@413oV9RH093ooooo0029ooooo`Oo00001Ooo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000ooooooooool03?oo
ool01?o<c<coA4A4o`000?l@412>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41211 L
.01483 .41216 L
.01975 .41219 L
.02225 .4122 L
.02496 .41222 L
.02644 .41222 L
.02782 .41222 L
.02922 .41223 L
.03053 .41223 L
.03164 .41223 L
.03285 .41223 L
.03418 .41223 L
.0354 .41223 L
.03667 .41223 L
.03805 .41223 L
.03935 .41223 L
.04057 .41223 L
.04586 .41222 L
.05159 .41221 L
.05422 .4122 L
.05566 .4122 L
.057 .4122 L
.05815 .4122 L
.05938 .4122 L
.06074 .4122 L
.06198 .4122 L
.06272 .4122 L
.06351 .4122 L
.06418 .4122 L
.06493 .4122 L
.06658 .4122 L
.06813 .41221 L
.07093 .41222 L
.07395 .41223 L
.07962 .41226 L
.08481 .41231 L
.10636 .41256 L
.11177 .41261 L
.11687 .41266 L
.12183 .4127 L
.12641 .41273 L
.13092 .41275 L
.1332 .41275 L
.1357 .41276 L
.1409 .41277 L
.14576 .41278 L
.14843 .41278 L
.15097 .41279 L
.15572 .4128 L
Mistroke
.15838 .41281 L
.16085 .41282 L
.16643 .41286 L
.17178 .4129 L
.17755 .41297 L
.18802 .41313 L
.20757 .41348 L
.21842 .41365 L
.22855 .41378 L
.2391 .41389 L
.25068 .414 L
.26168 .41414 L
.27209 .41434 L
.29159 .41484 L
.33189 .41589 L
.35228 .41632 L
.37476 .41697 L
.41605 .41853 L
.45832 .41966 L
.47776 .42028 L
.48876 .42066 L
.49899 .42098 L
.50424 .42111 L
.50919 .42122 L
.51193 .42127 L
.5149 .42131 L
.51757 .42134 L
.52008 .42137 L
.52275 .42139 L
.52417 .42139 L
.52569 .4214 L
.52645 .4214 L
.52728 .4214 L
.52806 .4214 L
.52879 .42141 L
.53016 .42141 L
.53085 .4214 L
.53162 .4214 L
.53299 .4214 L
.53425 .4214 L
.5371 .42138 L
.5396 .42137 L
.54224 .42135 L
.55225 .42125 L
.56295 .42113 L
.57297 .42099 L
.58222 .42083 L
.58744 .4207 L
.59296 .42053 L
.59851 .42032 L
Mistroke
.60461 .42003 L
.61553 .41932 L
.62576 .41845 L
.64704 .41608 L
.66649 .41347 L
.68813 .41002 L
.70821 .40591 L
.74833 .39462 L
.78944 .38108 L
.83312 .36446 L
.85505 .35672 L
.86466 .35396 L
.87521 .35147 L
.8854 .34959 L
.89491 .34829 L
.90016 .34776 L
.90265 .34756 L
.90495 .34741 L
.9076 .34727 L
.909 .34722 L
.90971 .34719 L
.91048 .34717 L
.91176 .34715 L
.91297 .34714 L
.91366 .34714 L
.9144 .34714 L
.91571 .34715 L
.91701 .34718 L
.91774 .34721 L
.91842 .34723 L
.91963 .34729 L
.92097 .34737 L
.92329 .34755 L
.92574 .34781 L
.92841 .34817 L
.93128 .34867 L
.93646 .34987 L
.94163 .35151 L
.94654 .35351 L
.95575 .35858 L
.96585 .36622 L
.9766 .37669 L
.99592 .39993 L
1 .40519 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?oooooo2_oooolBo`0002cooooo000Nooooo`03o`000?oooooooooo0?oooooo
1oooool3o`0001;ooooo0ol0000Yooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo1_l0
000Hooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?gooooo0ol0000O
ooooo`;o00009_ooool001kooooo00?o0000ooooooooool0noooool2o`0002Cooooo00?o0000oooo
ooooool08oooool001kooooo00?o0000ooooooooool0nOooool2o`0002Oooooo0_l0000Sooooo`00
7_ooool00ol0003oooooooooo`3fooooo`?o0000:oooool00ol0003oooooooooo`0Pooooo`007_oo
ool3o`000??ooooo0ol0000_ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooo
oooo0?7ooooo0_l0000cooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo
0>kooooo0ol0000eooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0>_o
oooo0ol0000iooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0>Sooooo
0ol0000mooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0>Gooooo0ol0
0011ooooo`03o`000?oooooooooo01_ooooo000Nooooo`?o0000h_ooool3o`0004Cooooo00?o0000
ooooooooool06oooool001kooooo00?o0000ooooooooool0g_ooool4o`0004Sooooo00?o0000oooo
ooooool06_ooool001kooooo00?o0000ooooooooool0f_ooool4o`0004gooooo00?o0000oooooooo
ool06Oooool001kooooo00?o0000ooooooooool0e_ooool4o`0005;ooooo00?o0000ooooooooool0
6?ooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0=?ooooo0ol0001Gooooo`03o`000?oo
oooooooo01Oooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`3@ooooo`?o0000M?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolio`0009Gooooo1Ol0001g
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo03Kooooo=ol0001Boooo
o`co0000O?ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1]oooooaKo
0000=?ooool8o`0008Sooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Poooooldo`00093ooooo000Dooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooo
ooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o
0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go
00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Q
onk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3oooooodSooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooo
oom8ooooo`005_ooool00ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo
0?ooooooCoooool001Cooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0oooooom@ooooo`00oooooomYooooo`00SOooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0]?ooool008gooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[Gooooo0023
ooooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
1?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo07[ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0003oV9RH
oooooonHV9So8B4Q00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1kooooo`00
QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02oooool01Ol0003oEEEEo`000?l@413oc<c<00kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<07cooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00004ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000:
ooooo`03oeEEEOn7QhOooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1n
ooooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool00ooMgMgo410@oiRHV00=ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooo
oooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo00Coc<c<odA4A?l0003o410@2ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001mooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41212 L
.01483 .41217 L
.01975 .41221 L
.02496 .41223 L
.02782 .41224 L
.02913 .41225 L
.03053 .41225 L
.03172 .41225 L
.03303 .41226 L
.03422 .41226 L
.03534 .41226 L
.03666 .41226 L
.03786 .41226 L
.03925 .41226 L
.04057 .41226 L
.04126 .41226 L
.042 .41226 L
.04335 .41226 L
.04588 .41225 L
.04863 .41225 L
.05154 .41225 L
.05276 .41225 L
.05406 .41225 L
.05482 .41224 L
.0555 .41224 L
.05684 .41224 L
.05804 .41224 L
.05935 .41224 L
.06058 .41224 L
.06172 .41225 L
.06304 .41225 L
.06446 .41225 L
.06704 .41226 L
.06853 .41226 L
.07011 .41227 L
.07292 .41228 L
.0786 .41232 L
.08481 .41238 L
.10712 .41265 L
.11225 .41271 L
.11767 .41276 L
.1227 .4128 L
.1274 .41283 L
.13222 .41286 L
.13752 .41288 L
.14325 .41289 L
.14849 .4129 L
.15341 .41292 L
.15808 .41294 L
Mistroke
.16302 .41297 L
.1684 .41301 L
.17399 .41308 L
.17926 .41315 L
.18909 .41331 L
.21113 .41372 L
.23225 .41401 L
.25166 .41422 L
.26191 .41436 L
.27147 .41454 L
.29318 .4151 L
.33409 .41612 L
.37757 .41718 L
.39934 .41796 L
.40891 .41827 L
.41946 .41857 L
.43902 .41897 L
.45976 .41935 L
.48183 .41987 L
.49148 .42009 L
.49659 .42019 L
.49939 .42024 L
.50203 .42028 L
.50462 .42031 L
.50742 .42034 L
.50866 .42035 L
.50997 .42035 L
.51108 .42036 L
.51231 .42037 L
.51356 .42037 L
.51469 .42037 L
.516 .42037 L
.51725 .42037 L
.51839 .42036 L
.51946 .42036 L
.52062 .42035 L
.52186 .42035 L
.52432 .42033 L
.52697 .4203 L
.53177 .42023 L
.54271 .42001 L
.56373 .41945 L
.57443 .41912 L
.58587 .41869 L
.59671 .41815 L
.60657 .4175 L
.62585 .4157 L
.64597 .41318 L
.6678 .40999 L
.71073 .40192 L
Mistroke
.75207 .3909 L
.79182 .37991 L
.81392 .37369 L
.83414 .36828 L
.84413 .36607 L
.8494 .3651 L
.85503 .36424 L
.85781 .36389 L
.86043 .36361 L
.86297 .36338 L
.86532 .36321 L
.86755 .36309 L
.86869 .36303 L
.86991 .36299 L
.87113 .36295 L
.87227 .36293 L
.87363 .36292 L
.87487 .36291 L
.87611 .36292 L
.87727 .36294 L
.87855 .36297 L
.87992 .36301 L
.88129 .36307 L
.88272 .36314 L
.88529 .3633 L
.88989 .36371 L
.89493 .36432 L
.90039 .36518 L
.90622 .36634 L
.91673 .36916 L
.92233 .37113 L
.92749 .3733 L
.93916 .3797 L
.94944 .38745 L
.96032 .39814 L
.98083 .42529 L
1 .45634 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0ooooool4ooooo`So0000??ooool001kooooo00?o0000oooooooo
ool0o?ooool7o`0000Sooooo2?l0000dooooo`007_ooool00ol0003oooooooooo`3iooooo`?o0000
5oooool2o`0003;ooooo000Nooooo`?o0000m_ooool3o`0001cooooo1?l0000^ooooo`007_ooool0
0ol0003oooooooooo`3aooooo`Go00008oooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0
003oooooooooo`3]ooooo`Co0000:Oooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003o
ooooooooo`3Zooooo`?o0000;_ooool00ol0003oooooooooo`0Yooooo`007_ooool00ol0003ooooo
ooooo`3Wooooo`?o0000<_ooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003ooooooooo
o`3Tooooo`?o0000=_ooool2o`0002Sooooo000Nooooo`?o0000h?ooool4o`0003_ooooo00?o0000
ooooooooool09Oooool001kooooo00?o0000ooooooooool0foooool5o`00043ooooo00?o0000oooo
ooooool09?ooool001kooooo00?o0000ooooooooool0eoooool4o`0004Kooooo00?o0000oooooooo
ool08oooool001kooooo00?o0000ooooooooool0doooool4o`0004[ooooo00?o0000ooooooooool0
8oooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0<kooooo1Ol0001?ooooo`03o`000?oo
oooooooo02;ooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`3:ooooo`Co0000EOooool00ol0003oooooooooo`0Qooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooocGo0000Toooool5o`0005[ooooo00?o0000ooooooooool08?ooool001Kooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`0booooocWo0000COooool=o`0005oooooo00?o0000oooo
ooooool08?ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1[ooooob?o
00005ooooolCo`0006gooooo00?o0000ooooooooool07oooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2>oooooaOo0000POooool00ol0003oooooooooo`0Nooooo`005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooolXooooo`03o`00
0?oooooooooo01gooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo0ol0003oooooobWooooo00?o
0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooo
oooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0Koooo
o`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool06_ooool001kooooo
00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3o
ooooobgooooo00?o0000ooooooooool06?ooool001kooooo0ol0003oooooobgooooo00?o0000oooo
ooooool06?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8oooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodSo
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o
0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool0
01Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o0000
0?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWo
oooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo0_lQ8B45
ooooo`05odA4A?l0003o0000oc8b<_oMgMd0POooool008Sooooo00?o0000ooooooooool01_ooool0
2_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@
00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_ooooooEEEEogMg
MoooooooV9RHob4Q8@Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo083ooooo0028ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`1oooooo`00R?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`00
0006ooooool0003oV9RHoooooonHV9So8B4Q3oooool00omgMgOo<S8booooo`20ooooo`00R?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02ooo
ool01Ol0003oEEEEo`000?l@413oc<c<00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c021ooooo`00
QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooo
ooooool04?ooool00ol@413o0000o`000003o`0000[ooooo00?oEEEEohN7Qoooool03_ooool00ol0
003oooooooooo`23ooooo`00QOooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool00ooMgMgo410@oiRHV00>ooooo`03o`000?oooooooooo
08?ooooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Co
oooo00?o0000ooooooooool03?ooool01?o<c<coA4A4o`000?l@410<ooooo`Co0000P_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41212 L
.01975 .41221 L
.02496 .41225 L
.02787 .41226 L
.03053 .41227 L
.033 .41228 L
.03431 .41228 L
.03569 .41228 L
.0369 .41228 L
.03822 .41229 L
.03943 .41229 L
.04057 .41229 L
.04187 .41229 L
.0431 .41229 L
.04377 .41229 L
.04451 .41229 L
.04579 .41229 L
.04654 .41229 L
.04733 .41229 L
.04806 .41229 L
.04875 .41229 L
.05006 .41229 L
.05075 .41229 L
.05149 .41229 L
.05283 .41229 L
.05359 .41229 L
.05428 .41229 L
.05557 .41229 L
.05693 .41229 L
.05814 .4123 L
.05928 .4123 L
.06188 .4123 L
.06335 .41231 L
.06489 .41231 L
.06764 .41232 L
.07061 .41233 L
.07385 .41235 L
.07953 .4124 L
.08481 .41245 L
.10448 .4127 L
.11484 .41282 L
.12581 .41292 L
.13136 .41295 L
.13747 .41298 L
.14822 .41303 L
.15349 .41305 L
.15915 .41308 L
.1645 .41312 L
.16938 .41317 L
Mistroke
.17974 .41331 L
.18935 .41347 L
.21113 .41388 L
.23272 .41419 L
.25227 .41441 L
.26282 .41457 L
.27252 .41475 L
.29439 .41531 L
.33591 .41628 L
.37584 .41715 L
.39808 .41783 L
.40861 .41812 L
.41834 .41834 L
.42841 .41851 L
.43936 .41865 L
.45924 .41886 L
.48055 .41915 L
.48563 .41922 L
.49098 .41928 L
.49554 .41932 L
.49679 .41933 L
.49813 .41933 L
.49929 .41934 L
.50053 .41934 L
.50182 .41935 L
.50301 .41935 L
.50428 .41935 L
.50501 .41935 L
.50569 .41935 L
.50691 .41934 L
.50803 .41934 L
.50932 .41933 L
.51055 .41932 L
.51281 .41931 L
.5149 .41928 L
.51964 .41922 L
.52438 .41912 L
.52962 .419 L
.54022 .41867 L
.56222 .4178 L
.5824 .41686 L
.60216 .41557 L
.61211 .4147 L
.62299 .41354 L
.66554 .40764 L
.70651 .40052 L
.75005 .39059 L
.79199 .38195 L
.8112 .37861 L
.82212 .37696 L
Mistroke
.82746 .37627 L
.83235 .37575 L
.83481 .37552 L
.8375 .37531 L
.84007 .37515 L
.84239 .37503 L
.84379 .37498 L
.84511 .37494 L
.84649 .37491 L
.84728 .3749 L
.848 .3749 L
.8492 .3749 L
.85052 .37491 L
.85191 .37494 L
.85319 .37498 L
.85457 .37503 L
.85606 .3751 L
.85877 .37529 L
.86141 .37552 L
.86386 .37579 L
.8694 .37658 L
.87528 .37771 L
.88513 .38024 L
.89574 .38387 L
.91494 .39297 L
.925 .39935 L
.936 .40801 L
.95816 .43251 L
.97839 .46411 L
1 .50474 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?Sooooo3ol00010ooooo`007_ooool00ol0003oooooooooo`3aoooo
o`Oo00003oooool3o`0003gooooo000Nooooo`03o`000?oooooooooo0>cooooo1Ol0000Iooooo`?o
0000>_ooool001kooooo00?o0000ooooooooool0ioooool5o`00027ooooo0ol0000gooooo`007_oo
ool00ol0003oooooooooo`3Sooooo`Co0000:Oooool3o`0003Cooooo000Nooooo`?o0000goooool4
o`00033ooooo0_l0000booooo`007_ooool00ol0003oooooooooo`3Jooooo`Go0000=_ooool00ol0
003oooooooooo`0_ooooo`007_ooool00ol0003oooooooooo`3Fooooo`Co0000??ooool00ol0003o
ooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3Aooooo`Go0000@Oooool00ol0003ooooo
ooooo`0]ooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0b_ooool7o`0004Oooooo00?o
0000ooooooooool0;?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0<Cooooo1_l0001?ooooo`03o`000?oooooooooo02_ooooo000Eooooo`03oiRHV?lQ8B7o
k^k^00Kooooo;ol0002Aooooo`Oo0000E_ooool00ol0003oooooooooo`0Zooooo`005_ooool00onH
V9So8B4Qonk^kP05ooooo`03o`000?oooooooooo02cooooo?_l00017ooooo`co0000G_ooool00ol0
003oooooooooo`0Yooooo`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo06[o
ooooAol0001[ooooo`03o`000?oooooooooo02Sooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool0
9_ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo
8?ooool00ol0003oooooooooo`0Uooooo`007_ooool3o`000?oooooo8Oooool00ol0003ooooooooo
o`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool0
01kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`03
o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003ooooo
ooooo`3oooooob?ooooo00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool0oooo
oolTooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool0
0ol0003oooooooooo`0Qooooo`007_ooool3o`000?oooooo9Oooool00ol0003oooooooooo`0Poooo
o`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo
00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oo
oooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3o
ooooobOooooo00?o0000ooooooooool07_ooool001kooooo00?o0000ooooooooool0oooooolXoooo
o`03o`000?oooooooooo01gooooo000Nooooo`?o0000oooooolXooooo`03o`000?oooooooooo01go
oooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_oo
ool00ol0003oooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000
ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo
0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob_o
oooo00?o0000ooooooooool06_ooool001kooooo0ol0003oooooobcooooo00?o0000ooooooooool0
6Oooool001kooooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000N
ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0
003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000F
ooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?oooo
o`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@
o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_oo
ool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003ooooo
ooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`1k
ooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo000000gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@0>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00Go0000oeEEEOl0003o410@olc<c00>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01looooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00002_ooool00omE
EEGoQhN7ooooo`0@ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0O_ooool008;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00?ogMgMoa0@4?nHV9P03Oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000
ooooooooool0O_ooool008;ooooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04oooo
o`;o00005Oooool00ol0003oooooooooo`0<ooooo`04olc<c?m4A4Co0000oa0@40_ooooo1Ol00004
ooooo`Co0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41212 L
.01975 .41222 L
.02496 .41225 L
.03053 .41228 L
.03578 .4123 L
.04057 .41231 L
.05147 .41233 L
.05446 .41234 L
.05763 .41235 L
.06036 .41236 L
.06331 .41237 L
.06859 .41239 L
.07354 .41243 L
.08481 .41253 L
.1055 .41279 L
.11644 .41292 L
.12244 .41298 L
.12809 .41303 L
.13943 .4131 L
.14972 .41315 L
.15936 .41322 L
.16479 .41327 L
.16979 .41332 L
.18955 .41362 L
.21125 .41402 L
.23345 .41435 L
.2537 .41459 L
.26374 .41475 L
.27468 .41496 L
.29455 .41544 L
.33737 .41635 L
.3786 .41715 L
.39928 .41766 L
.40833 .41786 L
.41347 .41795 L
.41824 .41802 L
.42342 .41809 L
.42813 .41813 L
.43317 .41817 L
.43855 .4182 L
.44396 .41822 L
.44982 .41824 L
.46045 .41828 L
.47123 .41832 L
.47651 .41835 L
.48132 .41836 L
.48257 .41837 L
.48392 .41837 L
.48522 .41837 L
Mistroke
.48639 .41837 L
.48776 .41837 L
.48851 .41837 L
.48922 .41837 L
.49048 .41837 L
.49184 .41837 L
.49257 .41837 L
.49324 .41837 L
.49478 .41836 L
.49627 .41836 L
.49787 .41835 L
.50078 .41833 L
.50342 .4183 L
.50848 .41824 L
.51385 .41814 L
.51844 .41803 L
.5235 .41789 L
.54531 .41702 L
.56737 .41589 L
.58758 .41466 L
.60741 .41307 L
.62825 .41078 L
.66832 .40528 L
.71097 .39853 L
.75202 .39115 L
.7628 .38951 L
.77447 .38801 L
.78456 .38695 L
.79565 .38603 L
.80086 .38569 L
.80646 .38539 L
.80917 .38528 L
.81174 .38519 L
.81404 .38512 L
.81525 .3851 L
.81656 .38507 L
.81792 .38506 L
.8192 .38504 L
.81994 .38504 L
.82072 .38504 L
.82139 .38504 L
.82212 .38505 L
.8229 .38505 L
.8236 .38506 L
.82441 .38507 L
.82518 .38509 L
.82655 .38512 L
.82804 .38517 L
.83072 .38528 L
.83356 .38544 L
Mistroke
.83599 .38562 L
.83867 .38585 L
.84413 .38649 L
.84932 .38731 L
.85906 .38945 L
.86955 .3927 L
.88099 .39741 L
.90166 .40903 L
.92369 .42623 L
.94619 .45098 L
.96737 .48318 L
1 .54737 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0>gooooo
4_l00018ooooo`007_ooool00ol0003oooooooooo`3Tooooo`Wo00004_ooool6o`0004;ooooo000N
ooooo`?o0000goooool5o`00027ooooo0_l00010ooooo`007_ooool00ol0003oooooooooo`3Hoooo
o`Oo0000:?ooool2o`0003kooooo000Nooooo`03o`000?oooooooooo0=;ooooo1_l0000aooooo`;o
0000??ooool001kooooo00?o0000ooooooooool0boooool7o`0003Wooooo0_l0000jooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0aOooool6o`0004;ooooo0_l0000hooooo`005?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0_oooool6o`0004[ooooo0_l0
000fooooo`005Oooool00onHV9So8B4Qonk^kP06ooooob[o0000T_ooool6o`0005;ooooo00?o0000
ooooooooool0<oooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Woooo
ocSo0000B?oooolBo`0005Wooooo00?o0000ooooooooool0<_ooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`1OooooodSo0000K?ooool00ol0003oooooooooo`0aooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003ooooo
ooooo`0`ooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
oooooolFooooo`03o`000?oooooooooo02oooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0;_ooool001kooooo0ol0
003ooooooaOooooo00?o0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolH
ooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0
003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000oooooooo
ool0:oooool001kooooo00?o0000ooooooooool0oooooolKooooo`03o`000?oooooooooo02[ooooo
000Nooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`007_ooool0
0ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool001kooooo0ol0003ooooo
oagooooo00?o0000ooooooooool0:?ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03
o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003ooooo
ooooo`0Vooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_oo
ool001kooooo00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo000Noooo
o`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool3o`000?oo
oooo8_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo
00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oo
oooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Q
ooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001ko
oooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`?o0000
oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9_oo
ool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000
ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo
01kooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooolXooooo`03o`000?oooooooooo01gooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?oooooo:?ooool00ol0003oooooooooo`0Mooooo`00
1_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooolYooooo`03o`000?oooooooooo01cooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003ooooo
ooooo`0Kooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo0004ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo:ooo
ool00ol0003oooooooooo`0Jooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool0
0ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo0ol0003ooooo
obcooooo00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0ooooool]ooooo`03
o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003ooooo
ooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05ooo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02oooool00ol0003ok^k^ooooo`05oooo
o`;o8B4QQoooool008cooooo00?o0000ooooooooool01_ooool02_l0003oooooooooooooooook^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o
^[Zjonk^k_mgMgOo410@00;ooooo1_l00003ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B67oooo
o`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool00onYZJWoEEEEooooo`2>ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o8B4Qoooo
ooooool0SOooool008cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00kooooo00?oEEEEolc<c?ooool0SOooool008Wooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@
o`000?l000000ol0000=ooooo`03ojVYZOmgMgOooooo08gooooo0029ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?oooooo
oooooooooolb<S80S_ooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`Go0000S_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41234 L
.05077 .41238 L
.06168 .41242 L
.06795 .41246 L
.07365 .4125 L
.08481 .41261 L
.12636 .41309 L
.14816 .41326 L
.15774 .41333 L
.16829 .41344 L
.17839 .41357 L
.18786 .41372 L
.20862 .41409 L
.24933 .41466 L
.29262 .41546 L
.33431 .41627 L
.37441 .4169 L
.3968 .41732 L
.40737 .41749 L
.412 .41754 L
.41709 .41759 L
.42203 .41763 L
.42473 .41765 L
.42725 .41766 L
.42868 .41766 L
.43003 .41766 L
.43124 .41767 L
.43256 .41767 L
.43324 .41767 L
.43399 .41767 L
.43478 .41767 L
.43551 .41767 L
.43683 .41767 L
.43757 .41767 L
.43825 .41767 L
.43941 .41767 L
.44065 .41767 L
.44288 .41766 L
.44554 .41766 L
.44796 .41765 L
.45818 .41762 L
.46796 .41758 L
.47832 .41752 L
.48373 .41749 L
.48968 .41743 L
.49509 .41737 L
.50016 .41729 L
.50539 .41718 L
.51109 .41705 L
Mistroke
.52146 .41672 L
.54092 .41586 L
.56335 .41461 L
.58366 .4133 L
.6248 .40957 L
.66692 .40439 L
.70745 .39922 L
.72802 .39652 L
.73891 .39521 L
.75056 .39401 L
.75634 .39353 L
.76181 .39315 L
.76672 .39288 L
.76925 .39277 L
.77205 .39267 L
.77465 .3926 L
.7771 .39255 L
.77845 .39253 L
.77968 .39252 L
.78104 .39251 L
.78172 .39251 L
.78246 .3925 L
.78372 .39251 L
.78487 .39251 L
.7862 .39252 L
.78745 .39254 L
.78967 .39258 L
.79208 .39264 L
.79456 .39273 L
.79723 .39284 L
.80204 .3931 L
.80777 .39351 L
.81299 .394 L
.81842 .39464 L
.82434 .39549 L
.8351 .39757 L
.84495 .40016 L
.85584 .40395 L
.8672 .40905 L
.87789 .41498 L
.89905 .42998 L
.91847 .44778 L
.93832 .47084 L
.96005 .50334 L
1 .58159 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000>Cooooo3_l0001E
ooooo`007_ooool00ol0003oooooooooo`3Gooooo`go00003_ooool9o`0004cooooo000Nooooo`03
o`000?oooooooooo0=7ooooo1_l0000Tooooo`?o0000BOooool001kooooo00?o0000ooooooooool0
boooool6o`0002gooooo0ol00016ooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0`_oo
ool9o`0003Kooooo0ol00013ooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0^?ooool:o`0004;ooooo0ol00010ooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooob;o0000T_ooool7o`0004oooooo00?o0000ooooooooool0?Oooool001Kooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`0Ooooood_o0000=OoooolBo`0005Oooooo0_l0000moooo
o`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo06[ooooo=Ol0001[ooooo`03
o`000?oooooooooo03[ooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
ooooool<ooooo`03o`000?oooooooooo03Wooooo000Dooooo`05o`000?nj^[[ooooooiRHV?l@4100
1Oooool00ol0003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0>?ooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003ooooo
ooooo`0gooooo`007_ooool3o`000?oooooo3oooool2o`0003Oooooo000Nooooo`03o`000?oooooo
oooo0?oooooo4Oooool00ol0003oooooooooo`0dooooo`007_ooool00ol0003oooooooooo`3ooooo
oa;ooooo00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0oooooolCooooo`03
o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003ooooo
ooooo`0aooooo`007_ooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool0<?oo
ool001kooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo033ooooo000Noooo
o`?o0000oooooolFooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`000?oooooooooo0?oo
oooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3ooooooaSooooo
00?o0000ooooooooool0;Oooool001kooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oo
oooooooo02cooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[
ooooo`007_ooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool001ko
oooo0ol0003ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool0
oooooolLooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo0?oooooo7Ooo
ool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo00?o0000
ooooooooool0:?ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo
02Oooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`00
7_ooool3o`000?oooooo8?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003ooooooooo
o`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooooolQ
ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0
003oooooooooo`0Sooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`001Oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooob?ooooo00?o0000oooooooo
ool08_ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooobCooooo
00?o0000ooooooooool08Oooool000Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooobGooooo00?o0000ooooooooool08?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07ooo
ool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo000Noooo
o`?o0000oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oo
oooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo
00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolXooooo`03o`000?oo
oooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0L
ooooo`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001ko
oooo0ol0003oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0
oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:ooo
ool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000
ooooooooool06_ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo
01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`00
7_ooool3o`000?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003ooooooooo
o`3oooooobgooooo00?o0000ooooooooool06?ooool001kooooo00?o0000ooooooooool0ooooool^
ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool008gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0;Cooooo002=ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Cooooo0_lb<S:eooooo`00Poooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool0
0oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003ooooooooo
o`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Co
oooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmEEEGooooo00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o8B4Qoooo
ooooool03?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>oooo
o`03oeEEEOo<c<cooooo00gooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<07cooooo0022ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004
ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000=ooooo`03ojVYZOmgMgOo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool0
1Ol@413ooooooooooooooooo<S8b00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo07kooooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?oo
ool2o`0001Gooooo00?o0000ooooooooool02oooool5o`0000_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co0000OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41236 L
.06168 .41249 L
.07365 .41258 L
.08481 .41269 L
.12636 .41316 L
.14599 .41334 L
.1673 .41355 L
.18967 .41387 L
.21082 .41421 L
.25373 .41481 L
.29505 .41553 L
.33477 .41619 L
.37708 .41672 L
.39654 .41696 L
.40187 .41702 L
.40756 .41706 L
.41032 .41708 L
.41292 .41709 L
.41526 .4171 L
.41779 .41711 L
.41917 .41712 L
.42047 .41712 L
.42121 .41712 L
.42189 .41712 L
.42267 .41712 L
.42341 .41712 L
.42412 .41712 L
.42488 .41712 L
.42625 .41712 L
.42701 .41712 L
.42772 .41712 L
.42934 .41711 L
.43065 .41711 L
.43201 .41711 L
.43446 .4171 L
.43998 .41707 L
.4452 .41704 L
.45005 .417 L
.46107 .41689 L
.47212 .41676 L
.48255 .41661 L
.49192 .41645 L
.50207 .41621 L
.51201 .41591 L
.52294 .4155 L
.54504 .41442 L
.58739 .41173 L
.62816 .40817 L
.6715 .40374 L
Mistroke
.69316 .40173 L
.71325 .40004 L
.72327 .39931 L
.7327 .39874 L
.73792 .39849 L
.74067 .39839 L
.74356 .39829 L
.74601 .39823 L
.74731 .3982 L
.74869 .39817 L
.74997 .39815 L
.75113 .39814 L
.7523 .39813 L
.7534 .39813 L
.75461 .39813 L
.7559 .39813 L
.75712 .39814 L
.75824 .39815 L
.75948 .39817 L
.76084 .39819 L
.76357 .39826 L
.76627 .39835 L
.76916 .39847 L
.77435 .39877 L
.77957 .39917 L
.7845 .39964 L
.7937 .40077 L
.80394 .40244 L
.81476 .40473 L
.83415 .41045 L
.84408 .41437 L
.85474 .41945 L
.87399 .43119 L
.89626 .44913 L
.91738 .47062 L
.95759 .52601 L
1 .60526 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3HoooooaKo
0000FOooool001kooooo00?o0000ooooooooool0cOooool;o`0001Kooooo1_l0001Cooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0`oooool:o`0002Oooooo1?l0001?ooooo`005?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0]_ooool=o`0003Gooooo0ol0
001<ooooo`005Oooool00onHV9So8B4Qonk^kP06ooooob;o0000Roooool<o`0004Gooooo0ol00019
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooC?l0000Zoooo
oaGo0000E?ooool3o`0004Kooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0JooooolZo`0006cooooo0_l00014ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`11ooooo`005?ooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool0ooooool5ooooo`;o0000@Oooool001Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooo
ooooo`0nooooo`007_ooool3o`000?oooooo2?ooool2o`0003kooooo000Nooooo`03o`000?oooooo
oooo0?oooooo2_ooool00ol0003oooooooooo`0kooooo`007_ooool00ol0003oooooooooo`3ooooo
o`_ooooo00?o0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`03
o`000?oooooooooo03Wooooo000Nooooo`03o`000?oooooooooo0?oooooo3Oooool00ol0003ooooo
ooooo`0hooooo`007_ooool00ol0003oooooooooo`3oooooo`kooooo00?o0000ooooooooool0=ooo
ool001kooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo03Kooooo000Noooo
o`?o0000ooooool@ooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo0?oo
oooo4Oooool00ol0003oooooooooo`0dooooo`007_ooool00ol0003oooooooooo`3ooooooa;ooooo
00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oo
oooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo5?ooool00ol0003oooooooooo`0a
ooooo`007_ooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool0<?ooool001ko
oooo0ol0003ooooooaGooooo00?o0000ooooooooool0<?ooool001kooooo00?o0000ooooooooool0
oooooolFooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`000?oooooooooo0?oooooo5ooo
ool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000
ooooooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo
02gooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003oooooooooo`0/ooooo`00
7_ooool3o`000?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003ooooooooo
o`3ooooooa[ooooo00?o0000ooooooooool0:oooool001kooooo00?o0000ooooooooool0oooooolK
ooooo`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0
003oooooooooo`0Yooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`001Oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003ooooooakooooo00?o0000oooooooo
ool09oooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaoooooo
00?o0000ooooooooool09_ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Uooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooob7ooooo00?o0000ooooooooool09?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?oo
ool001kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo000Noooo
o`?o0000oooooolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3oooooob?ooooo
00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oo
oooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0P
ooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000ooooooooool08?ooool001ko
oooo0ol0003oooooobKooooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0
oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9ooo
ool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o0000
ooooooooool07_ooool001kooooo00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo
01gooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Mooooo`00
7_ooool3o`000?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003ooooooooo
o`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0oooooolZ
ooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0
003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000oooooooo
ool06_ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo
000Nooooo`?o0000ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooo
oooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3ooooo
obgooooo00?o0000ooooooooool06?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo01Oooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003o
ooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool0
0ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Co
oooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooom@ooooo`00oooooomYooooo`00TOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0/Oooool0097ooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[;ooooo0026ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@21ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6
o`0000?ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0P?ooool0
08Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@
olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00gooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`1oooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6
o`0000Cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`20ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0POooool008Gooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
0_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo
00?o410@o`000?l000000ol0000=ooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool0
Poooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo08?o
oooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo
00?o0000ooooooooool02oooool5o`0000cooooo1?l00022ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41237 L
.08481 .41276 L
.12636 .41321 L
.16632 .41365 L
.20885 .41423 L
.2498 .41481 L
.29331 .41546 L
.31511 .41579 L
.33524 .41604 L
.35606 .41625 L
.37557 .41642 L
.38584 .4165 L
.39033 .41652 L
.39524 .41655 L
.39801 .41656 L
.40058 .41657 L
.4032 .41658 L
.40567 .41658 L
.40704 .41658 L
.40776 .41658 L
.40852 .41658 L
.40986 .41659 L
.4111 .41659 L
.41179 .41659 L
.41253 .41659 L
.41386 .41658 L
.41468 .41658 L
.41545 .41658 L
.41689 .41658 L
.41809 .41658 L
.41938 .41658 L
.42171 .41657 L
.42448 .41656 L
.42703 .41655 L
.43227 .41651 L
.4378 .41647 L
.44703 .41638 L
.45714 .41625 L
.47773 .41588 L
.48926 .41562 L
.49973 .41532 L
.51987 .4146 L
.54171 .41359 L
.58467 .41102 L
.62605 .40797 L
.66583 .40497 L
.68625 .40375 L
.69771 .40323 L
.70278 .40305 L
Mistroke
.70818 .40289 L
.71099 .40282 L
.71362 .40277 L
.71599 .40273 L
.71721 .40272 L
.71855 .4027 L
.71981 .40269 L
.72099 .40268 L
.72223 .40268 L
.72356 .40268 L
.7248 .40268 L
.72597 .40268 L
.72702 .40269 L
.72816 .4027 L
.72951 .40271 L
.73077 .40273 L
.73365 .40278 L
.73646 .40285 L
.73948 .40295 L
.74494 .40319 L
.74993 .40348 L
.76025 .40434 L
.76984 .40547 L
.78037 .40712 L
.79159 .4094 L
.80238 .41214 L
.81405 .41578 L
.83522 .42444 L
.85613 .43606 L
.87824 .45216 L
.91808 .49192 L
.96049 .55026 L
1 .61692 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0=;ooooo3Ol0001Xooooo`005?ooool5o`0000Gooooo00?o
0000ooooooooool0`OoooolAo`0000gooooo2ol0001Mooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0]Oooool<o`0002Wooooo1ol0001Fooooo`005Oooool0
0onHV9So8B4Qonk^kP06ooooob;o0000R_ooool<o`0003cooooo0ol0001Cooooo`005_ooool00onH
V9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooC_l0000Jooooob;o0000Boooool2o`00
057ooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0KOoooolJo`0006oo
oooo0ol0001>ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?Wooooo
0_l0001<ooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
noooool2o`0004[ooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`3mooooo`;o0000B?ooool001kooooo0ol0003oooooo`;o0000A_ooool001kooooo00?o0000
ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0ooooool4oooo
o`03o`000?oooooooooo047ooooo000Nooooo`03o`000?oooooooooo0?oooooo1Oooool2o`00047o
oooo000Nooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`0nooooo`007_oo
ool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0?Oooool001kooooo00?o0000
ooooooooool0ooooool9ooooo`03o`000?oooooooooo03cooooo000Nooooo`?o0000ooooool:oooo
o`03o`000?oooooooooo03_ooooo000Nooooo`03o`000?oooooooooo0?oooooo2oooool00ol0003o
ooooooooo`0jooooo`007_ooool00ol0003oooooooooo`3oooooo`cooooo00?o0000ooooooooool0
>Oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooooooo03Sooooo000N
ooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`0gooooo`007_ooool00ol0
003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0=_ooool001kooooo0ol0003ooooooa3o
oooo00?o0000ooooooooool0=Oooool001kooooo00?o0000ooooooooool0oooooolAooooo`03o`00
0?oooooooooo03Cooooo000Nooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003ooooooooo
o`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa?ooooo00?o0000ooooooooool0<_ooool0
01kooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooooooo037ooooo000Nooooo`03
o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_ooool3o`000?oooooo
5Oooool00ol0003oooooooooo`0`ooooo`007_ooool00ol0003oooooooooo`3ooooooaKooooo00?o
0000ooooooooool0;oooool001kooooo00?o0000ooooooooool0oooooolGooooo`03o`000?oooooo
oooo02kooooo000Nooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003oooooooooo`0]oooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0;Oooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo6Oooool00ol0003oooooooooo`0/ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003ooooooa[ooooo00?o0000ooooooooool0:oooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
6_ooool00ol0003oooooooooo`0[ooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0
:_ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`001?ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooagooooo00?o
0000ooooooooool0:?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool001kooooo00?o0000
ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo000Nooooo`?o0000oooooolOoooo
o`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003o
ooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0
9Oooool001kooooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Cooooo000N
ooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0
003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0003oooooob?o
oooo00?o0000ooooooooool08_ooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`00
0?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0003ooooooooo
o`0Qooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000ooooooooool08?ooool0
01kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03
o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Oooooo`007_ooool3o`000?oooooo
9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobOooooo00?o
0000ooooooooool07_ooool001kooooo00?o0000ooooooooool0oooooolXooooo`03o`000?oooooo
oooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Moooo
o`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo
00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`?o0000oooo
oolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool0
0ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000oooo
ooooool06_ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooobgo
oooo00?o0000ooooooooool06?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00SOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo
00?o0000okZj^_ooool0]?ooool008gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool01?ooool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o0000o`000?l@41001Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02oooool00ol0003ok^k^ooooo`05ooooo`;o
8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000ooo
ool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMg
oa0@4?ooool6o`0000Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00onYZJWoEEEEooooo`0=ooooo`03
ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0N_ooool008Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03
ob4Q8Ooooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`1kooooo`00
QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo
<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool03_ooool00omEEEGoc<c<ooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01looooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00onY
ZJWoMgMgooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0O_ooool008;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00Go410@oooooooooooooooooc8b<P0;ooooo`05oa0@4?oooooooooooooooolb<S801?oo
ool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooo
oooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo1Ol0000;ooooo`Go00001?ooool4
o`0007gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41239 L
.08481 .41283 L
.12636 .41325 L
.16632 .41374 L
.20885 .41426 L
.2498 .41482 L
.29331 .41538 L
.31511 .41563 L
.33524 .41583 L
.35482 .416 L
.3647 .41606 L
.37031 .41609 L
.37304 .4161 L
.37557 .41611 L
.37831 .41611 L
.38079 .41612 L
.3822 .41612 L
.38354 .41612 L
.38422 .41612 L
.38495 .41612 L
.38574 .41612 L
.38647 .41612 L
.38771 .41612 L
.38903 .41612 L
.39027 .41612 L
.39141 .41612 L
.39275 .41612 L
.3942 .41612 L
.39683 .41611 L
.39916 .41611 L
.40173 .4161 L
.40694 .41609 L
.41176 .41607 L
.41628 .41604 L
.42661 .41597 L
.43748 .41587 L
.44676 .41576 L
.45691 .41561 L
.4775 .41517 L
.4995 .41452 L
.54307 .41278 L
.58505 .41055 L
.62544 .40824 L
.6459 .40724 L
.65675 .40679 L
.66273 .40658 L
.6684 .4064 L
.67375 .40626 L
.67657 .4062 L
Mistroke
.67957 .40615 L
.68235 .4061 L
.68487 .40608 L
.68608 .40606 L
.6874 .40606 L
.68864 .40605 L
.68978 .40604 L
.69094 .40604 L
.69218 .40604 L
.69335 .40605 L
.69442 .40605 L
.69567 .40606 L
.69704 .40607 L
.69951 .4061 L
.7021 .40614 L
.70485 .4062 L
.70978 .40634 L
.71493 .40655 L
.71964 .40679 L
.73026 .40752 L
.73963 .40842 L
.74947 .40964 L
.75952 .41121 L
.77024 .41328 L
.78954 .41819 L
.81199 .42621 L
.83317 .43642 L
.87361 .46392 L
.89452 .48264 L
.91663 .50596 L
.95647 .55575 L
.99888 .61427 L
1 .61584 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0<Oooooo3ol0001aooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0]OoooolBo`0000oooooo3_l0001Sooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooob;o0000OOoooolIo`0002oooooo0ol0001Pooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo01ooooooOOl0001;ooooo`Co0000G?ooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`3[ooooo`Go0000Eoooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3`ooooo`?o0000E?ooool001Cooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo0??ooooo0ol0001Aooooo`005?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0m_ooool00ol0003oooooooooo`1>ooooo`007_oo
ool3o`000?Oooooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`3iooooo`03o`000?oooooo
oooo04_ooooo000Nooooo`03o`000?oooooooooo0?[ooooo0_l0001;ooooo`007_ooool00ol0003o
ooooooooo`3looooo`03o`000?oooooooooo04Sooooo000Nooooo`03o`000?oooooooooo0?gooooo
0_l00018ooooo`007_ooool00ol0003oooooooooo`3oooooo`03o`000?oooooooooo04Gooooo000N
ooooo`03o`000?oooooooooo0?oooooo0Oooool2o`0004Gooooo000Nooooo`?o0000ooooool3oooo
o`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo0?oooooo1?ooool2o`0004;o
oooo000Nooooo`03o`000?oooooooooo0?oooooo1_ooool00ol0003oooooooooo`0oooooo`007_oo
ool00ol0003oooooooooo`3oooooo`Oooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`3o
ooooo`Wooooo00?o0000ooooooooool0??ooool001kooooo00?o0000ooooooooool0ooooool:oooo
o`03o`000?oooooooooo03_ooooo000Nooooo`?o0000ooooool;ooooo`03o`000?oooooooooo03[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`0iooooo`007_oo
ool00ol0003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0>?ooool001kooooo00?o0000
ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0fooooo`007_ooool00ol0003oooooooooo`3ooooooa3o
oooo00?o0000ooooooooool0=Oooool001kooooo0ol0003ooooooa7ooooo00?o0000ooooooooool0
=?ooool001kooooo00?o0000ooooooooool0oooooolBooooo`03o`000?oooooooooo03?ooooo000N
ooooo`03o`000?oooooooooo0?oooooo4oooool00ol0003oooooooooo`0booooo`007_ooool00ol0
003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolEoooo
o`03o`000?oooooooooo033ooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaGooooo00?o0000oooo
ooooool0<?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o
0000oooooolFooooo`03o`000?oooooooooo02oooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0
;_ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo02gooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaWooooo00?o
0000ooooooooool0;?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolJooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool0
0ol0003oooooooooo`0Zooooo`007_ooool3o`000?oooooo7?ooool00ol0003oooooooooo`0Yoooo
o`007_ooool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool001kooooo
00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oo
oooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`3o
oooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolPoooo
o`03o`000?oooooooooo02Gooooo000Nooooo`?o0000oooooolQooooo`03o`000?oooooooooo02Co
oooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_oo
ool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000
ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo
0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3oooooobCo
oooo00?o0000ooooooooool08Oooool001kooooo0ol0003oooooobGooooo00?o0000ooooooooool0
8?ooool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000N
ooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003oooooooooo`0Oooooo`007_ooool00ol0
003oooooooooo`3oooooobOooooo00?o0000ooooooooool07_ooool001kooooo00?o0000oooooooo
ool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo
:?ooool00ol0003oooooooooo`0Mooooo`007_ooool3o`000?oooooo:Oooool00ol0003ooooooooo
o`0Looooo`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool0
01kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03
o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`005?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01[o
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooobco
oooo00?o0000ooooooooool06Oooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooobgooooo0_l0000Iooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooo
oom8ooooo`005_ooool00ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo
0?ooooooCoooool001Cooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0oooooom@ooooo`00oooooomYooooo`00UOooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0[Oooool009Gooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<Zkooooo002:
ooooo`05oa0@4?l0003o0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03
o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o8B4QQoooool008cooooo00?o0000oooo
ooooool01_ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03
olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo
00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00000
1_oooooo8B4QoiRHV?ooooooV9RHob4Q8@Gooooo0_lQ8B67ooooo`00S?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000008kooooo002<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`04ooooo`Ko000000Kooooooc8b<_nHV9SooooooiRHV?lb<S:>
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02oooool01Oo<c<co0000o`000?l0003oc<c<08kooooo0029ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol@413o^[Zjoooooonj^[[o410@08kooooo0029ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05
o`000?nj^[[ooooookZj^_l00000S_ooool008Wooooo1ol00005ooooo`;o00004_ooool00ol0003o
ooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0S_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.08481 .41288 L
.10632 .41307 L
.12636 .41327 L
.16632 .4138 L
.20726 .41424 L
.25078 .41482 L
.29271 .41526 L
.33304 .41558 L
.34379 .41567 L
.34906 .4157 L
.35387 .41573 L
.35893 .41576 L
.36172 .41577 L
.36438 .41577 L
.36577 .41577 L
.36653 .41578 L
.36725 .41578 L
.36792 .41578 L
.36864 .41578 L
.36991 .41578 L
.37064 .41578 L
.37144 .41578 L
.37228 .41578 L
.37306 .41578 L
.37379 .41578 L
.37445 .41577 L
.37595 .41577 L
.37835 .41577 L
.381 .41576 L
.38636 .41574 L
.39599 .41568 L
.41779 .41551 L
.4381 .41531 L
.44953 .41516 L
.46 .41498 L
.47987 .4145 L
.50161 .41381 L
.5442 .41232 L
.58519 .41056 L
.6061 .40968 L
.61711 .40931 L
.62313 .40915 L
.62877 .40901 L
.6342 .40891 L
.63917 .40883 L
.64468 .40876 L
.64772 .40873 L
.65061 .40871 L
Mistroke
.65303 .4087 L
.65438 .40869 L
.65561 .40869 L
.65676 .40869 L
.658 .40869 L
.65917 .40869 L
.66024 .40869 L
.6615 .40869 L
.66268 .4087 L
.66397 .4087 L
.66535 .40871 L
.66818 .40874 L
.67075 .40876 L
.67581 .40884 L
.67837 .4089 L
.68118 .40897 L
.69083 .40931 L
.69625 .40958 L
.70208 .40995 L
.71264 .41083 L
.72271 .41194 L
.73372 .4135 L
.75589 .41771 L
.77652 .42309 L
.79853 .4308 L
.82099 .44127 L
.84216 .45368 L
.88261 .48383 L
.92563 .52544 L
.96705 .56969 L
1 .60209 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0;;ooooo8?l0001eooooo`005Oooool00onHV9So8B4Qonk^kP06oooooaoo0000POoooolE
o`00023ooooo2_l0001[ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo
01coooooPOl0000oooooo`Go0000I_ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3Qooooo`Go0000HOooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Vooooo`?o0000G_ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`00
0?oooooooooo0>Wooooo0ol0001Kooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0k?ooool3o`0005Sooooo000Nooooo`?o0000koooool3o`0005Gooooo000N
ooooo`03o`000?oooooooooo0?;ooooo0ol0001Booooo`007_ooool00ol0003oooooooooo`3eoooo
o`;o0000D?ooool001kooooo00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`00
0?oooooooooo0?Wooooo00?o0000ooooooooool0Boooool001kooooo00?o0000ooooooooool0n_oo
ool2o`0004_ooooo000Nooooo`03o`000?oooooooooo0?cooooo00?o0000ooooooooool0B?ooool0
01kooooo0ol0003mooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0ooooool00ol0003o
ooooooooo`15ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000ooooooooool0
A?ooool001kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000A?ooool001kooooo00?o0000
ooooooooool0ooooool4ooooo`03o`000?oooooooooo047ooooo000Nooooo`03o`000?oooooooooo
0?oooooo1Oooool00ol0003oooooooooo`10ooooo`007_ooool3o`000?oooooo1_ooool2o`00043o
oooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool00ol0003oooooooooo`0mooooo`007_oo
ool00ol0003oooooooooo`3oooooo`Wooooo00?o0000ooooooooool0??ooool001kooooo00?o0000
ooooooooool0ooooool:ooooo`03o`000?oooooooooo03_ooooo000Nooooo`03o`000?oooooooooo
0?oooooo2oooool00ol0003oooooooooo`0jooooo`007_ooool00ol0003oooooooooo`3oooooo`co
oooo00?o0000ooooooooool0>Oooool001kooooo0ol0003oooooo`gooooo00?o0000ooooooooool0
>?ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000N
ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0fooooo`007_ooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0=Oooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolAoooo
o`03o`000?oooooooooo03Cooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000oooo
ooooool0<oooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o
0000oooooolCooooo`03o`000?oooooooooo03;ooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0
<Oooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo033ooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaKooooo00?o
0000ooooooooool0;oooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolGooooo`03o`000?oooooooooo02kooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolHooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool0
0ol0003oooooooooo`0/ooooo`007_ooool3o`000?oooooo6_ooool00ol0003oooooooooo`0[oooo
o`007_ooool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo
00?o0000ooooooooool0oooooolLooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oo
oooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3o
oooooakooooo00?o0000ooooooooool09oooool001kooooo00?o0000ooooooooool0oooooolOoooo
o`03o`000?oooooooooo02Kooooo000Nooooo`?o0000oooooolPooooo`03o`000?oooooooooo02Go
oooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_oo
ool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000
ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo
0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3oooooobGo
oooo00?o0000ooooooooool08?ooool001kooooo0ol0003oooooobKooooo00?o0000ooooooooool0
7oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000N
ooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0
003oooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo00?o0000oooooooo
ool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo
:oooool00ol0003oooooooooo`0Jooooo`007_ooool3o`000?oooooo;?ooool00ol0003ooooooooo
o`0Iooooo`007_ooool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool0
01kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000F
ooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?oooo
o`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002=ooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2dooooo`00SOooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b]Oooool008?ooooo00Go410@
o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_oo
ool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003ooooo
ooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo
00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0Nooo
ool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o
410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool0N_ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S803Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05
olc<c?l0003o0000o`000?o<c<`03_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003
o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000[ooooo00Go410@
okZj^_oooooo^[Zjoa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_oo
ool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo00Go0000okZj^_oooooo^[Zjo`00000;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`00
0?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007gooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.08481 .41293 L
.10632 .41309 L
.11681 .41318 L
.12636 .41328 L
.14567 .41355 L
.16632 .41385 L
.18642 .41405 L
.20824 .41422 L
.22907 .41445 L
.25115 .41477 L
.26104 .41489 L
.26649 .41495 L
.27167 .415 L
.27646 .41504 L
.2817 .41507 L
.29088 .41511 L
.30241 .41515 L
.31326 .4152 L
.32301 .41526 L
.33356 .41533 L
.34396 .41541 L
.34965 .41544 L
.35243 .41545 L
.35496 .41546 L
.35607 .41546 L
.35728 .41547 L
.35833 .41547 L
.35949 .41547 L
.36071 .41547 L
.36201 .41548 L
.36321 .41548 L
.36434 .41548 L
.3656 .41547 L
.36693 .41547 L
.36806 .41547 L
.3693 .41547 L
.37207 .41546 L
.37465 .41545 L
.37995 .41541 L
.38569 .41537 L
.39613 .41527 L
.41564 .41506 L
.4361 .41486 L
.44695 .41474 L
.45861 .41456 L
.46978 .41432 L
.47998 .41405 L
.49998 .41344 L
Mistroke
.54173 .4123 L
.58189 .41114 L
.59255 .41084 L
.59778 .41072 L
.60258 .41062 L
.60814 .41054 L
.61107 .41051 L
.61254 .4105 L
.61415 .41049 L
.61552 .41048 L
.61677 .41047 L
.61746 .41047 L
.6182 .41047 L
.61957 .41047 L
.62084 .41047 L
.62219 .41048 L
.62335 .41048 L
.62462 .41049 L
.62709 .4105 L
.6298 .41053 L
.63262 .41057 L
.63524 .41061 L
.64497 .41081 L
.65053 .41096 L
.65558 .41113 L
.66689 .41158 L
.6774 .41214 L
.68707 .41281 L
.69769 .41377 L
.70892 .41512 L
.72952 .41856 L
.74876 .42292 L
.78958 .43592 L
.81186 .44595 L
.83298 .45771 L
.87319 .48474 L
.91597 .51916 L
.93721 .5374 L
.95717 .55295 L
.99677 .57506 L
1 .57652 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolOo`00083ooooo=Ol0001f
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01coooooP?l0000eoooo
o`So0000K_ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3Iooooo`Ko
0000J?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Oooooo`Go0000
Hoooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0>Cooooo
0ol0001Pooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
ioooool3o`0005gooooo000Nooooo`?o0000j_ooool3o`0005[ooooo000Nooooo`03o`000?oooooo
oooo0>gooooo0_l0001Hooooo`007_ooool00ol0003oooooooooo`3_ooooo`?o0000EOooool001ko
oooo00?o0000ooooooooool0l_ooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo0?Cooooo
0_l0001Aooooo`007_ooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo04kooooo000N
ooooo`03o`000?oooooooooo0?Oooooo0_l0001>ooooo`007_ooool3o`000?Wooooo00?o0000oooo
ooooool0Boooool001kooooo00?o0000ooooooooool0n_ooool2o`0004_ooooo000Nooooo`03o`00
0?oooooooooo0?cooooo00?o0000ooooooooool0B?ooool001kooooo00?o0000ooooooooool0oOoo
ool2o`0004Sooooo000Nooooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool0AOooool0
01kooooo00?o0000ooooooooool0ooooool1ooooo`;o0000AOooool001kooooo0ol0003oooooo`?o
oooo00?o0000ooooooooool0@_ooool001kooooo00?o0000ooooooooool0ooooool4ooooo`;o0000
@_ooool001kooooo00?o0000ooooooooool0ooooool6ooooo`03o`000?oooooooooo03oooooo000N
ooooo`03o`000?oooooooooo0?oooooo1oooool2o`0003oooooo000Nooooo`03o`000?oooooooooo
0?oooooo2Oooool00ol0003oooooooooo`0looooo`007_ooool00ol0003oooooooooo`3oooooo`[o
oooo00?o0000ooooooooool0>oooool001kooooo0ol0003oooooo`_ooooo00?o0000ooooooooool0
>_ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`03o`000?oooooooooo03Wooooo000N
ooooo`03o`000?oooooooooo0?oooooo3Oooool2o`0003Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo3oooool00ol0003oooooooooo`0fooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000oooo
ooooool0=Oooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0doooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003ooooooa;o
oooo00?o0000ooooooooool0<oooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool00ol0003oooooooooo`0booooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3ooooooaCooooo0_l0000booooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo02oooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo5oooool2o`0002oooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo000N
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool3o`00
0?oooooo6oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003o
ooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool0
9oooool001kooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo02Kooooo000N
ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0
003oooooooooo`3oooooob7ooooo0_l0000Uooooo`007_ooool3o`000?oooooo8oooool2o`0002?o
oooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_oo
ool00ol0003oooooooooo`3oooooobKooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`3o
ooooobSooooo0_l0000Nooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo00?o0000oooo
ooooool06oooool001kooooo00?o0000ooooooooool0ooooool[ooooo`;o00006oooool001kooooo
0ol0003oooooobgooooo0_l0000Iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00TOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0/Oooool0097ooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool00oooool2oc8b<[;ooooo0026ooooo`05oa0@4?l0003o0000o`000?l@41001_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo
00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM087ooooo0028ooooo`03o`000?oooooo
oooo00Kooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<
c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03
ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000Ko
ooooob4Q8OnHV9SooooooiRHV?lQ8B45ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`20ooooo`00
R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0Ooooool008So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^
kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Cooooo1_l000001_oooooo<S8boiRHV?ooooooV9RHoc8b<Poooooo00?oMgMgoc8b<_ooool0P?oo
ool008Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00_ooooo00Goc<c<o`000?l0003o0000olc<c00<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0POooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41003?ooool00ol0003oooooooooo`23ooooo`00QOooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj
^[[o000000cooooo00?o0000ooooooooool0Poooool008Gooooo1ol00005ooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT03?ooool4o`0008;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.06168 .41272 L
.08481 .41296 L
.09599 .41303 L
.10656 .4131 L
.11606 .41317 L
.12636 .41328 L
.14691 .41358 L
.15737 .41374 L
.16889 .41389 L
.17965 .414 L
.18972 .41407 L
.20104 .41413 L
.2118 .4142 L
.22197 .4143 L
.23306 .41443 L
.25251 .4147 L
.25809 .41477 L
.26335 .41483 L
.26812 .41487 L
.27317 .4149 L
.2758 .41492 L
.27868 .41493 L
.2813 .41494 L
.28375 .41494 L
.28523 .41495 L
.28664 .41495 L
.28927 .41495 L
.29074 .41495 L
.29211 .41495 L
.29519 .41495 L
.29756 .41496 L
.30006 .41496 L
.30136 .41496 L
.30279 .41496 L
.30411 .41496 L
.3053 .41496 L
.30768 .41496 L
.31022 .41497 L
.31257 .41497 L
.31479 .41498 L
.32019 .415 L
.32517 .41503 L
.33642 .4151 L
.34592 .41515 L
.34865 .41517 L
.35125 .41518 L
.35358 .41519 L
.35489 .41519 L
Mistroke
.35612 .41519 L
.35683 .41519 L
.3576 .41519 L
.35894 .4152 L
.3597 .4152 L
.3605 .4152 L
.36118 .4152 L
.36193 .41519 L
.36328 .41519 L
.36403 .41519 L
.36472 .41519 L
.36607 .41519 L
.36732 .41518 L
.3699 .41517 L
.3727 .41515 L
.37779 .41512 L
.38793 .41501 L
.39743 .41489 L
.41908 .41463 L
.43852 .41447 L
.44384 .41442 L
.44953 .41436 L
.45976 .41422 L
.47081 .41401 L
.48084 .41376 L
.50301 .41317 L
.51282 .41294 L
.52319 .41276 L
.53457 .4126 L
.54504 .41247 L
.56587 .4122 L
.57497 .41207 L
.58488 .41194 L
.58752 .41192 L
.59033 .41189 L
.59273 .41188 L
.5941 .41187 L
.59538 .41187 L
.5966 .41186 L
.59788 .41186 L
.59897 .41186 L
.60017 .41187 L
.60147 .41187 L
.60285 .41188 L
.60415 .41189 L
.60534 .41189 L
.60816 .41193 L
.61075 .41196 L
.61663 .41208 L
.6218 .41223 L
Mistroke
.62729 .41242 L
.63718 .41287 L
.64782 .41348 L
.66704 .41484 L
.67766 .41577 L
.68925 .41702 L
.70031 .4185 L
.71035 .42016 L
.73102 .42455 L
.75304 .43055 L
.77497 .4377 L
.79513 .44559 L
.83563 .46637 L
.87712 .49156 L
.91701 .51712 L
.92842 .52422 L
.93923 .53028 L
.94975 .53517 L
.95437 .53692 L
.95947 .53853 L
.96433 .53975 L
.96889 .5406 L
.9714 .54095 L
.9737 .54121 L
.97623 .54141 L
.9775 .54149 L
.97889 .54155 L
.97957 .54158 L
.98032 .5416 L
.98166 .54162 L
.98297 .54163 L
.98418 .54162 L
.98549 .5416 L
.98623 .54158 L
.98692 .54156 L
.98983 .54144 L
.99239 .54129 L
.99473 .54113 L
1 .54072 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolQo`0007[ooooo:_l00025
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01koooooN_l0000Zoooo
o`co0000NOooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3>ooooo`Oo
0000L_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Eooooo`Co0000
K_ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0=Wooooo
1Ol0001Yooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
g_ooool3o`0006Kooooo000Nooooo`?o0000hOooool4o`0006;ooooo000Nooooo`03o`000?oooooo
oooo0>Gooooo0ol0001Oooooo`007_ooool00ol0003oooooooooo`3Xooooo`Co0000Foooool001ko
oooo00?o0000ooooooooool0k?ooool3o`0005Sooooo000Nooooo`03o`000?oooooooooo0>oooooo
0_l0001Fooooo`007_ooool00ol0003oooooooooo`3aooooo`;o0000E?ooool001kooooo00?o0000
ooooooooool0loooool00ol0003oooooooooo`1Aooooo`007_ooool3o`000?Cooooo0_l0001Aoooo
o`007_ooool00ol0003oooooooooo`3fooooo`;o0000Coooool001kooooo00?o0000ooooooooool0
n?ooool00ol0003oooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`3iooooo`;o0000C?oo
ool001kooooo00?o0000ooooooooool0noooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo
0?gooooo0_l00018ooooo`007_ooool3o`000?oooooo0_l00016ooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`3oooooo`Cooooo00?o
0000ooooooooool0@Oooool001kooooo00?o0000ooooooooool0ooooool5ooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool0ooooool7ooooo`;o0000?oooool001kooooo00?o0000oooooooo
ool0ooooool9ooooo`;o0000?Oooool001kooooo0ol0003oooooo`_ooooo00?o0000ooooooooool0
>_ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`;o0000>_ooool001kooooo00?o0000
ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo3oooool2o`0003Oooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0doooo
o`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooolBooooo`;o0000=?ooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolDooooo`03o`000?oooooooooo037o
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3ooooooaGooooo0_l0000aooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0
;_ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo6?ooool2o`0002kooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003ooooooooo
o`0[ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oo
oooooooo0?oooooo6oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool2
o`0002Wooooo000Nooooo`?o0000oooooolOooooo`?o00009_ooool001kooooo00?o0000oooooooo
ool0oooooolRooooo`Ko00000_ooool5o`0001Wooooo000Nooooo`03o`000?oooooooooo0?oooooo
:?ooool3o`0001gooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o
0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool0
01Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o0000
0?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWo
oooo002=ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zj
ooooo`2dooooo`00SOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`04ooooo`;o<S8b]Oooool008?ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool2ob4Q
8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07cooooo0025oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo
00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@
413ooooo1_l00002ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool2ob4Q8@Kooooo00?oEEEE
ojVYZOooool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`1jooooo`00QOooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool6o`0000;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0>ooooo`03ob4Q8Ooooooooooo00Kooooo
00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Goc<c<o`000?l0003o0000olc<c00>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01looooo`00P_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`0Aoooo
o`03oa0@4?l0003o000000?o00002_ooool01Ol@413o^[Zjoooooonj^[[o410@00kooooo00?oZJVY
ogMgMoooool00oooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj
^[[o000000_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo07kooooo
0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Gooooo00?o
0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00_ooooo1Ol00004ooooo`Co0000
OOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.06168 .41273 L
.06747 .41281 L
.07365 .41288 L
.08481 .41298 L
.10473 .41308 L
.11019 .41312 L
.11598 .41316 L
.12636 .41327 L
.137 .41341 L
.14873 .4136 L
.15977 .41377 L
.16988 .4139 L
.17487 .41394 L
.18033 .41398 L
.18548 .41401 L
.19026 .41404 L
.20154 .41408 L
.20708 .4141 L
.21218 .41413 L
.21721 .41417 L
.22253 .41422 L
.23373 .41435 L
.25327 .41461 L
.25838 .41467 L
.26322 .41472 L
.26589 .41474 L
.2688 .41476 L
.27122 .41477 L
.27389 .41478 L
.27509 .41478 L
.27639 .41479 L
.27751 .41479 L
.27873 .41479 L
.28004 .41479 L
.28142 .41479 L
.2827 .41479 L
.28388 .41479 L
.28509 .41479 L
.28623 .41479 L
.28725 .41479 L
.28836 .41479 L
.29314 .41478 L
.29793 .41477 L
.30057 .41477 L
.30307 .41476 L
.30449 .41476 L
.30602 .41476 L
.3067 .41476 L
Mistroke
.30742 .41476 L
.30872 .41476 L
.30941 .41476 L
.31015 .41476 L
.31149 .41476 L
.3128 .41476 L
.31401 .41476 L
.31529 .41476 L
.31666 .41476 L
.31913 .41477 L
.32208 .41478 L
.32476 .41479 L
.3361 .41485 L
.34584 .41491 L
.34821 .41492 L
.35076 .41493 L
.35222 .41493 L
.35356 .41494 L
.35484 .41494 L
.35618 .41494 L
.35754 .41494 L
.3583 .41495 L
.35899 .41495 L
.36033 .41494 L
.3616 .41494 L
.36232 .41494 L
.36308 .41494 L
.36444 .41494 L
.36591 .41493 L
.36752 .41492 L
.37013 .41491 L
.37293 .41489 L
.37799 .41484 L
.39877 .41457 L
.40973 .41443 L
.41574 .41437 L
.42139 .41433 L
.4317 .41426 L
.44309 .41421 L
.4478 .41418 L
.45276 .41414 L
.4582 .41408 L
.46319 .41402 L
.4732 .41385 L
.48389 .41363 L
.49392 .41341 L
.50317 .41324 L
.50828 .41316 L
.51391 .41309 L
.51683 .41306 L
Mistroke
.51957 .41304 L
.52245 .41303 L
.52408 .41302 L
.52556 .41302 L
.52686 .41301 L
.52825 .41301 L
.52956 .41301 L
.53075 .41301 L
.53148 .41301 L
.53215 .41301 L
.53288 .41301 L
.53366 .41301 L
.53497 .41302 L
.53641 .41302 L
.53898 .41302 L
.54174 .41303 L
.54671 .41305 L
.56753 .41311 L
.57323 .41313 L
.57611 .41314 L
.57929 .41315 L
.58199 .41317 L
.5849 .41319 L
.58764 .41321 L
.59016 .41324 L
.59521 .41332 L
.5999 .41342 L
.60506 .41356 L
.61056 .41376 L
.6218 .41432 L
.63202 .41501 L
.65218 .41674 L
.67402 .41907 L
.69491 .42197 L
.71701 .42629 L
.73758 .43161 L
.75681 .43742 L
.7976 .4522 L
.84096 .47298 L
.88273 .49326 L
.90382 .5025 L
.9229 .50989 L
.92804 .51153 L
.93358 .51304 L
.93613 .51362 L
.93881 .51416 L
.94133 .51457 L
.94362 .51487 L
.94488 .51501 L
.94625 .51512 L
Mistroke
.947 .51518 L
.94769 .51522 L
.94906 .51528 L
.95023 .5153 L
.95152 .51531 L
.95287 .51528 L
.95414 .51523 L
.95485 .51519 L
.95562 .51513 L
.95703 .515 L
.95969 .51467 L
.96278 .51413 L
.96566 .51347 L
.97011 .51218 L
.97493 .51041 L
.98367 .50637 L
1 .49692 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolNo`00087ooooo1ol0002T
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01_oooooPOl00007oooo
oako0000Q_ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`31ooooo`go
0000NOooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3>ooooo`Go0000
M?ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0=?ooooo
0ol0001aooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
e_ooool5o`0006cooooo000Nooooo`?o0000foooool5o`0006Oooooo000Nooooo`03o`000?oooooo
oooo0>3ooooo0ol0001Tooooo`007_ooool00ol0003oooooooooo`3Sooooo`?o0000HOooool001ko
oooo00?o0000ooooooooool0i_ooool3o`0005kooooo000Nooooo`03o`000?oooooooooo0>Wooooo
0ol0001Kooooo`007_ooool00ol0003oooooooooo`3/ooooo`?o0000F?ooool001kooooo00?o0000
ooooooooool0koooool2o`0005Kooooo000Nooooo`?o0000lOooool2o`0005Cooooo000Nooooo`03
o`000?oooooooooo0??ooooo0_l0001Booooo`007_ooool00ol0003oooooooooo`3eooooo`;o0000
D?ooool001kooooo00?o0000ooooooooool0moooool2o`0004kooooo000Nooooo`03o`000?oooooo
oooo0?Wooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`3kooooo`;o0000B_ooool001ko
oooo0ol0003mooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0ooooool2o`0004Kooooo
000Nooooo`03o`000?oooooooooo0?oooooo0_ooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo0?oooooo1?ooool2o`0004;ooooo000Nooooo`03o`000?oooooooooo0?oooooo1_ooool2o`00
043ooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003kooooo000Nooooo`?o0000
ooooool:ooooo`;o0000??ooool001kooooo00?o0000ooooooooool0ooooool<ooooo`?o00007_oo
ool2o`0001Wooooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool2o`0001[ooooo0_l0000K
ooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo0_l0000Gooooo`03o`000?oooooooooo
01_ooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?oooooo4oooool3o`0001;ooooo0_l0000Nooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooolFooooo`Co00003?ooool2o`00023ooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?oooooo6_ooool5o`000003ooooool0003o000000Co
00008_ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?oooooo7_ooool3o`0002Oooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Eooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2]ooooo`00UOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b[_ooool008[ooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01?l@413o0000odA4A?o<c<`6
ooooo`;o8B4QQoooool008cooooo00?o0000ooooooooool01_ooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00003ooooo`03oiRHV?l@413ogMgM00Gooooo0_lQ8B67
ooooo`00S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03_ooool00on7QhOoEEEEooooo`2=ooooo`00S?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`000006ooooooo<c<co
8B4Qo`000?mEEEGo0000S_ooool008cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00_ooooo00Go8B4QohN7QoooooooV9RHo`00002>ooooo`00
ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooo
ooooool04?ooool00ol@413o0000o`000003o`0000[ooooo00Go0000ooooooooooooooooo`00002>
ooooo`00ROooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE08kooooo0029ooooo`Oo00001Oooool2
o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000ooooooooool02oooool0
1Oo<c<co410@o`000?lb<S;ok^k^08kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.25) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.06168 .41274 L
.06747 .41282 L
.07365 .41289 L
.0795 .41294 L
.08481 .41298 L
.0953 .41303 L
.10104 .41306 L
.10641 .41308 L
.1159 .41314 L
.12094 .41319 L
.12636 .41325 L
.14646 .41354 L
.15778 .41372 L
.16829 .41385 L
.17342 .4139 L
.1789 .41394 L
.18202 .41395 L
.18497 .41397 L
.19048 .41398 L
.20073 .41401 L
.2059 .41402 L
.20883 .41403 L
.21157 .41405 L
.21689 .41408 L
.22175 .41412 L
.23265 .41423 L
.25205 .41448 L
.2571 .41454 L
.26246 .41459 L
.26704 .41462 L
.26964 .41463 L
.27209 .41464 L
.27336 .41464 L
.27475 .41465 L
.27546 .41465 L
.27621 .41465 L
.27756 .41465 L
.27891 .41465 L
.28019 .41465 L
.28134 .41465 L
.28258 .41464 L
.28394 .41464 L
.28544 .41464 L
.28846 .41463 L
.29389 .41461 L
.29936 .41459 L
.30206 .41458 L
.30456 .41457 L
Mistroke
.30701 .41457 L
.30922 .41456 L
.31049 .41456 L
.31168 .41456 L
.31295 .41456 L
.31431 .41456 L
.31568 .41456 L
.31696 .41456 L
.3177 .41456 L
.31837 .41456 L
.31987 .41457 L
.32289 .41457 L
.32574 .41459 L
.33077 .41461 L
.33624 .41464 L
.34141 .41467 L
.34698 .4147 L
.34954 .41471 L
.35224 .41472 L
.35335 .41473 L
.35454 .41473 L
.35584 .41473 L
.35705 .41473 L
.35841 .41474 L
.35917 .41474 L
.35988 .41473 L
.36118 .41473 L
.36255 .41473 L
.36378 .41473 L
.36493 .41472 L
.36755 .41471 L
.37047 .4147 L
.37313 .41468 L
.37912 .41462 L
.38964 .41449 L
.40083 .41434 L
.41037 .41424 L
.41581 .41419 L
.41825 .41418 L
.42092 .41416 L
.4233 .41415 L
.42584 .41415 L
.42724 .41414 L
.42852 .41414 L
.42981 .41414 L
.43101 .41413 L
.43329 .41413 L
.4345 .41413 L
.43577 .41413 L
.44027 .41413 L
Mistroke
.44274 .41413 L
.44413 .41412 L
.4454 .41412 L
.44786 .41412 L
.4502 .41411 L
.45291 .4141 L
.45543 .41409 L
.45819 .41408 L
.46114 .41406 L
.46677 .41401 L
.47195 .41395 L
.48363 .41379 L
.48892 .41371 L
.49459 .41363 L
.49949 .41358 L
.50226 .41355 L
.50482 .41353 L
.5074 .41352 L
.5087 .41351 L
.50945 .41351 L
.51013 .41351 L
.51138 .41351 L
.51273 .41351 L
.51392 .41351 L
.51517 .41351 L
.5163 .41351 L
.5175 .41352 L
.51967 .41353 L
.52225 .41355 L
.5246 .41357 L
.52996 .41363 L
.53576 .41371 L
.5463 .4139 L
.56678 .4143 L
.57763 .41453 L
.58361 .41467 L
.58929 .41483 L
.59464 .41501 L
.60047 .41525 L
.61068 .41581 L
.62106 .41656 L
.63068 .41742 L
.67184 .42229 L
.69438 .42582 L
.71558 .43025 L
.75613 .44166 L
.79926 .45612 L
.8408 .47284 L
.86171 .48053 L
.88075 .48608 L
Mistroke
.89059 .4884 L
.90129 .4905 L
.90716 .49146 L
.91258 .49217 L
.91526 .49246 L
.91777 .49268 L
.92039 .49286 L
.92177 .49292 L
.92254 .49295 L
.92327 .49298 L
.92394 .493 L
.92466 .49301 L
.92593 .49302 L
.92665 .49302 L
.92741 .49301 L
.92877 .49298 L
.93002 .49293 L
.9312 .49286 L
.93249 .49277 L
.93387 .49265 L
.93698 .49228 L
.93993 .49179 L
.94257 .49122 L
.94545 .49047 L
.95076 .48869 L
.9564 .48618 L
.96654 .48005 L
.97484 .47351 L
.9838 .46514 L
1 .44785 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolOo`000?oooooo;?ooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Loooooiko0000SOooool001Oo
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`2jooooo`[o0000Poooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`34ooooo`[o0000NOooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0<kooooo1Ol0001dooooo`005?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0doooool3o`00077ooooo
000Nooooo`?o0000e_ooool4o`0006gooooo000Nooooo`03o`000?oooooooooo0=[ooooo1?l0001Y
ooooo`007_ooool00ol0003oooooooooo`3Nooooo`Co0000IOooool001kooooo00?o0000oooooooo
ool0h_ooool3o`0006;ooooo000Nooooo`03o`000?oooooooooo0>Gooooo0ol0001Oooooo`007_oo
ool00ol0003oooooooooo`3Xooooo`?o0000@_ooool00ol0003oooooooooo`0Gooooo`007_ooool0
0ol0003oooooooooo`3[ooooo`;o0000?oooool00ol0003oooooooooo`0Hooooo`007_ooool3o`00
0>gooooo0ol0000kooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?3o
oooo0_l0000hooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?;ooooo
0ol0000dooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?Gooooo0ol0
000`ooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?Sooooo0_l0000]
ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?[ooooo0ol0000Yoooo
o`03o`000?oooooooooo01kooooo000Nooooo`?o0000oOooool3o`0002Gooooo00?o0000oooooooo
ool07oooool001kooooo00?o0000ooooooooool0ooooool1ooooo`?o00008Oooool00ol0003ooooo
ooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooo`Cooooo0ol0000Looooo`;o00008ooo
ool001kooooo00?o0000ooooooooool0ooooool7ooooo`?o00006?ooool00ol0003oooooooooo`0S
ooooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo1_l0000>ooooo`Co00009_ooool001ko
oooo00?o0000ooooooooool0ooooool@ooooo`?o00002Oooool2o`0002[ooooo000Nooooo`?o0000
oooooolCooooo`Wo0000;?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001Oooool00onHV9So
8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRH
V?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo
0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_oooooo
MgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0
003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q
8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Co
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002=ooooo`;o0000
2oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2dooooo`00SOoo
ool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b]Ooo
ool008?ooooo00Go410@o`000?l0003o0000oa0@4005ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
0oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P09ooooo`04oa0@4?l0003oA4A4olc<c0Kooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00004ooooo`03oiRHV?l@413ogMgM
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`1k
ooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`00
0?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03_ooool00on7QhOoEEEEooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool0N_ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05olc<c?lQ8B7o0000oeEEEOl000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05ob4Q8On7
QhOooooooiRHV?l000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Co
oooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000[ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O_ooool008;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooo
oooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.5) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .4124 L
.06168 .41274 L
.06747 .41282 L
.07365 .41289 L
.0795 .41294 L
.08481 .41297 L
.0953 .41302 L
.10104 .41304 L
.10641 .41306 L
.11099 .41309 L
.1159 .41312 L
.12136 .41317 L
.12636 .41322 L
.14646 .41351 L
.15778 .41368 L
.16329 .41375 L
.16829 .4138 L
.17325 .41385 L
.17793 .41388 L
.18051 .41389 L
.18288 .4139 L
.18564 .41391 L
.18822 .41392 L
.19065 .41392 L
.19326 .41392 L
.1988 .41393 L
.2018 .41394 L
.20465 .41394 L
.2072 .41395 L
.20998 .41396 L
.21507 .41398 L
.21985 .41401 L
.22509 .41405 L
.23074 .41411 L
.24128 .41424 L
.2528 .41437 L
.25807 .41443 L
.26097 .41445 L
.2637 .41447 L
.26625 .41448 L
.26759 .41449 L
.26902 .4145 L
.27021 .4145 L
.27153 .4145 L
.27272 .41451 L
.27384 .41451 L
.27521 .41451 L
.27599 .41451 L
.27671 .41451 L
Mistroke
.27802 .41451 L
.27876 .41451 L
.27942 .41451 L
.28069 .41451 L
.28205 .4145 L
.28452 .4145 L
.2905 .41447 L
.296 .41445 L
.30095 .41443 L
.30367 .41442 L
.30625 .41441 L
.30864 .4144 L
.31 .4144 L
.31125 .4144 L
.3123 .4144 L
.31346 .41439 L
.31467 .41439 L
.3158 .41439 L
.31707 .4144 L
.31779 .4144 L
.31846 .4144 L
.31982 .4144 L
.32126 .4144 L
.32388 .41441 L
.32626 .41442 L
.33205 .41445 L
.33751 .41448 L
.34775 .41454 L
.35024 .41455 L
.35291 .41457 L
.35444 .41457 L
.35583 .41457 L
.35651 .41457 L
.35724 .41458 L
.35857 .41458 L
.35977 .41458 L
.36089 .41458 L
.36212 .41458 L
.36345 .41458 L
.36477 .41457 L
.36615 .41457 L
.36864 .41456 L
.37094 .41455 L
.37309 .41453 L
.37796 .4145 L
.39761 .41428 L
.40299 .41422 L
.40869 .41418 L
.41104 .41416 L
.41356 .41415 L
Mistroke
.41501 .41414 L
.41633 .41414 L
.41769 .41413 L
.41892 .41413 L
.4203 .41413 L
.42106 .41413 L
.42177 .41413 L
.42304 .41413 L
.42441 .41413 L
.42514 .41413 L
.42593 .41413 L
.42676 .41413 L
.42753 .41413 L
.4304 .41414 L
.43316 .41415 L
.43567 .41416 L
.44131 .41418 L
.44651 .4142 L
.44926 .41421 L
.45217 .41422 L
.4534 .41422 L
.45472 .41423 L
.45547 .41423 L
.45616 .41423 L
.45752 .41423 L
.45867 .41423 L
.45993 .41423 L
.46124 .41423 L
.46246 .41423 L
.4638 .41423 L
.46522 .41422 L
.46777 .41421 L
.47051 .4142 L
.47352 .41419 L
.48396 .41412 L
.48882 .41409 L
.4915 .41408 L
.49282 .41408 L
.49405 .41407 L
.49528 .41407 L
.49641 .41406 L
.49765 .41406 L
.49898 .41406 L
.50009 .41406 L
.5013 .41406 L
.50243 .41406 L
.50348 .41407 L
.50481 .41407 L
.50607 .41408 L
.50844 .41409 L
Mistroke
.51098 .41411 L
.51374 .41414 L
.51871 .41422 L
.5233 .4143 L
.53384 .41457 L
.54502 .41492 L
.56575 .41564 L
.58473 .41638 L
.59517 .41689 L
.6051 .41752 L
.61558 .41837 L
.62702 .41952 L
.66968 .42514 L
.71076 .43259 L
.73323 .4382 L
.75441 .44408 L
.79487 .45555 L
.81539 .46177 L
.83791 .46844 L
.84825 .47103 L
.85395 .47223 L
.85935 .47321 L
.86436 .47396 L
.86981 .47461 L
.87222 .47483 L
.87477 .47503 L
.87696 .47518 L
.87936 .4753 L
.88057 .47535 L
.88186 .47539 L
.88322 .47542 L
.88449 .47544 L
.88576 .47546 L
.88695 .47546 L
.88803 .47545 L
.88919 .47544 L
.89047 .47542 L
.89119 .4754 L
.89187 .47538 L
.89471 .47528 L
.89716 .47515 L
.8998 .47496 L
.90494 .47448 L
.90982 .47385 L
.91421 .47311 L
.91899 .47212 L
.92458 .47064 L
.92984 .46889 L
.93967 .46448 L
.94519 .46125 L
Mistroke
.95026 .45774 L
.96171 .44776 L
.97997 .42602 L
1 .39654 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03
o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003ooooo
ooooo`3oooooobgooooo00?o0000ooooooooool06?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000E
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo7ol0003oooooo`oooooo00?o0000ooooooooool06_ooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Loooooi7o0000O?ooool00ol0
003oooooooooo`0Kooooo`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0:go
oooo4ol0001Yooooo`03o`000?oooooooooo01_ooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0`?ooool7o`00067ooooo00?o0000ooooooooool07?ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0<Oooooo1_l0001Jooooo`03o`00
0?oooooooooo01gooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`3=ooooo`Ko0000E?ooool00ol0003oooooooooo`0Mooooo`007_ooool3o`000=?ooooo1Ol0
001>ooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0=Sooooo0ol0001:
ooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0=_ooooo1?l00015oooo
o`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0=oooooo0ol00011ooooo`03
o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0>;ooooo0ol0000mooooo`03o`00
0?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0>Gooooo1Ol0000gooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0>[ooooo1?l0000booooo`03o`000?oooooo
oooo02Cooooo000Nooooo`?o0000k_ooool4o`0002gooooo00?o0000ooooooooool09Oooool001ko
oooo00?o0000ooooooooool0l_ooool3o`0002Sooooo0_l0000Xooooo`007_ooool00ol0003ooooo
ooooo`3eooooo`?o00009?ooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003ooooooooo
o`3hooooo`?o00007oooool2o`0002_ooooo000Nooooo`03o`000?oooooooooo0?_ooooo1?l0000H
ooooo`?o0000;Oooool001kooooo00?o0000ooooooooool0ooooool3o`0001;ooooo0ol0000`oooo
o`007_ooool3o`000?oooooo0ooooolBo`0003?ooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8oooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooodSo
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o
0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo
00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo000Gooooo`03ojVYZOl@
413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool0
01Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413oV9RHoooooonj^[[o0000
0?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooe3ooooo003oooooofWo
oooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003ooooooooo
o`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@4006ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X02Oooool01?l@413o0000odA4A?o<c<`6ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM087ooooo0028ooooo`03o`000?oooooooooo00Kooooo00[o0000
ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o
410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00000oooool00onHV9So410@omgM
g@05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`20ooooo`00R?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00on7QhOoEEEEoooo
o`0?ooooo`03o`000?oooooooooo07oooooo0028ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Ko000000Koooooolc<c?lQ8B7o0000
oeEEEOl0000?ooooo`03ogMgMolb<S;ooooo083ooooo0028ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05ob4Q8On7QhOooooooiRH
V?l000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<087ooooo0025ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0
003o000000?o00002_ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool0
Poooool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@0<ooooo`03o`000?oooooooooo08?o
oooo0025ooooo`Oo00001Oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo
00?o0000ooooooooool02oooool01Oo<c<co410@o`000?lb<S;ok^k^00cooooo1?l00022ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.75) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41239 L
.06168 .41272 L
.06747 .4128 L
.07365 .41287 L
.0795 .41292 L
.08481 .41295 L
.0953 .413 L
.10104 .41302 L
.10641 .41304 L
.11137 .41306 L
.1159 .41309 L
.12094 .41313 L
.12636 .41319 L
.14646 .41346 L
.15778 .41363 L
.16329 .41369 L
.16829 .41374 L
.17325 .41378 L
.17793 .41381 L
.18051 .41382 L
.18288 .41383 L
.18547 .41384 L
.18822 .41384 L
.19872 .41386 L
.20175 .41386 L
.20461 .41386 L
.20718 .41387 L
.20998 .41388 L
.21245 .41388 L
.21517 .4139 L
.22069 .41393 L
.2258 .41397 L
.2306 .41401 L
.24985 .41423 L
.2552 .41428 L
.26017 .41432 L
.26289 .41434 L
.26536 .41436 L
.26811 .41437 L
.26962 .41437 L
.27104 .41438 L
.27216 .41438 L
.2734 .41438 L
.27469 .41438 L
.27589 .41438 L
.27702 .41438 L
.27805 .41438 L
.27924 .41438 L
.28036 .41438 L
Mistroke
.28287 .41437 L
.2852 .41437 L
.29047 .41435 L
.29582 .41432 L
.3016 .4143 L
.30425 .41429 L
.30705 .41428 L
.30821 .41428 L
.30944 .41428 L
.3108 .41427 L
.31206 .41427 L
.31337 .41427 L
.31458 .41427 L
.31591 .41427 L
.31658 .41427 L
.31732 .41427 L
.31856 .41428 L
.31989 .41428 L
.3223 .41428 L
.32467 .41429 L
.32716 .4143 L
.33161 .41433 L
.34166 .4144 L
.34718 .41443 L
.34989 .41445 L
.35238 .41446 L
.3547 .41447 L
.35724 .41448 L
.35856 .41448 L
.3598 .41448 L
.3611 .41449 L
.36183 .41449 L
.3625 .41449 L
.36367 .41449 L
.36476 .41449 L
.36595 .41449 L
.36721 .41448 L
.36831 .41448 L
.36934 .41448 L
.37168 .41447 L
.37423 .41446 L
.3766 .41445 L
.38199 .41441 L
.39285 .41432 L
.39767 .41428 L
.40223 .41425 L
.40475 .41423 L
.40749 .41422 L
.4087 .41422 L
.40998 .41421 L
Mistroke
.41107 .41421 L
.41227 .41421 L
.41362 .41421 L
.41488 .41421 L
.41626 .41421 L
.41703 .41421 L
.41773 .41421 L
.41902 .41421 L
.42041 .41422 L
.42292 .41423 L
.42539 .41424 L
.428 .41426 L
.43266 .41429 L
.44325 .41439 L
.45459 .4145 L
.46014 .41454 L
.46539 .41457 L
.4701 .41459 L
.47523 .4146 L
.48001 .41462 L
.48516 .41463 L
.48753 .41464 L
.49003 .41465 L
.49448 .41467 L
.49693 .41469 L
.4992 .41471 L
.50436 .41478 L
.50963 .41486 L
.51526 .41499 L
.52682 .41534 L
.53733 .41576 L
.55918 .41678 L
.57933 .4178 L
.59896 .41905 L
.60886 .41988 L
.61974 .42098 L
.66212 .42666 L
.7029 .43347 L
.74626 .44337 L
.78803 .45272 L
.80912 .45703 L
.82821 .46054 L
.83334 .46131 L
.83889 .46202 L
.84143 .46229 L
.84412 .46254 L
.84663 .46274 L
.84892 .46288 L
.85019 .46294 L
.85155 .463 L
Mistroke
.85231 .46302 L
.853 .46304 L
.85437 .46307 L
.85554 .46309 L
.85683 .46309 L
.85818 .46308 L
.85944 .46306 L
.86015 .46304 L
.86093 .46302 L
.86234 .46297 L
.86499 .46282 L
.86809 .46259 L
.87097 .4623 L
.87629 .4616 L
.88205 .4606 L
.8925 .45813 L
.90268 .45492 L
.91204 .45118 L
.92157 .44645 L
.93179 .44005 L
.94301 .43102 L
.95349 .42027 L
.97578 .38929 L
.9969 .35196 L
1 .3462 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool^oooo
o`03o`000?oooooooooo01Oooooo000Nooooo`?o0000ooooool^ooooo`03o`000?oooooooooo01Oo
oooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_oo
ool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool001kooooo00?o0000
ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob_o
oooo00?o0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`00
0?oooooooooo01_ooooo000Nooooo`?o0000oooooolYooooo`03o`000?oooooooooo01cooooo000N
ooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0
003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000oooooooo
ool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo
9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o
0000ooooooooool07oooool001kooooo0ol0003oooooobKooooo00?o0000ooooooooool07oooool0
01kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03
o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003ooooo
ooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000E
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo8Ol0003oooooo`Cooooo00?o0000ooooooooool08oooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0NooooohOo0000Noooool00ol0
003oooooooooo`0Tooooo`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0:Go
oooo4Ol0001Zooooo`03o`000?oooooooooo02Cooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0]_ooool7o`0006;ooooo00?o0000ooooooooool09Oooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0;gooooo1ol0001Jooooo`03o`00
0?oooooooooo02Kooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`34ooooo`Ko0000Doooool00ol0003oooooooooo`0Wooooo`007_ooool3o`000<[ooooo1ol0
001:ooooo`;o0000:_ooool001kooooo00?o0000ooooooooool0dOooool5o`0004Cooooo00?o0000
ooooooooool0:_ooool001kooooo00?o0000ooooooooool0e_ooool5o`0003kooooo00?o0000oooo
ooooool0:oooool001kooooo00?o0000ooooooooool0foooool4o`0003Sooooo0_l0000^ooooo`00
7_ooool00ol0003oooooooooo`3Oooooo`Co0000<oooool00ol0003oooooooooo`0^ooooo`007_oo
ool00ol0003oooooooooo`3Sooooo`Go0000;?ooool2o`00037ooooo000Nooooo`03o`000?oooooo
oooo0>Sooooo1?l0000Uooooo`?o0000<oooool001kooooo0ol0003/ooooo`Go00007Oooool3o`00
03Kooooo000Nooooo`03o`000?oooooooooo0?7ooooo1_l0000Dooooo`?o0000>Oooool001kooooo
00?o0000ooooooooool0moooool7o`0000Sooooo1Ol0000looooo`007_ooool00ol0003ooooooooo
o`3nooooo`So0000@Oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o
0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00SOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo
00?o0000okZj^_ooool0]?ooool008gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool01?ooool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o0000o`000?l@41001Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01?l@413o0000odA4A?o<c<`6oooo
o`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0O?ooool0
08Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^ko
MgMgoa0@4?ooool6o`0000Cooooo00?oV9RHoa0@4?oMgMd01Oooool2ob4Q8@Kooooo00?oEEEEojVY
ZOooool01oooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00on7QhOoEEEEooooo`0<oooo
o`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool0N_ooool008Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002oooo
o`05olc<c?lQ8B7o0000oeEEEOl000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;o
oooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ
8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`05ob4Q8On7QhOooooooiRHV?l000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0O?ooool008;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000
o`000003o`0000[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOmgMgOooooo00?o
oooo00?o0000ooooooooool0O_ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@0;oooo
o`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`1nooooo`00P_ooool7o`00
00Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo
00_ooooo00Goc<c<oa0@4?l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0007gooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41239 L
.06168 .4127 L
.06747 .41277 L
.07365 .41284 L
.08481 .41292 L
.10473 .41301 L
.11019 .41303 L
.11598 .41307 L
.12636 .41316 L
.137 .41328 L
.14873 .41345 L
.15977 .41359 L
.16988 .41369 L
.17487 .41372 L
.17751 .41373 L
.18033 .41375 L
.18303 .41376 L
.18548 .41376 L
.18794 .41377 L
.19026 .41377 L
.20092 .41379 L
.20351 .41379 L
.20629 .41379 L
.20933 .4138 L
.21218 .41381 L
.21784 .41384 L
.22321 .41387 L
.23326 .41396 L
.25266 .41416 L
.25789 .4142 L
.26279 .41423 L
.26546 .41425 L
.26791 .41426 L
.27063 .41427 L
.27206 .41427 L
.27283 .41427 L
.27356 .41427 L
.27477 .41427 L
.27588 .41427 L
.27706 .41428 L
.27835 .41427 L
.27947 .41427 L
.28066 .41427 L
.28168 .41427 L
.2828 .41427 L
.28532 .41426 L
.28802 .41426 L
.2929 .41424 L
.29806 .41422 L
Mistroke
.30088 .41422 L
.30354 .41421 L
.30506 .41421 L
.3067 .4142 L
.30742 .4142 L
.30819 .4142 L
.30956 .4142 L
.31094 .4142 L
.31222 .4142 L
.31296 .4142 L
.31363 .4142 L
.3144 .4142 L
.31514 .4142 L
.31635 .4142 L
.31769 .41421 L
.3204 .41421 L
.3229 .41422 L
.32525 .41423 L
.33624 .4143 L
.34659 .41438 L
.35224 .41442 L
.35498 .41443 L
.35748 .41445 L
.35964 .41446 L
.36197 .41446 L
.36326 .41447 L
.36444 .41447 L
.36557 .41447 L
.36677 .41447 L
.36798 .41447 L
.36927 .41447 L
.37049 .41447 L
.37161 .41447 L
.37291 .41447 L
.37433 .41447 L
.37692 .41446 L
.37936 .41445 L
.382 .41444 L
.38677 .41442 L
.39197 .4144 L
.39492 .41439 L
.39766 .41438 L
.40036 .41437 L
.40114 .41437 L
.40188 .41437 L
.40326 .41437 L
.40397 .41437 L
.40473 .41437 L
.40609 .41437 L
.40684 .41437 L
Mistroke
.40755 .41437 L
.40832 .41437 L
.40916 .41437 L
.41051 .41437 L
.41198 .41438 L
.41467 .41439 L
.41728 .4144 L
.41971 .41442 L
.42504 .41447 L
.43081 .41453 L
.44127 .41468 L
.46081 .41498 L
.48135 .41522 L
.49223 .41537 L
.49833 .41548 L
.50389 .4156 L
.51491 .41592 L
.52535 .41633 L
.54537 .41735 L
.58564 .41984 L
.60642 .42154 L
.62848 .42401 L
.66814 .42955 L
.71037 .43635 L
.75102 .44415 L
.77166 .4475 L
.78258 .44895 L
.79424 .45029 L
.80554 .45136 L
.8158 .45212 L
.82076 .45237 L
.82355 .45248 L
.82488 .45252 L
.82612 .45255 L
.82721 .45257 L
.82838 .45259 L
.82967 .4526 L
.83085 .45261 L
.83208 .4526 L
.83342 .45259 L
.83469 .45256 L
.83586 .45254 L
.83722 .45249 L
.83865 .45243 L
.84122 .45229 L
.84397 .4521 L
.847 .45182 L
.85242 .45114 L
.85747 .45029 L
.86691 .4481 L
Mistroke
.87702 .44488 L
.88774 .44046 L
.89938 .43449 L
.90944 .42831 L
.92053 .42023 L
.94135 .40026 L
.95274 .3859 L
.96343 .36991 L
1 .29995 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
;_ooool00ol0003oooooooooo`0Gooooo`001oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003ooooooooo
o`0Gooooo`001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?oooooo;Oooool00ol0003oooooooooo`0Hoooo
o`001oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool000Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003o
ooooooooo`0Iooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01[ooooo0005ooooo`03oeEEEOmV
IVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003ooooooooo
o`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool0
01kooooo0ol0003oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000oooooooo
ool0oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo
:?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o
0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooo
oooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Noooo
o`007_ooool3o`000?oooooo9_ooool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003ooooo
ooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooo
oolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool0
0ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000oooo
ooooool08Oooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo027o
oooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_oo
ool3o`000?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3o
ooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolQoooo
o`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003o
ooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool0
9_ooool001kooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo02Kooooo000N
ooooo`?o0000oooooolNooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`3ooooooago
oooo00?o0000ooooooooool0:?ooool001kooooo00?o0000ooooooooool0oooooolLooooo`03o`00
0?oooooooooo02Wooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3ooooooa_ooooo00?o
0000ooooooooool0:_ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooobCo0000moooool00ol0003oooooooooo`0/ooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo027oooooP?l0001fooooo`03o`000?oooooooooo02gooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0XOooool9o`0006cooooo00?o0000oooooooo
ool0;_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Zoooooa3o0000
F_ooool2o`00037ooooo000Dooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003ooooo
ooooo`2jooooo`Ko0000D_ooool2o`0003?ooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`30ooooo`Ko0000B_ooool2o`0003Gooooo000Nooooo`?o0000a_oo
ool6o`0004?ooooo00?o0000ooooooooool0=Oooool001kooooo00?o0000ooooooooool0c?ooool7
o`0003[ooooo0_l0000hooooo`007_ooool00ol0003oooooooooo`3Cooooo`Ko0000<oooool00ol0
003oooooooooo`0hooooo`007_ooool00ol0003oooooooooo`3Iooooo`Ko0000:oooool2o`0003_o
oooo000Nooooo`03o`000?oooooooooo0=oooooo1ol0000Pooooo`Co0000?Oooool001kooooo00?o
0000ooooooooool0i_ooool8o`0001Gooooo0ol00011ooooo`007_ooool00ol0003oooooooooo`3^
ooooo`_o00000_ooool8o`0004Cooooo000Nooooo`?o0000nOooool2o`0004cooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool0097ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0;7ooooo002Aooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:booooo`00Q_ooool01Ol@413o0000o`000?l0
003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B63ooooo`00R?ooool00ol0003ooooooooo
o`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00ooo
ool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B63ooooo`00
R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413o
c<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100R_ooool008So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^
kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Cooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002:
ooooo`00R?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000R_oo
ool008Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`00
0?oooooooooo013ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@402:ooooo`00QOooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0R_ooool008Gooooo1ol00005ooooo`;o00004_ooool00ol0003o
ooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP2:ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.06168 .41267 L
.06747 .41274 L
.07365 .4128 L
.08481 .41288 L
.10473 .41298 L
.11019 .41301 L
.11598 .41304 L
.12636 .41313 L
.14873 .41339 L
.15892 .41351 L
.16454 .41357 L
.16988 .41361 L
.175 .41364 L
.18059 .41367 L
.18567 .41369 L
.19039 .4137 L
.19962 .41372 L
.20447 .41373 L
.2096 .41374 L
.21538 .41377 L
.2207 .41379 L
.23115 .41387 L
.25069 .41405 L
.26064 .41413 L
.26351 .41415 L
.26622 .41416 L
.26869 .41417 L
.27131 .41418 L
.27359 .41419 L
.27488 .41419 L
.2761 .41419 L
.27721 .41419 L
.27823 .4142 L
.27935 .4142 L
.28053 .4142 L
.28173 .4142 L
.28301 .4142 L
.28422 .4142 L
.28532 .4142 L
.28802 .41419 L
.29056 .41419 L
.29583 .41418 L
.29841 .41418 L
.30077 .41418 L
.30204 .41417 L
.30325 .41417 L
.30452 .41417 L
.30525 .41417 L
Mistroke
.30591 .41417 L
.30666 .41417 L
.30735 .41417 L
.30866 .41417 L
.30939 .41418 L
.31006 .41418 L
.31157 .41418 L
.3139 .41418 L
.31607 .41419 L
.31845 .4142 L
.321 .41421 L
.32621 .41424 L
.33095 .41427 L
.34151 .41435 L
.35272 .41445 L
.35733 .41448 L
.36229 .41451 L
.36514 .41452 L
.36774 .41453 L
.37284 .41455 L
.37534 .41455 L
.37804 .41456 L
.3806 .41456 L
.38295 .41456 L
.3857 .41456 L
.3886 .41457 L
.39105 .41457 L
.39243 .41457 L
.39373 .41457 L
.39626 .41458 L
.39857 .41458 L
.40106 .41459 L
.40377 .4146 L
.40864 .41463 L
.41314 .41466 L
.41773 .41471 L
.42279 .41477 L
.43305 .41493 L
.4548 .41537 L
.4768 .41582 L
.48643 .41602 L
.49698 .41628 L
.50722 .41661 L
.51675 .41699 L
.53757 .41808 L
.57853 .42081 L
.62207 .42482 L
.66402 .4302 L
.70438 .43563 L
.72481 .43859 L
Mistroke
.73565 .44013 L
.74731 .44162 L
.75846 .44281 L
.76866 .44362 L
.77356 .44391 L
.77615 .44404 L
.77891 .44415 L
.78156 .44424 L
.78396 .44431 L
.78512 .44434 L
.78637 .44436 L
.78754 .44438 L
.78865 .44439 L
.78995 .44441 L
.79114 .44441 L
.79242 .44442 L
.79315 .44442 L
.79381 .44442 L
.79493 .44441 L
.79615 .4444 L
.79743 .44439 L
.79864 .44437 L
.80139 .44432 L
.80391 .44424 L
.80668 .44414 L
.8096 .44401 L
.81507 .44367 L
.82017 .44325 L
.82575 .44264 L
.83172 .44181 L
.84249 .43971 L
.84856 .43815 L
.85415 .43643 L
.86509 .43225 L
.87531 .42731 L
.89503 .41491 L
.91671 .39678 L
.93803 .37315 L
.95749 .34478 L
.99926 .26226 L
1 .26067 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03
o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0?oooooo;_ooool00ol0003ooooo
ooooo`0Gooooo`007_ooool3o`000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool0
0ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool001kooooo00?o0000oooo
ooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oo
oooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo
00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oo
oooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0J
ooooo`007_ooool3o`000?oooooo:_ooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003o
ooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0
oooooolYooooo`03o`000?oooooooooo01cooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
:Oooool00ol0003oooooooooo`0Looooo`001oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003ooooooooo
o`0Mooooo`001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?oooooo9oooool00ol0003oooooooooo`0Noooo
o`001oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool000Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo9_ooool00ol0003o
ooooooooo`0Oooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo0005ooooo`03oeEEEOmV
IVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003ooooooooo
o`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool0
01kooooo0ol0003oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000oooooooo
ool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo
8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o
0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooo
oooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Toooo
o`007_ooool3o`000?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003ooooo
ooooo`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooo
oolOooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool0
0ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000oooo
ooooool09oooool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02So
oooo000Nooooo`03o`000?oooooooooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`007_oo
ool3o`000?oooooo6oooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`3o
oooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool0oooooolJoooo
o`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003o
ooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0
;Oooool001kooooo00?o0000ooooooooool0oooooolHooooo`03o`000?oooooooooo02gooooo000N
ooooo`?o0000oooooolGooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo
0?oooooo5_ooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003oooooooooo`3ooooooaCo
oooo0_l0000booooo`007_ooool00ol0003oooooooooo`3ooooooa?ooooo00?o0000ooooooooool0
<_ooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0?oooooo4Oooool2o`0003Gooooo000D
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3ooooooa3ooooo00?o
0000ooooooooool0=Oooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolTo`000>gooooo00?o0000
ooooooooool0=_ooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Qoooo
ogKo0000MOooool2o`0003Wooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0UooooolAo`0006?ooooo00?o0000ooooooooool0>Oooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2Xooooo`go0000E?ooool2o`0003cooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`2eooooo`Wo0000B_ooool00ol0003ooooo
ooooo`0looooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
__ooool7o`00047ooooo0_l0000oooooo`007_ooool3o`000<Gooooo2Ol0000eooooo`?o0000@Ooo
ool001kooooo00?o0000ooooooooool0c_ooool9o`0002_ooooo00?o0000ooooooooool0@_ooool0
01kooooo00?o0000ooooooooool0eoooool5o`0002;ooooo1?l00015ooooo`007_ooool00ol0003o
ooooooooo`3Looooo`Oo00005?ooool7o`0004Wooooo000Nooooo`03o`000?oooooooooo0>?ooooo
5?l0001@ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooo
odSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?oo
ooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
5?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool008Wooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0;Sooooo0029ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Cooooo0_lb<S:iooooo`00Ooooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
N?ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj
^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo
<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo07Kooooo0021ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`Ko00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07Oooooo0021ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c01hooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@
4?l0003o000000?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o0000
3Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07[ooooo001nooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`1jooooo`00O_ooool7o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo
00Cooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000NOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.06168 .41263 L
.08481 .41284 L
.10656 .41296 L
.12636 .41311 L
.13692 .41321 L
.14691 .41332 L
.15758 .41343 L
.16889 .41353 L
.17887 .41359 L
.18455 .41362 L
.18987 .41364 L
.19912 .41367 L
.20923 .4137 L
.21488 .41373 L
.22013 .41375 L
.23049 .41383 L
.24994 .41399 L
.25527 .41403 L
.26103 .41407 L
.26612 .4141 L
.27149 .41413 L
.27634 .41414 L
.27891 .41415 L
.28166 .41416 L
.2865 .41416 L
.29102 .41417 L
.2962 .41418 L
.30171 .41418 L
.30458 .41419 L
.30774 .4142 L
.31333 .41422 L
.31857 .41424 L
.32422 .41428 L
.33445 .41436 L
.37765 .41472 L
.38807 .41479 L
.3938 .41482 L
.3992 .41487 L
.40971 .41497 L
.41926 .41511 L
.43846 .4155 L
.45927 .41603 L
.47973 .41659 L
.49058 .41692 L
.50223 .41733 L
.52361 .41833 L
.54361 .41954 L
.58695 .42267 L
Mistroke
.6287 .42665 L
.66885 .43115 L
.69128 .43349 L
.71159 .43549 L
.72202 .43645 L
.73303 .43735 L
.74243 .43796 L
.74776 .43822 L
.75014 .43831 L
.75273 .43839 L
.7541 .43843 L
.75536 .43846 L
.75654 .43848 L
.75785 .4385 L
.75901 .43852 L
.76011 .43852 L
.76126 .43853 L
.76251 .43853 L
.76378 .43853 L
.7645 .43852 L
.76517 .43852 L
.76653 .4385 L
.76797 .43847 L
.7706 .43841 L
.77298 .43833 L
.77838 .43809 L
.78143 .4379 L
.78424 .4377 L
.79485 .43669 L
.80506 .4353 L
.81459 .4336 L
.82506 .43121 L
.83628 .4279 L
.84695 .42389 L
.85856 .41843 L
.87968 .40524 L
.90041 .38803 L
.92246 .36484 L
.96207 .30673 L
1 .2308 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003ooooooooo
o`3oooooobkooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool0ooooool]
ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0
003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000oooooooo
ool06Oooool001kooooo0ol0003oooooobcooooo00?o0000ooooooooool06Oooool001kooooo00?o
0000ooooooooool0ooooool[ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3ooooo
ob[ooooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03
o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003ooooo
ooooo`0Looooo`007_ooool3o`000?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool0
0ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000oooo
ooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oo
oooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo
00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oo
oooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0P
ooooo`007_ooool3o`000?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003o
ooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0
oooooolTooooo`03o`000?oooooooooo027ooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
8oooool00ol0003oooooooooo`0Rooooo`001oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003ooooooooo
o`0Rooooo`001oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?oooooo8_ooool00ol0003oooooooooo`0Soooo
o`001oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?ooool000Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003o
ooooooooo`0Uooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooolPooooo`03o`000?oooooooooo02Gooooo0005ooooo`03oeEEEOmV
IVKo000000gooooo1?l00005ooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003ooooooooo
o`0Vooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool0
01kooooo0ol0003ooooooakooooo00?o0000ooooooooool09oooool001kooooo00?o0000oooooooo
ool0oooooolMooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oooooooooo0?oooooo
7?ooool00ol0003oooooooooo`0Yooooo`007_ooool00ol0003oooooooooo`3ooooooacooooo00?o
0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolKooooo`03o`000?oooooo
oooo02[ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[oooo
o`007_ooool3o`000?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003ooooo
ooooo`3ooooooaWooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0oooo
oolHooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`000?oooooooooo0?oooooo6?ooool0
0ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000oooo
ooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolFooooo`03o`000?oooooooooo02oo
oooo000Nooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0_ooooo`007_oo
ool3o`000?oooooo5Oooool00ol0003oooooooooo`0`ooooo`007_ooool00ol0003oooooooooo`3o
oooooaCooooo00?o0000ooooooooool0<Oooool001kooooo00?o0000ooooooooool0oooooolCoooo
o`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003o
ooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa7ooooo00?o0000ooooooooool0
=?ooool001kooooo00?o0000ooooooooool0ooooool?ooooo`;o0000=oooool001kooooo0ol0003o
ooooo`kooooo00?o0000ooooooooool0=oooool001kooooo00?o0000ooooooooool0ooooool<oooo
o`;o0000>_ooool001kooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo03[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0kooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0ooooool8ooooo`;o0000?_ooool001Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003ooooooooo
o`0nooooo`005Oooool00onHV9So8B4Qonk^kP06ooooobGo0000h_ooool2o`00047ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool08_oooom[o`0007Kooooo00?o0000oooo
ooooool0@Oooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`2=oooooago
0000Eoooool2o`0004Cooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Z_ooool9o`0004cooooo0_l00016ooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0/oooool7o`0004?ooooo0_l00018ooooo`005?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0^_ooool9o`0003Oooooo0ol0001:ooooo`007_oo
ool3o`000<?ooooo2_l0000Zooooo`?o0000COooool001kooooo00?o0000ooooooooool0cOooool;
o`0001Wooooo1_l0001@ooooo`007_ooool00ol0003oooooooooo`3HoooooaWo0000E_ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Go
oooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`00
1_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`3oooooodSooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0
003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oiRH
V?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oa0@
4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005oooool00onYZJWo410@oooo
o`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3ooooooe3ooooo000Goooo
o`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooo
oe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@ooooo`00oooooomYooooo`00
SOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0
]?ooool008gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?oo
ool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X02_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM07cooooo0025ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;o
oooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000oooo
ooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`1kooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`1jooooo`00QOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c01looooo`00P_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l0
0008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0
003o000000?o00003Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`1nooooo`00P_ooool7o`0000Cooooo
0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0001mooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.08481 .4128 L
.12636 .41309 L
.16632 .41344 L
.18687 .41357 L
.20885 .41368 L
.23122 .41382 L
.25237 .41398 L
.29271 .4142 L
.30254 .41424 L
.31312 .4143 L
.32474 .41439 L
.33562 .41449 L
.37693 .41494 L
.39763 .41519 L
.40934 .41537 L
.42022 .41557 L
.46191 .4167 L
.503 .4182 L
.52548 .41935 L
.54666 .42066 L
.58714 .42354 L
.63019 .4272 L
.65164 .42913 L
.67165 .43077 L
.69213 .43216 L
.7022 .43271 L
.71152 .43313 L
.71639 .4333 L
.72176 .43346 L
.72454 .43352 L
.72716 .43356 L
.7286 .43358 L
.72992 .4336 L
.73067 .4336 L
.73137 .43361 L
.7321 .43361 L
.73289 .43362 L
.73411 .43362 L
.73543 .43361 L
.73668 .43361 L
.73783 .4336 L
.73887 .43359 L
.74001 .43357 L
.74231 .43353 L
.74482 .43347 L
.74751 .43339 L
.75238 .43318 L
.7579 .43285 L
Mistroke
.76302 .43244 L
.77461 .43118 L
.78483 .42961 L
.79572 .42745 L
.80655 .42476 L
.81824 .42116 L
.83943 .41248 L
.86041 .40054 L
.88254 .38371 L
.92247 .34165 L
.94299 .31354 L
.96497 .27799 L
1 .21219 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool^ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Noooo
o`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool3o`000?oo
oooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo
00?o0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oo
oooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0K
ooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo00?o0000ooooooooool06oooool001ko
oooo00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`?o0000
oooooolYooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:?oo
ool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000
ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo
01kooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo0ol0
003oooooobGooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolU
ooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9?ooool00ol0
003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000oooooooo
ool08Oooool001kooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo
000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool0
0ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0003ooooo
ob7ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool0oooooolQooooo`03
o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003ooooo
ooooo`0Uooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000ooooooooool0
9Oooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool000Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo7_ooool0
0ol0003oooooooooo`0Wooooo`001oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0003ooooooakooooo00?o0000ooooooooool09oooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolMoooo
o`03o`000?oooooooooo02Sooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool000Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
7?ooool00ol0003oooooooooo`0Yooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000
ooooooooool0oooooolJooooo`03o`000?oooooooooo02_ooooo000Nooooo`?o0000oooooolIoooo
o`03o`000?oooooooooo02cooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003o
ooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0
;Oooool001kooooo00?o0000ooooooooool0oooooolGooooo`03o`000?oooooooooo02kooooo000N
ooooo`03o`000?oooooooooo0?oooooo5_ooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0
003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0;oooool001kooooo0ol0003ooooooaGo
oooo00?o0000ooooooooool0<?ooool001kooooo00?o0000ooooooooool0oooooolDooooo`03o`00
0?oooooooooo037ooooo000Nooooo`03o`000?oooooooooo0?oooooo4oooool00ol0003ooooooooo
o`0booooo`007_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0<oooool0
01kooooo00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo03Cooooo000Nooooo`03
o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0eooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`oooooo00?o0000ooooooooool0=_ooool001kooooo0ol0003oooooo`kooooo00?o
0000ooooooooool0=oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooo
oooo03Sooooo000Nooooo`03o`000?oooooooooo0?oooooo3?ooool00ol0003oooooooooo`0ioooo
o`007_ooool00ol0003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool0>_ooool001kooooo
00?o0000ooooooooool0ooooool9ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0oooo
ool8ooooo`03o`000?oooooooooo03gooooo000Nooooo`?o0000ooooool6ooooo`;o0000@?ooool0
01kooooo00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo043ooooo000Nooooo`03
o`000?oooooooooo0?oooooo1?ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo0_l00014ooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0oooo
ool2o`0004Kooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`3mooooo`;o0000B?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolRo`000=cooooo0_l0001:
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooI_l0001doooo
o`;o0000C?ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`25oooooaco
0000E_ooool2o`0004kooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
XOooool:o`0004Wooooo0ol0001@ooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0Zoooool=o`0003Wooooo0ol0001Cooooo`005?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0^?ooool?o`0002Oooooo0ol0001Fooooo`007_oo
ool3o`000<Oooooo3_l0000?ooooo`[o0000FOooool001kooooo00?o0000ooooooooool0eOooool?
o`0006?ooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`00
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o
0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go
00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Q
onk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3oooooodSooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<
c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb
<S801Oooool00ol0003oooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooo
oom8ooooo`005_ooool00ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo
0?ooooooCoooool001Cooooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05
ojVYZOl@413o0000oa0@4?nYZJT0oooooom@ooooo`00oooooomYooooo`00ROooool2o`0000_ooooo
00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0^?ooool008Wooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[Wooooo001o
ooooo`05oa0@4?l0003o0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo
00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1_oo
ool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0N?ooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003o
gMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?oo
ool6o`0000Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOoo
ool02?ooool00ol0003oooooooooo`1fooooo`00POooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0N?oo
ool007kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o
0000ooooooooool04Oooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003ooooo
ooooo`1jooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0N_ooool007ko
oooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003o
ooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`Go00001?ooool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.08481 .41275 L
.12636 .41308 L
.16632 .41339 L
.20885 .41368 L
.2498 .41395 L
.29331 .41427 L
.33524 .41466 L
.37557 .41518 L
.3964 .41553 L
.41848 .416 L
.45821 .41713 L
.50051 .41882 L
.54122 .42099 L
.58451 .42379 L
.6262 .42666 L
.64724 .42799 L
.66631 .42898 L
.67141 .42919 L
.67694 .42939 L
.68172 .42954 L
.68696 .42967 L
.68985 .42972 L
.69254 .42976 L
.694 .42978 L
.69538 .42979 L
.69615 .4298 L
.69698 .42981 L
.69773 .42981 L
.69843 .42981 L
.69969 .42982 L
.70037 .42982 L
.70109 .42982 L
.70181 .42982 L
.70256 .42982 L
.70391 .42981 L
.70517 .4298 L
.70633 .42979 L
.70898 .42976 L
.71032 .42974 L
.71174 .42972 L
.71428 .42966 L
.72003 .42948 L
.725 .42927 L
.73046 .42896 L
.74055 .42819 L
.74998 .42719 L
.76091 .42567 L
.77128 .4238 L
Mistroke
.79075 .41907 L
.81158 .41191 L
.8309 .40301 L
.85249 .39009 L
.87204 .37537 L
.91417 .33302 L
.9547 .27852 L
.99781 .20964 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?oooooo;_ooool00ol0003oooooooooo`0Gooooo`005oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`00
5oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003ooooo
ooooo`0Hooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo;?oo
ool00ol0003oooooooooo`0Iooooo`005Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooo
oooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3ooooo
ob_ooooo00?o0000ooooooooool06_ooool001kooooo0ol0003oooooob[ooooo00?o0000oooooooo
ool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo
000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool0
0ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000oooo
ooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oo
oooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool3o`000?oooooo9_ooool00ol0003ooooo
ooooo`0Oooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07ooo
ool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo000Noooo
o`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003o
ooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0
oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`?o0000oooooolSooooo`03o`000?oo
oooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0S
ooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001ko
oooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`00
0?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Uooooo`007_ooool00ol0003ooooooooo
o`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooooolO
ooooo`03o`000?oooooooooo02Kooooo000Nooooo`?o0000oooooolNooooo`03o`000?oooooooooo
02Oooooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`00
7_ooool00ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool000Gooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
00?o0000ooooooooool0oooooolLooooo`03o`000?oooooooooo02Wooooo0007ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0oooo
oolKooooo`03o`000?oooooooooo02[ooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool0
00Oooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`?o0000oooooolJoooo
o`03o`000?oooooooooo02_ooooo0007ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003oooooooooo`0/oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolHooooo`03o`000?oooooooooo02gooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0
;_ooool000Gooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolGooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo0?oooooo5_ooool0
0ol0003oooooooooo`0_ooooo`007_ooool3o`000?oooooo5Oooool00ol0003oooooooooo`0`oooo
o`007_ooool00ol0003oooooooooo`3ooooooaCooooo00?o0000ooooooooool0<Oooool001kooooo
00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3o
oooooa7ooooo00?o0000ooooooooool0=?ooool001kooooo00?o0000ooooooooool0ooooool@oooo
o`03o`000?oooooooooo03Gooooo000Nooooo`?o0000ooooool?ooooo`03o`000?oooooooooo03Ko
oooo000Nooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003oooooooooo`0gooooo`007_oo
ool00ol0003oooooooooo`3oooooo`gooooo00?o0000ooooooooool0>?ooool001kooooo00?o0000
ooooooooool0ooooool<ooooo`03o`000?oooooooooo03Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo2oooool00ol0003oooooooooo`0jooooo`007_ooool00ol0003oooooooooo`3oooooo`[o
oooo00?o0000ooooooooool0>oooool001kooooo00?o0000ooooooooool0ooooool9ooooo`03o`00
0?oooooooooo03cooooo000Nooooo`?o0000ooooool8ooooo`03o`000?oooooooooo03gooooo000N
ooooo`03o`000?oooooooooo0?oooooo1_ooool2o`00043ooooo000Nooooo`03o`000?oooooooooo
0?oooooo1Oooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`3oooooo`Co
oooo00?o0000ooooooooool0@Oooool001kooooo00?o0000ooooooooool0ooooool3ooooo`03o`00
0?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool00ol0003ooooooooo
o`13ooooo`007_ooool3o`000?oooooo0_l00016ooooo`007_ooool00ol0003oooooooooo`3moooo
o`;o0000B?ooool001kooooo00?o0000ooooooooool0noooool2o`0004[ooooo000Nooooo`03o`00
0?oooooooooo0?Wooooo0_l0001<ooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0mooo
ool2o`0004kooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003ooooooooo
o`3eooooo`;o0000D?ooool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolRo`000=?ooooo0ol0001B
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooI?l0001/oooo
o`?o0000EOooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`23oooooa[o
0000Coooool3o`0005Sooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
WOooool=o`0003oooooo0ol0001Kooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0Z_ooool<o`0002gooooo1_l0001Nooooo`005?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0]_oooolFo`0000_ooooo3?l0001Tooooo`007_oo
ool3o`000<cooooo2ol0001`ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003o
ooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool0
0ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Co
oooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooom@ooooo`00oooooomYooooo`00TOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Gooooo00?o0000okZj^_ooool0/Oooool0097ooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[;ooooo0026ooooo`05oa0@4?l0003o
0000o`000?l@41001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7
Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?o
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000001?l@
413oooooooooooooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B63ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o8B4QPoooool0
08Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@
olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`29ooooo`00R?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Wooooo0025ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0
003o000000?o00003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Wooooo0025
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0ROooool008Gooooo1ol00005
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0<
ooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l00000Roooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.08481 .41272 L
.12636 .41308 L
.16632 .41334 L
.20885 .4137 L
.2498 .41398 L
.29331 .41437 L
.33524 .41486 L
.35443 .4151 L
.37557 .41546 L
.3964 .41591 L
.41848 .41645 L
.44057 .41706 L
.46079 .41771 L
.5015 .41944 L
.54319 .42149 L
.58329 .42371 L
.60568 .42493 L
.62597 .42585 L
.63613 .42621 L
.64148 .42637 L
.64713 .42651 L
.65208 .42662 L
.65751 .42672 L
.65989 .42675 L
.66245 .42678 L
.66486 .4268 L
.66706 .42682 L
.66829 .42682 L
.66946 .42683 L
.67073 .42683 L
.6721 .42683 L
.67347 .42683 L
.67415 .42683 L
.6749 .42682 L
.67623 .42682 L
.67747 .42681 L
.67991 .42678 L
.68212 .42675 L
.68468 .42671 L
.6871 .42666 L
.69254 .4265 L
.69756 .42631 L
.70306 .42603 L
.70889 .42566 L
.7188 .42483 L
.72945 .42364 L
.74868 .42063 L
.75931 .41845 L
Mistroke
.77091 .4156 L
.79202 .40894 L
.81271 .40017 L
.83475 .38809 L
.87847 .35535 L
.92059 .31202 L
.96112 .26192 L
1 .21264 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
ooooool^ooooo`03o`000?oooooooooo01Oooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Eooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Noooo
o`03o`000?oooooooooo0?oooooo;?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`000?oo
oooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo
00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oo
oooooooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0L
ooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001ko
oooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`?o0000
oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9_oo
ool00ol0003oooooooooo`0Oooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000
ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo
027ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`00
7_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0
003oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolQ
ooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0
003oooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo00?o0000oooooooo
ool09_ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo
000Nooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool0
0ol0003oooooooooo`3ooooooagooooo00?o0000ooooooooool0:?ooool001kooooo0ol0003ooooo
oacooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolKooooo`03
o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003ooooo
ooooo`0[ooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0
:oooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3ooooooaWooooo00?o0000ooooooooool0;?ooool000Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo6?ooool0
0ol0003oooooooooo`0]ooooo`001oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0003ooooooaOooooo00?o0000ooooooooool0;_ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolFoooo
o`03o`000?oooooooooo02oooooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool0<?ooool000Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo
5?ooool00ol0003oooooooooo`0aooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooa?ooooo00?o0000ooooooooool0<_ooool001kooooo00?o0000
ooooooooool0oooooolBooooo`03o`000?oooooooooo03?ooooo000Nooooo`?o0000oooooolAoooo
o`03o`000?oooooooooo03Cooooo000Nooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003o
ooooooooo`0eooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
=_ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000N
ooooo`03o`000?oooooooooo0?oooooo3Oooool00ol0003oooooooooo`0hooooo`007_ooool00ol0
003oooooooooo`3oooooo`cooooo00?o0000ooooooooool0>Oooool001kooooo0ol0003oooooo`_o
oooo00?o0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0ooooool:ooooo`03o`00
0?oooooooooo03_ooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`0003kooooo000N
ooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003oooooooooo`0nooooo`007_ooool00ol0
003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooooooo
ool0ooooool4ooooo`;o0000@_ooool001kooooo00?o0000ooooooooool0ooooool3ooooo`03o`00
0?oooooooooo04;ooooo000Nooooo`?o0000ooooool2ooooo`03o`000?oooooooooo04?ooooo000N
ooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003oooooooooo`14ooooo`007_ooool00ol0
003oooooooooo`3nooooo`;o0000Aoooool001kooooo00?o0000ooooooooool0oOooool00ol0003o
ooooooooo`17ooooo`007_ooool00ol0003oooooooooo`3looooo`03o`000?oooooooooo04Sooooo
000Nooooo`03o`000?oooooooooo0?[ooooo0_l0001;ooooo`007_ooool3o`000?Sooooo0_l0001=
ooooo`007_ooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo04gooooo000Nooooo`03
o`000?oooooooooo0?Gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`3cooooo`;o0000
D_ooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0?3ooooo0ol0001Dooooo`005?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0k?ooool4o`0005Oooooo000E
ooooo`03oiRHV?lQ8B7ok^k^00Kooooo8_l0003:ooooo`?o0000Foooool001Kooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ol0003oooooooooo`0Ooooooe_o0000K?ooool3o`0005kooooo000Gooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0N_oooolSo`0004Kooooo0ol0001Qooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09gooooo3?l0000eooooo`Go0000
I?ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0:Wooooo
5ol0000Booooo`co0000JOooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo0<3ooooo4_l0001eooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?ooooooB?ooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?oo
ool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj
^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@oooo
o`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool008Wooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;Sooooo
0029ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb
<S:iooooo`00Ooooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00[ooooo1?l000001?l@413oooooooooooooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0021oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo
00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@
413ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo07Oooooo0021oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo07Kooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`1g
ooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMg
MomgMgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07Sooooo001nooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_oo
ool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo017ooooo00?o
410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07[ooooo001nooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool0N_ooool007kooooo1ol00004ooooo`;o00004oooool00ol0003ooooooooo
o`04ooooo`;o00005Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Gooooo00?o
EEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001iooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41238 L
.08481 .41269 L
.10632 .41292 L
.11681 .41302 L
.12636 .41309 L
.14567 .4132 L
.1564 .41326 L
.16632 .41332 L
.17608 .41339 L
.18642 .4135 L
.20824 .41373 L
.22876 .4139 L
.24797 .41402 L
.25887 .4141 L
.26923 .41419 L
.28868 .41444 L
.32878 .415 L
.35117 .41529 L
.37146 .41565 L
.39262 .41616 L
.41255 .41671 L
.45303 .41784 L
.47396 .4186 L
.49608 .41957 L
.53595 .42127 L
.5784 .42306 L
.59796 .42384 L
.60333 .42402 L
.60902 .42418 L
.61394 .42429 L
.61925 .42438 L
.6221 .42442 L
.62472 .42445 L
.62722 .42447 L
.62848 .42448 L
.62985 .42448 L
.63064 .42449 L
.63139 .42449 L
.63206 .42449 L
.63278 .42449 L
.63357 .42449 L
.63441 .42449 L
.63513 .42449 L
.63591 .42449 L
.63665 .42449 L
.63732 .42449 L
.63883 .42448 L
.64022 .42447 L
.64155 .42446 L
Mistroke
.64409 .42444 L
.6468 .42441 L
.65166 .42435 L
.65744 .42423 L
.66268 .4241 L
.66781 .42394 L
.67323 .42374 L
.68293 .42326 L
.69336 .42253 L
.7048 .42143 L
.71555 .42007 L
.72533 .41851 L
.7473 .41395 L
.76738 .40843 L
.7892 .40072 L
.81 .39123 L
.83207 .37859 L
.87177 .34998 L
.91403 .31169 L
.95471 .27053 L
.99796 .23327 L
1 .23167 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003ooooooooo
o`3oooooobcooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000
ooooooooool06_ooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo
01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`00
7_ooool3o`000?oooooo:?ooool00ol0003oooooooooo`0Mooooo`007_ooool00ol0003ooooooooo
o`3oooooobKooooo0_l0000Pooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000
ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo
027ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0Rooooo`00
7_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0
003oooooob7ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool0oooooolP
ooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0
003oooooooooo`0Uooooo`007_ooool00ol0003oooooooooo`3ooooooaoooooo00?o0000oooooooo
ool09_ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo
000Nooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_ooool0
0ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool001kooooo0ol0003ooooo
oa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool0oooooolJooooo`03
o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003ooooo
ooooo`0/ooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0
;Oooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3ooooooaOooooo00?o0000ooooooooool0;_ooool000Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo5_ooool0
0ol0003oooooooooo`0_ooooo`001oooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0003ooooooaGooooo00?o0000ooooooooool0<?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolCoooo
o`;o0000<oooool000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo4_ooool00ol0003oooooooooo`0cooooo`001oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolAooooo`03o`00
0?oooooooooo03Cooooo0005ooooo`03oeEEEOmVIVKo000000gooooo1?l00005ooooo`03o`000?oo
oooooooo0?oooooo4?ooool00ol0003oooooooooo`0eooooo`007_ooool00ol0003oooooooooo`3o
ooooo`oooooo00?o0000ooooooooool0=_ooool001kooooo0ol0003oooooo`gooooo0_l0000ioooo
o`007_ooool00ol0003oooooooooo`3oooooo`cooooo00?o0000ooooooooool0>Oooool001kooooo
00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo03[ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo2_ooool00ol0003oooooooooo`0kooooo`007_ooool00ol0003oooooooooo`3o
ooooo`Wooooo00?o0000ooooooooool0??ooool001kooooo00?o0000ooooooooool0ooooool8oooo
o`03o`000?oooooooooo03gooooo000Nooooo`?o0000ooooool6ooooo`;o0000@?ooool001kooooo
00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo043ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo1?ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0003oooooooooo`3o
ooooo`;ooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo00?o0000oooo
ooooool0A?ooool001kooooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`15ooooo`00
7_ooool00ol0003oooooooooo`3mooooo`;o0000B?ooool001kooooo0ol0003looooo`03o`000?oo
oooooooo04Sooooo000Nooooo`03o`000?oooooooooo0?_ooooo00?o0000ooooooooool0BOooool0
01kooooo00?o0000ooooooooool0nOooool2o`0004cooooo000Nooooo`03o`000?oooooooooo0?Oo
oooo0_l0001>ooooo`007_ooool00ol0003oooooooooo`3fooooo`03o`000?oooooooooo04kooooo
000Nooooo`03o`000?oooooooooo0?Cooooo0_l0001Aooooo`007_ooool3o`000?;ooooo0_l0001C
ooooo`007_ooool00ol0003oooooooooo`3`ooooo`;o0000EOooool001kooooo00?o0000oooooooo
ool0k_ooool2o`0005Oooooo000Nooooo`03o`000?oooooooooo0>_ooooo0ol0001Iooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0j?ooool3o`0005cooooo000Dooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool00ol0003oooooooooo`3Uooooo`?o0000Goooool001Gooooo00?oV9RH
ob4Q8Oo^k^h01_oooolWo`000;kooooo0ol0001Rooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo02CoooooEOl0001Tooooo`Go0000IOooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`1iooooob;o0000?Oooool5o`0006[ooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Voooool=o`0002Oooooo2Ol0001_ooooo`005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0Z?oooolWo`0007Sooooo
000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003o
ooooooooo`02ooooo`?o0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVoooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo
0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooodSooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooo
oooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`3oooooodSooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003o
ooooooooo`3oooooodSooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool0
0ol@413o0000okZj^P3ooooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Co
oooo00Go410@oiRHV?oooooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@
4?nYZJT0oooooom@ooooo`00oooooomYooooo`00SOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool2o`0000Kooooo00?o0000okZj^_ooool0]?ooool008gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o
0000o`000?l@41001Oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool0
1?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000004
oa0@4?ooooooooooooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@1looooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo00Go
410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@4100
3?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo0000oa0@4?o<c<`;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1joooo
o`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07cooooo0022ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2
o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo017ooooo00?o410@
o`000?l000000ol0000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0O_ooool008;ooooo1ol00004ooooo`;o00004oooool00ol0
003oooooooooo`04ooooo`;o00005Oooool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo0000
00Gooooo00?oEEEEofIVI_l000003Oooool4o`0007gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41214 L
.01975 .41225 L
.02496 .41229 L
.03053 .41233 L
.04057 .41239 L
.05147 .41243 L
.05722 .41246 L
.06331 .41249 L
.07449 .41256 L
.08481 .41267 L
.10728 .41293 L
.11827 .41305 L
.12308 .41309 L
.12833 .41312 L
.13814 .41318 L
.14747 .41321 L
.15256 .41323 L
.15807 .41326 L
.16805 .41332 L
.1737 .41337 L
.17889 .41342 L
.18871 .41354 L
.21073 .41382 L
.22027 .41391 L
.2305 .41399 L
.24172 .41406 L
.25219 .41412 L
.26288 .41421 L
.26891 .41427 L
.27449 .41435 L
.29562 .41469 L
.33685 .41532 L
.34692 .41545 L
.35753 .41562 L
.37649 .41602 L
.3968 .4166 L
.4187 .41722 L
.45872 .4183 L
.47931 .41905 L
.50131 .41995 L
.54488 .42135 L
.56672 .42195 L
.57631 .42222 L
.58686 .42249 L
.59175 .42259 L
.59444 .42264 L
.597 .42267 L
.59937 .4227 L
.60195 .42273 L
Mistroke
.60309 .42274 L
.6043 .42275 L
.60544 .42275 L
.60648 .42276 L
.60778 .42276 L
.60916 .42276 L
.61033 .42276 L
.61162 .42276 L
.61235 .42275 L
.61301 .42275 L
.6145 .42274 L
.61588 .42273 L
.61718 .42271 L
.62201 .42264 L
.62473 .42259 L
.62725 .42253 L
.63738 .42221 L
.64689 .42181 L
.65744 .42125 L
.66853 .42053 L
.67868 .41971 L
.68977 .4186 L
.70921 .41588 L
.72003 .41385 L
.72984 .41169 L
.75185 .40577 L
.77374 .39851 L
.79389 .39033 L
.83433 .36828 L
.87576 .3399 L
.9156 .30892 L
.93777 .29138 L
.95801 .27787 L
.96804 .27266 L
.97896 .26817 L
.99883 .26222 L
1 .26191 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooobcooooo0ol0000Iooooo`007_ooool3o`000?oooooo:Ooo
ool3o`0001cooooo000Nooooo`03o`000?oooooooooo0?oooooo9_ooool3o`0001oooooo000Noooo
o`03o`000?oooooooooo0?oooooo8oooool3o`0002;ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo8?ooool3o`0002Gooooo000Nooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003ooooo
ooooo`0Vooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09ooo
ool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02Sooooo000Noooo
o`?o0000oooooolLooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo0?oo
oooo6_ooool2o`0002cooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0003ooooo
ooooo`0/ooooo`001Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3ooooooaOooooo0_l0000_ooooo`001ooo
ool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo0?oooooo5_ooool00ol0003oooooooooo`0_ooooo`001oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooo
oooo033ooooo0007ooooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool00oooool3o`00
0?oooooo4oooool2o`0003?ooooo0007ooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003oooooooooo`0coooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooolAooooo`03o`000?oooooooooo03Cooooo0007ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`oooooo0_l0000gooooo`001Ooo
ool00omEEEGoIVIVo`00000=ooooo`Co00001Oooool00ol0003oooooooooo`3oooooo`kooooo00?o
0000ooooooooool0=oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`03o`000?oooooo
oooo03Sooooo000Nooooo`?o0000ooooool;ooooo`;o0000>oooool001kooooo00?o0000oooooooo
ool0ooooool:ooooo`03o`000?oooooooooo03_ooooo000Nooooo`03o`000?oooooooooo0?oooooo
2Oooool00ol0003oooooooooo`0looooo`007_ooool00ol0003oooooooooo`3oooooo`Oooooo0_l0
000oooooo`007_ooool00ol0003oooooooooo`3oooooo`Kooooo00?o0000ooooooooool0?oooool0
01kooooo00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo043ooooo000Nooooo`?o
0000ooooool3ooooo`;o0000@oooool001kooooo00?o0000ooooooooool0ooooool2ooooo`03o`00
0?oooooooooo04?ooooo000Nooooo`03o`000?oooooooooo0?oooooo0Oooool00ol0003ooooooooo
o`14ooooo`007_ooool00ol0003oooooooooo`3nooooo`;o0000Aoooool001kooooo00?o0000oooo
ooooool0oOooool00ol0003oooooooooo`17ooooo`007_ooool00ol0003oooooooooo`3looooo`03
o`000?oooooooooo04Sooooo000Nooooo`03o`000?oooooooooo0?[ooooo0_l0001;ooooo`007_oo
ool3o`000?Sooooo0_l0001=ooooo`007_ooool00ol0003oooooooooo`3fooooo`;o0000Coooool0
01kooooo00?o0000ooooooooool0m?ooool2o`00057ooooo000Nooooo`03o`000?oooooooooo0??o
oooo00?o0000ooooooooool0DOooool001kooooo00?o0000ooooooooool0lOooool2o`0005Cooooo
000Nooooo`03o`000?oooooooooo0>oooooo0_l0001Fooooo`007_ooool3o`000>gooooo0_l0001H
ooooo`007_ooool00ol0003oooooooooo`3Zooooo`?o0000F_ooool001kooooo00?o0000oooooooo
ool0ioooool3o`0005gooooo000Nooooo`03o`000?oooooooooo0>Cooooo0ol0001Pooooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0h?ooool4o`0006?ooooo000Dooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool00ol0003oooooooooo`3Mooooo`?o0000Ioooool001Gooooo00?oV9RH
ob4Q8Oo^k^h01_oooolTo`000;Wooooo0ol0001Zooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo027oooooDol0001Nooooo`So0000KOooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`1dooooob3o0000>Oooool5o`0007Gooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0U?oooolio`0007[ooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3oooooodSooooo000Dooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?ooooooB?ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o
0000oooooom8ooooo`001_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3oooooodSooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00ROooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo
00?o0000okZj^_ooool0^?ooool008Wooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool01?ooool2oc8b<[Wooooo001oooooo`05oa0@4?l0003o0000o`000?l@41001Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000004oa0@4?oooooooooooooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4
A4Co0000o`000?lb<S;ogMgM07Sooooo0021ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00cooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`1fooooo`00POooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01h
ooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool0
0ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1j
ooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00Go410@
oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo07[ooooo001nooooo`Oo00001?ooool2
o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Gooooo00?o0000ooooooooool03?ooool0
0omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo000000cooooo1Ol00004ooooo`Co0000NOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41215 L
.01975 .41226 L
.02496 .41231 L
.03053 .41235 L
.03578 .41237 L
.04057 .41239 L
.05147 .41243 L
.05722 .41245 L
.06331 .41247 L
.06863 .4125 L
.07449 .41255 L
.08481 .41265 L
.1069 .41294 L
.11738 .41306 L
.12711 .41314 L
.13194 .41317 L
.13709 .41319 L
.14798 .41323 L
.15334 .41325 L
.15839 .41327 L
.16292 .4133 L
.16782 .41333 L
.1778 .41343 L
.18876 .41357 L
.20033 .41374 L
.21087 .41389 L
.22139 .41401 L
.23136 .41409 L
.24201 .41415 L
.24784 .41419 L
.25332 .41422 L
.26326 .41431 L
.26854 .41437 L
.27423 .41445 L
.29357 .41481 L
.33676 .41553 L
.34718 .41567 L
.35832 .41584 L
.36882 .41606 L
.37837 .4163 L
.41838 .41746 L
.44022 .41796 L
.46036 .41846 L
.50075 .41985 L
.51025 .42014 L
.52045 .42038 L
.53165 .42058 L
.54213 .42072 L
.56286 .42095 L
Mistroke
.57381 .42107 L
.57696 .4211 L
.57993 .42112 L
.58262 .42114 L
.58409 .42115 L
.58547 .42116 L
.58672 .42116 L
.58806 .42116 L
.58882 .42116 L
.58954 .42116 L
.59089 .42116 L
.59214 .42116 L
.59328 .42116 L
.59454 .42115 L
.59588 .42115 L
.59721 .42114 L
.59864 .42112 L
.60123 .42109 L
.60431 .42104 L
.60713 .42099 L
.61181 .42086 L
.61692 .42069 L
.62722 .4202 L
.63803 .41952 L
.64785 .41877 L
.66986 .41671 L
.69004 .41419 L
.70142 .41234 L
.7119 .41028 L
.75332 .39885 L
.79316 .38375 L
.83557 .36157 L
.87639 .33731 L
.89717 .32501 L
.91979 .31185 L
.93031 .3063 L
.94149 .30134 L
.94609 .2997 L
.95104 .29823 L
.95388 .29755 L
.95648 .29703 L
.95916 .29659 L
.96032 .29644 L
.96159 .2963 L
.96282 .29618 L
.96395 .29609 L
.96503 .29603 L
.96618 .29598 L
.96739 .29595 L
.96851 .29594 L
Mistroke
.96975 .29595 L
.97109 .29599 L
.97222 .29604 L
.97345 .29612 L
.9757 .29631 L
.97789 .29656 L
.97993 .29684 L
.98502 .29775 L
.98964 .29878 L
1 .30148 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooob3ooooo2Ol0000Oooooo`001Oooool4o`000003oa0@4?oo
oooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003ooooo
ooooo`3ooooooagooooo0ol00009ooooo`Go00006_ooool000Oooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3ooooooa_ooooo0_l0
000Aooooo`03o`000?oooooooooo01Oooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooaSooooo0ol0000]ooooo`001oooool00ol0
003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0003ooooooaKooooo0_l0000`oooo
o`001oooool00ol0003oooooooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`3ooooooaCooooo0_l0000booooo`001oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;o
oooo0007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3ooooooa7ooooo0_l0000eooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0=Oooool001kooooo00?o0000
ooooooooool0ooooool>ooooo`;o0000>?ooool001kooooo0ol0003oooooo`cooooo0_l0000joooo
o`007_ooool00ol0003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool0>_ooool001kooooo
00?o0000ooooooooool0ooooool9ooooo`;o0000?Oooool001kooooo00?o0000ooooooooool0oooo
ool7ooooo`;o0000?oooool001kooooo00?o0000ooooooooool0ooooool5ooooo`;o0000@Oooool0
01kooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo047ooooo000Nooooo`?o
0000ooooool2ooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0ooooool2o`0004Kooooo
000Nooooo`03o`000?oooooooooo0?kooooo00?o0000ooooooooool0A_ooool001kooooo00?o0000
ooooooooool0o?ooool2o`0004Wooooo000Nooooo`03o`000?oooooooooo0?[ooooo0_l0001;oooo
o`007_ooool00ol0003oooooooooo`3hooooo`;o0000COooool001kooooo00?o0000ooooooooool0
m_ooool2o`0004oooooo000Nooooo`?o0000m?ooool2o`00057ooooo000Nooooo`03o`000?oooooo
oooo0??ooooo00?o0000ooooooooool0DOooool001kooooo00?o0000ooooooooool0lOooool2o`00
05Cooooo000Nooooo`03o`000?oooooooooo0>oooooo0_l0001Fooooo`007_ooool00ol0003ooooo
ooooo`3]ooooo`;o0000F?ooool001kooooo00?o0000ooooooooool0j_ooool3o`0005[ooooo000N
ooooo`?o0000ioooool3o`0005gooooo000Nooooo`03o`000?oooooooooo0>Cooooo0ol0001Poooo
o`007_ooool00ol0003oooooooooo`3Pooooo`Co0000Hoooool001kooooo00?o0000ooooooooool0
gOooool3o`0006Oooooo000Dooooo`Go00001Oooool00ol0003oooooooooo`3Jooooo`?o0000J_oo
ool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0=Oooooo0ol0
001]ooooo`005Oooool00onHV9So8B4Qonk^kP06ooooobCo0000/?ooool6o`00073ooooo000Foooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool08OoooomFo`0005Gooooo1Ol0001foooo
o`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo07Oooooo6Ol0000^ooooo`ko
0000Noooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2@ooooobko0000
ROooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo1?l00005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oo
oooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03
o`000?oooooooooo0?ooooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3oooooodSooooo000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000F
ooooo`03oa0@4?l0003o^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?oooo
o`005?ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@3ooooooe3ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@
o`000?l0003o0000oa0@4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo
00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000oooooooo
ool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`00
0003oa0@4?oooooooooo00Go00001Oooool2ob4Q8H?ooooo0028ooooo`03o`000?oooooooooo00Ko
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8H?ooooo0028oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h0Roooool008Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1_l00004
ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0R_ooool008Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool00omgMgOoIVIVooooo`29ooooo`00QOooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000o`00
0003o`0000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`28ooooo`00QOooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@4100R_ooool008Gooooo1ol0
0005ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02:ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41215 L
.01975 .41227 L
.02496 .41232 L
.03053 .41236 L
.03578 .41238 L
.04057 .4124 L
.05147 .41243 L
.05722 .41244 L
.06012 .41245 L
.06331 .41247 L
.06908 .4125 L
.07449 .41254 L
.08481 .41265 L
.10427 .41293 L
.11456 .41306 L
.1202 .41312 L
.12552 .41316 L
.13155 .4132 L
.13703 .41322 L
.14771 .41326 L
.15264 .41327 L
.15784 .41329 L
.16355 .41333 L
.1688 .41337 L
.17876 .41348 L
.18942 .41363 L
.20868 .41394 L
.21936 .41408 L
.22539 .41414 L
.23098 .41418 L
.24187 .41425 L
.2521 .41432 L
.26154 .4144 L
.26684 .41446 L
.2717 .41453 L
.29333 .41496 L
.33494 .4157 L
.34572 .41583 L
.3559 .41598 L
.36504 .41615 L
.37495 .41638 L
.39554 .41698 L
.41754 .41758 L
.438 .41798 L
.46051 .41841 L
.48188 .419 L
.49145 .41928 L
.50188 .41955 L
.50755 .41967 L
Mistroke
.51281 .41976 L
.51783 .41983 L
.52064 .41985 L
.52318 .41987 L
.5244 .41988 L
.52569 .41988 L
.52681 .41989 L
.528 .41989 L
.52929 .41989 L
.53049 .4199 L
.53122 .4199 L
.53191 .4199 L
.53321 .4199 L
.53435 .41989 L
.53556 .41989 L
.53659 .41989 L
.53773 .41989 L
.54027 .41988 L
.54265 .41987 L
.553 .41982 L
.56388 .41975 L
.57317 .41968 L
.57843 .41964 L
.58332 .41958 L
.58864 .41949 L
.5944 .41936 L
.59984 .4192 L
.60484 .41901 L
.61434 .41853 L
.62437 .41784 L
.64497 .41592 L
.66421 .41368 L
.68375 .41094 L
.70503 .40703 L
.72731 .40147 L
.74843 .39501 L
.79121 .37957 L
.83241 .36051 L
.87201 .34179 L
.89401 .33301 L
.90364 .32953 L
.91419 .32608 L
.91914 .32466 L
.92443 .32333 L
.929 .32237 L
.93141 .32195 L
.93396 .32158 L
.93534 .32141 L
.93687 .32125 L
.93828 .32114 L
Mistroke
.93956 .32106 L
.94088 .321 L
.94161 .32098 L
.9423 .32097 L
.94353 .32096 L
.94486 .32099 L
.94617 .32104 L
.94735 .32111 L
.94872 .32122 L
.95001 .32135 L
.9523 .32167 L
.95478 .32212 L
.95995 .32342 L
.96477 .32509 L
.97573 .33046 L
.98641 .33749 L
.99786 .34623 L
1 .34793 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooaKooooo3Ol0000Uooooo`007_ooool00ol0003oooooooooo`3o
oooooa?ooooo0ol0000=ooooo`?o00008_ooool001kooooo0ol0003ooooooa3ooooo0ol0000Coooo
o`;o00008?ooool001kooooo00?o0000ooooooooool0ooooool=ooooo`?o00006?ooool00ol0003o
ooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooo`[ooooo0ol0000Looooo`03o`00
0?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo2?ooool2o`00023ooooo0_l0
000Looooo`007_ooool00ol0003oooooooooo`3oooooo`Kooooo0_l0000Tooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo1?ooool2o`0002Oooooo00?o0000oooo
ooooool06?ooool001kooooo0ol0003oooooo`;ooooo0_l0000Zooooo`03o`000?oooooooooo01Oo
oooo000Nooooo`03o`000?oooooooooo0?oooooo0_l00016ooooo`007_ooool00ol0003ooooooooo
o`3mooooo`;o0000B?ooool001kooooo00?o0000ooooooooool0noooool2o`0004[ooooo000Noooo
o`03o`000?oooooooooo0?Wooooo0_l0001<ooooo`007_ooool00ol0003oooooooooo`3fooooo`?o
0000C_ooool001kooooo00?o0000ooooooooool0loooool3o`00057ooooo000Nooooo`?o0000lOoo
ool2o`0005Cooooo000Nooooo`03o`000?oooooooooo0>kooooo0ol0001Fooooo`007_ooool00ol0
003oooooooooo`3/ooooo`;o0000FOooool001kooooo00?o0000ooooooooool0jOooool3o`0005_o
oooo000Nooooo`03o`000?oooooooooo0>Kooooo0ol0001Nooooo`007_ooool00ol0003ooooooooo
o`3Tooooo`;o0000HOooool001kooooo0ol0003Qooooo`?o0000Hoooool001kooooo00?o0000oooo
ooooool0goooool2o`0006Kooooo000Nooooo`03o`000?oooooooooo0=cooooo0ol0001Xooooo`00
7_ooool00ol0003oooooooooo`3Hooooo`Co0000Joooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0=Gooooo0ol0001_ooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0d?ooool5o`0007;ooooo000Eooooo`03oiRHV?lQ8B7ok^k^00Kooooo8ol0002Z
ooooo`Ko0000Moooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Poooo
odoo0000Coooool<o`0007gooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0KooooolXo`0001Oooooo4?l00029ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo09Oooooo5ol0002Iooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?ooooooB?ooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?oo
ool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj
^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@oooo
o`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool008Wooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;Sooooo
0029ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb
<S:iooooo`00Ooooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<
o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?oo
ool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00oooool00onHV9So8B4Qonk^kP0=ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool0M_ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h03Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo07Oooooo0021oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool03Oooool00omgMgOoIVIVooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0N?ooool007kooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`00
0003o`0000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0N_ooool007kooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03
o`000?oooooooooo07[ooooo001nooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool0
1?ooool2o`0001Gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000004ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0001ioooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41216 L
.01975 .41228 L
.02496 .41233 L
.03053 .41237 L
.03323 .41238 L
.03578 .41239 L
.04057 .41241 L
.05086 .41243 L
.05358 .41244 L
.0565 .41245 L
.06178 .41247 L
.06476 .41248 L
.06748 .4125 L
.07375 .41254 L
.07942 .4126 L
.08481 .41266 L
.10584 .41297 L
.115 .41309 L
.11982 .41314 L
.12491 .41319 L
.13045 .41323 L
.13555 .41325 L
.14032 .41327 L
.14557 .41329 L
.15106 .41331 L
.15696 .41333 L
.16252 .41336 L
.16759 .4134 L
.17264 .41345 L
.178 .41352 L
.18763 .41366 L
.19812 .41384 L
.20943 .41403 L
.22009 .41418 L
.22987 .41427 L
.23922 .41434 L
.24906 .4144 L
.25909 .41448 L
.2647 .41455 L
.26979 .41462 L
.28908 .41499 L
.33106 .41579 L
.35029 .41602 L
.36122 .41619 L
.37145 .41641 L
.39232 .41697 L
.40365 .41728 L
.41441 .41754 L
.42461 .41772 L
Mistroke
.43572 .41788 L
.45518 .41812 L
.46604 .4183 L
.47588 .41849 L
.48736 .41874 L
.49239 .41884 L
.49791 .41894 L
.50301 .41901 L
.50545 .41904 L
.50777 .41906 L
.50902 .41907 L
.51039 .41907 L
.51164 .41908 L
.51279 .41908 L
.51403 .41909 L
.51539 .41909 L
.51608 .41909 L
.51682 .41909 L
.51816 .41909 L
.51954 .41908 L
.52082 .41908 L
.52223 .41907 L
.52373 .41906 L
.5268 .41903 L
.52958 .419 L
.54004 .41883 L
.56022 .4184 L
.57063 .41815 L
.58207 .41783 L
.59288 .41743 L
.60298 .41692 L
.61365 .41618 L
.62509 .41514 L
.64587 .41272 L
.66849 .40957 L
.71029 .40169 L
.73103 .39615 L
.75308 .38938 L
.79268 .37621 L
.83486 .36 L
.85424 .3531 L
.86522 .34986 L
.87545 .34738 L
.88561 .34542 L
.89647 .34384 L
.89933 .34351 L
.90243 .34321 L
.90517 .34299 L
.90807 .3428 L
.91068 .34267 L
Mistroke
.91139 .34264 L
.91216 .34262 L
.91283 .3426 L
.91355 .34259 L
.91491 .34257 L
.91619 .34257 L
.91745 .34258 L
.91861 .3426 L
.91996 .34264 L
.92065 .34267 L
.92139 .34271 L
.92395 .34287 L
.92539 .343 L
.92693 .34316 L
.92972 .34353 L
.93253 .34401 L
.93519 .34456 L
.94018 .34591 L
.94504 .34764 L
.94954 .34965 L
.95972 .35573 L
.9696 .36374 L
.97887 .37302 L
1 .39836 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?oooooo3oooool;o`0002kooooo000Nooooo`03o`000?oooooooooo
0?oooooo2_ooool5o`0000[ooooo1?l0000[ooooo`007_ooool3o`000?oooooo1?ooool6o`0001?o
oooo1?l0000Wooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo0ol0000Mooooo`03o`00
0?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?gooooo0ol0000Qooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?[ooooo0ol0000Uooooo`03o`000?oooooo
oooo02;ooooo000Nooooo`03o`000?oooooooooo0?Oooooo0ol0000Yooooo`03o`000?oooooooooo
027ooooo000Nooooo`03o`000?oooooooooo0?Cooooo0ol0000]ooooo`03o`000?oooooooooo023o
oooo000Nooooo`03o`000?oooooooooo0?;ooooo0_l0000aooooo`03o`000?oooooooooo01oooooo
000Nooooo`?o0000koooool3o`0003Cooooo00?o0000ooooooooool07_ooool001kooooo00?o0000
ooooooooool0kOooool2o`0003Oooooo00?o0000ooooooooool07_ooool001kooooo00?o0000oooo
ooooool0j_ooool3o`0003[ooooo00?o0000ooooooooool07Oooool001kooooo00?o0000oooooooo
ool0ioooool3o`0003kooooo00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0
i?ooool3o`0004;ooooo00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0h?oo
ool4o`0004Kooooo00?o0000ooooooooool06_ooool001kooooo0ol0003Mooooo`?o0000Boooool0
0ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3Jooooo`?o0000Coooool00ol0
003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3Gooooo`?o0000Doooool00ol0003o
ooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`3Booooo`Go0000L?ooool001Cooooo1Ol0
0005ooooo`03o`000?oooooooooo0<_ooooo1ol0001eooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0aOooool6o`0007cooooo000Eooooo`03oiRHV?lQ8B7o
k^k^00Kooooo8ol0002Nooooo`Oo0000P_ooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0
003oooooooooo`0Pooooodko0000B?ooool8o`0008Wooooo000Gooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0K_oooom8o`00097ooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo
00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000
ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool00_ooool3o`000?ooooooB?ooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooom8ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?oo
ool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj
^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@oooo
o`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool008gooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;Cooooo
002=ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb
<S:eooooo`00Poooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd0O?ooool008Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0
003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000oooooooo
ool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
07_ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?oMgMgo
0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`1jooooo`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool01?ooool00onH
V9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo07_ooooo0025ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<07cooooo0022oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooo
oooo017ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1nooooo`00P_ooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`1nooooo`00P_ooool7
o`0000Cooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooo
oooo00cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
001mooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41216 L
.01975 .41228 L
.02496 .41233 L
.03053 .41237 L
.03578 .4124 L
.04057 .41242 L
.05147 .41245 L
.05722 .41246 L
.06012 .41247 L
.06331 .41249 L
.06908 .41252 L
.07449 .41257 L
.08481 .41269 L
.10427 .41298 L
.11456 .41312 L
.1202 .41318 L
.12552 .41323 L
.13155 .41327 L
.13703 .4133 L
.14771 .41334 L
.15264 .41336 L
.15784 .41338 L
.16355 .41342 L
.1688 .41347 L
.17876 .41359 L
.18942 .41376 L
.20868 .4141 L
.21936 .41425 L
.23098 .41437 L
.24102 .41444 L
.2521 .41452 L
.25726 .41457 L
.26281 .41463 L
.27287 .41478 L
.28437 .415 L
.29493 .41524 L
.33653 .41595 L
.34731 .41607 L
.3575 .4162 L
.36664 .41635 L
.37654 .41656 L
.39714 .41708 L
.40761 .41731 L
.41317 .41742 L
.41913 .41751 L
.42477 .41758 L
.42992 .41763 L
.44 .4177 L
.4621 .41785 L
Mistroke
.47259 .41796 L
.48376 .4181 L
.48919 .41816 L
.49186 .41819 L
.4943 .41821 L
.49649 .41822 L
.49889 .41824 L
.50014 .41824 L
.5013 .41824 L
.50253 .41825 L
.50385 .41825 L
.50515 .41825 L
.50654 .41824 L
.50772 .41824 L
.50902 .41824 L
.51042 .41823 L
.51193 .41822 L
.51465 .41819 L
.51725 .41816 L
.51998 .41812 L
.52487 .41802 L
.53401 .41779 L
.544 .41747 L
.56636 .41663 L
.58665 .41572 L
.59679 .41512 L
.60778 .4143 L
.6277 .41223 L
.67072 .40603 L
.71215 .39795 L
.75198 .3872 L
.7944 .37537 L
.81394 .36979 L
.83522 .36402 L
.84678 .36147 L
.85187 .36057 L
.85749 .35975 L
.86003 .35945 L
.86277 .35917 L
.86514 .35897 L
.86773 .3588 L
.86906 .35873 L
.87049 .35866 L
.872 .35861 L
.87267 .35859 L
.8734 .35858 L
.87413 .35857 L
.87481 .35856 L
.87613 .35855 L
.87734 .35856 L
Mistroke
.87861 .35857 L
.87988 .3586 L
.88126 .35864 L
.88257 .35868 L
.88378 .35874 L
.8885 .35905 L
.8912 .35929 L
.89365 .35956 L
.89914 .36029 L
.9039 .3611 L
.90904 .36217 L
.91836 .36471 L
.92835 .36852 L
.93931 .3744 L
.95075 .38296 L
.96143 .39352 L
.98161 .42018 L
1 .44964 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo0_ooool?
o`0003Oooooo000Nooooo`03o`000?oooooooooo0?gooooo1?l0000?ooooo`Co0000<oooool001ko
oooo00?o0000ooooooooool0n?ooool5o`0001Oooooo0ol0000`ooooo`007_ooool00ol0003ooooo
ooooo`3cooooo`Go00007oooool2o`0002kooooo000Nooooo`?o0000l?ooool3o`0002Kooooo00?o
0000ooooooooool0:oooool001kooooo00?o0000ooooooooool0kOooool3o`0002[ooooo0_l0000[
ooooo`007_ooool00ol0003oooooooooo`3Zooooo`?o0000;oooool2o`0002Wooooo000Nooooo`03
o`000?oooooooooo0>Oooooo0ol0000dooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`00
0?oooooooooo0>Cooooo0ol0000gooooo`03o`000?oooooooooo02Kooooo000Nooooo`03o`000?oo
oooooooo0>3ooooo1?l0000kooooo`03o`000?oooooooooo02Gooooo000Nooooo`?o0000foooool5
o`00043ooooo00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool0eoooool4o`00
04Kooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0d_ooool5o`0004[o
oooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0c?ooool6o`00053ooooo
00?o0000ooooooooool08_ooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0<Kooooo1_l0
001Gooooo`03o`000?oooooooooo027ooooo000Dooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Ooo
ool00ol0003oooooooooo`2oooooo`Oo0000G_ooool00ol0003oooooooooo`0Pooooo`005Oooool0
0onHV9So8B4Qonk^kP06ooooob?o0000VOooool6o`0006Gooooo00?o0000ooooooooool08?ooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Pooooodgo0000?oooool=o`00
06cooooo00?o0000ooooooooool07oooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`1]ooooocoo0000N_ooool00ol0003oooooooooo`0Nooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Mooooo`005?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooolXooooo`03o`00
0?oooooooooo01gooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003ooooo
ooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo0ol0003oooooob[ooooo00?o
0000ooooooooool06oooool001kooooo00?o0000ooooooooool0oooooolZooooo`03o`000?oooooo
oooo01_ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Joooo
o`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo
00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oo
oooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3o
ooooobkooooo00?o0000ooooooooool05oooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3oooooodSooooo0005ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000oooooooo
ool00_ooool3o`000?ooooooB?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oom8ooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool008Wooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0;Sooooo0029ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:iooooo`00Ooooool01Ol@413o0000o`000?l0
003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413o
ooooooooo`05o`0000Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@1hooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo00Go410@
okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?oo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^
00kooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`1fooooo`00POooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`00
00Gooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP0>ooooo`03ob4Q8Ooooooooooo
00Kooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00omg
MgOoIVIVooooo`0=ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01h
ooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool0
0ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`1j
ooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@41002ooo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0N_ooool007kooooo1ol0
0004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00;ooooo`Go0000
1?ooool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.00942 .41216 L
.01975 .41228 L
.02496 .41233 L
.03053 .41237 L
.03578 .4124 L
.04057 .41243 L
.05147 .41246 L
.05722 .41248 L
.06331 .41251 L
.06863 .41254 L
.07449 .41259 L
.08481 .41271 L
.1069 .41304 L
.11738 .41318 L
.12711 .41327 L
.13194 .41331 L
.13709 .41334 L
.14798 .41339 L
.15334 .41342 L
.15839 .41345 L
.16782 .41352 L
.17271 .41358 L
.17807 .41365 L
.1889 .41382 L
.2083 .41416 L
.21882 .41431 L
.22878 .41442 L
.24027 .41452 L
.25074 .4146 L
.26088 .4147 L
.266 .41476 L
.27165 .41485 L
.29099 .41522 L
.3332 .41595 L
.3526 .41614 L
.3636 .41628 L
.37383 .41645 L
.39487 .41689 L
.40034 .417 L
.40626 .41711 L
.41139 .41718 L
.41702 .41725 L
.42245 .41729 L
.42542 .41731 L
.4282 .41732 L
.42953 .41733 L
.43079 .41733 L
.43194 .41733 L
.43317 .41734 L
Mistroke
.43449 .41734 L
.43572 .41734 L
.43647 .41734 L
.43718 .41734 L
.4385 .41734 L
.43964 .41734 L
.44088 .41734 L
.44218 .41734 L
.44339 .41734 L
.44789 .41734 L
.4504 .41733 L
.45164 .41733 L
.45278 .41733 L
.45409 .41733 L
.45479 .41733 L
.45552 .41733 L
.45671 .41733 L
.45802 .41733 L
.4593 .41733 L
.4605 .41733 L
.4618 .41734 L
.4632 .41734 L
.46605 .41734 L
.46865 .41735 L
.47838 .41738 L
.48101 .41738 L
.48379 .41739 L
.48525 .41739 L
.48602 .41739 L
.48684 .4174 L
.4876 .4174 L
.4883 .4174 L
.48965 .4174 L
.49101 .4174 L
.49227 .41739 L
.49365 .41739 L
.49434 .41739 L
.49511 .41739 L
.4964 .41738 L
.49778 .41737 L
.50029 .41736 L
.5028 .41734 L
.50548 .41731 L
.51032 .41723 L
.51607 .41711 L
.52131 .41697 L
.53269 .41658 L
.54345 .41611 L
.56266 .41515 L
.58381 .41396 L
Mistroke
.60465 .41237 L
.61606 .41122 L
.62674 .40994 L
.66747 .40395 L
.71078 .39604 L
.75249 .38628 L
.79261 .37792 L
.81501 .37395 L
.82559 .37238 L
.83023 .3718 L
.83531 .37128 L
.84026 .37089 L
.84157 .37081 L
.84296 .37074 L
.84427 .37069 L
.84549 .37064 L
.8469 .37061 L
.84765 .37059 L
.84844 .37058 L
.84977 .37058 L
.85053 .37058 L
.85124 .37058 L
.85256 .3706 L
.85377 .37063 L
.85509 .37068 L
.85649 .37074 L
.85887 .37088 L
.86142 .37108 L
.86601 .37158 L
.87146 .3724 L
.87642 .37336 L
.88691 .37606 L
.89658 .37935 L
.90787 .3842 L
.91842 .38987 L
.93814 .40448 L
.94859 .41504 L
.95982 .42901 L
1 .49858 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003goooooa?o0000?Ooo
ool001kooooo00?o0000ooooooooool0l_ooool5o`0001?ooooo0ol0000jooooo`007_ooool00ol0
003oooooooooo`3[ooooo`Oo00006oooool2o`0003Sooooo000Nooooo`03o`000?oooooooooo0>Go
oooo1_l0000Tooooo`;o0000=_ooool001kooooo00?o0000ooooooooool0h?ooool5o`0002cooooo
0ol0000cooooo`007_ooool00ol0003oooooooooo`3Kooooo`Go0000=?ooool2o`00037ooooo000N
ooooo`?o0000eoooool4o`0003_ooooo00?o0000ooooooooool0;_ooool001kooooo00?o0000oooo
ooooool0doooool4o`00043ooooo00?o0000ooooooooool0;Oooool001kooooo00?o0000oooooooo
ool0c_ooool5o`0004Gooooo00?o0000ooooooooool0;?ooool001kooooo00?o0000ooooooooool0
b_ooool4o`0004_ooooo00?o0000ooooooooool0:oooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0<Gooooo1Ol0001@ooooo`03o`000?oooooooooo02[ooooo000Dooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01Oooool00ol0003oooooooooo`2oooooo`Ko0000E_ooool00ol0003ooooooooo
o`0Yooooo`005Oooool00onHV9So8B4Qonk^kP06oooooaoo0000U_ooool=o`0005gooooo00?o0000
ooooooooool0:?ooool001Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0Loooo
oe?o0000<_oooolAo`0006_ooooo00?o0000ooooooooool09oooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`1_oooooc;o0000OOooool00ol0003oooooooooo`0Vooooo`00
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo8?ooool00ol0003ooooo
ooooo`0Uooooo`005?ooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
oooooolQooooo`03o`000?oooooooooo02Cooooo000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1Oooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool001kooooo0ol0
003oooooob;ooooo00?o0000ooooooooool08oooool001kooooo00?o0000ooooooooool0oooooolS
ooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0
003oooooooooo`0Rooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o0000oooooooo
ool08Oooool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo
000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Pooooo`007_ooool0
0ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo0ol0003ooooo
obKooooo00?o0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003ooooo
ooooo`0Nooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Ooo
ool001kooooo00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo01cooooo000Noooo
o`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool3o`000?oo
oooo:_ooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooob[ooooo
00?o0000ooooooooool06oooool001kooooo00?o0000ooooooooool0ooooool[ooooo`03o`000?oo
oooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0J
ooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001ko
oooo00?o0000ooooooooool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`?o0000
ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03o`000?oooooooooo0?oooooo;_oo
ool00ol0003oooooooooo`0Gooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooom8ooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;o
oooo0ol0003oooooodSooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?ooooooB?ooool000Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooB?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooom8ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?oo
ool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3ooooo
odSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0
oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo002Aooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2aooooo`00TOooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b/_ooool008Kooooo00Go410@o`000?l0003o0000oa0@
4006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
1?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000008oa0@4?oooooooooo
oiRHV?l@413o0000oc8b<_o<c<`5ooooo`;o8B4QPoooool008Sooooo00?o0000ooooooooool01_oo
ool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o
410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?o
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00004ooooo`03o`00
0?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4QPoooool008Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`28ooooo`00R?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`0000Co
oooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`29ooooo`00R?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03oa0@4?l0003o^[Zj08[ooooo0025ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o0000
00?o00003Oooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo08Wooooo0025ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`00002:ooooo`00QOooool7o`00
00Gooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oooooooooo
00cooooo00?oEEEEofIVI_l000001?ooool01OnYZJWo410@o`000?l@413oZJVY08[ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41243 L
.05077 .41248 L
.06168 .41253 L
.06795 .41257 L
.07365 .41262 L
.08481 .41275 L
.10641 .41306 L
.1159 .41319 L
.12636 .4133 L
.13612 .41337 L
.14646 .41343 L
.15786 .4135 L
.16829 .41359 L
.17873 .41372 L
.18867 .41388 L
.21059 .41425 L
.22065 .41439 L
.23138 .4145 L
.25069 .41467 L
.26149 .41477 L
.27317 .41494 L
.29435 .41533 L
.3374 .41595 L
.37887 .41641 L
.38958 .41658 L
.39972 .41674 L
.40414 .41679 L
.40883 .41684 L
.41128 .41687 L
.41398 .41689 L
.41643 .4169 L
.41874 .41691 L
.41993 .41691 L
.42124 .41692 L
.42261 .41692 L
.42388 .41692 L
.42507 .41692 L
.42616 .41692 L
.42741 .41692 L
.4286 .41692 L
.42988 .41691 L
.43125 .41691 L
.43369 .4169 L
.43922 .41687 L
.46118 .41672 L
.47185 .41666 L
.48197 .41659 L
.49106 .41651 L
.4962 .41644 L
Mistroke
.50096 .41636 L
.51085 .41613 L
.51638 .41596 L
.52138 .41578 L
.54332 .41472 L
.56527 .41341 L
.58545 .41204 L
.60517 .41035 L
.62598 .40799 L
.6659 .4023 L
.7084 .39544 L
.74931 .38783 L
.76002 .38609 L
.77166 .38446 L
.78171 .38329 L
.7928 .38224 L
.79797 .38183 L
.80353 .38146 L
.80834 .3812 L
.81089 .38108 L
.8136 .38098 L
.81513 .38094 L
.81651 .3809 L
.81792 .38087 L
.81922 .38085 L
.81993 .38084 L
.82068 .38083 L
.82143 .38083 L
.82226 .38083 L
.82297 .38083 L
.82374 .38083 L
.82512 .38084 L
.82648 .38086 L
.82724 .38088 L
.82795 .3809 L
.82923 .38093 L
.83064 .38098 L
.83308 .3811 L
.83567 .38126 L
.84082 .3817 L
.84342 .38199 L
.84625 .38237 L
.85596 .38416 L
.86144 .38553 L
.8673 .38729 L
.87785 .39128 L
.90024 .40316 L
.92139 .419 L
.94238 .44082 L
.96175 .46833 L
Mistroke
1 .54214 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3ZoooooaOo0000A_ooool001kooooo00?o0000ooooooooool0
hoooool7o`0001Oooooo1?l00012ooooo`007_ooool00ol0003oooooooooo`3Nooooo`Go00008_oo
ool3o`0003oooooo000Nooooo`?o0000eoooool7o`0002[ooooo0_l0000mooooo`007_ooool00ol0
003oooooooooo`3Aooooo`Ko0000<oooool2o`0003_ooooo000Nooooo`03o`000?oooooooooo0<[o
oooo1ol0000kooooo`03o`000?oooooooooo03Sooooo000Nooooo`03o`000?oooooooooo0<Cooooo
1_l00013ooooo`;o0000>?ooool001Cooooo1Ol00005ooooo`03o`000?oooooooooo0;kooooo1_l0
001;ooooo`;o0000=_ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0;Sooooo1_l0001Cooooo`03o`000?oooooooooo03?ooooo000Eooooo`03oiRHV?lQ8B7o
k^k^00Kooooo7ol0002@ooooo`co0000F_ooool2o`0003?ooooo000Fooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?o0000ooooooooool07?oooom?o`0002cooooo5Ol0001Xooooo`03o`000?oooooooooo
033ooooo000Gooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0Joooool/o`0007ko
oooo00?o0000ooooooooool0;oooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3ooooooaKooooo00?o0000ooooooooool0;oooool001Cooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`005?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooolHooooo`03o`00
0?oooooooooo02gooooo000Nooooo`?o0000oooooolIooooo`03o`000?oooooooooo02cooooo000N
ooooo`03o`000?oooooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0
003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000oooooooo
ool0oooooolLooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo0?oooooo
7?ooool00ol0003oooooooooo`0Yooooo`007_ooool00ol0003oooooooooo`3ooooooagooooo00?o
0000ooooooooool0:?ooool001kooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooo
oooo02Oooooo000Nooooo`?o0000oooooolOooooo`03o`000?oooooooooo02Kooooo000Nooooo`03
o`000?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003ooooo
ooooo`3oooooob3ooooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooo
oolQooooo`03o`000?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool0
0ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000oooo
ooooool08oooool001kooooo0ol0003oooooob?ooooo00?o0000ooooooooool08_ooool001kooooo
00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3o
ooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0oooooolUoooo
o`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003o
ooooooooo`0Pooooo`007_ooool3o`000?oooooo9_ooool00ol0003oooooooooo`0Oooooo`007_oo
ool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo00?o0000
ooooooooool0oooooolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo
0?oooooo9oooool00ol0003oooooooooo`0Nooooo`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3oooooobSooooo00?o0000oooo
ooooool07Oooool000Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0003oooooooooo`0Loooo
o`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo00;ooooo0ol0003oooooobWo
oooo00?o0000ooooooooool07?ooool000Kooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0Kooooo`001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`3oooooob[ooooo00?o0000ooooooooool06oooool000Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003ooooooooo
o`0Jooooo`001?ooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooob_ooooo00?o0000ooooooooool06_ooool000Cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Oooool00ol0003oooooooooo`3oooooobcooooo00?o
0000ooooooooool06Oooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`?o0000ooooool]ooooo`03o`000?oooooooooo01Sooooo000Nooooo`03
o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003ooooo
ooooo`3oooooobkooooo00?o0000ooooooooool05oooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool008Wooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0;Sooooo0029ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:iooooo`00Ooooool01Ol@413o0000o`000?l0
003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413o
oooooooooonHV9So410@o`000?lb<S;oc<c<1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0
003o0000oc8b<_oMgMd0N?ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@
00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`1fooooo`00
POooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413o
k^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool6o`0000Gooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`0<ooooo`03
oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol@413o0000okZj^P0>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c01hooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o0000
00?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00ol0
003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1jooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9Sooooo
okZj^_l000002oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0N_oo
ool007kooooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool0
0ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0007Wooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41244 L
.06168 .41256 L
.07365 .41266 L
.08481 .41279 L
.10656 .41309 L
.12636 .41332 L
.13645 .4134 L
.14741 .41348 L
.15768 .41356 L
.1673 .41365 L
.17721 .41377 L
.18813 .41393 L
.21021 .41428 L
.23147 .41454 L
.25092 .41471 L
.27086 .41494 L
.28214 .41511 L
.29262 .41529 L
.31235 .41561 L
.32347 .41574 L
.3337 .41583 L
.35618 .41598 L
.37736 .41617 L
.38771 .41628 L
.39341 .41634 L
.39881 .41639 L
.40382 .41642 L
.40666 .41644 L
.40801 .41645 L
.40928 .41645 L
.41043 .41645 L
.41148 .41646 L
.41265 .41646 L
.41391 .41646 L
.41505 .41646 L
.4163 .41646 L
.41761 .41646 L
.41883 .41646 L
.42012 .41645 L
.42132 .41645 L
.42402 .41644 L
.4264 .41643 L
.42893 .41641 L
.4381 .41633 L
.4587 .41607 L
.47948 .41577 L
.48857 .41561 L
.49848 .41539 L
.50895 .41508 L
Mistroke
.5189 .41469 L
.54083 .41354 L
.56326 .41208 L
.58357 .41061 L
.62471 .40657 L
.66683 .4011 L
.70737 .3957 L
.72793 .39287 L
.73882 .39149 L
.75047 .39022 L
.75625 .3897 L
.76172 .38928 L
.76704 .38896 L
.76938 .38885 L
.77196 .38874 L
.7742 .38866 L
.77662 .38859 L
.77795 .38857 L
.77917 .38854 L
.78033 .38853 L
.78156 .38851 L
.78282 .3885 L
.78399 .3885 L
.78471 .3885 L
.78538 .3885 L
.78664 .3885 L
.78798 .38851 L
.78921 .38853 L
.79056 .38855 L
.79199 .38858 L
.79466 .38865 L
.79719 .38874 L
.80193 .38896 L
.80703 .38929 L
.81258 .38976 L
.81743 .39027 L
.82258 .39094 L
.83183 .3925 L
.84165 .39477 L
.85225 .39807 L
.86225 .40209 L
.87143 .40662 L
.89128 .4192 L
.913 .43748 L
.93357 .45989 L
.95556 .49114 L
.9991 .57568 L
1 .57761 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0h_oooolCo`0005;ooooo000Nooooo`?o0000eoooool;
o`0001?ooooo2?l0001:ooooo`007_ooool00ol0003oooooooooo`3Aooooo`Ko00009_ooool3o`00
04Oooooo000Nooooo`03o`000?oooooooooo0<_ooooo1_l0000_ooooo`?o0000A?ooool001kooooo
00?o0000ooooooooool0aOooool6o`0003Sooooo0_l00012ooooo`005?ooool5o`0000Gooooo00?o
0000ooooooooool0__ooool7o`00043ooooo00?o0000ooooooooool0?oooool001Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0;Gooooo2Ol00018ooooo`;o0000?ooo
ool001Gooooo00?oV9RHob4Q8Oo^k^h01_oooolOo`0008Wooooo4?l0001Cooooo`;o0000?Oooool0
01Kooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`0LoooooeWo00003?oooolTo`00
06Gooooo0_l0000kooooo`005oooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo07Go
oooo3?l0002;ooooo`03o`000?oooooooooo03Sooooo000Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo03Oooooo000Dooooo`05o`000?nj
^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0
=_ooool001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`0eooooo`007_ooool3o`000?oooooo4Oooool00ol0003ooooooooo
o`0dooooo`007_ooool00ol0003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0<oooool0
01kooooo00?o0000ooooooooool0oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03
o`000?oooooooooo0?oooooo5?ooool00ol0003oooooooooo`0aooooo`007_ooool00ol0003ooooo
ooooo`3ooooooaGooooo00?o0000ooooooooool0<?ooool001kooooo00?o0000ooooooooool0oooo
oolFooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`000?oooooooooo0?oooooo5oooool0
0ol0003oooooooooo`0^ooooo`007_ooool3o`000?oooooo6?ooool00ol0003oooooooooo`0]oooo
o`007_ooool00ol0003oooooooooo`3ooooooaWooooo00?o0000ooooooooool0;?ooool001kooooo
00?o0000ooooooooool0oooooolJooooo`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oo
oooooooo0?oooooo6_ooool00ol0003oooooooooo`0[ooooo`007_ooool00ol0003oooooooooo`3o
oooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool0oooooolLoooo
o`03o`000?oooooooooo02Wooooo000Nooooo`?o0000oooooolLooooo`03o`000?oooooooooo02Wo
oooo000Nooooo`03o`000?oooooooooo0?oooooo7Oooool00ol0003oooooooooo`0Xooooo`007_oo
ool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool001kooooo00?o0000
ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo
0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`3oooooob3o
oooo00?o0000ooooooooool09Oooool001kooooo0ol0003oooooob3ooooo00?o0000ooooooooool0
9Oooool001kooooo00?o0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Cooooo000N
ooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0
003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool000Cooooo1Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolRoooo
o`03o`000?oooooooooo02?ooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooob?ooooo00?o0000oooo
ooooool08_ooool000Gooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o
0000oooooolTooooo`03o`000?oooooooooo027ooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3oooooobCooooo00?o0000ooooooooool0
8Oooool000Oooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0oooooolUooooo`03o`000?oooooooooo023ooooo0008ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooobGooooo00?o
0000ooooooooool08?ooool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo01oooooo0004
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooo
oolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool0
0ol0003oooooooooo`0Nooooo`007_ooool3o`000?oooooo9oooool00ol0003oooooooooo`0Noooo
o`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo
00?o0000ooooooooool0oooooolXooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oo
oooooooo0?oooooo:Oooool00ol0003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`3o
ooooobWooooo00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0oooooolZoooo
o`03o`000?oooooooooo01_ooooo000Nooooo`?o0000ooooool[ooooo`03o`000?oooooooooo01[o
oooo000Nooooo`03o`000?oooooooooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_oo
ool00ol0003oooooooooo`3oooooobcooooo00?o0000ooooooooool06Oooool001kooooo00?o0000
ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo
0?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool00ol0003oooooooooo`3oooooobgo
oooo00?o0000ooooooooool06?ooool001kooooo0ol0003oooooobkooooo00?o0000ooooooooool0
5oooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01OnHV9So410@
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0oooooom8ooooo`005?ooool01Ol@413o^[Zj
oooooomgMgOo<S8b00Gooooo00?o0000ooooooooool0oooooom8ooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?oZJVYoa0@4?ooool01?oo
ool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@ooooo`005oooool00onj
^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj^_l00000oooooom@oooo
o`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?ooooooJOooool008gooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;Cooooo
002=ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb
<S:eooooo`00Poooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o0000ooooooooool00_oo
ool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413ooooooooooonHV9So410@o`000?lb<S;oc<c<1Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@1looooo`00QOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03
olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo
00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo07[ooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003ooooo
ooooo`05ooooo`03ojVYZOl@413ooooo00kooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`0O?ooool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Co
oooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0000gooooo00?o0000oooooooo
ool01Oooool00onj^[[o8B4Qooooo`0;ooooo`03o`000?oooooooooo07kooooo0022ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`00000<ooooo`03o`000?oooooooooo
07kooooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Go
oooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT03?ooool4o`0007gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41244 L
.08481 .41283 L
.12636 .41333 L
.16632 .4137 L
.18687 .41395 L
.20885 .41427 L
.25237 .41474 L
.2943 .41526 L
.31349 .4155 L
.32441 .41561 L
.33463 .41568 L
.35546 .41578 L
.37754 .41589 L
.38275 .41592 L
.38844 .41595 L
.39104 .41596 L
.39381 .41597 L
.39641 .41597 L
.3988 .41598 L
.40003 .41598 L
.40132 .41598 L
.40263 .41598 L
.40336 .41598 L
.40405 .41598 L
.4053 .41598 L
.40644 .41598 L
.40776 .41598 L
.409 .41598 L
.4113 .41597 L
.41343 .41596 L
.41577 .41595 L
.41825 .41594 L
.42338 .4159 L
.42809 .41585 L
.4387 .41572 L
.45789 .41538 L
.47776 .41496 L
.48915 .41467 L
.4995 .41436 L
.52009 .41351 L
.54208 .41227 L
.58407 .40931 L
.62445 .40557 L
.66742 .40087 L
.68879 .39871 L
.70879 .39686 L
.72797 .39534 L
.73349 .395 L
.73874 .39472 L
Mistroke
.74344 .39452 L
.74612 .39443 L
.74857 .39437 L
.74986 .39434 L
.75126 .39431 L
.75268 .3943 L
.75345 .39429 L
.75417 .39428 L
.7555 .39427 L
.75671 .39427 L
.75738 .39427 L
.75811 .39428 L
.75944 .39429 L
.76062 .3943 L
.76192 .39432 L
.76327 .39435 L
.76455 .39438 L
.76682 .39445 L
.76927 .39454 L
.77488 .39484 L
.78077 .39527 L
.78581 .39575 L
.79131 .39638 L
.80212 .39798 L
.81194 .39988 L
.82327 .40268 L
.83395 .40604 L
.85501 .41514 L
.8744 .42698 L
.89414 .44272 L
.91582 .46444 L
.95823 .52315 L
.99905 .60086 L
1 .60279 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0eooooolJo`0005Kooooo000Nooooo`03o`000?oooooooooo0<_o
oooo3?l0000Jooooo`?o0000Doooool001kooooo00?o0000ooooooooool0`_ooool9o`0002Wooooo
1_l0001=ooooo`005?ooool5o`0000Gooooo00?o0000ooooooooool0]Oooool=o`0003Sooooo0_l0
001;ooooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0ZOoo
ool<o`0004Oooooo0ol00018ooooo`005Oooool00onHV9So8B4Qonk^kP06ooooob;o0000P?ooool:
o`0005Kooooo0_l00016ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo
01ooooooP?l0001Rooooo`;o0000A?ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3oooooo`Cooooo00?o0000ooooooooool0@Oooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3oooooo`Gooooo0_l00011ooooo`005?ooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool0ooooool7ooooo`03o`000?oooooooooo03kooooo
000Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooo`Sooooo
0_l0000nooooo`007_ooool3o`000?oooooo2_ooool00ol0003oooooooooo`0kooooo`007_ooool0
0ol0003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool0>_ooool001kooooo00?o0000oooo
ooooool0ooooool<ooooo`03o`000?oooooooooo03Wooooo000Nooooo`03o`000?oooooooooo0?oo
oooo3Oooool00ol0003oooooooooo`0hooooo`007_ooool00ol0003oooooooooo`3oooooo`kooooo
00?o0000ooooooooool0=oooool001kooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oo
oooooooo03Kooooo000Nooooo`03o`000?oooooooooo0?oooooo4?ooool00ol0003oooooooooo`0e
ooooo`007_ooool3o`000?oooooo4Oooool00ol0003oooooooooo`0dooooo`007_ooool00ol0003o
ooooooooo`3ooooooa;ooooo00?o0000ooooooooool0<oooool001kooooo00?o0000ooooooooool0
oooooolCooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo0?oooooo5?oo
ool00ol0003oooooooooo`0aooooo`007_ooool00ol0003oooooooooo`3ooooooaCooooo00?o0000
ooooooooool0<Oooool001kooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo
033ooooo000Nooooo`?o0000oooooolFooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`00
0?oooooooooo0?oooooo5oooool00ol0003oooooooooo`0^ooooo`007_ooool00ol0003ooooooooo
o`3ooooooaOooooo00?o0000ooooooooool0;_ooool001kooooo00?o0000ooooooooool0oooooolH
ooooo`03o`000?oooooooooo02gooooo000Nooooo`03o`000?oooooooooo0?oooooo6Oooool00ol0
003oooooooooo`0/ooooo`007_ooool00ol0003oooooooooo`3ooooooaWooooo00?o0000oooooooo
ool0;?ooool001kooooo0ol0003ooooooa[ooooo00?o0000ooooooooool0:oooool001kooooo00?o
0000ooooooooool0oooooolKooooo`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo7?ooool00ol0003oooooooooo`0Yooooo`007_ooool00ol0003oooooooooo`3ooooo
oacooooo00?o0000ooooooooool0:Oooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo
02Sooooo0004ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09oooool000Go
oooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolNooooo`03
o`000?oooooooooo02Oooooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool000Oooooo00?o
MgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
oooooolPooooo`03o`000?oooooooooo02Gooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooob7ooooo00?o0000ooooooooool09?oo
ool000Cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolQooooo`03o`000?oooooooooo02Cooooo0004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool4o`0000Gooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003oooooooooo`0S
ooooo`007_ooool3o`000?oooooo8oooool00ol0003oooooooooo`0Rooooo`007_ooool00ol0003o
ooooooooo`3oooooobCooooo00?o0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0
oooooolTooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Ooo
ool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobGooooo00?o0000
ooooooooool08?ooool001kooooo00?o0000ooooooooool0oooooolVooooo`03o`000?oooooooooo
01oooooo000Nooooo`?o0000oooooolVooooo`03o`000?oooooooooo01oooooo000Nooooo`03o`00
0?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`007_ooool00ol0003ooooooooo
o`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo00?o0000ooooooooool0oooooolX
ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo0?oooooo:Oooool00ol0
003oooooooooo`0Looooo`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000oooooooo
ool07?ooool001kooooo0ol0003oooooob[ooooo00?o0000ooooooooool06oooool001kooooo00?o
0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3ooooo
ob_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0ooooool/ooooo`03
o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003ooooo
ooooo`0Hooooo`007_ooool3o`000?oooooo;Oooool00ol0003oooooooooo`0Hooooo`007_ooool0
0ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool05oooool001kooooo00?o0000oooo
ooooool0ooooool^ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Cooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`03o`000?oooooooooo0?oo
ooooB?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03ojVYZOl@413ooooo00Cooooo0ol0003oooooodSooooo000Fooooo`03oa0@4?l0003o
^[Zj0?ooooooD?ooool001Oooooo00?o^[Zjob4Q8Oooool0oooooom?ooooo`005?ooool01Ol@413o
V9RHoooooonj^[[o00000?ooooooD?ooool001Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooo
oe3ooooo003oooooofWooooo0029ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1_ooool00ol0003o^[Zjooooo`2hooooo`00ROooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`04ooooo`;o<S8b^Oooool007oooooo00Go410@o`000?l0003o0000oa0@
4005ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000So410@oooooooo
ooooV9RHoa0@4?l0003o<S8bolc<c0Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@1hooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Go
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`00
0?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool0
1oooool00omgMgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`1fooooo`00POoo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool6o`0000Gooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`0=ooooo`03ob4Q
8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool0Moooool0087ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1?ooool00ol@413o0000okZj^P0>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c01hooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o
00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003o
ooooooooo`05ooooo`03okZj^_lQ8B7ooooo00gooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`1jooooo`00O_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?nHV9SooooookZj
^_l000002oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0N_ooool0
07kooooo1ol00004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0
003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0;
ooooo`Go00001?ooool4o`0007Wooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41244 L
.08481 .41287 L
.12636 .41334 L
.16632 .41374 L
.20885 .41426 L
.2498 .4147 L
.29331 .41515 L
.30389 .41525 L
.31511 .41535 L
.32469 .41541 L
.33524 .41547 L
.34527 .41551 L
.35091 .41552 L
.35606 .41554 L
.36085 .41554 L
.36337 .41555 L
.36607 .41555 L
.36865 .41556 L
.371 .41556 L
.37213 .41556 L
.37335 .41556 L
.37451 .41556 L
.37557 .41556 L
.3769 .41556 L
.37815 .41556 L
.37928 .41556 L
.38051 .41556 L
.38184 .41556 L
.38251 .41556 L
.38325 .41556 L
.38458 .41556 L
.3858 .41556 L
.38817 .41555 L
.39072 .41555 L
.39534 .41553 L
.39795 .41552 L
.40039 .41551 L
.40591 .41548 L
.41129 .41544 L
.41704 .41539 L
.42779 .41526 L
.43945 .41507 L
.46061 .41462 L
.48148 .41405 L
.50357 .41326 L
.52413 .4123 L
.54335 .41121 L
.58412 .40843 L
.62746 .4049 L
Mistroke
.64912 .40304 L
.66921 .40148 L
.68866 .40024 L
.69953 .3997 L
.70937 .39933 L
.7145 .39919 L
.71709 .39914 L
.71992 .39909 L
.72117 .39907 L
.72234 .39906 L
.7237 .39905 L
.72494 .39904 L
.7261 .39904 L
.72718 .39904 L
.72836 .39904 L
.72962 .39905 L
.73097 .39906 L
.7322 .39907 L
.73356 .39909 L
.73499 .39911 L
.73739 .39916 L
.74002 .39923 L
.7429 .39933 L
.74597 .39947 L
.75149 .39978 L
.75711 .40019 L
.76227 .40067 L
.77395 .40212 L
.78424 .40386 L
.79512 .4062 L
.81571 .41223 L
.83496 .42011 L
.8563 .43193 L
.87578 .44598 L
.91758 .48753 L
.95779 .54319 L
1 .6161 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3@oooooa?o
0000I?ooool001kooooo00?o0000ooooooooool0_ooooolAo`0001?ooooo2?l0001Looooo`005?oo
ool5o`0000Gooooo00?o0000ooooooooool0]_ooool9o`0002cooooo1ol0001Eooooo`005?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0ZOooool=o`0003cooooo0ol0
001Booooo`005Oooool00onHV9So8B4Qonk^kP06ooooob;o0000N_ooool@o`0004cooooo0_l0001@
ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooN_l0001Noooo
o`;o0000C_ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3iooooo`;o
0000C?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3kooooo`;o0000
B_ooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?gooooo
0_l00018ooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
ooooool2o`0004Kooooo000Nooooo`?o0000ooooool2ooooo`;o0000A?ooool001kooooo00?o0000
ooooooooool0ooooool4ooooo`03o`000?oooooooooo047ooooo000Nooooo`03o`000?oooooooooo
0?oooooo1Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo0?oooooo1oooool00ol0003o
ooooooooo`0nooooo`007_ooool00ol0003oooooooooo`3oooooo`Sooooo00?o0000ooooooooool0
?Oooool001kooooo00?o0000ooooooooool0ooooool9ooooo`03o`000?oooooooooo03cooooo000N
ooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003oooooooooo`0kooooo`007_ooool3o`00
0?oooooo2oooool00ol0003oooooooooo`0jooooo`007_ooool00ol0003oooooooooo`3oooooo`co
oooo00?o0000ooooooooool0>Oooool001kooooo00?o0000ooooooooool0ooooool=ooooo`03o`00
0?oooooooooo03Sooooo000Nooooo`03o`000?oooooooooo0?oooooo3_ooool00ol0003ooooooooo
o`0gooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo00?o0000ooooooooool0=_ooool0
01kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooooooo03Gooooo000Nooooo`?o
0000oooooolAooooo`03o`000?oooooooooo03Cooooo000Nooooo`03o`000?oooooooooo0?oooooo
4_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003oooooooooo`3ooooooa?ooooo00?o
0000ooooooooool0<_ooool001kooooo00?o0000ooooooooool0oooooolDooooo`03o`000?oooooo
oooo037ooooo000Nooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`oooo
o`007_ooool00ol0003oooooooooo`3ooooooaGooooo00?o0000ooooooooool0<?ooool001kooooo
0ol0003ooooooaKooooo00?o0000ooooooooool0;oooool001kooooo00?o0000ooooooooool0oooo
oolGooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo0?oooooo5oooool0
0ol0003oooooooooo`0^ooooo`007_ooool00ol0003oooooooooo`3ooooooaSooooo00?o0000oooo
ooooool0;Oooool000Cooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00?o0000ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo0004ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`3ooooooa[ooooo00?o0000ooooooooool0:oooool000Gooooo00?oV9RHob4Q8Oo^
k^h04Oooool00ol0003oooooooooo`02ooooo`?o0000oooooolJooooo`03o`000?oooooooooo02_o
oooo0006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool000Oooooo00?oMgMgofIVI_ooool02ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooolLooooo`03o`00
0?oooooooooo02Wooooo0008ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool000Cooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolMooooo`03o`000?oooooooooo02Sooooo0004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool4o`0000Gooooo00?o0000ooooooooool0oooooolNooooo`03o`000?oooooooooo02Oooooo000N
ooooo`03o`000?oooooooooo0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool3o`00
0?oooooo7oooool00ol0003oooooooooo`0Vooooo`007_ooool00ol0003oooooooooo`3oooooob3o
oooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooooolQooooo`03o`00
0?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8Oooool00ol0003ooooooooo
o`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool0
01kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oooooooooo02?ooooo000Nooooo`?o
0000oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo0?oooooo
9?ooool00ol0003oooooooooo`0Qooooo`007_ooool00ol0003oooooooooo`3oooooobCooooo00?o
0000ooooooooool08Oooool001kooooo00?o0000ooooooooool0oooooolUooooo`03o`000?oooooo
oooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Oooool00ol0003oooooooooo`0Poooo
o`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000ooooooooool07oooool001kooooo
0ol0003oooooobOooooo00?o0000ooooooooool07_ooool001kooooo00?o0000ooooooooool0oooo
oolWooooo`03o`000?oooooooooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool0
0ol0003oooooooooo`0Mooooo`007_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000oooo
ooooool07Oooool001kooooo00?o0000ooooooooool0oooooolYooooo`03o`000?oooooooooo01co
oooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0003oooooooooo`0Kooooo`007_oo
ool3o`000?oooooo:_ooool00ol0003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3o
ooooob_ooooo00?o0000ooooooooool06_ooool001kooooo00?o0000ooooooooool0ooooool[oooo
o`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo;?ooool00ol0003o
ooooooooo`0Iooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0ooooool]ooooo`03o`000?oooooooooo01Sooooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb
<S801Oooool00ol0003oooooooooo`3oooooobgooooo00?o0000ooooooooool06?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobkooooo00?o0000ooooooooool0
5oooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool0097ooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00005ooooo`03o`000?nj^[[ooooo0;7ooooo002Aooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:booooo`00Q_ooool01Ol@413o0000o`000?l0
003o410@00Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@oooo
ooooool00_ooool2o`000003oa0@4?oooooooooo00?ooooo0_lQ8B63ooooo`00R?ooool00ol0003o
ooooooooo`06ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooooooo
ool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`00
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o8B4QPoooool008So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<
c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool5o`0008[ooooo0028ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Ko00001?ooool00ol0
003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0008_ooooo0028ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMoeEEEOoooooo0000Roooool008Gooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l00000
0ol0000=ooooo`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l00000Roooool008Gooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00oooool00oo^k^koA4A4o`00002;ooooo`00QOooool7o`0000Gooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oooooooooo00cooooo00?o
EEEEofIVI_l000001_ooool00omgMgOo0000ooooo`2:ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.25) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41243 L
.08481 .4129 L
.12636 .41333 L
.16632 .41378 L
.20885 .41422 L
.2498 .41465 L
.27066 .41484 L
.29331 .41501 L
.31511 .41513 L
.3255 .41518 L
.33059 .4152 L
.33524 .41521 L
.33977 .41523 L
.34471 .41524 L
.34742 .41524 L
.34874 .41524 L
.34994 .41525 L
.35117 .41525 L
.35234 .41525 L
.35357 .41525 L
.3549 .41525 L
.35625 .41525 L
.35752 .41525 L
.3589 .41525 L
.35968 .41525 L
.36039 .41525 L
.36181 .41524 L
.36336 .41524 L
.36618 .41524 L
.36879 .41523 L
.37157 .41522 L
.37656 .4152 L
.3864 .41514 L
.397 .41505 L
.4162 .41483 L
.43724 .41449 L
.45939 .41399 L
.48012 .41335 L
.49941 .41262 L
.5404 .41065 L
.58398 .408 L
.62596 .40529 L
.64519 .40419 L
.65612 .40366 L
.66635 .40323 L
.67641 .40291 L
.67931 .40284 L
.68206 .40278 L
.68476 .40273 L
Mistroke
.68722 .40269 L
.68987 .40267 L
.69133 .40265 L
.6927 .40265 L
.69398 .40264 L
.69515 .40264 L
.69643 .40264 L
.69779 .40265 L
.69916 .40266 L
.69993 .40266 L
.70063 .40267 L
.70329 .4027 L
.70477 .40272 L
.70638 .40275 L
.70931 .40282 L
.71442 .40299 L
.71921 .4032 L
.72446 .40349 L
.73012 .40388 L
.74164 .40494 L
.75219 .40627 L
.7721 .40983 L
.78337 .41255 L
.79385 .41561 L
.81537 .4237 L
.8349 .43341 L
.85679 .44725 L
.87694 .46297 L
.91738 .50378 L
.95881 .55726 L
.99865 .61474 L
1 .61672 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0<[ooooo3_l0001_ooooo`005?ooool5o`0000Gooooo00?o
0000ooooooooool0]OoooolEo`0000kooooo3Ol0001Rooooo`005?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?o0000ooooooooool0Z?ooool=o`00033ooooo0ol0001Oooooo`005Oooool0
0onHV9So8B4Qonk^kP06ooooob;o0000LooooolFo`00043ooooo1_l0001Iooooo`005_ooool00onH
V9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01ooooooLol0001Looooo`;o0000Eoooool001Oo
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3`ooooo`?o0000E?ooool001Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3cooooo`;o0000D_ooool001Cooooo00Go
0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?Gooooo0_l0001@ooooo`005?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0moooool2o`0004kooooo
000Nooooo`?o0000nOooool2o`0004cooooo000Nooooo`03o`000?oooooooooo0?_ooooo0_l0001:
ooooo`007_ooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo04Oooooo000Nooooo`03
o`000?oooooooooo0?kooooo0_l00017ooooo`007_ooool00ol0003oooooooooo`3oooooo`7ooooo
00?o0000ooooooooool0A?ooool001kooooo00?o0000ooooooooool0ooooool2ooooo`;o0000A?oo
ool001kooooo00?o0000ooooooooool0ooooool4ooooo`03o`000?oooooooooo047ooooo000Noooo
o`?o0000ooooool5ooooo`03o`000?oooooooooo043ooooo000Nooooo`03o`000?oooooooooo0?oo
oooo1_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`3oooooo`Oooooo
00?o0000ooooooooool0?_ooool001kooooo00?o0000ooooooooool0ooooool8ooooo`;o0000?_oo
ool001kooooo00?o0000ooooooooool0ooooool:ooooo`03o`000?oooooooooo03_ooooo000Noooo
o`03o`000?oooooooooo0?oooooo2oooool00ol0003oooooooooo`0jooooo`007_ooool3o`000?oo
oooo3?ooool00ol0003oooooooooo`0iooooo`007_ooool00ol0003oooooooooo`3oooooo`gooooo
00?o0000ooooooooool0>?ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oo
oooooooo03Oooooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0f
ooooo`007_ooool00ol0003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0=Oooool001ko
oooo00?o0000ooooooooool0oooooolAooooo`03o`000?oooooooooo03Cooooo000Nooooo`?o0000
oooooolBooooo`03o`000?oooooooooo03?ooooo000Nooooo`03o`000?oooooooooo0?oooooo4ooo
ool00ol0003oooooooooo`0booooo`007_ooool00ol0003oooooooooo`3ooooooaCooooo00?o0000
ooooooooool0<Oooool001kooooo00?o0000ooooooooool0oooooolEooooo`03o`000?oooooooooo
033ooooo0004ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`ooooo`001?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooo
ooooool0oooooolFooooo`03o`000?oooooooooo02oooooo0005ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool00_ooool3o`000?oooooo5oooool00ol0003oooooooooo`0^ooooo`00
1_ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
oooooolHooooo`03o`000?oooooooooo02gooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo0?oooooo6?ooool00ol0003ooooo
ooooo`0]ooooo`002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo0004ooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo6_oo
ool00ol0003oooooooooo`0[ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0
0005ooooo`03o`000?oooooooooo0?oooooo6oooool00ol0003oooooooooo`0Zooooo`007_ooool0
0ol0003oooooooooo`3ooooooa_ooooo00?o0000ooooooooool0:_ooool001kooooo0ol0003ooooo
oacooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000ooooooooool0oooooolMooooo`03
o`000?oooooooooo02Sooooo000Nooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003ooooo
ooooo`0Wooooo`007_ooool00ol0003oooooooooo`3ooooooakooooo00?o0000ooooooooool09ooo
ool001kooooo00?o0000ooooooooool0oooooolOooooo`03o`000?oooooooooo02Kooooo000Noooo
o`03o`000?oooooooooo0?oooooo8?ooool00ol0003oooooooooo`0Uooooo`007_ooool3o`000?oo
oooo8Oooool00ol0003oooooooooo`0Tooooo`007_ooool00ol0003oooooooooo`3oooooob7ooooo
00?o0000ooooooooool09?ooool001kooooo00?o0000ooooooooool0oooooolRooooo`03o`000?oo
oooooooo02?ooooo000Nooooo`03o`000?oooooooooo0?oooooo8oooool00ol0003oooooooooo`0R
ooooo`007_ooool00ol0003oooooooooo`3oooooob?ooooo00?o0000ooooooooool08_ooool001ko
oooo00?o0000ooooooooool0oooooolTooooo`03o`000?oooooooooo027ooooo000Nooooo`?o0000
oooooolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9Ooo
ool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o0000
ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooooooo
01kooooo000Nooooo`03o`000?oooooooooo0?oooooo9oooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`3oooooobSooooo00?o0000ooooooooool07Oooool001kooooo0ol0
003oooooobWooooo00?o0000ooooooooool07?ooool001kooooo00?o0000ooooooooool0oooooolY
ooooo`03o`000?oooooooooo01cooooo000Nooooo`03o`000?oooooooooo0?oooooo:_ooool00ol0
003oooooooooo`0Kooooo`007_ooool00ol0003oooooooooo`3oooooob_ooooo00?o0000oooooooo
ool06_ooool001Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`03o`000?oooooooooo0?oo
oooo:oooool00ol0003oooooooooo`0Jooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo01Wooooo000Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0ooooool]ooooo`;o00006Oooool001Oooooo00?o
ZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@o`000?nj^[X0oooooom@
ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05oa0@4?nHV9SooooookZj
^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY0?ooooooD?ooool00?oo
ooooJOooool008Wooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0;Sooooo0029ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00Cooooo0_lb<S:iooooo`00Ooooool01Ol@413o0000o`000?l0003o410@00Gooooo00?o
0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00Go
V9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413oooooooooo`02ooooo`;o
000000?o410@ooooooooool00oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd0N?ooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko
410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b
<_ooool0Moooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool5o`0000cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`1fooooo`00POooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000oooo
ooooool00_ooool01?m4A4CogMgMooooool0000>ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMg
oc8b<_ooool0Moooool0087ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01?oMgMgoEEEEooooool0
000?ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c01hooooo`00O_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003ooooo
ooooo`0Aooooo`03oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`03ooooo`03ogMg
Moo<c<co0000013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1jooooo`00O_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000cooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo07[ooooo001nooooo`Oo00001?ooool2o`0001?ooooo
00?o0000ooooooooool01?ooool2o`0001Gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIV
o`000006ooooo`03ogMgMol0003ooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
0000NOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.5) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41243 L
.08481 .41293 L
.12636 .41331 L
.16632 .41379 L
.20885 .41416 L
.2498 .41457 L
.26052 .41467 L
.26617 .41471 L
.27217 .41475 L
.2774 .41478 L
.28316 .4148 L
.29331 .41484 L
.3154 .41488 L
.32588 .41491 L
.33562 .41493 L
.34044 .41494 L
.34184 .41494 L
.34315 .41494 L
.34432 .41494 L
.34559 .41494 L
.34691 .41494 L
.34766 .41495 L
.34835 .41495 L
.34909 .41495 L
.34976 .41494 L
.35053 .41494 L
.35127 .41494 L
.35257 .41494 L
.35377 .41494 L
.35509 .41494 L
.35649 .41494 L
.35883 .41493 L
.36135 .41492 L
.36592 .4149 L
.37135 .41487 L
.37633 .41483 L
.38662 .41472 L
.3962 .41459 L
.41793 .41426 L
.4376 .41392 L
.45893 .41342 L
.48134 .41269 L
.5025 .41185 L
.54547 .40998 L
.58684 .40788 L
.60763 .40686 L
.62662 .40615 L
.6371 .40587 L
.64191 .40576 L
Mistroke
.64704 .40567 L
.6499 .40563 L
.65249 .4056 L
.65512 .40557 L
.65754 .40555 L
.65889 .40554 L
.66037 .40553 L
.66186 .40553 L
.66267 .40553 L
.66343 .40552 L
.66415 .40552 L
.66483 .40552 L
.66611 .40552 L
.66748 .40553 L
.66826 .40553 L
.66898 .40553 L
.67022 .40554 L
.67153 .40555 L
.67386 .40557 L
.67637 .4056 L
.67911 .40564 L
.68404 .40575 L
.68861 .40589 L
.69411 .40611 L
.69909 .40636 L
.71026 .40715 L
.72077 .40819 L
.73045 .40943 L
.7523 .41326 L
.77204 .41807 L
.79373 .42519 L
.81419 .4341 L
.83614 .44629 L
.87953 .47814 L
.92134 .51887 L
.96155 .56377 L
1 .60462 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0;Wooooo7?l0001booooo`005?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o
0000ooooooooool0ZOooool@o`0001cooooo2Ol0001Yooooo`005Oooool00onHV9So8B4Qonk^kP06
ooooob;o0000KOoooolMo`0003Gooooo0ol0001Vooooo`005_ooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo01ooooooKOl0001Eooooo`Go0000HOooool001Oooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`3Vooooo`Go0000G?ooool001Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3[ooooo`?o0000FOooool001Cooooo00Go0000okZj^_ooooooV9RH
oa0@4005ooooo`03o`000?oooooooooo0>kooooo0_l0001Gooooo`005?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0l?ooool2o`0005Gooooo000Nooooo`?o0000l_oo
ool2o`0005?ooooo000Nooooo`03o`000?oooooooooo0?Cooooo0_l0001Aooooo`007_ooool00ol0
003oooooooooo`3fooooo`;o0000Coooool001kooooo00?o0000ooooooooool0n?ooool00ol0003o
ooooooooo`1<ooooo`007_ooool00ol0003oooooooooo`3iooooo`;o0000C?ooool001kooooo00?o
0000ooooooooool0noooool2o`0004[ooooo000Nooooo`03o`000?oooooooooo0?gooooo00?o0000
ooooooooool0Aoooool001kooooo0ol0003nooooo`;o0000Aoooool001kooooo00?o0000oooooooo
ool0ooooool1ooooo`03o`000?oooooooooo04Cooooo000Nooooo`03o`000?oooooooooo0?oooooo
0_ooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo0?oooooo1?ooool00ol0003ooooooooo
o`11ooooo`007_ooool00ol0003oooooooooo`3oooooo`Gooooo00?o0000ooooooooool0@?ooool0
01kooooo00?o0000ooooooooool0ooooool6ooooo`;o0000@?ooool001kooooo0ol0003oooooo`So
oooo00?o0000ooooooooool0?Oooool001kooooo00?o0000ooooooooool0ooooool9ooooo`03o`00
0?oooooooooo03cooooo000Nooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003ooooooooo
o`0kooooo`007_ooool00ol0003oooooooooo`3oooooo`_ooooo00?o0000ooooooooool0>_ooool0
01kooooo00?o0000ooooooooool0ooooool<ooooo`03o`000?oooooooooo03Wooooo000Nooooo`03
o`000?oooooooooo0?oooooo3Oooool00ol0003oooooooooo`0hooooo`007_ooool3o`000?oooooo
3_ooool00ol0003oooooooooo`0gooooo`007_ooool00ol0003oooooooooo`3oooooo`oooooo00?o
0000ooooooooool0=_ooool001kooooo00?o0000ooooooooool0ooooool@ooooo`03o`000?oooooo
oooo03Gooooo000Nooooo`03o`000?oooooooooo0?oooooo4Oooool00ol0003oooooooooo`0doooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3ooooooa;ooooo00?o0000ooooooooool0<oooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo4oooool00ol0003oooooooooo`0booooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003ooooooaCooooo00?o0000ooooooooool0<Oooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
5Oooool00ol0003oooooooooo`0`ooooo`001oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`3ooooooaKooooo00?o0000ooooooooool0
;oooool000Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?oooooo5_ooool00ol0003oooooooooo`0_ooooo`001?ooool01Ol0003o^[ZjoooooonH
V9So410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooaOooooo00?o
0000ooooooooool0;_ooool000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3ooooooaSooooo00?o0000ooooooooool0;Oooool001kooooo00?o0000
ooooooooool0oooooolIooooo`03o`000?oooooooooo02cooooo000Nooooo`?o0000oooooolJoooo
o`03o`000?oooooooooo02_ooooo000Nooooo`03o`000?oooooooooo0?oooooo6oooool00ol0003o
ooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0
:Oooool001kooooo00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02Sooooo000N
ooooo`03o`000?oooooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0
003oooooooooo`3ooooooaoooooo00?o0000ooooooooool09_ooool001kooooo0ol0003oooooob3o
oooo00?o0000ooooooooool09Oooool001kooooo00?o0000ooooooooool0oooooolQooooo`03o`00
0?oooooooooo02Cooooo000Nooooo`03o`000?oooooooooo0?oooooo8_ooool00ol0003ooooooooo
o`0Sooooo`007_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool08oooool0
01kooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo02;ooooo000Nooooo`03
o`000?oooooooooo0?oooooo9?ooool00ol0003oooooooooo`0Qooooo`007_ooool3o`000?oooooo
9Oooool00ol0003oooooooooo`0Pooooo`007_ooool00ol0003oooooooooo`3oooooobKooooo00?o
0000ooooooooool07oooool001kooooo00?o0000ooooooooool0oooooolWooooo`03o`000?oooooo
oooo01kooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Moooo
o`007_ooool00ol0003oooooooooo`3oooooobWooooo00?o0000ooooooooool07?ooool001kooooo
00?o0000ooooooooool0oooooolZooooo`03o`000?oooooooooo01_ooooo000Nooooo`?o0000oooo
ool[ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo0?oooooo;?ooool0
0ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`3oooooobgooooo00?o0000oooo
ooooool06?ooool001kooooo00?o0000ooooooooool0ooooool^ooooo`03o`000?oooooooooo01Oo
oooo000Dooooo`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`3oooooodSo
oooo000Dooooo`05oa0@4?nj^[[oooooogMgMolb<S801Oooool00ol0003oooooooooo`3oooooodSo
oooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom8ooooo`005ooo
ool00onYZJWo410@ooooo`04ooooo`?o0000oooooom8ooooo`005_ooool00ol@413o0000okZj^P3o
oooooe3ooooo000Gooooo`03okZj^_lQ8B7ooooo0?ooooooCoooool001Cooooo00Go410@oiRHV?oo
oooo^[Zjo`00003ooooooe3ooooo000Dooooo`05ojVYZOl@413o0000oa0@4?nYZJT0oooooom@oooo
o`00oooooomYooooo`00SOooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo
00?o0000okZj^_ooool0]?ooool008gooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool01?ooool2oc8b<[Gooooo0023ooooo`05oa0@4?l0003o0000o`000?l@41001Ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_l000000ol@413oooooooooo`03ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
07cooooo0025ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj
^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0Noooool008Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool5o`00013ooooo00?o0000ooooooooool0N_ooool008Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo00004?ooool00omgMgOo<S8booooo`1koooo
o`00QOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0000gooooo00Go0000
ob4Q8Ol0003o<S8bolc<c01looooo`00P_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00003Ooo
ool00ol0003oooooooooo`03ooooo`03ogMgMoo<c<co000000gooooo00?o0000ooooooooool0O_oo
ool008;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00oooool00oo^k^koA4A4o`00000=ooooo`03o`000?oo
oooooooo07kooooo0022ooooo`Oo00001?ooool2o`0001?ooooo00?o0000ooooooooool01?ooool2
o`0001Gooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0003o
oooo00cooooo1?l0001mooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.75) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41242 L
.06168 .4127 L
.08481 .41294 L
.10656 .4131 L
.12636 .41328 L
.14691 .41354 L
.15834 .41369 L
.16889 .41381 L
.17865 .4139 L
.189 .41397 L
.19951 .41402 L
.21082 .41409 L
.22153 .41417 L
.23133 .41426 L
.25055 .41447 L
.25555 .41451 L
.26088 .41455 L
.26549 .41459 L
.27048 .41461 L
.27354 .41462 L
.27636 .41463 L
.27905 .41464 L
.28041 .41464 L
.28117 .41464 L
.28189 .41464 L
.28324 .41464 L
.28448 .41464 L
.2858 .41464 L
.28655 .41464 L
.28724 .41464 L
.2884 .41464 L
.28967 .41464 L
.29099 .41464 L
.29224 .41464 L
.30256 .41462 L
.30529 .41462 L
.30819 .41462 L
.30961 .41462 L
.31094 .41462 L
.31215 .41462 L
.31343 .41461 L
.31454 .41461 L
.31575 .41461 L
.31685 .41461 L
.31789 .41461 L
.3191 .41461 L
.32021 .41461 L
.32149 .41462 L
.32271 .41462 L
Mistroke
.32757 .41462 L
.33286 .41463 L
.33555 .41463 L
.33846 .41463 L
.33979 .41464 L
.3412 .41464 L
.34241 .41464 L
.34372 .41464 L
.34501 .41464 L
.34618 .41464 L
.34753 .41464 L
.34881 .41463 L
.35 .41463 L
.35109 .41463 L
.35356 .41463 L
.35618 .41462 L
.35865 .41461 L
.36157 .41459 L
.36425 .41457 L
.36971 .41453 L
.3756 .41447 L
.3955 .41416 L
.41726 .41378 L
.43961 .41339 L
.4599 .41293 L
.47005 .41263 L
.48103 .41225 L
.50095 .41149 L
.54397 .40998 L
.56539 .40921 L
.5854 .40845 L
.59526 .40812 L
.60462 .40787 L
.60978 .40776 L
.6125 .40772 L
.6154 .40768 L
.61782 .40766 L
.61911 .40765 L
.62051 .40764 L
.62178 .40763 L
.62294 .40762 L
.62406 .40762 L
.62524 .40762 L
.62653 .40762 L
.62726 .40762 L
.62793 .40762 L
.62917 .40762 L
.63048 .40763 L
.63165 .40764 L
.63274 .40764 L
Mistroke
.63524 .40766 L
.63793 .40769 L
.6404 .40772 L
.64594 .40782 L
.65582 .40805 L
.66522 .40836 L
.67529 .40881 L
.68603 .40947 L
.69616 .41031 L
.70534 .4113 L
.72556 .41436 L
.73695 .41664 L
.74743 .41908 L
.76889 .42509 L
.78891 .43217 L
.8288 .45197 L
.86968 .47953 L
.91313 .51531 L
.95499 .55202 L
.99525 .57799 L
1 .58054 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00>Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Oooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo1Ol0
000Iooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`05oiRH
V?l@413o0000oc8b<_o<c<`06Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd06_ooool2o`000003oa0@4?oooooooooo01Kooooo000ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06_ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo01Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool01Ol@413o^[ZjoooooomgMgOo<S8b01Wo
oooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Joooo
o`03o`000?oooooooooo01Oooooo000iooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Fooooo`Go00006?ooool003Wooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01Wooooo00?oV9RHob4Q8Oo^k^h06oooool00onHV9So8B4Qonk^kP0?oooo
o`03ogMgMolb<S;ooooo01[ooooo00?oZJVYoa0@4?ooool06oooool00onYZJWo410@ooooo`0>oooo
o`03ogMgMolb<S;ooooo01Oooooo00CoA4A4omgMgOoooooo00006Oooool003Wooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Kooooo`03ogMg
MomVIVKooooo01_ooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01[o
oooo00?o410@o`000?nj^[X06oooool00ol@413o0000okZj^P0<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`06?ooool01?oMgMgoEEEEooooool0000Iooooo`00>Oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07Oooool00onj^[[o8B4Qooooo`0Kooooo`03okZj^_lQ8B7o
oooo00_ooooo00?o0000ooooooooool06oooool00omgMgOoc<c<o`00000Iooooo`00>Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o^[ZjoooooonH
V9So410@01Wooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo01[ooooo
00Go410@oiRHV?oooooo^[Zjo`00000Iooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00ol0
003oooooooooo`0Kooooo`03onk^k_m4A4Co000001Wooooo000iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0001[ooooo00?oEEEEofIVI_l000006oooool00omEEEGoIVIVo`00000=oooo
o`Co00006Oooool01OnHV9So410@o`000?lQ8B7oc<c<01Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00006Oooool01OnYZJWo410@o`000?l@413oZJVY01Wooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`Co00006oooool00omgMgOo0000ooooo`0Hooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomJooooo`;o00000_ooool2o`0000Wooooo003ooooooe[ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd9ooooo`00oooooomKooooo`04omgMgOl0003o410@olc<c0[ooooo000N
oooooooo0000<_l0000;ooooo`04onk^k_lQ8B7o410@onk^kP[ooooo000Nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`007_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool2
o`0000;ooooo0_l00009ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0
003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03
o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`3oooooodSooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000oooooom8ooooo`001?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`3o
ooooodSooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooodSooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0?ooooooB?ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Eooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo
000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom8ooooo`005oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?ooool001Oooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooB?ooool001Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodSooooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom8ooooo`005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooB?oo
ool001Gooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000Nooooo`03o`00
0?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o
0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Noooo
o`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool0
0ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001ko
oooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`00
7_ooool00ol0003oooooooooo`3oooooodSooooo0005ooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo0?oooooo
B?ooool000Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooodSooooo0007ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool00oooool3o`000?ooooooB?ooool000Oooooo00?o0000oooooooo
ool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0oooooom8oooo
o`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0oooooom8ooooo`001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0oooooom8ooooo`001Oooool00omEEEGoIVIVo`00000=ooooo`Co00001Ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo0ol0003oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo
00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool3o`000?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_oo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo0ol0003oooooodSooooo000N
ooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8oooo
o`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oooooo
B?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool3o`000?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo1Ol00005ooooo`03o`000?oo
oooooooo0?ooooooB?ooool001Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oo
oooooooo0:Kooooo:ol0001fooooo`005Oooool00onHV9So8B4Qonk^kP06oooooaoo0000J_oooolP
o`0002_ooooo1ol0001_ooooo`005_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo
01coooooJ_l0001Booooo`Go0000J_ooool001Oooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3Mooooo`Ko0000I?ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Sooooo`?o0000HOooool001Cooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`00
0?oooooooooo0>Kooooo1?l0001Mooooo`005?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0j_ooool3o`0005[ooooo000Nooooo`?o0000kOooool2o`0005Sooooo000N
ooooo`03o`000?oooooooooo0>oooooo0_l0001Fooooo`007_ooool00ol0003oooooooooo`3aoooo
o`;o0000E?ooool001kooooo00?o0000ooooooooool0loooool2o`0005;ooooo000Nooooo`03o`00
0?oooooooooo0?Gooooo0_l0001@ooooo`007_ooool00ol0003oooooooooo`3gooooo`;o0000C_oo
ool001kooooo00?o0000ooooooooool0nOooool2o`0004cooooo000Nooooo`?o0000noooool00ol0
003oooooooooo`19ooooo`007_ooool00ol0003oooooooooo`3looooo`03o`000?oooooooooo04So
oooo000Nooooo`03o`000?oooooooooo0?gooooo0_l00018ooooo`007_ooool00ol0003ooooooooo
o`3oooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo0?oooooo0Oooool0
0ol0003oooooooooo`14ooooo`007_ooool00ol0003oooooooooo`3oooooo`;ooooo0_l00014oooo
o`007_ooool3o`000?oooooo1?ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0003ooooo
ooooo`3oooooo`Gooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0oooo
ool6ooooo`;o0000@?ooool001kooooo00?o0000ooooooooool0ooooool8ooooo`03o`000?oooooo
oooo03gooooo000Nooooo`03o`000?oooooooooo0?oooooo2Oooool00ol0003oooooooooo`0loooo
o`007_ooool00ol0003oooooooooo`3oooooo`[ooooo00?o0000ooooooooool0>oooool001kooooo
0ol0003oooooo`_ooooo00?o0000ooooooooool0>_ooool001kooooo00?o0000ooooooooool0oooo
ool<ooooo`;o0000>_ooool001kooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooo
oooo03Oooooo000Nooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`0foooo
o`001?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`3ooooooa3ooooo00?o0000ooooooooool0=Oooool000Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
0?oooooo4Oooool00ol0003oooooooooo`0dooooo`001Oooool00onHV9So8B4Qonk^kP0Aooooo`03
o`000?oooooooooo00;ooooo0ol0003ooooooa;ooooo00?o0000ooooooooool0<oooool000Kooooo
00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo0?oooooo
4oooool2o`0003?ooooo0007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`0`ooooo`002?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolFooooo`03o`000?oooooooooo02oooooo0004ooooo`05o`000?nj^[[ooooooiRHV?l@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5oooool00ol0003ooooooooo
o`0^ooooo`001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l00005ooooo`03o`000?oo
oooooooo0?oooooo6?ooool00ol0003oooooooooo`0]ooooo`007_ooool00ol0003oooooooooo`3o
oooooaWooooo0_l0000]ooooo`007_ooool3o`000?oooooo6oooool00ol0003oooooooooo`0Zoooo
o`007_ooool00ol0003oooooooooo`3ooooooacooooo00?o0000ooooooooool0:Oooool001kooooo
00?o0000ooooooooool0oooooolMooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`000?oo
oooooooo0?oooooo7_ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`3o
oooooaoooooo00?o0000ooooooooool09_ooool001kooooo00?o0000ooooooooool0oooooolPoooo
o`;o00009_ooool001kooooo0ol0003oooooob;ooooo00?o0000ooooooooool08oooool001kooooo
00?o0000ooooooooool0oooooolSooooo`;o00008oooool001kooooo00?o0000ooooooooool0oooo
oolUooooo`03o`000?oooooooooo023ooooo000Nooooo`03o`000?oooooooooo0?oooooo9_ooool2
o`00023ooooo000Nooooo`03o`000?oooooooooo0?oooooo:?ooool00ol0003oooooooooo`0Moooo
o`007_ooool00ol0003oooooooooo`3oooooobWooooo0_l0000Mooooo`007_ooool3o`000?oooooo
:oooool00ol0003oooooooooo`0Jooooo`007_ooool00ol0003oooooooooo`3oooooobcooooo0ol0
000Iooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo
0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooo
ooooo`3oooooodSooooo000Nooooo`?o0000oooooom8ooooo`007_ooool00ol0003oooooooooo`3o
ooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`005?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo00?o0000oooooooo
ool0oooooom8ooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
B?ooool001Oooooo00?oZJVYoa0@4?ooool01?ooool3o`000?ooooooB?ooool001Kooooo00?o410@
o`000?nj^[X0oooooom@ooooo`005oooool00onj^[[o8B4Qooooo`3oooooodoooooo000Dooooo`05
oa0@4?nHV9SooooookZj^_l00000oooooom@ooooo`005?ooool01OnYZJWo410@o`000?l@413oZJVY
0?ooooooD?ooool00?ooooooJOooool008Wooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0;Sooooo0029ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:iooooo`00Ooooool01Ol@413o0000o`000?l0
003o410@00Gooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o000000?o410@ooooooooool00oooool2ob4Q8@Kooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM07Sooooo0021ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<
o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?oo
ool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`Go
00003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo07Kooooo0021ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko
00001Oooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000oooooo00?o8B4Qoooo
ooooool01_ooool00omgMgOo<S8booooo`1gooooo`00POooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`04omgMgOmEEEGoooooo`0000oooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<07Sooooo001nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol0
0004ooooo`03o`000?oooooooooo017ooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgolc<c?l000003oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oo
oooooooo07[ooooo001nooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000003?oo
ool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool0N_ooool007kooooo1ol0
0004ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003ooooooooo
o`0<ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool02oooool5o`0000Cooooo1?l0
001iooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.25 0 0.206011 [
[.125 -0.0125 -9 -9 ]
[.125 -0.0125 9 0 ]
[.25 -0.0125 -3 -9 ]
[.25 -0.0125 3 0 ]
[.375 -0.0125 -9 -9 ]
[.375 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -9 -9 ]
[.625 -0.0125 9 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -9 -9 ]
[.875 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .10301 -18 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -6 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -6 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -18 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.5)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(1)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(1.5)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(2.5)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(3)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3.5)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10301 m
.00625 .10301 L
s
[(0.5)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(1)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1.5)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(2)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(2.5)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(3)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .41202 m
.04057 .41241 L
.06168 .41271 L
.07365 .41286 L
.08481 .41295 L
.09599 .41302 L
.10656 .41307 L
.11606 .41314 L
.12636 .41324 L
.14584 .4135 L
.15692 .41365 L
.1673 .41377 L
.17245 .41382 L
.17734 .41385 L
.18297 .41389 L
.18813 .41391 L
.19882 .41394 L
.20469 .41396 L
.21021 .41399 L
.21545 .41401 L
.22112 .41405 L
.23101 .41414 L
.25031 .41433 L
.25513 .41438 L
.26029 .41441 L
.26326 .41443 L
.26596 .41445 L
.26726 .41445 L
.26868 .41446 L
.26992 .41446 L
.27125 .41446 L
.27262 .41446 L
.2739 .41447 L
.27464 .41447 L
.27542 .41447 L
.27609 .41447 L
.27682 .41447 L
.2776 .41447 L
.2783 .41447 L
.27912 .41447 L
.27989 .41447 L
.28126 .41446 L
.28274 .41446 L
.28542 .41445 L
.28827 .41444 L
.29337 .41442 L
.30328 .41438 L
.30874 .41436 L
.31143 .41435 L
.31392 .41434 L
Mistroke
.31644 .41434 L
.31873 .41433 L
.32004 .41433 L
.32127 .41433 L
.32257 .41433 L
.3233 .41433 L
.32397 .41433 L
.32507 .41433 L
.3261 .41433 L
.32723 .41433 L
.32844 .41433 L
.3297 .41433 L
.3309 .41433 L
.33315 .41433 L
.33548 .41433 L
.33798 .41433 L
.33868 .41433 L
.33942 .41434 L
.34073 .41434 L
.34197 .41434 L
.34331 .41434 L
.34404 .41434 L
.34473 .41434 L
.34602 .41433 L
.3474 .41433 L
.3489 .41433 L
.35022 .41433 L
.35161 .41432 L
.3541 .41432 L
.3564 .41431 L
.35886 .41429 L
.36332 .41426 L
.36862 .41421 L
.37345 .41415 L
.39346 .41381 L
.41525 .41339 L
.43558 .41307 L
.44639 .41289 L
.45804 .41265 L
.47928 .41204 L
.49924 .41136 L
.5424 .41026 L
.56393 .40983 L
.57443 .4096 L
.58397 .4094 L
.58874 .40932 L
.59125 .40929 L
.59391 .40925 L
.59623 .40923 L
.59746 .40922 L
Mistroke
.59879 .40921 L
.6 .40921 L
.60111 .4092 L
.60223 .4092 L
.60329 .4092 L
.60459 .4092 L
.60577 .4092 L
.60714 .4092 L
.60842 .40921 L
.60961 .40922 L
.6107 .40923 L
.61317 .40926 L
.61567 .40929 L
.61842 .40934 L
.62395 .40948 L
.62946 .40965 L
.63468 .40985 L
.64445 .41032 L
.65511 .41093 L
.66642 .41171 L
.67637 .41252 L
.68734 .41362 L
.70669 .41627 L
.71729 .41821 L
.72701 .4203 L
.74892 .42602 L
.77049 .43286 L
.79055 .44048 L
.83058 .46068 L
.8716 .48619 L
.91519 .51556 L
.93705 .52981 L
.94665 .53509 L
.95719 .53977 L
.96209 .54147 L
.96734 .54297 L
.9723 .54406 L
.97683 .5448 L
.97948 .54513 L
.98193 .54538 L
.98462 .54559 L
.986 .54568 L
.98749 .54575 L
.98892 .54581 L
.99023 .54586 L
.99145 .54589 L
.9928 .54592 L
.99401 .54594 L
.99514 .54596 L
.99633 .54597 L
Mistroke
.9976 .54598 L
1 .54599 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell["\<\
From these plots we can observe an interesting aspect of solutions \
to the heat equation with oscillatory boundary conditions: the temperature \
oscillations at the boundary only penetrate a short distance into the \
material, depending on the thermal diffusivity. The larger the diffusivity, \
the longer the penetration distance of the oscillations (try increasing \
\[Chi] by a factor of 4 in the above plots.)\
\>", "Text"],

Cell[TextData[{
  "\t One can easily understand this intuitively: As the boundary condition \
oscillates, heat flows in and out of the slab though the surface. In an \
oscillation period ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 2  \[Pi]/\[Omega]\_o\)]],
  ", the heat flows into the material only a certain distance, which grows \
larger as \[Chi] increases. (We will see in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", "c:17"},
    ButtonStyle->"Hyperlink"],
  " that this distance scales as ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Chi]\ \[Tau]\)\)]],
  ". ) In one half period, heat flows into the system, and in the next half \
period heat flows back out. The net effect is to average out the \
oscillations,  and so produce a nearly time-independent temperature far from \
the surface."
}], "Text"],

Cell["\<\
\t This is why wine cellars are buried underground. Rock and dirt \
have a rather low thermal diffusivitiy, so the temperature in a wine cellar \
remains nearly constant from day to day, although the earth's surface \
temperature oscillates considerably from day to night and from season to \
season. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2: Cracking the Whip", "Section",
  CellTags->"c:21"],

Cell[TextData[{
  "\tIn the previous example, the system was uniform, so the eigenmodes were \
simply the usual trigonometric Fourier modes. Let us now consider a \
nonuniform system for which the eigenmodes are not trigonometric. This time \
we take an example from the wave equation, and consider a hanging  string of \
uniform mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ". The string is fixed to the ceiling at  ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  ", but the bottom of the string at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " can move freely.  "
}], "Text"],

Cell[TextData[{
  " \tAccording to Eq. ",
  ButtonBox["(3.1.1)",
    ButtonData:>{"Chapter3.nb", "(3.1.1)"},
    ButtonStyle->"Hyperlink"],
  " the tension in such a string increases with height according to ",
  Cell[BoxData[
      \(TraditionalForm\`T(z)\  = \[Rho]\ g\ z\)]],
  ". Therefore, transverse perturbations on the string satisfy the nonuniform \
wave equation ",
  ButtonBox["(3.1.7)",
    ButtonData:>{"Chapter3.nb", "(3.1.7)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(z, t)\) = 
        g \(\[PartialD]\/\[PartialD]z\)[
            z\ \(\[PartialD]\/\[PartialD]z\) \(y(z, t)\)]\)]],
  "."
}], "NE3",
  CellTags->"(4.2.41)"],

Cell[TextData[{
  "There is a regular singular point in this equation at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ", because the string tension vanishes at the free end of the string.  For \
this reason, as a boundary condition we need only specify that ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t)\)]],
  " be finite. The other boundary condition is that the string is fixed to \
the ceiling at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  " so ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(L, t)\)\(\ \)\(=\)\(\ \)\(0.\)\(\ \)\)\)]],
  "These boundary conditions are homogeneous, so the problem is already in \
standard form. Therefore, we can take ",
  Cell[BoxData[
      \(TraditionalForm\`u = 0\)]],
  " and find the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(z, t)\)\(\ \)\)\)]],
  "directly as a generalized Fourier series of eigenmodes,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(z, 
          t)\  = \ \[Sum]\+n\(\( c\_n\)(t)\)\ \(\(\[Psi]\_n\)(z)\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.42)"],

Cell["These eigenmodes satisfy", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g \(\[PartialD]\/\[PartialD]z\)[
            z\ \(\[PartialD]\/\[PartialD]z\) \(\(\[Psi]\_n\)(
                z)\)] = \(-\[Omega]\_n\^2\) \(\(\[Psi]\_n\)(z)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.43)"],

Cell[TextData[{
  "with boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](L) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](0)\)]],
  " finite, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " is the eigenfrequency. The general solution to Eq. ",
  ButtonBox["(4.2.43)",
    ButtonData:>"(4.2.43)",
    ButtonStyle->"Hyperlink"],
  " is in terms of Bessel functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(z) = 
        A\ \(\(J\_o\)(2  \[Omega]\_n\ \@\(\(\(\ \)\(z\)\)\/g\)\ \ )\) + \ 
          B\ \(\(Y\_o\)(\ 
              2\ \(\[Omega]\_n\) \@\(\(\(\ \)\(z\)\)\/g\)\ \ )\)\)]],
  "."
}], "NE3",
  CellTags->"(4.2.44)"],

Cell[TextData[{
  "This can be verified using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[
      g\ D[z\ D[\[Psi][z], z], z]\  \[Equal] \ \(-\[Omega]\^2\)\ \[Psi][
            z], \[Psi][z], z]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.15"],

Cell[BoxData[
    \({{\[Psi][z] \[Rule] 
          BesselJ[0, \(2\ \@z\ \[Omega]\)\/\@g]\ C[1] + 
            BesselY[0, \(2\ \@z\ \[Omega]\)\/\@g]\ C[2]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Since the ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_o\)]],
  " function is singular at the origin, it cannot enter into the eigenmode.  \
The boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](L) = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          z) = \(A\ \(\(J\_o\)(
              2\ \(\[Omega]\_n\) \@\(\(\ \)\(L/g\)\)\ \ )\) = 0\)\)]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Omega]\_n\ \@\(\(\ \)\(L/g\)\) = 
        j\_\(o, n\)\)]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of ",
  Cell[BoxData[
      \(TraditionalForm\`J\_o\)]],
  ", so the eigenfrequencies are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n = \(j\_\(o, n\)\/2\) \@\(g\/L\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.45)"],

Cell["and the eigenfunctions are", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x)\  = \ 
        A\ \(\(J\_o\)(\(j\_\(o, n\)\) \@\(z/L\))\)\)]],
  "."
}], "NE3",
  CellTags->{"i:41", "(4.2.46)"}],

Cell[TextData[{
  "A  few of these eigenmodes are displayed in Cell ",
  ButtonBox["4.16",
    ButtonData:>"Cell 4.16",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< NumericalMath`\ ;\)\), "\n", 
    \(\(j0\  = \ BesselJZeros[0, 5];\)\), "\n", 
    \(\(L = 3;\)\), "\n", 
    \(\(plts\  = \ 
        Table[ParametricPlot[{BesselJ[0, j0[\([n]\)]\ \@\(z/L\)], z}, {z, 0, 
              L}, PlotRange \[Rule] {{\(-1\), 1}, {0, L}}, 
            AspectRatio \[Rule] L/2, Axes \[Rule] False, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] Hue[1/n]], {n, 1, 5}];\)\), "\n", 
    \(\(Show[plts, DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.16"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
[ ] 0 setdash
1 0 m
.9711 .06085 L
.94055 .12721 L
.91274 .18954 L
.88681 .24948 L
.86004 .31328 L
.83509 .37469 L
.80941 .43997 L
.78549 .50286 L
.7632 .56336 L
.74028 .62773 L
.71894 .6897 L
.69909 .74929 L
.67866 .81275 L
.65968 .87381 L
.6402 .93874 L
.62212 1.00128 L
.60534 1.06144 L
.58812 1.12545 L
.57217 1.18708 L
.55586 1.25257 L
.54076 1.31568 L
.5268 1.3764 L
.51252 1.44098 L
.5 1.5 L
s
0 1 1 r
1 0 m
.85702 .06085 L
.72555 .12721 L
.62286 .18954 L
.54104 .24948 L
.4702 .31328 L
.41604 .37469 L
.37175 .43997 L
.35416 .47267 L
.34041 .50286 L
.31941 .56336 L
.31206 .59285 L
.30863 .60982 L
.30596 .62534 L
.30385 .63995 L
.30198 .65591 L
.30114 .66465 L
.30047 .67277 L
.29989 .68111 L
.29946 .68879 L
.29911 .69679 L
.29896 .70091 L
.29884 .70544 L
.29875 .70938 L
.29869 .71306 L
.29866 .71509 L
.29864 .71695 L
.29864 .71797 L
.29863 .71909 L
.29862 .72111 L
.29862 .72292 L
.29862 .72462 L
.29863 .72649 L
.29864 .7285 L
.29866 .73049 L
.29869 .73259 L
.29875 .73634 L
.29882 .73982 L
.29891 .74306 L
.29915 .75042 L
.29949 .75837 L
.29995 .76699 L
.30102 .78264 L
.3038 .81192 L
.3078 .84322 L
.31309 .87636 L
.32499 .93604 L
.34044 .99957 L
.35742 1.06072 L
.37713 1.12573 L
Mistroke
.39723 1.18835 L
.41718 1.24859 L
.43868 1.31269 L
.45932 1.3744 L
.48086 1.43997 L
.5 1.5 L
Mfstroke
0 1 0 r
1 0 m
.83154 .02962 L
.68656 .06085 L
.56938 .09252 L
.47083 .12721 L
.40566 .15804 L
.35577 .19101 L
.3379 .2071 L
.32276 .22457 L
.31718 .23258 L
.31215 .24106 L
.30823 .24902 L
.30527 .25629 L
.30294 .26338 L
.30099 .27111 L
.30018 .27535 L
.29959 .27929 L
.29915 .28305 L
.29897 .28515 L
.29883 .28706 L
.29874 .28886 L
.29867 .29077 L
.29863 .2924 L
.29862 .29419 L
.29864 .29611 L
.29869 .29818 L
.29877 .30012 L
.29888 .3019 L
.29915 .30534 L
.29955 .30908 L
.30055 .31588 L
.30208 .32352 L
.30389 .33069 L
.30923 .34703 L
.32458 .38011 L
.36428 .44105 L
.41537 .50584 L
.46665 .56825 L
.51358 .62827 L
.55781 .69215 L
.59293 .75365 L
.60768 .78501 L
.62115 .81901 L
.63084 .849 L
.63916 .88198 L
.64483 .91328 L
.64703 .93041 L
.64854 .94643 L
.64909 .95427 L
.64933 .95841 L
Mistroke
.64955 .96282 L
.64972 .96706 L
.64984 .97089 L
.64994 .97475 L
.64997 .97648 L
.65 .97838 L
.65003 .98022 L
.65004 .98194 L
.65005 .98375 L
.65006 .98569 L
.65006 .9875 L
.65005 .98921 L
.65004 .99075 L
.65002 .99241 L
.64999 .99423 L
.64996 .99624 L
.64986 1.00029 L
.64975 1.00405 L
.64962 1.00758 L
.64927 1.015 L
.64877 1.0231 L
.64743 1.03943 L
.64579 1.05454 L
.64394 1.06859 L
.63238 1.13017 L
.62397 1.16385 L
.61489 1.19561 L
.59502 1.25628 L
.57122 1.32081 L
.54678 1.38295 L
.52277 1.4427 L
.5 1.5 L
Mfstroke
.5 1 0 r
1 0 m
.84913 .01414 L
.71137 .02962 L
.59347 .04597 L
.5078 .06085 L
.43336 .07745 L
.40285 .08596 L
.37502 .09521 L
.35377 .10376 L
.33769 .11166 L
.32533 .11915 L
.31493 .12721 L
.31074 .13129 L
.30738 .13517 L
.30467 .13894 L
.30263 .14244 L
.30111 .14574 L
.2999 .14926 L
.29939 .15127 L
.29903 .15317 L
.29881 .15487 L
.29866 .15671 L
.29862 .15873 L
.29869 .16063 L
.29889 .16271 L
.29905 .16387 L
.29923 .16493 L
.29969 .16707 L
.30032 .1694 L
.30183 .17362 L
.30588 .18171 L
.31088 .18919 L
.3242 .20435 L
.33988 .21859 L
.38337 .25104 L
.47551 .31197 L
.51979 .34291 L
.56243 .37676 L
.59621 .40946 L
.61984 .43917 L
.62964 .45506 L
.63708 .47006 L
.64305 .48589 L
.64559 .49482 L
.64742 .50305 L
.64864 .51042 L
.64916 .51455 L
.64953 .51832 L
.64978 .52183 L
.64989 .52381 L
Mistroke
.64996 .52565 L
.65002 .52742 L
.65005 .52902 L
.65006 .53087 L
.65005 .53261 L
.65002 .5345 L
.64996 .53657 L
.64991 .53761 L
.64986 .53873 L
.64975 .54075 L
.64946 .54467 L
.6491 .54823 L
.64793 .55691 L
.64641 .56511 L
.6426 .58036 L
.63724 .59653 L
.62461 .62557 L
.58943 .68511 L
.54406 .74851 L
.49882 .80952 L
.45448 .8744 L
.41929 .93689 L
.40513 .9684 L
.3946 .99699 L
.38575 1.02794 L
.38203 1.04494 L
.37927 1.06096 L
.37729 1.07631 L
.37654 1.08405 L
.37591 1.09254 L
.37552 1.0998 L
.37536 1.10386 L
.3753 1.10579 L
.37525 1.10758 L
.37522 1.10922 L
.37519 1.11103 L
.37517 1.11285 L
.37515 1.11479 L
.37515 1.11648 L
.37515 1.11831 L
.37516 1.12004 L
.37518 1.12163 L
.37521 1.12363 L
.37525 1.12553 L
.37535 1.12908 L
.37549 1.1329 L
.37568 1.13704 L
.37614 1.14451 L
.37668 1.15139 L
.37836 1.16722 L
Mistroke
.38076 1.18398 L
.38677 1.21477 L
.39409 1.2436 L
.41415 1.3047 L
.44052 1.36966 L
.4687 1.43223 L
.49653 1.49242 L
.5 1.5 L
Mfstroke
.8 1 0 r
1 0 m
.7699 .01414 L
.58381 .02962 L
.51209 .03743 L
.44956 .04579 L
.40282 .05362 L
.36875 .06085 L
.33836 .06942 L
.32625 .07393 L
.31608 .07871 L
.30931 .08286 L
.30457 .08675 L
.30252 .08897 L
.30103 .09101 L
.30037 .09214 L
.29978 .09336 L
.29933 .09452 L
.29901 .0956 L
.29868 .09758 L
.29862 .0987 L
.29865 .09973 L
.29892 .10162 L
.29948 .10362 L
.30021 .10542 L
.30109 .10709 L
.30374 .1109 L
.30756 .11502 L
.31182 .11877 L
.32382 .12721 L
.35287 .14283 L
.38501 .15727 L
.46444 .18997 L
.53677 .22187 L
.567 .23749 L
.59088 .25181 L
.60995 .26548 L
.62651 .28043 L
.63863 .29545 L
.64336 .30365 L
.6466 .31127 L
.6479 .31541 L
.64883 .31922 L
.64921 .32122 L
.64954 .32341 L
.64968 .32452 L
.6498 .3257 L
.6499 .32681 L
.64996 .32784 L
.65004 .32985 L
.65006 .33091 L
Mistroke
.65005 .33204 L
.65003 .33312 L
.64998 .33413 L
.64986 .33602 L
.64968 .33789 L
.64947 .33961 L
.64881 .34349 L
.64801 .34701 L
.6471 .35029 L
.64445 .35774 L
.64112 .365 L
.63681 .37277 L
.61062 .40628 L
.57767 .43799 L
.50636 .49844 L
.4716 .52904 L
.43768 .56276 L
.41122 .59509 L
.39311 .62469 L
.38636 .63957 L
.38098 .65522 L
.37888 .66336 L
.37736 .67093 L
.37667 .6752 L
.37614 .67923 L
.3759 .68146 L
.37568 .68387 L
.37551 .68608 L
.37538 .68809 L
.37528 .69 L
.37522 .69182 L
.37517 .69373 L
.37516 .69481 L
.37515 .69581 L
.37515 .69748 L
.37518 .69931 L
.37523 .70123 L
.37529 .70303 L
.37539 .70504 L
.37553 .70715 L
.37584 .71093 L
.37628 .715 L
.37688 .71945 L
.37831 .72775 L
.3803 .73663 L
.38501 .75262 L
.3911 .76872 L
.39908 .7862 L
.41668 .81793 L
.46064 .88232 L
Mistroke
.50641 .94433 L
.54693 1.00395 L
.56615 1.03711 L
.58096 1.06744 L
.59315 1.09877 L
.60161 1.12853 L
.6047 1.14365 L
.60605 1.15194 L
.6071 1.15975 L
.60789 1.16705 L
.60823 1.17089 L
.60853 1.17495 L
.60874 1.17837 L
.60892 1.18212 L
.60898 1.18377 L
.60904 1.18553 L
.60909 1.18718 L
.60912 1.18872 L
.60916 1.19064 L
.60917 1.19166 L
.60917 1.19276 L
.60918 1.19385 L
.60918 1.195 L
.60917 1.19705 L
.60915 1.19896 L
.60911 1.20073 L
.60907 1.20268 L
.609 1.20476 L
.6088 1.20946 L
.60854 1.2139 L
.60789 1.2222 L
.60707 1.23011 L
.60613 1.23741 L
.60342 1.25389 L
.59661 1.28347 L
.58652 1.31598 L
.56058 1.37955 L
.53062 1.44073 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{143, 214.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b000132000`400?l00000o`00003o/_ooool0
0:Oooooo2oo<o`0009;ooooo5Oo<o`03ogoo00Co0?l00_l0ool1ooooo`7oo`000023ooooo`ooc?l0
2omoo`05ooooo`Ko0?l00oooool2o`3oo`?ooooo0Ooo0001ooooo`00N?ooool;olco00Oooooo2?mo
o`0:ooooo`Ko0?l01_ooool3o`3oo`Gooooo0Ooo0001ooooo`00KOooool;olco00[ooooo2?moo`0<
ooooo`Ko0?l02_ooool2o`3oo`Oooooo0Ooo0001ooooo`7ooooo001Qooooo`coc?l03_ooool7ogoo
00oooooo1Ol0o`0=ooooo`?o0?oo2Oooool1ool0007ooooo0Oooool005Sooooo2Oo<o`0Cooooo`Oo
Ool04Oooool5o`3o013ooooo0_l0ool;ooooo`03ool00?oooooooooo007ooooo001Booooo`Koc?l0
5Oooool7ogoo01?ooooo1Ol0o`0Booooo`?o0?oo3Oooool00ooo003oooooooooo`01ooooo`00Booo
ool7olco01?ooooo2?moo`0Eooooo`Go0?l05Oooool2o`3oo`oooooo00?oo`00ooooooooool00_oo
ool004Cooooo1oo<o`0Cooooo`OoOol06?ooool5o`3o01Oooooo0ol0oolAooooo`03ool00?oooooo
oooo00;ooooo0010ooooo`Coc?l05?ooool6ogoo01[ooooo1Ol0o`0Jooooo`;o0?oo4oooool00ooo
003oooooooooo`03ooooo`00?Oooool3olco01?ooooo1Omoo`0Mooooo`?o0?l07Oooool2o`3ooaGo
oooo00?oo`00ooooooooool00oooool003_ooooo0_o<o`0Booooo`CoOol07_ooool4o`3o01kooooo
0_l0oolFooooo`03ool00?oooooooooo00Cooooo000iooooo`;oc?l04Oooool3ogoo01oooooo0ol0
o`0Pooooo`;o0?oo6?ooool00ooo003oooooooooo`04ooooo`00=_ooool3olco013ooooo0omoo`0N
ooooo`Co0?l08Oooool2o`3ooa[ooooo00?oo`00ooooooooool01?ooool003Gooooo0_o<o`0?oooo
o`?oOol07_ooool3o`3o02?ooooo0_l0oolKooooo`03ool00?oooooooooo00Gooooo000eooooo`03
olco0?oooooooooo00_ooooo0omoo`0Nooooo`?o0?l09?ooool2o`3ooagooooo00?oo`00oooooooo
ool01Oooool003Gooooo00?oc?l0ooooooooool02?ooool3ogoo01kooooo0ol0o`0Uooooo`;o0?oo
7_ooool00ooo003oooooooooo`06ooooo`00=Oooool00oo<o`3oooooooooo`05ooooo`?oOol07_oo
ool3o`3o02Kooooo0_l0oolPooooo`03ool00?oooooooooo00Kooooo000eooooo`03olco0?oooooo
oooo00?ooooo0_moo`0Nooooo`?o0?l09oooool2o`3oob7ooooo00?oo`00ooooooooool01oooool0
03Kooooo00Goc?l0ooooooooooooooooogoo000Mooooo`?o0?l0:?ooool2o`3oob?ooooo00?oo`00
ooooooooool01oooool003Oooooo0_o<o`000omoo`3oooooooooo`0Iooooo`?o0?l0:Oooool2o`3o
obGooooo00?oo`00ooooooooool01oooool003Oooooo00CoOol0ooooooo<o`3oc?l05oooool3o`3o
02[ooooo0_l0oolVooooo`03ool00?oooooooooo00Sooooo000gooooo`04ogoo0?oooooooooooooo
o`;oc?l04oooool2o`3o02cooooo00?o0?ooooooooooool09_ooool00ooo003oooooooooo`08oooo
o`00=_ooool00omoo`3oooooooooo`04ooooo`03olco0?oooooooooo00kooooo0_l0o`0/ooooo`;o
0?oo:?ooool00ooo003oooooooooo`09ooooo`00=Oooool00omoo`3oooooooooo`06ooooo`;oc?l0
3Oooool00ol0o`3oooooooooo`0Zooooo`;o0?oo:_ooool00ooo003oooooooooo`09ooooo`00=Ooo
ool00omoo`3oooooooooo`08ooooo`;oc?l02Oooool2o`3o02cooooo00?o0?ooooooooooool0:Ooo
ool00ooo003oooooooooo`0:ooooo`00=Oooool00omoo`3oooooooooo`0:ooooo`;oc?l01Oooool2
o`3o02cooooo0_l0ool/ooooo`03ool00?oooooooooo00[ooooo000eooooo`03ogoo0?oooooooooo
00cooooo0_o<o`000ooooooo0?l0o`3o000/ooooo`;o0?oo;Oooool00ooo003oooooooooo`0;oooo
o`00=Oooool00omoo`3oooooooooo`0>ooooo`?oc?l0:oooool00ol0ooooooooooooo`0]ooooo`03
ool00?oooooooooo00_ooooo000eooooo`03ogoo0?oooooooooo00cooooo0_l0o`03ooooo`?oc?l0
9_ooool2o`3ooc3ooooo00?oo`00ooooooooool02oooool003Gooooo00?oOol0ooooooooool02ooo
ool00ol0o`3oooooooooo`06ooooo`?oc?l08Oooool2o`3ooc7ooooo00?oo`00ooooooooool03?oo
ool003Kooooo00?oOol0ooooooooool02?ooool2o`3o00cooooo0oo<o`0Mooooo`03o`3ooooooooo
oooo037ooooo00?oo`00ooooooooool03?ooool003Oooooo00?oOol0ooooooooool01_ooool00ol0
o`3oooooooooo`0?ooooo`;oc?l06Oooool2o`3ooc?ooooo00?oo`00ooooooooool03Oooool003Oo
oooo00?oOol0ooooooooool01?ooool2o`3o01Cooooo0_o<o`0Fooooo`03o`3ooooooooooooo03?o
oooo00?oo`00ooooooooool03Oooool003Sooooo00?oOol0ooooooooool00_ooool00ol0o`3ooooo
ooooo`0Fooooo`;oc?l04oooool00ol0ooooooooooooo`0cooooo`03ool00?oooooooooo00kooooo
000iooooo`;oOol000?oooooo`3o0?ooool06_ooool3olco00oooooo00?o0?ooooooooooool0=?oo
ool00ooo003oooooooooo`0>ooooo`00>oooool00omoo`3o0?l0ooooo`0Mooooo`;oc?l02oooool2
o`3oocKooooo00?oo`00ooooooooool03oooool003_ooooo00?o0?l0ogoo0?moo`007oooool2olco
00Sooooo00?o0?ooooooooooool0=_ooool00ooo003oooooooooo`0?ooooo`00>_ooool01Ol0o`3o
ooooooooooooooooOol0023ooooo0_o<o`05ooooo`03o`3ooooooooooooo03Kooooo00?oo`00oooo
ooooool04?ooool003Wooooo00?o0?l0ooooooooool00oooool00omoo`3oooooooooo`0Oooooo`;o
c?l000?oooooo`3oool0ool0>Oooool00ooo003oooooooooo`0@ooooo`00>?ooool00ol0o`3ooooo
ooooo`05ooooo`;oOol08Oooool00oo<o`3oooooooooo`0iooooo`03ool00?oooooooooo013ooooo
000gooooo`03o`3o0?oooooooooo00Sooooo00?oOol0ooooooooool07Oooool01?l0ooooooooolco
0?o<o`0hooooo`03ool00?oooooooooo017ooooo000gooooo`03o`3o0?oooooooooo00Wooooo00?o
Ool0ooooooooool06oooool00ol0ooooooooooooo`02ooooo`?oc?l0=Oooool00ooo003ooooooooo
o`0Aooooo`00=_ooool00ol0o`3oooooooooo`0;ooooo`;oOol06Oooool2o`3oo`Sooooo00?oc?l0
ooooooooool0<Oooool00ooo003oooooooooo`0Booooo`00=_ooool00ol0o`3oooooooooo`0=oooo
o`03ogoo0?oooooooooo01Gooooo00?o0?ooooooooooool02Oooool00oo<o`3oooooooooo`0`oooo
o`03ool00?oooooooooo01;ooooo000eooooo`03o`3o0?oooooooooo00oooooo0_moo`0Dooooo`03
o`3ooooooooooooo00_ooooo00?oc?l0ooooooooool0;_ooool00ooo003oooooooooo`0Cooooo`00
=Oooool00ol0o`3oooooooooo`0Aooooo`03ogoo0?oooooooooo013ooooo00?o0?ooooooooooool0
3Oooool2olco02kooooo00?oo`00ooooooooool04oooool003Gooooo00?o0?l0ooooooooool04_oo
ool2ogoo00oooooo00?o0?ooooooooooool04?ooool00oo<o`3oooooooooo`0Zooooo`03ool00?oo
oooooooo01Cooooo000eooooo`03o`3o0?oooooooooo01Cooooo00?oOol0ooooooooool02_ooool2
o`3ooaCooooo00?oc?l0ooooooooool0:Oooool00ooo003oooooooooo`0Dooooo`00=Oooool00ol0
o`3oooooooooo`0Eooooo`03ogoo0?oooooooooo00Sooooo00?o0?ooooooooooool05?ooool00oo<
o`3oooooooooo`0Xooooo`03ool00?oooooooooo01Gooooo000eooooo`03o`3o0?oooooooooo01Ko
oooo0_moo`07ooooo`03o`3ooooooooooooo01Kooooo00?oc?l0ooooooooool09oooool00ooo003o
ooooooooo`0Eooooo`00=Oooool00ol0o`3oooooooooo`0Hooooo`03ogoo0?oooooooooo00?ooooo
00?o0?ooooooooooool06?ooool00oo<o`3oooooooooo`0Vooooo`03ool00?oooooooooo01Gooooo
000eooooo`03o`3o0?oooooooooo01Wooooo0_moo`02ooooo`03o`3ooooooooooooo01Wooooo00?o
c?l0ooooooooool09Oooool00ooo003oooooooooo`0Fooooo`00=Oooool00ol0o`3oooooooooo`0K
ooooo`03ogoo0?l0oooooooo01cooooo00?oc?l0ooooooooool09?ooool00ooo003oooooooooo`0F
ooooo`00=Oooool00ol0o`3oooooooooo`0Kooooo`03o`3ooomoo`3oOol001cooooo00?oc?l0oooo
ooooool08oooool00ooo003oooooooooo`0Gooooo`00=Oooool00ol0o`3oooooooooo`0Kooooo`04
o`3oooooooooooooogoo01cooooo00?oc?l0ooooooooool08_ooool00ooo003oooooooooo`0Goooo
o`00=Oooool00ol0o`3oooooooooo`0Jooooo`03o`3ooooooooooooo00;ooooo00?oOol0oooooooo
ool06Oooool00oo<o`3oooooooooo`0Qooooo`03ool00?oooooooooo01Sooooo000fooooo`03o`3o
0?oooooooooo01Sooooo00?o0?ooooooooooool01?ooool2ogoo01Wooooo00?oc?l0ooooooooool0
8Oooool00ooo003oooooooooo`0Hooooo`00=_ooool00ol0o`3oooooooooo`0Gooooo`03o`3ooooo
oooooooo00Oooooo00?oOol0ooooooooool05_ooool00oo<o`3oooooooooo`0Qooooo`03ool00?oo
oooooooo01Sooooo000fooooo`03o`3o0?oooooooooo01Kooooo00?o0?ooooooooooool02Oooool0
0omoo`3oooooooooo`0Eooooo`03olco0?oooooooooo023ooooo00?oo`00ooooooooool06Oooool0
03Kooooo00?o0?l0ooooooooool05Oooool00ol0ooooooooooooo`0;ooooo`;oOol05Oooool00oo<
o`3oooooooooo`0Pooooo`03ool00?oooooooooo01Wooooo000fooooo`03o`3o0?oooooooooo01Co
oooo00?o0?ooooooooooool03_ooool00omoo`3oooooooooo`0Booooo`03olco0?oooooooooo023o
oooo00?oo`00ooooooooool06Oooool003Oooooo00?o0?l0ooooooooool04_ooool00ol0oooooooo
ooooo`0@ooooo`03ogoo0?oooooooooo013ooooo00?oc?l0ooooooooool08?ooool00ooo003ooooo
ooooo`0Jooooo`00=oooool00ol0o`3oooooooooo`0Aooooo`03o`3ooooooooooooo01;ooooo00?o
Ool0ooooooooool03_ooool00oo<o`3oooooooooo`0Qooooo`03ool00?oooooooooo01[ooooo000h
ooooo`03o`3o0?oooooooooo00oooooo00?o0?ooooooooooool05?ooool00omoo`3oooooooooo`0=
ooooo`03olco0?oooooooooo027ooooo00?oo`00ooooooooool06_ooool003Sooooo00?o0?l0oooo
ooooool03_ooool00ol0ooooooooooooo`0Fooooo`03ogoo0?oooooooooo00cooooo00?oc?l0oooo
ooooool08?ooool00ooo003oooooooooo`0Kooooo`00>Oooool00ol0o`3oooooooooo`0=ooooo`03
o`3ooooooooooooo01Oooooo0_moo`0<ooooo`03olco0?oooooooooo023ooooo00?oo`00oooooooo
ool06oooool003Wooooo00?o0?l0ooooooooool03?ooool00ol0ooooooooooooo`0Jooooo`03ogoo
0?oooooooooo00Sooooo00?oc?l0ooooooooool08?ooool00ooo003oooooooooo`0Looooo`00>_oo
ool00ol0o`3oooooooooo`0;ooooo`03o`3ooooooooooooo01_ooooo00?oOol0ooooooooool01_oo
ool00oo<o`3oooooooooo`0Qooooo`03ool00?oooooooooo01cooooo000kooooo`03o`3o0?oooooo
oooo00Wooooo00?o0?ooooooooooool07Oooool00omoo`3oooooooooo`04ooooo`03olco0?oooooo
oooo02;ooooo00?oo`00ooooooooool07?ooool003_ooooo00?o0?l0ooooooooool02?ooool00ol0
ooooooooooooo`0Oooooo`03ogoo0?oooooooooo00;ooooo00?oc?l0ooooooooool08_ooool00ooo
003oooooooooo`0Mooooo`00??ooool00ol0o`3oooooooooo`07ooooo`03o`3ooooooooooooo023o
oooo00CoOol0ooooooo<o`3oc?l09Oooool00ooo003oooooooooo`0Mooooo`00?Oooool00ol0o`3o
ooooooooo`05ooooo`03o`3ooooooooooooo027ooooo00?oOol0olco0?ooool09Oooool00ooo003o
ooooooooo`0Nooooo`00?Oooool00ol0o`3oooooooooo`05ooooo`03o`3ooooooooooooo027ooooo
00?oc?l0ogoo0?ooool09Oooool00ooo003oooooooooo`0Nooooo`00?_ooool00ol0o`3ooooooooo
o`03ooooo`03o`3ooooooooooooo027ooooo00Coc?l0ooooooooooooOol09?ooool00ooo003ooooo
ooooo`0Oooooo`00?_ooool00ol0o`3oooooooooo`02ooooo`03o`3ooooooooooooo027ooooo00?o
c?l0ooooooooool00_ooool00omoo`3oooooooooo`0Qooooo`03ool00?oooooooooo01oooooo000o
ooooo`05o`3o0?ooooooooooooooool0ool08Oooool2olco00Kooooo00?oOol0ooooooooool08?oo
ool00ooo003oooooooooo`0Oooooo`00@?ooool00ol0o`3oooooo`3oo`0Qooooo`03olco0?oooooo
oooo00Oooooo00?oOol0ooooooooool07_ooool00ooo003oooooooooo`0Pooooo`00@?ooool00ol0
o`3oooooo`3oo`0Pooooo`03olco0?oooooooooo00Sooooo00?oOol0ooooooooool07_ooool00ooo
003oooooooooo`0Pooooo`00@Oooool00ol0o`3oooooooooo`0Nooooo`03olco0?oooooooooo00[o
oooo00?oOol0ooooooooool07?ooool00ooo003oooooooooo`0Qooooo`00@?ooool00ol0oooooooo
o`3o000Nooooo`03olco0?oooooooooo00_ooooo00?oOol0ooooooooool07?ooool00ooo003ooooo
ooooo`0Qooooo`00@?ooool01?l0ooooooooooooool0o`0Looooo`03olco0?oooooooooo00gooooo
00?oOol0ooooooooool06oooool00ooo003oooooooooo`0Qooooo`00?oooool01Ol0oooooooooooo
oooooooo0?l001_ooooo00?oc?l0ooooooooool03oooool00omoo`3oooooooooo`0Iooooo`03ool0
0?oooooooooo02;ooooo000nooooo`03o`3ooooooooooooo00?ooooo00?o0?l0ooooooooool05ooo
ool00oo<o`3oooooooooo`0@ooooo`03ogoo0?oooooooooo01Wooooo00?oo`00ooooooooool08_oo
ool003kooooo00?o0?ooooooooooool01?ooool00ol0o`3oooooooooo`0Eooooo`03olco0?oooooo
oooo01;ooooo00?oOol0ooooooooool06?ooool00ooo003oooooooooo`0Rooooo`00?Oooool00ol0
ooooooooooooo`06ooooo`03o`3o0?oooooooooo01?ooooo00?oc?l0ooooooooool04oooool00omo
o`3oooooooooo`0Gooooo`03ool00?oooooooooo02?ooooo000mooooo`03o`3ooooooooooooo00Ko
oooo00?o0?l0ooooooooool04_ooool00oo<o`3oooooooooo`0Dooooo`03ogoo0?oooooooooo01Oo
oooo00?oo`00ooooooooool08oooool003gooooo00?o0?ooooooooooool01oooool00ol0o`3ooooo
ooooo`0?ooooo`;oc?l05oooool00omoo`3oooooooooo`0Gooooo`03ool00?oooooooooo02?ooooo
000looooo`03o`3ooooooooooooo00Wooooo00?o0?l0ooooooooool03Oooool00oo<o`3ooooooooo
o`0Hooooo`03ogoo0?oooooooooo01Gooooo00?oo`00ooooooooool09?ooool003cooooo00?o0?oo
ooooooooool02_ooool00ol0o`3oooooooooo`0;ooooo`03olco0?oooooooooo01Wooooo00?oOol0
ooooooooool05Oooool00ooo003oooooooooo`0Tooooo`00>oooool00ol0ooooooooooooo`0;oooo
o`03o`3o0?oooooooooo00[ooooo00?oc?l0ooooooooool06_ooool00omoo`3oooooooooo`0Doooo
o`03ool00?oooooooooo02Gooooo000kooooo`03o`3ooooooooooooo00cooooo00?o0?l0oooooooo
ool02?ooool00oo<o`3oooooooooo`0Kooooo`03ogoo0?oooooooooo01Cooooo00?oo`00oooooooo
ool09Oooool003_ooooo00?o0?ooooooooooool03Oooool00ol0o`3oooooooooo`06ooooo`03olco
0?oooooooooo01cooooo00?oOol0ooooooooool05?ooool00ooo003oooooooooo`0Uooooo`00>_oo
ool00ol0ooooooooooooo`0?ooooo`03o`3o0?oooooooooo00Cooooo00?oc?l0ooooooooool07Ooo
ool00omoo`3oooooooooo`0Cooooo`03ool00?oooooooooo02Kooooo000jooooo`03o`3ooooooooo
oooo013ooooo00?o0?l0ooooooooool00_ooool00oo<o`3oooooooooo`0Nooooo`03ogoo0?oooooo
oooo01?ooooo00?oo`00ooooooooool09_ooool003[ooooo00?o0?ooooooooooool04Oooool01?l0
o`3oooooooooooo<o`0Qooooo`03ogoo0?oooooooooo01?ooooo00?oo`00ooooooooool09_ooool0
03Wooooo00?o0?ooooooooooool04_ooool00ol0o`3oooooolco000Rooooo`03ogoo0?oooooooooo
01;ooooo00?oo`00ooooooooool09oooool003Wooooo00?o0?ooooooooooool04oooool00oo<o`3o
ooooooooo`0Qooooo`03ogoo0?oooooooooo01;ooooo00?oo`00ooooooooool09oooool003Wooooo
00?o0?ooooooooooool04_ooool00oo<o`3oooooo`3o000Rooooo`03ogoo0?oooooooooo01;ooooo
00?oo`00ooooooooool09oooool003Sooooo00?o0?ooooooooooool04_ooool01Oo<o`3ooooooooo
oooooooo0?l0023ooooo00?oOol0ooooooooool04_ooool00ooo003oooooooooo`0Xooooo`00>?oo
ool00ol0ooooooooooooo`0Booooo`03olco0?oooooooooo00;ooooo00?o0?l0ooooooooool07Ooo
ool00omoo`3oooooooooo`0Booooo`03ool00?oooooooooo02Sooooo000hooooo`03o`3ooooooooo
oooo017ooooo00?oc?l0ooooooooool00oooool00ol0o`3oooooooooo`0Mooooo`03ogoo0?oooooo
oooo017ooooo00?oo`00ooooooooool0:Oooool003Oooooo00?o0?ooooooooooool04Oooool00oo<
o`3oooooooooo`05ooooo`03o`3o0?oooooooooo01cooooo00?oOol0ooooooooool04Oooool00ooo
003oooooooooo`0Yooooo`00=oooool00ol0ooooooooooooo`0@ooooo`03olco0?oooooooooo00Oo
oooo00?o0?l0ooooooooool06oooool00omoo`3oooooooooo`0Aooooo`03ool00?oooooooooo02Wo
oooo000gooooo`03o`3ooooooooooooo00oooooo00?oc?l0ooooooooool02Oooool00ol0o`3ooooo
ooooo`0Iooooo`03ogoo0?oooooooooo017ooooo00?oo`00ooooooooool0:_ooool003Oooooo00?o
0?ooooooooooool03oooool00oo<o`3oooooooooo`0:ooooo`03o`3o0?oooooooooo01Sooooo00?o
Ool0ooooooooool04Oooool00ooo003oooooooooo`0Zooooo`00=_ooool00ol0ooooooooooooo`0?
ooooo`03olco0?oooooooooo00cooooo00?o0?l0ooooooooool05oooool00omoo`3oooooooooo`0A
ooooo`03ool00?oooooooooo02[ooooo000fooooo`03o`3ooooooooooooo00kooooo00?oc?l0oooo
ooooool03_ooool00ol0o`3oooooooooo`0Eooooo`03ogoo0?oooooooooo017ooooo00?oo`00oooo
ooooool0:oooool003Kooooo00?o0?ooooooooooool03_ooool00oo<o`3oooooooooo`0?ooooo`03
o`3o0?oooooooooo01Cooooo00?oOol0ooooooooool04Oooool00ooo003oooooooooo`0[ooooo`00
=_ooool00ol0ooooooooooooo`0=ooooo`03olco0?oooooooooo017ooooo00?o0?l0ooooooooool0
4oooool00omoo`3oooooooooo`0Aooooo`03ool00?oooooooooo02_ooooo000fooooo`03o`3ooooo
oooooooo00cooooo00?oc?l0ooooooooool04oooool00ol0o`3oooooooooo`0Aooooo`03ogoo0?oo
oooooooo017ooooo00?oo`00ooooooooool0;?ooool003Kooooo00?o0?ooooooooooool03?ooool0
0oo<o`3oooooooooo`0Cooooo`03o`3o0?oooooooooo017ooooo00?oOol0ooooooooool04Oooool0
0ooo003oooooooooo`0/ooooo`00=_ooool00ol0ooooooooooooo`0;ooooo`03olco0?oooooooooo
01Gooooo00?o0?l0ooooooooool03oooool00omoo`3oooooooooo`0Aooooo`03ool00?oooooooooo
02gooooo000fooooo`03o`3ooooooooooooo00_ooooo00?oc?l0ooooooooool05_ooool00ol0o`3o
ooooooooo`0=ooooo`03ogoo0?oooooooooo01;ooooo00?oo`00ooooooooool0;Oooool003Gooooo
00?o0?ooooooooooool02oooool00oo<o`3oooooooooo`0Gooooo`03o`3o0?oooooooooo00gooooo
00?oOol0ooooooooool04_ooool00ooo003oooooooooo`0]ooooo`00=Oooool00ol0oooooooooooo
o`0;ooooo`03olco0?oooooooooo01Sooooo00?o0?l0ooooooooool02oooool00omoo`3ooooooooo
o`0Booooo`03ool00?oooooooooo02kooooo000eooooo`03o`3ooooooooooooo00_ooooo00?oc?l0
ooooooooool06Oooool00ol0o`3oooooooooo`09ooooo`03ogoo0?oooooooooo01?ooooo00?oo`00
ooooooooool0;_ooool003Gooooo00?o0?ooooooooooool02oooool00oo<o`3oooooooooo`0Ioooo
o`03o`3o0?oooooooooo00Sooooo00?oOol0ooooooooool05?ooool00ooo003oooooooooo`0^oooo
o`00=Oooool00ol0ooooooooooooo`0;ooooo`03olco0?oooooooooo01[ooooo00?o0?l0oooooooo
ool01oooool00omoo`3oooooooooo`0Cooooo`03ool00?oooooooooo02oooooo000eooooo`03o`3o
oooooooooooo00[ooooo00?oc?l0ooooooooool07?ooool00ol0o`3oooooooooo`05ooooo`03ogoo
0?oooooooooo01Cooooo00?oo`00ooooooooool0;oooool003Gooooo00?o0?ooooooooooool02_oo
ool00oo<o`3oooooooooo`0Looooo`03o`3o0?oooooooooo00Cooooo00?oOol0ooooooooool05Ooo
ool00ooo003oooooooooo`0_ooooo`00=Oooool00ol0ooooooooooooo`0:ooooo`03olco0?oooooo
oooo01gooooo00?o0?l0ooooooooool00oooool00omoo`3oooooooooo`0Dooooo`03ool00?oooooo
oooo033ooooo000eooooo`03o`3ooooooooooooo00[ooooo00?oc?l0ooooooooool07_ooool01Ol0
o`3oooooooooooooooooOol001Oooooo00?oo`00ooooooooool0<?ooool003Gooooo00?o0?oooooo
ooooool02_ooool00oo<o`3oooooooooo`0Nooooo`04o`3o0?ooooooooooogoo01Sooooo00?oo`00
ooooooooool0<?ooool003Gooooo00?o0?ooooooooooool02_ooool00oo<o`3oooooooooo`0Ooooo
o`03o`3o0?ooooooOol001Oooooo00?oo`00ooooooooool0<Oooool003Gooooo00?o0?oooooooooo
ool02_ooool00oo<o`3oooooooooo`0Oooooo`03o`3o0?moo`3ooooo01Oooooo00?oo`00oooooooo
ool0<Oooool003Gooooo00?o0?ooooooooooool02_ooool00oo<o`3oooooooooo`0Oooooo`03ogoo
0?l0o`3ooooo01Oooooo00?oo`00ooooooooool0<Oooool003Gooooo00?o0?ooooooooooool02_oo
ool00oo<o`3oooooooooo`0Oooooo`03ogoo0?l0o`3ooooo01Kooooo00?oo`00ooooooooool0<_oo
ool003Gooooo00?o0?ooooooooooool02oooool00oo<o`3oooooooooo`0Mooooo`04ogoo0?oooooo
ooooo`3o01Kooooo00?oo`00ooooooooool0<_ooool003Gooooo00?o0?ooooooooooool02oooool0
0oo<o`3oooooooooo`0Looooo`03ogoo0?oooooooooo00;ooooo00?o0?l0ooooooooool04oooool0
0ooo003oooooooooo`0booooo`00=Oooool00ol0ooooooooooooo`0;ooooo`03olco0?oooooooooo
01cooooo00?oOol0ooooooooool00_ooool00ol0o`3oooooooooo`0Cooooo`03ool00?oooooooooo
03;ooooo000eooooo`03o`3ooooooooooooo00_ooooo00?oc?l0ooooooooool06oooool00omoo`3o
ooooooooo`04ooooo`03o`3o0?oooooooooo017ooooo00?oo`00ooooooooool0<oooool003Gooooo
00?o0?ooooooooooool03?ooool00oo<o`3oooooooooo`0Iooooo`03ogoo0?oooooooooo00Gooooo
00?o0?l0ooooooooool04Oooool00ooo003oooooooooo`0cooooo`00=Oooool00ol0oooooooooooo
o`0<ooooo`03olco0?oooooooooo01Wooooo00?oOol0ooooooooool01_ooool00ol0o`3ooooooooo
o`0@ooooo`03ool00?oooooooooo03?ooooo000eooooo`03o`3ooooooooooooo00gooooo00?oc?l0
ooooooooool05oooool00omoo`3oooooooooo`07ooooo`03o`3o0?oooooooooo00oooooo00?oo`00
ooooooooool0=?ooool003Gooooo00?o0?ooooooooooool03Oooool00oo<o`3oooooooooo`0Foooo
o`03ogoo0?oooooooooo00Wooooo00?o0?l0ooooooooool03_ooool00ooo003oooooooooo`0doooo
o`00=Oooool00ol0ooooooooooooo`0=ooooo`03olco0?oooooooooo01Gooooo00?oOol0oooooooo
ool02oooool00ol0o`3oooooooooo`0=ooooo`03ool00?oooooooooo03Cooooo000eooooo`03o`3o
oooooooooooo00kooooo00?oc?l0ooooooooool04oooool00omoo`3oooooooooo`0<ooooo`03o`3o
0?oooooooooo00cooooo00?oo`00ooooooooool0=Oooool003Gooooo00?o0?ooooooooooool03_oo
ool00oo<o`3oooooooooo`0Cooooo`03ogoo0?oooooooooo00gooooo00?o0?l0ooooooooool02ooo
ool00ooo003oooooooooo`0eooooo`00=Oooool00ol0ooooooooooooo`0>ooooo`03olco0?oooooo
oooo01;ooooo00?oOol0ooooooooool03_ooool00ol0o`3oooooooooo`0;ooooo`03ool00?oooooo
oooo03Gooooo000eooooo`03o`3ooooooooooooo00oooooo00?oc?l0ooooooooool04?ooool00omo
o`3oooooooooo`0@ooooo`03o`3o0?oooooooooo00Wooooo00?oo`00ooooooooool0=_ooool003Ko
oooo00?o0?ooooooooooool03oooool00oo<o`3oooooooooo`0>ooooo`03ogoo0?oooooooooo017o
oooo00?o0?l0ooooooooool02Oooool00ooo003oooooooooo`0fooooo`00=_ooool00ol0oooooooo
ooooo`0?ooooo`03olco0?oooooooooo00gooooo00?oOol0ooooooooool04_ooool00ol0o`3ooooo
ooooo`09ooooo`03ool00?oooooooooo03Kooooo000fooooo`03o`3ooooooooooooo013ooooo00?o
c?l0ooooooooool03?ooool00omoo`3oooooooooo`0Cooooo`03o`3o0?oooooooooo00Oooooo00?o
o`00ooooooooool0=oooool003Kooooo00?o0?ooooooooooool04Oooool00oo<o`3oooooooooo`0:
ooooo`03ogoo0?oooooooooo01Cooooo00?o0?l0ooooooooool01oooool00ooo003oooooooooo`0g
ooooo`00=_ooool00ol0ooooooooooooo`0Aooooo`03olco0?oooooooooo00Wooooo00?oOol0oooo
ooooool05Oooool00ol0o`3oooooooooo`07ooooo`03ool00?oooooooooo03Oooooo000fooooo`03
o`3ooooooooooooo01;ooooo00?oc?l0ooooooooool02?ooool00omoo`3oooooooooo`0Fooooo`03
o`3o0?oooooooooo00Gooooo00?oo`00ooooooooool0>?ooool003Kooooo00?o0?ooooooooooool0
4oooool00oo<o`3oooooooooo`06ooooo`03ogoo0?oooooooooo01Oooooo00?o0?l0ooooooooool0
1Oooool00ooo003oooooooooo`0hooooo`00=_ooool00ol0ooooooooooooo`0Cooooo`03olco0?oo
oooooooo00Gooooo00?oOol0ooooooooool06?ooool00ol0o`3oooooooooo`05ooooo`03ool00?oo
oooooooo03Sooooo000fooooo`03o`3ooooooooooooo01Cooooo00?oc?l0ooooooooool01?ooool0
0omoo`3oooooooooo`0Iooooo`03o`3o0?oooooooooo00?ooooo00?oo`00ooooooooool0>Oooool0
03Kooooo00?o0?ooooooooooool05Oooool00oo<o`3oooooooooo`02ooooo`03ogoo0?oooooooooo
01[ooooo00?o0?l0ooooooooool00oooool00ooo003oooooooooo`0iooooo`00=_ooool00ol0oooo
ooooooooo`0Eooooo`05olco0?oooooooooooooooomoo`007Oooool00ol0o`3oooooooooo`03oooo
o`03ool00?oooooooooo03Wooooo000gooooo`03o`3ooooooooooooo01Gooooo00Coc?l0oooooooo
ooooOol07Oooool00ol0o`3oooooooooo`03ooooo`03ool00?oooooooooo03Wooooo000gooooo`03
o`3ooooooooooooo01Gooooo00?oc?l0oooooomoo`007oooool01Ol0o`3oooooooooooooooooo`00
03cooooo000gooooo`03o`3ooooooooooooo01Kooooo00?oc?l0ooooooooool07_ooool01Ol0o`3o
ooooooooooooooooo`0003cooooo000gooooo`03o`3ooooooooooooo01Kooooo00?oOol0olco0?oo
ool07_ooool01Ol0o`3oooooooooooooooooo`0003cooooo000gooooo`03o`3ooooooooooooo01Go
oooo00?oOol0ooooooo<o`007oooool01?l0o`3ooooooooooooo000mooooo`00=oooool00ol0oooo
ooooooooo`0Eooooo`04ogoo0?ooooooooooolco01kooooo00Co0?l0ooooooooooooo`00?Oooool0
03Sooooo00?o0?ooooooooooool04oooool00omoo`3oooooooooo`02ooooo`03olco0?oooooooooo
01_ooooo00Co0?l0ooooooooooooo`00?Oooool003Sooooo00?o0?ooooooooooool04oooool00omo
o`3oooooooooo`03ooooo`03olco0?oooooooooo01_ooooo00?o0?l0ool00?ooool0?Oooool003So
oooo00?o0?ooooooooooool04_ooool00omoo`3oooooooooo`05ooooo`03olco0?oooooooooo01[o
oooo00?o0?l0ool00?ooool0?Oooool003Sooooo00?o0?ooooooooooool04Oooool00omoo`3ooooo
ooooo`07ooooo`03olco0?oooooooooo01Wooooo00?o0?l0ool00?ooool0?Oooool003Sooooo00?o
0?ooooooooooool04Oooool00omoo`3oooooooooo`07ooooo`03olco0?oooooooooo01Wooooo00?o
0?l0ooooooooool0?Oooool003Wooooo00?o0?ooooooooooool03oooool00omoo`3oooooooooo`09
ooooo`03olco0?oooooooooo01Sooooo00?oo`00o`3o0?ooool0?Oooool003Wooooo00?o0?oooooo
ooooool03oooool00omoo`3oooooooooo`0:ooooo`03olco0?oooooooooo01Oooooo00?oo`00o`3o
0?ooool0?Oooool003Wooooo00?o0?ooooooooooool03_ooool00omoo`3oooooooooo`0<ooooo`03
olco0?oooooooooo01Gooooo00?oo`00ooooool0o`00?_ooool003Wooooo00?o0?ooooooooooool0
3_ooool00omoo`3oooooooooo`0=ooooo`03olco0?oooooooooo01Cooooo00?oo`00ooooool0o`00
?_ooool003Wooooo00?o0?ooooooooooool03Oooool00omoo`3oooooooooo`0>ooooo`03olco0?oo
oooooooo01Cooooo00?oo`00ooooool0o`00?_ooool003[ooooo00?o0?ooooooooooool03?ooool0
0omoo`3oooooooooo`0?ooooo`03olco0?oooooooooo01;ooooo00Coo`00oooooooooooo0?l0?_oo
ool003[ooooo00?o0?ooooooooooool03?ooool00omoo`3oooooooooo`0@ooooo`03olco0?oooooo
oooo017ooooo00Coo`00oooooooooooo0?l0?_ooool003[ooooo00?o0?ooooooooooool02oooool0
0omoo`3oooooooooo`0Aooooo`03olco0?oooooooooo017ooooo00Coo`00oooooooooooo0?l0?_oo
ool003_ooooo00?o0?ooooooooooool02_ooool00omoo`3oooooooooo`0Booooo`03olco0?oooooo
oooo013ooooo00Coo`00oooooooooooo0?l0?_ooool003_ooooo00?o0?ooooooooooool02_ooool0
0omoo`3oooooooooo`0Cooooo`03olco0?oooooooooo00kooooo00Goo`00ooooooooooooooooo`3o
000nooooo`00>oooool00ol0ooooooooooooo`09ooooo`03ogoo0?oooooooooo01Cooooo00?oc?l0
ooooooooool03_ooool01Ooo003ooooooooooooooooo0?l003kooooo000kooooo`03o`3ooooooooo
oooo00Wooooo00?oOol0ooooooooool05Oooool00oo<o`3oooooooooo`0=ooooo`05ool00?oooooo
ooooooooool0o`00?_ooool003cooooo00?o0?ooooooooooool02?ooool00omoo`3oooooooooo`0E
ooooo`03olco0?oooooooooo00gooooo00Goo`00ooooooooooooooooo`3o000nooooo`00??ooool0
0ol0ooooooooooooo`07ooooo`03ogoo0?oooooooooo01Oooooo00?oc?l0ooooooooool02oooool0
0ooo003oooooooooo`02ooooo`03o`3o0?oooooooooo03cooooo000looooo`03o`3ooooooooooooo
00Oooooo00?oOol0ooooooooool06?ooool00oo<o`3oooooooooo`0:ooooo`03ool00?oooooooooo
00;ooooo00?o0?l0ooooooooool0??ooool003cooooo00?o0?ooooooooooool01_ooool00omoo`3o
ooooooooo`0Iooooo`03olco0?oooooooooo00[ooooo00?oo`00ooooooooool00_ooool00ol0o`3o
ooooooooo`0looooo`00?Oooool00ol0ooooooooooooo`05ooooo`03ogoo0?oooooooooo01[ooooo
00?oc?l0ooooooooool02Oooool00ooo003oooooooooo`02ooooo`03o`3o0?oooooooooo03cooooo
000mooooo`03o`3ooooooooooooo00Gooooo00?oOol0ooooooooool06_ooool00oo<o`3ooooooooo
o`08ooooo`03ool00?oooooooooo00?ooooo00?o0?l0ooooooooool0??ooool003gooooo00?o0?oo
ooooooooool01?ooool00omoo`3oooooooooo`0Looooo`03olco0?oooooooooo00Oooooo00?oo`00
ooooooooool00oooool00ol0o`3oooooooooo`0looooo`00?_ooool00ol0ooooooooooooo`03oooo
o`03ogoo0?oooooooooo01cooooo00?oc?l0ooooooooool01oooool00ooo003oooooooooo`03oooo
o`03o`3o0?oooooooooo03cooooo000nooooo`03o`3ooooooooooooo00;ooooo00?oOol0oooooooo
ool07_ooool00oo<o`3oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?o0?l0oooooooo
ool0??ooool003kooooo00?o0?ooooooooooool00_ooool00omoo`3oooooooooo`0Nooooo`03olco
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ol0o`3oooooooooo`0looooo`00?_oo
ool00ol0ooooooooooooo`02ooooo`03ogoo0?oooooooooo01oooooo00?oc?l0ooooooooool01?oo
ool00ooo003oooooooooo`03ooooo`03o`3o0?oooooooooo03gooooo000oooooo`05o`3ooooooooo
oooooooooomoo`008_ooool00oo<o`3oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?o
0?l0ooooooooool0?Oooool003oooooo00Go0?ooooooooooooooooooogoo000Rooooo`03olco0?oo
oooooooo00;ooooo00?oo`00ooooooooool01?ooool00ol0o`3oooooooooo`0mooooo`00?oooool0
1Ol0ooooooooooooooooooooOol002?ooooo00Goc?l0ooooooooooooooooool00006ooooo`03o`3o
0?oooooooooo03gooooo0010ooooo`04o`3oooooooooooooogoo02?ooooo00Goc?l0oooooooooooo
ooooool00006ooooo`03o`3o0?oooooooooo03gooooo0010ooooo`04o`3oooooooooooooogoo02Co
oooo00?oc?l0oooooooo00001oooool00ol0o`3oooooooooo`0mooooo`00@?ooool00ol0oooooooo
ogoo000Uooooo`03olco0?ooooooo`0000Oooooo00?o0?l0ooooooooool0?Oooool0047ooooo00?o
0?ooogoo0?ooool09?ooool00oo<o`3oooooool00006ooooo`03o`3o0?oooooooooo03kooooo0011
ooooo`03o`3ooomoo`3ooooo02Gooooo00?oc?l0ool00?ooool01Oooool00ol0o`3oooooooooo`0n
ooooo`00@Oooool00ol0ooooOol0ooooo`0Uooooo`03olco0?oooooooooo00Gooooo00?o0?l0oooo
ooooool0?_ooool004;ooooo00?oOol0ooooooooool09?ooool00oo<o`3oooooooooo`05ooooo`03
o`3o0?oooooooooo03kooooo0012ooooo`03ogoo0?oooooooooo02Cooooo00?oc?l0ooooooooool0
1Oooool00ol0o`3oooooooooo`0nooooo`00@_ooool00omoo`3oooooooooo`0Tooooo`03ool00?o<
o`3ooooo00Cooooo00?o0?l0ooooooooool0?oooool004;ooooo00?oOol0o`3oooooool08oooool0
0ooo003oooooolco0005ooooo`03o`3o0?oooooooooo03oooooo0012ooooo`03ogoo0?l0oooooooo
02?ooooo00?oo`00ooooooo<o`001Oooool00ol0o`3oooooooooo`0oooooo`00@_ooool00omoo`3o
0?ooooooo`0Sooooo`03ool00?ooooooc?l000Gooooo00?o0?l0ooooooooool0?oooool004;ooooo
00?oOol0o`3oooooool08oooool01?oo003oooooooooooo<o`03ooooo`03o`3o0?oooooooooo043o
oooo0012ooooo`03ogoo0?oooooo0?oo02;ooooo00Goo`00ooooooooooooooooolco0003ooooo`03
o`3o0?oooooooooo043ooooo0012ooooo`03ogoo0?oooooo0?oo02;ooooo00Goo`00oooooooooooo
ooooolco0003ooooo`03o`3o0?oooooooooo043ooooo0012ooooo`03ogoo0?oooooo0?oo02;ooooo
00Goo`00ooooooooooooooooolco0002ooooo`03o`3o0?oooooooooo047ooooo0013ooooo`03ogoo
0?oooooo0?oo023ooooo00?oo`00ooooooooool00_ooool01?o<o`3oooooooooool0o`13ooooo`00
@oooool00omoo`3oooooo`3oo`0Pooooo`03ool00?oooooooooo00?ooooo00?oc?l0ooooool0o`00
@oooool004?ooooo00?oOol0ooooool0ool08?ooool00ooo003oooooooooo`03ooooo`03olco0?oo
oooo0?l004?ooooo0013ooooo`03ogoo0?oooooo0?oo023ooooo00?oo`00ooooooooool00oooool0
0oo<o`3oooooo`3o0013ooooo`00@oooool01?moo`3oooooooooool0oolNooooo`03ool00?oooooo
oooo00Cooooo00?oc?l0o`3o0?ooool0@oooool004?ooooo00CoOol0oooooooooooo0?oo7_ooool0
0ooo003oooooooooo`04ooooo`03olco0?l0o`3ooooo04?ooooo0013ooooo`04ogoo0?oooooooooo
o`3ooakooooo00?oo`00ooooooooool01?ooool00oo<o`3o0?l0ooooo`13ooooo`00@oooool01Omo
o`3ooooooooooooooooo0?oo01gooooo00?oo`00ooooooooool01?ooool00oo<o`3o0?l0ooooo`13
ooooo`00A?ooool01?moo`3oooooooooool0oolLooooo`03ool00?oooooooooo00Gooooo00?oc?l0
ooooooooool0@oooool004Cooooo00CoOol0oooooooooooo0?oo7?ooool00ooo003oooooooooo`05
ooooo`03olco0?oooooooooo04?ooooo0014ooooo`05ogoo0?ooooooooooooooool0ool06oooool0
0ooo003oooooooooo`05ooooo`03olco0?oooooooooo04?ooooo0014ooooo`05ogoo0?oooooooooo
ooooool0ool06_ooool00ooo003oooooooooo`05ooooo`03o`3o0?o<o`3ooooo04Cooooo0015oooo
o`04ogoo0?ooooooooooo`3ooa[ooooo00?oo`00ooooooooool01Oooool00oo<o`3oooooooooo`14
ooooo`00AOooool01Omoo`3ooooooooooooooooo0?oo01Wooooo00?oo`00ooooooooool01Oooool0
0oo<o`3oooooooooo`14ooooo`00AOooool01Omoo`3ooooooooooooooooo0?oo01Wooooo00?oo`00
ooooooooool01?ooool00ol0o`3oc?l0ooooo`15ooooo`00A_ooool01?moo`3oooooooooool0oolH
ooooo`03ool00?oooooooooo00Gooooo00?o0?l0olco0?ooool0AOooool004Kooooo00GoOol0oooo
ooooooooooooo`3oo`0Gooooo`03ool00?oooooooooo00Gooooo00?o0?l0olco0?ooool0AOooool0
04Kooooo00GoOol0ooooooooooooooooo`3oo`0Gooooo`03ool00?oooooooooo00Cooooo00?o0?l0
ooooooo<o`00A_ooool004Oooooo00CoOol0oooooooooooo0?oo5oooool00ooo003oooooooooo`04
ooooo`03o`3o0?ooooooc?l004Kooooo0017ooooo`05ogoo0?ooooooooooooooool0ool05_ooool0
0ooo003oooooooooo`03ooooo`04o`3o0?ooooooooooolco04Kooooo0017ooooo`05ogoo0?oooooo
ooooooooool0ool05Oooool00ooo003oooooooooo`04ooooo`03o`3o0?ooooooc?l004Oooooo0018
ooooo`04ogoo0?ooooooooooo`3ooaGooooo00?oo`00ooooooooool01?ooool00ol0o`3oooooolco
0017ooooo`00B?ooool01Omoo`3ooooooooooooooooo0?oo01Cooooo00?oo`00ooooooooool00ooo
ool01?l0o`3oooooooooooo<o`17ooooo`00B?ooool01Omoo`3ooooooooooooooooo0?oo01Cooooo
00?oo`00ooooooooool00oooool01?l0o`3oooooooooooo<o`17ooooo`00B?ooool01Omoo`3ooooo
oooooooooooo0?oo01Cooooo00?oo`00ooooooooool00oooool00ol0o`3oooooolco0018ooooo`00
BOooool01?moo`3oooooooooool0oolCooooo`03ool00?oooooooooo00?ooooo00Co0?l0oooooooo
ooooc?l0B?ooool004Wooooo00GoOol0ooooooooooooooooo`3oo`0Booooo`03ool00?oooooooooo
00?ooooo00Co0?l0ooooooooooooc?l0B?ooool004Wooooo00GoOol0ooooooooooooooooo`3oo`0B
ooooo`03ool00?oooooooooo00?ooooo00?o0?l0ooooooo<o`00BOooool004[ooooo00CoOol0oooo
oooooooo0?oo4_ooool00ooo003oooooooooo`02ooooo`04o`3o0?ooooooooooolco04Wooooo001:
ooooo`05ogoo0?ooooooooooooooool0ool04Oooool00ooo003oooooooooo`02ooooo`04o`3o0?oo
ooooooooolco04Wooooo001;ooooo`04ogoo0?ooooooooooo`3ooa3ooooo00?oo`00ooooooooool0
0_ooool01?l0o`3oooooooooooo<o`1:ooooo`00Boooool01?moo`3oooooooooool0ool@ooooo`03
ool00?oooooooooo00;ooooo00Co0?l0ooooooooooooc?l0B_ooool004cooooo00CoOol0oooooooo
oooo0?oo3oooool00ooo003oooooooooo`02ooooo`03o`3o0?ooooooc?l004_ooooo001<ooooo`04
ogoo0?ooooooooooo`3oo`kooooo00?oo`00ooooooooool00_ooool01?l0o`3oooooooooooo<o`1;
ooooo`00C?ooool01?moo`3oooooooooool0ool>ooooo`03ool00?oooooooooo00;ooooo00?o0?l0
ooooooo<o`00C?ooool004gooooo00CoOol0oooooooooooo0?oo3Oooool00ooo003oooooooooo`02
ooooo`03o`3o0?ooooooc?l004cooooo001=ooooo`04ogoo0?ooooooooooo`3oo`gooooo00Goo`00
ooooooooooooooooo`3o0002ooooo`03olco0?oooooooooo04[ooooo001>ooooo`03ogoo0?oooooo
0?oo00cooooo00?oo`00ooooooooool00_ooool00ol0o`3oooooolco001=ooooo`00C_ooool01?mo
o`3oooooooooool0ool;ooooo`03ool00?oooooooooo00;ooooo00?o0?l0ooooooo<o`00COooool0
04oooooo00?oOol0ooooool0ool02oooool01ooo003ooooooooooooooooo0?l0ooooooo<o`00C_oo
ool004oooooo00CoOol0oooooooooooo0?oo2_ooool01ooo003ooooooooooooooooo0?l0ooooooo<
o`00C_ooool0053ooooo00?oOol0ooooool0ool02_ooool01_oo003oooooooooool0o`3oooooolco
04oooooo001@ooooo`03ogoo0?oooooo0?oo00Wooooo00Ooo`00ooooooooooooooooo`3o0?oooooo
c?l004oooooo001Aooooo`03ogoo0?oooooo0?oo00Sooooo00Koo`00oooooooooooo0?l0ooooooo<
o`1@ooooo`00DOooool00omoo`3oooooo`3oo`08ooooo`06ool00?ooooooooooo`3o0?ooooooc?l0
D?ooool0057ooooo00?oOol0ooooool0ool02?ooool01Ooo003oooooo`3o0?ooooooc?l0057ooooo
001Booooo`03ogoo0?oooooo0?oo00Oooooo00Goo`00ooooool0o`3oooooolco001Aooooo`00D_oo
ool00omoo`3oooooo`3oo`07ooooo`05ool00?oooooo0?l0ooooooo<o`00DOooool005?ooooo00?o
Ool0o`3oooooool01Oooool01Ooo003oooooo`3o0?ooooooc?l005;ooooo001Cooooo`03ogoo0?oo
oooo0?oo00Gooooo00Goo`00ooooool0o`3oooooolco001Booooo`00E?ooool00omoo`3o0?oooooo
o`04ooooo`04ool00?l0o`3oooooolco05?ooooo001Dooooo`03ogoo0?l0oooooooo00Cooooo00Co
o`00o`3o0?ooooooc?l0Doooool005Gooooo00?oOol0ooooooooool00oooool00ol0o`3oooooolco
001Dooooo`00EOooool00omoo`3o0?ooooooo`02ooooo`03ool00?l0o`3oc?l005Gooooo001Foooo
o`07ogoo0?oooooooooooooooooo003o0?l0olco001Eooooo`00E_ooool01_moo`3ooooooooooooo
oooo0?l0olco05Kooooo001Fooooo`06ogoo0?l0ooooooooool00?l0o`3oc?l0E_ooool005Oooooo
00CoOol0ooooool0o`3oc?l0Eoooool005Oooooo00?oOol0ooooooo<o`00F?ooool005Sooooo00?o
Ool0olco0?ooool0Eoooool005Sooooo00?oc?l0ooooooooool0Eoooool00001\
\>"],
  ImageRangeCache->{{{0, 177.75}, {267.188, 0}} -> {-1.00001, -0.00317959, \
0.0140648, 0.0140648}}]
}, Open  ]],

Cell[TextData[{
  "\tThe lowest frequency eigenmode is a sort of pendulum oscillation of the \
string from side to side, which can be easily set up in a real piece of \
string. The higher-order modes take more work to view in a real string; one \
must oscillate the top of the string at just the right frequency to set up  \
one of these modes.  However, in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " it is easy to see the modes oscillate, using an animation. In Cell ",
  ButtonBox["4.17",
    ButtonData:>"Cell 4.17",
    ButtonStyle->"Hyperlink"],
  " we show  the",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 2\)\)\)]],
  " mode. To make the animation realistic-looking, we must try to account for \
the change in height of the bottom of the string during an oscillation. This \
change in height occurs because the length of the string is fixed. When a \
mode is present, the length is determined by an integral over  length \
elements ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]s\)]],
  " where"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{Cell[TextData[{
            "\[DifferentialD]s=",
            Cell[BoxData[
                \(TraditionalForm\`\@\(\[DifferentialD]y\^\(\(\ \)\(2\)\) + \
\[DifferentialD]\(\(z\)\(\ \)\)\^2\) = \[DifferentialD]z \@\( 1 + \((\
\[PartialD]y\/\[PartialD]z)\)\^2\)\)]]
          }]], " ", "~", 
          " ", \(\[DifferentialD]z\ [
              1\  + \ \(1\/2\) \((\[PartialD]y\/\[PartialD]z)\)\^2]\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "Thus, the fixed length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the string determines the height ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_o\)(t)\)]],
  " of the bottom of the string, according to \t"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`L = \
\(\[Integral]\_\(\(z\_o\)(t)\)\%L\[DifferentialD]s \[TildeEqual] \
\[Integral]\_\(\(z\_o\)(t)\)\%L\([1\  + \ \(1\/2\) \((\(\[PartialD]y\/\
\[PartialD]z\) \((z, t)\))\)\^2]\) \[DifferentialD]z = 
          L - \(z\_o\)(
              t)\  + \ \(1\/2\) \(\[Integral]\_\(\(z\_o\)(t)\)\%L\( 
                      1\/2\) \(\((\(\[PartialD]y\/\[PartialD]z\) \((z, 
                            t)\))\)\^2\) \[DifferentialD]z\)\)\)]],
  " . "
}], "Text"],

Cell[TextData[{
  "For small ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\_o\)\(,\)\)\)]],
  " we can replace the lower bound of the last integral by zero, obtaining"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_o\)(
          t)\  = \ \(1\/2\) \(\[Integral]\_0\%L\( 
                  1\/2\) \(\((\(\[PartialD]y\/\[PartialD]z\) \((z, 
                        t)\))\)\^2\) \[DifferentialD]z\)\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "The change in height of the string end is a nonlinear effect: ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_o\)(t)\)]],
  " depends on the square of the mode amplitude. Strictly speaking this \
effect goes beyond our discussion of the linear wave equation. However, for \
finite amplitude modes it can be important to allow for this effect; \
otherwise the modes simply don't look right."
}], "Text"],

Cell[TextData[{
  "\tThe  ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "commands in Cell ",
  ButtonBox["4.17",
    ButtonData:>"Cell 4.17",
    ButtonStyle->"Hyperlink"],
  " determine the height of the bottom of the string, ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_o\)(t)\)]],
  ", for a given mode ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ",  and with amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". We then  animate the mode, ",
  StyleBox["assuming ",
    FontSlant->"Italic"],
  "that the change in height of the bottom of the string corresponds to a \
mode on a slightly shortened string, of the form ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\  \[TildeEqual] 
        a\ \ cos\ \[Omega]\ t\ \ \(\(J\_o\)(
            j\_\(o\ n\)\ \@\(\([z - \(z\_o\)(t)]\)/\([L - \
\(z\_o\)(t)]\)\))\), \ \ \(z\_o\)(t) < z < L\)]],
  ". Of course, this is just a guess. To do this problem properly, we need to \
look for solutions to a nonlinear wave equation, which takes us beyond the \
bounds of this chapter. Some aspects of nonlinear waves will be considered in \
Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(n = 2;\), " ", 
      StyleBox[\( (*\ mode\ number\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", 
    RowBox[{\(L = 3;\), " ", 
      StyleBox[\( (*\ length\ of\ string\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", 
    RowBox[{
      RowBox[{\(a\  = \ 1/2;\), " ", 
        StyleBox[\( (*\ mode\ amplitude*) \),
          FontColor->RGBColor[1, 0, 0]]}], "\n"}], "\n", 
    RowBox[{\(j0\  = \ BesselJZeros[0, n];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{\(z0[t_]\  = 
          Integrate[\(\(\ \)\(1\)\)\/2\ a\^2\ Cos[t]^2\ D[
                  BesselJ[0, j0[\([n]\)]\ \@\(z/L\)], z]^2, {z, 0, L}];\), 
      "   ", "\n"}], "\n", \(Table[
        ParametricPlot[
          Evaluate[{a\ \ Cos[t] 
                BesselJ[0, 
                  j0[\([n]\)]\ \@\(\((z - z0[t])\)/\((L - z0[t])\)\)], 
              z}], {z, z0[t], L}, AspectRatio \[Rule] L/2, 
          PlotRange \[Rule] {{\(-1\), 1}, {0, L}}, 
          PlotStyle \[Rule] Thickness[0.02], 
          PlotLabel -> "\<n = \>" <> ToString[n]], {t, 0, 
          1.9\ Pi, \  .1\ Pi}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.17"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.75 .14033 m
.67851 .19549 L
.61277 .25564 L
.56143 .31214 L
.52052 .36647 L
.4851 .4243 L
.45802 .47997 L
.43587 .53914 L
.42708 .56878 L
.42021 .59614 L
.40971 .65099 L
.40603 .67772 L
.40431 .6931 L
.40298 .70717 L
.40193 .72041 L
.40099 .73488 L
.40057 .7428 L
.40024 .75016 L
.39995 .75772 L
.39973 .76468 L
.39955 .77193 L
.39948 .77567 L
.39942 .77977 L
.39937 .78334 L
.39934 .78668 L
.39933 .78852 L
.39932 .7902 L
.39932 .79113 L
.39931 .79214 L
.39931 .79398 L
.39931 .79562 L
.39931 .79716 L
.39932 .79885 L
.39932 .80067 L
.39933 .80248 L
.39934 .80438 L
.39937 .80778 L
.39941 .81094 L
.39945 .81388 L
.39957 .82055 L
.39974 .82775 L
.39998 .83557 L
.40051 .84975 L
.4019 .87629 L
.4039 .90467 L
.40655 .93471 L
.4125 .9888 L
.42022 1.04639 L
.42871 1.10182 L
.43856 1.16074 L
Mistroke
.44861 1.21751 L
.45859 1.27211 L
.46934 1.33021 L
.47966 1.38615 L
.49043 1.44559 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003a0001JR000`400?l00000o`00003olOooool0
0?7ooooo000>ooooo`Co000000?o410@ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00_oA4A4o`000?l0003o<S8b
omgMgOooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`0;odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00_ooooo1?l000000ol@413oooooooooo`04ooooo`004?ooool00ol0003oooooooooo`09ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool02Omg
MgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool02?mgMgOo<S8b
oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo01Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00SoMgMgoc8b<_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool03?ooool00ol0
003oooooooooo`06ooooo`001Oooool6o`0000Gooooo00Co0000oooooooooooooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`03ooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00[ooooo1ol000000ooooooo410@ooooo`02ooooo`03oa0@4?oo
oooooooo00[ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Cooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`04o`000?oooooooooooa0@40?o
oooo00?o410@ooooooooool03_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00_o
oooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Ko
oooo000@ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`03o`000?oooooooooo
00gooooo00CoMgMgoc8b<_oooooo00000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?oMgMgoc8b<_ooool05?ooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0
3Oooool01?mgMgOo<S8booooool00003ooooo`03o`000?oooooooooo00cooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`0<ooooo`03o`000?oooooooooo00Kooooo000@ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000003?ooool0
1ol0003o8B4Qo`000?lb<S;oc<c<ooooool000000oooool00ol0003oooooooooo`0<ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Oo0000ob4Q8Ol0003o<S8bolc<c?oooooo000000?o
oooo00?o0000ooooooooool03?ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`03Oooool00ol0003oooooooooo`06ooooo`004?ooool00ol0003oooooooooo`09ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00?ooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`03ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01_ooool0013ooooo00?o0000ooooooooool02Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooo
oooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`0Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooo
oooooc8b<P04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool000kooooo
00?oEEEEofIVI_l000002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00002ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000Fooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`Go00001?ooool4o`0000cooooo00?oEEEEofIVI_l000002?ooool00?7ooooo003aooooo`00
lOooool00?7ooooo000<ooooomgo00002?ooool000cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`00N_ooool00ol0003oooooooooo`1dooooo`00N_ooool00ol0003ooooo
ooooo`1dooooo`00N_ooool00ol0003oooooooooo`1dooooo`00N_ooool00ol0003oooooooooo`1d
ooooo`00N_ooool00ol0003oooooooooo`1dooooo`00N_ooool00ol0003oooooooooo`1dooooo`00
N_ooool00ol0003oooooooooo`1dooooo`00N_ooool00ol0003oooooooooo`1dooooo`00N_ooool0
0ol0003oooooooooo`1dooooo`00N_ooool2o`0007Gooooo001jooooo`03o`000?oooooooooo07Co
oooo001jooooo`03o`000?oooooooooo07Cooooo001jooooo`03o`000?oooooooooo07Cooooo001j
ooooo`03o`000?oooooooooo07Cooooo001jooooo`03o`000?oooooooooo07Cooooo001jooooo`03
o`000?oooooooooo07Cooooo001jooooo`03o`000?oooooooooo07Cooooo001jooooo`03o`000?oo
oooooooo07Cooooo001jooooo`03o`000?oooooooooo07Cooooo001jooooo`03o`000?oooooooooo
07Cooooo001jooooo`;o0000MOooool007[ooooo00?o0000ooooooooool0M?ooool007[ooooo00?o
0000ooooooooool0M?ooool007[ooooo00?o0000ooooooooool0M?ooool007[ooooo00?o0000oooo
ooooool0M?ooool007[ooooo00?o0000ooooooooool0M?ooool007[ooooo00?o0000ooooooooool0
M?ooool007[ooooo00?o0000ooooooooool0M?ooool007[ooooo00?o0000ooooooooool0<Oooool5
o`0003kooooo001jooooo`03o`000?oooooooooo033ooooo1_l0000nooooo`00N_ooool00ol0003o
ooooooooo`0_ooooo`Oo0000?_ooool007[ooooo0_l0000^ooooo`Wo0000?_ooool007[ooooo00?o
0000ooooooooool0;?ooool8o`00043ooooo001jooooo`03o`000?oooooooooo02_ooooo2?l00011
ooooo`00N_ooool00ol0003oooooooooo`0Yooooo`Wo0000@_ooool007[ooooo00?o0000oooooooo
ool0:?ooool8o`0004Cooooo001jooooo`03o`000?oooooooooo02Oooooo2?l00015ooooo`00N_oo
ool00ol0003oooooooooo`0Uooooo`Wo0000A_ooool007[ooooo00?o0000ooooooooool09?ooool8
o`0004Sooooo001jooooo`03o`000?oooooooooo02?ooooo2?l00019ooooo`00N_ooool00ol0003o
ooooooooo`0Qooooo`Wo0000B_ooool007[ooooo00?o0000ooooooooool08?ooool8o`0004cooooo
001jooooo`;o00008?ooool8o`0004gooooo001jooooo`03o`000?oooooooooo01kooooo2?l0001>
ooooo`00N_ooool00ol0003oooooooooo`0Mooooo`Oo0000D?ooool007[ooooo00?o0000oooooooo
ool07?ooool7o`00057ooooo001jooooo`03o`000?oooooooooo01_ooooo1ol0001Booooo`00N_oo
ool00ol0003oooooooooo`0Jooooo`Oo0000Doooool007[ooooo00?o0000ooooooooool06Oooool7
o`0005Cooooo001jooooo`03o`000?oooooooooo01Sooooo1ol0001Eooooo`00H?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`0Gooooo`Oo0000E_ooool0063ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Kooooo1ol0001G
ooooo`00H?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Eooooo`Oo0000F?ooool0063ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Eooooo`Oo0000FOooool0063ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0Dooooo`Ko0000F_ooool0063ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04oooool6o`0005_ooooo001Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo1_l0
001Looooo`00H?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oo
oooooooo017ooooo1ol0001Looooo`00N_ooool00ol0003oooooooooo`0@ooooo`Oo0000GOooool0
07[ooooo00?o0000ooooooooool03oooool7o`0005kooooo001jooooo`03o`000?oooooooooo00ko
oooo1ol0001Oooooo`00N_ooool00ol0003oooooooooo`0=ooooo`Oo0000H?ooool007[ooooo00?o
0000ooooooooool03?ooool7o`00067ooooo001jooooo`03o`000?oooooooooo00_ooooo1ol0001R
ooooo`00N_ooool2o`0000_ooooo1ol0001Sooooo`00N_ooool00ol0003oooooooooo`09ooooo`Oo
0000I?ooool007[ooooo00?o0000ooooooooool02?ooool7o`0006Gooooo001jooooo`03o`000?oo
oooooooo00Sooooo1_l0001Vooooo`00N_ooool00ol0003oooooooooo`07ooooo`Ko0000Ioooool0
07[ooooo00?o0000ooooooooool01_ooool6o`0006Sooooo001jooooo`03o`000?oooooooooo00Go
oooo1ol0001Xooooo`00N_ooool00ol0003oooooooooo`05ooooo`Ko0000JOooool007[ooooo00?o
0000ooooooooool01?ooool6o`0006[ooooo001jooooo`03o`000?oooooooooo00?ooooo1_l0001[
ooooo`00N_ooool00ol0003oooooooooo`02ooooo`Oo0000Joooool007[ooooo0_l00003ooooo`Ko
0000K?ooool007[ooooo00Co0000oooooooooooooooo1_l0001]ooooo`00N_ooool00ol0003ooooo
ooooo`06o`0006kooooo001jooooo`03o`000?oooooo000000Ko0000K_ooool007[ooooo00?o0000
ooooool000001Ol0001_ooooo`00N_ooool7o`00073ooooo001jooooo`Ko0000LOooool007[ooooo
1_l0001aooooo`00NOooool6o`0007;ooooo001hooooo`Ko0000Loooool007Sooooo1_l0001coooo
o`00Moooool6o`0007Cooooo001fooooo`Ko0000MOooool007Kooooo1_l0001eooooo`00MOooool6
o`0007Kooooo001dooooo`Oo0000M_ooool007Cooooo1ol0001fooooo`00Loooool6o`000003oooo
ool0003ooooo07Gooooo001cooooo`Go00000_ooool00ol0003oooooooooo`1dooooo`00L_ooool6
o`0000;ooooo00?o0000ooooooooool0M?ooool007;ooooo1Ol00003ooooo`03o`000?oooooooooo
07Cooooo001aooooo`Ko00000oooool00ol0003oooooooooo`1dooooo`00LOooool5o`0000Cooooo
0_l0001eooooo`00L?ooool6o`0000Cooooo00?o0000ooooooooool0M?ooool0073ooooo1Ol00005
ooooo`03o`000?oooooooooo07Cooooo001_ooooo`Ko00001Oooool00ol0003oooooooooo`1doooo
o`00Koooool5o`0000Kooooo00?o0000ooooooooool0M?ooool006kooooo1_l00006ooooo`03o`00
0?oooooooooo07Cooooo001^ooooo`Go00001oooool00ol0003oooooooooo`1dooooo`00K_ooool5
o`0000Oooooo00?o0000ooooooooool0M?ooool006gooooo2?l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo07Cooooo001]ooooo`Go000000?oooooo`000?ooool01Oooool00ol0003o
ooooooooo`1dooooo`00KOooool5o`000003ooooool0003ooooo00Gooooo00?o0000ooooooooool0
M?ooool006cooooo1Ol00002ooooo`03o`000?oooooooooo00Cooooo0_l0001eooooo`00K?ooool5
o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`00K?ooool5o`00
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`00Joooool5o`0000?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`00Joooool5o`000004oooo
oomEEEGoIVIVo`0000Kooooo00?o0000ooooooooool0M?ooool006_ooooo1Ol0000:ooooo`03o`00
0?oooooooooo07Cooooo001Zooooo`Go00002oooool00ol0003oooooooooo`1dooooo`00J_ooool5
o`0000_ooooo00?o0000ooooooooool0M?ooool006[ooooo1Ol0000;ooooo`03o`000?oooooooooo
07Cooooo001Zooooo`Co00003?ooool00ol0003oooooooooo`1dooooo`00JOooool5o`0000cooooo
00?o0000ooooooooool0M?ooool006Wooooo1Ol0000<ooooo`;o0000MOooool006Wooooo1Ol0000<
ooooo`03o`000?oooooooooo07Cooooo001Xooooo`Go00003Oooool00ol0003oooooooooo`1doooo
o`00J?ooool5o`0000gooooo00?o0000ooooooooool0M?ooool006Sooooo1Ol0000=ooooo`03o`00
0?oooooooooo07Cooooo001Wooooo`Go00003_ooool00ol0003oooooooooo`1dooooo`00Ioooool5
o`0000kooooo00?o0000ooooooooool0M?ooool006Oooooo1Ol0000>ooooo`03o`000?oooooooooo
07Cooooo001Vooooo`Go00003oooool00ol0003oooooooooo`1dooooo`00I_ooool5o`0000oooooo
00?o0000ooooooooool0M?ooool006Kooooo1Ol0000?ooooo`03o`000?oooooooooo07Cooooo001V
ooooo`Co00004?ooool2o`0007Gooooo001Vooooo`Co00004?ooool00ol0003oooooooooo`1doooo
o`00IOooool5o`00013ooooo00?o0000ooooooooool0M?ooool006Gooooo1Ol0000@ooooo`03o`00
0?oooooooooo07Cooooo001Uooooo`Go00004?ooool00ol0003oooooooooo`1dooooo`00IOooool4
o`00017ooooo00?o0000ooooooooool0M?ooool006Gooooo1?l0000Aooooo`03o`000?oooooooooo
07Cooooo001Uooooo`Co00004Oooool00ol0003oooooooooo`1dooooo`00I?ooool5o`00017ooooo
00?o0000ooooooooool0M?ooool006Cooooo1Ol0000Aooooo`03o`000?oooooooooo07Cooooo001T
ooooo`Go00004Oooool00ol0003oooooooooo`1dooooo`00I?ooool4o`0001;ooooo0_l0001eoooo
o`00I?ooool4o`0001;ooooo00?o0000ooooooooool0M?ooool006Cooooo1?l0000Booooo`03o`00
0?oooooooooo07Cooooo001Sooooo`Go00004_ooool00ol0003oooooooooo`1dooooo`00Hoooool5
o`0001;ooooo00?o0000ooooooooool0M?ooool006?ooooo1Ol0000Booooo`03o`000?oooooooooo
07Cooooo001Sooooo`Co00004oooool00ol0003oooooooooo`1dooooo`00Hoooool4o`0001?ooooo
00?o0000ooooooooool0M?ooool006?ooooo1?l0000Cooooo`03o`000?oooooooooo07Cooooo001S
ooooo`Co00004oooool00ol0003oooooooooo`1dooooo`00H_ooool5o`0001?ooooo00?o0000oooo
ooooool0M?ooool006;ooooo1Ol0000Cooooo`;o0000MOooool006;ooooo1Ol0000Cooooo`03o`00
0?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_ooool4
o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03o`000?oooooooooo
07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_ooool4o`0001Cooooo
00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03o`000?oooooooooo07Cooooo001Q
ooooo`Go00001?ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oo
oooooooo07Cooooo001Rooooo`Co00001?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`1dooooo`00H_ooool4o`0000oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1dooooo`00H_ooool4o`0000kooooo00?oMgMgoc8b<_ooool00oooool2o`0007Go
oooo001Rooooo`Co00002oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0M?ooool006;ooooo1?l0000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
M?ooool006;ooooo1?l0000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0M?oo
ool0067ooooo00?oEEEEo`000?l000000_l0000;ooooo`Co00001Oooool00ol0003oooooooooo`1d
ooooo`00H_ooool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03
o`000?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_oo
ool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03o`000?oooooo
oooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_ooool4o`0001Co
oooo0_l0001eooooo`00H_ooool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0
000Dooooo`03o`000?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1d
ooooo`00H_ooool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03
o`000?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_oo
ool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03o`000?oooooo
oooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_ooool4o`0001Co
oooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`;o0000MOooool006;ooooo1?l0
000Dooooo`03o`000?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1d
ooooo`00H_ooool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03
o`000?oooooooooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_oo
ool4o`0001Cooooo00?o0000ooooooooool0M?ooool006;ooooo1?l0000Dooooo`03o`000?oooooo
oooo07Cooooo001Rooooo`Co00005?ooool00ol0003oooooooooo`1dooooo`00H_ooool5o`0001?o
oooo00?o0000ooooooooool0M?ooool006;ooooo1Ol0000Cooooo`03o`000?oooooooooo07Cooooo
001Rooooo`Go00004oooool2o`0007Gooooo001Sooooo`Co00004oooool00ol0003oooooooooo`1d
ooooo`00Hoooool4o`0001?ooooo00?o0000ooooooooool0M?ooool006?ooooo1?l0000Cooooo`03
o`000?oooooooooo07Cooooo001Sooooo`Co00004oooool00ol0003oooooooooo`1dooooo`00Hooo
ool4o`0001?ooooo00?o0000ooooooooool0M?ooool006?ooooo1?l0000Cooooo`03o`000?oooooo
oooo07Cooooo001Sooooo`Co00004oooool00ol0003oooooooooo`1dooooo`00Hoooool4o`0001?o
oooo00?o0000ooooooooool0M?ooool006?ooooo1?l0000Cooooo`03o`000?oooooooooo07Cooooo
001Sooooo`Co00004oooool00ol0003oooooooooo`1dooooo`00Hoooool4o`0001?ooooo0_l0001e
ooooo`00Hoooool4o`0001?ooooo00?o0000ooooooooool0M?ooool006?ooooo1Ol0000Booooo`03
o`000?oooooooooo07Cooooo001Sooooo`Go00004_ooool00ol0003oooooooooo`1dooooo`00Hooo
ool5o`0001;ooooo00?o0000ooooooooool0M?ooool006Cooooo1?l0000Booooo`03o`000?oooooo
oooo07Cooooo001Tooooo`Co00004_ooool00ol0003oooooooooo`1dooooo`00I?ooool4o`0001;o
oooo00?o0000ooooooooool0M?ooool006Cooooo1?l00008ooooo`Go00001Oooool00ol0003ooooo
ooooo`1dooooo`00I?ooool4o`0000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`00
0?oooooooooo07Cooooo001Tooooo`Co00002Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo07Cooooo001Tooooo`Go00002Oooool00onHV9So8B4Qonk^kP05ooooo`;o0000MOooool0
06Cooooo1Ol0000:ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0M?ooool006Co
oooo1Ol0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0M?ooool006Gooooo
1?l00007ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`1dooooo`00
IOooool4o`0000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo07Co
oooo001Uooooo`Co00004Oooool00ol0003oooooooooo`1dooooo`00IOooool4o`00017ooooo00?o
0000ooooooooool0M?ooool006Gooooo1Ol0000@ooooo`03o`000?oooooooooo07Cooooo001Uoooo
o`Go00004?ooool00ol0003oooooooooo`1dooooo`00IOooool5o`00013ooooo00?o0000oooooooo
ool0M?ooool006Kooooo1?l0000@ooooo`03o`000?oooooooooo07Cooooo001Vooooo`Co00004?oo
ool2o`0007Gooooo001Vooooo`Co00004?ooool00ol0003oooooooooo`1dooooo`00I_ooool5o`00
00oooooo00?o0000ooooooooool0M?ooool006Kooooo1Ol0000?ooooo`03o`000?oooooooooo07Co
oooo001Vooooo`Go00003oooool00ol0003oooooooooo`1dooooo`00Ioooool4o`0000oooooo00?o
0000ooooooooool0M?ooool006Oooooo1?l0000?ooooo`03o`000?oooooooooo07Cooooo001Woooo
o`Co00003oooool00ol0003oooooooooo`1dooooo`00Ioooool5o`0000kooooo00?o0000oooooooo
ool0M?ooool006Oooooo1Ol0000>ooooo`03o`000?oooooooooo07Cooooo001Wooooo`Go00003_oo
ool00ol0003oooooooooo`1dooooo`00J?ooool4o`0000kooooo0_l0001eooooo`00J?ooool4o`00
00kooooo00?o0000ooooooooool0M?ooool006Sooooo1?l0000>ooooo`03o`000?oooooooooo07Co
oooo001Xooooo`Go00003Oooool00ol0003oooooooooo`1dooooo`00J?ooool5o`0000gooooo00?o
0000ooooooooool0M?ooool006Sooooo1Ol0000=ooooo`03o`000?oooooooooo07Cooooo001Yoooo
o`Co00003Oooool00ol0003oooooooooo`1dooooo`00JOooool4o`0000gooooo00?o0000oooooooo
ool0M?ooool006Wooooo1?l0000=ooooo`03o`000?oooooooooo07Cooooo001Yooooo`Co00003Ooo
ool00ol0003oooooooooo`1dooooo`00JOooool5o`0000cooooo00?o0000ooooooooool0M?ooool0
06Wooooo1Ol0000<ooooo`;o0000MOooool006Wooooo1Ol0000<ooooo`03o`000?oooooooooo07Co
oooo001Zooooo`Co00003?ooool00ol0003oooooooooo`1dooooo`00J_ooool4o`0000cooooo00?o
0000ooooooooool0M?ooool006[ooooo1?l0000<ooooo`03o`000?oooooooooo07Cooooo001Zoooo
o`Go00002oooool00ol0003oooooooooo`1dooooo`00J_ooool5o`0000_ooooo00?o0000oooooooo
ool0M?ooool006[ooooo1Ol0000;ooooo`03o`000?oooooooooo07Cooooo001[ooooo`Co00002ooo
ool00ol0003oooooooooo`1dooooo`00Joooool4o`0000_ooooo00?o0000ooooooooool0M?ooool0
06_ooooo1?l0000;ooooo`03o`000?oooooooooo07Cooooo001[ooooo`Co00002oooool2o`0007Go
oooo001[ooooo`Go00002_ooool00ol0003oooooooooo`1dooooo`00Joooool5o`0000[ooooo00?o
0000ooooooooool0M?ooool006_ooooo1Ol0000:ooooo`03o`000?oooooooooo07Cooooo001/oooo
o`Co00002_ooool00ol0003oooooooooo`1dooooo`00K?ooool4o`0000[ooooo00?o0000oooooooo
ool0M?ooool006cooooo1Ol00009ooooo`03o`000?oooooooooo07Cooooo001/ooooo`Go00002Ooo
ool00ol0003oooooooooo`1dooooo`00H?ooool5o`0000Gooooo0_lQ8B45o`000005odA4A?l0003o
0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`1dooooo`00H?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo0_lQ8B400ooooooo0000o`000002o`0000?ooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`1dooooo`00HOooool00onHV9So8B4Qonk^kP09ooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Cooooo001Rooooo`03oiRHV?lQ8B7ok^k^
00Sooooo1Ol00002ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0001eooooo`00Hoooool00omgMgOo
IVIVooooo`07ooooo`Go000000Co8B4Qo`000?lb<S;oc<c<1?ooool00ol0003oooooooooo`1doooo
o`00I?ooool00ol0003oooooooooo`07ooooo`Co00002?ooool00ol0003oooooooooo`1dooooo`00
H?ooool01Ol0003o^[ZjoooooonHV9So410@00Wooooo1Ol00007ooooo`03o`000?oooooooooo07Co
oooo001Pooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02Oooool7o`0000Gooooo00?o0000oooooooo
ool0M?ooool006kooooo1Ol00007ooooo`03o`000?oooooooooo07Cooooo001_ooooo`Co00001ooo
ool00ol0003oooooooooo`1dooooo`00Koooool4o`0000Oooooo00?o0000ooooooooool0M?ooool0
06oooooo1Ol00006ooooo`03o`000?oooooooooo07Cooooo001_ooooo`Go00001_ooool00ol0003o
ooooooooo`1dooooo`00Koooool5o`0000Kooooo00?o0000ooooooooool0M?ooool0073ooooo1?l0
0006ooooo`;o0000MOooool0073ooooo1?l00006ooooo`03o`000?oooooooooo07Cooooo001`oooo
o`Co00001_ooool00ol0003oooooooooo`1dooooo`00L?ooool5o`0000Gooooo00?o0000oooooooo
ool0M?ooool0073ooooo1Ol00005ooooo`03o`000?oooooooooo07Cooooo001`ooooo`Go00001Ooo
ool00ol0003oooooooooo`1dooooo`00LOooool4o`0000Gooooo00?o0000ooooooooool0M?ooool0
077ooooo1?l00005ooooo`03o`000?oooooooooo07Cooooo001aooooo`Co00001Oooool00ol0003o
ooooooooo`1dooooo`00LOooool5o`0000Cooooo00?o0000ooooooooool0M?ooool0077ooooo1Ol0
0004ooooo`03o`000?oooooooooo07Cooooo001aooooo`Go00001?ooool2o`0007Gooooo001boooo
o`Co00001?ooool00ol0003oooooooooo`1dooooo`00L_ooool4o`0000Cooooo00?o0000oooooooo
ool0M?ooool007;ooooo1?l00004ooooo`03o`000?oooooooooo07Cooooo001booooo`Co00001?oo
ool00ol0003oooooooooo`1dooooo`00L_ooool5o`0000?ooooo00?o0000ooooooooool0M?ooool0
07;ooooo1Ol00003ooooo`03o`000?oooooooooo07Cooooo001booooo`Go00000oooool00ol0003o
ooooooooo`1dooooo`00Loooool4o`0000?ooooo00?o0000ooooooooool0M?ooool007?ooooo1?l0
0003ooooo`03o`000?oooooooooo07Cooooo001cooooo`Go00000_ooool00ol0003oooooooooo`1d
ooooo`00Loooool5o`0000;ooooo0_l0001eooooo`00Loooool5o`0000;ooooo00?o0000oooooooo
ool0M?ooool007Cooooo1?l00002ooooo`03o`000?oooooooooo07Cooooo001dooooo`Go000000?o
ooooo`000?ooool0MOooool007Cooooo1Ol000000ooooooo0000ooooo`1eooooo`00M?ooool5o`00
0003ooooool0003ooooo07Gooooo001eooooo`Co000000?oooooo`000?ooool0MOooool007Gooooo
1?l000000ooooooo0000ooooo`1eooooo`00MOooool6o`0007Kooooo001eooooo`Ko0000M_ooool0
07Gooooo1_l0001fooooo`00M_ooool6o`0007Gooooo001fooooo`Go0000M_ooool007Kooooo1Ol0
001fooooo`00M_ooool5o`0007Kooooo001fooooo`Go0000M_ooool007Oooooo1?l0001fooooo`00
Moooool4o`0007Kooooo001gooooo`Co0000M_ooool0073ooooo00GoV9RHoa0@4?l0003o<S8bolc<
c002ooooo`Go0000MOooool0073ooooo00Go410@okZj^_ooooooMgMgoc8b<P02ooooo`Go0000MOoo
ool007Cooooo00?o0000ooooooooool01Ol0001eooooo`00Loooool00onYZJWo410@ooooo`02oooo
o`Co0000MOooool007;ooooo00?o410@o`000?nj^[X00oooool4o`0007Gooooo001cooooo`03okZj
^_lQ8B7ooooo00;ooooo1?l0001eooooo`00L?ooool01Ol@413oV9RHoooooonj^[[o000007cooooo
001`ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0O?ooool00?7ooooo003aooooo`00J?ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Gooooo1Ol0001Vooooo`00JOooool01Ol0
003ooooooooooooooooo000000Wooooo1_l00009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0I_oo
ool006Wooooo00Go0000ooooooooooooooooo`00000Iooooo`03oiRHV?lQ8B7ok^k^06Oooooo001Y
ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000_ooooo00?oV9RHob4Q8Oo^k^h0I_oo
ool006Wooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03ogMgMomVIVKooooo06Gooooo001X
ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool06_ooool00ol0003oooooooooo`1T
ooooo`00Q_ooool01Ol0003o^[ZjoooooonHV9So410@06Kooooo0026ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0I_ooool00?7ooooo003aooooo`00lOooool00001\
\>"],
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1.11171, -0.127346, \
0.0113701, 0.0113701}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.73776 .12693 m
.66977 .18263 L
.60725 .24338 L
.55842 .30043 L
.51952 .3553 L
.48583 .4137 L
.46007 .46992 L
.43901 .52967 L
.43065 .5596 L
.42411 .58724 L
.41413 .64262 L
.41063 .66962 L
.409 .68514 L
.40773 .69935 L
.40673 .71273 L
.40584 .72733 L
.40544 .73534 L
.40512 .74277 L
.40484 .75041 L
.40464 .75744 L
.40447 .76475 L
.4044 .76853 L
.40434 .77267 L
.4043 .77628 L
.40427 .77965 L
.40426 .78151 L
.40425 .78321 L
.40425 .78415 L
.40424 .78517 L
.40424 .78702 L
.40424 .78868 L
.40424 .79023 L
.40424 .79194 L
.40425 .79378 L
.40426 .7956 L
.40427 .79752 L
.4043 .80096 L
.40433 .80415 L
.40437 .80711 L
.40449 .81385 L
.40465 .82113 L
.40487 .82902 L
.40538 .84334 L
.4067 .87014 L
.4086 .8988 L
.41112 .92914 L
.41678 .98376 L
.42413 1.04192 L
.4322 1.09789 L
.44157 1.1574 L
Mistroke
.45113 1.21473 L
.46062 1.26986 L
.47084 1.32854 L
.48065 1.38503 L
.4909 1.44505 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.70225 .09185 m
.64442 .14897 L
.59124 .21127 L
.5497 .26978 L
.5166 .32605 L
.48795 .38594 L
.46604 .4436 L
.44812 .50488 L
.44101 .53557 L
.43545 .56392 L
.42695 .62071 L
.42398 .6484 L
.42259 .66432 L
.42151 .6789 L
.42066 .69262 L
.4199 .70759 L
.41956 .7158 L
.41929 .72342 L
.41906 .73125 L
.41888 .73846 L
.41874 .74597 L
.41868 .74984 L
.41863 .75409 L
.41859 .75779 L
.41857 .76124 L
.41856 .76315 L
.41855 .76489 L
.41855 .76586 L
.41854 .7669 L
.41854 .76881 L
.41854 .77051 L
.41854 .7721 L
.41854 .77385 L
.41855 .77574 L
.41856 .77761 L
.41857 .77958 L
.41859 .7831 L
.41862 .78637 L
.41866 .78941 L
.41875 .79632 L
.41889 .80378 L
.41908 .81188 L
.41951 .82657 L
.42064 .85405 L
.42225 .88344 L
.42439 .91455 L
.42921 .97057 L
.43546 1.03021 L
.44232 1.08762 L
.4503 1.14865 L
Mistroke
.45843 1.20744 L
.4665 1.26398 L
.4752 1.32416 L
.48354 1.38209 L
.49226 1.44365 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.64695 .04848 m
.60493 .10737 L
.56629 .17158 L
.53611 .2319 L
.51206 .2899 L
.49124 .35164 L
.47532 .41106 L
.46231 .47423 L
.45714 .50587 L
.4531 .53509 L
.44693 .59363 L
.44477 .62217 L
.44376 .63859 L
.44297 .65361 L
.44235 .66775 L
.4418 .68319 L
.44156 .69165 L
.44136 .6995 L
.44119 .70758 L
.44106 .71501 L
.44096 .72275 L
.44092 .72674 L
.44088 .73112 L
.44085 .73493 L
.44084 .73849 L
.44083 .74046 L
.44082 .74226 L
.44082 .74325 L
.44082 .74433 L
.44082 .74629 L
.44082 .74804 L
.44082 .74968 L
.44082 .75149 L
.44082 .75343 L
.44083 .75536 L
.44084 .75739 L
.44085 .76102 L
.44088 .76439 L
.4409 .76753 L
.44097 .77465 L
.44107 .78234 L
.44121 .79069 L
.44152 .80583 L
.44234 .83416 L
.44351 .86445 L
.44507 .89652 L
.44857 .95426 L
.45311 1.01575 L
.4581 1.07492 L
.46389 1.13783 L
Mistroke
.4698 1.19843 L
.47566 1.25672 L
.48198 1.31874 L
.48804 1.37846 L
.49438 1.44191 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.57725 .0134 m
.55516 .07371 L
.53485 .13948 L
.51898 .20125 L
.50634 .26065 L
.4954 .32388 L
.48703 .38475 L
.48018 .44944 L
.47747 .48185 L
.47534 .51177 L
.4721 .57173 L
.47096 .60096 L
.47043 .61777 L
.47002 .63315 L
.46969 .64764 L
.4694 .66345 L
.46927 .67211 L
.46917 .68016 L
.46908 .68843 L
.46902 .69604 L
.46896 .70396 L
.46894 .70805 L
.46892 .71253 L
.4689 .71644 L
.4689 .72009 L
.46889 .7221 L
.46889 .72394 L
.46889 .72496 L
.46889 .72606 L
.46889 .72807 L
.46889 .72987 L
.46889 .73155 L
.46889 .7334 L
.46889 .73539 L
.46889 .73736 L
.4689 .73944 L
.46891 .74316 L
.46892 .74661 L
.46893 .74983 L
.46897 .75712 L
.46902 .765 L
.46909 .77354 L
.46926 .78905 L
.46969 .81806 L
.4703 .84909 L
.47112 .88194 L
.47296 .94107 L
.47535 1.00404 L
.47797 1.06464 L
.48102 1.12907 L
Mistroke
.48412 1.19114 L
.4872 1.25084 L
.49053 1.31436 L
.49371 1.37552 L
.49704 1.44051 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.5 0 m
.5 .06085 L
.5 .12721 L
.5 .18954 L
.5 .24948 L
.5 .31328 L
.5 .37469 L
.5 .43997 L
.5 .47267 L
.5 .50286 L
.5 .56336 L
.5 .59285 L
.5 .60982 L
.5 .62534 L
.5 .63995 L
.5 .65591 L
.5 .66465 L
.5 .67277 L
.5 .68111 L
.5 .68879 L
.5 .69679 L
.5 .70091 L
.5 .70544 L
.5 .70938 L
.5 .71306 L
.5 .71509 L
.5 .71695 L
.5 .71797 L
.5 .71909 L
.5 .72111 L
.5 .72292 L
.5 .72462 L
.5 .72649 L
.5 .7285 L
.5 .73049 L
.5 .73259 L
.5 .73634 L
.5 .73982 L
.5 .74306 L
.5 .75042 L
.5 .75837 L
.5 .76699 L
.5 .78264 L
.5 .81192 L
.5 .84322 L
.5 .87636 L
.5 .93604 L
.5 .99957 L
.5 1.06072 L
.5 1.12573 L
Mistroke
.5 1.18835 L
.5 1.24859 L
.5 1.31269 L
.5 1.3744 L
.5 1.43997 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.42275 .0134 m
.44484 .07371 L
.46515 .13948 L
.48102 .20125 L
.49366 .26065 L
.5046 .32388 L
.51297 .38475 L
.51982 .44944 L
.52253 .48185 L
.52466 .51177 L
.5279 .57173 L
.52904 .60096 L
.52957 .61777 L
.52998 .63315 L
.53031 .64764 L
.5306 .66345 L
.53073 .67211 L
.53083 .68016 L
.53092 .68843 L
.53098 .69604 L
.53104 .70396 L
.53106 .70805 L
.53108 .71253 L
.5311 .71644 L
.5311 .72009 L
.53111 .7221 L
.53111 .72394 L
.53111 .72496 L
.53111 .72606 L
.53111 .72807 L
.53111 .72987 L
.53111 .73155 L
.53111 .7334 L
.53111 .73539 L
.53111 .73736 L
.5311 .73944 L
.53109 .74316 L
.53108 .74661 L
.53107 .74983 L
.53103 .75712 L
.53098 .765 L
.53091 .77354 L
.53074 .78905 L
.53031 .81806 L
.5297 .84909 L
.52888 .88194 L
.52704 .94107 L
.52465 1.00404 L
.52203 1.06464 L
.51898 1.12907 L
Mistroke
.51588 1.19114 L
.5128 1.25084 L
.50947 1.31436 L
.50629 1.37552 L
.50296 1.44051 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.35305 .04848 m
.39507 .10737 L
.43371 .17158 L
.46389 .2319 L
.48794 .2899 L
.50876 .35164 L
.52468 .41106 L
.53769 .47423 L
.54286 .50587 L
.5469 .53509 L
.55307 .59363 L
.55523 .62217 L
.55624 .63859 L
.55703 .65361 L
.55765 .66775 L
.5582 .68319 L
.55844 .69165 L
.55864 .6995 L
.55881 .70758 L
.55894 .71501 L
.55904 .72275 L
.55908 .72674 L
.55912 .73112 L
.55915 .73493 L
.55916 .73849 L
.55917 .74046 L
.55918 .74226 L
.55918 .74325 L
.55918 .74433 L
.55918 .74629 L
.55918 .74804 L
.55918 .74968 L
.55918 .75149 L
.55918 .75343 L
.55917 .75536 L
.55916 .75739 L
.55915 .76102 L
.55912 .76439 L
.5591 .76753 L
.55903 .77465 L
.55893 .78234 L
.55879 .79069 L
.55848 .80583 L
.55766 .83416 L
.55649 .86445 L
.55493 .89652 L
.55143 .95426 L
.54689 1.01575 L
.5419 1.07492 L
.53611 1.13783 L
Mistroke
.5302 1.19843 L
.52434 1.25672 L
.51802 1.31874 L
.51196 1.37846 L
.50562 1.44191 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.29775 .09185 m
.35558 .14897 L
.40876 .21127 L
.4503 .26978 L
.4834 .32605 L
.51205 .38594 L
.53396 .4436 L
.55188 .50488 L
.55899 .53557 L
.56455 .56392 L
.57305 .62071 L
.57602 .6484 L
.57741 .66432 L
.57849 .6789 L
.57934 .69262 L
.5801 .70759 L
.58044 .7158 L
.58071 .72342 L
.58094 .73125 L
.58112 .73846 L
.58126 .74597 L
.58132 .74984 L
.58137 .75409 L
.58141 .75779 L
.58143 .76124 L
.58144 .76315 L
.58145 .76489 L
.58145 .76586 L
.58146 .7669 L
.58146 .76881 L
.58146 .77051 L
.58146 .7721 L
.58146 .77385 L
.58145 .77574 L
.58144 .77761 L
.58143 .77958 L
.58141 .7831 L
.58138 .78637 L
.58134 .78941 L
.58125 .79632 L
.58111 .80378 L
.58092 .81188 L
.58049 .82657 L
.57936 .85405 L
.57775 .88344 L
.57561 .91455 L
.57079 .97057 L
.56454 1.03021 L
.55768 1.08762 L
.5497 1.14865 L
Mistroke
.54157 1.20744 L
.5335 1.26398 L
.5248 1.32416 L
.51646 1.38209 L
.50774 1.44365 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.26224 .12693 m
.33023 .18263 L
.39275 .24338 L
.44158 .30043 L
.48048 .3553 L
.51417 .4137 L
.53993 .46992 L
.56099 .52967 L
.56935 .5596 L
.57589 .58724 L
.58587 .64262 L
.58937 .66962 L
.591 .68514 L
.59227 .69935 L
.59327 .71273 L
.59416 .72733 L
.59456 .73534 L
.59488 .74277 L
.59516 .75041 L
.59536 .75744 L
.59553 .76475 L
.5956 .76853 L
.59566 .77267 L
.5957 .77628 L
.59573 .77965 L
.59574 .78151 L
.59575 .78321 L
.59575 .78415 L
.59576 .78517 L
.59576 .78702 L
.59576 .78868 L
.59576 .79023 L
.59576 .79194 L
.59575 .79378 L
.59574 .7956 L
.59573 .79752 L
.5957 .80096 L
.59567 .80415 L
.59563 .80711 L
.59551 .81385 L
.59535 .82113 L
.59513 .82902 L
.59462 .84334 L
.5933 .87014 L
.5914 .8988 L
.58888 .92914 L
.58322 .98376 L
.57587 1.04192 L
.5678 1.09789 L
.55843 1.1574 L
Mistroke
.54887 1.21473 L
.53938 1.26986 L
.52916 1.32854 L
.51935 1.38503 L
.5091 1.44505 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.25 .14033 m
.32149 .19549 L
.38723 .25564 L
.43857 .31214 L
.47948 .36647 L
.5149 .4243 L
.54198 .47997 L
.56413 .53914 L
.57292 .56878 L
.57979 .59614 L
.59029 .65099 L
.59397 .67772 L
.59569 .6931 L
.59702 .70717 L
.59807 .72041 L
.59901 .73488 L
.59943 .7428 L
.59976 .75016 L
.60005 .75772 L
.60027 .76468 L
.60045 .77193 L
.60052 .77567 L
.60058 .77977 L
.60063 .78334 L
.60066 .78668 L
.60067 .78852 L
.60068 .7902 L
.60068 .79113 L
.60069 .79214 L
.60069 .79398 L
.60069 .79562 L
.60069 .79716 L
.60068 .79885 L
.60068 .80067 L
.60067 .80248 L
.60066 .80438 L
.60063 .80778 L
.60059 .81094 L
.60055 .81388 L
.60043 .82055 L
.60026 .82775 L
.60002 .83557 L
.59949 .84975 L
.5981 .87629 L
.5961 .90467 L
.59345 .93471 L
.5875 .9888 L
.57978 1.04639 L
.57129 1.10182 L
.56144 1.16074 L
Mistroke
.55139 1.21751 L
.54141 1.27211 L
.53066 1.33021 L
.52034 1.38615 L
.50957 1.44559 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.26224 .12693 m
.33023 .18263 L
.39275 .24338 L
.44158 .30043 L
.48048 .3553 L
.51417 .4137 L
.53993 .46992 L
.56099 .52967 L
.56935 .5596 L
.57589 .58724 L
.58587 .64262 L
.58937 .66962 L
.591 .68514 L
.59227 .69935 L
.59327 .71273 L
.59416 .72733 L
.59456 .73534 L
.59488 .74277 L
.59516 .75041 L
.59536 .75744 L
.59553 .76475 L
.5956 .76853 L
.59566 .77267 L
.5957 .77628 L
.59573 .77965 L
.59574 .78151 L
.59575 .78321 L
.59575 .78415 L
.59576 .78517 L
.59576 .78702 L
.59576 .78868 L
.59576 .79023 L
.59576 .79194 L
.59575 .79378 L
.59574 .7956 L
.59573 .79752 L
.5957 .80096 L
.59567 .80415 L
.59563 .80711 L
.59551 .81385 L
.59535 .82113 L
.59513 .82902 L
.59462 .84334 L
.5933 .87014 L
.5914 .8988 L
.58888 .92914 L
.58322 .98376 L
.57587 1.04192 L
.5678 1.09789 L
.55843 1.1574 L
Mistroke
.54887 1.21473 L
.53938 1.26986 L
.52916 1.32854 L
.51935 1.38503 L
.5091 1.44505 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.29775 .09185 m
.35558 .14897 L
.40876 .21127 L
.4503 .26978 L
.4834 .32605 L
.51205 .38594 L
.53396 .4436 L
.55188 .50488 L
.55899 .53557 L
.56455 .56392 L
.57305 .62071 L
.57602 .6484 L
.57741 .66432 L
.57849 .6789 L
.57934 .69262 L
.5801 .70759 L
.58044 .7158 L
.58071 .72342 L
.58094 .73125 L
.58112 .73846 L
.58126 .74597 L
.58132 .74984 L
.58137 .75409 L
.58141 .75779 L
.58143 .76124 L
.58144 .76315 L
.58145 .76489 L
.58145 .76586 L
.58146 .7669 L
.58146 .76881 L
.58146 .77051 L
.58146 .7721 L
.58146 .77385 L
.58145 .77574 L
.58144 .77761 L
.58143 .77958 L
.58141 .7831 L
.58138 .78637 L
.58134 .78941 L
.58125 .79632 L
.58111 .80378 L
.58092 .81188 L
.58049 .82657 L
.57936 .85405 L
.57775 .88344 L
.57561 .91455 L
.57079 .97057 L
.56454 1.03021 L
.55768 1.08762 L
.5497 1.14865 L
Mistroke
.54157 1.20744 L
.5335 1.26398 L
.5248 1.32416 L
.51646 1.38209 L
.50774 1.44365 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.35305 .04848 m
.39507 .10737 L
.43371 .17158 L
.46389 .2319 L
.48794 .2899 L
.50876 .35164 L
.52468 .41106 L
.53769 .47423 L
.54286 .50587 L
.5469 .53509 L
.55307 .59363 L
.55523 .62217 L
.55624 .63859 L
.55703 .65361 L
.55765 .66775 L
.5582 .68319 L
.55844 .69165 L
.55864 .6995 L
.55881 .70758 L
.55894 .71501 L
.55904 .72275 L
.55908 .72674 L
.55912 .73112 L
.55915 .73493 L
.55916 .73849 L
.55917 .74046 L
.55918 .74226 L
.55918 .74325 L
.55918 .74433 L
.55918 .74629 L
.55918 .74804 L
.55918 .74968 L
.55918 .75149 L
.55918 .75343 L
.55917 .75536 L
.55916 .75739 L
.55915 .76102 L
.55912 .76439 L
.5591 .76753 L
.55903 .77465 L
.55893 .78234 L
.55879 .79069 L
.55848 .80583 L
.55766 .83416 L
.55649 .86445 L
.55493 .89652 L
.55143 .95426 L
.54689 1.01575 L
.5419 1.07492 L
.53611 1.13783 L
Mistroke
.5302 1.19843 L
.52434 1.25672 L
.51802 1.31874 L
.51196 1.37846 L
.50562 1.44191 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.42275 .0134 m
.44484 .07371 L
.46515 .13948 L
.48102 .20125 L
.49366 .26065 L
.5046 .32388 L
.51297 .38475 L
.51982 .44944 L
.52253 .48185 L
.52466 .51177 L
.5279 .57173 L
.52904 .60096 L
.52957 .61777 L
.52998 .63315 L
.53031 .64764 L
.5306 .66345 L
.53073 .67211 L
.53083 .68016 L
.53092 .68843 L
.53098 .69604 L
.53104 .70396 L
.53106 .70805 L
.53108 .71253 L
.5311 .71644 L
.5311 .72009 L
.53111 .7221 L
.53111 .72394 L
.53111 .72496 L
.53111 .72606 L
.53111 .72807 L
.53111 .72987 L
.53111 .73155 L
.53111 .7334 L
.53111 .73539 L
.53111 .73736 L
.5311 .73944 L
.53109 .74316 L
.53108 .74661 L
.53107 .74983 L
.53103 .75712 L
.53098 .765 L
.53091 .77354 L
.53074 .78905 L
.53031 .81806 L
.5297 .84909 L
.52888 .88194 L
.52704 .94107 L
.52465 1.00404 L
.52203 1.06464 L
.51898 1.12907 L
Mistroke
.51588 1.19114 L
.5128 1.25084 L
.50947 1.31436 L
.50629 1.37552 L
.50296 1.44051 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.5 0 m
.5 .06085 L
.5 .12721 L
.5 .18954 L
.5 .24948 L
.5 .31328 L
.5 .37469 L
.5 .43997 L
.5 .47267 L
.5 .50286 L
.5 .56336 L
.5 .59285 L
.5 .60982 L
.5 .62534 L
.5 .63995 L
.5 .65591 L
.5 .66465 L
.5 .67277 L
.5 .68111 L
.5 .68879 L
.5 .69679 L
.5 .70091 L
.5 .70544 L
.5 .70938 L
.5 .71306 L
.5 .71509 L
.5 .71695 L
.5 .71797 L
.5 .71909 L
.5 .72111 L
.5 .72292 L
.5 .72462 L
.5 .72649 L
.5 .7285 L
.5 .73049 L
.5 .73259 L
.5 .73634 L
.5 .73982 L
.5 .74306 L
.5 .75042 L
.5 .75837 L
.5 .76699 L
.5 .78264 L
.5 .81192 L
.5 .84322 L
.5 .87636 L
.5 .93604 L
.5 .99957 L
.5 1.06072 L
.5 1.12573 L
Mistroke
.5 1.18835 L
.5 1.24859 L
.5 1.31269 L
.5 1.3744 L
.5 1.43997 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.57725 .0134 m
.55516 .07371 L
.53485 .13948 L
.51898 .20125 L
.50634 .26065 L
.4954 .32388 L
.48703 .38475 L
.48018 .44944 L
.47747 .48185 L
.47534 .51177 L
.4721 .57173 L
.47096 .60096 L
.47043 .61777 L
.47002 .63315 L
.46969 .64764 L
.4694 .66345 L
.46927 .67211 L
.46917 .68016 L
.46908 .68843 L
.46902 .69604 L
.46896 .70396 L
.46894 .70805 L
.46892 .71253 L
.4689 .71644 L
.4689 .72009 L
.46889 .7221 L
.46889 .72394 L
.46889 .72496 L
.46889 .72606 L
.46889 .72807 L
.46889 .72987 L
.46889 .73155 L
.46889 .7334 L
.46889 .73539 L
.46889 .73736 L
.4689 .73944 L
.46891 .74316 L
.46892 .74661 L
.46893 .74983 L
.46897 .75712 L
.46902 .765 L
.46909 .77354 L
.46926 .78905 L
.46969 .81806 L
.4703 .84909 L
.47112 .88194 L
.47296 .94107 L
.47535 1.00404 L
.47797 1.06464 L
.48102 1.12907 L
Mistroke
.48412 1.19114 L
.4872 1.25084 L
.49053 1.31436 L
.49371 1.37552 L
.49704 1.44051 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.64695 .04848 m
.60493 .10737 L
.56629 .17158 L
.53611 .2319 L
.51206 .2899 L
.49124 .35164 L
.47532 .41106 L
.46231 .47423 L
.45714 .50587 L
.4531 .53509 L
.44693 .59363 L
.44477 .62217 L
.44376 .63859 L
.44297 .65361 L
.44235 .66775 L
.4418 .68319 L
.44156 .69165 L
.44136 .6995 L
.44119 .70758 L
.44106 .71501 L
.44096 .72275 L
.44092 .72674 L
.44088 .73112 L
.44085 .73493 L
.44084 .73849 L
.44083 .74046 L
.44082 .74226 L
.44082 .74325 L
.44082 .74433 L
.44082 .74629 L
.44082 .74804 L
.44082 .74968 L
.44082 .75149 L
.44082 .75343 L
.44083 .75536 L
.44084 .75739 L
.44085 .76102 L
.44088 .76439 L
.4409 .76753 L
.44097 .77465 L
.44107 .78234 L
.44121 .79069 L
.44152 .80583 L
.44234 .83416 L
.44351 .86445 L
.44507 .89652 L
.44857 .95426 L
.45311 1.01575 L
.4581 1.07492 L
.46389 1.13783 L
Mistroke
.4698 1.19843 L
.47566 1.25672 L
.48198 1.31874 L
.48804 1.37846 L
.49438 1.44191 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.70225 .09185 m
.64442 .14897 L
.59124 .21127 L
.5497 .26978 L
.5166 .32605 L
.48795 .38594 L
.46604 .4436 L
.44812 .50488 L
.44101 .53557 L
.43545 .56392 L
.42695 .62071 L
.42398 .6484 L
.42259 .66432 L
.42151 .6789 L
.42066 .69262 L
.4199 .70759 L
.41956 .7158 L
.41929 .72342 L
.41906 .73125 L
.41888 .73846 L
.41874 .74597 L
.41868 .74984 L
.41863 .75409 L
.41859 .75779 L
.41857 .76124 L
.41856 .76315 L
.41855 .76489 L
.41855 .76586 L
.41854 .7669 L
.41854 .76881 L
.41854 .77051 L
.41854 .7721 L
.41854 .77385 L
.41855 .77574 L
.41856 .77761 L
.41857 .77958 L
.41859 .7831 L
.41862 .78637 L
.41866 .78941 L
.41875 .79632 L
.41889 .80378 L
.41908 .81188 L
.41951 .82657 L
.42064 .85405 L
.42225 .88344 L
.42439 .91455 L
.42921 .97057 L
.43546 1.03021 L
.44232 1.08762 L
.4503 1.14865 L
Mistroke
.45843 1.20744 L
.4665 1.26398 L
.4752 1.32416 L
.48354 1.38209 L
.49226 1.44365 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0 0.5 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[.4875 .25 -18 -4.5 ]
[.4875 .25 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .75 -18 -4.5 ]
[.4875 .75 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.25 -18 -4.5 ]
[.4875 1.25 0 4.5 ]
[.4875 1.5 -6 -4.5 ]
[.4875 1.5 0 4.5 ]
[.5 1.5125 -17 0 ]
[.5 1.5125 17 12 ]
[ 0 0 0 0 ]
[ 1 1.5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-1)] 0 -0.0125 0 1 Mshowa
.125 0 m
.125 .00625 L
s
[(-0.75)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-0.25)] .375 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.5 .25 m
.50625 .25 L
s
[(0.5)] .4875 .25 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(1)] .4875 .5 1 0 Mshowa
.5 .75 m
.50625 .75 L
s
[(1.5)] .4875 .75 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(2)] .4875 1 1 0 Mshowa
.5 1.25 m
.50625 1.25 L
s
[(2.5)] .4875 1.25 1 0 Mshowa
.5 1.5 m
.50625 1.5 L
s
[(3)] .4875 1.5 1 0 Mshowa
.125 Mabswid
.5 .05 m
.50375 .05 L
s
.5 .1 m
.50375 .1 L
s
.5 .15 m
.50375 .15 L
s
.5 .2 m
.50375 .2 L
s
.5 .3 m
.50375 .3 L
s
.5 .35 m
.50375 .35 L
s
.5 .4 m
.50375 .4 L
s
.5 .45 m
.50375 .45 L
s
.5 .55 m
.50375 .55 L
s
.5 .6 m
.50375 .6 L
s
.5 .65 m
.50375 .65 L
s
.5 .7 m
.50375 .7 L
s
.5 .8 m
.50375 .8 L
s
.5 .85 m
.50375 .85 L
s
.5 .9 m
.50375 .9 L
s
.5 .95 m
.50375 .95 L
s
.5 1.05 m
.50375 1.05 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.15 m
.50375 1.15 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.3 m
.50375 1.3 L
s
.5 1.35 m
.50375 1.35 L
s
.5 1.4 m
.50375 1.4 L
s
.5 1.45 m
.50375 1.45 L
s
.25 Mabswid
.5 0 m
.5 1.5 L
s
gsave
.5 1.5125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
.02 w
.73776 .12693 m
.66977 .18263 L
.60725 .24338 L
.55842 .30043 L
.51952 .3553 L
.48583 .4137 L
.46007 .46992 L
.43901 .52967 L
.43065 .5596 L
.42411 .58724 L
.41413 .64262 L
.41063 .66962 L
.409 .68514 L
.40773 .69935 L
.40673 .71273 L
.40584 .72733 L
.40544 .73534 L
.40512 .74277 L
.40484 .75041 L
.40464 .75744 L
.40447 .76475 L
.4044 .76853 L
.40434 .77267 L
.4043 .77628 L
.40427 .77965 L
.40426 .78151 L
.40425 .78321 L
.40425 .78415 L
.40424 .78517 L
.40424 .78702 L
.40424 .78868 L
.40424 .79023 L
.40424 .79194 L
.40425 .79378 L
.40426 .7956 L
.40427 .79752 L
.4043 .80096 L
.40433 .80415 L
.40437 .80711 L
.40449 .81385 L
.40465 .82113 L
.40487 .82902 L
.40538 .84334 L
.4067 .87014 L
.4086 .8988 L
.41112 .92914 L
.41678 .98376 L
.42413 1.04192 L
.4322 1.09789 L
.44157 1.1574 L
Mistroke
.45113 1.21473 L
.46062 1.26986 L
.47084 1.32854 L
.48065 1.38503 L
.4909 1.44505 L
.5 1.5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{193.375, 290.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.0773857,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 240.688}, {361.562, 0}} -> {-1, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThe reader is invited to reevaluate this cell for different values of \
the mode number ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can use these modes to determine the evolution of an initial \
disturbance on the string.  Let's assume that initially the string has a \
sharply peaked Gaussian pulse shape ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, 
          t)\  = \ \(\(y\_o\)(
            x) = \[ExponentialE]\^\(\(-40\) \((z - L/2)\)\^2\)\)\)]],
  ".  We will also choose an  initial velocity of the string consistent with \
this pulse traveling down the string. On a uniform string, such a pulse would \
have the form ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(y\_o\)(z + \ c\ t)\)]],
  " [see Eq. ",
  ButtonBox["(3.1.26)",
    ButtonData:>{"Chapter3.nb", "(3.1.26)"},
    ButtonStyle->"Hyperlink"],
  "], and this implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]y\/\[PartialD]t = 
        c \[PartialD]y\/\[PartialD]z\)]],
  ".  We will use this form for the initial condition of the nonuniform \
string, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((z, 0)\) = \(c(
            z)\) \[PartialD]y\_o\/\[PartialD]z\)]],
  ",  where ",
  Cell[BoxData[
      \(TraditionalForm\`c(z) = \@\(g\ z\)\)]],
  " is the (nonuniform) propagation speed on the string. Then we know that \
the  solution of Eq. ",
  ButtonBox["(4.2.41)",
    ButtonData:>"(4.2.41)",
    ButtonStyle->"Hyperlink"],
  " is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(z, 
          t)\  = \ \[Sum]\+\(n = 1\)\%\[Infinity]\((A\_n\ cos\ \
\(\[Omega]\_n\) t\  + B\_n\ sin\ \(\[Omega]\_n\) t\ )\) \(\(\[Psi]\_n\)(
              z)\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  " given by Eqs. ",
  ButtonBox["(4.2.45)",
    ButtonData:>"(4.2.45)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.2.46)",
    ButtonData:>"(4.2.46)",
    ButtonStyle->"Hyperlink"],
  ".  According to the Sturm-Liouville form of Eq. ",
  ButtonBox["(4.2.43)",
    ButtonData:>"(4.2.43)",
    ButtonStyle->"Hyperlink"],
  ", different modes are orthogonal with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((f, 
          g)\) = \[Integral]\_0\%L\( f\^\(\(*\)\(\ \)\)\) 
            g \[DifferentialD]z\)]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\_n\)\(\ \)\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " are given in terms of this inner product by Eqs. ",
  ButtonBox["(4.2.25)",
    ButtonData:>"(4.2.25)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.2.27)",
    ButtonData:>"(4.2.27)",
    ButtonStyle->"Hyperlink"],
  ".  We evaluate the required inner products in Cell ",
  ButtonBox["4.18",
    ButtonData:>"Cell 4.18",
    ButtonStyle->"Hyperlink"],
  " keeping ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(=\)\(50\)\(\ \)\)\)]],
  "terms in the series solution, and we then plot the result. Here we do not \
bother to try to account for the change in height of the string end during \
the evolution. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< NumericalMath`;\)\), "\n", 
    \(M = 50; g = 9.8; L = 3;\), "\n", 
    \(\(j0\  = \ BesselJZeros[0, M];\)\), "\n", 
    \(\(\[Omega][n_]\  := j0[\([n]\)]\ \ Sqrt[g/L]/2;\)\), "\n", 
    \(\(\(\[Psi][n_, z_]\  := \ BesselJ[0, j0[\([n]\)]\ Sqrt[z/L]];\)\(\n\)
    \)\), "\n", 
    \(\(\(y0[z_]\  = \ Exp[\(-\((z - L/2)\)^2\)\ 40];\)\(\n\)
    \)\), "\n", 
    \(\(\(dy0[z_]\  = \ D[y0[z], z];\)\(\n\)
    \)\), "\n", 
    \(\(a\  = \ 
        Table[NIntegrate[\[Psi][n, z]\ y0[z], {z, 0, L}]/
            Integrate[\[Psi][n, z]^2, {z, 0, L}], {n, 1, M}];\)\), "\n", 
    \(\(\(b\  = \ 
        Table[NIntegrate[\[Psi][n, z]\ Sqrt[g\ z] dy0[z], {z, 0, 
                L}]/\((Integrate[\[Psi][n, z]^2, {z, 0, L}]\ \[Omega][
                  n])\), {n, 1, M}];\)\(\n\)
    \)\), "\n", 
    \(\(\(y[z_, t_]\  = \ 
        Sum[\((a[\([n]\)]\ Cos[\[Omega][n]\ t] + \ 
                b[\([n]\)]\ Sin[\[Omega][n]\ t])\)\ \[Psi][n, z], {n, 1, 
            M}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[
        ParametricPlot[Evaluate[{y[z, t], z}], {z, 0, L}, 
          AspectRatio \[Rule] 1/2, PlotRange \[Rule] {{\(-L\), L}, {0, L}}, 
          Axes \[Rule] False, PlotPoints \[Rule] 60, 
          PlotLabel \[Rule] "\<y[z,t],t = \>" <> 
              ToString[t] <> "\< sec\>"], {t, 0, 2, \  .05}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.18"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -50 0 ]
[.5 .5125 50 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -111 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
141.000 13.000 moveto
(sec) show
159.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49996 0 m
.49999 .00099 L
.5 .00147 L
.5 .0017 L
.50001 .00192 L
.50001 .00217 L
.50001 .00245 L
.5 .00268 L
.5 .00293 L
.49999 .0032 L
.49999 .00345 L
.49999 .00372 L
.49999 .00388 L
.49999 .00402 L
.5 .00452 L
.5 .00479 L
.50001 .00505 L
.50001 .0052 L
.50001 .00536 L
.50001 .00564 L
.50001 .00578 L
.50001 .00593 L
.5 .00619 L
.5 .00666 L
.5 .00692 L
.5 .00717 L
.49999 .00731 L
.49999 .00746 L
.49999 .00773 L
.49999 .008 L
.49999 .00825 L
.5 .00925 L
.5 .00952 L
.5 .00967 L
.5 .00981 L
.50001 .01006 L
.50001 .01032 L
.50001 .01048 L
.50001 .01062 L
.50001 .0109 L
.5 .01105 L
.5 .01119 L
.5 .01151 L
.5 .01208 L
.5 .01236 L
.5 .01261 L
.5 .01288 L
.49999 .01313 L
.49999 .0134 L
.49999 .01355 L
Mistroke
.49999 .01369 L
.49999 .01384 L
.49999 .01399 L
.5 .01426 L
.5 .01487 L
.5 .01542 L
.5 .01573 L
.5 .01601 L
.5 .01632 L
.50001 .01648 L
.50001 .01666 L
.50001 .01682 L
.50001 .01697 L
.50001 .0171 L
.50001 .01725 L
.5 .01751 L
.5 .01775 L
.5 .01829 L
.5 .01926 L
.5 .01978 L
.5 .01992 L
.5 .02007 L
.49999 .02034 L
.49999 .02049 L
.49999 .02065 L
.49999 .0208 L
.49999 .02094 L
.49999 .0212 L
.5 .02148 L
.5 .02259 L
.5 .02365 L
.5 .02393 L
.5 .02423 L
.5 .02438 L
.5 .02456 L
.50001 .02471 L
.50001 .02486 L
.50001 .02514 L
.50001 .02539 L
.5 .02567 L
.5 .02582 L
.5 .02597 L
.5 .02702 L
.5 .02759 L
.5 .02814 L
.5 .02865 L
.5 .02879 L
.5 .02893 L
.5 .0292 L
.49999 .02943 L
Mistroke
.49999 .02965 L
.49999 .0299 L
.5 .03016 L
.5 .03042 L
.5 .03066 L
.5 .03121 L
.5 .0322 L
.5 .03268 L
.5 .03318 L
.5 .0336 L
.5 .03385 L
.5 .03407 L
.5 .03435 L
.5 .0346 L
.5 .03473 L
.5 .03488 L
.5 .03516 L
.5 .0353 L
.5 .03545 L
.5 .03577 L
.5 .03633 L
.5 .03735 L
.5 .03789 L
.5 .03846 L
.5 .03897 L
.5 .03926 L
.5 .03953 L
.5 .03978 L
.5 .04 L
.5 .04026 L
.5 .04051 L
.5 .04074 L
.5 .04099 L
.5 .0412 L
.5 .04143 L
.5 .04243 L
.5 .04355 L
.5 .0441 L
.5 .04461 L
.5 .04507 L
.5 .04532 L
.5 .04555 L
.5 .04581 L
.5 .04609 L
.5 .04635 L
.5 .04659 L
.5 .04685 L
.5 .04713 L
.5 .04763 L
.5 .04876 L
Mistroke
.5 .04995 L
.5 .05048 L
.5 .05075 L
.5 .05105 L
.5 .05134 L
.5 .0516 L
.5 .05186 L
.5 .05211 L
.5 .05239 L
.5 .05265 L
.5 .0528 L
.5 .05293 L
.5 .05323 L
.5 .05354 L
.5 .05382 L
.5 .05445 L
.5 .0556 L
.5 .05668 L
.5 .05721 L
.5 .05769 L
.5 .05795 L
.5 .0582 L
.5 .05846 L
.5 .05861 L
.5 .05874 L
.5 .05901 L
.5 .05916 L
.5 .0593 L
.5 .05945 L
.5 .05959 L
.5 .0599 L
.5 .06202 L
.5 .06318 L
.5 .06375 L
.5 .06428 L
.5 .06478 L
.5 .06503 L
.5 .06531 L
.5 .06558 L
.5 .06574 L
.5 .06588 L
.5 .06616 L
.5 .06642 L
.5 .06665 L
.5 .0669 L
.5 .06735 L
.5 .06788 L
.5 .06836 L
.5 .07037 L
.5 .07093 L
Mistroke
.5 .07151 L
.5 .07201 L
.5 .07229 L
.5 .07255 L
.5 .0728 L
.5 .07306 L
.5 .07332 L
.5 .07355 L
.5 .07376 L
.5 .07399 L
.5 .07423 L
.5 .07446 L
.5 .07497 L
.5 .07544 L
.5 .0765 L
.5 .07845 L
.5 .07902 L
.5 .07955 L
.5 .08003 L
.5 .0803 L
.5 .08054 L
.5 .08082 L
.5 .08107 L
.5 .08136 L
.5 .08151 L
.5 .08166 L
.5 .08195 L
.5 .08226 L
.5 .08284 L
.5 .08394 L
.5 .08497 L
.5 .0859 L
.5 .08688 L
.5 .08739 L
.5 .08767 L
.5 .08796 L
.5 .08823 L
.5 .08847 L
.5 .08871 L
.5 .08895 L
.50001 .08922 L
.50001 .08936 L
.5 .08951 L
.5 .08978 L
.5 .09003 L
.5 .09033 L
.5 .0906 L
.5 .09121 L
.5 .0923 L
.5 .09334 L
Mistroke
.5 .0944 L
.5 .09539 L
.5 .09594 L
.5 .09623 L
.5 .09654 L
.5 .09679 L
.5 .09693 L
.5 .09708 L
.49999 .09733 L
.49999 .09757 L
.49999 .09784 L
.49999 .09808 L
.49999 .09835 L
.5 .09848 L
.5 .09863 L
.5 .09914 L
.5 .09963 L
.5 .10053 L
.5 .1015 L
.5 .10257 L
.5 .10372 L
.5 .10427 L
.5 .1048 L
.5 .10527 L
.5 .10553 L
.5 .10578 L
.50001 .10604 L
.50001 .10618 L
.50001 .10633 L
.50001 .10648 L
.50001 .10663 L
.50001 .1069 L
.50001 .10716 L
.50001 .1074 L
.5 .10766 L
.5 .10793 L
.5 .10857 L
.5 .10917 L
.5 .11029 L
.5 .11238 L
.5 .11352 L
.5 .11408 L
.5 .11459 L
.5 .11481 L
.49999 .11505 L
.49999 .11526 L
.49999 .1155 L
.49999 .11574 L
.49999 .116 L
.49999 .11624 L
Mistroke
.49999 .11647 L
.49999 .11674 L
.49999 .11699 L
.49999 .11722 L
.5 .11746 L
.5 .11802 L
.5 .11853 L
.5 .12048 L
.5 .12254 L
.5 .12362 L
.5 .12423 L
.50001 .12453 L
.50001 .1248 L
.50001 .12506 L
.50001 .12533 L
.50001 .12558 L
.50001 .12581 L
.50001 .12606 L
.50001 .12633 L
.50001 .12647 L
.50001 .12662 L
.50001 .12689 L
.5 .12744 L
.5 .12805 L
.5 .12927 L
.5 .13145 L
.5 .13253 L
.5 .13312 L
.5 .13368 L
.5 .13421 L
.49999 .13448 L
.49999 .13477 L
.49999 .13502 L
.49999 .13529 L
.49999 .13553 L
.49999 .13576 L
.49999 .13603 L
.49999 .13618 L
.49999 .13631 L
.49999 .13657 L
.49999 .13682 L
.49999 .13711 L
.49999 .13738 L
.5 .13798 L
.5 .13901 L
.5 .14009 L
.5 .14216 L
.5 .14306 L
.5 .14405 L
.50001 .14459 L
Mistroke
.50001 .14509 L
.50001 .14533 L
.50001 .14557 L
.50001 .14581 L
.50001 .14607 L
.50001 .14634 L
.50001 .14662 L
.50001 .14686 L
.50001 .14712 L
.50001 .1474 L
.50001 .1477 L
.50001 .14824 L
.5 .14875 L
.5 .1493 L
.5 .1503 L
.5 .15216 L
.5 .15314 L
.5 .15419 L
.5 .15479 L
.5 .15534 L
.49999 .1556 L
.49999 .15589 L
.49999 .15616 L
.49999 .15641 L
.49999 .15656 L
.49999 .15669 L
.49999 .15684 L
.49999 .157 L
.49999 .15726 L
.49999 .15741 L
.49999 .15755 L
.49999 .15782 L
.49999 .15805 L
.5 .15859 L
.5 .15916 L
.5 .15978 L
.5 .16091 L
.50001 .16514 L
.50002 .1673 L
.50002 .16963 L
.50003 .17075 L
.50003 .17181 L
.50003 .17284 L
.50004 .1738 L
.50005 .17471 L
.50006 .17567 L
.50007 .17674 L
.50008 .17771 L
.5001 .17875 L
.50013 .17985 L
Mistroke
.5002 .18182 L
.50025 .18292 L
.50031 .18394 L
.50038 .18505 L
.50048 .18627 L
.50072 .1885 L
.50105 .19061 L
.50147 .19267 L
.502 .19457 L
.50276 .19663 L
.50369 .19856 L
.50501 .20068 L
.50688 .20296 L
.50902 .205 L
.51197 .20724 L
.51589 .2096 L
.52026 .21174 L
.53134 .21593 L
.54722 .22041 L
.58801 .22894 L
.63143 .23716 L
.64984 .2414 L
.65696 .24354 L
.66018 .24475 L
.66268 .24589 L
.66443 .24693 L
.6652 .24752 L
.66577 .24806 L
.66618 .24857 L
.66644 .24902 L
.66654 .24928 L
.66662 .24955 L
.66666 .24981 L
.66666 .25005 L
.66664 .25031 L
.66658 .25058 L
.66649 .25084 L
.66638 .25108 L
.66622 .25136 L
.666 .25167 L
.66548 .25222 L
.66479 .2528 L
.66389 .25341 L
.66185 .25451 L
.65678 .25651 L
.64955 .25867 L
.6327 .26258 L
.58632 .27138 L
.56406 .27577 L
.5462 .27985 L
Mistroke
.5314 .28404 L
.52084 .288 L
.51645 .2901 L
.51256 .29237 L
.50757 .29635 L
.50574 .29837 L
.50418 .3006 L
.50296 .30292 L
.50211 .30509 L
.50147 .30732 L
.50102 .30943 L
.50073 .31133 L
.5005 .3134 L
.50035 .3154 L
.50028 .31654 L
.50023 .31761 L
.50015 .31977 L
.50012 .32098 L
.5001 .3221 L
.50008 .32311 L
.50006 .32419 L
.50005 .32613 L
.50004 .32732 L
.50003 .32845 L
.50002 .33055 L
.50001 .33262 L
.50001 .33482 L
.5 .33688 L
.5 .33876 L
.5 .34077 L
.5 .34188 L
.5 .34239 L
.49999 .34293 L
.49999 .34344 L
.49999 .3439 L
.49999 .34413 L
.49999 .34437 L
.49999 .34459 L
.49999 .3448 L
.49999 .34505 L
.49999 .34528 L
.49999 .34553 L
.49999 .34579 L
.49999 .34608 L
.49999 .34634 L
.49999 .34684 L
.5 .34782 L
.5 .34891 L
.5 .3511 L
.5 .35503 L
Mistroke
.5 .35608 L
.5 .35719 L
.5 .35813 L
.5 .35866 L
.50001 .35916 L
.50001 .35945 L
.50001 .35975 L
.50001 .36 L
.50001 .36028 L
.50001 .36044 L
.50001 .36058 L
.50001 .36074 L
.50001 .3609 L
.50001 .36105 L
.50001 .3612 L
.50001 .36147 L
.50001 .36173 L
.50001 .36201 L
.50001 .36227 L
.50001 .3625 L
.5 .36308 L
.5 .36362 L
.5 .36462 L
.5 .36571 L
.5 .36792 L
.5 .37187 L
.5 .37299 L
.5 .37405 L
.5 .37501 L
.5 .37554 L
.5 .37604 L
.5 .37658 L
.5 .37687 L
.5 .37717 L
.5 .37733 L
.5 .37749 L
.5 .37765 L
.5 .3778 L
.5 .37807 L
.5 .37823 L
.5 .37837 L
.5 .37864 L
.5 .3789 L
.5 .37918 L
.5 .37947 L
.5 .37997 L
.5 .38051 L
.5 .38163 L
.5 .38269 L
.5 .38468 L
Mistroke
.5 .38684 L
.5 .38914 L
.5 .39116 L
.5 .39231 L
.5 .39284 L
.5 .39339 L
.5 .39386 L
.5 .39411 L
.5 .39438 L
.5 .39463 L
.5 .39485 L
.5 .39507 L
.5 .39529 L
.5 .39553 L
.5 .39579 L
.5 .39602 L
.5 .39626 L
.5 .39653 L
.5 .39681 L
.5 .39733 L
.5 .39787 L
.5 .39845 L
.5 .39949 L
.5 .40185 L
.5 .40614 L
.5 .40834 L
.5 .40949 L
.5 .41013 L
.5 .41072 L
.5 .41128 L
.5 .41179 L
.5 .41206 L
.5 .41235 L
.5 .41252 L
.5 .41267 L
.5 .41281 L
.5 .41296 L
.5 .41321 L
.5 .41344 L
.5 .41371 L
.5 .41396 L
.5 .41421 L
.5 .41448 L
.5 .41476 L
.5 .41502 L
.5 .41559 L
.5 .41611 L
.5 .41728 L
.5 .4194 L
.5 .42337 L
Mistroke
.5 .42531 L
.5 .42738 L
.5 .42858 L
.5 .42966 L
.5 .43019 L
.5 .43046 L
.5 .43076 L
.5 .43101 L
.5 .43115 L
.5 .43129 L
.5 .43155 L
.5 .43179 L
.5 .43206 L
.5 .4323 L
.5 .43258 L
.5 .43285 L
.5 .43309 L
.5 .43332 L
.5 .43383 L
.5 .43435 L
.5 .43492 L
.5 .43607 L
.5 .43839 L
.5 .44057 L
.5 .44453 L
.5 .44561 L
.5 .44677 L
.5 .44786 L
.5 .44834 L
.5 .44885 L
.5 .44913 L
.5 .44943 L
.5 .44971 L
.5 .44997 L
.5 .45011 L
.5 .45027 L
.5 .45043 L
.5 .45059 L
.5 .45074 L
.5 .45089 L
.5 .45117 L
.5 .45143 L
.5 .45171 L
.5 .45197 L
.5 .45221 L
.5 .45277 L
.5 .45336 L
.5 .45442 L
.5 .45541 L
.5 .45765 L
Mistroke
.5 .46166 L
.5 .46376 L
.5 .46599 L
.5 .46712 L
.5 .46776 L
.5 .46837 L
.5 .46865 L
.5 .46892 L
.5 .46916 L
.5 .46942 L
.5 .4697 L
.5 .46996 L
.5 .47012 L
.5 .47027 L
.5 .47055 L
.5 .4708 L
.5 .47108 L
.5 .47136 L
.5 .47163 L
.5 .47211 L
.5 .47262 L
.5 .47379 L
.5 .47486 L
.5 .47894 L
.5 .48105 L
.5 .48338 L
.5 .48443 L
.5 .48556 L
.5 .48654 L
.5 .48761 L
.5 .4882 L
.5 .48875 L
.5 .48906 L
.5 .48933 L
.5 .48949 L
.5 .48965 L
.5 .48981 L
.5 .48995 L
.5 .49021 L
.5 .49045 L
.5 .49071 L
.5 .491 L
.5 .49129 L
.5 .49157 L
.5 .4921 L
.5 .49304 L
.5 .49409 L
.5 .4962 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomKooooo`;o0000oooooomBooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooG_ooool00ol0003oooooooooo`3ooooo
odkooooo003ooooooeoooooo0_l0003oooooodkooooo003oooooof7ooooo0_l0003oooooodcooooo
003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomTooooo`?o0000oooooom8
ooooo`00oooooomWooooo`?o0000oooooom5ooooo`00oooooomZooooo`Co0000oooooom1ooooo`00
oooooom^ooooo`?o0000oooooolnooooo`00oooooomaooooo`?o0000oooooolkooooo`00oooooomd
ooooo`Co0000oooooolgooooo`00oooooomhooooo`Go0000oooooolbooooo`00oooooommooooo`Co
0000ooooool^ooooo`00oooooon1ooooo`Co0000oooooolZooooo`00oooooon5ooooo`Go0000oooo
oolUooooo`00oooooon:ooooo`Co0000oooooolQooooo`00oooooon>ooooo`Go0000oooooolLoooo
o`00oooooonCooooo`Go0000oooooolGooooo`00oooooonHooooo`Ko0000oooooolAooooo`00oooo
oonNooooo`Ko0000ooooool;ooooo`00oooooonTooooo`Go0000ooooool6ooooo`00oooooonYoooo
o`Go0000ooooool1ooooo`00oooooon^ooooo`Co0000o?ooool00?oooooo/_ooool4o`000?Sooooo
003ooooookKooooo1?l0003dooooo`00oooooonjooooo`?o0000lOooool00?oooooo_Oooool3o`00
0>kooooo003ooooool3ooooo00?o0000ooooooooool0joooool00?oooooo`?ooool2o`000>cooooo
003ooooool7ooooo00?o0000ooooooooool0j_ooool00?oooooo`Oooool00ol0003oooooooooo`3Z
ooooo`00oooooonoooooo`;o0000kOooool00?oooooo_Oooool2o`000>oooooo003ooooook[ooooo
0ol0003aooooo`00oooooongooooo`?o0000m?ooool00?oooooo]?ooool3o`000?Oooooo003ooooo
ojoooooo1Ol0003jooooo`00oooooonZooooo`Go0000ooooool00?ooooooYOooool5o`000?oooooo
1Oooool00?ooooooX?ooool5o`000?oooooo2_ooool00?ooooooVoooool5o`000?oooooo3oooool0
0?ooooooU_ooool5o`000?oooooo5?ooool00?ooooooTOooool5o`000?oooooo6Oooool00?oooooo
S?ooool5o`000?oooooo7_ooool00?ooooooQoooool5o`000?oooooo8oooool00?ooooooP_ooool5
o`000?oooooo:?ooool00?ooooooOOooool5o`000?oooooo;Oooool00?ooooooMoooool6o`000?oo
oooo<_ooool00?ooooooLoooool4o`000?oooooo>?ooool00?ooooooL?ooool3o`000?oooooo??oo
ool00?ooooooKOooool3o`000?oooooo?oooool00?ooooooJOooool4o`000?oooooo@_ooool00?oo
ooooI_ooool3o`000?ooooooA_ooool00?ooooooHoooool3o`000?ooooooBOooool00?ooooooH_oo
ool00ol0003oooooooooo`3ooooood[ooooo003oooooof3ooooo0_l0003oooooodgooooo003ooooo
oeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomNooooo`03o`000?oooooooooo0?oo
ooooC_ooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooa_ooooo
0ol000000ol@413oooooooooo`3oooooohkooooo003ooooooagooooo00?o410@okZj^_ooool01_oo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooo
oomRooooo`00oooooolMooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooHoooool00?oooooo7Oooool00ooM
gMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj
00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7
o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0:ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003o
A4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooooacooooo003ooooooagooooo00?o
EEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`;oMgMg0_ooool01ol0003ooooooooo
ooooooooc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000oooo
ooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`06o`000?nYZJWooooooooooonj^[[o
00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@413ooooooacooooo003ooooooacooooo00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`00
0?oooooooooo00?ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolOooooo`00oooooolLooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0
003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooooooo
ooooool000002_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`00
0?oooooooooo0?oooooo7oooool00?oooooo6oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oM
gMgooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooolb<S;oQhN700_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000:ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooo
oacooooo003ooooooa_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0
003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4
A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo7?ooool00?oooooo9_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooollooooo`00oooooolV
ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0oooooollooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.812, 0}} -> {-3.22234, -1.53751*^-5, \
0.0117614, 0.0117614}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49997 0 m
.49999 .00099 L
.5 .00147 L
.5 .0017 L
.50001 .00192 L
.50001 .00217 L
.50001 .00245 L
.5 .00268 L
.5 .00293 L
.49999 .0032 L
.49999 .00345 L
.49999 .00372 L
.49999 .00388 L
.5 .00402 L
.5 .00452 L
.5 .00479 L
.50001 .00505 L
.50001 .0052 L
.50001 .00536 L
.50001 .00564 L
.50001 .00578 L
.5 .00593 L
.5 .00619 L
.5 .00666 L
.5 .00692 L
.5 .00717 L
.49999 .00731 L
.49999 .00746 L
.49999 .00773 L
.49999 .008 L
.5 .00825 L
.5 .00925 L
.5 .00952 L
.5 .00967 L
.5 .00981 L
.50001 .01006 L
.50001 .01032 L
.50001 .01048 L
.50001 .01062 L
.5 .0109 L
.5 .01105 L
.5 .01119 L
.5 .01151 L
.5 .01208 L
.5 .01236 L
.5 .01261 L
.5 .01288 L
.49999 .01313 L
.49999 .0134 L
.49999 .01355 L
Mistroke
.49999 .01369 L
.5 .01384 L
.5 .01399 L
.5 .01426 L
.5 .01487 L
.5 .01542 L
.5 .01573 L
.5 .01601 L
.5 .01616 L
.5 .01632 L
.50001 .0165 L
.50001 .01666 L
.50001 .0168 L
.50001 .01696 L
.5 .01711 L
.5 .01725 L
.5 .01819 L
.5 .01917 L
.5 .01942 L
.5 .01969 L
.5 .01984 L
.5 .01998 L
.5 .02025 L
.49999 .0205 L
.5 .02076 L
.5 .02101 L
.5 .02124 L
.5 .02152 L
.5 .02177 L
.5 .02235 L
.5 .02296 L
.5 .02352 L
.5 .02377 L
.5 .02404 L
.5 .0243 L
.5 .02454 L
.5 .0248 L
.5 .02508 L
.5 .02522 L
.5 .02537 L
.5 .02565 L
.5 .02672 L
.5 .0273 L
.5 .02786 L
.5 .02838 L
.5 .02852 L
.5 .02867 L
.5 .02894 L
.5 .02918 L
.5 .02941 L
Mistroke
.5 .02965 L
.5 .02992 L
.5 .0302 L
.5 .0305 L
.5 .03104 L
.5 .03207 L
.5 .03266 L
.5 .03299 L
.5 .03329 L
.5 .03358 L
.5 .03374 L
.5 .03389 L
.5 .03415 L
.5 .03443 L
.5 .03469 L
.5 .03483 L
.5 .03497 L
.5 .03522 L
.5 .03549 L
.5 .03594 L
.5 .03645 L
.5 .0375 L
.5 .03804 L
.5 .03834 L
.5 .03862 L
.5 .03889 L
.5 .03913 L
.5 .03939 L
.5 .03954 L
.5 .03968 L
.5 .03992 L
.5 .04014 L
.5 .04038 L
.5 .04064 L
.5 .04111 L
.5 .04155 L
.5 .04254 L
.5 .0436 L
.5 .04389 L
.5 .04421 L
.5 .0445 L
.5 .04476 L
.5 .04504 L
.5 .04518 L
.5 .04533 L
.5 .04559 L
.5 .04587 L
.5 .04612 L
.5 .04639 L
.5 .04664 L
Mistroke
.5 .04687 L
.5 .0488 L
.5 .0493 L
.5 .04985 L
.5 .05036 L
.5 .05061 L
.5 .05083 L
.5 .05108 L
.5 .05135 L
.5 .05159 L
.5 .05184 L
.5 .05199 L
.5 .05215 L
.5 .05229 L
.5 .05243 L
.5 .05269 L
.5 .05296 L
.5 .05389 L
.5 .05492 L
.5 .05603 L
.5 .05665 L
.5 .05694 L
.5 .05722 L
.5 .05747 L
.5 .05774 L
.5 .05802 L
.5 .05817 L
.5 .05832 L
.5 .05858 L
.5 .05882 L
.5 .05908 L
.5 .05936 L
.5 .06155 L
.5 .06263 L
.5 .0631 L
.5 .06362 L
.5 .06385 L
.5 .06409 L
.5 .0643 L
.5 .06452 L
.5 .06478 L
.5 .06502 L
.5 .06526 L
.5 .06548 L
.5 .06574 L
.5 .06599 L
.5 .06621 L
.5 .06646 L
.5 .06749 L
.5 .06953 L
Mistroke
.5 .07056 L
.5 .07084 L
.5 .07114 L
.5 .07142 L
.5 .07168 L
.5 .07183 L
.5 .07198 L
.5 .07214 L
.5 .07231 L
.5 .07245 L
.5 .07261 L
.5 .07276 L
.5 .0729 L
.5 .07316 L
.5 .07331 L
.5 .07344 L
.5 .07401 L
.5 .07455 L
.5 .07505 L
.5 .07615 L
.5 .07719 L
.5 .07776 L
.5 .07829 L
.5 .07874 L
.5 .07897 L
.5 .07923 L
.5 .0795 L
.5 .07977 L
.5 .08002 L
.5 .08026 L
.5 .08051 L
.5 .08078 L
.5 .08104 L
.5 .08128 L
.5 .08183 L
.5 .08241 L
.5 .0847 L
.5 .08575 L
.5 .08626 L
.5 .08673 L
.5 .08699 L
.5 .08728 L
.5 .08757 L
.5 .08773 L
.5 .08787 L
.5 .08813 L
.5 .08837 L
.5 .08865 L
.5 .08891 L
.5 .08916 L
Mistroke
.5 .08938 L
.5 .08988 L
.5 .09078 L
.5 .09283 L
.5 .09387 L
.5 .09444 L
.5 .09497 L
.5 .09542 L
.5 .09568 L
.5 .09591 L
.5 .09616 L
.5 .09644 L
.5 .0967 L
.5 .09694 L
.5 .0972 L
.5 .09747 L
.5 .09773 L
.5 .09797 L
.5 .09852 L
.5 .0991 L
.5 .10139 L
.5 .10244 L
.5 .10343 L
.5 .10398 L
.5 .10428 L
.5 .10457 L
.5 .10481 L
.5 .10507 L
.5 .10535 L
.5 .10561 L
.5 .10585 L
.5 .10611 L
.5 .10636 L
.5 .10659 L
.5 .10703 L
.5 .1075 L
.5 .10856 L
.5 .10953 L
.5 .11153 L
.5 .11254 L
.5 .11311 L
.5 .11337 L
.5 .11365 L
.5 .1138 L
.5 .11395 L
.5 .11408 L
.49999 .11423 L
.49999 .11449 L
.49999 .11477 L
.49999 .11492 L
Mistroke
.49999 .11507 L
.5 .11523 L
.5 .11539 L
.5 .11566 L
.5 .11597 L
.5 .1165 L
.5 .11707 L
.5 .1181 L
.5 .12029 L
.5 .12145 L
.5 .12208 L
.5 .12267 L
.5 .12293 L
.50001 .12318 L
.50001 .12332 L
.50001 .12347 L
.50001 .12373 L
.50001 .12388 L
.50001 .12403 L
.50001 .12419 L
.50001 .12434 L
.50001 .12462 L
.50001 .12477 L
.50001 .12491 L
.50001 .12516 L
.5 .12539 L
.5 .12591 L
.5 .12643 L
.5 .12697 L
.5 .12916 L
.5 .13031 L
.5 .13094 L
.5 .13153 L
.5 .13204 L
.5 .1323 L
.5 .13259 L
.5 .13276 L
.5 .13291 L
.5 .13306 L
.5 .1332 L
.5 .13348 L
.5 .13362 L
.5 .13376 L
.5 .13402 L
.5 .13428 L
.5 .13451 L
.5 .13476 L
.5 .13531 L
.5 .13583 L
.5 .1369 L
Mistroke
.5 .13806 L
.50001 .14018 L
.50002 .14414 L
.50003 .14615 L
.50004 .1473 L
.50004 .14837 L
.50006 .1495 L
.50007 .15053 L
.50009 .15167 L
.50011 .15286 L
.50014 .15393 L
.50018 .1549 L
.50022 .15595 L
.50029 .15708 L
.50036 .15813 L
.50044 .1591 L
.50064 .161 L
.50096 .16308 L
.50136 .16502 L
.50198 .16714 L
.50291 .16943 L
.50412 .17159 L
.50592 .17395 L
.5082 .17618 L
.51092 .17825 L
.51472 .18051 L
.51919 .18264 L
.5302 .18662 L
.54645 .19092 L
.56531 .19487 L
.61381 .20332 L
.63762 .20757 L
.65525 .21145 L
.65898 .21248 L
.66247 .21359 L
.665 .21456 L
.66723 .21562 L
.66814 .21617 L
.66893 .21675 L
.66929 .21708 L
.66957 .21737 L
.6698 .21767 L
.66997 .21795 L
.67008 .2182 L
.67017 .21848 L
.6702 .21863 L
.67021 .21878 L
.67021 .21905 L
.67017 .21931 L
.67009 .21955 L
Mistroke
.66998 .21982 L
.66981 .2201 L
.66936 .22064 L
.66878 .22115 L
.66729 .22212 L
.66514 .22316 L
.66217 .22429 L
.65527 .22632 L
.64733 .2282 L
.60077 .23659 L
.55541 .24465 L
.53703 .24878 L
.52923 .25091 L
.52201 .25323 L
.51198 .25751 L
.50807 .25985 L
.50526 .26202 L
.50304 .26427 L
.50148 .26639 L
.50044 .26829 L
.49998 .26936 L
.49963 .27036 L
.49908 .27238 L
.49886 .27345 L
.49869 .2746 L
.49862 .27518 L
.49856 .2758 L
.49851 .27636 L
.49847 .27695 L
.49843 .27753 L
.49841 .27806 L
.4984 .27832 L
.49839 .27859 L
.49839 .27885 L
.49838 .27909 L
.49838 .27936 L
.49838 .2796 L
.49838 .27986 L
.49837 .28001 L
.49837 .28015 L
.49837 .28037 L
.49838 .28062 L
.49838 .28088 L
.49838 .28113 L
.49838 .2814 L
.49839 .28169 L
.4984 .2822 L
.49844 .28336 L
.49853 .28551 L
.49865 .28786 L
Mistroke
.49916 .29653 L
.49954 .30488 L
.49969 .30945 L
.4998 .31375 L
.49984 .31584 L
.49988 .31804 L
.49992 .32198 L
.49994 .324 L
.49996 .32617 L
.49997 .32821 L
.49997 .33008 L
.49998 .33219 L
.49998 .33415 L
.49999 .33858 L
.49999 .34256 L
.5 .34486 L
.5 .34696 L
.5 .34897 L
.5 .34998 L
.5 .35109 L
.5 .35167 L
.5 .3522 L
.5 .35249 L
.5 .35281 L
.5 .35311 L
.5 .35339 L
.5 .35365 L
.5 .35389 L
.5 .35415 L
.5 .3543 L
.5 .35443 L
.5 .3547 L
.5 .35486 L
.5 .355 L
.5 .35554 L
.5 .35581 L
.5 .3561 L
.5 .35662 L
.5 .3578 L
.5 .35992 L
.5 .3639 L
.5 .36494 L
.5 .36592 L
.5 .36647 L
.5 .36706 L
.5 .3676 L
.5 .36784 L
.5 .36809 L
.5 .36834 L
.5 .36856 L
Mistroke
.5 .36877 L
.5 .369 L
.5 .36924 L
.5 .36947 L
.5 .36972 L
.5 .36999 L
.5 .37025 L
.5 .37054 L
.5 .37105 L
.5 .37155 L
.5 .37201 L
.5 .37408 L
.5 .37602 L
.5 .37828 L
.5 .38043 L
.5 .38143 L
.5 .3825 L
.5 .38312 L
.5 .38368 L
.5 .38424 L
.5 .38449 L
.5 .38476 L
.5 .385 L
.5 .38525 L
.5 .38551 L
.5 .38576 L
.5 .386 L
.5 .38623 L
.5 .38644 L
.5 .38667 L
.5 .38691 L
.5 .38719 L
.5 .38774 L
.5 .38824 L
.5 .38872 L
.5 .38978 L
.5 .39094 L
.5 .39304 L
.5 .397 L
.5 .39813 L
.5 .3992 L
.5 .40016 L
.5 .4007 L
.5 .4012 L
.5 .40174 L
.5 .40202 L
.5 .40218 L
.5 .40233 L
.5 .40249 L
.5 .40265 L
Mistroke
.5 .4028 L
.5 .40296 L
.5 .40323 L
.5 .40338 L
.5 .40353 L
.5 .40379 L
.5 .40407 L
.5 .40456 L
.5 .40509 L
.5 .40568 L
.5 .4068 L
.5 .40787 L
.5 .40986 L
.5 .41203 L
.5 .41433 L
.5 .41637 L
.5 .41692 L
.5 .41752 L
.5 .41804 L
.5 .41831 L
.5 .41861 L
.5 .41889 L
.5 .41915 L
.5 .41941 L
.5 .41966 L
.5 .41991 L
.5 .42014 L
.5 .4204 L
.5 .42066 L
.5 .42089 L
.5 .42113 L
.5 .42156 L
.5 .42208 L
.5 .42255 L
.5 .42357 L
.5 .42467 L
.5 .42663 L
.5 .42876 L
.5 .43106 L
.5 .43212 L
.5 .43324 L
.5 .43427 L
.5 .43477 L
.5 .43523 L
.5 .43566 L
.5 .43613 L
.5 .43639 L
.5 .43662 L
.5 .43685 L
.5 .43709 L
Mistroke
.5 .43733 L
.5 .43759 L
.5 .43784 L
.5 .43806 L
.5 .43833 L
.5 .43847 L
.5 .43861 L
.5 .43913 L
.5 .43965 L
.5 .44012 L
.5 .44118 L
.5 .44311 L
.5 .44751 L
.5 .44946 L
.5 .45053 L
.5 .45154 L
.5 .45211 L
.5 .45274 L
.5 .4533 L
.5 .45357 L
.5 .45383 L
.5 .45408 L
.5 .45432 L
.5 .45458 L
.5 .45486 L
.5 .45513 L
.5 .45528 L
.5 .45542 L
.5 .45568 L
.5 .45596 L
.5 .45622 L
.5 .45651 L
.5 .4571 L
.5 .45765 L
.5 .45816 L
.5 .46053 L
.5 .46484 L
.5 .46707 L
.5 .46817 L
.5 .46919 L
.5 .47011 L
.5 .47058 L
.5 .47108 L
.5 .47135 L
.5 .47159 L
.5 .47184 L
.5 .47207 L
.5 .47232 L
.5 .47259 L
.5 .47286 L
Mistroke
.5 .47301 L
.5 .47315 L
.5 .4734 L
.5 .47364 L
.5 .4739 L
.5 .47418 L
.5 .47476 L
.5 .47528 L
.5 .47629 L
.5 .47725 L
.5 .48169 L
.5 .4839 L
.5 .48598 L
.5 .48688 L
.5 .48784 L
.5 .48834 L
.5 .48889 L
.5 .48939 L
.5 .48986 L
.5 .49012 L
.5 .49027 L
.5 .4904 L
.5 .49065 L
.5 .49092 L
.5 .49116 L
.5 .49138 L
.5 .49163 L
.5 .49189 L
.5 .49215 L
.5 .49244 L
.5 .49303 L
.5 .49407 L
.5 .49519 L
.5 .49639 L
.5 .49855 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?oo
ooooG?ooool2o`000?ooooooDOooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo
003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomPooooo`?o0000oooooom<
ooooo`00oooooomSooooo`;o0000oooooom:ooooo`00oooooomUooooo`?o0000oooooom7ooooo`00
oooooomXooooo`;o0000oooooom5ooooo`00oooooomZooooo`Co0000oooooom1ooooo`00oooooom^
ooooo`Go0000oooooollooooo`00oooooomcooooo`Go0000oooooolgooooo`00oooooomhooooo`Co
0000oooooolcooooo`00oooooomlooooo`Co0000ooooool_ooooo`00oooooon0ooooo`Go0000oooo
oolZooooo`00oooooon5ooooo`Ko0000oooooolTooooo`00oooooon;ooooo`Oo0000oooooolMoooo
o`00oooooonBooooo`Ko0000oooooolGooooo`00oooooonHooooo`Ko0000oooooolAooooo`00oooo
oonNooooo`Ko0000ooooool;ooooo`00oooooonTooooo`Go0000ooooool6ooooo`00oooooonYoooo
o`Go0000ooooool1ooooo`00oooooon^ooooo`Go0000noooool00?oooooo/oooool5o`000?Kooooo
003ooooookSooooo1?l0003booooo`00oooooonlooooo`?o0000koooool00?oooooo_oooool3o`00
0>cooooo003ooooool;ooooo00?o0000ooooooooool0jOooool00?oooooo`oooool00ol0003ooooo
ooooo`3Xooooo`00ooooooo3ooooo`;o0000jOooool00?oooooo`oooool00ol0003oooooooooo`3X
ooooo`00ooooooo1ooooo`?o0000j_ooool00?oooooo_oooool2o`000>gooooo003ooooookcooooo
0ol0003_ooooo`00oooooonhooooo`Co0000l_ooool00?oooooo/_ooool6o`000?Kooooo003ooooo
ojcooooo1_l0003looooo`00oooooonVooooo`Ko0000ooooool3ooooo`00oooooonPooooo`Ko0000
ooooool9ooooo`00oooooonJooooo`Ko0000ooooool?ooooo`00oooooonEooooo`Go0000oooooolE
ooooo`00oooooon@ooooo`Go0000oooooolJooooo`00oooooon;ooooo`Go0000oooooolOooooo`00
oooooon6ooooo`Go0000oooooolTooooo`00oooooon1ooooo`Go0000oooooolYooooo`00ooooooml
ooooo`Go0000ooooool^ooooo`00oooooomgooooo`Go0000oooooolcooooo`00oooooombooooo`Go
0000oooooolhooooo`00oooooom^ooooo`Co0000oooooolmooooo`00oooooom[ooooo`?o0000oooo
oom1ooooo`00oooooomXooooo`?o0000oooooom4ooooo`00oooooomTooooo`Co0000oooooom7oooo
o`00oooooomRooooo`;o0000oooooom;ooooo`00oooooomPooooo`;o0000oooooom=ooooo`00oooo
oomNooooo`;o0000oooooom?ooooo`00oooooomLooooo`;o0000oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo003ooooooa;ooooo00?o
410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o
0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooK_ooool0
0?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo1Ol00003oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooo
oooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_oo
ool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooo
oa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`;o
MgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool01oooool01_l0
003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06
ofIVI_mgMgOooooooooooon7QhOo410@ooooool@ooooo`00oooooolAooooo`05omgMgOl@413ooooo
ob4Q8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`07ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo4oooool00?oooooo4Oooool01OmVIVKoQhN7oooooonHV9SoEEEE00Go
oooo00?o0000ooooooooool01?ooool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;o
oooo00Oooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003ooooo
ooooo`3ooooooa?ooooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooooa3ooooo003o
oooooa3ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003ooooooooo
o`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0
003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIV
o`000?l0003oA4A4o`000?oooooo4?ooool00?oooooo6oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000
ooooooooool0ooooool`ooooo`00oooooolKooooo`;o00004oooool00ol0003oooooooooo`04oooo
o`;o00003Oooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0003ooooooboooooo003ooooooooooooo[oooool0
0?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49999 0 m
.5 .00099 L
.5 .00122 L
.5 .00147 L
.5 .0017 L
.5 .00192 L
.5 .00217 L
.5 .00245 L
.5 .00268 L
.5 .00293 L
.5 .0032 L
.5 .00345 L
.5 .0036 L
.5 .00374 L
.5 .00402 L
.5 .00428 L
.5 .00452 L
.5 .00466 L
.5 .00481 L
.5 .00507 L
.5 .00531 L
.5 .00557 L
.5 .0058 L
.5 .00604 L
.5 .00632 L
.5 .00659 L
.5 .00674 L
.5 .0069 L
.5 .00718 L
.5 .00745 L
.5 .00759 L
.5 .00774 L
.5 .00825 L
.5 .00882 L
.5 .0091 L
.5 .00927 L
.5 .00942 L
.5 .00969 L
.5 .00993 L
.5 .01007 L
.5 .01022 L
.5 .01048 L
.5 .01109 L
.5 .01165 L
.5 .01194 L
.5 .0121 L
.5 .01224 L
.5 .0124 L
.5 .01258 L
.5 .01274 L
Mistroke
.5 .01289 L
.5 .01303 L
.5 .01319 L
.5 .01347 L
.5 .01399 L
.5 .01456 L
.5 .01487 L
.5 .01516 L
.5 .01541 L
.5 .01568 L
.5 .01583 L
.5 .01598 L
.5 .01625 L
.5 .0165 L
.5 .01673 L
.5 .01725 L
.5 .01824 L
.5 .01851 L
.5 .0188 L
.5 .01904 L
.5 .01931 L
.5 .01956 L
.5 .0198 L
.5 .02006 L
.5 .02031 L
.5 .02076 L
.5 .02124 L
.5 .02182 L
.5 .02236 L
.5 .02265 L
.5 .02292 L
.5 .02307 L
.5 .02322 L
.5 .02337 L
.5 .02354 L
.5 .02379 L
.5 .02407 L
.5 .02421 L
.5 .02436 L
.5 .02463 L
.5 .02565 L
.5 .02663 L
.5 .02692 L
.5 .02718 L
.5 .02743 L
.5 .02769 L
.5 .02783 L
.5 .02798 L
.5 .02814 L
.5 .02829 L
Mistroke
.5 .02856 L
.5 .02871 L
.5 .02884 L
.5 .0294 L
.5 .02992 L
.5 .03096 L
.5 .03124 L
.5 .03154 L
.5 .0318 L
.5 .03207 L
.5 .03223 L
.5 .03241 L
.5 .03257 L
.5 .03271 L
.5 .03299 L
.5 .03315 L
.5 .03329 L
.5 .03357 L
.5 .03387 L
.5 .03443 L
.5 .03547 L
.5 .03603 L
.5 .03661 L
.5 .03685 L
.5 .03712 L
.5 .03727 L
.5 .0374 L
.5 .03767 L
.5 .03791 L
.5 .03818 L
.5 .03842 L
.5 .03865 L
.5 .03891 L
.5 .03914 L
.5 .03969 L
.5 .04078 L
.5 .04191 L
.5 .04222 L
.5 .04255 L
.5 .04271 L
.5 .04286 L
.5 .04314 L
.5 .04341 L
.5 .04355 L
.5 .0437 L
.5 .04396 L
.5 .04421 L
.5 .04436 L
.5 .0445 L
.5 .04477 L
Mistroke
.5 .04536 L
.5 .04646 L
.5 .04747 L
.5 .04795 L
.5 .0484 L
.5 .04862 L
.5 .04886 L
.5 .04913 L
.5 .04937 L
.5 .04963 L
.5 .04988 L
.5 .05014 L
.5 .05029 L
.5 .05043 L
.5 .05095 L
.5 .05143 L
.5 .05352 L
.5 .05402 L
.5 .05457 L
.5 .05488 L
.5 .05516 L
.5 .0553 L
.5 .05545 L
.5 .05572 L
.5 .05596 L
.5 .05619 L
.5 .05644 L
.5 .05671 L
.5 .05698 L
.5 .05726 L
.5 .05777 L
.5 .05966 L
.5 .06017 L
.5 .06071 L
.5 .06119 L
.5 .06146 L
.5 .0617 L
.5 .06198 L
.5 .06213 L
.5 .06229 L
.5 .06244 L
.5 .06258 L
.5 .06284 L
.5 .0631 L
.5 .06334 L
.5 .0636 L
.5 .06388 L
.5 .06439 L
.5 .06494 L
.5 .06594 L
Mistroke
.5 .06684 L
.5 .0678 L
.5 .06835 L
.5 .06861 L
.5 .06885 L
.5 .06909 L
.5 .06936 L
.5 .06959 L
.5 .06983 L
.5 .0701 L
.5 .07025 L
.5 .07038 L
.5 .07063 L
.5 .07089 L
.5 .07145 L
.5 .07206 L
.5 .07328 L
.5 .07442 L
.5 .07545 L
.5 .07573 L
.5 .07603 L
.5 .07631 L
.5 .07657 L
.5 .07682 L
.5 .07706 L
.5 .07732 L
.5 .0776 L
.5 .07784 L
.5 .0781 L
.5 .07832 L
.5 .07856 L
.5 .07911 L
.5 .0797 L
.5 .08076 L
.5 .0819 L
.5 .08252 L
.5 .08309 L
.5 .08359 L
.5 .08384 L
.5 .08412 L
.5 .08427 L
.5 .08442 L
.5 .08455 L
.5 .0847 L
.5 .08496 L
.5 .08524 L
.5 .08551 L
.5 .08577 L
.5 .08605 L
.5 .08635 L
Mistroke
.5 .0869 L
.5 .0874 L
.5 .08938 L
.5 .09049 L
.5 .09107 L
.5 .09168 L
.5 .09222 L
.5 .09236 L
.5 .09252 L
.5 .09266 L
.5 .09281 L
.5 .09308 L
.5 .09335 L
.5 .0936 L
.5 .09384 L
.5 .09409 L
.5 .09436 L
.5 .09483 L
.5 .09534 L
.5 .0959 L
.5 .09783 L
.5 .09893 L
.5 .09954 L
.5 .10011 L
.5 .10064 L
.5 .10094 L
.5 .10122 L
.5 .10145 L
.5 .10171 L
.5 .10198 L
.5 .10223 L
.5 .1025 L
.5 .10265 L
.5 .10278 L
.5 .10329 L
.5 .10358 L
.5 .10389 L
.5 .10445 L
.5 .10656 L
.5 .10757 L
.5 .10811 L
.5 .10863 L
.5 .10906 L
.5 .10929 L
.5 .10953 L
.5 .1098 L
.5 .11005 L
.5 .11029 L
.5 .11052 L
.5 .11079 L
Mistroke
.5 .11104 L
.5 .11127 L
.5 .11151 L
.5 .11207 L
.5 .11258 L
.5 .11352 L
.5 .11452 L
.50001 .11683 L
.50001 .11892 L
.50002 .11996 L
.50002 .12106 L
.50002 .12201 L
.50003 .12303 L
.50004 .12412 L
.50005 .12514 L
.50006 .12636 L
.50008 .12747 L
.50011 .1285 L
.50014 .12959 L
.50018 .13052 L
.50023 .13154 L
.50029 .13264 L
.50038 .13383 L
.50049 .13494 L
.50061 .13598 L
.50094 .13802 L
.50117 .1391 L
.50147 .14025 L
.50185 .14146 L
.50229 .14261 L
.50337 .14476 L
.50482 .14683 L
.5069 .14903 L
.50924 .1509 L
.51254 .15297 L
.51697 .15513 L
.52201 .15711 L
.53734 .16158 L
.55643 .16563 L
.5823 .17006 L
.61212 .17462 L
.63845 .17875 L
.65014 .18082 L
.66088 .18305 L
.665 .18408 L
.66873 .18517 L
.67154 .18617 L
.67364 .18711 L
.67453 .18762 L
.6753 .18817 L
Mistroke
.67558 .18841 L
.67583 .18867 L
.67603 .18891 L
.67618 .18914 L
.6763 .18939 L
.67639 .18967 L
.67642 .18991 L
.67642 .19017 L
.67636 .19045 L
.67625 .19071 L
.67617 .19086 L
.67608 .191 L
.67585 .19131 L
.67532 .19181 L
.67468 .19228 L
.67273 .19332 L
.67043 .19425 L
.66744 .19522 L
.65956 .19724 L
.6489 .19941 L
.62551 .20332 L
.5683 .21214 L
.54451 .21655 L
.52747 .22064 L
.51555 .2246 L
.51063 .22681 L
.5071 .22881 L
.50414 .23096 L
.50204 .23294 L
.5003 .2351 L
.49898 .23739 L
.49813 .23942 L
.49777 .24054 L
.49749 .24159 L
.49727 .24258 L
.49707 .24365 L
.4968 .24551 L
.49669 .24655 L
.4966 .24753 L
.49652 .24869 L
.49646 .24975 L
.49641 .25086 L
.49638 .25191 L
.49635 .25303 L
.49632 .25424 L
.49631 .25537 L
.4963 .25644 L
.49629 .2574 L
.49628 .25844 L
.49628 .25898 L
Mistroke
.49628 .25957 L
.49628 .26019 L
.49627 .26049 L
.49627 .26077 L
.49627 .26103 L
.49627 .26131 L
.49627 .26157 L
.49627 .26181 L
.49627 .26206 L
.49627 .26221 L
.49627 .26235 L
.49627 .26262 L
.49627 .26278 L
.49627 .26292 L
.49627 .26319 L
.49627 .26345 L
.49627 .26368 L
.49627 .26393 L
.49627 .26449 L
.49628 .26501 L
.49628 .26596 L
.49628 .26696 L
.49629 .26906 L
.4963 .27026 L
.49631 .27138 L
.49633 .2736 L
.49636 .27571 L
.49642 .27967 L
.4965 .28391 L
.4966 .28784 L
.4969 .2962 L
.49713 .30078 L
.49738 .30509 L
.49793 .31334 L
.49854 .3221 L
.49906 .33055 L
.49946 .33867 L
.49962 .34284 L
.49974 .34731 L
.49979 .34949 L
.49983 .35185 L
.49986 .3539 L
.49989 .35615 L
.49993 .36038 L
.49995 .3627 L
.49996 .36487 L
.49998 .36919 L
.49999 .37314 L
.49999 .37524 L
.5 .37719 L
Mistroke
.5 .37831 L
.5 .37933 L
.5 .3799 L
.5 .38051 L
.5 .38104 L
.5 .38162 L
.5 .3819 L
.5 .38216 L
.5 .38242 L
.5 .38266 L
.5 .38289 L
.5 .38313 L
.5 .38337 L
.5 .38364 L
.5 .38378 L
.5 .38393 L
.5 .38419 L
.5 .38434 L
.5 .38448 L
.5 .38479 L
.5 .38531 L
.5 .38587 L
.5 .38708 L
.5 .38822 L
.5 .39037 L
.5 .39244 L
.5 .39357 L
.5 .39463 L
.5 .39554 L
.5 .39604 L
.5 .39651 L
.5 .39677 L
.5 .39701 L
.5 .39728 L
.5 .39743 L
.5 .39757 L
.5 .39782 L
.5 .39808 L
.5 .39834 L
.5 .39857 L
.5 .3991 L
.5 .39958 L
.5 .40065 L
.5 .40165 L
.5 .40259 L
.5 .40701 L
.5 .40907 L
.5 .4102 L
.5 .41126 L
.5 .41224 L
Mistroke
.5 .41313 L
.5 .41362 L
.5 .41413 L
.5 .41439 L
.5 .41464 L
.5 .41491 L
.5 .41506 L
.5 .4152 L
.5 .41545 L
.5 .41569 L
.5 .41595 L
.5 .41623 L
.5 .41637 L
.5 .41653 L
.5 .41681 L
.5 .41733 L
.5 .41782 L
.5 .41835 L
.5 .4193 L
.5 .42163 L
.5 .42374 L
.5 .42591 L
.5 .42821 L
.5 .42915 L
.5 .43016 L
.5 .43075 L
.5 .43128 L
.5 .43177 L
.5 .43205 L
.5 .43231 L
.5 .43258 L
.5 .43282 L
.5 .43308 L
.5 .43337 L
.5 .43361 L
.5 .43387 L
.5 .43411 L
.5 .43434 L
.5 .43463 L
.5 .4349 L
.5 .43541 L
.5 .43596 L
.5 .43655 L
.5 .43864 L
.5 .44056 L
.5 .44492 L
.5 .44704 L
.5 .44805 L
.5 .44899 L
.5 .44995 L
Mistroke
.5 .45046 L
.5 .45071 L
.5 .45099 L
.5 .45124 L
.5 .45146 L
.5 .45167 L
.5 .4519 L
.5 .45215 L
.5 .45238 L
.5 .45263 L
.5 .4529 L
.5 .45318 L
.5 .45344 L
.5 .45403 L
.5 .45455 L
.5 .45509 L
.5 .45709 L
.5 .45911 L
.5 .46127 L
.5 .46518 L
.5 .46623 L
.5 .46734 L
.5 .46798 L
.5 .46856 L
.5 .46915 L
.5 .46941 L
.5 .4697 L
.5 .46995 L
.5 .47022 L
.5 .47037 L
.5 .47051 L
.5 .47077 L
.5 .47102 L
.5 .47128 L
.5 .47153 L
.5 .47176 L
.5 .47203 L
.5 .47228 L
.5 .47284 L
.5 .4734 L
.5 .47399 L
.5 .47604 L
.5 .47828 L
.5 .48278 L
.5 .48494 L
.5 .486 L
.5 .48698 L
.5 .48751 L
.5 .4881 L
.5 .4887 L
Mistroke
.5 .48902 L
.5 .48932 L
.5 .4896 L
.5 .48986 L
.5 .4901 L
.5 .49035 L
.5 .49063 L
.5 .49077 L
.5 .49092 L
.5 .4912 L
.5 .49145 L
.5 .49197 L
.5 .49245 L
.5 .49355 L
.5 .49462 L
.5 .49576 L
.5 .49971 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe_ooooo0_l0003ooooooe;ooooo003ooooo
oegooooo0_l0003ooooooe3ooooo003ooooooeoooooo0_l0003oooooodkooooo003oooooof7ooooo
00?o0000ooooooooool0oooooom;ooooo`00oooooomRooooo`?o0000oooooom:ooooo`00oooooomU
ooooo`?o0000oooooom7ooooo`00oooooomXooooo`?o0000oooooom4ooooo`00oooooom[ooooo`?o
0000oooooom1ooooo`00oooooom^ooooo`Go0000oooooollooooo`00oooooomcooooo`Ko0000oooo
oolfooooo`00oooooomiooooo`Ko0000ooooool`ooooo`00oooooomoooooo`Go0000ooooool[oooo
o`00oooooon4ooooo`Go0000oooooolVooooo`00oooooon9ooooo`Ko0000oooooolPooooo`00oooo
oon?ooooo`Oo0000oooooolIooooo`00oooooonFooooo`Ko0000oooooolCooooo`00oooooonLoooo
o`Ko0000ooooool=ooooo`00oooooonRooooo`Ko0000ooooool7ooooo`00oooooonXooooo`Go0000
ooooool2ooooo`00oooooon]ooooo`Oo0000n_ooool00?oooooo]?ooool8o`000?;ooooo003ooooo
okcooooo1?l0003^ooooo`00ooooooo0ooooo`?o0000joooool00?oooooo`oooool3o`000>Sooooo
003oooooolKooooo00?o0000ooooooooool0iOooool00?ooooooaoooool00ol0003oooooooooo`3T
ooooo`00ooooooo7ooooo`;o0000iOooool00?ooooooa_ooool2o`000>Kooooo003ooooool?ooooo
0ol0003Xooooo`00ooooooo0ooooo`?o0000joooool00?oooooo^oooool5o`000>kooooo003ooooo
okSooooo0ol0003cooooo`00oooooonbooooo`Ko0000m_ooool00?ooooooZoooool7o`000?cooooo
003oooooojCooooo1ol0003oooooo`Cooooo003ooooooikooooo1_l0003oooooo`_ooooo003ooooo
oiSooooo1_l0003ooooooa7ooooo003ooooooi;ooooo1_l0003ooooooaOooooo003oooooohcooooo
1_l0003ooooooagooooo003oooooohKooooo1_l0003oooooob?ooooo003ooooooh3ooooo1_l0003o
ooooobWooooo003oooooog_ooooo1Ol0003ooooooboooooo003oooooogKooooo1Ol0003oooooocCo
oooo003oooooog3ooooo1_l0003oooooocWooooo003oooooof_ooooo1Ol0003oooooocoooooo003o
ooooofOooooo1?l0003oooooodCooooo003oooooofCooooo0ol0003oooooodSooooo003oooooof;o
oooo0_l0003ooooood_ooooo003oooooof3ooooo0_l0003oooooodgooooo003ooooooegooooo0ol0
003oooooodoooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFOooool2o`000?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo
[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00oooooolCooooo`?o000000?o410@ooooooooool0oooooonFooooo`00oooo
oolEooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
0005ooooo`03o`000?nj^[[ooooo0?ooooooJ_ooool00?oooooo5Oooool00onHV9So<S8booooo`07
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S;o
ooooof_ooooo003ooooooaGooooo00?ogMgMo`000?nj^[X01oooool01?l0003oooooooooooooool5
o`0000Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o
0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooooooo
ool01_ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4
A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0oooooolDooooo`00oooooolEooooo`03oeEE
EOmgMgOoA4A400Oooooo00Co0000oooooooooooooooo0_mgMgL2ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooooooo
o`08ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooaCooooo003ooooooaCooooo00Go
gMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEEoiRHV?ooool0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
6_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool02Oooool01Onj^[[o
QhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
oaOooooo003ooooooaCooooo00GoIVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo
00?ooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00Sooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko0000
0_ooool00ol0003oooooooooo`3ooooooaOooooo003ooooooa?ooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00olb<S;oQhN7
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`08ooooo`06
o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo
00KoIVIVogMgMoooooooooooohN7Qol0003ooooooaCooooo003ooooooa?ooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003
o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Sooooo00Ko
ZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool0
1_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?ooool00?oooooo7oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3ooooooc;ooooo
003ooooooaoooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oo
oooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo00000?oooooo
=?ooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00001
\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50003 0 m
.50001 .00099 L
.5 .00147 L
.5 .0017 L
.49999 .00192 L
.49999 .00217 L
.5 .00245 L
.5 .00268 L
.5 .00293 L
.5 .0032 L
.50001 .00345 L
.50001 .00372 L
.50001 .00388 L
.5 .00402 L
.5 .00452 L
.5 .00479 L
.5 .00505 L
.49999 .0052 L
.49999 .00536 L
.49999 .00564 L
.49999 .00578 L
.5 .00593 L
.5 .00619 L
.5 .00666 L
.5 .00692 L
.5 .00717 L
.5 .00731 L
.5 .00746 L
.50001 .00773 L
.50001 .008 L
.5 .00825 L
.5 .00852 L
.5 .00877 L
.5 .00932 L
.5 .00957 L
.5 .00981 L
.5 .01006 L
.5 .01032 L
.5 .01047 L
.5 .01062 L
.5 .0109 L
.5 .01118 L
.5 .01143 L
.5 .01204 L
.5 .01234 L
.5 .01261 L
.5 .01286 L
.5 .01313 L
.5 .01328 L
.5 .01342 L
Mistroke
.5 .01369 L
.5 .01384 L
.5 .01399 L
.5 .01426 L
.5 .01441 L
.5 .01455 L
.5 .01487 L
.5 .01546 L
.5 .01602 L
.5 .01633 L
.5 .0165 L
.5 .01666 L
.5 .0168 L
.5 .01695 L
.5 .0171 L
.5 .01725 L
.5 .0175 L
.5 .01777 L
.5 .018 L
.5 .01825 L
.5 .01933 L
.5 .01982 L
.5 .02009 L
.5 .02034 L
.5 .02058 L
.5 .02083 L
.5 .02106 L
.5 .02128 L
.5 .02153 L
.5 .02181 L
.5 .02206 L
.5 .0223 L
.5 .02342 L
.5 .02398 L
.5 .02428 L
.5 .02444 L
.5 .02459 L
.5 .02486 L
.5 .02501 L
.5 .02516 L
.5 .02544 L
.5 .02569 L
.5 .02597 L
.5 .02622 L
.5 .0267 L
.5 .02778 L
.5 .02827 L
.5 .02873 L
.5 .02898 L
.5 .02921 L
Mistroke
.5 .02946 L
.5 .02973 L
.5 .03 L
.5 .03015 L
.5 .03029 L
.5 .03055 L
.5 .03083 L
.5 .03111 L
.5 .03137 L
.5 .03185 L
.5 .03295 L
.5 .03353 L
.5 .03385 L
.5 .03415 L
.5 .03442 L
.5 .03457 L
.5 .03471 L
.5 .03496 L
.5 .03523 L
.5 .03548 L
.5 .03571 L
.5 .03596 L
.5 .03624 L
.5 .0368 L
.5 .03739 L
.5 .03844 L
.5 .03891 L
.5 .03917 L
.5 .03942 L
.5 .03964 L
.5 .03989 L
.5 .04012 L
.5 .04032 L
.5 .04057 L
.5 .0408 L
.5 .04105 L
.5 .04133 L
.5 .04146 L
.5 .04161 L
.5 .04188 L
.5 .04239 L
.5 .04343 L
.5 .04398 L
.5 .04456 L
.5 .04506 L
.5 .04533 L
.5 .04562 L
.5 .04589 L
.5 .04613 L
.5 .04637 L
Mistroke
.5 .0466 L
.5 .04673 L
.5 .04688 L
.5 .04704 L
.5 .04718 L
.5 .04745 L
.5 .04773 L
.5 .04837 L
.5 .04895 L
.5 .04998 L
.5 .05108 L
.5 .05135 L
.5 .05165 L
.5 .05193 L
.5 .05218 L
.5 .05241 L
.5 .05267 L
.5 .05293 L
.5 .05318 L
.5 .05344 L
.5 .05367 L
.5 .05412 L
.5 .05461 L
.5 .05513 L
.5 .05615 L
.5 .05724 L
.5 .05786 L
.5 .05813 L
.5 .05843 L
.5 .05857 L
.5 .05872 L
.5 .05898 L
.5 .05914 L
.5 .05928 L
.5 .05956 L
.5 .0598 L
.5 .06007 L
.5 .06035 L
.5 .06061 L
.5 .06108 L
.5 .06158 L
.5 .06378 L
.5 .06435 L
.5 .06466 L
.5 .06498 L
.5 .06529 L
.5 .06557 L
.5 .06571 L
.5 .06586 L
.50001 .06612 L
Mistroke
.50001 .06638 L
.50001 .06653 L
.50001 .06667 L
.5 .06694 L
.5 .0671 L
.5 .06724 L
.5 .06749 L
.5 .06777 L
.5 .06827 L
.5 .07045 L
.5 .07152 L
.5 .07198 L
.5 .07249 L
.5 .07274 L
.5 .073 L
.49999 .07327 L
.49999 .07352 L
.49999 .07367 L
.49999 .07382 L
.49999 .0741 L
.49999 .07438 L
.49999 .07463 L
.5 .07491 L
.5 .07517 L
.5 .07577 L
.5 .07698 L
.5 .07805 L
.5 .07921 L
.5 .07974 L
.5 .08031 L
.50001 .08054 L
.50001 .08079 L
.50001 .08106 L
.50001 .08132 L
.50001 .08157 L
.50001 .0818 L
.50001 .08206 L
.50001 .08233 L
.50001 .08246 L
.50001 .08261 L
.50001 .08288 L
.5 .08339 L
.5 .08437 L
.5 .08528 L
.5 .08721 L
.5 .08777 L
.5 .08829 L
.5 .08852 L
.5 .08877 L
.49999 .08903 L
Mistroke
.49999 .08928 L
.49999 .08944 L
.49999 .08958 L
.49999 .08973 L
.49999 .0899 L
.49999 .09017 L
.49999 .09033 L
.49999 .09048 L
.5 .09075 L
.5 .091 L
.5 .09156 L
.5 .09208 L
.5 .09265 L
.5 .09369 L
.50002 .09791 L
.50002 .10005 L
.50003 .10126 L
.50004 .1024 L
.50005 .1034 L
.50006 .1045 L
.50007 .10505 L
.50008 .10565 L
.50011 .10671 L
.50015 .10778 L
.5002 .10878 L
.50026 .10968 L
.50033 .11066 L
.50054 .11269 L
.50071 .11383 L
.50091 .11491 L
.50145 .11708 L
.50187 .11829 L
.50235 .1194 L
.50356 .12151 L
.50513 .12347 L
.5075 .12561 L
.51099 .1279 L
.51551 .1301 L
.52194 .13248 L
.53837 .13679 L
.56127 .14106 L
.59167 .14556 L
.65013 .15368 L
.66272 .15583 L
.67229 .15786 L
.67642 .15898 L
.67823 .15957 L
.67986 .1602 L
.681 .16072 L
.682 .1613 L
Mistroke
.68235 .16156 L
.68267 .16183 L
.68292 .16209 L
.6831 .16233 L
.68318 .16246 L
.68326 .16261 L
.68334 .16287 L
.68336 .16301 L
.68337 .16317 L
.68333 .16344 L
.68325 .1637 L
.68311 .16394 L
.68292 .1642 L
.68264 .16448 L
.68179 .16511 L
.6807 .16571 L
.6779 .16684 L
.67437 .1679 L
.67039 .16889 L
.65916 .17113 L
.60095 .17951 L
.54777 .18756 L
.52844 .19169 L
.52019 .19401 L
.51413 .19614 L
.50972 .19809 L
.50602 .20018 L
.50298 .20247 L
.50091 .2046 L
.49938 .20678 L
.49873 .20802 L
.49823 .20915 L
.49755 .21124 L
.49729 .2123 L
.49706 .21346 L
.49689 .21457 L
.49675 .21562 L
.49657 .21761 L
.4965 .21871 L
.49645 .21974 L
.4964 .22087 L
.49637 .22207 L
.49634 .22321 L
.49632 .22427 L
.49631 .22542 L
.4963 .22664 L
.49629 .22771 L
.49629 .2287 L
.49628 .22978 L
.49628 .23095 L
Mistroke
.49627 .23211 L
.49627 .23319 L
.49627 .23421 L
.49627 .23474 L
.49627 .2353 L
.49627 .23581 L
.49627 .23628 L
.49627 .23672 L
.49627 .23694 L
.49627 .23719 L
.49627 .23746 L
.49627 .23771 L
.49627 .23785 L
.49627 .238 L
.49627 .23827 L
.49627 .23852 L
.49627 .23879 L
.49627 .23902 L
.49627 .23927 L
.49627 .2398 L
.49627 .24038 L
.49627 .24144 L
.49627 .24343 L
.49629 .24789 L
.49629 .25006 L
.4963 .2521 L
.4963 .25323 L
.4963 .25446 L
.4963 .255 L
.4963 .25557 L
.4963 .25606 L
.4963 .25659 L
.4963 .25687 L
.4963 .25713 L
.4963 .25738 L
.4963 .25765 L
.4963 .25788 L
.4963 .25812 L
.4963 .25838 L
.4963 .25862 L
.4963 .2589 L
.4963 .25905 L
.4963 .2592 L
.4963 .25947 L
.4963 .25962 L
.4963 .25975 L
.4963 .26029 L
.4963 .26079 L
.4963 .26127 L
.4963 .26153 L
Mistroke
.4963 .26177 L
.4963 .26198 L
.4963 .2622 L
.4963 .26245 L
.4963 .26268 L
.4963 .26294 L
.4963 .26318 L
.4963 .26344 L
.4963 .26372 L
.4963 .26419 L
.4963 .26471 L
.4963 .26521 L
.4963 .26576 L
.49631 .26687 L
.49631 .26789 L
.49631 .26884 L
.49631 .271 L
.49632 .2733 L
.49633 .27755 L
.49633 .27979 L
.49634 .28216 L
.49634 .28427 L
.49635 .2866 L
.49635 .2907 L
.49635 .29287 L
.49636 .29485 L
.49637 .29714 L
.49638 .29931 L
.4964 .30355 L
.49644 .30748 L
.49649 .31187 L
.49654 .31584 L
.49662 .31996 L
.49673 .32441 L
.49686 .32868 L
.49704 .33318 L
.49745 .3413 L
.49798 .34994 L
.4985 .35826 L
.49903 .3671 L
.49925 .37153 L
.49943 .37562 L
.49958 .37985 L
.4997 .38382 L
.49978 .38781 L
.49985 .39221 L
.4999 .39653 L
.49994 .40048 L
.49996 .40453 L
.49997 .40683 L
Mistroke
.49998 .40896 L
.49999 .41121 L
.49999 .41232 L
.49999 .41333 L
.49999 .41524 L
.5 .41624 L
.5 .41731 L
.5 .41785 L
.5 .41836 L
.5 .41883 L
.5 .41933 L
.5 .41958 L
.5 .41986 L
.5 .42012 L
.5 .42036 L
.5 .42064 L
.5 .42079 L
.5 .42095 L
.5 .42121 L
.5 .42136 L
.5 .42149 L
.5 .42174 L
.5 .422 L
.5 .42225 L
.5 .42248 L
.5 .42292 L
.5 .42338 L
.5 .42541 L
.5 .42742 L
.5 .42853 L
.5 .42907 L
.5 .42958 L
.5 .43005 L
.5 .4303 L
.5 .43056 L
.5 .43071 L
.5 .43085 L
.5 .43112 L
.5 .43136 L
.5 .43162 L
.5 .43185 L
.5 .43208 L
.5 .43231 L
.5 .43251 L
.5 .43301 L
.5 .43349 L
.5 .43447 L
.5 .43555 L
.5 .43774 L
.5 .44168 L
Mistroke
.5 .44386 L
.5 .44616 L
.5 .44711 L
.5 .44812 L
.5 .44871 L
.5 .44923 L
.5 .44977 L
.5 .45003 L
.5 .45027 L
.5 .45052 L
.5 .45075 L
.5 .451 L
.5 .45127 L
.5 .45153 L
.5 .45168 L
.5 .45182 L
.5 .45207 L
.5 .45233 L
.5 .45258 L
.5 .45285 L
.5 .45333 L
.5 .45423 L
.5 .45533 L
.5 .45648 L
.5 .45853 L
.5 .46279 L
.5 .46464 L
.5 .46666 L
.5 .4672 L
.5 .46777 L
.5 .46831 L
.5 .4688 L
.5 .46927 L
.5 .46953 L
.5 .46977 L
.5 .47003 L
.5 .47018 L
.5 .47032 L
.5 .47057 L
.5 .47083 L
.5 .47098 L
.5 .47114 L
.5 .47141 L
.5 .47171 L
.5 .47204 L
.5 .47263 L
.5 .47318 L
.5 .4742 L
.5 .4753 L
.5 .47984 L
Mistroke
.5 .48192 L
.5 .48413 L
.5 .48615 L
.5 .48671 L
.5 .4873 L
.5 .48782 L
.5 .48838 L
.5 .48863 L
.5 .4889 L
.5 .48913 L
.5 .48938 L
.5 .48953 L
.5 .48967 L
.5 .48993 L
.5 .49018 L
.5 .49043 L
.5 .49066 L
.5 .4909 L
.5 .49112 L
.5 .49133 L
.5 .49184 L
.5 .49232 L
.5 .49333 L
.5 .49425 L
.5 .4963 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooecooooo0_l0003ooooooe7ooooo003ooooooekooooo0_l0003ooooo
odoooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomQooooo`?o0000
oooooom;ooooo`00oooooomTooooo`Co0000oooooom7ooooo`00oooooomXooooo`?o0000oooooom4
ooooo`00oooooom[ooooo`?o0000oooooom1ooooo`00oooooom^ooooo`Go0000oooooollooooo`00
oooooomcooooo`Go0000oooooolgooooo`00oooooomhooooo`Go0000oooooolbooooo`00oooooomm
ooooo`Oo0000ooooool[ooooo`00oooooon4ooooo`Wo0000oooooolRooooo`00oooooon=ooooo`So
0000oooooolJooooo`00oooooonEooooo`Oo0000oooooolCooooo`00oooooonLooooo`Ko0000oooo
ool=ooooo`00oooooonRooooo`Ko0000ooooool7ooooo`00oooooonXooooo`Oo0000ooooool00?oo
oooo[oooool6o`000?Wooooo003ooooookGooooo1ol0003booooo`00oooooonlooooo`Oo0000jooo
ool00?oooooo`oooool5o`000>Kooooo003oooooolSooooo0_l0003Tooooo`00ooooooo:ooooo`;o
0000h_ooool00?ooooooboooool2o`000>7ooooo003ooooool_ooooo0_l0003Qooooo`00ooooooo9
ooooo`?o0000h_ooool00?ooooooaoooool2o`000>Gooooo003ooooool;ooooo1Ol0003Wooooo`00
oooooonoooooo`?o0000k?ooool00?oooooo^Oooool6o`000>oooooo003ooooook;ooooo1ol0003e
ooooo`00oooooonZooooo`So0000o?ooool00?ooooooX_ooool8o`000?oooooo1Oooool00?oooooo
Voooool7o`000?oooooo3Oooool00?ooooooU?ooool7o`000?oooooo5?ooool00?ooooooSOooool7
o`000?oooooo6oooool00?ooooooQ_ooool7o`000?oooooo8_ooool00?ooooooOoooool7o`000?oo
oooo:Oooool00?ooooooN?ooool7o`000?oooooo<?ooool00?ooooooLoooool5o`000?oooooo=ooo
ool00?ooooooKoooool4o`000?oooooo??ooool00?ooooooJoooool4o`000?oooooo@?ooool00?oo
ooooIoooool4o`000?ooooooA?ooool00?ooooooHoooool4o`000?ooooooB?ooool00?ooooooHOoo
ool2o`000?ooooooC?ooool00?ooooooGoooool2o`000?ooooooC_ooool00?ooooooG?ooool3o`00
0?ooooooD?ooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00ooooool@ooooo`?o000000?o410@ooooooooool0
oooooonIooooo`00oooooolBooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooKOooool00?oooooo4_ooool0
0onHV9So<S8booooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00Cooooo0_lb<S;oooooofkooooo003ooooooa;ooooo00?ogMgMo`000?nj^[X01_ooool00ol0
003oooooooooo`02ooooo`Go00000oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool01oooool01_l@413o
<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIV
I_l0003o0000odA4A?o<c<`0ooooool@ooooo`00oooooolBooooo`03oeEEEOmgMgOoA4A400Kooooo
00?o0000ooooooooool00_ooool2ogMgM`;ooooo00Oo0000ooooooooooooooooolc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8b
ooooo`07ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooa3ooooo003ooooooa7ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?oo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo4oooool00?oooooo4Oooool01OmVIVKoQhN7oooooonHV9So
EEEE00Gooooo00?o0000ooooooooool01?ooool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool0
1Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`07ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000oooooooo
ool0oooooolCooooo`00ooooool@ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0
0oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooc8b<_n7QhL02oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo4?ooool00?oooooo4?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool5o`0000Wooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o
410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002oooo
o`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oo
oooo4?ooool00?oooooo6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo<?ooool00?oooooo
6oooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`000?oo
oooo;oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool0
0001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50004 0 m
.50001 .00099 L
.5 .00147 L
.49999 .0017 L
.49999 .00192 L
.49999 .00217 L
.49999 .00245 L
.5 .00268 L
.5 .00293 L
.50001 .0032 L
.50001 .00345 L
.50001 .00372 L
.50001 .00388 L
.50001 .00402 L
.5 .00452 L
.49999 .00479 L
.49999 .00505 L
.49999 .0052 L
.49999 .00536 L
.49999 .00564 L
.49999 .00578 L
.49999 .00593 L
.5 .00619 L
.5 .00666 L
.5 .00692 L
.50001 .00717 L
.50001 .00731 L
.50001 .00746 L
.50001 .00773 L
.50001 .008 L
.50001 .00825 L
.5 .00925 L
.5 .00952 L
.49999 .00967 L
.49999 .00981 L
.49999 .01006 L
.49999 .01032 L
.49999 .01048 L
.49999 .01062 L
.49999 .0109 L
.49999 .01105 L
.5 .01119 L
.5 .01151 L
.5 .01208 L
.5 .01236 L
.50001 .01261 L
.50001 .01288 L
.50001 .01313 L
.50001 .0134 L
.50001 .01355 L
Mistroke
.50001 .01369 L
.50001 .01384 L
.50001 .01399 L
.50001 .01426 L
.5 .01487 L
.5 .01542 L
.5 .01573 L
.49999 .01601 L
.49999 .01617 L
.49999 .01632 L
.49999 .01648 L
.49999 .01666 L
.49999 .0168 L
.49999 .01696 L
.49999 .01711 L
.49999 .01725 L
.49999 .0175 L
.49999 .01777 L
.5 .01824 L
.5 .0188 L
.5 .01931 L
.50001 .01976 L
.50001 .02001 L
.50001 .02023 L
.50001 .02048 L
.50001 .02075 L
.50001 .02101 L
.50001 .02124 L
.50001 .0215 L
.5 .02177 L
.5 .02226 L
.5 .02338 L
.5 .02367 L
.49999 .02399 L
.49999 .02414 L
.49999 .02429 L
.49999 .02457 L
.49999 .02483 L
.49999 .02508 L
.49999 .02535 L
.49999 .02551 L
.49999 .02565 L
.5 .0276 L
.5 .02816 L
.50001 .02843 L
.50001 .02869 L
.50001 .02892 L
.50001 .02917 L
.50001 .02941 L
.50001 .02968 L
Mistroke
.50001 .02983 L
.50001 .02998 L
.50001 .03025 L
.50001 .03054 L
.5 .03086 L
.5 .03197 L
.5 .03299 L
.5 .03327 L
.49999 .03357 L
.49999 .03382 L
.49999 .0341 L
.49999 .03425 L
.49999 .03439 L
.49999 .03454 L
.49999 .03469 L
.49999 .03495 L
.49999 .0351 L
.49999 .03524 L
.49999 .03548 L
.5 .03576 L
.5 .03631 L
.5 .03735 L
.5 .03831 L
.50001 .03885 L
.50001 .03912 L
.50001 .03927 L
.50001 .03942 L
.50001 .03957 L
.50001 .03972 L
.50001 .04 L
.50001 .04015 L
.50001 .0403 L
.50001 .04045 L
.50001 .04062 L
.50001 .04087 L
.50001 .04115 L
.5 .04165 L
.5 .04279 L
.5 .04383 L
.5 .04414 L
.49999 .04442 L
.49999 .04468 L
.49999 .04495 L
.49999 .0451 L
.49999 .04526 L
.49999 .04554 L
.49999 .0457 L
.49999 .04587 L
.49999 .04603 L
.49999 .04618 L
Mistroke
.49999 .04646 L
.49999 .04676 L
.5 .04731 L
.5 .04935 L
.5 .04991 L
.5 .05022 L
.50001 .05052 L
.50001 .05079 L
.50001 .05093 L
.50001 .05108 L
.50001 .05135 L
.50001 .05161 L
.50001 .05174 L
.50001 .05189 L
.50001 .05215 L
.50001 .0523 L
.50001 .05244 L
.50001 .05275 L
.50001 .05302 L
.50001 .05327 L
.5 .05383 L
.5 .05584 L
.5 .05637 L
.49999 .05694 L
.49999 .05724 L
.49999 .0574 L
.49999 .05757 L
.49999 .05772 L
.49999 .05787 L
.49999 .05815 L
.49999 .05841 L
.49999 .05865 L
.49999 .05892 L
.49999 .05907 L
.49999 .05921 L
.49999 .05979 L
.5 .06033 L
.5 .0624 L
.5 .06295 L
.50001 .06354 L
.50001 .06382 L
.50001 .06409 L
.50001 .06434 L
.50001 .0646 L
.50001 .06485 L
.50001 .06507 L
.50001 .06529 L
.50001 .0655 L
.50001 .06574 L
.50001 .06597 L
Mistroke
.50001 .06622 L
.50001 .06648 L
.50001 .06699 L
.5 .06746 L
.5 .06854 L
.5 .06961 L
.5 .07018 L
.49999 .07078 L
.49999 .07103 L
.49999 .0713 L
.49999 .07146 L
.49999 .0716 L
.49999 .07188 L
.49999 .07212 L
.49999 .07237 L
.49999 .07264 L
.49999 .07289 L
.49999 .07314 L
.49999 .07341 L
.5 .0739 L
.5 .07438 L
.5 .07481 L
.50001 .07686 L
.50002 .0788 L
.50003 .08087 L
.50003 .08206 L
.50004 .08315 L
.50005 .08368 L
.50006 .08425 L
.50007 .08474 L
.50008 .08528 L
.5001 .08632 L
.50014 .08729 L
.50019 .08844 L
.50026 .0895 L
.50035 .09054 L
.50049 .09168 L
.50067 .09287 L
.50088 .09398 L
.50115 .09506 L
.50152 .09623 L
.50193 .09725 L
.50247 .09834 L
.50306 .09933 L
.50385 .10041 L
.50569 .10231 L
.50863 .10448 L
.51235 .10646 L
.51815 .10874 L
.52544 .11092 L
Mistroke
.54547 .11515 L
.57124 .11908 L
.63967 .12743 L
.65657 .12963 L
.67208 .13201 L
.67791 .1331 L
.68302 .13425 L
.68645 .13524 L
.68801 .1358 L
.68918 .13632 L
.69011 .13685 L
.69049 .13713 L
.69081 .13744 L
.69101 .1377 L
.69113 .13794 L
.6912 .13821 L
.69121 .13836 L
.6912 .1385 L
.69113 .13874 L
.69102 .13896 L
.69083 .1392 L
.69057 .13946 L
.68983 .14 L
.68891 .14048 L
.68599 .14159 L
.68157 .14278 L
.67053 .14495 L
.64049 .1492 L
.6032 .15369 L
.56986 .15792 L
.54468 .16178 L
.52471 .16594 L
.51674 .16823 L
.51091 .1704 L
.50672 .17245 L
.50341 .17464 L
.50115 .1767 L
.49967 .17857 L
.49903 .17961 L
.49847 .18072 L
.49772 .18269 L
.49741 .18379 L
.49717 .18481 L
.49697 .18593 L
.4968 .18714 L
.49668 .1883 L
.49659 .18938 L
.49652 .1904 L
.49647 .19149 L
.49643 .19247 L
Mistroke
.49641 .19338 L
.49638 .19438 L
.49637 .19546 L
.49635 .19658 L
.49634 .19762 L
.49633 .19875 L
.49633 .19997 L
.49632 .20113 L
.49632 .20222 L
.49632 .20327 L
.49632 .20426 L
.49631 .20525 L
.49631 .20582 L
.49631 .20634 L
.49631 .20689 L
.49631 .20714 L
.49631 .2074 L
.49631 .20754 L
.49631 .20769 L
.49631 .20795 L
.49631 .2081 L
.49631 .20826 L
.49631 .20841 L
.49631 .20854 L
.49631 .20877 L
.49631 .20902 L
.49631 .20925 L
.49631 .20946 L
.49631 .20998 L
.49631 .21046 L
.49631 .21143 L
.49631 .21249 L
.49632 .21451 L
.49632 .21673 L
.49633 .21907 L
.49633 .22122 L
.49633 .22224 L
.49634 .22335 L
.49634 .2244 L
.49634 .22537 L
.49634 .22595 L
.49634 .2265 L
.49634 .227 L
.49634 .22753 L
.49634 .22781 L
.49634 .22811 L
.49634 .22827 L
.49634 .22843 L
.49634 .22857 L
.49634 .22873 L
Mistroke
.49634 .22888 L
.49634 .22902 L
.49634 .2293 L
.49634 .22983 L
.49634 .23008 L
.49634 .23035 L
.49634 .23057 L
.49634 .23082 L
.49634 .23109 L
.49634 .23137 L
.49634 .23164 L
.49634 .23189 L
.49634 .23237 L
.49634 .23288 L
.49634 .23337 L
.49634 .23382 L
.49634 .23484 L
.49634 .23596 L
.49634 .23713 L
.49634 .23822 L
.49636 .24652 L
.49636 .24868 L
.49636 .24983 L
.49637 .25104 L
.49637 .25222 L
.49637 .25327 L
.49637 .25534 L
.49637 .25751 L
.49637 .2587 L
.49637 .25981 L
.49637 .26177 L
.49637 .2628 L
.49637 .26391 L
.49638 .26613 L
.49638 .26823 L
.49639 .27216 L
.49639 .27607 L
.49639 .27829 L
.4964 .28037 L
.4964 .28241 L
.4964 .2846 L
.4964 .28909 L
.4964 .29125 L
.49641 .2936 L
.49641 .29789 L
.49642 .30657 L
.49643 .31493 L
.49644 .31919 L
.49644 .32144 L
.49645 .32381 L
Mistroke
.49645 .32593 L
.49646 .32826 L
.49647 .33236 L
.49649 .33653 L
.49651 .341 L
.49655 .34553 L
.49659 .34983 L
.49665 .35408 L
.49673 .35801 L
.49682 .362 L
.49695 .3664 L
.49729 .37498 L
.49771 .38324 L
.49822 .39203 L
.49872 .40049 L
.49914 .40863 L
.49934 .41316 L
.4995 .41729 L
.49963 .42163 L
.49973 .42563 L
.49981 .42972 L
.49987 .43416 L
.49991 .43817 L
.49993 .44047 L
.49995 .44258 L
.49997 .44673 L
.49997 .44902 L
.49998 .45119 L
.49999 .45324 L
.49999 .45543 L
.49999 .45749 L
.49999 .45936 L
.49999 .4615 L
.5 .46347 L
.5 .46564 L
.5 .46792 L
.5 .47604 L
.5 .48057 L
.5 .48271 L
.5 .48469 L
.5 .48566 L
.5 .48674 L
.5 .48782 L
.5 .48841 L
.5 .48867 L
.5 .48896 L
.5 .48922 L
.5 .48946 L
.5 .48971 L
.5 .48998 L
Mistroke
.5 .49023 L
.5 .49047 L
.5 .49068 L
.5 .49091 L
.5 .49116 L
.5 .49144 L
.5 .492 L
.5 .49252 L
.5 .49301 L
.5 .49488 L
.5 .49666 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo0_l0003ooooooeGooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`;o0000oooooomDooooo`00oooooomKooooo`03o`000?oooooo
oooo0?ooooooDOooool00?ooooooG?ooool3o`000?ooooooD?ooool00?ooooooGoooool2o`000?oo
ooooC_ooool00?ooooooHOooool2o`000?ooooooC?ooool00?ooooooHoooool3o`000?ooooooBOoo
ool00?ooooooI_ooool4o`000?ooooooAOooool00?ooooooJ_ooool5o`000?oooooo@?ooool00?oo
ooooKoooool4o`000?oooooo??ooool00?ooooooLoooool5o`000?oooooo=oooool00?ooooooN?oo
ool5o`000?oooooo<_ooool00?ooooooOOooool5o`000?oooooo;Oooool00?ooooooP_ooool7o`00
0?oooooo9_ooool00?ooooooROooool9o`000?oooooo7Oooool00?ooooooT_ooool9o`000?oooooo
5?ooool00?ooooooVoooool9o`000?oooooo2oooool00?ooooooY?ooool9o`000?oooooo0_ooool0
0?oooooo[Oooool:o`000?Oooooo003ooooookOooooo2?l0003_ooooo`00oooooonoooooo`Go0000
j_ooool00?ooooooa?ooool7o`000>?ooooo003ooooool_ooooo0ol0003Pooooo`00ooooooo>oooo
o`;o0000g_ooool00?ooooood?ooool2o`000=cooooo003oooooom7ooooo00?o0000ooooooooool0
f_ooool00?oooooocoooool3o`000=cooooo003oooooolgooooo0_l0003Oooooo`00ooooooo8oooo
o`Go0000hOooool00?oooooo`Oooool7o`000>Kooooo003ooooook[ooooo1ol0003]ooooo`00oooo
oondooooo`Ko0000m?ooool00?oooooo[Oooool7o`000?[ooooo003oooooojGooooo2?l0003ooooo
o`;ooooo003ooooooigooooo2?l0003oooooo`[ooooo003ooooooiCooooo2Ol0003ooooooa;ooooo
003oooooohWooooo2ol0003ooooooa_ooooo003ooooooh7ooooo2?l0003oooooobKooooo003ooooo
og_ooooo1_l0003oooooobkooooo003oooooogKooooo1Ol0003oooooocCooooo003oooooog3ooooo
1_l0003oooooocWooooo003oooooof[ooooo1_l0003oooooocoooooo003oooooofKooooo1?l0003o
ooooodGooooo003oooooof?ooooo0ol0003oooooodWooooo003oooooof3ooooo0ol0003oooooodco
oooo003ooooooegooooo0ol0003oooooodoooooo003ooooooecooooo00?o0000ooooooooool0oooo
oom@ooooo`00oooooomJooooo`;o0000oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooolCooooo`?o0000
00?o410@ooooooooool0oooooonFooooo`00oooooolEooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0?ooooooJ_oo
ool00?oooooo5Oooool00onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00?ooooo0_lb<S;oooooof_ooooo003ooooooaGooooo00?ogMgMo`00
0?nj^[X01oooool01?l0003oooooooooooooool5o`0000Cooooo00?oQhN7o`000?nj^[X01?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00002Oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0oooooolDooooo`00
oooooolEooooo`03oeEEEOmgMgOoA4A400Oooooo00Co0000oooooooooooooooo0_mgMgL2ooooo`03
o`000?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Wooooo00Ko0000ojVYZOoooooooooookZj^_l00002oooo
o`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oo
oooo5?ooool00?oooooo5?ooool01OoMgMgo410@oooooolQ8B7ogMgM00Kooooo00?o0000oooooooo
ool00_ooool00omEEEGoV9RHooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP0;ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo5?ooool01OmVIVKoQhN7oooooonHV9So
EEEE00Kooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h02Oooool01_lb<S;o8B4QogMg
MomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo
4oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`03oc8b<_n7QhOooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo5?ooool0
0?oooooo4oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000
oooooooooooooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool01oooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000oooooolDooooo`00
oooooolOooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@4100oooooolcooooo`00oooooolOooooo`;o00004_ooool00ol0003o
ooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<0?oooooo<oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50003 0 m
.50001 .00099 L
.5 .00147 L
.49999 .0017 L
.49999 .00192 L
.49999 .00217 L
.5 .00245 L
.5 .0027 L
.5 .00293 L
.50001 .00318 L
.50001 .00346 L
.50001 .00373 L
.5 .00388 L
.5 .00402 L
.5 .00452 L
.5 .0048 L
.49999 .00505 L
.49999 .0052 L
.49999 .00536 L
.49999 .00551 L
.49999 .00564 L
.5 .00591 L
.5 .00619 L
.5 .00666 L
.5 .00693 L
.50001 .00717 L
.50001 .00731 L
.50001 .00746 L
.50001 .00773 L
.5 .008 L
.5 .00825 L
.5 .00874 L
.5 .00925 L
.5 .00952 L
.5 .00967 L
.49999 .00981 L
.49999 .01006 L
.49999 .01032 L
.49999 .01048 L
.5 .01064 L
.5 .01094 L
.5 .01151 L
.5 .01178 L
.5 .01208 L
.5 .01235 L
.5 .01261 L
.50001 .01275 L
.50001 .01291 L
.50001 .01317 L
.50001 .01333 L
Mistroke
.5 .01349 L
.5 .01365 L
.5 .01379 L
.5 .01442 L
.5 .01503 L
.5 .0153 L
.5 .01558 L
.5 .01583 L
.5 .01609 L
.49999 .01625 L
.49999 .01638 L
.49999 .01654 L
.49999 .01669 L
.5 .01696 L
.5 .01711 L
.5 .01725 L
.5 .01824 L
.5 .01876 L
.5 .01905 L
.5 .01931 L
.5 .01954 L
.5 .01979 L
.50001 .02007 L
.50001 .02032 L
.5 .02055 L
.5 .02079 L
.5 .02103 L
.5 .02124 L
.5 .02235 L
.5 .02289 L
.5 .02338 L
.5 .02365 L
.5 .0239 L
.49999 .02417 L
.49999 .02432 L
.49999 .02446 L
.5 .02473 L
.5 .02489 L
.5 .02504 L
.5 .02533 L
.5 .02565 L
.5 .02663 L
.5 .02717 L
.5 .02769 L
.5 .02798 L
.5 .02813 L
.5 .02829 L
.5 .02843 L
.5 .02858 L
.50001 .02884 L
Mistroke
.5 .02911 L
.5 .02926 L
.5 .0294 L
.5 .02967 L
.5 .02992 L
.5 .03104 L
.5 .0321 L
.5 .03239 L
.5 .03269 L
.5 .03284 L
.5 .03302 L
.5 .03317 L
.5 .03332 L
.49999 .0336 L
.49999 .03385 L
.5 .03399 L
.5 .03415 L
.5 .03443 L
.5 .03469 L
.5 .03493 L
.5 .03549 L
.5 .03662 L
.5 .0371 L
.5 .0376 L
.5 .03787 L
.5 .03815 L
.5 .03841 L
.50001 .03866 L
.50001 .0389 L
.50001 .03917 L
.5 .03942 L
.5 .03965 L
.5 .03986 L
.5 .04009 L
.5 .04056 L
.5 .04259 L
.5 .04312 L
.5 .0434 L
.5 .0437 L
.5 .04385 L
.49999 .04399 L
.49999 .04425 L
.49999 .04449 L
.49999 .04476 L
.49999 .045 L
.5 .04526 L
.5 .04554 L
.5 .04579 L
.5 .04674 L
.5 .04784 L
Mistroke
.5 .04842 L
.5 .04904 L
.5 .04929 L
.5 .04957 L
.50001 .04973 L
.50001 .04988 L
.50001 .05003 L
.50001 .05016 L
.50001 .05042 L
.50001 .0507 L
.50001 .05094 L
.50001 .0512 L
.50001 .05135 L
.5 .0515 L
.5 .05177 L
.5 .05238 L
.5 .05349 L
.5 .05456 L
.5 .05509 L
.5 .05531 L
.5 .05556 L
.5 .05581 L
.5 .05603 L
.5 .05625 L
.5 .05648 L
.5 .05672 L
.5 .05694 L
.5 .05719 L
.5 .05745 L
.5 .05771 L
.5 .05798 L
.5 .05854 L
.5 .05953 L
.50001 .06172 L
.50003 .06372 L
.50004 .06482 L
.50004 .0654 L
.50005 .06602 L
.50006 .06655 L
.50007 .06715 L
.5001 .06819 L
.50012 .06872 L
.50014 .0693 L
.5002 .07036 L
.50028 .07139 L
.50038 .07234 L
.50053 .07347 L
.50072 .0745 L
.50101 .07569 L
.50136 .0768 L
Mistroke
.50177 .0778 L
.50234 .07889 L
.5031 .08003 L
.50399 .0811 L
.50614 .083 L
.50774 .08407 L
.50948 .08504 L
.51441 .08716 L
.52062 .08912 L
.52961 .09128 L
.54194 .09356 L
.57211 .09773 L
.60773 .10163 L
.64589 .10558 L
.66556 .10782 L
.68088 .1099 L
.68726 .11097 L
.69219 .11198 L
.69444 .11253 L
.69647 .11314 L
.69794 .11368 L
.69896 .11419 L
.69937 .11445 L
.69971 .11473 L
.69994 .11499 L
.70008 .11523 L
.70015 .11551 L
.70014 .11567 L
.70011 .11582 L
.69998 .11609 L
.69988 .11623 L
.69974 .11638 L
.69937 .11668 L
.69895 .11695 L
.69764 .11757 L
.6961 .11812 L
.69411 .1187 L
.68416 .12073 L
.66922 .1229 L
.63493 .12682 L
.59475 .13107 L
.55657 .13568 L
.54225 .13783 L
.52979 .14011 L
.52054 .14225 L
.51395 .14421 L
.50876 .14622 L
.50466 .14838 L
.50195 .15038 L
.50012 .15229 L
Mistroke
.49934 .15336 L
.49876 .15434 L
.49825 .15539 L
.49781 .15652 L
.49749 .15757 L
.49725 .15854 L
.49706 .15954 L
.49692 .16045 L
.49679 .16145 L
.49669 .16253 L
.49662 .16352 L
.49656 .16447 L
.49652 .16557 L
.49648 .16658 L
.49646 .1677 L
.49644 .16888 L
.49642 .16993 L
.49641 .17088 L
.49641 .17193 L
.4964 .17304 L
.49639 .17491 L
.49639 .17596 L
.49638 .17694 L
.49638 .17747 L
.49638 .17802 L
.49638 .17863 L
.49638 .1789 L
.49638 .17919 L
.49638 .17947 L
.49638 .17971 L
.49638 .17997 L
.49638 .1802 L
.49638 .18048 L
.49638 .18074 L
.49638 .18102 L
.49638 .18117 L
.49638 .18131 L
.49638 .18183 L
.49638 .1823 L
.49638 .18336 L
.49639 .18528 L
.49639 .1874 L
.49639 .18856 L
.49639 .18966 L
.4964 .19068 L
.4964 .19122 L
.4964 .19179 L
.4964 .19227 L
.4964 .1928 L
.4964 .19303 L
Mistroke
.4964 .19328 L
.4964 .19352 L
.4964 .19373 L
.4964 .19399 L
.4964 .19427 L
.4964 .19453 L
.4964 .19477 L
.4964 .19491 L
.4964 .19505 L
.4964 .19531 L
.4964 .19559 L
.4964 .1959 L
.4964 .19642 L
.4964 .19697 L
.4964 .19797 L
.4964 .19895 L
.4964 .19999 L
.4964 .20041 L
.4964 .20087 L
.4964 .20114 L
.4964 .20138 L
.4964 .20161 L
.4964 .20185 L
.4964 .20211 L
.4964 .20239 L
.4964 .20265 L
.4964 .20289 L
.4964 .20317 L
.4964 .20347 L
.4964 .20402 L
.4964 .20462 L
.4964 .20525 L
.4964 .20638 L
.4964 .20843 L
.49641 .21068 L
.49641 .21281 L
.49641 .21483 L
.49641 .21594 L
.49641 .21653 L
.49641 .21716 L
.49642 .21774 L
.49642 .21826 L
.49642 .21879 L
.49642 .21929 L
.49642 .21954 L
.49642 .21981 L
.49642 .22004 L
.49642 .22029 L
.49642 .22044 L
.49642 .22058 L
Mistroke
.49642 .22086 L
.49642 .22111 L
.49642 .22138 L
.49642 .22164 L
.49642 .22192 L
.49642 .22218 L
.49642 .22243 L
.49642 .22358 L
.49642 .22403 L
.49642 .2245 L
.49642 .22477 L
.49642 .22502 L
.49642 .22527 L
.49642 .22551 L
.49642 .22575 L
.49642 .22601 L
.49642 .22623 L
.49642 .22648 L
.49642 .22674 L
.49642 .22702 L
.49642 .22753 L
.49642 .22807 L
.49642 .22865 L
.49642 .2297 L
.49642 .23093 L
.49642 .23206 L
.49643 .23635 L
.49643 .23853 L
.49643 .24082 L
.49643 .24278 L
.49644 .24389 L
.49644 .24492 L
.49644 .246 L
.49644 .24701 L
.49644 .24792 L
.49644 .24891 L
.49644 .25094 L
.49644 .25149 L
.49644 .25209 L
.49644 .25317 L
.49644 .25372 L
.49644 .25431 L
.49644 .25538 L
.49644 .25643 L
.49644 .25741 L
.49644 .25958 L
.49645 .2619 L
.49645 .26616 L
.49646 .26841 L
.49646 .27078 L
Mistroke
.49646 .2729 L
.49646 .27411 L
.49646 .27523 L
.49646 .27721 L
.49646 .27933 L
.49646 .28151 L
.49646 .28273 L
.49646 .28387 L
.49647 .28595 L
.49647 .28817 L
.49648 .29623 L
.49648 .30036 L
.49648 .30268 L
.49649 .30481 L
.49649 .30919 L
.49649 .31133 L
.49649 .31327 L
.49649 .3153 L
.49649 .31721 L
.4965 .32141 L
.49651 .32962 L
.49651 .33387 L
.49651 .33601 L
.49651 .33836 L
.49652 .34067 L
.49652 .34286 L
.49652 .345 L
.49652 .34698 L
.49653 .35094 L
.49653 .35527 L
.49655 .36363 L
.49656 .36791 L
.49656 .37015 L
.49657 .37252 L
.49658 .37465 L
.49659 .37699 L
.49661 .38109 L
.49664 .38526 L
.49669 .38973 L
.49676 .39428 L
.49684 .39858 L
.49705 .40677 L
.49719 .411 L
.49737 .41549 L
.49775 .42356 L
.49821 .43216 L
.49867 .44043 L
.4991 .44923 L
.49944 .4577 L
.49968 .46585 L
Mistroke
.49977 .47004 L
.49984 .47452 L
.49989 .47909 L
.49993 .48339 L
.49995 .48768 L
.49997 .49162 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomIooooo`;o0000oooooomDooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooFoooool2o`000?ooooooD_ooool00?ooooooGOoo
ool3o`000?ooooooCoooool00?ooooooH?ooool3o`000?ooooooC?ooool00?ooooooHoooool4o`00
0?ooooooB?ooool00?ooooooIoooool3o`000?ooooooAOooool00?ooooooJ_ooool5o`000?oooooo
@?ooool00?ooooooKoooool7o`000?oooooo>Oooool00?ooooooM_ooool7o`000?oooooo<_ooool0
0?ooooooOOooool6o`000?oooooo;?ooool00?ooooooPoooool9o`000?oooooo8oooool00?oooooo
S?ooool;o`000?oooooo6?ooool00?ooooooUoooool:o`000?oooooo3_ooool00?ooooooXOooool8
o`000?oooooo1_ooool00?ooooooZOooool8o`000?gooooo003ooooook7ooooo2ol0003booooo`00
oooooonlooooo`So0000j_ooool00?ooooooa?ooool5o`000>Gooooo003oooooolWooooo2?l0003M
ooooo`00oooooooAooooo`?o0000f_ooool00?ooooooe?ooool3o`000=Oooooo003oooooomKooooo
0_l0003Fooooo`00oooooooFooooo`;o0000e_ooool00?oooooodOooool5o`000=Sooooo003ooooo
olkooooo0ol0003Mooooo`00ooooooo8ooooo`Ko0000h?ooool00?oooooo__ooool:o`000>Kooooo
003ooooook?ooooo2ol0003`ooooo`00oooooonYooooo`[o0000noooool00?ooooooX?ooool9o`00
0?oooooo1_ooool00?ooooooUoooool9o`000?oooooo3oooool00?ooooooSoooool8o`000?oooooo
6?ooool00?ooooooQoooool8o`000?oooooo8?ooool00?ooooooOoooool8o`000?oooooo:?ooool0
0?ooooooMoooool8o`000?oooooo<?ooool00?ooooooL?ooool7o`000?oooooo>?ooool00?oooooo
K?ooool4o`000?oooooo?oooool00?ooooooIoooool5o`000?oooooo@oooool00?ooooooHoooool4
o`000?ooooooB?ooool00?ooooooHOooool2o`000?ooooooC?ooool00?ooooooGoooool2o`000?oo
ooooC_ooool00?ooooooG?ooool3o`000?ooooooD?ooool00?ooooooFOooool3o`000?ooooooDooo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo003ooooooa;ooooo00?o
410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o
0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooK_ooool0
0?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo1Ol00003oooo
o`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooo
oooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0
003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooooa3ooooo003ooooooa;ooooo
00?oEEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`;oMgMg0_ooool01ol0003ooooo
ooooooooooooc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000
ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zj
o`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7
QhOo410@ooooool@ooooo`00oooooolAooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0
003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool01oooool01Onj^[[oQhN7ofIVI_mV
IVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo003o
oooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooooooo00Cooooo00?o
EEEEoiRHV?ooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^
kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo4oooool00?oooooo4?ooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooolb<S;oQhN700_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[oooooonk^k_mgMgOo
00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7
Qol0003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0003o000000?o0000
1?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`06
ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo
00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooa3ooooo003ooooooa_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo0?oooooo<?ooool00?oooooo6oooool2o`0001?ooooo00?o0000oooo
ooooool01?ooool2o`0000gooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000ooooool_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49999 0 m
.5 .00825 L
.5 .0085 L
.5 .00876 L
.5 .0089 L
.5 .00905 L
.5 .00932 L
.5 .0098 L
.5 .01033 L
.5 .01049 L
.5 .01064 L
.5 .01078 L
.5 .01093 L
.5 .01107 L
.5 .01122 L
.5 .01149 L
.5 .01163 L
.5 .01177 L
.5 .01204 L
.5 .01255 L
.5 .01316 L
.5 .0135 L
.5 .01366 L
.5 .01381 L
.5 .01408 L
.5 .01423 L
.5 .01437 L
.5 .01452 L
.5 .01466 L
.5 .01482 L
.5 .01498 L
.5 .01525 L
.5 .01554 L
.5 .01606 L
.5 .01668 L
.5 .01698 L
.5 .01725 L
.5 .0175 L
.5 .01775 L
.5 .018 L
.5 .01827 L
.5 .01841 L
.5 .01856 L
.5 .01886 L
.5 .0194 L
.5 .02049 L
.5 .0208 L
.5 .0211 L
.5 .02137 L
.5 .02152 L
Mistroke
.5 .02166 L
.5 .02193 L
.5 .02219 L
.5 .02242 L
.5 .02267 L
.5 .02294 L
.5 .02323 L
.5 .02375 L
.5 .02423 L
.5 .02475 L
.5 .02521 L
.5 .02544 L
.5 .0257 L
.5 .02584 L
.5 .02599 L
.5 .02625 L
.5 .02652 L
.5 .02676 L
.5 .02699 L
.5 .02723 L
.5 .02773 L
.5 .02878 L
.5 .02936 L
.5 .02964 L
.5 .0299 L
.5 .03015 L
.5 .03041 L
.5 .03068 L
.5 .03083 L
.5 .03097 L
.5 .03121 L
.5 .03143 L
.5 .03169 L
.5 .03193 L
.5 .0324 L
.5 .03284 L
.5 .03382 L
.5 .0343 L
.5 .03481 L
.5 .03507 L
.5 .03536 L
.5 .03563 L
.5 .03587 L
.5 .03612 L
.5 .03636 L
.5 .03657 L
.5 .03681 L
.5 .03706 L
.5 .03732 L
.5 .0378 L
Mistroke
.5 .03889 L
.5 .03992 L
.5 .0402 L
.5 .04049 L
.5 .04066 L
.5 .04081 L
.5 .04097 L
.5 .04111 L
.5 .04138 L
.5 .04163 L
.5 .04191 L
.5 .04205 L
.5 .0422 L
.5 .04248 L
.5 .04274 L
.5 .04324 L
.5 .04436 L
.50001 .04637 L
.50002 .04825 L
.50003 .04876 L
.50003 .04931 L
.50005 .05028 L
.50005 .05079 L
.50007 .05133 L
.50009 .05229 L
.50012 .05282 L
.50014 .05332 L
.50017 .0539 L
.50022 .05445 L
.50031 .05543 L
.50043 .05633 L
.50059 .0573 L
.50084 .05835 L
.50117 .0594 L
.50157 .06037 L
.50214 .06145 L
.50296 .0626 L
.5041 .0638 L
.50551 .06495 L
.50712 .06597 L
.50929 .06709 L
.51205 .06823 L
.51522 .0693 L
.52287 .07131 L
.53404 .07346 L
.54993 .07579 L
.58925 .08006 L
.63955 .08456 L
.66334 .08675 L
.68299 .08881 L
Mistroke
.69688 .09067 L
.70276 .09172 L
.70501 .09222 L
.70677 .09269 L
.7083 .09319 L
.70934 .09365 L
.70979 .09391 L
.71011 .09416 L
.71034 .09443 L
.71042 .09457 L
.71046 .09471 L
.71045 .09499 L
.71033 .09526 L
.71012 .0955 L
.7098 .09575 L
.70933 .09603 L
.70869 .09633 L
.70721 .09686 L
.70531 .09739 L
.7028 .09796 L
.69713 .09899 L
.67945 .10133 L
.5871 .11016 L
.56683 .11231 L
.54841 .11458 L
.53446 .11669 L
.52403 .11867 L
.51635 .12054 L
.51009 .12256 L
.50745 .12365 L
.50515 .1248 L
.50338 .12588 L
.50205 .12685 L
.49998 .12889 L
.49916 .13001 L
.49854 .13107 L
.49812 .13198 L
.49776 .13295 L
.49745 .13401 L
.49723 .13499 L
.49704 .13604 L
.49691 .137 L
.4968 .13811 L
.49672 .13917 L
.49667 .14014 L
.49663 .14104 L
.4966 .14203 L
.49657 .14308 L
.49655 .14422 L
.49654 .14528 L
Mistroke
.49653 .14644 L
.49652 .14766 L
.4965 .14971 L
.4965 .15088 L
.49649 .15197 L
.49649 .15304 L
.49649 .15364 L
.49649 .15393 L
.49649 .1542 L
.49649 .15446 L
.49649 .15469 L
.49649 .15495 L
.49649 .15523 L
.49649 .15548 L
.49649 .15576 L
.49649 .1559 L
.49649 .15605 L
.49649 .15632 L
.49649 .15659 L
.49649 .15683 L
.49649 .15739 L
.49649 .1584 L
.49649 .16028 L
.4965 .16222 L
.4965 .16278 L
.4965 .16331 L
.4965 .16379 L
.4965 .1643 L
.4965 .16457 L
.4965 .16471 L
.4965 .16486 L
.4965 .16513 L
.4965 .16539 L
.4965 .16553 L
.4965 .16569 L
.4965 .16586 L
.4965 .16601 L
.4965 .16628 L
.4965 .16644 L
.4965 .16658 L
.4965 .1671 L
.4965 .16767 L
.4965 .16871 L
.49649 .17286 L
.49649 .174 L
.49649 .17463 L
.49649 .17522 L
.49649 .17578 L
.49649 .17609 L
.49649 .17624 L
Mistroke
.49649 .17638 L
.49649 .17665 L
.49649 .17689 L
.49649 .17715 L
.49649 .1773 L
.49649 .17744 L
.49649 .17769 L
.49649 .17792 L
.49649 .17819 L
.49649 .17844 L
.49649 .17939 L
.49649 .18041 L
.49649 .18152 L
.49649 .18358 L
.4965 .18467 L
.4965 .18584 L
.4965 .1864 L
.4965 .18698 L
.4965 .18752 L
.4965 .18778 L
.4965 .18802 L
.4965 .18825 L
.4965 .18849 L
.4965 .18875 L
.4965 .189 L
.4965 .18927 L
.4965 .1894 L
.4965 .18955 L
.4965 .18982 L
.4965 .19007 L
.4965 .19034 L
.4965 .19065 L
.4965 .1912 L
.4965 .19223 L
.4965 .19455 L
.4965 .1956 L
.49649 .19672 L
.49649 .19772 L
.49649 .19826 L
.49649 .19876 L
.49649 .19907 L
.49649 .19935 L
.49649 .19966 L
.49649 .19983 L
.49649 .19999 L
.49649 .20027 L
.49649 .20053 L
.49649 .20067 L
.49649 .20081 L
.49649 .20097 L
Mistroke
.49649 .20112 L
.49649 .20139 L
.49649 .20165 L
.49649 .20214 L
.49649 .20267 L
.49649 .20325 L
.4965 .20545 L
.4965 .20744 L
.4965 .20978 L
.4965 .2108 L
.49651 .21192 L
.49651 .21242 L
.49651 .21295 L
.49651 .21346 L
.49651 .21392 L
.49651 .21419 L
.49651 .21444 L
.49651 .21471 L
.49651 .21485 L
.49651 .215 L
.49651 .21526 L
.49651 .21553 L
.49651 .21579 L
.49651 .21603 L
.49651 .21656 L
.49651 .21706 L
.49651 .21819 L
.4965 .22047 L
.4965 .22155 L
.4965 .22212 L
.4965 .22272 L
.4965 .22324 L
.4965 .22352 L
.4965 .22382 L
.4965 .22409 L
.4965 .22435 L
.4965 .2246 L
.4965 .22484 L
.4965 .22509 L
.4965 .22531 L
.4965 .22558 L
.4965 .22582 L
.4965 .22605 L
.4965 .22626 L
.4965 .22674 L
.4965 .22722 L
.4965 .22774 L
.4965 .22881 L
.4965 .22993 L
.49651 .23099 L
Mistroke
.49651 .23298 L
.49651 .23514 L
.49651 .23633 L
.49652 .23744 L
.49652 .2385 L
.49652 .23947 L
.49652 .23999 L
.49652 .24054 L
.49652 .2411 L
.49652 .24141 L
.49652 .2417 L
.49652 .24195 L
.49652 .24221 L
.49652 .24247 L
.49652 .2427 L
.49652 .24291 L
.49652 .24314 L
.49652 .24338 L
.49652 .2436 L
.49652 .24412 L
.49652 .24458 L
.49652 .24564 L
.49652 .24761 L
.49652 .24869 L
.49652 .24922 L
.49652 .2497 L
.49652 .25028 L
.49652 .25059 L
.49652 .25074 L
.49652 .25091 L
.49652 .25118 L
.49652 .25134 L
.49652 .25148 L
.49652 .25175 L
.49652 .252 L
.49652 .25226 L
.49652 .25253 L
.49652 .25302 L
.49652 .25355 L
.49652 .25413 L
.49652 .25524 L
.49652 .2563 L
.49652 .25828 L
.49653 .26274 L
.49653 .26478 L
.49653 .26591 L
.49653 .26697 L
.49653 .26795 L
.49653 .26847 L
.49653 .26902 L
Mistroke
.49653 .26949 L
.49653 .27 L
.49653 .27046 L
.49653 .27066 L
.49653 .27089 L
.49653 .27116 L
.49653 .27131 L
.49653 .27145 L
.49653 .27169 L
.49653 .27196 L
.49653 .2721 L
.49653 .27226 L
.49653 .27242 L
.49653 .27257 L
.49653 .27284 L
.49653 .27312 L
.49653 .27369 L
.49653 .27423 L
.49653 .27524 L
.49653 .27616 L
.49653 .27714 L
.49653 .27765 L
.49653 .27792 L
.49653 .27821 L
.49653 .27848 L
.49653 .27872 L
.49653 .27897 L
.49653 .2792 L
.49653 .27947 L
.49653 .27962 L
.49653 .27975 L
.49653 .28001 L
.49653 .28028 L
.49653 .28074 L
.49653 .28125 L
.49653 .2818 L
.49653 .28238 L
.49653 .28344 L
.49654 .28449 L
.49654 .28549 L
.49654 .28737 L
.49654 .29126 L
.49655 .29348 L
.49655 .29556 L
.49655 .2976 L
.49655 .29874 L
.49655 .29929 L
.49655 .29979 L
.49655 .30034 L
.49655 .30084 L
Mistroke
.49655 .30139 L
.49655 .30169 L
.49655 .30198 L
.49655 .30226 L
.49655 .30241 L
.49655 .30256 L
.49655 .30281 L
.49655 .30309 L
.49655 .30324 L
.49655 .30339 L
.49655 .30366 L
.49655 .30382 L
.49655 .30396 L
.49655 .30412 L
.49655 .30428 L
.49655 .30628 L
.49655 .30683 L
.49655 .3071 L
.49655 .30726 L
.49655 .3074 L
.49655 .30766 L
.49655 .30794 L
.49655 .30819 L
.49655 .30843 L
.49655 .30866 L
.49655 .30891 L
.49655 .30917 L
.49655 .30941 L
.49655 .30984 L
.49655 .31031 L
.49655 .31085 L
.49655 .31137 L
.49655 .31234 L
.49656 .31341 L
.49656 .31438 L
.49656 .31657 L
.49656 .3205 L
.49657 .32495 L
.49657 .32691 L
.49657 .32795 L
.49657 .32906 L
.49657 .33014 L
.49657 .33113 L
.49657 .33212 L
.49657 .33306 L
.49658 .33357 L
.49658 .33411 L
.49658 .33458 L
.49658 .33509 L
.49658 .33563 L
Mistroke
.49658 .33614 L
.49658 .33674 L
.49658 .33729 L
.49658 .3383 L
.49658 .33887 L
.49658 .33939 L
.49658 .33987 L
.49658 .34039 L
.49658 .34134 L
.49658 .34187 L
.49658 .34245 L
.49658 .34364 L
.49658 .34473 L
.49658 .34576 L
.49658 .34798 L
.49658 .35009 L
.49659 .35405 L
.49659 .35834 L
.49659 .36021 L
.4966 .36222 L
.4966 .36335 L
.4966 .36439 L
.4966 .36545 L
.4966 .36643 L
.4966 .36748 L
.4966 .36862 L
.4966 .37092 L
.4966 .37199 L
.4966 .37316 L
.4966 .37426 L
.4966 .37527 L
.4966 .3772 L
.4966 .37817 L
.4966 .37924 L
.49661 .38338 L
.49661 .38784 L
.49662 .39664 L
.49663 .40104 L
.49663 .40512 L
.49664 .40906 L
.49665 .41127 L
.49665 .41327 L
.49667 .41738 L
.49668 .41969 L
.49669 .42182 L
.49673 .42584 L
.49677 .43025 L
.49682 .43442 L
.4969 .43888 L
.49698 .44311 L
Mistroke
.4971 .44771 L
.49739 .45622 L
.49778 .46492 L
.49824 .4733 L
.49874 .48136 L
.49931 .48995 L
.49988 .4982 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`;o0000oooooomEooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooF_ooool2o`000?ooooooDoooool00?ooooooG?ooool3o`000?ooooooD?ooool00?oooooo
Goooool2o`000?ooooooC_ooool00?ooooooHOooool4o`000?ooooooB_ooool00?ooooooIOooool6
o`000?ooooooA?ooool00?ooooooJoooool6o`000?oooooo?_ooool00?ooooooLOooool5o`000?oo
oooo>Oooool00?ooooooM_ooool6o`000?oooooo<oooool00?ooooooO?ooool9o`000?oooooo:_oo
ool00?ooooooQOooool8o`000?oooooo8_ooool00?ooooooSOooool9o`000?oooooo6Oooool00?oo
ooooU_ooool;o`000?oooooo3_ooool00?ooooooXOooool;o`000?oooooo0oooool00?oooooo[?oo
ool=o`000?Gooooo003ooooookWooooo3_l0003Wooooo`00ooooooo7ooooo`_o0000g?ooool00?oo
ooood_ooool6o`000=Kooooo003oooooomSooooo0ol0003Cooooo`00oooooooKooooo`?o0000d?oo
ool00?oooooogOooool00ol0003oooooooooo`3>ooooo`00oooooooKooooo`?o0000d?ooool00?oo
ooooeoooool4o`000=?ooooo003ooooooloooooo2?l0003Gooooo`00ooooooo4ooooo`_o0000gooo
ool00?oooooo^_ooool:o`000>[ooooo003ooooook7ooooo2Ol0003dooooo`00oooooonWooooo`[o
0000oOooool00?ooooooWOooool:o`000?oooooo2?ooool00?ooooooU?ooool9o`000?oooooo4_oo
ool00?ooooooROooool;o`000?oooooo6oooool00?ooooooOoooool:o`000?oooooo9_ooool00?oo
ooooNOooool6o`000?oooooo<?ooool00?ooooooL_ooool7o`000?oooooo=_ooool00?ooooooJ_oo
ool8o`000?oooooo?Oooool00?ooooooI?ooool6o`000?ooooooAOooool00?ooooooH?ooool4o`00
0?ooooooBoooool00?ooooooG_ooool2o`000?ooooooCoooool00?ooooooFoooool3o`000?oooooo
DOooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooeSooooo0_l0003o
oooooeGooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomFooooo`;o
0000oooooomGooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@
4?oooooooooo0?ooooooU_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003o
oooooaGooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`03ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj
00Oooooo00Co0000oooooooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01OnHV9So410@o`000?lb<S;oc<c<00Wooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0?oooooo5?ooool00?oooooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?oooooooooooooo
o`;oMgMg0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P09ooooo`06o`000?nYZJWooooooooo
oonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol@413ooooooaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06oooo
o`03o`000?oooooooooo00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool02?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaOooooo003ooooooaCooooo00GoIVIV
ohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool6o`0000Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ojVYZOl@413ooooo00Sooooo
00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooo
oaOooooo003ooooooa?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`05
o`000?ooooooooooooooool000000_ooool00olb<S;oQhN7ooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooo
ooooool000003Oooool00ol@413o0000okZj^P09ooooo`06o`000?nj^[[oooooonk^k_mgMgOo0000
0_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
003ooooooaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03okZj^_lQ8B7ooooo00Sooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`00
0?oooooo5?ooool00?oooooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o00000?oooooo<oooool00?oooooo7oooool2o`00
01;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000ooooooooool06_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@3ooooooc?ooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.35) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49995 0 m
.49999 .00099 L
.5 .00147 L
.50001 .0017 L
.50001 .00192 L
.50001 .00217 L
.50001 .00245 L
.5 .00268 L
.5 .00293 L
.49999 .0032 L
.49999 .00345 L
.49999 .00372 L
.49999 .00388 L
.49999 .00402 L
.5 .00452 L
.5 .00479 L
.50001 .00505 L
.50001 .0052 L
.50001 .00536 L
.50001 .00564 L
.50001 .00578 L
.50001 .00593 L
.50001 .00619 L
.5 .00666 L
.5 .00692 L
.49999 .00717 L
.49999 .00731 L
.49999 .00746 L
.49999 .00773 L
.49999 .008 L
.49999 .00825 L
.49999 .00852 L
.5 .00877 L
.5 .00932 L
.50001 .00957 L
.50001 .00981 L
.50001 .01006 L
.50001 .01032 L
.50001 .01047 L
.50001 .01062 L
.50001 .0109 L
.50001 .01118 L
.5 .01143 L
.5 .01204 L
.5 .01234 L
.49999 .01261 L
.49999 .01288 L
.49999 .01313 L
.49999 .0134 L
.49999 .01355 L
Mistroke
.49999 .01369 L
.49999 .01384 L
.49999 .01399 L
.49999 .01426 L
.49999 .01455 L
.5 .01487 L
.5 .01547 L
.5 .0158 L
.50001 .01611 L
.50001 .01637 L
.50001 .01665 L
.50001 .01681 L
.50001 .01696 L
.50001 .0171 L
.50001 .01725 L
.50001 .01751 L
.50001 .01775 L
.50001 .01801 L
.5 .01829 L
.5 .01926 L
.49999 .01977 L
.49999 .02006 L
.49999 .02032 L
.49999 .02047 L
.49999 .02063 L
.49999 .02078 L
.49999 .02092 L
.49999 .02119 L
.49999 .02133 L
.49999 .02148 L
.5 .02269 L
.5 .02328 L
.50001 .02383 L
.50001 .02408 L
.50001 .02432 L
.50001 .02458 L
.50001 .02485 L
.50001 .02513 L
.50001 .02539 L
.50001 .02567 L
.50001 .02581 L
.50001 .02597 L
.5 .027 L
.5 .02798 L
.49999 .02852 L
.49999 .02867 L
.49999 .02883 L
.49999 .02911 L
.49999 .02936 L
.49999 .02959 L
Mistroke
.49999 .02985 L
.49999 .03013 L
.49999 .03028 L
.49999 .03043 L
.49999 .03075 L
.5 .03134 L
.50001 .03244 L
.50002 .0346 L
.50003 .03568 L
.50004 .03629 L
.50005 .03685 L
.50006 .03735 L
.50007 .03789 L
.50009 .03845 L
.50011 .03898 L
.50014 .0395 L
.50018 .03999 L
.50027 .0409 L
.50033 .04141 L
.5004 .04189 L
.50062 .04296 L
.50091 .04395 L
.50133 .04501 L
.50188 .04602 L
.50255 .04695 L
.50353 .04797 L
.50496 .04909 L
.50695 .05026 L
.50937 .05135 L
.51243 .05243 L
.51661 .0536 L
.52693 .05572 L
.54093 .05779 L
.55762 .05969 L
.60823 .06404 L
.66261 .06811 L
.68667 .07011 L
.70502 .07201 L
.71265 .07306 L
.71585 .07361 L
.71859 .0742 L
.71966 .07448 L
.72051 .07475 L
.7212 .07501 L
.72171 .07524 L
.72209 .07547 L
.72237 .0757 L
.72254 .07594 L
.72258 .0762 L
.72246 .07648 L
Mistroke
.72221 .07674 L
.72203 .07688 L
.72177 .07703 L
.72113 .07733 L
.71947 .07788 L
.71737 .07839 L
.71212 .07935 L
.70464 .08038 L
.682 .08272 L
.65651 .08485 L
.6007 .08925 L
.57616 .09139 L
.55692 .09333 L
.54128 .09523 L
.52786 .09728 L
.51728 .09944 L
.51329 .1005 L
.51016 .10148 L
.50524 .10351 L
.50333 .10459 L
.5017 .10574 L
.50038 .10695 L
.49942 .10809 L
.49875 .10912 L
.4982 .11024 L
.49781 .11127 L
.49753 .11224 L
.4973 .11331 L
.49711 .11446 L
.49698 .1156 L
.49693 .11617 L
.49689 .1168 L
.49683 .11791 L
.49679 .11894 L
.49676 .12002 L
.49673 .12119 L
.49672 .12229 L
.4967 .12331 L
.49669 .12524 L
.49667 .12728 L
.49666 .12929 L
.49666 .13042 L
.49666 .13096 L
.49665 .13146 L
.49665 .13196 L
.49665 .13242 L
.49665 .13292 L
.49665 .1332 L
.49665 .13346 L
.49665 .1337 L
Mistroke
.49665 .13394 L
.49665 .13415 L
.49665 .13438 L
.49665 .13463 L
.49665 .13489 L
.49665 .13514 L
.49665 .13537 L
.49665 .13735 L
.49665 .13783 L
.49665 .13808 L
.49665 .13835 L
.49665 .13849 L
.49665 .13865 L
.49665 .13892 L
.49665 .13919 L
.49665 .13945 L
.49665 .1396 L
.49665 .13975 L
.49665 .1399 L
.49665 .14004 L
.49665 .14029 L
.49665 .14057 L
.49665 .14113 L
.49665 .14176 L
.49665 .14286 L
.49665 .14389 L
.49664 .14786 L
.49663 .14996 L
.49663 .15102 L
.49663 .15163 L
.49663 .15219 L
.49662 .15277 L
.49662 .15308 L
.49662 .1534 L
.49662 .15368 L
.49662 .15394 L
.49662 .15409 L
.49662 .15423 L
.49662 .15439 L
.49662 .15454 L
.49662 .1548 L
.49662 .15508 L
.49662 .15532 L
.49662 .15558 L
.49662 .15617 L
.49663 .15672 L
.49663 .15877 L
.49663 .15933 L
.49663 .15993 L
.49663 .16022 L
Mistroke
.49663 .1605 L
.49663 .16074 L
.49663 .16101 L
.49663 .16128 L
.49663 .16143 L
.49663 .16157 L
.49663 .16172 L
.49663 .16186 L
.49663 .16202 L
.49663 .16216 L
.49663 .16243 L
.49663 .16267 L
.49663 .16323 L
.49663 .16371 L
.49663 .16425 L
.49662 .16534 L
.49662 .16738 L
.49662 .16929 L
.49661 .17139 L
.49661 .17254 L
.49661 .1731 L
.49661 .1736 L
.49661 .17404 L
.49661 .17452 L
.49661 .17478 L
.49661 .17502 L
.49661 .17525 L
.49661 .17549 L
.49661 .17574 L
.49661 .17597 L
.49661 .17624 L
.49661 .17649 L
.49661 .17675 L
.49661 .1769 L
.49661 .17704 L
.49661 .17729 L
.49661 .17756 L
.49661 .17811 L
.49661 .1787 L
.49661 .17976 L
.49661 .18214 L
.49661 .18313 L
.49661 .18368 L
.49661 .18419 L
.49661 .18449 L
.49661 .18464 L
.49661 .18481 L
.49661 .18494 L
.49661 .18509 L
.49661 .18536 L
Mistroke
.49661 .18563 L
.49661 .18578 L
.49661 .18592 L
.49661 .18619 L
.49661 .18645 L
.49661 .18671 L
.49661 .187 L
.49661 .18752 L
.49661 .18849 L
.49661 .18963 L
.49661 .19067 L
.4966 .1946 L
.4966 .1956 L
.4966 .19668 L
.4966 .1972 L
.4966 .19769 L
.4966 .19813 L
.4966 .19862 L
.4966 .19889 L
.4966 .19914 L
.4966 .19942 L
.4966 .19958 L
.4966 .19973 L
.4966 .2 L
.4966 .20016 L
.4966 .2003 L
.4966 .20045 L
.4966 .20059 L
.4966 .20091 L
.4966 .20143 L
.4966 .202 L
.4966 .20303 L
.4966 .20718 L
.49661 .20832 L
.49661 .20895 L
.49661 .20955 L
.49661 .2101 L
.49661 .21041 L
.49661 .21056 L
.49661 .2107 L
.49661 .21097 L
.49661 .21122 L
.49661 .21148 L
.49661 .21162 L
.49661 .21176 L
.49661 .21202 L
.49661 .21225 L
.49661 .21252 L
.49661 .21277 L
.49661 .21322 L
Mistroke
.49661 .21371 L
.49661 .21482 L
.4966 .21585 L
.4966 .21808 L
.4966 .22017 L
.4966 .22111 L
.4966 .22209 L
.4966 .22261 L
.4966 .22288 L
.4966 .22317 L
.4966 .22344 L
.4966 .22368 L
.4966 .22393 L
.4966 .22416 L
.4966 .22441 L
.4966 .22469 L
.4966 .22484 L
.4966 .22499 L
.4966 .22526 L
.4966 .22553 L
.4966 .22579 L
.4966 .22627 L
.4966 .22684 L
.4966 .22737 L
.4966 .22856 L
.4966 .23259 L
.49661 .2347 L
.49661 .23577 L
.49661 .23694 L
.49661 .23753 L
.49661 .23786 L
.49661 .23817 L
.49661 .23846 L
.49661 .23863 L
.49661 .23878 L
.49661 .23904 L
.49661 .23918 L
.49661 .23933 L
.49661 .23947 L
.49661 .23961 L
.49661 .23987 L
.49661 .24015 L
.49661 .24046 L
.49661 .24101 L
.49661 .24152 L
.49661 .24262 L
.49661 .24361 L
.4966 .24583 L
.4966 .24783 L
.4966 .24884 L
Mistroke
.4966 .24941 L
.4966 .24966 L
.4966 .24994 L
.4966 .2501 L
.4966 .25024 L
.4966 .25038 L
.4966 .25053 L
.4966 .25078 L
.4966 .25106 L
.4966 .25121 L
.4966 .25136 L
.4966 .25151 L
.4966 .25168 L
.4966 .25195 L
.4966 .25226 L
.4966 .25279 L
.4966 .25336 L
.4966 .25439 L
.4966 .25553 L
.49661 .25658 L
.49661 .25895 L
.49661 .26117 L
.49661 .26325 L
.49661 .26424 L
.49661 .26518 L
.49661 .2657 L
.49661 .26626 L
.49661 .26678 L
.49661 .26726 L
.49661 .26754 L
.49661 .26784 L
.49661 .26811 L
.49661 .26836 L
.49661 .26864 L
.49661 .26879 L
.49661 .26894 L
.49661 .26909 L
.49661 .26923 L
.49661 .26939 L
.49661 .26954 L
.49661 .2698 L
.49661 .27007 L
.49661 .2703 L
.49661 .27056 L
.49661 .27166 L
.49661 .27385 L
.49661 .27504 L
.49661 .27615 L
.49661 .27664 L
.49661 .2771 L
Mistroke
.49661 .27736 L
.49661 .27763 L
.49661 .27788 L
.49661 .27811 L
.49661 .27837 L
.49661 .27861 L
.49661 .27887 L
.49661 .27902 L
.49661 .27916 L
.49661 .27943 L
.49661 .27972 L
.49661 .28026 L
.49661 .28077 L
.49661 .28125 L
.49661 .28234 L
.49661 .28341 L
.49661 .28455 L
.49662 .28853 L
.49662 .29272 L
.49662 .29387 L
.49662 .2951 L
.49662 .29625 L
.49662 .29731 L
.49663 .29783 L
.49663 .2984 L
.49663 .29898 L
.49663 .29929 L
.49663 .29959 L
.49663 .29984 L
.49663 .30012 L
.49663 .30027 L
.49663 .30042 L
.49663 .3007 L
.49663 .30096 L
.49663 .3012 L
.49663 .30148 L
.49663 .30174 L
.49663 .30197 L
.49663 .30223 L
.49663 .30274 L
.49663 .30367 L
.49663 .30467 L
.49663 .3052 L
.49663 .30576 L
.49663 .30604 L
.49663 .30635 L
.49663 .30662 L
.49663 .30688 L
.49663 .30715 L
.49663 .30739 L
Mistroke
.49663 .30766 L
.49663 .30794 L
.49663 .30818 L
.49663 .30844 L
.49663 .30889 L
.49663 .30944 L
.49663 .30993 L
.49663 .31104 L
.49663 .31166 L
.49663 .31223 L
.49663 .3144 L
.49663 .31647 L
.49663 .31841 L
.49664 .32282 L
.49664 .32504 L
.49664 .32715 L
.49664 .32905 L
.49664 .33012 L
.49664 .33111 L
.49664 .3322 L
.49664 .33281 L
.49664 .33338 L
.49664 .33387 L
.49664 .33441 L
.49664 .33498 L
.49664 .33551 L
.49664 .33649 L
.49664 .33743 L
.49664 .33794 L
.49664 .3385 L
.49664 .33901 L
.49664 .33948 L
.49664 .34048 L
.49664 .34104 L
.49664 .34155 L
.49664 .34348 L
.49664 .34456 L
.49664 .34574 L
.49664 .34788 L
.49665 .35243 L
.49665 .35656 L
.49665 .35863 L
.49666 .36086 L
.49666 .36189 L
.49666 .36297 L
.49666 .36491 L
.49666 .36597 L
.49666 .36694 L
.49666 .3691 L
.49666 .371 L
Mistroke
.49666 .37302 L
.49666 .37402 L
.49666 .37513 L
.49666 .37709 L
.49666 .37938 L
.49666 .38152 L
.49667 .38978 L
.49668 .39856 L
.49668 .40295 L
.49668 .40508 L
.49668 .40702 L
.49669 .40905 L
.49669 .41096 L
.49669 .41297 L
.4967 .41516 L
.4967 .41718 L
.49671 .4194 L
.49673 .42389 L
.49676 .42804 L
.4968 .4325 L
.49686 .43702 L
.49693 .44132 L
.49703 .44555 L
.49713 .44948 L
.49744 .45784 L
.49787 .46673 L
.49837 .4753 L
.49889 .48354 L
.49948 .4923 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe_ooooo1?l0003ooooooe3o
oooo003ooooooeoooooo0ol0003oooooodgooooo003oooooof;ooooo1?l0003oooooodWooooo003o
ooooofKooooo2?l0003ooooood7ooooo003oooooofkooooo1ol0003ooooooc[ooooo003oooooogGo
oooo1Ol0003oooooocGooooo003oooooog[ooooo2ol0003oooooob[ooooo003oooooohGooooo4?l0
003ooooooa[ooooo003ooooooiGooooo3_l0003oooooo`cooooo003ooooooj?ooooo3?l0003ooooo
o`00oooooon_ooooo`_o0000m?ooool00?oooooo^_ooool>o`000>Kooooo003oooooolSooooo3Ol0
003Iooooo`00oooooooEooooo`Wo0000d?ooool00?oooooog_ooool3o`000<gooooo003oooooon7o
oooo1?l00039ooooo`00oooooooTooooo`;o0000b?ooool00?oooooohoooool3o`000<Sooooo003o
ooooomcooooo1ol0003;ooooo`00oooooooCooooo`Wo0000d_ooool00?ooooooaoooool<o`000=_o
oooo003ooooookoooooo2?l0003Wooooo`00oooooonbooooo`go0000koooool00?ooooooX?oooolB
o`000?cooooo003ooooooi?ooooo3Ol0003oooooo`oooooo003oooooohcooooo1ol0003ooooooaco
oooo003ooooooh;ooooo2_l0003oooooob?ooooo003oooooogKooooo3?l0003oooooobgooooo003o
ooooofoooooo1ol0003oooooocWooooo003oooooof_ooooo1?l0003ooooood3ooooo003oooooofKo
oooo1Ol0003oooooodCooooo003oooooof7ooooo1Ol0003oooooodWooooo003ooooooecooooo1Ol0
003oooooodkooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomIoooo
o`;o0000oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeKooooo0_l0003ooooooeOooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomEooooo`;o0000oooooomHoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo
[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooool@ooooo`?o000000?o410@ooooooooool0oooooonIooooo`00oooo
oolBooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l0
0006ooooo`03o`000?nj^[[ooooo0?ooooooKOooool00?oooooo4_ooool00onHV9So<S8booooo`06
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S;o
ooooofkooooo003ooooooa;ooooo00?ogMgMo`000?nj^[X01_ooool00ol0003oooooooooo`02oooo
o`Go00000oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool0
0ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o
<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool01_l@413o<S8bo`000?l0003o
410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4
A?o<c<`0ooooool@ooooo`00oooooolBooooo`03oeEEEOmgMgOoA4A400Kooooo00?o0000oooooooo
ool00_ooool2ogMgM`;ooooo00Oo0000ooooooooooooooooolc<c?l0003o410@00Gooooo00Go410@
okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo
00Oooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoM
gMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0J
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1Oooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`00
0?ooooooooooooooool000003_ooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Oo
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3o
oooooa?ooooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo
ooooooooool000003Oooool00ol@413o0000okZj^P04ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go
00002Oooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo
00?ooooo00?o0000ooooooooool02_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Ko
k^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@
ooooo`00oooooolKooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0003oooooooooo`3ooooooc3ooooo003o
oooooa_ooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooo
oooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
1?ooool4o`000?oooooo;oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49994 0 m
.49998 .00099 L
.5 .00147 L
.50001 .0017 L
.50001 .00192 L
.50001 .00217 L
.50001 .00245 L
.49999 .00293 L
.49999 .00318 L
.49999 .00346 L
.49999 .0036 L
.49999 .00375 L
.49999 .00402 L
.5 .00456 L
.50001 .00471 L
.50001 .00487 L
.50001 .00501 L
.50001 .00515 L
.50001 .00542 L
.50001 .00557 L
.50001 .00571 L
.50001 .00596 L
.5 .00623 L
.5 .00669 L
.49999 .00695 L
.49999 .00719 L
.49999 .00747 L
.49999 .00774 L
.49999 .00798 L
.49999 .00825 L
.5 .00881 L
.5 .00911 L
.50001 .00942 L
.50001 .00969 L
.50001 .00985 L
.50001 .00999 L
.50001 .01025 L
.50001 .01052 L
.50001 .01067 L
.50001 .01083 L
.50001 .01112 L
.5 .01166 L
.5 .01195 L
.49999 .01226 L
.49999 .01244 L
.49999 .01261 L
.49999 .01277 L
.49999 .01292 L
.49999 .0132 L
.49999 .01345 L
Mistroke
.49999 .01372 L
.49999 .01388 L
.49999 .01402 L
.5 .01457 L
.5 .01517 L
.50001 .01545 L
.50001 .01573 L
.50001 .01598 L
.50001 .01624 L
.50001 .01649 L
.50001 .01676 L
.50001 .01702 L
.50001 .01725 L
.50001 .0175 L
.50001 .01774 L
.5 .01828 L
.5 .01885 L
.49999 .0191 L
.49999 .01937 L
.49999 .01961 L
.49999 .01983 L
.49999 .02007 L
.49999 .02032 L
.49999 .02059 L
.49999 .02085 L
.49999 .02108 L
.5 .02133 L
.50001 .02246 L
.50002 .02364 L
.50004 .02475 L
.50005 .02528 L
.50006 .02577 L
.50007 .02627 L
.50009 .02681 L
.50012 .02728 L
.50016 .02779 L
.5002 .02832 L
.50026 .02882 L
.50035 .02937 L
.50047 .02996 L
.50074 .03095 L
.50093 .03145 L
.50118 .032 L
.50176 .03297 L
.50252 .03387 L
.50376 .03495 L
.50568 .03612 L
.50819 .03722 L
.51127 .03824 L
.5148 .03915 L
Mistroke
.51965 .04016 L
.5331 .0422 L
.54274 .04331 L
.5535 .04437 L
.57791 .04635 L
.64732 .05081 L
.68002 .05286 L
.69623 .05399 L
.70965 .05504 L
.72014 .05603 L
.72473 .05656 L
.72884 .05711 L
.73169 .05757 L
.73413 .05808 L
.73497 .0583 L
.73572 .05854 L
.73627 .05877 L
.73665 .05897 L
.73695 .05922 L
.73706 .05946 L
.73699 .05972 L
.73671 .06 L
.73621 .06028 L
.73588 .06042 L
.73545 .06057 L
.7335 .06109 L
.731 .06158 L
.72764 .06211 L
.71991 .06305 L
.69328 .06538 L
.66294 .06749 L
.59645 .07193 L
.57136 .07388 L
.54864 .07603 L
.53182 .07809 L
.52019 .08002 L
.51152 .08206 L
.50798 .0832 L
.50541 .08425 L
.50342 .08527 L
.50176 .08636 L
.50055 .08738 L
.4997 .08831 L
.49893 .08941 L
.49833 .0906 L
.49792 .09172 L
.49764 .09274 L
.49745 .09375 L
.4973 .09483 L
.4972 .09585 L
Mistroke
.49713 .09677 L
.49708 .09786 L
.49705 .09848 L
.49703 .09905 L
.49701 .10009 L
.49699 .10119 L
.49696 .1032 L
.49693 .10536 L
.49692 .1074 L
.49691 .10927 L
.4969 .11029 L
.4969 .11137 L
.49689 .11332 L
.49689 .11563 L
.49688 .11775 L
.49687 .11994 L
.49686 .12232 L
.49685 .12454 L
.49684 .12662 L
.49683 .12856 L
.49683 .13064 L
.49683 .13295 L
.49682 .13505 L
.49681 .13913 L
.49681 .14143 L
.4968 .14356 L
.49679 .14548 L
.49679 .14755 L
.49678 .14873 L
.49678 .14981 L
.49678 .15194 L
.49677 .15633 L
.49677 .1604 L
.49676 .16459 L
.49675 .16854 L
.49675 .17063 L
.49675 .17174 L
.49674 .17291 L
.49674 .17497 L
.49674 .17688 L
.49674 .17889 L
.49674 .18105 L
.49674 .1831 L
.49673 .18496 L
.49673 .18937 L
.49673 .19151 L
.49672 .19345 L
.49672 .19443 L
.49672 .19549 L
.49672 .19741 L
Mistroke
.49672 .19847 L
.49672 .1996 L
.49672 .20162 L
.49672 .20365 L
.49672 .20478 L
.49672 .20582 L
.49672 .20783 L
.49671 .20974 L
.49671 .21363 L
.49671 .21585 L
.49671 .21793 L
.49671 .21892 L
.49671 .21997 L
.49671 .22111 L
.49671 .22216 L
.49671 .2227 L
.49671 .22327 L
.49671 .22381 L
.49671 .2243 L
.49671 .22488 L
.49671 .22521 L
.49671 .22551 L
.49671 .22606 L
.49671 .22665 L
.49671 .22719 L
.49671 .2277 L
.49671 .22816 L
.49671 .22867 L
.49671 .22921 L
.49671 .22979 L
.49671 .23029 L
.49671 .23083 L
.49671 .2318 L
.4967 .23285 L
.4967 .23475 L
.4967 .23894 L
.4967 .24115 L
.4967 .24237 L
.4967 .24352 L
.4967 .24462 L
.4967 .2452 L
.4967 .24582 L
.4967 .24633 L
.4967 .2469 L
.4967 .24742 L
.4967 .2479 L
.4967 .24815 L
.4967 .24843 L
.4967 .24868 L
.4967 .24893 L
Mistroke
.4967 .24916 L
.4967 .24938 L
.4967 .24963 L
.4967 .24986 L
.4967 .25012 L
.4967 .25039 L
.4967 .25088 L
.4967 .25198 L
.4967 .25416 L
.4967 .25523 L
.4967 .25622 L
.4967 .2571 L
.4967 .25757 L
.4967 .25807 L
.4967 .25833 L
.4967 .25858 L
.4967 .25882 L
.4967 .25905 L
.4967 .25929 L
.4967 .25955 L
.4967 .25981 L
.4967 .26009 L
.4967 .26037 L
.4967 .26063 L
.4967 .26091 L
.4967 .26121 L
.4967 .26172 L
.4967 .26227 L
.4967 .2633 L
.4967 .26425 L
.4967 .26655 L
.4967 .26872 L
.4967 .26973 L
.4967 .2708 L
.4967 .27141 L
.4967 .27197 L
.4967 .27253 L
.4967 .27278 L
.4967 .27306 L
.4967 .27331 L
.4967 .27354 L
.4967 .27378 L
.4967 .27405 L
.4967 .27429 L
.4967 .27452 L
.4967 .27473 L
.4967 .27496 L
.4967 .27521 L
.4967 .27548 L
.4967 .27603 L
Mistroke
.4967 .27654 L
.4967 .27701 L
.4967 .27923 L
.4967 .28133 L
.4967 .28529 L
.4967 .28733 L
.4967 .28846 L
.4967 .28951 L
.4967 .2905 L
.4967 .29102 L
.4967 .29157 L
.4967 .29204 L
.4967 .29255 L
.4967 .29301 L
.4967 .29344 L
.4967 .29398 L
.4967 .29426 L
.4967 .29456 L
.4967 .2948 L
.4967 .29506 L
.4967 .29535 L
.4967 .29562 L
.4967 .29586 L
.4967 .29612 L
.4967 .29665 L
.4967 .29689 L
.4967 .29714 L
.4967 .29738 L
.4967 .2976 L
.4967 .29788 L
.4967 .29818 L
.4967 .29843 L
.4967 .2987 L
.4967 .299 L
.4967 .29932 L
.4967 .2999 L
.4967 .30048 L
.4967 .30103 L
.4967 .30207 L
.4967 .30314 L
.4967 .30412 L
.4967 .3063 L
.4967 .30833 L
.4967 .31023 L
.49671 .31847 L
.49671 .32273 L
.49671 .32488 L
.49671 .32723 L
.49671 .33175 L
.49671 .33587 L
Mistroke
.49671 .34014 L
.49671 .34419 L
.49672 .35238 L
.49672 .35652 L
.49672 .35872 L
.49672 .36109 L
.49672 .36335 L
.49672 .36542 L
.49673 .36753 L
.49673 .36948 L
.49674 .37353 L
.49674 .37567 L
.49675 .37795 L
.49676 .38014 L
.49677 .38252 L
.49678 .38457 L
.49679 .38682 L
.49683 .39107 L
.49689 .39556 L
.49696 .39972 L
.49707 .40419 L
.49735 .41301 L
.49772 .4215 L
.49815 .42968 L
.49861 .43837 L
.49903 .44675 L
.49939 .45565 L
.49954 .46011 L
.49965 .46422 L
.49974 .46849 L
.49981 .47247 L
.49987 .4765 L
.49991 .48092 L
.49994 .48528 L
.49996 .48924 L
.49998 .49333 L
.49999 .49777 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`;o0000oooooomEooooo`00oooooomIooooo`;o0000oooooomDooooo`00oooooomKooooo`?o0000
oooooomAooooo`00oooooomNooooo`;o0000oooooom?ooooo`00oooooomPooooo`Wo0000oooooom6
ooooo`00oooooomYooooo`Oo0000ooooooloooooo`00oooooom`ooooo`Oo0000oooooolhooooo`00
oooooomgooooo`_o0000ooooool]ooooo`00oooooon2ooooo`oo0000oooooolNooooo`00oooooonA
ooooo`oo0000ooooool?ooooo`00oooooonPooooo`oo0000ooooool00?oooooo[ooooolBo`000>go
oooo003ooooool7ooooo3ol0003Nooooo`00ooooooo@ooooo`[o0000e?ooool00?oooooof_ooool<
o`000<Sooooo003oooooonKooooo1_l00032ooooo`00ooooooo/ooooo`?o0000_oooool00?oooooo
kOooool2o`000;oooooo003oooooonKooooo1ol00031ooooo`00oooooooKooooo`_o0000b?ooool0
0?oooooocOooool>o`000=?ooooo003oooooolCooooo2Ol0003Qooooo`00oooooondoooooa3o0000
j_ooool00?ooooooWooooolEo`000?[ooooo003ooooooi3ooooo3ol0003ooooooa3ooooo003ooooo
ohSooooo2?l0003ooooooaoooooo003ooooooggooooo2ol0003oooooobOooooo003oooooog7ooooo
3?l0003ooooooc;ooooo003oooooofWooooo2?l0003oooooockooooo003oooooofKooooo0ol0003o
ooooodKooooo003oooooof7ooooo1Ol0003oooooodWooooo003ooooooegooooo1?l0003oooooodko
oooo003ooooooe[ooooo0ol0003ooooooe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomGooooo`;o0000oooooomFooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@
4?oooooooooo0?ooooooU_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003o
oooooaGooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`03ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj
00Oooooo00Co0000oooooooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Oooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oo
oooo5?ooool00?oooooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?ooooooooooooooo`;o
MgMg0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Oooooo00?o0000ooooooooool02?ooool01_l0003oZJVYoooooooooooo^[Zjo`0000;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@
oooooolDooooo`00oooooolDooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003ooooo
ooooo`02ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00002_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooooaOooooo003ooooooaCooooo00GoIVIVohN7QoooooooV9RHoeEEE@06oooo
o`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000[ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooooaOooooo003ooooooa?ooooo
00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`05o`000?ooooooooooooooool0
00000_ooool00olb<S;oQhN7ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool0000:ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooooaCooooo003o
oooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
2Oooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?ooool00?oo
oooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00003oooooocCooooo003ooooooaoooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo0?oooooo<oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.45) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49998 0 m
.49999 .00099 L
.5 .00122 L
.5 .00147 L
.50001 .0017 L
.50001 .00192 L
.5 .00217 L
.5 .00245 L
.5 .00268 L
.5 .00293 L
.49999 .0032 L
.5 .00345 L
.5 .0036 L
.5 .00374 L
.5 .00402 L
.5 .00428 L
.5 .00452 L
.5 .00466 L
.50001 .00481 L
.50001 .00507 L
.5 .00531 L
.5 .00557 L
.5 .00604 L
.5 .0063 L
.5 .00659 L
.49999 .00685 L
.49999 .00709 L
.49999 .00724 L
.5 .00738 L
.5 .00753 L
.5 .00769 L
.5 .00825 L
.5 .00852 L
.5 .0088 L
.50001 .00905 L
.50001 .00931 L
.50001 .00946 L
.50001 .0096 L
.50001 .00976 L
.5 .00991 L
.5 .01017 L
.5 .01046 L
.5 .01098 L
.5 .01127 L
.5 .01153 L
.5 .01176 L
.5 .01201 L
.5 .01228 L
.5 .01253 L
.5 .01268 L
Mistroke
.5 .01282 L
.5 .01313 L
.50001 .01369 L
.50001 .01429 L
.50002 .01495 L
.50004 .01557 L
.50005 .01613 L
.50007 .01668 L
.50008 .01695 L
.5001 .01725 L
.50014 .01779 L
.50017 .01809 L
.5002 .01837 L
.50028 .01889 L
.50039 .01943 L
.50052 .01992 L
.50068 .02038 L
.5009 .02088 L
.5012 .02142 L
.50158 .02197 L
.50211 .02256 L
.50283 .02318 L
.50367 .02376 L
.50573 .02479 L
.50725 .02537 L
.50891 .02589 L
.51312 .02693 L
.51916 .02803 L
.52586 .02897 L
.53507 .03 L
.56339 .0323 L
.59938 .03444 L
.6793 .03842 L
.71744 .04052 L
.73273 .04157 L
.73992 .04219 L
.74535 .04275 L
.74974 .04333 L
.75151 .04364 L
.75296 .04396 L
.75389 .04424 L
.75446 .0445 L
.75466 .04465 L
.75476 .04479 L
.75479 .04495 L
.75471 .0451 L
.75436 .04536 L
.75369 .04564 L
.75287 .04588 L
.7517 .04614 L
Mistroke
.74817 .04673 L
.74372 .04728 L
.73204 .04836 L
.71845 .04935 L
.68085 .05157 L
.60085 .05597 L
.56867 .05811 L
.54572 .06006 L
.53644 .06103 L
.52799 .06209 L
.51641 .06401 L
.51172 .06507 L
.50787 .0662 L
.50533 .06716 L
.50317 .06822 L
.50147 .06934 L
.50029 .0704 L
.4995 .07135 L
.49887 .07239 L
.49839 .07351 L
.4982 .07408 L
.49804 .07471 L
.49792 .07524 L
.49782 .07581 L
.49768 .07685 L
.49763 .07737 L
.49758 .07791 L
.49751 .0789 L
.49746 .08007 L
.49742 .08114 L
.49737 .08346 L
.49733 .08564 L
.4973 .08772 L
.49728 .08992 L
.49725 .09386 L
.49718 .10196 L
.49713 .11058 L
.49708 .11887 L
.49703 .12769 L
.497 .13619 L
.49698 .14048 L
.49697 .14234 L
.49696 .14436 L
.49696 .14653 L
.49695 .14857 L
.49695 .15071 L
.49695 .15306 L
.49693 .15733 L
.49692 .16183 L
.49691 .16397 L
Mistroke
.4969 .16601 L
.4969 .16835 L
.4969 .17048 L
.49689 .17438 L
.49689 .1766 L
.49688 .17868 L
.49687 .18291 L
.49687 .18521 L
.49686 .1874 L
.49686 .18947 L
.49686 .19064 L
.49686 .19172 L
.49685 .19364 L
.49685 .19568 L
.49685 .19787 L
.49685 .19903 L
.49685 .20025 L
.49685 .20249 L
.49684 .20456 L
.49683 .2088 L
.49683 .21065 L
.49683 .21266 L
.49683 .21377 L
.49683 .2148 L
.49683 .21585 L
.49682 .21683 L
.49682 .21786 L
.49682 .21899 L
.49682 .2201 L
.49682 .22129 L
.49682 .22228 L
.49682 .22334 L
.49682 .22449 L
.49682 .22557 L
.49682 .22679 L
.49682 .22793 L
.49682 .23008 L
.49681 .23399 L
.49681 .23621 L
.49681 .23829 L
.49681 .23934 L
.49681 .24033 L
.4968 .24148 L
.4968 .24253 L
.4968 .24307 L
.4968 .24365 L
.4968 .24393 L
.4968 .24419 L
.4968 .24442 L
.4968 .24468 L
Mistroke
.4968 .24497 L
.4968 .24512 L
.4968 .24527 L
.4968 .24553 L
.4968 .24581 L
.4968 .24596 L
.4968 .24614 L
.4968 .2463 L
.4968 .24644 L
.4968 .24673 L
.4968 .24703 L
.4968 .248 L
.4968 .24854 L
.4968 .24903 L
.4968 .24929 L
.4968 .24957 L
.4968 .24973 L
.4968 .24988 L
.4968 .25016 L
.4968 .25042 L
.4968 .25065 L
.4968 .25091 L
.4968 .25119 L
.4968 .25165 L
.4968 .25215 L
.4968 .25262 L
.4968 .25305 L
.4968 .2541 L
.4968 .2551 L
.4968 .25715 L
.4968 .25934 L
.4968 .26327 L
.49679 .26527 L
.49679 .26632 L
.49679 .26742 L
.49679 .26839 L
.49679 .26891 L
.49679 .26946 L
.49679 .26996 L
.49679 .27042 L
.49679 .27065 L
.49679 .27089 L
.49679 .27111 L
.49679 .27132 L
.49679 .27159 L
.49679 .27184 L
.49679 .27207 L
.49679 .27232 L
.49679 .27259 L
.49679 .27287 L
Mistroke
.49679 .27339 L
.49679 .2744 L
.49679 .27532 L
.49679 .27762 L
.49679 .27863 L
.49679 .27916 L
.49679 .27973 L
.49679 .28001 L
.49679 .28027 L
.49679 .28051 L
.49679 .28076 L
.49679 .28101 L
.49679 .28127 L
.49679 .28149 L
.49679 .28173 L
.49679 .282 L
.49679 .28225 L
.49679 .28253 L
.49679 .28282 L
.49679 .28331 L
.49679 .28384 L
.49679 .28496 L
.49679 .28614 L
.49679 .28829 L
.49679 .29254 L
.49679 .29478 L
.49679 .29591 L
.49679 .29656 L
.49679 .29715 L
.49679 .29772 L
.49679 .29826 L
.49678 .29855 L
.49678 .29883 L
.49678 .29899 L
.49678 .29913 L
.49678 .29929 L
.49678 .29945 L
.49678 .29971 L
.49678 .29999 L
.49678 .30022 L
.49678 .30048 L
.49678 .30076 L
.49679 .30106 L
.49679 .3016 L
.49679 .3027 L
.49679 .30374 L
.49679 .30569 L
.49679 .30757 L
.49679 .30959 L
.49679 .31075 L
Mistroke
.49679 .31181 L
.49679 .31232 L
.49679 .31259 L
.49679 .31288 L
.49679 .31315 L
.49679 .3134 L
.49679 .31365 L
.49679 .31389 L
.49679 .31414 L
.49679 .3144 L
.49679 .31469 L
.49679 .31495 L
.49679 .31519 L
.49679 .31542 L
.49679 .31592 L
.49679 .31646 L
.49679 .31705 L
.49679 .31812 L
.49679 .32026 L
.49679 .32139 L
.49679 .32199 L
.49679 .32261 L
.49679 .32315 L
.49679 .32344 L
.49679 .32375 L
.49679 .32403 L
.49679 .32429 L
.49679 .32454 L
.49679 .32479 L
.49679 .32504 L
.49679 .3253 L
.49679 .32552 L
.49679 .32577 L
.49679 .32603 L
.49679 .32632 L
.49679 .32683 L
.49679 .32741 L
.49679 .32803 L
.49679 .32917 L
.49679 .33029 L
.49679 .33132 L
.49679 .33358 L
.4968 .3357 L
.4968 .33761 L
.49681 .33968 L
.49683 .34394 L
.49684 .34609 L
.49686 .34844 L
.4969 .35261 L
.49693 .35495 L
Mistroke
.49696 .35708 L
.49704 .36116 L
.49716 .3656 L
.49748 .37431 L
.49789 .3827 L
.49834 .39077 L
.49883 .39936 L
.49925 .40763 L
.49944 .41183 L
.49961 .41642 L
.49974 .42086 L
.49984 .42489 L
.49991 .42908 L
.49998 .43356 L
.50002 .43766 L
.50004 .43997 L
.50005 .4421 L
.50006 .44404 L
.50007 .44611 L
.50007 .4473 L
.50008 .44839 L
.50008 .44942 L
.50008 .45052 L
.50008 .45163 L
.50008 .45263 L
.50008 .45312 L
.50008 .45337 L
.50008 .45364 L
.50008 .45388 L
.50008 .45414 L
.50008 .45437 L
.50008 .45459 L
.50008 .45487 L
.50008 .45502 L
.50008 .45517 L
.50008 .45543 L
.50008 .45571 L
.50008 .45596 L
.50008 .4562 L
.50008 .45673 L
.50008 .45731 L
.50008 .45783 L
.50008 .45902 L
.50008 .46112 L
.50008 .46307 L
.50007 .4675 L
.50005 .47585 L
.50004 .48473 L
.50002 .49329 L
.5 .5 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool2o`000?ooooooE_ooool00?ooooooF?ooool2o`000?ooooooEOooool00?ooooooFOooool3
o`000?ooooooDoooool00?ooooooG?ooool3o`000?ooooooD?ooool00?ooooooGoooool7o`000?oo
ooooBOooool00?ooooooI_ooool5o`000?ooooooA?ooool00?ooooooJoooool<o`000?oooooo>?oo
ool00?ooooooMoooool?o`000?oooooo:Oooool00?ooooooQ_ooool;o`000?oooooo7_ooool00?oo
ooooTOoooolCo`000?oooooo2oooool00?ooooooY?oooolIo`000?7ooooo003ooooookgooooo6_l0
003Gooooo`00oooooooGoooooa7o0000a_ooool00?ooooooj?ooool;o`000;_ooooo003ooooooo?o
oooo1Ol0002fooooo`00ooooooohooooo`?o0000/oooool00?oooooom?ooool6o`000;Cooooo003o
ooooonOooooo3Ol0002jooooo`00oooooooFoooooa7o0000aoooool00?oooooo`_oooolDo`000=So
oooo003ooooook7ooooo4Ol0003/ooooo`00oooooonPoooooa7o0000oOooool00?ooooooT_ooool>
o`000?oooooo3oooool00?ooooooR?ooool:o`000?oooooo7Oooool00?ooooooO?ooool<o`000?oo
oooo9oooool00?ooooooK?ooool@o`000?oooooo<oooool00?ooooooIOooool7o`000?oooooo@ooo
ool00?ooooooH?ooool5o`000?ooooooB_ooool00?ooooooGOooool3o`000?ooooooCoooool00?oo
ooooF_ooool3o`000?ooooooD_ooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeOooooo0_l0003ooooooeKooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo
003ooooooa;ooooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Kooooo00?o0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooK_ooool00?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo
00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003ooooo
ooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Oooooo
00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo410@
oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05
oa0@4?ooooooooooooooool@41002oooool5o`0000Sooooo00?o0000ooooooooool01oooool01Onj
^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa?ooooo003ooooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooo
oooo00Cooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool01oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo4oooool00?oo
oooo4?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooolb<S;oQhN700_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06o`00
0?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol0003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03
oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o
00006Oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001Oooool00ol0
003oooooooooo`0:ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooa3ooooo003ooooo
oa_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001Oooool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Coooo
o`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Cooooo1?l0003ooooooboooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50004 0 m
.50001 .00099 L
.5 .00147 L
.5 .0017 L
.49999 .00192 L
.49999 .00217 L
.49999 .00245 L
.5 .00268 L
.5 .00293 L
.50001 .00318 L
.50001 .00345 L
.50001 .0036 L
.50001 .00374 L
.50001 .00402 L
.5 .00452 L
.5 .00479 L
.49999 .00505 L
.49999 .0052 L
.49999 .00536 L
.49999 .00564 L
.49999 .00578 L
.49999 .00593 L
.49999 .00619 L
.5 .00643 L
.5 .0067 L
.50001 .00717 L
.50003 .00825 L
.50004 .00854 L
.50005 .00885 L
.50006 .00912 L
.50007 .00941 L
.50009 .00972 L
.50013 .01006 L
.50017 .01038 L
.50021 .01067 L
.50034 .0112 L
.50043 .0115 L
.50054 .01178 L
.50082 .01235 L
.50102 .01267 L
.50124 .01296 L
.50178 .01351 L
.50244 .01402 L
.50338 .01457 L
.50471 .01517 L
.50619 .01568 L
.5079 .01616 L
.51041 .01672 L
.51328 .01725 L
.52099 .01831 L
Mistroke
.53281 .01947 L
.54666 .02049 L
.56518 .02158 L
.65989 .02554 L
.71691 .02774 L
.74206 .0289 L
.75342 .02953 L
.7622 .03012 L
.76833 .03064 L
.77088 .0309 L
.77317 .03119 L
.77424 .03136 L
.77509 .03151 L
.77576 .03165 L
.77635 .03181 L
.77701 .03208 L
.77718 .03223 L
.77722 .03237 L
.77698 .03262 L
.77631 .03289 L
.77541 .03311 L
.77407 .03336 L
.77223 .03363 L
.76982 .03392 L
.76438 .03443 L
.74781 .03557 L
.72806 .03662 L
.67456 .039 L
.62329 .04123 L
.58206 .04331 L
.55231 .04524 L
.52983 .04732 L
.52081 .0485 L
.51433 .04963 L
.50993 .05063 L
.50634 .05173 L
.50388 .05276 L
.50219 .05374 L
.50085 .0548 L
.50029 .0554 L
.49987 .05595 L
.49926 .05699 L
.49901 .05758 L
.49882 .05813 L
.49854 .05924 L
.49842 .05987 L
.49834 .06043 L
.49823 .06147 L
.49819 .06199 L
.49815 .06256 L
Mistroke
.49805 .06453 L
.49801 .06563 L
.49797 .06682 L
.49791 .06897 L
.49786 .07113 L
.49782 .07348 L
.49776 .07777 L
.49768 .08233 L
.49762 .08646 L
.49759 .08853 L
.49757 .09076 L
.49753 .09482 L
.49748 .099 L
.49745 .10121 L
.49743 .10358 L
.49739 .10794 L
.49737 .11202 L
.49733 .11625 L
.49731 .11848 L
.49729 .12085 L
.49726 .12528 L
.49724 .12937 L
.49719 .13743 L
.49718 .13962 L
.49717 .14192 L
.49715 .14602 L
.49712 .15429 L
.4971 .15856 L
.49708 .16243 L
.49708 .16459 L
.49707 .16662 L
.49706 .1711 L
.49704 .17932 L
.49702 .18348 L
.49702 .18569 L
.49701 .18806 L
.497 .19034 L
.497 .19241 L
.497 .19648 L
.49699 .20055 L
.49698 .20285 L
.49698 .20498 L
.49697 .209 L
.49696 .21112 L
.49696 .21335 L
.49696 .21449 L
.49695 .21574 L
.49695 .21793 L
.49695 .22019 L
.49695 .22224 L
Mistroke
.49695 .22439 L
.49694 .22642 L
.49694 .23089 L
.49693 .23479 L
.49692 .23701 L
.49692 .23909 L
.49692 .24113 L
.49692 .24228 L
.49692 .24333 L
.49692 .24443 L
.49692 .24563 L
.49692 .24782 L
.49692 .24895 L
.49692 .25002 L
.49691 .25202 L
.49691 .25314 L
.49691 .25417 L
.49691 .2565 L
.4969 .26085 L
.4969 .26298 L
.4969 .26493 L
.4969 .26589 L
.4969 .26693 L
.4969 .26784 L
.49689 .26884 L
.49689 .26989 L
.49689 .27047 L
.49689 .27102 L
.49689 .27149 L
.49689 .27199 L
.49689 .27225 L
.49689 .27253 L
.49689 .27303 L
.49689 .27331 L
.49689 .27358 L
.49689 .27385 L
.49689 .274 L
.49689 .27415 L
.49689 .27432 L
.49689 .27448 L
.49689 .27463 L
.49689 .27478 L
.49689 .27493 L
.49689 .27509 L
.49689 .27537 L
.49689 .27565 L
.49689 .2758 L
.49689 .27596 L
.49689 .2761 L
.49689 .27625 L
Mistroke
.49689 .27652 L
.49689 .27678 L
.49689 .27706 L
.49689 .27733 L
.49689 .27757 L
.49689 .27782 L
.49689 .2781 L
.49689 .27858 L
.49689 .27911 L
.49689 .27969 L
.49689 .28072 L
.49689 .28169 L
.49689 .28271 L
.49689 .28379 L
.49689 .28571 L
.49689 .2878 L
.49689 .29003 L
.49689 .29117 L
.49689 .29173 L
.49689 .29224 L
.49688 .29271 L
.49688 .29295 L
.49688 .29321 L
.49688 .29346 L
.49688 .2937 L
.49688 .29385 L
.49688 .29399 L
.49688 .29425 L
.49688 .29447 L
.49688 .29472 L
.49688 .29498 L
.49688 .29523 L
.49689 .29566 L
.49689 .29613 L
.49689 .29665 L
.49689 .2972 L
.49689 .29817 L
.49689 .29924 L
.49689 .30021 L
.4969 .30238 L
.4969 .3044 L
.49691 .3063 L
.49692 .30837 L
.49694 .31057 L
.49697 .31451 L
.497 .31652 L
.49703 .31868 L
.4971 .32259 L
.49722 .32711 L
.49736 .3314 L
Mistroke
.49773 .33955 L
.49823 .34824 L
.49875 .35659 L
.49926 .36548 L
.49948 .36993 L
.49966 .37403 L
.49981 .37829 L
.49993 .38227 L
.50002 .38629 L
.50009 .3907 L
.50012 .39294 L
.50014 .39505 L
.50018 .39901 L
.50019 .40108 L
.5002 .40327 L
.50021 .40514 L
.50021 .4072 L
.50021 .40825 L
.50022 .40936 L
.50022 .4103 L
.50022 .41084 L
.50022 .41133 L
.50022 .41161 L
.50022 .41191 L
.50022 .41205 L
.50022 .4122 L
.50022 .41246 L
.50022 .41272 L
.50022 .41295 L
.50022 .41321 L
.50022 .41349 L
.50022 .41364 L
.50022 .41378 L
.50022 .4141 L
.50022 .41439 L
.50022 .41469 L
.50022 .41579 L
.50022 .41635 L
.50022 .41694 L
.50021 .41799 L
.50021 .42037 L
.5002 .42468 L
.50018 .4328 L
.50016 .44145 L
.50014 .44977 L
.50011 .45862 L
.50008 .46714 L
.50006 .47534 L
.50004 .48406 L
.50002 .49246 L
Mistroke
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomIooooo`;o0000oooooomDooooo`00oooooomK
ooooo`Co0000oooooom@ooooo`00oooooomOooooo`[o0000oooooom6ooooo`00oooooomYooooo`Wo
0000oooooolmooooo`00oooooomboooooa[o0000oooooolSooooo`00oooooon<oooooaCo0000oooo
ool?ooooo`00oooooonPoooooaCo0000n_ooool00?oooooo]?oooolLo`000=kooooo003oooooom3o
oooo6_l00034ooooo`00oooooooZoooooa?o0000/Oooool00?oooooooOooool9o`000:Sooooo003o
oooooooooooo1oooool3o`000:Gooooo003ooooooooooooo0oooool6o`000:Kooooo003oooooonoo
oooo4ol0002/ooooo`00oooooooGoooooaSo0000_oooool00?oooooo__oooolIo`000=Oooooo003o
ooooojkooooo4?l0003`ooooo`00oooooonIoooooaGo0000ooooool1ooooo`00oooooon2oooooaOo
0000oooooolFooooo`00oooooomeooooo`go0000ooooool]ooooo`00oooooom^ooooo`Oo0000oooo
ooljooooo`00oooooomWooooo`Oo0000oooooom1ooooo`00oooooomOooooo`So0000oooooom8oooo
o`00oooooomLooooo`?o0000oooooom@ooooo`00oooooomIooooo`?o0000oooooomCooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool2o`000?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@4?oooooooooo0?oooooo
U_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003ooooooaGooooo00?oV9RH
oc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03
ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Sooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oooooo5?ooool00?oo
oooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?ooooooooooooooo`;oMgMg0_ooool00ol0
003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMg
Moooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@oooooolDooooo`00
oooooolDooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`03
oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool0
0ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`07ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolGooooo`00oooooolCooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooooaCooooo003o
oooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
2Oooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?ooool00?oo
oooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`3oooooocCooooo003ooooooaoooooo0_l0000Booooo`03o`000?oooooooooo00Go
oooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co0000oooooolcooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooo
oon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.55) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50009 0 m
.50003 .00099 L
.5 .00147 L
.49999 .0017 L
.49998 .00192 L
.49998 .00217 L
.49999 .00245 L
.50001 .00268 L
.50002 .00293 L
.50005 .00345 L
.50006 .00374 L
.50008 .00402 L
.5001 .00428 L
.50012 .00442 L
.50014 .00456 L
.50018 .0048 L
.50024 .00506 L
.50034 .00532 L
.50045 .00557 L
.50075 .00603 L
.501 .0063 L
.50132 .00659 L
.50209 .0071 L
.50266 .00738 L
.5033 .00765 L
.50523 .00825 L
.50777 .00881 L
.51156 .00942 L
.51636 .00999 L
.52205 .01052 L
.5366 .01153 L
.55822 .01259 L
.58861 .01374 L
.62319 .01481 L
.71222 .01725 L
.74881 .01834 L
.77667 .01935 L
.78767 .01986 L
.79682 .0204 L
.80076 .02072 L
.80359 .02101 L
.80539 .02127 L
.8061 .02142 L
.80656 .02156 L
.80689 .02179 L
.80667 .02203 L
.80592 .02226 L
.80479 .02247 L
.80292 .02272 L
.80025 .02299 L
Mistroke
.79377 .02348 L
.78495 .02399 L
.77353 .02453 L
.74877 .02551 L
.62172 .02979 L
.59244 .03096 L
.56679 .03219 L
.54904 .03326 L
.53425 .0344 L
.52352 .03551 L
.5163 .03652 L
.51099 .03753 L
.50736 .03849 L
.50578 .03903 L
.50442 .03961 L
.50259 .04064 L
.50185 .04121 L
.50129 .04175 L
.50077 .04238 L
.50039 .04297 L
.49992 .04398 L
.49975 .04451 L
.49959 .04508 L
.49947 .04567 L
.49937 .04624 L
.49924 .04729 L
.49915 .04828 L
.49908 .04919 L
.49896 .05124 L
.49878 .05526 L
.49863 .05967 L
.49836 .0683 L
.49818 .0766 L
.498 .08542 L
.49787 .09393 L
.49775 .10211 L
.49766 .11081 L
.49757 .11919 L
.4975 .12724 L
.49743 .13582 L
.49738 .14408 L
.49733 .15285 L
.49728 .16131 L
.49725 .16944 L
.49722 .1781 L
.49718 .18643 L
.49717 .19098 L
.49716 .19528 L
.49713 .20349 L
.49712 .20765 L
Mistroke
.49711 .21222 L
.49709 .22063 L
.49707 .22924 L
.49705 .23752 L
.49705 .24204 L
.49704 .24633 L
.49703 .25449 L
.49703 .25684 L
.49703 .25905 L
.49703 .26001 L
.49703 .26103 L
.49703 .26157 L
.49703 .26185 L
.49703 .26215 L
.49702 .26243 L
.49702 .26268 L
.49702 .26294 L
.49702 .26318 L
.49702 .26342 L
.49702 .26366 L
.49702 .26391 L
.49703 .26419 L
.49703 .26446 L
.49703 .26475 L
.49703 .26526 L
.49703 .26573 L
.49703 .26618 L
.49703 .26718 L
.49703 .26829 L
.49703 .26929 L
.49704 .27038 L
.49704 .27154 L
.49705 .27367 L
.49706 .27564 L
.49708 .27775 L
.49711 .28008 L
.49717 .28424 L
.49721 .28657 L
.49726 .2887 L
.49739 .29277 L
.49756 .2972 L
.49802 .30589 L
.49856 .31426 L
.49914 .32316 L
.49963 .33173 L
.49998 .33998 L
.50011 .34425 L
.50021 .34875 L
.50025 .35078 L
.50028 .35296 L
Mistroke
.50033 .35688 L
.50034 .35906 L
.50036 .36142 L
.50037 .36366 L
.50037 .36465 L
.50037 .36572 L
.50038 .3668 L
.50038 .36779 L
.50038 .36826 L
.50038 .36878 L
.50038 .36926 L
.50038 .36972 L
.50038 .37 L
.50038 .3703 L
.50038 .37055 L
.50038 .37083 L
.50038 .37112 L
.50038 .37129 L
.50038 .37144 L
.50038 .37171 L
.50038 .37187 L
.50038 .372 L
.50038 .37228 L
.50038 .37253 L
.50038 .3728 L
.50038 .37309 L
.50038 .37358 L
.50038 .37413 L
.50038 .37517 L
.50038 .37628 L
.50038 .37825 L
.50037 .38271 L
.50034 .39084 L
.50031 .3995 L
.50028 .40784 L
.50025 .4167 L
.50022 .42523 L
.5002 .43345 L
.50017 .44218 L
.50015 .4506 L
.50012 .45868 L
.50009 .4673 L
.50007 .47558 L
.50004 .4844 L
.50002 .49289 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooF?ooool2o`000?ooooooEOooool00?ooooooF_ooool4
o`000?ooooooDOooool00?ooooooG_ooool=o`000?ooooooA?ooool00?ooooooJoooool;o`000?oo
oooo>Oooool00?ooooooM_oooolVo`000?oooooo4oooool00?ooooooW?oooolIo`000?Wooooo003o
oooookGooooo7?l0003Mooooo`00oooooooAoooooboo0000[_ooool00?ooooooooooool1oooooa;o
0000W?ooool00?oooooooooooolCooooo`[o0000T_ooool00?oooooooooooolFooooo`Oo0000T_oo
ool00?ooooooo_oooolGo`0009Wooooo003oooooonWooooo5Ol0002`ooooo`00ooooooo>oooooa_o
0000aOooool00?oooooo/ooooolKo`000>3ooooo003ooooooh[ooooo:Ol0003kooooo`00ooooooml
ooooo`ko0000oooooolUooooo`00oooooombooooo`[o0000oooooolcooooo`00oooooomTooooo`ko
0000oooooolmooooo`00oooooomPooooo`Co0000oooooom;ooooo`00oooooomKooooo`Go0000oooo
oom?ooooo`00oooooomIooooo`;o0000oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooo
oooo[oooool00?oooooo4?ooool3o`000003oa0@4?oooooooooo0?ooooooVOooool00?oooooo4_oo
ool00ol@413o^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`3oooooofgooooo003ooooooa;ooooo00?oV9RHoc8b<_ooool01_ooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8boooooom^
ooooo`00oooooolBooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool5o`00
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000
ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd00oooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0?oooooo4?ooool00?oooooo4_ooool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooooooo00;o
oooo0_mgMgL2ooooo`07o`000?ooooooooooooooooo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool01oooool01_l0003o
ZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIV
I_mgMgOooooooooooon7QhOo410@ooooool@ooooo`00oooooolAooooo`05omgMgOl@413oooooob4Q
8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3ooooooa?ooooo003ooooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oo
oooooooo00Cooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Gooooo00?oMgMgoc8b<_ooool01oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo4oooool00?oo
oooo4?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooolb<S;oQhN700_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo
00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo4?ooool00?oooooo4?ooool01?l@413o0000
o`000?ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool00_ooool5o`0000Wo
oooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l0
00000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo4?ooool0
0?oooooo6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo<?ooool00?oooooo6oooool2o`00
01?ooooo00?o0000ooooooooool01?ooool2o`0000gooooo00?o0000ooooooooool06_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`Co0000ooooool_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50007 0 m
.49998 .00025 L
.50001 .00048 L
.50006 .00074 L
.50012 .00099 L
.50019 .00122 L
.50029 .00144 L
.50045 .00167 L
.50073 .00192 L
.50112 .00217 L
.50172 .00243 L
.50248 .00269 L
.50338 .00292 L
.50473 .00319 L
.50663 .00348 L
.51154 .00402 L
.51508 .0043 L
.5191 .00457 L
.52861 .00508 L
.54207 .00562 L
.56066 .00621 L
.60468 .00727 L
.65485 .00825 L
.71589 .00934 L
.77718 .01051 L
.80204 .01108 L
.82132 .01162 L
.83453 .0121 L
.84014 .01237 L
.8441 .01263 L
.84694 .01289 L
.84844 .01313 L
.84878 .0134 L
.84839 .01356 L
.84766 .0137 L
.84535 .01396 L
.84352 .01411 L
.84148 .01425 L
.82972 .01483 L
.81241 .01544 L
.79318 .016 L
.74243 .01725 L
.65815 .01924 L
.58683 .02135 L
.56023 .02245 L
.54898 .02303 L
.53888 .02366 L
.53122 .02423 L
.52542 .02476 L
.52049 .0253 L
Mistroke
.5168 .02579 L
.51104 .02681 L
.50877 .02737 L
.50708 .0279 L
.50488 .02884 L
.50399 .02936 L
.50335 .02985 L
.50282 .03035 L
.50238 .03088 L
.50201 .03146 L
.50174 .03201 L
.5015 .03262 L
.50132 .0332 L
.50108 .03428 L
.50092 .03526 L
.50077 .03635 L
.50053 .03854 L
.5002 .04248 L
.49964 .05107 L
.49924 .05935 L
.4989 .06814 L
.49864 .07662 L
.49844 .08477 L
.49826 .09344 L
.49811 .10179 L
.49798 .11066 L
.49787 .11921 L
.49778 .12744 L
.49769 .13619 L
.49762 .14461 L
.49756 .15272 L
.49751 .16134 L
.49746 .16964 L
.49741 .17847 L
.49737 .18697 L
.49733 .19515 L
.4973 .20385 L
.49727 .21223 L
.49725 .22029 L
.49724 .22476 L
.49723 .22672 L
.49723 .22776 L
.49723 .22887 L
.49723 .22996 L
.49722 .23095 L
.49722 .23143 L
.49722 .23195 L
.49722 .23218 L
.49722 .23243 L
.49722 .23265 L
Mistroke
.49722 .23289 L
.49722 .23317 L
.49722 .23344 L
.49722 .23368 L
.49722 .23394 L
.49722 .23409 L
.49722 .23423 L
.49722 .23453 L
.49722 .23481 L
.49722 .23507 L
.49722 .23559 L
.49722 .23606 L
.49723 .23712 L
.49723 .23813 L
.49723 .2392 L
.49724 .24115 L
.49724 .24233 L
.49725 .24345 L
.49727 .24556 L
.49729 .24762 L
.49732 .24981 L
.4974 .25375 L
.49745 .25575 L
.49752 .25791 L
.49767 .26182 L
.49814 .27061 L
.49872 .27907 L
.4993 .28721 L
.49984 .29588 L
.50004 .29989 L
.50021 .30422 L
.50035 .30879 L
.5004 .31084 L
.50045 .31309 L
.50052 .31734 L
.50054 .31966 L
.50056 .32183 L
.50057 .3229 L
.50057 .32406 L
.50058 .32508 L
.50058 .32617 L
.50059 .32725 L
.50059 .32822 L
.50059 .3287 L
.50059 .32921 L
.50059 .32969 L
.50059 .33013 L
.50059 .33037 L
.50059 .33064 L
.50059 .33092 L
Mistroke
.50059 .33118 L
.50059 .33143 L
.50059 .33169 L
.50059 .33192 L
.50059 .33217 L
.50059 .33231 L
.50059 .33246 L
.50059 .33272 L
.50059 .33332 L
.50059 .33383 L
.50059 .3344 L
.50059 .33553 L
.50059 .33673 L
.50058 .3389 L
.50055 .34778 L
.50052 .35633 L
.50048 .36456 L
.50045 .37332 L
.50041 .38175 L
.50038 .38985 L
.50034 .39848 L
.50031 .40679 L
.50028 .41562 L
.50025 .42413 L
.50022 .43231 L
.50019 .44102 L
.50016 .4494 L
.50013 .45746 L
.50011 .46604 L
.50008 .4743 L
.50005 .48309 L
.50002 .49154 L
.5 .49968 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool3o`000?ooooooEOooool00?oo
ooooF_ooool=o`000?ooooooB?ooool00?ooooooIooooolBo`000?oooooo=_ooool00?ooooooNOoo
oolbo`000?oooooo1?ooool00?ooooooZooooolTo`000=oooooo003ooooooloooooo@_l0002Moooo
o`00oooooooooooooa;ooooo8Ol0001looooo`00oooooooooooooc?ooooo1?l0001hooooo`00oooo
oooooooooaWooooo6ol0001kooooo`00ooooooooooooo`?ooooo5_l0002Fooooo`00oooooooGoooo
ob_o0000[?ooool00?ooooooYOoooolbo`000=Oooooo003oooooohKooooo7ol0003oooooo`[ooooo
003oooooog?ooooo4ol0003oooooobWooooo003oooooofKooooo3Ol0003ooooooccooooo003ooooo
of3ooooo1_l0003oooooodWooooo003ooooooe_ooooo1Ol0003oooooodoooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomHooooo`;o0000oooooomEooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooo
oomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3o
oooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03
o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooo
oooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGo
oooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oooooo
Eoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000
ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oo
ooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0
oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool0
0ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGoooo
o`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooo
ooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomE
ooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooo
oooo[oooool00?oooooo4oooool3o`000003oa0@4?oooooooooo0?ooooooU_ooool00?oooooo5Ooo
ool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Ooo
ool00ol0003o^[Zjooooo`3oooooof[ooooo003ooooooaGooooo00?oV9RHoc8b<_ooool01oooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8boooooom[
ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oo
oooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Wooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oooooo5?ooool00?oooooo5Oooool00omEEEGo
MgMgodA4A007ooooo`04o`000?ooooooooooooooo`;oMgMg0_ooool00ol0003oooooooooo`02oooo
o`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0
0009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooooooo
V9RHob4Q8@09ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^
k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooaCooooo003ooooooaCo
oooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEEoiRH
V?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000:ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo5oooool00?oooooo5?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo
00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@09ooooo`06oc8b<_lQ8B7oMgMg
ogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolGooooo`00oooooolC
ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c009ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooo
oaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03oooo
o`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo00?o0000
ooooooooool02Oooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00_ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo
5?ooool00?oooooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV03oooooocGooooo003ooooooaoooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@4?oooooo<oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.65) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50061 0 m
.50251 .00025 L
.50533 .00048 L
.51023 .00074 L
.51679 .00099 L
.52471 .00122 L
.53372 .00144 L
.56026 .00192 L
.59538 .0024 L
.64216 .00294 L
.74951 .00402 L
.84398 .00507 L
.86527 .00537 L
.88225 .00566 L
.8947 .00592 L
.90471 .0062 L
.91108 .00647 L
.91418 .00671 L
.9148 .00695 L
.91318 .00718 L
.90872 .00745 L
.90236 .0077 L
.8931 .00797 L
.88104 .00825 L
.74259 .0105 L
.66604 .01173 L
.60844 .0129 L
.56977 .01399 L
.55365 .01461 L
.54187 .01518 L
.53335 .0157 L
.52698 .01618 L
.52171 .01669 L
.51724 .01725 L
.51432 .01772 L
.51186 .01824 L
.50991 .01878 L
.50854 .01929 L
.50755 .01976 L
.50685 .02019 L
.50621 .02068 L
.50574 .02115 L
.50534 .02166 L
.505 .0222 L
.50454 .02317 L
.50418 .02421 L
.50385 .02536 L
.50295 .02951 L
.50225 .03397 L
.5012 .04279 L
Mistroke
.50047 .05128 L
.49997 .05945 L
.49954 .06814 L
.49921 .07651 L
.49893 .0854 L
.4987 .09397 L
.49852 .10221 L
.49835 .11098 L
.49822 .11942 L
.4981 .12754 L
.498 .13619 L
.49791 .14451 L
.49782 .15335 L
.49775 .16187 L
.49769 .17007 L
.49763 .17879 L
.49758 .18719 L
.49754 .19526 L
.49753 .19728 L
.49752 .1994 L
.49751 .20051 L
.49751 .20172 L
.49751 .20283 L
.4975 .20386 L
.4975 .20442 L
.4975 .20494 L
.4975 .20521 L
.4975 .20536 L
.4975 .20551 L
.4975 .20566 L
.4975 .20582 L
.4975 .20597 L
.4975 .20611 L
.4975 .20636 L
.4975 .20664 L
.4975 .20687 L
.4975 .20713 L
.4975 .2074 L
.4975 .2077 L
.4975 .20823 L
.49751 .20871 L
.49751 .20924 L
.49751 .2103 L
.49751 .21129 L
.49752 .2122 L
.49752 .21328 L
.49753 .21445 L
.49755 .21657 L
.49758 .21863 L
.49761 .22054 L
Mistroke
.49766 .2226 L
.49771 .22454 L
.49787 .22894 L
.49808 .23327 L
.49832 .23723 L
.49894 .24571 L
.49957 .25387 L
.49989 .25843 L
.50015 .26256 L
.50037 .26691 L
.50053 .27092 L
.50066 .27503 L
.50071 .2772 L
.50075 .27948 L
.50078 .28151 L
.50081 .28368 L
.50083 .28573 L
.50084 .28759 L
.50084 .28862 L
.50085 .28971 L
.50085 .29064 L
.50086 .29167 L
.50086 .29225 L
.50086 .29277 L
.50086 .29335 L
.50086 .29364 L
.50086 .29381 L
.50086 .29396 L
.50086 .29424 L
.50086 .2945 L
.50086 .29477 L
.50086 .29493 L
.50086 .29507 L
.50086 .29531 L
.50086 .29558 L
.50086 .29585 L
.50086 .29611 L
.50086 .29666 L
.50086 .29717 L
.50085 .29833 L
.50085 .29935 L
.50085 .30044 L
.50083 .3044 L
.50079 .3133 L
.50075 .32187 L
.5007 .33012 L
.50065 .33889 L
.50061 .34734 L
.50057 .35546 L
.50053 .36411 L
Mistroke
.50049 .37244 L
.50045 .38128 L
.50041 .38981 L
.50038 .39801 L
.50034 .40674 L
.5003 .41514 L
.50027 .42321 L
.50024 .43182 L
.50021 .44009 L
.50017 .44889 L
.50014 .45737 L
.50012 .46553 L
.50009 .4742 L
.50006 .48256 L
.50003 .49143 L
.5 .49999 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
oooooaoo0000ooooooliooooo`00oooooomfoooooeoo0000fOooool00?ooooooeOoooom0o`0009Wo
oooo003ooooooooooooo5_oooom2o`0005Oooooo003oooooooooooooE_ooool<o`0004gooooo003o
oooooooooooo7ooooolgo`0005Wooooo003oooooom[oooooA?l0002@ooooo`00oooooon_ooooob_o
0000e?ooool00?ooooooO_oooolao`000?oooooo003oooooofoooooo3ol0003ooooooc7ooooo003o
ooooofCooooo2ol0003ooooood3ooooo003ooooooekooooo1_l0003ooooood_ooooo003ooooooe_o
oooo0ol0003ooooooe7ooooo003ooooooe[ooooo0_l0003ooooooe?ooooo003ooooooe[ooooo00?o
0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`00
0?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEooo
ool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooo
ooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?oooooo
EOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooo
oomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0
003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00
oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003ooooooooo
o`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEoooo
o`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOo
oooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oo
oooooooo0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooo
oeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?oo
ooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o
0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool0
0?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000oooooooo
ool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOoo
ool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo00?o0000ooooooooool0oooooomG
ooooo`00oooooomEooooo`03o`000?oooooooooo0?ooooooEoooool00?ooooooEOooool00ol0003o
ooooooooo`3ooooooeOooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooool@ooooo`?o0000
00?o410@ooooooooool0oooooonIooooo`00oooooolBooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooKOoo
ool00?oooooo4_ooool00onHV9So<S8booooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00Cooooo0_lb<S;oooooofkooooo003ooooooa;ooooo00?ogMgMo`00
0?nj^[X01_ooool00ol0003oooooooooo`02ooooo`Go00000oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o
^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd02?ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0ooooool@ooooo`00oooooolBooooo`03
oeEEEOmgMgOoA4A400Kooooo00?o0000ooooooooool00_ooool2ogMgM`;ooooo00Oo0000oooooooo
ooooooooolc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oo
oooooooo00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMooo
ooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko0000ojVYZOoooooooooookZj^_l0
0002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7
oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000
ooooooooool00oooool00omEEEGoV9RHooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01oooool01Onj^[[oQhN7
ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?o
oooo003ooooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooooooo00Co
oooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`07ooooo`06oc8b<_lQ8B7o
MgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolCooooo`00oooo
ool@ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?oooooooooooc8b<_n7QhL02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool0
1_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82oooo
o`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go00002Ooo
ool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`00
0003o`0001Wooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Kooooo
00?o0000ooooooooool02_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00
oooooolKooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Kooooo00?o0000ooooooooool0ooooool`ooooo`00oooooolKooooo`;o0000
4oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0Jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4104ooooo`Co0000ooooool_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.7) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.58848 0 m
.7291 .00048 L
.86768 .00099 L
.92321 .00124 L
.96656 .00148 L
.99735 .00169 L
s
.99735 .00169 m
1 .00171 L
s
1 .00334 m
.98138 .00354 L
.92611 .00402 L
.79424 .00507 L
.68868 .00607 L
.64362 .00662 L
.60555 .00721 L
.57945 .00775 L
.56134 .00825 L
.54735 .00877 L
.53632 .00934 L
.5321 .00962 L
.52836 .00993 L
.52325 .01048 L
.52137 .01075 L
.51967 .01104 L
.51728 .01157 L
.5156 .01208 L
.51443 .01255 L
.51339 .01311 L
.51263 .01364 L
.51136 .01483 L
.51043 .01599 L
.50959 .01725 L
.50743 .02153 L
.50582 .02604 L
.50469 .03025 L
.50386 .03417 L
.50253 .04251 L
.50153 .05137 L
.50084 .05991 L
.50032 .06813 L
.49987 .07687 L
.49954 .08528 L
.49926 .09337 L
.49902 .10199 L
.49881 .11028 L
.49864 .11909 L
.49848 .12758 L
.49836 .13575 L
.49824 .14444 L
.49813 .15281 L
.49804 .1617 L
.498 .16617 L
.49796 .17027 L
.49793 .17428 L
.49792 .1763 L
.49791 .17745 L
.49791 .17851 L
.49791 .17907 L
Mistroke
.49791 .17959 L
.49791 .17988 L
.49791 .18015 L
.49791 .18044 L
.49791 .18059 L
.49791 .18075 L
.49791 .18101 L
.49791 .18129 L
.49791 .18143 L
.49791 .18158 L
.49791 .18186 L
.49791 .18213 L
.49791 .18239 L
.49791 .18287 L
.49791 .18335 L
.49791 .18386 L
.49791 .18477 L
.49792 .18576 L
.49793 .18683 L
.49794 .18795 L
.49795 .18901 L
.49798 .191 L
.49802 .19313 L
.49809 .19546 L
.49825 .19968 L
.49849 .20416 L
.49908 .21222 L
.49979 .2208 L
.50041 .22905 L
.50066 .23324 L
.50087 .23783 L
.50095 .23995 L
.50102 .24221 L
.50107 .24433 L
.50111 .24629 L
.50114 .24847 L
.50116 .2496 L
.50117 .25084 L
.50119 .25293 L
.50119 .25407 L
.5012 .25514 L
.5012 .2562 L
.5012 .2568 L
.5012 .25736 L
.50121 .25764 L
.50121 .2579 L
.50121 .25813 L
.50121 .25838 L
.50121 .25865 L
.50121 .2589 L
Mistroke
.50121 .25917 L
.50121 .25933 L
.50121 .25947 L
.50121 .25972 L
.50121 .25998 L
.50121 .26024 L
.50121 .26047 L
.50121 .26091 L
.5012 .26138 L
.5012 .26235 L
.5012 .26343 L
.50119 .26558 L
.50118 .26756 L
.50116 .27202 L
.5011 .28048 L
.50104 .28863 L
.50098 .29729 L
.50092 .30563 L
.50086 .3145 L
.50081 .32304 L
.50076 .33126 L
.50071 .34001 L
.50066 .34842 L
.50062 .35652 L
.50058 .36514 L
.50053 .37344 L
.50049 .38225 L
.50045 .39075 L
.50041 .39892 L
.50037 .40762 L
.50033 .41599 L
.50029 .42488 L
.50026 .43346 L
.50022 .44171 L
.50019 .45048 L
.50015 .45893 L
.50012 .46705 L
.50009 .4757 L
.50006 .48402 L
.50002 .49287 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooon?
ooooonGo0000>_ooool00?oooooooooooomeooooob?o00005oooool00?oooooooooooolnoooooe[o
00005oooool00?oooooo`Ooooomlo`00077ooooo003ooooooi;ooooo;ol0003]ooooo`00oooooomb
ooooob3o0000oooooolMooooo`00oooooomUooooo`go0000oooooolmooooo`00oooooomQooooo`Co
0000oooooom:ooooo`00oooooomOooooo`;o0000oooooom>ooooo`00oooooomNooooo`03o`000?oo
oooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooo
oegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?oo
ooooCoooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003o
ooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooo
oomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3o
oooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooo
oooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKo
oooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oooooo
E_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000
ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oo
ooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0
oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooolCooooo`?o0000
00?o410@ooooooooool0oooooonFooooo`00oooooolEooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0?ooooooJ_oo
ool00?oooooo5Oooool00onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00?ooooo0_lb<S;oooooof_ooooo003ooooooaGooooo00?ogMgMo`00
0?nj^[X01oooool01?l0003oooooooooooooool5o`0000Cooooo00?oQhN7o`000?nj^[X01?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Wooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oo
oooo5?ooool00?oooooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?ooooooooooooooo`;o
MgMg0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool02Oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@
oooooolDooooo`00oooooolDooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003ooooo
ooooo`02ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
ojVYZOmEEEGooooo00[ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooooiRH
V?mEEED01_ooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009oooo
o`05o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`08ooooo`06oc8b<_lQ8B7o
MgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolGooooo`00oooo
oolCooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool02?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000oooooolDoooo
o`00oooooolCooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0
003oooooooooooooool5o`0000Wooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo00Wooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00onYZJWoMgMgooooo`08ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooaCooooo
003ooooooaoooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P3ooooooc?ooooo003ooooooaoooooo0_l0000Booooo`03o`00
0?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go0000oooooolcooooo`00ooooooooooooojoooooo003ooooooooooooo[ooo
ool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.75) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
1 .00147 m
.9989 .00148 L
.85583 .00192 L
.78892 .00219 L
.73876 .00243 L
.69531 .0027 L
.65783 .003 L
.63392 .00323 L
.61338 .00349 L
.59635 .00376 L
.58381 .00402 L
.57293 .0043 L
.56501 .00456 L
.55817 .00484 L
.55247 .00515 L
.54818 .00544 L
.54491 .00572 L
.5402 .00623 L
.53675 .00673 L
.53424 .0072 L
.52996 .00825 L
.52667 .00933 L
.52419 .01034 L
.51989 .01263 L
.51686 .01486 L
.51437 .01725 L
.51259 .01942 L
.51103 .02179 L
.50882 .02608 L
.50722 .03031 L
.5059 .03479 L
.50418 .04285 L
.50351 .04699 L
.5029 .05144 L
.50195 .06023 L
.50126 .06869 L
.50073 .07683 L
.50027 .08549 L
.49991 .09383 L
.49959 .10269 L
.49933 .11123 L
.49912 .11944 L
.49892 .12818 L
.49876 .1366 L
.49863 .14469 L
.49856 .14919 L
.49854 .15132 L
.49852 .1533 L
.49851 .15437 L
.49851 .15534 L
Mistroke
.4985 .15585 L
.4985 .15641 L
.4985 .15672 L
.4985 .157 L
.4985 .15727 L
.4985 .15742 L
.4985 .15755 L
.4985 .15781 L
.4985 .15804 L
.4985 .15828 L
.4985 .15855 L
.4985 .15879 L
.4985 .15903 L
.4985 .15925 L
.4985 .15948 L
.4985 .16001 L
.4985 .16057 L
.49851 .1611 L
.49851 .16159 L
.49852 .16261 L
.49853 .16369 L
.49857 .16564 L
.4986 .16684 L
.49863 .16796 L
.4987 .17007 L
.4989 .17435 L
.49915 .17829 L
.49985 .18672 L
.50057 .19482 L
.50091 .19933 L
.50117 .20345 L
.50138 .20771 L
.50152 .21175 L
.50157 .21381 L
.50161 .216 L
.50164 .21786 L
.50165 .21893 L
.50166 .21993 L
.50167 .22093 L
.50167 .22202 L
.50167 .22258 L
.50168 .22317 L
.50168 .22345 L
.50168 .22373 L
.50168 .22397 L
.50168 .22423 L
.50168 .22448 L
.50168 .22471 L
.50168 .22496 L
.50168 .22522 L
Mistroke
.50168 .22546 L
.50168 .22569 L
.50168 .2259 L
.50168 .22613 L
.50168 .22664 L
.50168 .22719 L
.50167 .22818 L
.50167 .22933 L
.50166 .23038 L
.50165 .23276 L
.50162 .23707 L
.50154 .2455 L
.50146 .25362 L
.50138 .26226 L
.50131 .27057 L
.50123 .27941 L
.50116 .28792 L
.50109 .29611 L
.50103 .30482 L
.50096 .31321 L
.50091 .32128 L
.50085 .32987 L
.5008 .33814 L
.50074 .34693 L
.50069 .35539 L
.50064 .36353 L
.50059 .3722 L
.50055 .38054 L
.5005 .38941 L
.50045 .39795 L
.50041 .40617 L
.50037 .41492 L
.50033 .42333 L
.50029 .43143 L
.50025 .44005 L
.50021 .44834 L
.50018 .45716 L
.50014 .46566 L
.50011 .47383 L
.50007 .48253 L
.50004 .4909 L
.5 .49979 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooooo
oooooiOooooo00?o0000ooooooooool05Oooool00?oooooo]?oooooRo`0001Sooooo003oooooogko
oooo=_l0003jooooo`00oooooomcooooo`_o0000oooooolaooooo`00oooooom/ooooo`Oo0000oooo
oollooooo`00oooooomYooooo`?o0000oooooom3ooooo`00oooooomVooooo`?o0000oooooom6oooo
o`00oooooomUooooo`03o`000?oooooooooo0?ooooooAoooool00?ooooooHoooool2o`000?oooooo
B_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof7ooooo00?o0000
ooooooooool0oooooom;ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?oo
ooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooekooooo00?o0000ooooooooool0
oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooGOooool0
0ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?oooo
o`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooG?ooool00ol0003ooooo
ooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomL
ooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003oooooooooo`3ooooo
oe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`00
0?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool0
0ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFoooo
o`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooo
ooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomF
ooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`00
0?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003o
oooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo
0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo
00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_oo
ool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooo
ooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?oooooo
E_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooo
oomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0
003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00
oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003ooooooooo
o`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFoooo
o`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKo
oooo003ooooooeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oo
oooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooo
oeKooooo00?o0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?oo
ooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o
0000ooooooooool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool0
0?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000oooooooo
ool0oooooomFooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooE_oo
ool00ol0003oooooooooo`3ooooooeKooooo003ooooooeKooooo00?o0000ooooooooool0oooooomF
ooooo`00oooooomFooooo`03o`000?oooooooooo0?ooooooE_ooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooo
oooo[oooool00?oooooo4?ooool3o`000003oa0@4?oooooooooo0?ooooooVOooool00?oooooo4_oo
ool00ol@413o^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`3oooooofgooooo003ooooooa;ooooo00?oV9RHoc8b<_ooool01_ooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8boooooom^
ooooo`00oooooolBooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool5o`00
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000
ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
1_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooooa3o
oooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`;oMgMg
0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko0000ojVYZOoooooo
oooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgoooo
ooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo410@oooooolQ8B7ogMgM00Go
oooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Oooooo00Go^[ZjohN7
QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolC
ooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0003oooooooooo`04
ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooooa?ooooo003ooooooa3ooooo
00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go00002Oooool00ol@413o0000o`00
0003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001Wooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
2_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^
k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00oooooolKooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooo
oolb<S801?ooool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Cooooo`03
o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`Go00001?ooool4o`000?oooooo;oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.73398 0 m
.80169 .00025 L
.8294 .00048 L
.83619 .00074 L
.82764 .00099 L
.81248 .00122 L
.79526 .00144 L
.75307 .00192 L
.67655 .00294 L
.64838 .00345 L
.62429 .00402 L
.60634 .00457 L
.59348 .00507 L
.58249 .00561 L
.57299 .0062 L
.56048 .00725 L
.55196 .00825 L
.54447 .00944 L
.53931 .01051 L
.5349 .01167 L
.53106 .01292 L
.52583 .01515 L
.52218 .01725 L
.51943 .01928 L
.517 .02151 L
.51336 .02601 L
.51096 .03017 L
.50902 .03464 L
.50751 .03917 L
.50635 .04347 L
.50469 .05166 L
.50342 .06037 L
.50249 .06875 L
.50181 .07681 L
.50121 .0854 L
.50075 .09366 L
.50033 .10245 L
.50001 .11091 L
.49973 .11905 L
.4996 .12359 L
.4995 .12771 L
.49946 .12977 L
.49943 .132 L
.49941 .13302 L
.4994 .13411 L
.4994 .13503 L
.49939 .13556 L
.49939 .13582 L
.49939 .13605 L
.49939 .13632 L
Mistroke
.49939 .13646 L
.49939 .1366 L
.49939 .13685 L
.49939 .13711 L
.49939 .13725 L
.49939 .13741 L
.49939 .13757 L
.49939 .13772 L
.49939 .13798 L
.49939 .13827 L
.4994 .13884 L
.4994 .13938 L
.49941 .14038 L
.49943 .14137 L
.49945 .14228 L
.49951 .14434 L
.49959 .1464 L
.49969 .14833 L
.49997 .15274 L
.5007 .16101 L
.5015 .16981 L
.50182 .1742 L
.50194 .17634 L
.50204 .17828 L
.50212 .18017 L
.50219 .18222 L
.50225 .18439 L
.50227 .18544 L
.50229 .18643 L
.5023 .18749 L
.50231 .18846 L
.50232 .18953 L
.50233 .19013 L
.50233 .19068 L
.50234 .19121 L
.50234 .19179 L
.50234 .19209 L
.50234 .19237 L
.50234 .19267 L
.50234 .19284 L
.50234 .19299 L
.50234 .19326 L
.50234 .1935 L
.50234 .19377 L
.50234 .19392 L
.50234 .19406 L
.50234 .19433 L
.50234 .19463 L
.50234 .19518 L
.50234 .19568 L
Mistroke
.50233 .19622 L
.50233 .1972 L
.50231 .19942 L
.50229 .20177 L
.50227 .20391 L
.50216 .2124 L
.50205 .22056 L
.50193 .22924 L
.50182 .2376 L
.50171 .24649 L
.50162 .25505 L
.50152 .26328 L
.50143 .27205 L
.50135 .28048 L
.50128 .2886 L
.5012 .29723 L
.50113 .30555 L
.50106 .31438 L
.50099 .3229 L
.50093 .33109 L
.50087 .3398 L
.50081 .34819 L
.50076 .35626 L
.5007 .36485 L
.50065 .37311 L
.5006 .3819 L
.50054 .39037 L
.5005 .39851 L
.50045 .40718 L
.50041 .41552 L
.50036 .42439 L
.50031 .43293 L
.50027 .44115 L
.50023 .44989 L
.50019 .45831 L
.50015 .46641 L
.50011 .47503 L
.50007 .48332 L
.50004 .49214 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003oooooooo/
oooood;o0000P?ooool00?oooooo_ooooom7o`000:Sooooo003ooooooiOooooo:?l0003_ooooo`00
oooooon9ooooo`ko0000oooooolHooooo`00oooooomkooooo`ko0000oooooolVooooo`00oooooomf
ooooo`Go0000ooooooldooooo`00oooooom_ooooo`Oo0000ooooooliooooo`00oooooom/ooooo`?o
0000oooooom0ooooo`00oooooomYooooo`?o0000oooooom3ooooo`00oooooomWooooo`;o0000oooo
oom6ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooI?ooool2o`00
0?ooooooBOooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof;ooooo
00?o0000ooooooooool0oooooom:ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBooo
ool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003ooooooeoooooo00?o0000oooo
ooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oooooo
G_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooo
oom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooGOooool00ol0
003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00
oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooG?ooool00ol0003ooooooooo
o`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLoooo
o`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oo
ooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o
0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@4?oooooooooo0?oooooo
U_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003ooooooaGooooo00?oV9RH
oc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03
ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj
^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Wooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oooooo5?ooool00?oo
oooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?ooooooooooooooo`;oMgMg0_ooool00ol0
003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooo
oaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo
00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000:ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo5?ooool01OmVIVKoQhN7oooo
oonHV9SoEEEE00Kooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko0000
2Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09oooo
o`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooo
oolGooooo`00oooooolCooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o<S8bohN7Qoooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0003ooooooaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001Wooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41002Oooool01_nYZJWo8B4Q
o`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mV
IVKo0000o`000?m4A4Co0000oooooolDooooo`00oooooolOooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000oooooolcoooo
o`00oooooolOooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003o
ooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY0?oooooo<oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo
[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.85) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
0 .00058 m
.11742 .00099 L
.2929 .00147 L
.43574 .00192 L
.50275 .00217 L
.56348 .00245 L
.60482 .00268 L
.6414 .00293 L
.67149 .00321 L
.68348 .00335 L
.69409 .0035 L
.70783 .00376 L
.71554 .00402 L
.71937 .0043 L
.71935 .00456 L
.71809 .00471 L
.7163 .00484 L
.71358 .005 L
.71049 .00515 L
.67948 .00623 L
.62116 .00825 L
.59848 .00935 L
.58079 .0105 L
.56952 .01149 L
.56002 .01257 L
.55216 .01374 L
.54564 .01499 L
.53713 .01725 L
.53134 .01942 L
.52663 .02179 L
.52319 .02402 L
.52065 .02608 L
.51685 .03007 L
.51378 .03447 L
.51163 .0386 L
.50978 .04305 L
.50841 .04725 L
.50718 .05184 L
.50544 .0603 L
.50412 .06896 L
.50316 .0773 L
.50235 .08616 L
.50173 .0947 L
.50124 .10292 L
.50104 .10716 L
.50095 .10933 L
.50088 .11166 L
.50085 .11278 L
.50083 .11384 L
.50081 .1148 L
Mistroke
.5008 .11534 L
.5008 .11584 L
.50079 .11608 L
.50079 .11634 L
.50079 .11657 L
.50079 .11682 L
.50079 .11708 L
.50079 .11736 L
.50079 .11762 L
.50079 .11787 L
.50079 .11811 L
.50079 .11834 L
.50079 .11855 L
.50079 .11877 L
.5008 .11928 L
.5008 .11975 L
.50082 .12074 L
.50083 .1213 L
.50084 .12181 L
.50091 .12374 L
.50102 .12589 L
.50116 .12814 L
.50186 .13629 L
.50229 .14084 L
.50265 .14497 L
.5028 .14703 L
.50295 .14927 L
.50306 .15136 L
.50315 .15332 L
.50321 .15534 L
.50324 .15642 L
.50327 .15757 L
.50328 .15878 L
.50329 .15937 L
.5033 .15992 L
.5033 .16041 L
.5033 .16095 L
.50331 .16149 L
.50331 .16179 L
.50331 .16207 L
.50331 .16232 L
.50331 .16258 L
.50331 .16284 L
.50331 .16307 L
.50331 .16334 L
.50331 .16349 L
.50331 .16363 L
.50331 .16389 L
.50331 .16416 L
.50331 .16471 L
Mistroke
.5033 .16521 L
.5033 .16637 L
.50329 .16737 L
.50328 .16828 L
.50326 .17032 L
.50319 .17438 L
.50311 .17881 L
.50292 .18749 L
.50275 .19585 L
.50258 .20474 L
.50242 .2133 L
.50229 .22153 L
.50215 .23029 L
.50202 .23873 L
.50192 .24685 L
.50181 .25548 L
.5017 .2638 L
.5016 .27263 L
.50151 .28115 L
.50142 .28934 L
.50133 .29805 L
.50125 .30644 L
.50118 .31451 L
.5011 .3231 L
.50103 .33136 L
.50096 .34015 L
.5009 .34862 L
.50083 .35676 L
.50077 .36543 L
.50072 .37377 L
.50066 .38264 L
.5006 .39118 L
.50054 .3994 L
.50049 .40814 L
.50044 .41656 L
.50039 .42466 L
.50034 .43328 L
.5003 .44157 L
.50025 .45039 L
.50021 .45889 L
.50016 .46706 L
.50012 .47575 L
.50008 .48413 L
.50004 .49302 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003o5ooooooZ
o`000?oooooo[Oooool00?oooooo0_oooonjo`000?;ooooo003ooooookcooooo:?l0003:ooooo`00
oooooooCoooooa3o0000boooool00?oooooo]ooooolLo`000=_ooooo003ooooooigooooo6_l0003g
ooooo`00oooooon7oooooaKo0000oooooolBooooo`00oooooon0ooooo`Oo0000oooooolXooooo`00
oooooomfooooo`[o0000ooooool_ooooo`00oooooomcooooo`?o0000ooooooliooooo`00oooooom`
ooooo`?o0000oooooollooooo`00oooooom]ooooo`?o0000ooooooloooooo`00oooooomZooooo`?o
0000oooooom2ooooo`00oooooomXooooo`;o0000oooooom5ooooo`00oooooomWooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooIOooool2o`000?ooooooB?ooool00?ooooooI?ooool00ol0
003oooooooooo`3oooooodSooooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00
oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooH_ooool00ol0003ooooooooo
o`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00oooooomQoooo
o`03o`000?oooooooooo0?ooooooBoooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodco
oooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomNooooo`03o`000?oo
oooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooo
oegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?oo
ooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooooooo
ool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?oo
ool00ol0003oooooooooo`3ooooooe3ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo0_l0003ooooooeKooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooo
oooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool0
0ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooo
ooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo
003ooooooa;ooooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Kooooo00?o0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooK_ooool00?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo
00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000
o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0
003oA4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003o
ooooooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?oMgMgoc8b
<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@ooooool@ooooo`00oooooolAoooo
o`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9So
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`07ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool00?oooooo4Oooool01OmVIVKoQhN7
oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool01?ooool00omEEEGoV9RHooooo`0;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`Ko
00002Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07
ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko0000
0_ooool00ol0003oooooooooo`3ooooooa?ooooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo<S8b
ohN7Q`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<
00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[oooooonk^k_mgMgOo0000
0_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001?oo
ool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03o`000?oooooooooo00[o
oooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo4?ooool00?oooooo6oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Cooooo00?o0000ooooooooool0ooooool`ooooo`00oooooolKooooo`;o00004oooool00ol0
003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo1?l0003ooooooboooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.9) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.26381 0 m
.18628 .00099 L
.16841 .00122 L
.1512 .00147 L
.13875 .00169 L
.12904 .00192 L
.12287 .00219 L
.1229 .00245 L
.12777 .00268 L
.13836 .00293 L
.15535 .0032 L
.17951 .00349 L
.23561 .00402 L
.49515 .00604 L
.55318 .0066 L
.60276 .00719 L
.62213 .00747 L
.63763 .00774 L
.65986 .00825 L
.66906 .00854 L
.67306 .0087 L
.67618 .00885 L
.68034 .00912 L
.6819 .00926 L
.68312 .00941 L
.68394 .00957 L
.6843 .00974 L
.68417 .00991 L
.6837 .01006 L
.68299 .0102 L
.68194 .01035 L
.67905 .01066 L
.67159 .01123 L
.66153 .01184 L
.64126 .01295 L
.60643 .015 L
.59166 .01609 L
.57878 .01725 L
.56847 .01841 L
.56089 .01947 L
.5497 .02153 L
.5451 .02264 L
.54094 .02385 L
.53496 .02604 L
.5307 .02806 L
.52696 .03028 L
.52139 .03477 L
.51774 .03893 L
.51479 .04339 L
.5125 .04791 L
Mistroke
.51077 .0522 L
.50828 .06037 L
.50638 .06906 L
.50503 .07743 L
.50446 .0817 L
.50393 .08632 L
.50353 .09079 L
.50337 .09291 L
.50326 .09489 L
.50317 .09683 L
.50314 .09792 L
.50313 .09841 L
.50312 .09892 L
.50311 .09919 L
.50311 .09948 L
.50311 .09976 L
.5031 .10001 L
.5031 .10015 L
.5031 .1003 L
.5031 .10045 L
.5031 .10061 L
.5031 .10076 L
.5031 .10091 L
.5031 .10119 L
.5031 .10146 L
.50311 .10162 L
.50311 .10177 L
.50311 .10231 L
.50312 .10281 L
.50313 .10333 L
.50317 .10439 L
.5032 .10535 L
.50332 .10752 L
.5036 .11144 L
.50397 .11585 L
.5043 .11994 L
.50457 .1239 L
.50467 .1259 L
.50472 .12698 L
.50476 .12812 L
.50479 .12914 L
.50482 .13027 L
.50483 .13076 L
.50484 .13129 L
.50485 .13179 L
.50485 .13224 L
.50486 .13282 L
.50486 .13312 L
.50486 .13328 L
.50486 .13344 L
Mistroke
.50486 .13372 L
.50486 .13398 L
.50486 .13414 L
.50486 .13429 L
.50486 .13443 L
.50486 .13458 L
.50486 .13485 L
.50486 .13511 L
.50486 .1354 L
.50486 .13568 L
.50485 .13617 L
.50485 .1367 L
.50483 .13775 L
.50482 .13873 L
.50477 .14096 L
.50465 .14546 L
.50438 .15377 L
.50407 .16261 L
.5038 .17112 L
.50356 .17931 L
.50333 .18802 L
.50312 .19641 L
.50294 .20448 L
.50276 .21307 L
.5026 .22134 L
.50244 .23013 L
.50229 .23859 L
.50216 .24674 L
.50204 .2554 L
.50191 .26375 L
.5018 .27261 L
.50169 .28115 L
.50159 .28937 L
.50149 .29812 L
.5014 .30654 L
.50132 .31463 L
.50123 .32325 L
.50115 .33155 L
.50108 .34037 L
.501 .34886 L
.50093 .35703 L
.50086 .36573 L
.5008 .3741 L
.50073 .383 L
.50066 .39157 L
.50061 .39982 L
.50055 .40859 L
.50049 .41704 L
.50044 .42516 L
.50038 .43381 L
Mistroke
.50033 .44213 L
.50028 .45098 L
.50023 .45951 L
.50018 .46771 L
.50013 .47643 L
.50008 .48483 L
.50004 .49291 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003oM?oooom<
o`000?ooooook_ooool006Gooooo4Ol0003ooooooooooooo>Oooool007KoooooRol0003oooooojgo
oooo003oooooo`;oooooI_l0003oooooodOooooo003oooooofSoooooCol0003gooooo`00oooooong
oooooaGo0000h_ooool00?ooooooaoooool7o`000>3ooooo003ooooookSooooo3ol0003Wooooo`00
oooooonVoooooa;o0000m_ooool00?ooooooU_ooool@o`000?oooooo2Oooool00?ooooooSOooool9
o`000?oooooo6Oooool00?ooooooPOooool<o`000?oooooo8_ooool00?ooooooNoooool6o`000?oo
oooo;_ooool00?ooooooM_ooool5o`000?oooooo=?ooool00?ooooooLoooool3o`000?oooooo>Ooo
ool00?ooooooKoooool4o`000?oooooo??ooool00?ooooooK?ooool3o`000?oooooo@?ooool00?oo
ooooJ_ooool2o`000?oooooo@oooool00?ooooooJOooool00ol0003oooooooooo`3ooooood?ooooo
003oooooofSooooo00?o0000ooooooooool0oooooom4ooooo`00oooooomWooooo`03o`000?oooooo
oooo0?ooooooAOooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofCo
oooo0_l0003oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooo
oomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3o
oooood[ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomPooooo`03
o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo
003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooo
oooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeko
oooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?oooooo
C_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooegooooo00?o0000
ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oo
ooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o0000ooooooooool0
oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool0
0ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@oooo
o`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003ooooo
ooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomK
ooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooo
oe7ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o
0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooolCooooo`?o0000
00?o410@ooooooooool0oooooonFooooo`00oooooolEooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0?ooooooJ_oo
ool00?oooooo5Oooool00onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00?ooooo0_lb<S;oooooof_ooooo003ooooooaGooooo00?ogMgMo`00
0?nj^[X01oooool01?l0003oooooooooooooool5o`0000Cooooo00?oQhN7o`000?nj^[X01?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`04oa0@4?l0003oA4A4olc<c0[ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0?oooooo5?ooool00?oooooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?oooooooooooooo
o`;oMgMg0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj
^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd02Oooool01_l0003oZJVYoooooooooooo^[Zjo`00
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo
410@oooooolDooooo`00oooooolDooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003o
ooooooooo`02ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ohN7QomEEEGooooo00Wooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooo
oiRHV?mEEED01_ooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo000000Wooooo
00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooo
oaOooooo003ooooooa?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`05
o`000?ooooooooooooooool000000_ooool00olb<S;oQhN7ooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooo
ooooool000002oooool01OlQ8B7oQhN7oooooonHV9So000000Wooooo00Ko0000okZj^_ooooook^k^
ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooo
ooooQhN7o`000?oooooo5?ooool00?oooooo4oooool01?l@413o0000o`000?ooool2o`000003oa0@
4?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ol00009ooooo`03oa0@4?l0003o000000?o
00001Oooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000009ooooo`06ojVYZOlQ8B7o
0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIV
I_l0003o0000odA4A?l0003ooooooaCooooo003ooooooaoooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@3ooooooc?ooooo
003ooooooaoooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oo
oooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^
k^h0oooooolcooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.95) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.36557 0 m
.35192 .00099 L
.3345 .00192 L
.30756 .00293 L
.27038 .00402 L
.25063 .00456 L
.23097 .00516 L
.22327 .00543 L
.21638 .00572 L
.21175 .00596 L
.20817 .00623 L
.20638 .0065 L
.20629 .00674 L
.20813 .00701 L
.21187 .00728 L
.21703 .00752 L
.22328 .00774 L
.24249 .00825 L
.40084 .01068 L
.4885 .01187 L
.55738 .01297 L
.60507 .01397 L
.62319 .01447 L
.63866 .01503 L
.64985 .01558 L
.65438 .01589 L
.65752 .01618 L
.65963 .01644 L
.66052 .01659 L
.66114 .01673 L
.66183 .01698 L
.66198 .01725 L
.66161 .0175 L
.66076 .01776 L
.6597 .01799 L
.65821 .01824 L
.65389 .01879 L
.64888 .0193 L
.62601 .02122 L
.59938 .02348 L
.57916 .02561 L
.56431 .0277 L
.55267 .02997 L
.54492 .03204 L
.5394 .03394 L
.53108 .03795 L
.52762 .04023 L
.52495 .04236 L
.52065 .04669 L
.51768 .05065 L
Mistroke
.51509 .05506 L
.51316 .05914 L
.51025 .06731 L
.50909 .0717 L
.50826 .07568 L
.50792 .07768 L
.50764 .0798 L
.50752 .0809 L
.50741 .08211 L
.50734 .08314 L
.50728 .08424 L
.50725 .08483 L
.50723 .08537 L
.50721 .08587 L
.5072 .08643 L
.5072 .08667 L
.50719 .08693 L
.50719 .08715 L
.50719 .0874 L
.50719 .08766 L
.50719 .08793 L
.50719 .08818 L
.50719 .08842 L
.50719 .0887 L
.50719 .08886 L
.50719 .089 L
.5072 .08955 L
.5072 .09005 L
.50722 .09058 L
.50725 .09168 L
.50729 .09289 L
.50747 .0974 L
.50755 .09954 L
.5076 .10151 L
.50762 .1025 L
.50763 .103 L
.50764 .10356 L
.50764 .10411 L
.50765 .10442 L
.50765 .10456 L
.50765 .1047 L
.50765 .10495 L
.50765 .10522 L
.50765 .10549 L
.50765 .10564 L
.50765 .10578 L
.50765 .10603 L
.50765 .10629 L
.50764 .10652 L
.50764 .10677 L
Mistroke
.50764 .10733 L
.50763 .10785 L
.50761 .1088 L
.50759 .10982 L
.50752 .11198 L
.50742 .11433 L
.50719 .11863 L
.50664 .12731 L
.50611 .13567 L
.50561 .14456 L
.50517 .15312 L
.50481 .16135 L
.50445 .17011 L
.50415 .17855 L
.50388 .18666 L
.50362 .1953 L
.5034 .20362 L
.50318 .21245 L
.50298 .22097 L
.5028 .22916 L
.50263 .23787 L
.50247 .24626 L
.50233 .25433 L
.50219 .26292 L
.50206 .27118 L
.50193 .27997 L
.50181 .28844 L
.50171 .29658 L
.5016 .30525 L
.5015 .31359 L
.5014 .32246 L
.50131 .331 L
.50122 .33922 L
.50113 .34796 L
.50105 .35638 L
.50098 .36448 L
.5009 .3731 L
.50083 .38139 L
.50076 .39021 L
.50069 .39871 L
.50063 .40688 L
.50056 .41557 L
.5005 .42395 L
.50043 .43284 L
.50037 .44141 L
.50032 .44966 L
.50026 .45843 L
.50021 .46688 L
.50015 .47501 L
.5001 .48365 L
Mistroke
.50005 .49198 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ol_ooool?
o`000?oooooo[Oooool00<oooooo8ol0003ooooookcooooo002aoooooako0000oooooooOooooo`00
WOoooolDo`000?oooooooOooool009_ooooo4_l0003ooooooooooooo0_ooool00:gooooo>Ol0003o
ooooolSooooo003Vooooodko0000oooooomjooooo`00ooooooleoooooc;o0000oooooom8ooooo`00
oooooomWoooooc[o0000ooooool>ooooo`00oooooonQoooooa?o0000n_ooool00?oooooo]?ooool;
o`000>oooooo003ooooook_ooooo1?l0003_ooooo`00oooooon_ooooo`co0000loooool00?oooooo
Xoooool<o`000?oooooo003ooooooi[ooooo2Ol0003oooooo`cooooo003ooooooi3ooooo2_l0003o
oooooaGooooo003oooooohGooooo2ol0003ooooooaoooooo003oooooogkooooo1ol0003oooooob[o
oooo003oooooog_ooooo0ol0003ooooooc7ooooo003oooooogOooooo1?l0003oooooocCooooo003o
ooooog;ooooo1Ol0003oooooocSooooo003oooooofoooooo0ol0003oooooocgooooo003oooooofgo
oooo0_l0003ooooood3ooooo003oooooofcooooo00?o0000ooooooooool0oooooom0ooooo`00oooo
oomZooooo`;o0000oooooom3ooooo`00oooooomYooooo`03o`000?oooooooooo0?oooooo@oooool0
0?ooooooJ?ooool00ol0003oooooooooo`3oooooodCooooo003oooooofKooooo0_l0003oooooodOo
oooo003oooooofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooooomTooooo`03o`000?oo
oooooooo0?ooooooB?ooool00?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo003ooooo
of?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomRooooo`03o`000?oooooooooo0?oo
ooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof7ooooo00?o
0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool0
0?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003ooooooeoooooo00?o0000oooooooo
ool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGooo
ool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=
ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003o
ooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooo
oomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooGOooool00ol0003oooooooooo`3o
ooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomLooooo`03
o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo
003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooo
oooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooeco
oooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oooooo
D?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000
ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oo
ooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0
oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool0
0ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@oooo
o`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooo
ooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomL
ooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooo
oe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`00
0?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003o
oooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo
0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo
00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?oo
ool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooe_ooooo00?o0000ooooooooool0oooo
oomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0
003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00
oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool0
0ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooo
ooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooo4?ooool3o`000003oa0@4?oooooooooo0?oooooo
VOooool00?oooooo4_ooool00ol@413o^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`3oooooofgooooo003ooooooa;ooooo00?oV9RH
oc8b<_ooool01_ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04
ooooo`;o<S8boooooom^ooooo`00oooooolBooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000oooo
ooooool00_ooool5o`0000?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o
0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`04oa0@
4?l0003oA4A4olc<c0Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000
o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0
003oA4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003o
ooooooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@
4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@07ooooo`03ogMgMolb<S;ooooo00Oo
oooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo
410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Joooo
o`05oa0@4?ooooooooooooooool@41003_ooool00on7QhOoEEEEooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Ooo
ool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co8B4Qo`000?mEEEGo000000Oooooo00?oMgMgoc8b<_oo
ool01oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooo
oooo0?oooooo4oooool00?oooooo4?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooolb<S;oQhN700_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go0000
ooooooooooooooooo`00000;ooooo`05ob4Q8On7QhOooooooiRHV?l000001?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo4?ooool00?oo
oooo4?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool5o`0000Wooooo00?o410@o`000?l000000ol00004ooooo`03o`000?oooooooooo
00Wooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo
0000o`000?m4A4Co0000ooooool@ooooo`00oooooolKooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED01?ooool00ol0003o
ooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo
0_l0000=ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
olc<c?l@413o0000oc8b<_o^k^h01?ooool4o`000?oooooo;oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -53 0 ]
[.5 .5125 53 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
147.000 13.000 moveto
(sec) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.40773 0 m
.39844 .00192 L
.38441 .00402 L
.37496 .00508 L
.3619 .00621 L
.34594 .00728 L
.32816 .00825 L
.28135 .01047 L
.26985 .01108 L
.26439 .01141 L
.25998 .01172 L
.25662 .01201 L
.25422 .01227 L
.25316 .01242 L
.25238 .01256 L
.25179 .01271 L
.25145 .01288 L
.2514 .01302 L
.25164 .01317 L
.25281 .01345 L
.25492 .01372 L
.25772 .01397 L
.26169 .01425 L
.26717 .01454 L
.28172 .01514 L
.31888 .01623 L
.36331 .01725 L
.45882 .01918 L
.55082 .02123 L
.58759 .0223 L
.60333 .02287 L
.6173 .02348 L
.62744 .02404 L
.63462 .02455 L
.63974 .02504 L
.6417 .02529 L
.64342 .02556 L
.64417 .02571 L
.64485 .02586 L
.64533 .02601 L
.64572 .02615 L
.64616 .02644 L
.64623 .02669 L
.64615 .02684 L
.64595 .02699 L
.64537 .02727 L
.64487 .02744 L
.6443 .0276 L
.64301 .02791 L
.63674 .02895 L
Mistroke
.6277 .03009 L
.58999 .03439 L
.57442 .03656 L
.56279 .0386 L
.55251 .04095 L
.5454 .04308 L
.5399 .04517 L
.53526 .04738 L
.52903 .05133 L
.52429 .05553 L
.52102 .05945 L
.51955 .06169 L
.51839 .0638 L
.51674 .06777 L
.5161 .06983 L
.51556 .07203 L
.51484 .07596 L
.51378 .08404 L
.51256 .09263 L
.5113 .10091 L
.51004 .1097 L
.50901 .11818 L
.50817 .12633 L
.50741 .135 L
.50679 .14335 L
.5062 .15222 L
.50572 .16077 L
.5053 .169 L
.5049 .17775 L
.50456 .18618 L
.50426 .19428 L
.50397 .2029 L
.50372 .21121 L
.50347 .22003 L
.50324 .22853 L
.50305 .23671 L
.50286 .24542 L
.50268 .25379 L
.50253 .26185 L
.50237 .27043 L
.50222 .27868 L
.50208 .28746 L
.50196 .29592 L
.50184 .30405 L
.50171 .3127 L
.50161 .32104 L
.5015 .32989 L
.50139 .33842 L
.5013 .34663 L
.50121 .35536 L
Mistroke
.50112 .36377 L
.50103 .37186 L
.50095 .38046 L
.50087 .38875 L
.50079 .39756 L
.50071 .40604 L
.50064 .4142 L
.50057 .42289 L
.50051 .43125 L
.50043 .44013 L
.50037 .44869 L
.5003 .45693 L
.50024 .46569 L
.50018 .47413 L
.50012 .48224 L
.50006 .49088 L
.50001 .49919 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooolI
ooooo`Co0000oooooonBooooo`00oooooolBooooo`Oo0000oooooonFooooo`00ooooool:ooooo`So
0000oooooonMooooo`00ooooool3ooooo`Oo0000oooooonUooooo`00k_oooolDo`000?oooooo[?oo
ool00=Wooooo5Ol0003ooooool3ooooo0037oooooa;o0000oooooooEooooo`00^Oooool>o`000?oo
ooooioooool00;Oooooo1ol0003ooooooo3ooooo002noooooa[o0000oooooooFooooo`00f?oooolJ
o`000?oooooo_?ooool00?;ooooo;Ol0003oooooohoooooo003oooooob3ooooo>ol0003ooooooeCo
oooo003ooooooe_ooooo:Ol0003oooooob_ooooo003oooooohCooooo6ol0003ooooooa3ooooo003o
oooooioooooo4Ol0003nooooo`00oooooon`ooooo`Go0000nOooool00?oooooo/?ooool5o`000?Wo
oooo003ooooooj_ooooo1Ol0003nooooo`00oooooonTooooo`Oo0000ooooool4ooooo`00oooooonL
ooooo`So0000ooooool;ooooo`00oooooonDooooo`So0000oooooolCooooo`00oooooon;ooooo`Wo
0000oooooolKooooo`00oooooon3ooooo`So0000oooooolTooooo`00oooooommooooo`Ko0000oooo
ool/ooooo`00oooooomjooooo`?o0000oooooolbooooo`00oooooomfooooo`Co0000ooooooleoooo
o`00oooooombooooo`Co0000ooooooliooooo`00oooooom_ooooo`?o0000oooooolmooooo`00oooo
oom^ooooo`03o`000?oooooooooo0?oooooo?_ooool00?ooooooK?ooool2o`000?oooooo@Oooool0
0?ooooooJ_ooool2o`000?oooooo@oooool00?ooooooJOooool00ol0003oooooooooo`3ooooood?o
oooo003oooooofSooooo00?o0000ooooooooool0oooooom4ooooo`00oooooomWooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003ooooo
ofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooooomTooooo`03o`000?oooooooooo0?oo
ooooB?ooool00?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o
0000ooooooooool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool0
0?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof;ooooo00?o0000oooooooo
ool0oooooom:ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooHOoo
ool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;
ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003o
ooooooooo`3ooooood_ooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooo
oomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3o
ooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03
o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo
003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooo
oooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003ooooooeoo
oooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?oooooo
COooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000
ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oo
ooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0
oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool0
0ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>oooo
o`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooGOooool00ol0003ooooo
ooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3ooooo
odoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003o
oooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo
0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo
00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?oo
ool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooo
oom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooaOooooo0ol000000ol@413oooooooooo`3ooooooi;ooooo
003ooooooaWooooo00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Gooooo00?o0000okZj^_ooool0oooooomVooooo`00oooooolIooooo`03oiRHV?lb<S;o
oooo00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2
oc8b<_ooooooIoooool00?oooooo6Oooool00ooMgMgo0000okZj^P07ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?oo
ool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@[ooooo00Ko410@oc8b<_l0003o
0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`00
0?m4A4Coc<c<0?oooooo6?ooool00?oooooo6Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?oo
ooooooooooooo`;oMgMg0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B4:ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooaSooooo003ooooo
oaSooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEE
oiRHV?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Aooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo6oooool00?oooooo6?ooool0
1OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00oooool00omEEEGoV9RHoooo
o`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0@ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolKooooo`00oooooolGooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0@ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0003ooooooaSooooo003ooooooaOooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001cooooo00?o0000
ooooooooool04?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o
0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000oooooolHooooo`00oooooolS
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolnooooo`00oooooolSoooo
o`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0Koooo
o`03oeEEEOmVIVKo00000?oooooo@?ooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.05) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.43067 0 m
.42653 .00192 L
.42114 .00402 L
.41421 .00623 L
.40625 .00825 L
.39447 .0105 L
.3859 .01174 L
.37585 .01291 L
.35238 .01499 L
.32018 .01725 L
.30625 .01822 L
.29324 .01927 L
.28741 .01986 L
.2852 .02015 L
.28351 .02041 L
.2822 .02067 L
.28167 .02081 L
.28123 .02096 L
.28077 .02124 L
.28078 .02149 L
.2813 .02177 L
.28177 .02191 L
.28245 .02206 L
.28407 .02234 L
.2861 .0226 L
.29247 .02318 L
.30207 .0238 L
.32676 .02494 L
.3562 .02598 L
.43007 .02812 L
.51091 .0304 L
.56802 .03234 L
.59279 .03345 L
.61047 .03449 L
.62254 .03549 L
.62688 .03599 L
.62888 .03628 L
.63041 .03654 L
.63151 .03677 L
.63249 .03701 L
.63329 .03727 L
.63384 .03752 L
.63418 .03775 L
.63435 .03799 L
.63437 .0382 L
.63425 .03843 L
.63411 .03856 L
.63391 .03871 L
.6334 .03898 L
.63275 .03924 L
Mistroke
.63202 .03948 L
.62721 .04062 L
.6216 .04161 L
.61474 .04267 L
.58575 .04695 L
.57289 .04919 L
.56195 .05156 L
.55425 .05369 L
.54769 .05603 L
.53953 .06013 L
.53637 .06232 L
.53398 .06431 L
.5297 .06877 L
.52383 .0773 L
.51982 .08549 L
.51666 .09421 L
.51438 .10261 L
.51265 .11068 L
.51118 .11928 L
.51002 .12755 L
.50899 .13635 L
.50816 .14482 L
.50746 .15297 L
.50683 .16165 L
.50629 .17 L
.50578 .17887 L
.50535 .18742 L
.50497 .19564 L
.50461 .20439 L
.50431 .21282 L
.50403 .22092 L
.50376 .22955 L
.50352 .23785 L
.50329 .24668 L
.50307 .25518 L
.50289 .26336 L
.5027 .27206 L
.50253 .28044 L
.50238 .28849 L
.50223 .29707 L
.50209 .30533 L
.50194 .31411 L
.50182 .32256 L
.5017 .33069 L
.50158 .33935 L
.50147 .34768 L
.50136 .35654 L
.50126 .36507 L
.50116 .37328 L
.50106 .38201 L
Mistroke
.50097 .39042 L
.50089 .3985 L
.5008 .40711 L
.50072 .41539 L
.50064 .4242 L
.50056 .43269 L
.50049 .44085 L
.50041 .44953 L
.50034 .45789 L
.50027 .46678 L
.5002 .47534 L
.50013 .48357 L
.50006 .49233 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooolZ
ooooo`;o0000oooooon3ooooo`00oooooolWooooo`?o0000oooooon5ooooo`00oooooolTooooo`?o
0000oooooon8ooooo`00oooooolQooooo`?o0000oooooon;ooooo`00oooooolNooooo`?o0000oooo
oon>ooooo`00oooooolHooooo`Ko0000oooooonAooooo`00oooooolAooooo`Oo0000oooooonGoooo
o`00ooooool;ooooo`Ko0000oooooonNooooo`00ooooool1ooooo`[o0000oooooonTooooo`00looo
ool=o`000?oooooo[_ooool00>Sooooo2ol0003ooooook_ooooo003Foooooa;o0000ooooooo6oooo
o`00cOooool9o`000?oooooof?ooool00<[ooooo0ol0003oooooon7ooooo003;ooooo`_o0000oooo
oooHooooo`00e_oooolLo`000?oooooo_?ooool00?;ooooo5Ol0003oooooojOooooo003oooooo`So
oooo5ol0003ooooooi3ooooo003ooooooaoooooo9_l0003oooooof[ooooo003oooooodGooooo;?l0
003oooooockooooo003oooooog7ooooo6_l0003oooooobCooooo003ooooooh_ooooo3_l0003ooooo
oaKooooo003ooooooiWooooo3ol0003oooooo`Oooooo003oooooojSooooo1Ol0003oooooo`;ooooo
003oooooojcooooo0_l0003oooooo`7ooooo003oooooojOooooo1_l0003oooooo`;ooooo003ooooo
oj?ooooo1?l0003oooooo`Sooooo003ooooooigooooo1_l0003oooooo`cooooo003ooooooiOooooo
1_l0003ooooooa;ooooo003ooooooi7ooooo1_l0003ooooooaSooooo003ooooooh[ooooo1ol0003o
oooooakooooo003ooooooh;ooooo2?l0003oooooobGooooo003ooooooggooooo1Ol0003oooooobgo
oooo003oooooog_ooooo0_l0003ooooooc;ooooo003oooooogSooooo0ol0003oooooocCooooo003o
ooooogCooooo1?l0003oooooocOooooo003oooooog;ooooo0_l0003ooooooc_ooooo003oooooog7o
oooo00?o0000ooooooooool0oooooolkooooo`00oooooom_ooooo`;o0000oooooolnooooo`00oooo
oom^ooooo`03o`000?oooooooooo0?oooooo?_ooool00?ooooooK_ooool00ol0003oooooooooo`3o
ooooockooooo003oooooofcooooo0_l0003ooooood7ooooo003oooooof_ooooo00?o0000oooooooo
ool0oooooom1ooooo`00oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJ_oo
ool00ol0003oooooooooo`3ooooood;ooooo003oooooofWooooo00?o0000ooooooooool0oooooom3
ooooo`00oooooomXooooo`03o`000?oooooooooo0?ooooooA?ooool00?ooooooJ?ooool00ol0003o
ooooooooo`3oooooodCooooo003oooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooI_ooool00ol0003oooooooooo`3o
ooooodKooooo003oooooofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooooomUooooo`03
o`000?oooooooooo0?ooooooAoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo
003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooo
oooo0?ooooooB?ooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof?o
oooo00?o0000ooooooooool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo
BOooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000
ooooooooool0oooooom:ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?oo
ooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000ooooooooool0
oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooH?ooool0
0ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<oooo
o`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooGoooool00ol0003ooooo
ooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomO
ooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3ooooo
odgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`00
0?oooooooooo0?ooooooCOooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003o
oooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo
0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo
00?o0000ooooooooool0oooooom>ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCooo
ool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000oooo
ooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oooooo
GOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooo
oom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0
003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00
oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003ooooooooo
o`3oooooodoooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLoooo
o`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3o
oooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oo
oooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooo
oecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oo
ooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03
o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo
003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooo
oooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_oo
ool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000oooo
ooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oooooo
F_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooo
oooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo
003ooooooa;ooooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Kooooo00?o0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooK_ooool00?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo
00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003ooooo
ooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Oooooo
00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo410@
oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo
00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool0
0ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooooa?o
oooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool0
1_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82oooo
o`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go00002Ooo
ool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`00
0003o`0001cooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00Cooooo
00?o0000ooooooooool02_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00
oooooolKooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0ooooool`ooooo`00oooooolKooooo`;o0000
4oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEE
EOmVIVKo000000cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000ooooool_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.1) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.44493 0 m
.44001 .00402 L
.43348 .00825 L
.42461 .01255 L
.41796 .01498 L
.4101 .01725 L
.39985 .01949 L
.38667 .02161 L
.37112 .02351 L
.35042 .02558 L
.32686 .02776 L
.31651 .02883 L
.30884 .02981 L
.30572 .03034 L
.30456 .03058 L
.30354 .03084 L
.30271 .03112 L
.30219 .03137 L
.302 .03153 L
.3019 .03168 L
.30196 .03195 L
.3021 .03209 L
.30235 .03224 L
.30272 .03239 L
.30316 .03254 L
.30418 .0328 L
.30563 .03308 L
.3103 .03372 L
.31623 .0343 L
.33052 .03533 L
.35072 .03642 L
.39746 .03838 L
.51955 .04281 L
.56547 .04481 L
.58481 .04587 L
.60125 .04697 L
.61236 .04794 L
.61702 .04846 L
.6211 .04901 L
.62409 .04951 L
.6262 .04998 L
.62702 .0502 L
.62777 .05044 L
.62834 .05066 L
.62877 .05088 L
.62917 .05114 L
.6294 .05138 L
.62952 .05164 L
.62949 .05192 L
.62935 .05217 L
Mistroke
.62909 .05243 L
.62873 .05267 L
.62833 .0529 L
.62702 .05345 L
.62518 .05404 L
.6209 .05512 L
.59702 .05961 L
.57568 .0638 L
.56648 .06601 L
.55832 .06838 L
.55189 .07067 L
.54706 .07275 L
.53972 .07683 L
.53432 .08091 L
.52991 .08535 L
.52662 .08958 L
.52381 .09407 L
.51995 .10214 L
.51693 .11074 L
.51472 .11901 L
.51287 .12781 L
.51144 .13628 L
.5103 .14443 L
.50927 .1531 L
.50844 .16145 L
.50767 .17033 L
.50703 .17888 L
.50649 .1871 L
.50597 .19585 L
.50553 .20428 L
.50515 .21238 L
.50478 .22101 L
.50445 .22931 L
.50414 .23813 L
.50387 .24664 L
.50362 .25482 L
.50338 .26352 L
.50316 .2719 L
.50296 .27995 L
.50277 .28853 L
.50259 .29679 L
.50242 .30557 L
.50226 .31402 L
.50211 .32215 L
.50196 .33081 L
.50183 .33914 L
.50169 .34799 L
.50157 .35653 L
.50145 .36473 L
.50133 .37347 L
Mistroke
.50122 .38187 L
.50112 .38996 L
.50102 .39857 L
.50092 .40685 L
.50082 .41566 L
.50073 .42414 L
.50064 .4323 L
.50055 .44099 L
.50047 .44935 L
.50038 .45823 L
.5003 .46679 L
.50023 .47503 L
.50014 .48379 L
.50007 .49223 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooolc
ooooo`;o0000oooooomjooooo`00oooooolbooooo`03o`000?oooooooooo0?ooooooN_ooool00?oo
oooo<?ooool2o`000?ooooooOOooool00?oooooo;oooool00ol0003oooooooooo`3ooooooggooooo
003oooooobkooooo00?o0000ooooooooool0oooooomnooooo`00ooooool/ooooo`;o0000oooooon1
ooooo`00oooooolZooooo`;o0000oooooon3ooooo`00oooooolXooooo`;o0000oooooon5ooooo`00
oooooolUooooo`?o0000oooooon7ooooo`00oooooolRooooo`?o0000oooooon:ooooo`00oooooolO
ooooo`?o0000oooooon=ooooo`00oooooolKooooo`Co0000oooooon@ooooo`00oooooolCooooo`So
0000oooooonDooooo`00ooooool=ooooo`Ko0000oooooonLooooo`00ooooool8ooooo`Go0000oooo
oonRooooo`00o_ooool9o`000?ooooooYoooool00?3ooooo3_l0003ooooook3ooooo003Uooooo`_o
0000oooooonnooooo`00goooool6o`000?oooooobOooool00=Sooooo1ol0003ooooooloooooo003H
ooooo`;o0000oooooooDooooo`00f_ooool=o`000?ooooooaoooool00>Oooooo2ol0003ooooookco
oooo003boooooaGo0000oooooonWooooo`00ooooool8oooooaco0000oooooon;ooooo`00oooooolT
oooooa[o0000oooooomaooooo`00oooooolnoooooaWo0000oooooomHooooo`00oooooomGoooooaco
0000oooooollooooo`00oooooomcoooooaGo0000oooooolWooooo`00oooooon8ooooo`co0000oooo
oolKooooo`00oooooonDoooooa3o0000ooooool;ooooo`00oooooonTooooo`Co0000ooooool7oooo
o`00oooooonXooooo`?o0000ooooool4ooooo`00oooooonYooooo`;o0000ooooool4ooooo`00oooo
oonVooooo`?o0000ooooool6ooooo`00oooooonRooooo`Co0000ooooool9ooooo`00oooooonMoooo
o`Go0000ooooool=ooooo`00oooooonHooooo`Go0000oooooolBooooo`00oooooonBooooo`Ko0000
oooooolGooooo`00oooooon;ooooo`Oo0000oooooolMooooo`00oooooon6ooooo`Go0000oooooolT
ooooo`00oooooon3ooooo`?o0000oooooolYooooo`00oooooomoooooo`Co0000ooooool/ooooo`00
oooooomkooooo`Co0000ooooool`ooooo`00oooooomiooooo`;o0000ooooooldooooo`00oooooomg
ooooo`;o0000oooooolfooooo`00oooooomdooooo`?o0000oooooolhooooo`00oooooombooooo`;o
0000oooooolkooooo`00oooooomaooooo`03o`000?oooooooooo0?oooooo>oooool00?ooooooKooo
ool2o`000?oooooo?_ooool00?ooooooK_ooool00ol0003oooooooooo`3oooooockooooo003ooooo
ofgooooo00?o0000ooooooooool0ooooooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oo
oooo@?ooool00?ooooooJoooool00ol0003oooooooooo`3ooooood7ooooo003oooooof[ooooo00?o
0000ooooooooool0oooooom2ooooo`00oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool0
0?ooooooJOooool00ol0003oooooooooo`3ooooood?ooooo003oooooofSooooo00?o0000oooooooo
ool0oooooom4ooooo`00oooooomXooooo`03o`000?oooooooooo0?ooooooA?ooool00?ooooooIooo
ool00ol0003oooooooooo`3oooooodGooooo003oooooofKooooo00?o0000ooooooooool0oooooom6
ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooIOooool00ol0003o
ooooooooo`3oooooodOooooo003oooooofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooo
oomUooooo`03o`000?oooooooooo0?ooooooAoooool00?ooooooI?ooool00ol0003oooooooooo`3o
ooooodSooooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomSooooo`03
o`000?oooooooooo0?ooooooBOooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo
003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomRooooo`03o`000?oooooo
oooo0?ooooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof7o
oooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?oooooo
Boooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof3ooooo00?o0000
ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?oo
ooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0
oooooom<ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool0
0ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=oooo
o`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003ooooo
ooooo`3oooooodgooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomN
ooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3ooooo
odkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`00
0?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003o
oooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo
0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo
00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_oo
ool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000oooo
ooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oooooo
GOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooo
oom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooooooo
o`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLoooo
o`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3o
oooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oo
oooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooo
oecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03
o`000?oooooooooo0?ooooooDOooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_oo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooo
oooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooa?ooooo0ol000000ol@413oooooooooo`3ooooooiKooooo003ooooooaGooooo00?o
410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o
0000okZj^_ooool0oooooomZooooo`00oooooolEooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<_ooooooJoooool0
0?oooooo5Oooool00ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooooooo
o`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`06ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00Go
IVIVo`000?l0003oA4A4olc<c03ooooooaCooooo003ooooooaGooooo00?oEEEEogMgMom4A4@01ooo
ool01?l0003oooooooooooooool2ogMgM`;ooooo00?o0000ooooooooool00_ooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q1oooool00ol0003oooooooooo`08ooooo`06o`000?nYZJWooooo
oooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooo
ooooooooohN7Qol@413ooooooaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06
ooooo`03o`000?oooooooooo00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Wooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOo
oooooiRHV?mEEED01_ooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0
000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool01_lb<S;o8B4QogMg
MomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo
4oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`03oc8b<_n7QhOooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`08ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooooaCooooo003ooooooa?o
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool02Oooool0
0ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^
kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooaCooooo003ooooooaoooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo<_ooool0
0?oooooo7oooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0000gooooo00?o0000oooo
ooooool06oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo00000?oooooo=?ooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.15) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.45453 0 m
.45165 .00402 L
.44815 .00825 L
.44344 .01291 L
.43791 .01725 L
.4317 .02118 L
.42313 .02538 L
.41741 .02756 L
.4094 .02993 L
.39927 .03216 L
.38708 .03423 L
.35355 .03857 L
.33715 .04069 L
.33086 .0417 L
.32646 .04263 L
.32492 .04309 L
.32427 .04335 L
.32381 .04359 L
.32347 .04384 L
.32329 .04412 L
.32331 .04438 L
.3235 .04463 L
.32383 .04485 L
.32427 .04507 L
.3249 .0453 L
.32577 .04555 L
.32812 .04606 L
.33098 .04652 L
.33974 .04755 L
.35301 .04867 L
.3861 .05071 L
.47462 .05485 L
.52199 .05705 L
.56524 .05942 L
.58139 .06052 L
.59541 .06168 L
.60493 .06267 L
.60938 .06323 L
.61282 .06375 L
.61557 .06423 L
.618 .06476 L
.61998 .06532 L
.62069 .06557 L
.62133 .06585 L
.62178 .06609 L
.62216 .06634 L
.62245 .06661 L
.62262 .06687 L
.6227 .06712 L
.62268 .06736 L
Mistroke
.62261 .06757 L
.62246 .06781 L
.62233 .06795 L
.62218 .06809 L
.62184 .06835 L
.6208 .06894 L
.61962 .06946 L
.61806 .07002 L
.61081 .07202 L
.59039 .0765 L
.57121 .08102 L
.55772 .08514 L
.5475 .08942 L
.54048 .09346 L
.53497 .09772 L
.53105 .10166 L
.52763 .10599 L
.52503 .11006 L
.52101 .11813 L
.51797 .1264 L
.5155 .1352 L
.51363 .14367 L
.51217 .15182 L
.51087 .1605 L
.50983 .16885 L
.50889 .17772 L
.5081 .18627 L
.50744 .19449 L
.50683 .20324 L
.5063 .21167 L
.50585 .21977 L
.50541 .2284 L
.50503 .2367 L
.50466 .24553 L
.50434 .25403 L
.50405 .26221 L
.50377 .27091 L
.50352 .27929 L
.50329 .28734 L
.50307 .29592 L
.50287 .30418 L
.50267 .31296 L
.50248 .32141 L
.50232 .32954 L
.50215 .3382 L
.502 .34653 L
.50184 .35539 L
.5017 .36392 L
.50157 .37213 L
.50144 .38086 L
Mistroke
.50131 .38927 L
.5012 .39735 L
.50108 .40596 L
.50097 .41424 L
.50086 .42305 L
.50075 .43153 L
.50066 .4397 L
.50056 .44838 L
.50046 .45674 L
.50036 .46563 L
.50027 .47419 L
.50018 .48242 L
.50009 .49118 L
.5 .49962 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooolj
ooooo`03o`000?oooooooooo0?ooooooL_ooool00?oooooo>Oooool00ol0003oooooooooo`3ooooo
og?ooooo003oooooocSooooo00?o0000ooooooooool0oooooomdooooo`00oooooolhooooo`03o`00
0?oooooooooo0?ooooooM?ooool00?oooooo=oooool00ol0003oooooooooo`3oooooogGooooo003o
ooooocKooooo00?o0000ooooooooool0oooooomfooooo`00ooooooleooooo`03o`000?oooooooooo
0?ooooooMoooool00?oooooo=?ooool00ol0003oooooooooo`3oooooogSooooo003ooooooc;ooooo
0_l0003oooooog_ooooo003ooooooc7ooooo00?o0000ooooooooool0oooooomkooooo`00ooooool`
ooooo`03o`000?oooooooooo0?ooooooO?ooool00?oooooo;_ooool2o`000?ooooooOoooool00?oo
oooo;?ooool2o`000?ooooooPOooool00?oooooo:_ooool2o`000?ooooooPoooool00?oooooo:?oo
ool2o`000?ooooooQOooool00?oooooo9oooool00ol0003oooooooooo`3oooooohGooooo003ooooo
obCooooo0ol0003oooooohSooooo003oooooob7ooooo0ol0003ooooooh_ooooo003ooooooakooooo
0ol0003oooooohkooooo003ooooooa[ooooo1?l0003ooooooi7ooooo003ooooooa?ooooo1ol0003o
oooooiGooooo003oooooo`cooooo1ol0003ooooooicooooo003oooooo`Gooooo1ol0003ooooooj?o
oooo003mooooo`Oo0000oooooonZooooo`00m_ooool7o`000?oooooo/Oooool00?7ooooo1Ol0003o
oooookSooooo003Yooooo`So0000oooooonmooooo`00i_ooool3o`000?ooooooaOooool00>Gooooo
0_l0003oooooolOooooo003Wooooo`Oo0000ooooooo0ooooo`00k_ooool7o`000?oooooo^Oooool0
0?Gooooo3ol0003ooooooj[ooooo003oooooo`Gooooo5?l0003ooooooiKooooo003ooooooaWooooo
4ol0003ooooooh?ooooo003oooooobcooooo4ol0003oooooog3ooooo003oooooocoooooo6?l0003o
oooooeSooooo003ooooooeOooooo7Ol0003ooooooc_ooooo003oooooogCooooo4ol0003oooooobSo
oooo003oooooohOooooo2_l0003ooooooakooooo003ooooooi7ooooo1ol0003ooooooaOooooo003o
oooooiSooooo2Ol0003oooooo`kooooo003ooooooj7ooooo1?l0003oooooo`[ooooo003oooooojCo
oooo0_l0003oooooo`Wooooo003oooooojGooooo00?o0000ooooooooool0ooooool7ooooo`00oooo
oonQooooo`Co0000ooooool:ooooo`00oooooonOooooo`;o0000ooooool>ooooo`00oooooonKoooo
o`Co0000ooooool@ooooo`00oooooonDooooo`Oo0000oooooolDooooo`00oooooon?ooooo`Go0000
oooooolKooooo`00oooooon:ooooo`Go0000oooooolPooooo`00oooooon6ooooo`Co0000oooooolU
ooooo`00oooooon3ooooo`?o0000oooooolYooooo`00oooooon0ooooo`?o0000ooooool/ooooo`00
oooooommooooo`?o0000ooooool_ooooo`00oooooomkooooo`;o0000oooooolbooooo`00oooooomh
ooooo`?o0000ooooooldooooo`00oooooomfooooo`;o0000oooooolgooooo`00oooooomdooooo`;o
0000ooooooliooooo`00oooooombooooo`;o0000oooooolkooooo`00oooooom`ooooo`;o0000oooo
oolmooooo`00oooooom_ooooo`03o`000?oooooooooo0?oooooo?Oooool00?ooooooK_ooool00ol0
003oooooooooo`3oooooockooooo003oooooofgooooo00?o0000ooooooooool0ooooooloooooo`00
oooooom/ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooJoooool00ol0003ooooooooo
o`3ooooood7ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00oooooomZoooo
o`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJOooool00ol0003oooooooooo`3ooooood?o
oooo003oooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomXooooo`03o`000?oo
oooooooo0?ooooooA?ooool00?ooooooIoooool00ol0003oooooooooo`3oooooodGooooo003ooooo
ofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oooooooooo0?oo
ooooA_ooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofGooooo00?o
0000ooooooooool0oooooom7ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool0
0?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o0000oooooooo
ool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooHooo
ool00ol0003oooooooooo`3oooooodWooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:
ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003o
ooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00oooo
oomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3o
oooood_ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03
o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo
003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooo
oooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3o
oooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?oooooo
C?ooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000
ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oo
ooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0
oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooG_ooool0
0ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>oooo
o`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003ooooo
ooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3ooooo
odoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003o
oooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo
0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo
00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCooo
ool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooo
oom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooooooo
o`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLoooo
o`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3o
oooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03
o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooool@ooooo`?o0000
00?o410@ooooooooool0oooooonIooooo`00oooooolBooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0
000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooKOoo
ool00?oooooo4_ooool00onHV9So<S8booooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>
ooooo`03o`000?oooooooooo00Cooooo0_lb<S;oooooofkooooo003ooooooa;ooooo00?ogMgMo`00
0?nj^[X01_ooool00ol0003oooooooooo`02ooooo`Go00000oooool00on7QhOo0000okZj^P05oooo
o`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o
^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool0
1oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj
^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0ooooool@ooooo`00oooooolBooooo`03oeEEEOmg
MgOoA4A400Kooooo00?o0000ooooooooool00_ooool2ogMgM`;ooooo00Oo0000oooooooooooooooo
olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo
00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@ooooool@ooooo`00oooooolA
ooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`03oeEEEOnH
V9Sooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1Oooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`07ooooo`06oc8b
<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolCoooo
o`00ooooool@ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?oooooooooooc8b<_n7QhL02oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[o
ooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMg
MoooooooooooohN7Qol0003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0
003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00007?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2
ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00oooooolKooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo<?ooool00?oooooo6oooool2o`0001?ooooo00?o0000ooooooooool01?ooool2
o`0000gooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo
000000Gooooo1?l0003ooooooboooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46136 0 m
.45746 .00825 L
.45319 .01725 L
.45253 .01936 L
.45176 .02162 L
.45077 .02376 L
.44952 .0257 L
.44785 .0277 L
.44554 .02988 L
.43993 .03383 L
.4316 .03806 L
.42609 .0402 L
.41853 .04255 L
.4 .0467 L
.37203 .05116 L
.35741 .05332 L
.35032 .05446 L
.34383 .05567 L
.34119 .05627 L
.33912 .05684 L
.33765 .05735 L
.33705 .05761 L
.33652 .0579 L
.33616 .05817 L
.33593 .05842 L
.33583 .05869 L
.33583 .05884 L
.33586 .05897 L
.33602 .05922 L
.33633 .05948 L
.33675 .05973 L
.33726 .05996 L
.33882 .06048 L
.34075 .06095 L
.34346 .06147 L
.34697 .06202 L
.35441 .06294 L
.3647 .06395 L
.39536 .06623 L
.43087 .06835 L
.50391 .07235 L
.5391 .07446 L
.57009 .07669 L
.58278 .07782 L
.59424 .07906 L
.60241 .08019 L
.60817 .08125 L
.61051 .0818 L
.61232 .08233 L
.6136 .0828 L
Mistroke
.61466 .08332 L
.61511 .08361 L
.61543 .08388 L
.61557 .08403 L
.61569 .08419 L
.61578 .08434 L
.61584 .08448 L
.6159 .08473 L
.61589 .085 L
.61585 .08514 L
.61579 .08528 L
.61564 .08555 L
.61542 .08581 L
.61511 .0861 L
.61427 .08668 L
.61214 .08773 L
.60884 .08895 L
.60513 .09009 L
.58874 .09439 L
.57383 .09835 L
.56026 .10267 L
.54998 .10695 L
.542 .11146 L
.53645 .11566 L
.5319 .12014 L
.52851 .1244 L
.52555 .12901 L
.52135 .13756 L
.51819 .14631 L
.51586 .15474 L
.51405 .16284 L
.51248 .17146 L
.51123 .17977 L
.51009 .18859 L
.50918 .19709 L
.5084 .20527 L
.50767 .21398 L
.50707 .22235 L
.50654 .23041 L
.50603 .23899 L
.5056 .24724 L
.50517 .25602 L
.5048 .26448 L
.50447 .27261 L
.50416 .28126 L
.50387 .2896 L
.50358 .29845 L
.50334 .30698 L
.50311 .31519 L
.50288 .32392 L
Mistroke
.50267 .33233 L
.50249 .34042 L
.5023 .34902 L
.50213 .35731 L
.50195 .36612 L
.5018 .3746 L
.50165 .38276 L
.5015 .39145 L
.50136 .39981 L
.50122 .40869 L
.50109 .41725 L
.50097 .42549 L
.50084 .43425 L
.50072 .44269 L
.50062 .4508 L
.5005 .45944 L
.50039 .46775 L
.50028 .47659 L
.50018 .4851 L
.50008 .49329 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003oooooooln
ooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_ooool00ol0003oooooooooo`3ooooo
ofkooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooolmooooo`03o`00
0?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo003o
oooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooollooooo`03o`000?oooooooooo
0?ooooooL?ooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc_ooooo
00?o0000ooooooooool0oooooomaooooo`00ooooooljooooo`03o`000?oooooooooo0?ooooooL_oo
ool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003oooooocWooooo00?o0000oooo
ooooool0oooooomcooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool00?oooooo
>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocSooooo00?o0000ooooooooool0oooo
oomdooooo`00oooooolhooooo`03o`000?oooooooooo0?ooooooM?ooool00?oooooo=oooool00ol0
003oooooooooo`3oooooogGooooo003oooooocKooooo00?o0000ooooooooool0oooooomfooooo`00
ooooooleooooo`03o`000?oooooooooo0?ooooooMoooool00?oooooo<oooool2o`000?ooooooN_oo
ool00?oooooo<_ooool00ol0003oooooooooo`3oooooog[ooooo003ooooooc3ooooo0_l0003ooooo
oggooooo003oooooobkooooo0_l0003oooooogoooooo003oooooobcooooo0_l0003ooooooh7ooooo
003oooooob[ooooo0_l0003ooooooh?ooooo003oooooobOooooo0ol0003oooooohGooooo003ooooo
obCooooo0ol0003oooooohSooooo003oooooob3ooooo1?l0003ooooooh_ooooo003ooooooa[ooooo
1_l0003oooooohoooooo003ooooooaCooooo1_l0003ooooooiGooooo003oooooo`kooooo1_l0003o
oooooi_ooooo003oooooo`Sooooo1_l0003ooooooj7ooooo003oooooo`?ooooo1Ol0003oooooojOo
oooo003mooooo`Go0000oooooon/ooooo`00m?ooool9o`000?oooooo/Oooool00?3ooooo1?l0003o
oooook[ooooo003^ooooo`;o0000oooooonnooooo`00kOooool00ol0003oooooooooo`3ooooookko
oooo003^ooooo`Co0000oooooonlooooo`00l_ooool6o`000?oooooo]_ooool00?Sooooo3_l0003o
ooooojSooooo003oooooo`Oooooo2Ol0003ooooooioooooo003ooooooa3ooooo4Ol0003oooooohko
oooo003oooooob7ooooo4ol0003oooooog_ooooo003oooooocCooooo3ol0003oooooofcooooo003o
oooood?ooooo3ol0003ooooooegooooo003ooooooe;ooooo5?l0003oooooodWooooo003oooooofKo
oooo5Ol0003oooooocCooooo003oooooog_ooooo3_l0003oooooobKooooo003oooooohWooooo2?l0
003ooooooakooooo003ooooooi7ooooo1_l0003ooooooaSooooo003ooooooiOooooo1_l0003ooooo
oa;ooooo003ooooooigooooo0ol0003oooooo`oooooo003ooooooj3ooooo0_l0003oooooo`gooooo
003ooooooj3ooooo0_l0003oooooo`gooooo003ooooooj3ooooo00?o0000ooooooooool0ooooool<
ooooo`00oooooonKooooo`Go0000ooooool?ooooo`00oooooonHooooo`?o0000oooooolDooooo`00
oooooonEooooo`?o0000oooooolGooooo`00oooooonBooooo`?o0000oooooolJooooo`00oooooon>
ooooo`Co0000oooooolMooooo`00oooooon9ooooo`Go0000oooooolQooooo`00oooooon5ooooo`Co
0000oooooolVooooo`00oooooon2ooooo`?o0000oooooolZooooo`00oooooomoooooo`?o0000oooo
ool]ooooo`00oooooomlooooo`?o0000ooooool`ooooo`00oooooomjooooo`;o0000oooooolcoooo
o`00oooooomhooooo`;o0000ooooooleooooo`00oooooomfooooo`;o0000oooooolgooooo`00oooo
oomdooooo`;o0000ooooooliooooo`00oooooomcooooo`03o`000?oooooooooo0?oooooo>Oooool0
0?ooooooLOooool2o`000?oooooo??ooool00?ooooooKoooool2o`000?oooooo?_ooool00?oooooo
K_ooool00ol0003oooooooooo`3oooooockooooo003oooooofgooooo00?o0000ooooooooool0oooo
ooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooJoooool00ol0
003oooooooooo`3ooooood7ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00
oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJOooool00ol0003ooooooooo
o`3ooooood?ooooo003oooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomXoooo
o`03o`000?oooooooooo0?ooooooA?ooool00?ooooooIoooool00ol0003oooooooooo`3oooooodGo
oooo003oooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oo
oooooooo0?ooooooA_ooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003ooooo
ofKooooo00?o0000ooooooooool0oooooom6ooooo`00oooooomUooooo`03o`000?oooooooooo0?oo
ooooAoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofCooooo00?o
0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool0
0?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o0000oooooooo
ool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooHooo
ool00ol0003oooooooooo`3oooooodWooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:
ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003o
ooooooooo`3ooooood[ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooo
oomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3o
oooood_ooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03
o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo
003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooo
oooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003ooooooeoo
oooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?oooooo
COooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000
ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oo
ooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0
oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool0
0ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>oooo
o`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooGOooool00ol0003ooooo
ooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3ooooo
odoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003o
oooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo
0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo
00?o0000ooooooooool0oooooom?ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?oo
ool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooo
oom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003o
ooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooo
oomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00oooooolCooooo`?o000000?o410@ooooooooool0
oooooonFooooo`00oooooolEooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0?ooooooJ_ooool00?oooooo5Oooool0
0onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S;oooooof_ooooo003ooooooaGooooo00?ogMgMo`000?nj^[X01oooool01?l0
003oooooooooooooool5o`0000Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0
003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go0000
2Oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj
^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0oooooolDooooo`00oooooolEooooo`03oeEEEOmg
MgOoA4A400Oooooo00Co0000oooooooooooooooo0_mgMgL2ooooo`03o`000?oooooooooo00;ooooo
00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooooooo
ool00oooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00cooooo00?o0000ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A009
ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooaCooooo003ooooooaCooooo00GogMgM
oa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEEoiRHV?ooool03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00Go^[ZjohN7QomVIVKoIVIV
oa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolGooooo`00oooo
oolDooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003oooooooooo`03ooooo`03oeEE
EOnHV9Sooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h0
2Oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo
0?oooooo5oooool00?oooooo4oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Co
oooo00Go0000ooooooooooooooooo`000002ooooo`03oc8b<_n7QhOooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool03Oooool00omgMgOoIVIVooooo`08ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_oo
ool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003o
oooooaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03
ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003o`0000Gooooo00?o
0000ooooooooool02Oooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooaCooooo
003ooooooaoooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05o`000?nj
^[[ooooooiRHV?l@4100oooooolcooooo`00oooooolOooooo`;o00004_ooool00ol0003ooooooooo
o`05ooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c03ooooooc?ooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.25) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.46644 0 m
.46591 .00192 L
.46529 .00402 L
.46501 .00508 L
.46488 .00566 L
.46477 .00621 L
.46469 .00672 L
.46468 .00686 L
.46466 .00701 L
.46464 .00728 L
.46463 .00752 L
.46463 .00774 L
.46463 .00799 L
.46465 .00825 L
.46466 .0084 L
.46467 .00854 L
.46471 .00885 L
.4648 .0094 L
.46495 .01005 L
.46512 .01066 L
.46587 .01295 L
.46616 .01395 L
.46629 .0145 L
.46639 .01502 L
.46644 .01531 L
.46647 .01557 L
.4665 .01586 L
.46651 .01603 L
.46651 .01618 L
.46652 .01645 L
.46652 .01669 L
.46651 .01696 L
.46651 .0171 L
.4665 .01725 L
.46648 .01751 L
.46645 .01775 L
.46637 .0183 L
.46626 .01883 L
.46612 .0194 L
.46544 .02138 L
.46435 .02371 L
.46316 .02584 L
.45721 .03437 L
.44942 .04259 L
.44406 .04683 L
.43677 .05133 L
.42747 .05551 L
.41513 .05942 L
.39587 .06375 L
.37401 .06771 L
Mistroke
.36321 .06968 L
.35344 .07177 L
.35113 .07239 L
.34927 .07298 L
.34781 .07355 L
.34728 .0738 L
.34678 .07407 L
.34642 .07431 L
.34612 .07457 L
.34589 .07484 L
.34577 .07509 L
.34574 .07524 L
.34574 .07539 L
.34583 .07567 L
.34602 .07595 L
.34631 .0762 L
.34669 .07645 L
.3472 .07672 L
.34839 .07719 L
.35007 .0777 L
.35241 .07826 L
.35793 .07926 L
.36456 .08019 L
.38495 .08232 L
.41355 .0846 L
.47783 .08886 L
.51188 .0911 L
.5443 .09347 L
.56842 .09559 L
.57899 .09672 L
.58853 .09792 L
.59564 .09903 L
.6008 .10004 L
.60475 .10106 L
.60742 .10202 L
.60843 .10252 L
.60915 .103 L
.60946 .10327 L
.60969 .10352 L
.60988 .10379 L
.60995 .10393 L
.61001 .10408 L
.61004 .10423 L
.61006 .10437 L
.61006 .10463 L
.60999 .10491 L
.60993 .10507 L
.60986 .10521 L
.6097 .10546 L
.60948 .10572 L
Mistroke
.60889 .10627 L
.60738 .10725 L
.60522 .1083 L
.60022 .1102 L
.57149 .11901 L
.55921 .12341 L
.55018 .12749 L
.54336 .13144 L
.53772 .13565 L
.53297 .14023 L
.52946 .14454 L
.52443 .15277 L
.52059 .16154 L
.5178 .16997 L
.51569 .17809 L
.51386 .18672 L
.51241 .19504 L
.51112 .20387 L
.51006 .21239 L
.50918 .22058 L
.50837 .22929 L
.50767 .23768 L
.50708 .24575 L
.50652 .25434 L
.50603 .2626 L
.50556 .27139 L
.50515 .27986 L
.50478 .288 L
.50442 .29667 L
.50411 .30501 L
.5038 .31388 L
.50352 .32242 L
.50326 .33064 L
.50301 .33938 L
.50279 .3478 L
.50258 .3559 L
.50237 .36452 L
.50218 .37281 L
.50199 .38163 L
.50181 .39013 L
.50164 .3983 L
.50148 .40699 L
.50133 .41537 L
.50117 .42426 L
.50102 .43283 L
.50088 .44108 L
.50074 .44985 L
.50061 .4583 L
.50048 .46643 L
.50035 .47508 L
Mistroke
.50024 .4834 L
.50011 .49225 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooom2
ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@Oooool00ol0003oooooooooo`3ooooo
of_ooooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`00
0?oooooooooo0?ooooooJoooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003o
oooood3ooooo00?o0000ooooooooool0oooooom/ooooo`00oooooom1ooooo`03o`000?oooooooooo
0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo
00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`;o0000oooooom/ooooo`00oooooom2
ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3ooooo
of[ooooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`00
0?oooooooooo0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003o
oooood3ooooo00?o0000ooooooooool0oooooom/ooooo`00ooooooloooooo`03o`000?oooooooooo
0?ooooooKOooool00?oooooo?oooool00ol0003oooooooooo`3oooooofgooooo003oooooockooooo
00?o0000ooooooooool0oooooom^ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKooo
ool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo003ooooooccooooo00?o0000oooo
ooooool0oooooom`ooooo`00oooooollooooo`03o`000?oooooooooo0?ooooooL?ooool00?oooooo
>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[ooooo00?o0000ooooooooool0oooo
oombooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool00?oooooo>?ooool00ol0
003oooooooooo`3oooooogCooooo003oooooocKooooo0_l0003oooooogOooooo003oooooocCooooo
0_l0003oooooogWooooo003ooooooc;ooooo0_l0003oooooog_ooooo003ooooooc7ooooo00?o0000
ooooooooool0oooooomkooooo`00ooooool`ooooo`03o`000?oooooooooo0?ooooooO?ooool00?oo
oooo;_ooool2o`000?ooooooOoooool00?oooooo;?ooool2o`000?ooooooPOooool00?oooooo:_oo
ool2o`000?ooooooPoooool00?oooooo9oooool3o`000?ooooooQOooool00?oooooo8oooool4o`00
0?ooooooR?ooool00?oooooo7oooool4o`000?ooooooS?ooool00?oooooo6oooool4o`000?oooooo
T?ooool00?oooooo5oooool4o`000?ooooooU?ooool00?oooooo4oooool4o`000?ooooooV?ooool0
0?oooooo3_ooool5o`000?ooooooW?ooool00?oooooo2Oooool5o`000?ooooooXOooool00?oooooo
1?ooool5o`000?ooooooY_ooool00?cooooo1ol0003ooooooj_ooooo003hooooo`Co0000oooooonb
ooooo`00mOooool3o`000?oooooo]_ooool00?Cooooo0_l0003ooooookSooooo003dooooo`03o`00
0?oooooooooo0?oooooo]oooool00?Cooooo1ol0003ooooook?ooooo003kooooo`Co0000oooooon_
ooooo`00ooooool9o`000?ooooooY_ooool00?oooooo2Oooool;o`000?ooooooVoooool00?oooooo
5?ooool9o`000?ooooooT_ooool00?oooooo7Oooool>o`000?ooooooQ?ooool00?oooooo:ooooolE
o`000?ooooooKoooool00?oooooo@?ooool@o`000?ooooooGoooool00?ooooooD?ooool;o`000?oo
ooooE?ooool00?ooooooFoooool?o`000?ooooooAOooool00?ooooooJ_ooool>o`000?oooooo=ooo
ool00?ooooooN?ooool8o`000?oooooo;oooool00?ooooooP?ooool=o`000?oooooo8_ooool00?oo
ooooSOooool6o`000?oooooo7?ooool00?ooooooToooool7o`000?oooooo5Oooool00?ooooooV_oo
ool00ol0003oooooooooo`3ooooooa;ooooo003ooooooi_ooooo0ol0003ooooooa7ooooo003ooooo
oigooooo00?o0000ooooooooool0ooooool?ooooo`00oooooonLooooo`;o0000oooooolAooooo`00
oooooonKooooo`03o`000?oooooooooo0?oooooo4Oooool00?ooooooVOooool2o`000?oooooo5?oo
ool00?ooooooUOooool4o`000?oooooo5_ooool00?ooooooT_ooool3o`000?oooooo6_ooool00?oo
ooooS_ooool4o`000?oooooo7Oooool00?ooooooR_ooool4o`000?oooooo8Oooool00?ooooooQooo
ool3o`000?oooooo9Oooool00?ooooooQ?ooool3o`000?oooooo:?ooool00?ooooooPOooool3o`00
0?oooooo:oooool00?ooooooO_ooool3o`000?oooooo;_ooool00?ooooooO?ooool2o`000?oooooo
<Oooool00?ooooooN_ooool2o`000?oooooo<oooool00?ooooooN?ooool2o`000?oooooo=Oooool0
0?ooooooM_ooool2o`000?oooooo=oooool00?ooooooM?ooool2o`000?oooooo>Oooool00?oooooo
L_ooool2o`000?oooooo>oooool00?ooooooLOooool00ol0003oooooooooo`3ooooooc_ooooo003o
ooooog3ooooo00?o0000ooooooooool0oooooollooooo`00oooooom_ooooo`03o`000?oooooooooo
0?oooooo?Oooool00?ooooooK_ooool00ol0003oooooooooo`3oooooockooooo003oooooofgooooo
00?o0000ooooooooool0ooooooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oooooo@?oo
ool00?ooooooK?ooool00ol0003oooooooooo`3ooooood3ooooo003oooooof_ooooo00?o0000oooo
ooooool0oooooom1ooooo`00oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool00?oooooo
J_ooool00ol0003oooooooooo`3ooooood;ooooo003oooooofWooooo00?o0000ooooooooool0oooo
oom3ooooo`00oooooomXooooo`03o`000?oooooooooo0?ooooooA?ooool00?ooooooJ?ooool00ol0
003oooooooooo`3oooooodCooooo003oooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00
oooooomWooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooI_ooool00ol0003ooooooooo
o`3oooooodKooooo003oooooofKooooo00?o0000ooooooooool0oooooom6ooooo`00oooooomUoooo
o`03o`000?oooooooooo0?ooooooAoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOo
oooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oo
oooooooo0?ooooooB?ooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003ooooo
of?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?oo
ooooBOooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o
0000ooooooooool0oooooom:ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool0
0?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000oooooooo
ool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOoo
ool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;
ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooH?ooool00ol0003o
ooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooo
oomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3o
ooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomOooooo`03
o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo
003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooo
oooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoo
oooo00?o0000ooooooooool0oooooom=ooooo`00oooooomNooooo`03o`000?oooooooooo0?oooooo
C_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000
ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?oo
ooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooegooooo00?o0000ooooooooool0
oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool0
0ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?oooo
o`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003ooooo
ooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3ooooo
odoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003o
oooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo
0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo
00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?oo
ool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooe_ooooo00?o0000ooooooooool0oooo
oomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0
003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00
oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooFOooool00ol0003ooooo
ooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooo
oooo[oooool00?oooooo4?ooool3o`000003oa0@4?oooooooooo0?ooooooVOooool00?oooooo4_oo
ool00ol@413o^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`3oooooofgooooo003ooooooa;ooooo00?oV9RHoc8b<_ooool01_ooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8boooooom^
ooooo`00oooooolBooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool5o`00
00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000
ooooooooool01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Sooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oooooo4?ooool00?oooooo4_oo
ool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooooooo00;ooooo0_mgMgL2ooooo`07o`000?oo
ooooooooooooooo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@
ooooool@ooooo`00oooooolAooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003ooooo
ooooo`03ooooo`03oeEEEOnHV9Sooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00onHV9So8B4Q
onk^kP09ooooo`03o`000?oooooooooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIV
I_n7QhOooooooiRHV?mEEED01Oooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo1_l0000<ooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`07ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000
ooooooooool0oooooolCooooo`00ooooool@ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooc8b<_n7QhL02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0=ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c008ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003ooooooa3ooooo003ooooooa3ooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
1Ol00009ooooo`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00007?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00
oooooolKooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?o0000ooooooooool0ooooool`ooooo`00oooooolKooooo`;o0000
4oooool00ol0003oooooooooo`04ooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEE
EOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000ooooool_ooooo`00
ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.3) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47038 0 m
.4704 .00025 L
.47035 .00048 L
.47029 .00073 L
.47024 .00099 L
.47022 .00124 L
.4702 .00147 L
.4702 .00169 L
.47021 .00192 L
.47023 .00217 L
.47027 .00243 L
.47032 .00269 L
.47039 .00292 L
.4705 .00319 L
.47064 .00348 L
.47098 .00402 L
.47294 .00624 L
.47378 .0072 L
.47454 .00825 L
.47488 .00886 L
.47512 .00941 L
.47529 .00995 L
.47535 .01021 L
.47541 .01051 L
.47543 .01067 L
.47545 .01082 L
.47546 .01096 L
.47547 .01111 L
.47547 .01127 L
.47548 .01145 L
.47547 .01159 L
.47547 .01175 L
.47546 .01191 L
.47545 .01204 L
.47542 .01235 L
.47539 .01263 L
.47534 .01292 L
.47513 .01399 L
.47486 .01499 L
.47413 .01725 L
.47093 .02559 L
.46708 .03445 L
.46263 .04299 L
.45722 .0512 L
.45386 .05536 L
.44942 .05994 L
.44414 .06434 L
.43802 .06836 L
.4296 .07251 L
.41691 .07697 L
Mistroke
.40118 .08103 L
.38049 .08546 L
.37043 .08763 L
.36223 .08967 L
.35863 .0908 L
.35709 .0914 L
.35577 .09202 L
.35492 .09255 L
.35455 .09285 L
.35429 .09313 L
.35411 .09339 L
.35401 .09363 L
.35397 .0939 L
.35401 .09415 L
.35411 .0944 L
.35429 .09466 L
.35454 .09491 L
.35483 .09514 L
.35574 .09567 L
.35706 .09622 L
.35874 .09676 L
.36063 .09727 L
.36614 .09841 L
.37901 .10032 L
.39751 .10235 L
.50902 .11122 L
.53509 .11339 L
.55887 .11568 L
.57661 .11779 L
.58365 .11883 L
.58915 .11977 L
.59358 .12068 L
.59752 .12167 L
.6007 .12271 L
.60286 .12369 L
.60367 .12421 L
.60432 .12478 L
.60456 .12506 L
.60467 .12521 L
.60476 .12537 L
.60483 .12551 L
.60488 .12566 L
.60495 .12593 L
.60496 .1262 L
.60494 .12645 L
.60491 .12658 L
.60487 .12673 L
.60475 .127 L
.60461 .12725 L
.60442 .12752 L
Mistroke
.60399 .128 L
.60266 .12905 L
.60103 .13001 L
.59628 .13218 L
.58548 .13608 L
.56187 .14457 L
.54562 .15273 L
.53972 .15693 L
.5348 .16141 L
.53107 .16568 L
.52781 .1703 L
.52324 .17886 L
.5198 .18762 L
.51725 .19606 L
.51529 .20417 L
.51357 .21281 L
.51219 .22112 L
.51095 .22996 L
.50992 .23847 L
.50906 .24666 L
.50826 .25538 L
.50758 .26377 L
.50699 .27183 L
.50642 .28042 L
.50593 .28869 L
.50546 .29748 L
.50504 .30595 L
.50467 .31409 L
.5043 .32275 L
.50398 .3311 L
.50366 .33996 L
.50337 .34851 L
.50311 .35673 L
.50284 .36547 L
.5026 .37389 L
.50239 .38198 L
.50217 .3906 L
.50196 .3989 L
.50176 .40772 L
.50157 .41621 L
.5014 .42438 L
.50122 .43308 L
.50105 .44145 L
.50088 .45035 L
.50072 .45892 L
.50057 .46717 L
.50041 .47594 L
.50026 .48439 L
.50013 .49251 L
.5 .5 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooom4
ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3ooooo
ofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom5ooooo`03o`00
0?oooooooooo0?ooooooIoooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003o
ooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo
0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo
00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOoo
ool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodKooooo00?o0000oooo
ooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oooooo
AOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooo
oomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooA?ooool00ol0
003oooooooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00
oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003ooooooooo
o`3oooooofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom2oooo
o`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[o
oooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom1ooooo`03o`000?oo
oooooooo0?ooooooJoooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooo
od3ooooo00?o0000ooooooooool0oooooom/ooooo`00ooooooloooooo`03o`000?oooooooooo0?oo
ooooKOooool00?oooooo?oooool00ol0003oooooooooo`3oooooofgooooo003oooooockooooo00?o
0000ooooooooool0oooooom^ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKoooool0
0?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo003ooooooccooooo00?o0000oooooooo
ool0oooooom`ooooo`00oooooollooooo`03o`000?oooooooooo0?ooooooL?ooool00?oooooo>ooo
ool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[ooooo00?o0000ooooooooool0oooooomb
ooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool00?oooooo>?ooool00ol0003o
ooooooooo`3oooooogCooooo003oooooocKooooo0_l0003oooooogOooooo003oooooocGooooo00?o
0000ooooooooool0oooooomgooooo`00ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool0
0?oooooo<_ooool2o`000?ooooooNoooool00?oooooo<?ooool2o`000?ooooooOOooool00?oooooo
;_ooool2o`000?ooooooOoooool00?oooooo;?ooool2o`000?ooooooPOooool00?oooooo:oooool0
0ol0003oooooooooo`3ooooooh7ooooo003oooooobWooooo0_l0003oooooohCooooo003oooooobKo
oooo0ol0003oooooohKooooo003oooooob?ooooo0ol0003oooooohWooooo003oooooob3ooooo0ol0
003oooooohcooooo003ooooooa_ooooo1Ol0003oooooohoooooo003ooooooaKooooo1Ol0003ooooo
oiCooooo003ooooooa7ooooo1Ol0003ooooooiWooooo003oooooo`gooooo1?l0003ooooooikooooo
003oooooo`Sooooo1Ol0003ooooooj;ooooo003oooooo`?ooooo1Ol0003oooooojOooooo003ooooo
o`?o0000oooooon/ooooo`00o?ooool3o`000?oooooo[oooool00?[ooooo0_l0003ooooook;ooooo
003iooooo`03o`000?oooooooooo0?oooooo/_ooool00?Wooooo00?o0000ooooooooool0oooooonb
ooooo`00n_ooool3o`000?oooooo/Oooool00?gooooo1ol0003ooooooj[ooooo003oooooo`Gooooo
1?l0003oooooojKooooo003oooooo`Wooooo2?l0003ooooooikooooo003ooooooa7ooooo3?l0003o
oooooi;ooooo003ooooooagooooo3?l0003oooooohKooooo003oooooobWooooo3?l0003oooooog[o
oooo003oooooocGooooo2ol0003oooooofoooooo003ooooood3ooooo3?l0003oooooof?ooooo003o
ooooodcooooo3?l0003ooooooeOooooo003ooooooeSooooo3_l0003oooooodWooooo003oooooofKo
oooo4?l0003oooooocWooooo003oooooogKooooo2ol0003oooooobkooooo003ooooooh7ooooo1Ol0
003oooooobWooooo003oooooohKooooo2Ol0003oooooob3ooooo003oooooohoooooo1?l0003ooooo
oacooooo003ooooooi?ooooo1?l0003ooooooaSooooo003ooooooiOooooo0ol0003ooooooaGooooo
003ooooooiWooooo0_l0003ooooooaCooooo003ooooooi[ooooo00?o0000ooooooooool0oooooolB
ooooo`00oooooonIooooo`;o0000oooooolDooooo`00oooooonFooooo`?o0000oooooolFooooo`00
oooooonEooooo`03o`000?oooooooooo0?oooooo5oooool00?ooooooToooool2o`000?oooooo6_oo
ool00?ooooooT?ooool3o`000?oooooo7?ooool00?ooooooSOooool3o`000?oooooo7oooool00?oo
ooooR_ooool3o`000?oooooo8_ooool00?ooooooQoooool3o`000?oooooo9Oooool00?ooooooQOoo
ool2o`000?oooooo:?ooool00?ooooooP_ooool3o`000?oooooo:_ooool00?ooooooOoooool3o`00
0?oooooo;Oooool00?ooooooOOooool2o`000?oooooo<?ooool00?ooooooNoooool2o`000?oooooo
<_ooool00?ooooooNOooool2o`000?oooooo=?ooool00?ooooooMoooool2o`000?oooooo=_ooool0
0?ooooooMOooool2o`000?oooooo>?ooool00?ooooooLoooool2o`000?oooooo>_ooool00?oooooo
L_ooool00ol0003oooooooooo`3ooooooc[ooooo003oooooog7ooooo00?o0000ooooooooool0oooo
oolkooooo`00oooooom`ooooo`03o`000?oooooooooo0?oooooo??ooool00?ooooooKoooool00ol0
003oooooooooo`3oooooocgooooo003oooooofkooooo00?o0000ooooooooool0oooooolnooooo`00
oooooom]ooooo`03o`000?oooooooooo0?oooooo?oooool00?ooooooK?ooool00ol0003ooooooooo
o`3ooooood3ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00oooooom[oooo
o`03o`000?oooooooooo0?oooooo@Oooool00?ooooooJ_ooool00ol0003oooooooooo`3ooooood;o
oooo003oooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomYooooo`03o`000?oo
oooooooo0?oooooo@oooool00?ooooooJ?ooool00ol0003oooooooooo`3oooooodCooooo003ooooo
ofSooooo00?o0000ooooooooool0oooooom4ooooo`00oooooomWooooo`03o`000?oooooooooo0?oo
ooooAOooool00?ooooooIoooool00ol0003oooooooooo`3oooooodGooooo003oooooofKooooo00?o
0000ooooooooool0oooooom6ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool0
0?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofGooooo00?o0000oooooooo
ool0oooooom7ooooo`00oooooomUooooo`03o`000?oooooooooo0?ooooooAoooool00?ooooooI?oo
ool00ol0003oooooooooo`3oooooodSooooo003oooooofCooooo00?o0000ooooooooool0oooooom8
ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooHoooool00ol0003o
ooooooooo`3oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooo
oomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3o
oooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00oooooomRooooo`03
o`000?oooooooooo0?ooooooB_ooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo
003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooo
oooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7o
oooo00?o0000ooooooooool0oooooom;ooooo`00oooooomPooooo`03o`000?oooooooooo0?oooooo
C?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000
ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?oo
ooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0
oooooom<ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool0
0ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=oooo
o`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003ooooo
ooooo`3oooooodgooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomN
ooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3ooooo
odkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`00
0?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003o
oooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo
0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo
00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCooo
ool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000oooo
ooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oooooo
GOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooo
oom?ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooooooo
o`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLoooo
o`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3o
oooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oo
oooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooooooo
ool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3o
oooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03
o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000
ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oo
ooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0
oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooa?ooooo0ol000000ol@413oooooooooo`3ooooooiKooooo003ooooooaGooooo00?o
410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o
0000okZj^_ooool0oooooomZooooo`00oooooolEooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000
ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<_ooooooJoooool0
0?oooooo5Oooool00ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooooooo
o`03ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c009ooooo`06
oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo
00GoIVIVo`000?l0003oA4A4olc<c03ooooooaCooooo003ooooooaGooooo00?oEEEEogMgMom4A4@0
1oooool01?l0003oooooooooooooool2ogMgM`;ooooo00?o0000ooooooooool00_ooool00oo<c<co
0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03oooo
o`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool0
0ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Wooooo00Ko
0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool0
1_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo5?ooool00?oooooo5?ooool01OoMgMgo410@oooo
oolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool00omEEEGoV9RHooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaOooooo003ooooooaCooooo
00GoIVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?oo
ool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool6o`0000cooooo00?o0000ooooooooool03Oooool00onYZJWo410@ooooo`08ooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolG
ooooo`00oooooolCooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<
ooooo`03oa0@4?l0003o^[Zj00Wooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEE
EOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo5?oo
ool00?oooooo4oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co
0000oooooooooooooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooo
ooooo`09ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0=ooooo`03okZj
^_lQ8B7ooooo00Sooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?ooool00?oooooo
7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go410@oiRHV?oooooo
^[Zjo`00003ooooooc?ooooo003ooooooaoooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo
0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo410@
o`000?l@413oZJVY0?oooooo<oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.35) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.47369 0 m
.47764 .00192 L
.47886 .00248 L
.47982 .00302 L
.48056 .00354 L
.48109 .00402 L
.4815 .00452 L
.48165 .00479 L
.48178 .00508 L
.48187 .00535 L
.48193 .00561 L
.48195 .00576 L
.48196 .0059 L
.48197 .00606 L
.48197 .00621 L
.48196 .00645 L
.48193 .00672 L
.4819 .00696 L
.48186 .00719 L
.4816 .00825 L
.47869 .01725 L
.47613 .02581 L
.47364 .03404 L
.47071 .0428 L
.46746 .05123 L
.46375 .05934 L
.45876 .06797 L
.45242 .07628 L
.44792 .08082 L
.44263 .08511 L
.43585 .08936 L
.42752 .0933 L
.41637 .09728 L
.40059 .10168 L
.3823 .10616 L
.37469 .10812 L
.37105 .10916 L
.36761 .11027 L
.36479 .11136 L
.36283 .11235 L
.36211 .11283 L
.3618 .11309 L
.36152 .11335 L
.36132 .11359 L
.36114 .11384 L
.36103 .11408 L
.36097 .11429 L
.36094 .11456 L
.36096 .1147 L
.36098 .11484 L
Mistroke
.36108 .11509 L
.36124 .11536 L
.36146 .11563 L
.36173 .11587 L
.36239 .11634 L
.36343 .11689 L
.36465 .11739 L
.36833 .11853 L
.37269 .11954 L
.37848 .12062 L
.39181 .12256 L
.43359 .12698 L
.48195 .13122 L
.53244 .13582 L
.55237 .13797 L
.56992 .14025 L
.58167 .1422 L
.59113 .14434 L
.59449 .14539 L
.59715 .1465 L
.59877 .14745 L
.59943 .14798 L
.59989 .14848 L
.60008 .14876 L
.60017 .14891 L
.60024 .14906 L
.6003 .1492 L
.60035 .14935 L
.6004 .14961 L
.60043 .14987 L
.60041 .15014 L
.60037 .1504 L
.6003 .15064 L
.60017 .15093 L
.60002 .1512 L
.59957 .15182 L
.59904 .15236 L
.59836 .15294 L
.59519 .15494 L
.59069 .15709 L
.58103 .16099 L
.55948 .16977 L
.55087 .17415 L
.54435 .17823 L
.53484 .18636 L
.53113 .19072 L
.52835 .19469 L
.52373 .20322 L
.52044 .21143 L
.51771 .22016 L
Mistroke
.51562 .22857 L
.51398 .23665 L
.51249 .24526 L
.51128 .25355 L
.51018 .26235 L
.50925 .27084 L
.50846 .279 L
.50772 .28768 L
.50708 .29604 L
.50647 .30493 L
.50594 .31349 L
.50547 .32173 L
.50502 .33049 L
.50461 .33892 L
.50425 .34704 L
.50389 .35568 L
.50357 .36399 L
.50325 .37283 L
.50296 .38134 L
.50269 .38953 L
.50243 .39824 L
.50218 .40663 L
.50196 .4147 L
.50173 .42329 L
.50152 .43156 L
.5013 .44035 L
.5011 .44881 L
.50091 .45696 L
.50072 .46562 L
.50054 .47396 L
.50035 .48283 L
.50017 .49137 L
.50001 .49959 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooom6
ooooo`?o0000oooooomVooooo`00oooooom9ooooo`;o0000oooooomTooooo`00oooooom;ooooo`03
o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo
003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooo
oooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood[o
oooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oooooo
H_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003oooooodWooooo00?o0000
ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?oo
ooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0
oooooomSooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool0
0ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomToooo
o`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooAoooool00ol0003ooooo
ooooo`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7
ooooo`03o`000?oooooooooo0?ooooooIOooool00?ooooooA_ooool00ol0003oooooooooo`3ooooo
ofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom5ooooo`03o`00
0?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003o
ooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom4ooooo`03o`000?oooooooooo
0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003oooooodCooooo
00?o0000ooooooooool0oooooomXooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOoo
ool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood?ooooo00?o0000oooo
ooooool0oooooomYooooo`00oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo
@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood7ooooo00?o0000ooooooooool0oooo
oom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool00?oooooo@Oooool00ol0
003oooooooooo`3oooooof_ooooo003ooooood3ooooo00?o0000ooooooooool0oooooom/ooooo`00
oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool00ol0003ooooooooo
o`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00oooooolnoooo
o`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_ooool00ol0003oooooooooo`3oooooofko
oooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooolmooooo`03o`000?oo
oooooooo0?ooooooKoooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3ooooo003ooooo
oc_ooooo00?o0000ooooooooool0oooooomaooooo`00ooooooljooooo`03o`000?oooooooooo0?oo
ooooL_ooool00?oooooo>Oooool00ol0003oooooooooo`3oooooog?ooooo003oooooocSooooo00?o
0000ooooooooool0oooooomdooooo`00oooooolgooooo`03o`000?oooooooooo0?ooooooMOooool0
0?oooooo=Oooool2o`000?ooooooN?ooool00?oooooo=?ooool00ol0003oooooooooo`3oooooogSo
oooo003ooooooc?ooooo00?o0000ooooooooool0oooooomiooooo`00oooooolaooooo`;o0000oooo
oomlooooo`00ooooool`ooooo`03o`000?oooooooooo0?ooooooO?ooool00?oooooo;oooool00ol0
003oooooooooo`3ooooooggooooo003oooooobgooooo0_l0003ooooooh3ooooo003oooooob[ooooo
0ol0003ooooooh;ooooo003oooooobSooooo0_l0003oooooohGooooo003oooooobGooooo0ol0003o
ooooohOooooo003oooooob?ooooo0_l0003ooooooh[ooooo003oooooob3ooooo0ol0003oooooohco
oooo003ooooooa_ooooo1Ol0003oooooohoooooo003ooooooaKooooo1Ol0003ooooooiCooooo003o
oooooa;ooooo1?l0003ooooooiWooooo003oooooo`kooooo1?l0003ooooooigooooo003oooooo`_o
oooo0ol0003ooooooj7ooooo003oooooo`Sooooo0ol0003oooooojCooooo003oooooo`Cooooo1?l0
003oooooojOooooo003oooooo`;ooooo0_l0003ooooooj_ooooo003nooooo`?o0000oooooon]oooo
o`00oOooool2o`000?oooooo[oooool00?gooooo0_l0003oooooojoooooo003nooooo`Co0000oooo
oon/ooooo`00ooooool3ooooo`?o0000oooooonYooooo`00ooooool6ooooo`?o0000oooooonVoooo
o`00ooooool9ooooo`Ko0000oooooonPooooo`00ooooool?ooooo`Wo0000oooooonGooooo`00oooo
oolHooooo`Wo0000oooooon>ooooo`00oooooolQooooo`Wo0000oooooon5ooooo`00oooooolZoooo
o`co0000oooooomiooooo`00oooooolfooooo`oo0000oooooomZooooo`00oooooom5ooooo`go0000
oooooomMooooo`00oooooomBooooo`_o0000oooooomBooooo`00oooooomMooooo`_o0000oooooom7
ooooo`00oooooomXooooo`So0000ooooooloooooo`00oooooom`ooooo`Ko0000ooooooliooooo`00
oooooomfooooo`Wo0000ooooool`ooooo`00oooooomoooooo`[o0000oooooolVooooo`00oooooon9
ooooo`Go0000oooooolQooooo`00oooooon>ooooo`?o0000oooooolNooooo`00oooooonAooooo`Co
0000oooooolJooooo`00oooooonEooooo`03o`000?oooooooooo0?oooooo5oooool00?ooooooU_oo
ool2o`000?oooooo5oooool00?ooooooUoooool00ol0003oooooooooo`3ooooooaGooooo003ooooo
oiKooooo0_l0003ooooooaOooooo003ooooooiGooooo0_l0003ooooooaSooooo003ooooooi?ooooo
0_l0003ooooooa[ooooo003ooooooi;ooooo00?o0000ooooooooool0oooooolJooooo`00oooooon@
ooooo`;o0000oooooolMooooo`00oooooon=ooooo`?o0000oooooolOooooo`00oooooon:ooooo`?o
0000oooooolRooooo`00oooooon7ooooo`?o0000oooooolUooooo`00oooooon5ooooo`;o0000oooo
oolXooooo`00oooooon3ooooo`;o0000oooooolZooooo`00oooooon0ooooo`?o0000ooooool/oooo
o`00oooooomnooooo`;o0000ooooool_ooooo`00oooooomlooooo`;o0000oooooolaooooo`00oooo
oomjooooo`;o0000oooooolcooooo`00oooooomhooooo`;o0000ooooooleooooo`00oooooomfoooo
o`;o0000oooooolgooooo`00oooooomdooooo`;o0000ooooooliooooo`00oooooombooooo`;o0000
oooooolkooooo`00oooooomaooooo`03o`000?oooooooooo0?oooooo>oooool00?ooooooL?ooool0
0ol0003oooooooooo`3ooooooccooooo003oooooofoooooo00?o0000ooooooooool0oooooolmoooo
o`00oooooom^ooooo`03o`000?oooooooooo0?oooooo?_ooool00?ooooooKOooool00ol0003ooooo
ooooo`3oooooocoooooo003oooooofgooooo00?o0000ooooooooool0ooooooloooooo`00oooooom/
ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooJoooool00ol0003oooooooooo`3ooooo
od7ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00oooooomZooooo`03o`00
0?oooooooooo0?oooooo@_ooool00?ooooooJOooool00ol0003oooooooooo`3ooooood?ooooo003o
ooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomXooooo`03o`000?oooooooooo
0?ooooooA?ooool00?ooooooIoooool00ol0003oooooooooo`3oooooodGooooo003oooooofOooooo
00?o0000ooooooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_oo
ool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofGooooo00?o0000oooo
ooooool0oooooom7ooooo`00oooooomUooooo`03o`000?oooooooooo0?ooooooAoooool00?oooooo
IOooool00ol0003oooooooooo`3oooooodOooooo003oooooofCooooo00?o0000ooooooooool0oooo
oom8ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool00?ooooooHoooool00ol0
003oooooooooo`3oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00
oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooH_ooool00ol0003ooooooooo
o`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00oooooomRoooo
o`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[o
oooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oo
oooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003ooooo
of7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?oo
ooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof3ooooo00?o
0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool0
0?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000oooooooo
ool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooGooo
ool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=
ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003o
ooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooo
oomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3o
ooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03
o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo
003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomMooooo`03o`000?oooooo
oooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooego
oooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?oooooo
Coooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000
ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oo
ooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0
oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool0
0ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o0000ooooooooool0oooooom@oooo
o`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooo
ooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomL
ooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooo
oe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`00
0?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003o
oooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo
0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo
00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOoo
ool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooo
ooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?oooooo
Foooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooo
oomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0
003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00
oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003ooooooooo
o`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oo
oooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooo
oe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oo
ooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o
0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool0
0?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooo
oooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool0
0ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooo
ooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooEoooool0
0ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoo
oooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00ooooool@ooooo`?o000000?o410@ooooooooool0
oooooonIooooo`00oooooolBooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooKOooool00?oooooo4_ooool0
0onHV9So<S8booooo`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00Cooooo0_lb<S;oooooofkooooo003ooooooa;ooooo00?ogMgMo`000?nj^[X01_ooool00ol0
003oooooooooo`02ooooo`Go00000oooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000
odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Cooooo00Go
V9RHoa0@4?l0003o<S8bolc<c004ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool01_l@413o
<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIV
I_l0003o0000odA4A?o<c<`0ooooool@ooooo`00oooooolBooooo`03oeEEEOmgMgOoA4A400Kooooo
00?o0000ooooooooool00_ooool2ogMgM`;ooooo00Oo0000ooooooooooooooooolc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<
o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oo
oooooooo00Cooooo0_lQ8B44ooooo`05oa0@4?nj^[[oooooogMgMolb<S801oooool00omgMgOo<S8b
ooooo`07ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooa3ooooo003ooooooa7ooooo
00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?oo
ool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooooa?ooooo003ooooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05oooo
o`03o`000?oooooooooo00Cooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooo
ooooool03Oooool00onYZJWo410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko<S8bob4Q
8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooooa?ooooo003o
oooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o
410@o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo00Ko0000okZj^_oooooo
k^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooo
ooooooooQhN7o`000?oooooo4?ooool00?oooooo4?ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo00;ooooo00?o0000ooooooooool00_ooool5o`0000Wooooo00?o410@o`000?l0
00000ol00004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000Looooo`03
o`000?oooooooooo00gooooo00?o^[Zjob4Q8Oooool00oooool00ol0003oooooooooo`0:ooooo`06
ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo
00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooa3ooooo003ooooooa_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0:ooooo`05oa0@4?nHV9SooooookZj^_l000001?ooool00ol0
003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Cooooo`03o`000?oooooooooo00Co
oooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003?ooool01OnYZJWo
410@o`000?l@413oZJVY00Cooooo1?l0003ooooooboooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.48495 0 m
.48635 .00025 L
.48724 .00048 L
.48792 .00074 L
.48833 .00099 L
.48855 .00122 L
.48866 .00144 L
.48871 .00167 L
.48868 .00192 L
.4886 .00217 L
.48848 .00243 L
.48819 .00292 L
.48745 .00402 L
.48514 .00825 L
.4842 .01066 L
.48344 .01295 L
.48221 .01725 L
.48019 .02541 L
.47816 .03409 L
.47615 .04244 L
.47386 .05132 L
.47137 .05988 L
.4686 .06811 L
.4651 .07687 L
.46092 .0853 L
.45579 .09341 L
.4522 .09793 L
.4483 .10204 L
.44326 .10636 L
.43734 .11035 L
.42951 .11443 L
.41836 .11886 L
.39017 .12725 L
.383 .1293 L
.37622 .13145 L
.37153 .1333 L
.36949 .13434 L
.36808 .13531 L
.36779 .13557 L
.36752 .13585 L
.36733 .1361 L
.36716 .13636 L
.36704 .13659 L
.36696 .13685 L
.36692 .13709 L
.36692 .13731 L
.36697 .13758 L
.36706 .13785 L
.36718 .13808 L
.36736 .13834 L
Mistroke
.36761 .13861 L
.36794 .13891 L
.3687 .13944 L
.36977 .14002 L
.37123 .14065 L
.37468 .14178 L
.37904 .14288 L
.38392 .1439 L
.41104 .14792 L
.45162 .15234 L
.49757 .15686 L
.53612 .16098 L
.55242 .16303 L
.56732 .16526 L
.57849 .16736 L
.58626 .1693 L
.58932 .1703 L
.59194 .17137 L
.59382 .17237 L
.59506 .1733 L
.59558 .17383 L
.59593 .17432 L
.59608 .17461 L
.59619 .17487 L
.59623 .17501 L
.59627 .17516 L
.59632 .17544 L
.59633 .17572 L
.59632 .17587 L
.59631 .17602 L
.59628 .17617 L
.59625 .17631 L
.59616 .17662 L
.59605 .17689 L
.5959 .17717 L
.59555 .1777 L
.5946 .17873 L
.59344 .17971 L
.58994 .18192 L
.58061 .1864 L
.56199 .19466 L
.55381 .19885 L
.54631 .20344 L
.5361 .21189 L
.53239 .21608 L
.52913 .22055 L
.5242 .2294 L
.52072 .23794 L
.51811 .24614 L
.51588 .25488 L
Mistroke
.51413 .26328 L
.51271 .27137 L
.51141 .27998 L
.51033 .28826 L
.50934 .29707 L
.50849 .30555 L
.50776 .31371 L
.50707 .3224 L
.50647 .33076 L
.50588 .33964 L
.50536 .3482 L
.50492 .35644 L
.50447 .3652 L
.50407 .37364 L
.5037 .38175 L
.50335 .39039 L
.50303 .3987 L
.5027 .40754 L
.50239 .41605 L
.50212 .42424 L
.50185 .43296 L
.50159 .44135 L
.50135 .44941 L
.5011 .458 L
.50088 .46627 L
.50064 .47506 L
.50042 .48353 L
.50021 .49167 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooom=
ooooo`Co0000oooooomNooooo`00oooooom?ooooo`;o0000oooooomNooooo`00oooooom?ooooo`03
o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo
003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom=ooooo`03o`000?oooooo
oooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgo
oooo00?o0000ooooooooool0oooooomOooooo`00oooooom<ooooo`03o`000?oooooooooo0?oooooo
H?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000
ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oo
ooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003ooooood_ooooo00?o0000ooooooooool0
oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool0
0ol0003oooooooooo`3oooooof7ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRoooo
o`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003ooooo
ooooo`3oooooof;ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9
ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3ooooo
of?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`00
0?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003o
ooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo
0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo
00?o0000ooooooooool0oooooomTooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOoo
ool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000oooo
ooooool0oooooomUooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oooooo
A_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooo
oomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooAOooool00ol0
003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00
oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003ooooooooo
o`3oooooofOooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4oooo
o`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSo
oooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oo
oooooooo0?ooooooJOooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooo
od;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?oo
ooooJ_ooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o
0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool0
0?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003oooooocoooooo00?o0000oooooooo
ool0oooooom]ooooo`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?_oo
ool00ol0003oooooooooo`3oooooofkooooo003oooooockooooo00?o0000ooooooooool0oooooom^
ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKoooool00?oooooo??ooool00ol0003o
ooooooooo`3oooooog3ooooo003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooo
oolkooooo`03o`000?oooooooooo0?ooooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3o
ooooog;ooooo003oooooocWooooo00?o0000ooooooooool0oooooomcooooo`00oooooolhooooo`03
o`000?oooooooooo0?ooooooM?ooool00?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo
003oooooocOooooo00?o0000ooooooooool0oooooomeooooo`00ooooooleooooo`;o0000oooooomh
ooooo`00ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo<_ooool2o`000?oo
ooooNoooool00?oooooo<Oooool00ol0003oooooooooo`3oooooog_ooooo003ooooooc3ooooo00?o
0000ooooooooool0oooooomlooooo`00ooooool^ooooo`;o0000oooooomoooooo`00ooooool/oooo
o`;o0000oooooon1ooooo`00ooooool[ooooo`03o`000?oooooooooo0?ooooooPOooool00?oooooo
:?ooool3o`000?ooooooQ?ooool00?oooooo9Oooool3o`000?ooooooQoooool00?oooooo8_ooool3
o`000?ooooooR_ooool00?oooooo7oooool3o`000?ooooooSOooool00?oooooo7?ooool3o`000?oo
ooooT?ooool00?oooooo6Oooool3o`000?ooooooToooool00?oooooo5_ooool3o`000?ooooooU_oo
ool00?oooooo4oooool3o`000?ooooooVOooool00?oooooo3oooool4o`000?ooooooW?ooool00?oo
oooo2_ooool5o`000?ooooooX?ooool00?oooooo1oooool3o`000?ooooooYOooool00?oooooo1_oo
ool00ol0003oooooooooo`3oooooojKooooo003oooooo`Cooooo0_l0003oooooojWooooo003ooooo
o`;ooooo0_l0003ooooooj_ooooo003oooooo`;ooooo00?o0000ooooooooool0oooooonZooooo`00
ooooool2ooooo`;o0000oooooon[ooooo`00ooooool3ooooo`Co0000oooooonXooooo`00ooooool7
ooooo`?o0000oooooonUooooo`00ooooool:ooooo`Oo0000oooooonNooooo`00oooooolAooooo`Ko
0000oooooonHooooo`00oooooolGooooo`Go0000oooooonCooooo`00oooooolLooooo`Oo0000oooo
oon<ooooo`00oooooolSooooo`Wo0000oooooon3ooooo`00ooooool/ooooo`Wo0000oooooomjoooo
o`00ooooooleooooo`Wo0000oooooomaooooo`00oooooolnooooo`[o0000oooooomWooooo`00oooo
oom8ooooo`Wo0000oooooomNooooo`00oooooomAooooo`_o0000oooooomCooooo`00oooooomLoooo
o`go0000oooooom6ooooo`00oooooomYooooo`Wo0000oooooolmooooo`00oooooombooooo`Go0000
oooooolhooooo`00oooooomgooooo`Oo0000oooooolaooooo`00oooooomnooooo`Wo0000oooooolX
ooooo`00oooooon7ooooo`Co0000oooooolTooooo`00oooooon;ooooo`?o0000oooooolQooooo`00
oooooon>ooooo`Co0000oooooolMooooo`00oooooonBooooo`03o`000?oooooooooo0?oooooo6_oo
ool00?ooooooToooool2o`000?oooooo6_ooool00?ooooooU?ooool00ol0003oooooooooo`3ooooo
oaSooooo003ooooooiCooooo00?o0000ooooooooool0oooooolHooooo`00oooooonDooooo`03o`00
0?oooooooooo0?oooooo6?ooool00?ooooooT_ooool2o`000?oooooo6oooool00?ooooooTOooool0
0ol0003oooooooooo`3ooooooa_ooooo003oooooohoooooo0_l0003ooooooakooooo003oooooohco
oooo0ol0003oooooob3ooooo003oooooohWooooo0ol0003oooooob?ooooo003oooooohOooooo0_l0
003oooooobKooooo003oooooohGooooo0_l0003oooooobSooooo003oooooohCooooo00?o0000oooo
ooooool0oooooolXooooo`00oooooon2ooooo`;o0000ooooool[ooooo`00oooooon0ooooo`;o0000
ooooool]ooooo`00oooooomnooooo`;o0000ooooool_ooooo`00oooooomkooooo`?o0000oooooola
ooooo`00oooooomhooooo`?o0000ooooooldooooo`00oooooomgooooo`03o`000?oooooooooo0?oo
oooo=Oooool00?ooooooM_ooool00ol0003oooooooooo`3oooooocKooooo003oooooogCooooo0_l0
003oooooocWooooo003oooooog?ooooo00?o0000ooooooooool0ooooooliooooo`00oooooomboooo
o`03o`000?oooooooooo0?oooooo>_ooool00?ooooooLOooool00ol0003oooooooooo`3ooooooc_o
oooo003oooooog3ooooo00?o0000ooooooooool0oooooollooooo`00oooooom_ooooo`03o`000?oo
oooooooo0?oooooo?Oooool00?ooooooK_ooool00ol0003oooooooooo`3oooooockooooo003ooooo
ofgooooo00?o0000ooooooooool0ooooooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oo
oooo@?ooool00?ooooooK?ooool00ol0003oooooooooo`3ooooood3ooooo003oooooof_ooooo00?o
0000ooooooooool0oooooom1ooooo`00oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool0
0?ooooooJ_ooool00ol0003oooooooooo`3ooooood;ooooo003oooooofWooooo00?o0000oooooooo
ool0oooooom3ooooo`00oooooomXooooo`03o`000?oooooooooo0?ooooooA?ooool00?ooooooJ?oo
ool00ol0003oooooooooo`3oooooodCooooo003oooooofOooooo00?o0000ooooooooool0oooooom5
ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooI_ooool00ol0003o
ooooooooo`3oooooodKooooo003oooooofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooo
oomUooooo`03o`000?oooooooooo0?ooooooAoooool00?ooooooIOooool00ol0003oooooooooo`3o
ooooodOooooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03
o`000?oooooooooo0?ooooooB?ooool00?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo
003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomSooooo`03o`000?oooooo
oooo0?ooooooBOooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof?o
oooo00?o0000ooooooooool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?oooooo
BOooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000
ooooooooool0oooooom:ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?oo
ooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000ooooooooool0
oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool0
0ol0003oooooooooo`3ooooood_ooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<oooo
o`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003ooooo
ooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomP
ooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooGoooool00ol0003oooooooooo`3ooooo
odgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`00
0?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003o
oooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomNooooo`03o`000?oooooooooo
0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo
00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_oo
ool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000oooo
ooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?oooooo
G_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooo
oom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0
003oooooooooo`3oooooodkooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00
oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003ooooooooo
o`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMoooo
o`03o`000?oooooooooo0?ooooooCoooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3o
oooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oo
oooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooo
oecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oo
ooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooooooo
ool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03
o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo
003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooo
oooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_o
oooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oooooo
DOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_oo
ool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oo
oooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooo
oeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?oo
ooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o
0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool0
0?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooooooo
ool0oooooomCooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000oooo
ooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooo
Eoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooo
oomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0
003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00
oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooooooo
o`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGoooo
o`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGo
oooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oo
oooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@
4?oooooooooo0?ooooooU_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003o
oooooaGooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`03ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj
00Oooooo00Co0000oooooooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Oooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2oooo
o`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0?oooooo
5?ooool00?oooooo5Oooool00omEEEGoMgMgodA4A007ooooo`04o`000?ooooooooooooooo`;oMgMg
0_ooool00ol0003oooooooooo`02ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^ko
MgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B47oooo
o`03o`000?oooooooooo00Sooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo5?ooool0
0?oooooo5?ooool01OoMgMgo410@oooooolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool0
0omEEEGoV9RHooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo1Ol0000:ooooo`05okZj^_n7QhOo
IVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo5ooo
ool00?oooooo5?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00ooo
ool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oM
gMgoooooo`0000[ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0
003oooooooooo`3ooooooaOooooo003ooooooa?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003o
gMgMooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00olb<S;oQhN7ooooo`0:oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo00002_ooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo0000oooooolDooooo`00oooooolCooooo`04oa0@4?l0003o0000ooooo`;o000000?o
410@ooooooooool00oooool01?l0003oooooooooooooool5o`0000Wooooo00?o410@o`000?l00000
0ol00005ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000Looooo`03o`00
0?oooooooooo00_ooooo00?oMgMgolc<c?l000002_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`00
00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co
0000oooooolDooooo`00oooooolOooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2oooool00oo^k^koA4A4o`00003oooooocCooooo003ooooooaoooooo0_l0000Booooo`03o`000?oo
oooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003_oo
ool00omgMgOo0000ooooo`3ooooooc?ooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.45) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.50666 0 m
.50409 .00025 L
.50216 .00048 L
.49881 .00099 L
.49659 .00147 L
.49503 .00192 L
.49367 .00244 L
.49271 .00292 L
.49183 .00349 L
.49116 .00402 L
.49018 .00499 L
.48936 .00607 L
.48813 .00825 L
.48717 .01051 L
.48645 .01259 L
.48513 .01725 L
.48324 .02573 L
.48165 .03389 L
.48001 .04257 L
.47841 .05092 L
.47659 .0598 L
.47467 .06836 L
.47261 .07659 L
.47009 .08535 L
.46725 .09378 L
.46396 .10189 L
.45964 .11052 L
.45422 .11883 L
.45075 .12306 L
.44616 .12767 L
.44059 .13209 L
.43399 .13618 L
.42582 .14016 L
.41452 .14456 L
.40094 .14904 L
.38806 .15315 L
.38215 .15523 L
.37752 .15717 L
.37548 .15823 L
.37399 .1592 L
.37336 .15971 L
.3728 .16027 L
.37256 .16057 L
.37238 .16085 L
.37225 .16112 L
.37219 .16127 L
.37215 .16141 L
.37209 .16167 L
.37207 .16195 L
.37209 .1622 L
Mistroke
.37215 .16246 L
.37225 .16272 L
.37238 .16297 L
.37272 .16342 L
.37328 .16397 L
.37395 .16447 L
.37607 .16559 L
.37837 .1665 L
.38154 .16749 L
.38992 .1695 L
.402 .17169 L
.41541 .17368 L
.45188 .17814 L
.49189 .18257 L
.52692 .18666 L
.5568 .1909 L
.56824 .19297 L
.57671 .19486 L
.58334 .19679 L
.58605 .19779 L
.58836 .19886 L
.59017 .19995 L
.59138 .20096 L
.59188 .20154 L
.59221 .20207 L
.59235 .20237 L
.5924 .20252 L
.59246 .20268 L
.5925 .20283 L
.59253 .20298 L
.59257 .20326 L
.59258 .20354 L
.59256 .20379 L
.59252 .20408 L
.59249 .20422 L
.59245 .20438 L
.59236 .20464 L
.59225 .20492 L
.59198 .20543 L
.5912 .20647 L
.59026 .20742 L
.58738 .20959 L
.58353 .21188 L
.56712 .22002 L
.55112 .22867 L
.53983 .237 L
.53521 .24156 L
.53163 .24586 L
.52635 .25407 L
.52227 .2628 L
Mistroke
.51928 .27121 L
.51698 .27929 L
.51498 .2879 L
.51337 .29618 L
.51192 .30499 L
.51072 .31348 L
.50971 .32164 L
.50876 .33032 L
.50795 .33868 L
.50717 .34757 L
.5065 .35613 L
.50591 .36436 L
.50533 .37312 L
.50482 .38156 L
.50437 .38968 L
.50392 .39831 L
.5035 .40663 L
.50309 .41546 L
.50272 .42398 L
.50239 .43217 L
.50204 .44088 L
.50172 .44927 L
.50142 .45734 L
.50112 .46593 L
.50084 .47419 L
.50055 .48298 L
.50027 .49145 L
.50001 .49959 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomE
ooooo`Oo0000oooooomCooooo`00oooooomBooooo`?o0000oooooomJooooo`00oooooomAooooo`;o
0000oooooomLooooo`00oooooom@ooooo`;o0000oooooomMooooo`00oooooom@ooooo`03o`000?oo
oooooooo0?ooooooG?ooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003ooooo
odoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?oo
ooooGOooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o
0000ooooooooool0oooooomNooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool0
0?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000oooooooo
ool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooC?oo
ool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomP
ooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003o
ooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooo
oom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3o
ooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03
o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo
003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom:ooooo`03o`000?oooooo
oooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[o
oooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oooooo
H_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003oooooodWooooo00?o0000
ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?oo
ooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0
oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool0
0ol0003oooooooooo`3oooooof?ooooo003oooooodSooooo00?o0000ooooooooool0oooooomToooo
o`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003ooooo
ooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8
ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooAoooool00ol0003oooooooooo`3ooooo
ofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`00
0?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003o
ooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo
0?ooooooI_ooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodGooooo
00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIooo
ool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000oooo
ooooool0oooooomWooooo`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo
A?ooool00ol0003oooooooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooo
oomXooooo`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo@oooool00ol0
003oooooooooo`3oooooofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00
oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo@_ooool00ol0003ooooooooo
o`3oooooof[ooooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom1oooo
o`03o`000?oooooooooo0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_o
oooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom0ooooo`03o`000?oo
oooooooo0?ooooooK?ooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooo
od3ooooo00?o0000ooooooooool0oooooom/ooooo`00ooooooloooooo`03o`000?oooooooooo0?oo
ooooKOooool00?oooooo?_ooool00ol0003oooooooooo`3oooooofkooooo003oooooockooooo00?o
0000ooooooooool0oooooom^ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKoooool0
0?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo003ooooooccooooo00?o0000oooooooo
ool0oooooom`ooooo`00oooooolkooooo`03o`000?oooooooooo0?ooooooLOooool00?oooooo>ooo
ool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[ooooo00?o0000ooooooooool0oooooomb
ooooo`00ooooooljooooo`03o`000?oooooooooo0?ooooooL_ooool00?oooooo>Oooool00ol0003o
ooooooooo`3oooooog?ooooo003oooooocSooooo00?o0000ooooooooool0oooooomdooooo`00oooo
oolgooooo`03o`000?oooooooooo0?ooooooMOooool00?oooooo=_ooool00ol0003oooooooooo`3o
ooooogKooooo003oooooocCooooo0_l0003oooooogWooooo003ooooooc?ooooo00?o0000oooooooo
ool0oooooomiooooo`00oooooolbooooo`03o`000?oooooooooo0?ooooooN_ooool00?oooooo<?oo
ool2o`000?ooooooOOooool00?oooooo;_ooool2o`000?ooooooOoooool00?oooooo;?ooool2o`00
0?ooooooPOooool00?oooooo:_ooool2o`000?ooooooPoooool00?oooooo:Oooool00ol0003ooooo
ooooo`3ooooooh?ooooo003oooooobOooooo0_l0003oooooohKooooo003oooooobCooooo0ol0003o
ooooohSooooo003oooooob7ooooo0ol0003ooooooh_ooooo003ooooooaoooooo0_l0003oooooohko
oooo003ooooooacooooo0ol0003ooooooi3ooooo003ooooooaWooooo0ol0003ooooooi?ooooo003o
oooooaKooooo0ol0003ooooooiKooooo003ooooooa;ooooo1?l0003ooooooiWooooo003oooooo`oo
oooo0ol0003ooooooigooooo003oooooo`gooooo0_l0003ooooooj3ooooo003oooooo`_ooooo0_l0
003ooooooj;ooooo003oooooo`Wooooo0_l0003oooooojCooooo003oooooo`Kooooo0ol0003ooooo
ojKooooo003oooooo`Gooooo0_l0003oooooojSooooo003oooooo`Gooooo00?o0000ooooooooool0
oooooonWooooo`00ooooool6ooooo`;o0000oooooonWooooo`00ooooool8ooooo`03o`000?oooooo
oooo0?ooooooY?ooool00?oooooo2Oooool5o`000?ooooooXOooool00?oooooo3_ooool3o`000?oo
ooooW_ooool00?oooooo4Oooool5o`000?ooooooVOooool00?oooooo5_ooool8o`000?ooooooTOoo
ool00?oooooo7_ooool8o`000?ooooooROooool00?oooooo9_ooool8o`000?ooooooPOooool00?oo
oooo;_ooool7o`000?ooooooN_ooool00?oooooo=Oooool8o`000?ooooooL_ooool00?oooooo?Ooo
ool9o`000?ooooooJOooool00?ooooooA_ooool9o`000?ooooooH?ooool00?ooooooCoooool8o`00
0?ooooooF?ooool00?ooooooEoooool7o`000?ooooooDOooool00?ooooooG_ooool7o`000?oooooo
B_ooool00?ooooooIOooool9o`000?oooooo@Oooool00?ooooooK_ooool9o`000?oooooo>?ooool0
0?ooooooMoooool7o`000?oooooo<Oooool00?ooooooO_ooool4o`000?oooooo;Oooool00?oooooo
P_ooool5o`000?oooooo:?ooool00?ooooooQoooool4o`000?oooooo9?ooool00?ooooooRoooool3
o`000?oooooo8Oooool00?ooooooS_ooool2o`000?oooooo7oooool00?ooooooT?ooool00ol0003o
ooooooooo`3ooooooacooooo003ooooooi7ooooo0_l0003ooooooacooooo003ooooooi;ooooo00?o
0000ooooooooool0oooooolJooooo`00oooooonBooooo`03o`000?oooooooooo0?oooooo6_ooool0
0?ooooooTOooool2o`000?oooooo7?ooool00?ooooooT?ooool2o`000?oooooo7Oooool00?oooooo
S_ooool2o`000?oooooo7oooool00?ooooooSOooool00ol0003oooooooooo`3ooooooaoooooo003o
oooooh_ooooo0_l0003oooooob;ooooo003oooooohWooooo0_l0003oooooobCooooo003oooooohOo
oooo0_l0003oooooobKooooo003oooooohGooooo0_l0003oooooobSooooo003ooooooh?ooooo0_l0
003oooooob[ooooo003ooooooh7ooooo0_l0003oooooobcooooo003oooooogoooooo0_l0003ooooo
obkooooo003ooooooggooooo0_l0003ooooooc3ooooo003oooooog_ooooo0_l0003ooooooc;ooooo
003oooooogWooooo0_l0003oooooocCooooo003oooooogOooooo0_l0003oooooocKooooo003ooooo
ogKooooo00?o0000ooooooooool0oooooolfooooo`00oooooomeooooo`03o`000?oooooooooo0?oo
oooo=oooool00?ooooooLoooool2o`000?oooooo>_ooool00?ooooooL_ooool00ol0003ooooooooo
o`3ooooooc[ooooo003oooooog7ooooo00?o0000ooooooooool0oooooolkooooo`00oooooom`oooo
o`03o`000?oooooooooo0?oooooo??ooool00?ooooooKoooool00ol0003oooooooooo`3oooooocgo
oooo003oooooofkooooo00?o0000ooooooooool0oooooolnooooo`00oooooom]ooooo`03o`000?oo
oooooooo0?oooooo?oooool00?ooooooK?ooool00ol0003oooooooooo`3ooooood3ooooo003ooooo
of_ooooo00?o0000ooooooooool0oooooom1ooooo`00oooooom[ooooo`03o`000?oooooooooo0?oo
oooo@Oooool00?ooooooJ_ooool00ol0003oooooooooo`3ooooood;ooooo003oooooof[ooooo00?o
0000ooooooooool0oooooom2ooooo`00oooooomYooooo`03o`000?oooooooooo0?oooooo@oooool0
0?ooooooJOooool00ol0003oooooooooo`3ooooood?ooooo003oooooofSooooo00?o0000oooooooo
ool0oooooom4ooooo`00oooooomXooooo`03o`000?oooooooooo0?ooooooA?ooool00?ooooooIooo
ool00ol0003oooooooooo`3oooooodGooooo003oooooofKooooo00?o0000ooooooooool0oooooom6
ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooIOooool00ol0003o
ooooooooo`3oooooodOooooo003oooooofGooooo00?o0000ooooooooool0oooooom7ooooo`00oooo
oomTooooo`03o`000?oooooooooo0?ooooooB?ooool00?ooooooI?ooool00ol0003oooooooooo`3o
ooooodSooooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomSooooo`03
o`000?oooooooooo0?ooooooBOooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo
003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooo
oooo0?ooooooBOooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;o
oooo00?o0000ooooooooool0oooooom:ooooo`00oooooomRooooo`03o`000?oooooooooo0?oooooo
B_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000
ooooooooool0oooooom:ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?oo
ooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000ooooooooool0
oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooH?ooool0
0ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<oooo
o`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooGoooool00ol0003ooooo
ooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomO
ooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3ooooo
odgooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`00
0?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003o
oooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo
0?ooooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooekooooo
00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_oo
ool00?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000oooo
ooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?oooooo
GOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooo
oom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0
003oooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00
oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003ooooooooo
o`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMoooo
o`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoo
oooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomLooooo`03o`000?oo
oooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooo
oecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oo
ooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooooooo
ool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?oo
ool00ol0003oooooooooo`3ooooooe3ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03
o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo
003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooo
oooo0?ooooooDOooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIoooo
o`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?o
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3o
oooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03
o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo
003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooo
oooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSo
oooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000
ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oo
ooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0
oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool0
0ol0003oooooooooo`3ooooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEoooo
o`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003ooooo
ooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooo
oeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`00
0?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003o
oooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo
0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo
003ooooooa;ooooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Kooooo00?o0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooK_ooool00?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo
00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`000?l@
413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4
olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003ooooooooo
o`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@413o
^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?ooool2
ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`07ooooo`06o`000?nYZJWo
oooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMg
MoooooooooooohN7Qol@413ooooooa3ooooo003ooooooa7ooooo00GogMgMoa0@4?oooooo8B4QomgM
g@05ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0:ooooo`Go00002?ooool00ol0003oooooooooo`07ooooo`05okZj^_n7QhOoIVIVofIVI_l@4100
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool00?oooooo4Ooo
ool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool01?ooool00omEEEGoV9RH
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`0000So
oooo00?oMgMgoc8b<_ooool01oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002
ooooo`03o`000?oooooooooo0?oooooo4oooool00?oooooo4?ooool00oo^k^ko0000onk^kP02oooo
o`03o`000?oMgMgooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooolb<S;o
QhN700_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool00005ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`02?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00
ooooool@ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`Go00002Oooool00ol@413o0000o`000003o`0000Cooooo00?o0000oooooooo
ool02Oooool00ol@413o0000o`000003o`0001cooooo00?o0000ooooooooool02oooool00omgMgOo
c<c<o`000005ooooo`03o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`00
0?oooooo4?ooool00?oooooo6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_o
oooo00?ok^k^odA4A?l000001Oooool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo
0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo
00?oEEEEofIVI_l000003_ooool00omgMgOo0000ooooo`04ooooo`Co0000ooooool_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.5) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49996 0 m
.49617 .00402 L
.4945 .00507 L
.49324 .00606 L
.49212 .00721 L
.49132 .00825 L
.49005 .01047 L
.48919 .01255 L
.48772 .01725 L
.4859 .02545 L
.48436 .03418 L
.48302 .04258 L
.48176 .05066 L
.4804 .05927 L
.47905 .06755 L
.4775 .07635 L
.47587 .08483 L
.47414 .09299 L
.47206 .10167 L
.46976 .11003 L
.46689 .11891 L
.46353 .12746 L
.45955 .13569 L
.45403 .14445 L
.45055 .14881 L
.44665 .15288 L
.43595 .16099 L
.42795 .16534 L
.41897 .1693 L
.39575 .17781 L
.38568 .1817 L
.38111 .18392 L
.37936 .185 L
.37808 .186 L
.37756 .18651 L
.37717 .18699 L
.37686 .18749 L
.37673 .18775 L
.37663 .18803 L
.37659 .18818 L
.37657 .18831 L
.37655 .18846 L
.37654 .18862 L
.37654 .18889 L
.37656 .18904 L
.37659 .18918 L
.37667 .18944 L
.37677 .18968 L
.37692 .18996 L
.37709 .19022 L
Mistroke
.37756 .19076 L
.37823 .19133 L
.37986 .19237 L
.38256 .1936 L
.38571 .19471 L
.39374 .19685 L
.40331 .19883 L
.43155 .20328 L
.49844 .21172 L
.5304 .21597 L
.5545 .21984 L
.56455 .22184 L
.57344 .22401 L
.57741 .22521 L
.58053 .22631 L
.58301 .22736 L
.58516 .22848 L
.58675 .22956 L
.58731 .23003 L
.58783 .23054 L
.58821 .231 L
.58853 .23149 L
.58868 .23176 L
.58879 .232 L
.58887 .23223 L
.58895 .23248 L
.58901 .23275 L
.58904 .2329 L
.58905 .23304 L
.58907 .2333 L
.58906 .23357 L
.58905 .23372 L
.58903 .23388 L
.589 .23404 L
.58897 .23418 L
.5889 .23445 L
.5888 .23474 L
.58857 .23527 L
.58829 .23576 L
.58746 .23688 L
.58649 .23788 L
.58523 .23898 L
.58215 .24119 L
.57544 .24514 L
.55946 .25379 L
.54638 .26212 L
.54107 .26637 L
.53627 .27098 L
.52948 .27951 L
.52454 .28824 L
Mistroke
.521 .29665 L
.51834 .30473 L
.51604 .31334 L
.51421 .32163 L
.51258 .33043 L
.51123 .33892 L
.5101 .34708 L
.50904 .35576 L
.50813 .36412 L
.50727 .37301 L
.50652 .38157 L
.50585 .38981 L
.50521 .39857 L
.50464 .407 L
.50412 .41512 L
.50361 .42376 L
.50314 .43207 L
.50267 .44091 L
.50225 .44942 L
.50185 .45761 L
.50145 .46632 L
.50107 .47471 L
.50072 .48278 L
.50036 .49137 L
.50001 .49964 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomG
ooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooE_ooool00ol0003oooooooooo`3ooooo
oeKooooo003ooooooeCooooo0_l0003ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0
oooooomIooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooDOooool0
0ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKoooo
o`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooD?ooool00ol0003ooooo
ooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom?
ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooo
oegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`00
0?oooooooooo0?ooooooGOooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003o
ooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo
0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo
00?o0000ooooooooool0oooooomNooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGooo
ool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000oooo
ooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oooooo
COooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooo
oomOooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0
003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00
oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003ooooooooo
o`3oooooof3ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;oooo
o`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7o
oooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oo
oooooooo0?ooooooHOooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooo
od[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oo
ooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o
0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool0
0?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000oooooooo
ool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_oo
ool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomR
ooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003o
ooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooo
oom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3o
ooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom8ooooo`03
o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo
003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooo
oooo0?ooooooI?ooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOo
oooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000
ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oo
ooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0
oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool0
0ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWoooo
o`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooA?ooool00ol0003ooooo
ooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4
ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3ooooo
ofSooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`00
0?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003o
oooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo
0?ooooooJ_ooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo
00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJooo
ool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000oooo
ooooool0oooooom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo
?oooool00ol0003oooooooooo`3oooooofgooooo003oooooockooooo00?o0000ooooooooool0oooo
oom^ooooo`00oooooolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?Oooool00ol0
003oooooooooo`3oooooofoooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00
oooooollooooo`03o`000?oooooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003ooooooooo
o`3oooooog3ooooo003ooooooc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkoooo
o`03o`000?oooooooooo0?ooooooLOooool00?oooooo>Oooool2o`000?ooooooM?ooool00?oooooo
>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000ooooooooool0oooo
oomeooooo`00oooooolgooooo`03o`000?oooooooooo0?ooooooMOooool00?oooooo=_ooool00ol0
003oooooooooo`3oooooogKooooo003oooooocCooooo0_l0003oooooogWooooo003ooooooc?ooooo
00?o0000ooooooooool0oooooomiooooo`00oooooolaooooo`;o0000oooooomlooooo`00ooooool`
ooooo`03o`000?oooooooooo0?ooooooO?ooool00?oooooo;oooool00ol0003oooooooooo`3ooooo
oggooooo003oooooobgooooo0_l0003ooooooh3ooooo003oooooob_ooooo0_l0003ooooooh;ooooo
003oooooob[ooooo00?o0000ooooooooool0oooooon2ooooo`00oooooolXooooo`;o0000oooooon5
ooooo`00oooooolVooooo`;o0000oooooon7ooooo`00oooooolTooooo`;o0000oooooon9ooooo`00
oooooolRooooo`;o0000oooooon;ooooo`00oooooolOooooo`?o0000oooooon=ooooo`00oooooolL
ooooo`?o0000oooooon@ooooo`00oooooolIooooo`?o0000oooooonCooooo`00oooooolFooooo`?o
0000oooooonFooooo`00oooooolCooooo`?o0000oooooonIooooo`00ooooool@ooooo`?o0000oooo
oonLooooo`00ooooool=ooooo`?o0000oooooonOooooo`00ooooool<ooooo`03o`000?oooooooooo
0?ooooooX?ooool00?oooooo2oooool00ol0003oooooooooo`3ooooooj7ooooo003oooooo`Wooooo
0_l0003oooooojCooooo003oooooo`Sooooo0_l0003oooooojGooooo003oooooo`Sooooo00?o0000
ooooooooool0oooooonTooooo`00ooooool8ooooo`;o0000oooooonUooooo`00ooooool9ooooo`?o
0000oooooonSooooo`00ooooool<ooooo`;o0000oooooonQooooo`00ooooool>ooooo`Co0000oooo
oonMooooo`00oooooolBooooo`Go0000oooooonHooooo`00oooooolGooooo`Ko0000oooooonBoooo
o`00oooooolMooooo`Ko0000oooooon<ooooo`00oooooolSooooo`Ko0000oooooon6ooooo`00oooo
oolYooooo`Oo0000oooooomoooooo`00ooooool`ooooo`Oo0000oooooomhooooo`00oooooolgoooo
o`Oo0000oooooomaooooo`00oooooolnooooo`Oo0000oooooomZooooo`00oooooom5ooooo`Oo0000
oooooomSooooo`00oooooom<ooooo`Oo0000oooooomLooooo`00oooooomCooooo`Wo0000oooooomC
ooooo`00oooooomLooooo`[o0000oooooom9ooooo`00oooooomVooooo`So0000oooooom1ooooo`00
oooooom^ooooo`Go0000oooooollooooo`00oooooomcooooo`Go0000oooooolgooooo`00oooooomh
ooooo`Ko0000oooooolaooooo`00oooooomnooooo`Ko0000ooooool[ooooo`00oooooon4ooooo`Co
0000oooooolWooooo`00oooooon8ooooo`;o0000oooooolUooooo`00oooooon:ooooo`;o0000oooo
oolSooooo`00oooooon<ooooo`;o0000oooooolQooooo`00oooooon>ooooo`;o0000oooooolOoooo
o`00oooooon?ooooo`;o0000oooooolNooooo`00oooooon@ooooo`03o`000?oooooooooo0?oooooo
7?ooool00?ooooooT?ooool00ol0003oooooooooo`3ooooooacooooo003oooooohoooooo00?o0000
ooooooooool0oooooolMooooo`00oooooon>ooooo`;o0000oooooolOooooo`00oooooon<ooooo`;o
0000oooooolQooooo`00oooooon:ooooo`;o0000oooooolSooooo`00oooooon9ooooo`03o`000?oo
oooooooo0?oooooo8oooool00?ooooooR?ooool00ol0003oooooooooo`3oooooobCooooo003ooooo
ohKooooo0_l0003oooooobOooooo003oooooohCooooo0_l0003oooooobWooooo003ooooooh;ooooo
0_l0003oooooob_ooooo003ooooooh3ooooo0_l0003oooooobgooooo003oooooogkooooo0_l0003o
oooooboooooo003oooooogcooooo0_l0003ooooooc7ooooo003oooooog_ooooo00?o0000oooooooo
ool0oooooolaooooo`00oooooomjooooo`03o`000?oooooooooo0?oooooo<_ooool00?ooooooN?oo
ool2o`000?oooooo=Oooool00?ooooooMoooool00ol0003oooooooooo`3oooooocGooooo003ooooo
ogKooooo00?o0000ooooooooool0oooooolfooooo`00oooooomdooooo`;o0000ooooooliooooo`00
oooooombooooo`;o0000oooooolkooooo`00oooooomaooooo`03o`000?oooooooooo0?oooooo>ooo
ool00?ooooooL?ooool00ol0003oooooooooo`3ooooooccooooo003oooooofoooooo00?o0000oooo
ooooool0oooooolmooooo`00oooooom^ooooo`03o`000?oooooooooo0?oooooo?_ooool00?oooooo
K_ooool00ol0003oooooooooo`3oooooockooooo003oooooofgooooo00?o0000ooooooooool0oooo
ooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooK?ooool00ol0
003oooooooooo`3ooooood3ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00
oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJ_ooool00ol0003ooooooooo
o`3ooooood;ooooo003oooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomXoooo
o`03o`000?oooooooooo0?ooooooA?ooool00?ooooooJ?ooool00ol0003oooooooooo`3oooooodCo
oooo003oooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomWooooo`03o`000?oo
oooooooo0?ooooooAOooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003ooooo
ofKooooo00?o0000ooooooooool0oooooom6ooooo`00oooooomUooooo`03o`000?oooooooooo0?oo
ooooAoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofCooooo00?o
0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool0
0?ooooooI?ooool00ol0003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o0000oooooooo
ool0oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooHooo
ool00ol0003oooooooooo`3oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9
ooooo`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003o
ooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00oooo
oomQooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3o
oooood_ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03
o`000?oooooooooo0?ooooooBoooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo
003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooo
oooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3o
oooo00?o0000ooooooooool0oooooom<ooooo`00oooooomOooooo`03o`000?oooooooooo0?oooooo
COooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000
ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oo
ooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0
oooooom=ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool0
0ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>oooo
o`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003ooooo
ooooo`3oooooodkooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomM
ooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3ooooo
odoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003o
oooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo
0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooegooooo
00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCooo
ool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooo
ooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oooooo
G?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooo
oom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0
003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00
oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?ooool00ol0003ooooooooo
o`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomKoooo
o`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7o
oooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oo
oooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooo
oe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?oo
ooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o
0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_oo
ool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomB
ooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003o
ooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooo
oomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?oooooo
Doooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000
ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool0
0ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooo
ooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo
00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?oo
ool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooo
ooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?oooooo
F?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooo
oomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooa?ooooo
0ol000000ol@413oooooooooo`3ooooooiKooooo003ooooooaGooooo00?o410@okZj^_ooool01ooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0oooo
oomZooooo`00oooooolEooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<_ooooooJoooool00?oooooo5Oooool00ooM
gMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`Go00001?ooool00on7QhOo0000okZj^P04
ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooaCooooo003ooooooaGooooo00?oEEEEogMgMom4A4@01oooool01?l0003ooooo
ooooooooool2ogMgM`;ooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`07ooooo`06o`000?nYZJWooooooooooonj^[[o0000
0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@
413ooooooaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oo
oooooooo00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1_ooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00kooooo00?oMgMgoc8b<_ooool01oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^
kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo4oooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03oc8b<_n7QhOooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Sooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000?oooooo5?ooool00?oooooo4oooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
1Ol00009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`09ooooo`03oa0@
4?l0003o000000?o00007?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_oo
ool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?ooool00?oooooo7oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooooldooooo`00oooo
oolOooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003ooooooooo
o`0Kooooo`03oeEEEOmVIVKo000000gooooo1?l0003ooooooc?ooooo003ooooooooooooo[oooool0
0?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.55) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49495 0 m
.49653 .00192 L
.49701 .00248 L
.49739 .00302 L
.49765 .0035 L
.49776 .00377 L
.49783 .00402 L
.49787 .00426 L
.49788 .00453 L
.49787 .00481 L
.49782 .00508 L
.49779 .00522 L
.49775 .00536 L
.49765 .00562 L
.49735 .00621 L
.49667 .00719 L
.49577 .00825 L
.49384 .01049 L
.49239 .01261 L
.49115 .01504 L
.49031 .01725 L
.48914 .02142 L
.48814 .02593 L
.48662 .03469 L
.48539 .04312 L
.4843 .05123 L
.48315 .05986 L
.48207 .06817 L
.48086 .077 L
.47965 .08551 L
.4784 .0937 L
.47696 .10241 L
.47544 .11079 L
.47382 .11886 L
.47186 .12744 L
.46972 .1357 L
.46703 .14449 L
.46395 .15295 L
.46032 .16109 L
.45539 .16975 L
.44899 .17809 L
.44436 .18265 L
.43891 .18695 L
.4246 .19517 L
.40377 .20391 L
.39304 .20825 L
.38842 .21038 L
.38489 .21232 L
.38345 .21328 L
.38217 .21432 L
Mistroke
.38169 .2148 L
.38125 .21531 L
.38092 .21578 L
.38068 .21622 L
.38057 .21649 L
.38048 .21677 L
.38042 .21705 L
.3804 .21721 L
.38039 .21735 L
.38039 .21762 L
.38041 .21787 L
.38044 .21801 L
.38047 .21815 L
.38055 .21842 L
.38065 .21866 L
.38079 .21892 L
.38116 .21946 L
.3816 .21995 L
.38212 .22041 L
.38356 .22142 L
.38567 .22252 L
.39162 .22473 L
.39915 .22678 L
.40783 .22869 L
.46061 .23703 L
.52395 .24591 L
.54991 .25036 L
.55919 .25231 L
.56775 .25446 L
.57394 .25639 L
.57904 .25846 L
.58119 .2596 L
.58277 .26064 L
.58399 .26169 L
.58446 .2622 L
.58483 .26268 L
.58515 .26319 L
.58537 .26366 L
.58547 .26391 L
.58555 .26418 L
.58562 .26445 L
.58565 .2646 L
.58567 .26474 L
.58568 .26488 L
.58569 .26503 L
.5857 .2653 L
.58569 .26556 L
.58566 .2658 L
.58562 .26606 L
.58556 .26635 L
Mistroke
.58547 .26665 L
.58537 .26693 L
.58489 .26792 L
.58428 .26883 L
.5824 .27086 L
.57985 .27297 L
.57708 .27492 L
.56991 .27935 L
.55589 .28771 L
.54342 .29659 L
.53459 .30515 L
.52847 .31339 L
.52371 .32215 L
.52026 .33059 L
.51764 .3387 L
.51538 .34734 L
.51355 .35565 L
.5119 .36449 L
.51054 .373 L
.50939 .38119 L
.50829 .38991 L
.50735 .3983 L
.50653 .40636 L
.50573 .41495 L
.50502 .42322 L
.50431 .43201 L
.50368 .44048 L
.50311 .44862 L
.50254 .45729 L
.502 .46563 L
.50146 .47449 L
.50096 .48304 L
.50049 .49126 L
.5 .5 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomD
ooooo`03o`000?oooooooooo0?ooooooF?ooool00?ooooooEOooool00ol0003oooooooooo`3ooooo
oeOooooo003ooooooeGooooo0_l0003ooooooeSooooo003ooooooeGooooo0_l0003ooooooeSooooo
003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomDooooo`03o`000?oooooo
oooo0?ooooooF?ooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?o
oooo00?o0000ooooooooool0oooooomIooooo`00oooooomBooooo`03o`000?oooooooooo0?oooooo
F_ooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000
ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oo
ooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe3ooooo00?o0000ooooooooool0
oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooCoooool0
0ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMoooo
o`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003ooooo
ooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom>
ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooo
oekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`00
0?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003o
ooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo
0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo
00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_oo
ool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000oooo
ooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oooooo
COooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooo
oomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooC?ooool00ol0
003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00
oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003ooooooooo
o`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<oooo
o`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3o
oooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oo
oooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003ooooo
odcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom;ooooo`03o`000?oooooooooo0?oo
ooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o
0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool0
0?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood[ooooo00?o0000oooooooo
ool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_oo
ool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomR
ooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooBOooool00ol0003o
ooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooo
oom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3o
ooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03
o`000?oooooooooo0?ooooooHoooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo
003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooo
oooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSo
oooo00?o0000ooooooooool0oooooomTooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000
ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?oo
ooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodKooooo00?o0000ooooooooool0
oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool0
0ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVoooo
o`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003ooooo
ooooo`3oooooofKooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5
ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3ooooo
ofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`00
0?oooooooooo0?ooooooIoooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003o
ooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4ooooo`03o`000?oooooooooo
0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003ooooood?ooooo
00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOoo
ool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood;ooooo00?o0000oooo
ooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo
@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood7ooooo00?o0000ooooooooool0oooo
oom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool00?oooooo@Oooool00ol0
003oooooooooo`3oooooof_ooooo003ooooood3ooooo00?o0000ooooooooool0oooooom/ooooo`00
oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool00ol0003ooooooooo
o`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00oooooolooooo
o`03o`000?oooooooooo0?ooooooKOooool00?oooooo?_ooool00ol0003oooooooooo`3oooooofko
oooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00oooooolmooooo`03o`000?oo
oooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo003ooooo
occooooo00?o0000ooooooooool0oooooom`ooooo`00oooooollooooo`03o`000?oooooooooo0?oo
ooooL?ooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[ooooo00?o
0000ooooooooool0oooooombooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool0
0?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000oooooooo
ool0oooooomeooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oooooo=Ooo
ool00ol0003oooooooooo`3oooooogOooooo003oooooocCooooo00?o0000ooooooooool0oooooomh
ooooo`00oooooolcooooo`03o`000?oooooooooo0?ooooooNOooool00?oooooo<_ooool00ol0003o
ooooooooo`3oooooog[ooooo003ooooooc7ooooo00?o0000ooooooooool0oooooomkooooo`00oooo
ool_ooooo`;o0000oooooomnooooo`00ooooool]ooooo`;o0000oooooon0ooooo`00ooooool[oooo
o`;o0000oooooon2ooooo`00oooooolZooooo`03o`000?oooooooooo0?ooooooP_ooool00?oooooo
:?ooool2o`000?ooooooQOooool00?oooooo9_ooool2o`000?ooooooQoooool00?oooooo9?ooool2
o`000?ooooooROooool00?oooooo8_ooool2o`000?ooooooRoooool00?oooooo7oooool3o`000?oo
ooooSOooool00?oooooo7Oooool2o`000?ooooooT?ooool00?oooooo6oooool2o`000?ooooooT_oo
ool00?oooooo6?ooool3o`000?ooooooU?ooool00?oooooo5Oooool3o`000?ooooooUoooool00?oo
oooo4_ooool3o`000?ooooooV_ooool00?oooooo4Oooool00ol0003oooooooooo`3ooooooi_ooooo
003oooooo`oooooo0_l0003ooooooikooooo003oooooo`kooooo00?o0000ooooooooool0oooooonN
ooooo`00ooooool<ooooo`;o0000oooooonQooooo`00ooooool;ooooo`03o`000?oooooooooo0?oo
ooooXOooool00?oooooo2oooool00ol0003oooooooooo`3ooooooj7ooooo003oooooo`_ooooo00?o
0000ooooooooool0oooooonQooooo`00ooooool;ooooo`;o0000oooooonRooooo`00ooooool=oooo
o`03o`000?oooooooooo0?ooooooWoooool00?oooooo3_ooool3o`000?ooooooW_ooool00?oooooo
4Oooool5o`000?ooooooVOooool00?oooooo5_ooool5o`000?ooooooU?ooool00?oooooo6oooool5
o`000?ooooooSoooool00?oooooo8?ooool6o`000?ooooooROooool00?oooooo9_ooool5o`000?oo
ooooQ?ooool00?oooooo:oooool6o`000?ooooooO_ooool00?oooooo<Oooool6o`000?ooooooN?oo
ool00?oooooo=oooool5o`000?ooooooLoooool00?oooooo??ooool7o`000?ooooooK?ooool00?oo
oooo@oooool8o`000?ooooooI?ooool00?ooooooBoooool8o`000?ooooooG?ooool00?ooooooDooo
ool8o`000?ooooooE?ooool00?ooooooFoooool8o`000?ooooooC?ooool00?ooooooHoooool7o`00
0?ooooooAOooool00?ooooooJ_ooool6o`000?oooooo?oooool00?ooooooL?ooool5o`000?oooooo
>_ooool00?ooooooMOooool5o`000?oooooo=Oooool00?ooooooN_ooool3o`000?oooooo<_ooool0
0?ooooooOOooool4o`000?oooooo;_ooool00?ooooooPOooool4o`000?oooooo:_ooool00?oooooo
QOooool4o`000?oooooo9_ooool00?ooooooROooool2o`000?oooooo9?ooool00?ooooooRoooool0
0ol0003oooooooooo`3oooooob7ooooo003oooooohcooooo0_l0003oooooob7ooooo003oooooohgo
oooo00?o0000ooooooooool0oooooolOooooo`00oooooon=ooooo`;o0000oooooolPooooo`00oooo
oon>ooooo`03o`000?oooooooooo0?oooooo7_ooool00?ooooooSOooool00ol0003oooooooooo`3o
oooooaoooooo003oooooohgooooo00?o0000ooooooooool0oooooolOooooo`00oooooon<ooooo`03
o`000?oooooooooo0?oooooo8?ooool00?ooooooRoooool00ol0003oooooooooo`3oooooob7ooooo
003oooooohWooooo0_l0003oooooobCooooo003oooooohOooooo0_l0003oooooobKooooo003ooooo
ohKooooo00?o0000ooooooooool0oooooolVooooo`00oooooon5ooooo`03o`000?oooooooooo0?oo
oooo9oooool00?ooooooPoooool2o`000?oooooo:_ooool00?ooooooPOooool2o`000?oooooo;?oo
ool00?ooooooOoooool2o`000?oooooo;_ooool00?ooooooO_ooool00ol0003oooooooooo`3ooooo
obkooooo003oooooogcooooo0_l0003ooooooc7ooooo003oooooog[ooooo0_l0003ooooooc?ooooo
003oooooogWooooo00?o0000ooooooooool0oooooolcooooo`00oooooomhooooo`03o`000?oooooo
oooo0?oooooo=?ooool00?ooooooM_ooool2o`000?oooooo=oooool00?ooooooMOooool00ol0003o
ooooooooo`3oooooocOooooo003oooooogCooooo00?o0000ooooooooool0oooooolhooooo`00oooo
oombooooo`;o0000oooooolkooooo`00oooooomaooooo`03o`000?oooooooooo0?oooooo>oooool0
0?ooooooL?ooool00ol0003oooooooooo`3ooooooccooooo003oooooofoooooo00?o0000oooooooo
ool0oooooolmooooo`00oooooom^ooooo`03o`000?oooooooooo0?oooooo?_ooool00?ooooooKOoo
ool00ol0003oooooooooo`3oooooocoooooo003oooooofgooooo00?o0000ooooooooool0oooooolo
ooooo`00oooooom/ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooJoooool00ol0003o
ooooooooo`3ooooood7ooooo003oooooof[ooooo00?o0000ooooooooool0oooooom2ooooo`00oooo
oomYooooo`03o`000?oooooooooo0?oooooo@oooool00?ooooooJOooool00ol0003oooooooooo`3o
oooood?ooooo003oooooofSooooo00?o0000ooooooooool0oooooom4ooooo`00oooooomXooooo`03
o`000?oooooooooo0?ooooooA?ooool00?ooooooIoooool00ol0003oooooooooo`3oooooodGooooo
003oooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oooooo
oooo0?ooooooA_ooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofGo
oooo00?o0000ooooooooool0oooooom7ooooo`00oooooomUooooo`03o`000?oooooooooo0?oooooo
Aoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofCooooo00?o0000
ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool00?oo
ooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0
oooooom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooH_ooool0
0ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:oooo
o`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003ooooo
ooooo`3ooooood[ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQ
ooooo`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooo
od_ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQooooo`03o`00
0?oooooooooo0?ooooooBoooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003o
ooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo
0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo
00?o0000ooooooooool0oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?oo
ool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000oooo
ooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?oooooo
Goooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o0000ooooooooool0oooo
oom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooG_ooool00ol0
003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00
oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003ooooooooo
o`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomMoooo
o`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoo
oooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oo
oooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooo
oecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oo
ooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooooooo
ool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooG?oo
ool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000ooooooooool0oooooom@
ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3o
oooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03
o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo
003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooooomKooooo`03o`000?oooooo
oooo0?ooooooDOooool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_o
oooo00?o0000ooooooooool0oooooomAooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oo
ooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0
oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBoooo
o`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomI
ooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooo
oe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`00
0?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003o
oooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo
0?ooooooDoooool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo
00?o0000ooooooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0
003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00
oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000oooooooo
ool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEooo
ool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomE
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooa3ooooo
0ol000000ol@413oooooooooo`3ooooooiWooooo003ooooooa;ooooo00?o410@okZj^_ooool01_oo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooo
oom]ooooo`00oooooolBooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooK_ooool00?oooooo4_ooool00ooM
gMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj
00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7
o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00GoA4A4o`000?l0003o
<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0
003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooooa3ooooo003ooooooa;ooooo
00?oEEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`;oMgMg0_ooool01ol0003ooooo
ooooooooooooc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000
ooooooooool01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01Ooo
ool00omgMgOo<S8booooo`07ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGo
MgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooa3ooooo
003ooooooa7ooooo00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo
00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooooa?ooooo003ooooooa7ooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@05ooooo`03o`000?oooooooooo00Cooooo00?oEEEEoiRHV?ooool02oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000co
oooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`05ooooo`03ogMgMolb<S;ooooo00Oo
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3o
oooooa?ooooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
2?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go
00002Oooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o
0000o`000003o`0001cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo4?ooool00?oo
oooo6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Cooooo`03o`00
0?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l00000
3Oooool4o`0000Cooooo1?l0003ooooooboooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49331 0 m
.49352 .00099 L
.49376 .00192 L
.49449 .00402 L
.49549 .00619 L
.49597 .00726 L
.49633 .00825 L
.49647 .00878 L
.49653 .00905 L
.49658 .00934 L
.4966 .00949 L
.49661 .00964 L
.49663 .0098 L
.49664 .00995 L
.49664 .01023 L
.49664 .01038 L
.49663 .01053 L
.49661 .0108 L
.49658 .01105 L
.49655 .01128 L
.4965 .01153 L
.49635 .01209 L
.49619 .0126 L
.49514 .01486 L
.49384 .01725 L
.49275 .01943 L
.49189 .02149 L
.49066 .02536 L
.4897 .02952 L
.48887 .03399 L
.48763 .04218 L
.4865 .05089 L
.48551 .05927 L
.4846 .06733 L
.48363 .07592 L
.48269 .08418 L
.48165 .09297 L
.48062 .10143 L
.47955 .10957 L
.47834 .11823 L
.47707 .12657 L
.4756 .13543 L
.47402 .14397 L
.4723 .15218 L
.47024 .16092 L
.46793 .16934 L
.46532 .17743 L
.462 .18604 L
.45801 .19434 L
.45249 .20315 L
Mistroke
.44897 .20756 L
.44504 .21164 L
.43451 .21981 L
.42699 .2242 L
.419 .22818 L
.39963 .23674 L
.39155 .24068 L
.38788 .24291 L
.38643 .244 L
.38535 .24499 L
.38489 .2455 L
.38446 .24605 L
.38417 .24652 L
.38391 .24705 L
.38381 .24734 L
.38374 .24761 L
.38371 .24775 L
.38368 .24789 L
.38367 .24804 L
.38365 .2482 L
.38365 .24846 L
.38367 .2487 L
.38372 .24897 L
.38375 .24912 L
.38379 .24926 L
.38389 .24954 L
.38403 .24983 L
.38435 .25037 L
.38481 .25094 L
.38545 .25157 L
.38699 .2527 L
.38887 .25376 L
.39428 .25598 L
.40122 .2581 L
.41872 .26206 L
.46827 .27024 L
.52441 .27894 L
.54723 .28326 L
.55644 .28538 L
.56364 .28732 L
.56936 .28917 L
.57434 .29119 L
.57807 .29323 L
.57958 .29434 L
.58067 .29537 L
.58151 .29645 L
.58185 .29706 L
.58198 .29735 L
.58209 .29762 L
.58223 .29811 L
Mistroke
.58228 .29837 L
.58233 .29865 L
.58234 .29879 L
.58235 .29894 L
.58236 .29922 L
.58235 .29949 L
.58233 .29974 L
.58229 .29999 L
.58224 .30026 L
.58211 .30075 L
.58194 .30122 L
.58175 .30166 L
.58119 .30265 L
.58044 .30371 L
.57855 .30573 L
.57602 .3079 L
.57056 .31182 L
.55686 .32066 L
.54504 .32917 L
.53617 .33736 L
.52921 .34607 L
.52428 .35446 L
.52066 .36253 L
.51764 .37112 L
.51529 .37939 L
.5132 .38818 L
.51148 .39664 L
.51005 .40479 L
.50871 .41345 L
.50756 .42179 L
.50644 .43066 L
.50546 .4392 L
.5046 .44742 L
.50374 .45617 L
.50295 .46458 L
.50223 .47268 L
.50151 .4813 L
.50083 .48959 L
.50013 .49841 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomC
ooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooo
oeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`00
0?oooooooooo0?ooooooFOooool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSooooo003o
oooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomEooooo`03o`000?oooooooooo
0?ooooooEoooool00?ooooooEOooool00ol0003oooooooooo`3ooooooeOooooo003ooooooeGooooo
00?o0000ooooooooool0oooooomGooooo`00oooooomDooooo`03o`000?oooooooooo0?ooooooF?oo
ool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSooooo003ooooooe?ooooo00?o0000oooo
ooooool0oooooomIooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
D_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooo
oomJooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003ooooooooo
o`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@oooo
o`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooeco
oooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom?ooooo`03o`000?oo
oooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003ooooo
odoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?oo
ooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o
0000ooooooooool0oooooomMooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool0
0?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000oooooooo
ool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_oo
ool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomN
ooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003o
ooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooo
oom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3o
oooooekooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03
o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo
003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooo
oooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgo
oooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?oooooo
Goooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000
ooooooooool0oooooomOooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oo
ooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0
oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool0
0ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPoooo
o`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003ooooo
ooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;
ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3ooooo
of7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`00
0?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003o
oooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo
0?ooooooHOooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo
00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_oo
ool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000oooo
ooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?oooooo
BOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooo
oomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0
003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00
oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003ooooooooo
o`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8oooo
o`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCo
oooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom7ooooo`03o`000?oo
oooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003ooooo
odOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oo
ooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodKooooo00?o
0000ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool0
0?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000oooooooo
ool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_oo
ool00ol0003oooooooooo`3oooooofKooooo003oooooodGooooo00?o0000ooooooooool0oooooomW
ooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003o
ooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooo
oom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooA?ooool00ol0003oooooooooo`3o
ooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4ooooo`03
o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo
003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4ooooo`03o`000?oooooo
oooo0?ooooooJ?ooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood?o
oooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?oooooo
JOooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood;ooooo00?o0000
ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oo
oooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood7ooooo00?o0000ooooooooool0
oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool00?oooooo@?ooool0
0ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0oooooom/oooo
o`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool00ol0003ooooo
ooooo`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00ooooooln
ooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_ooool00ol0003oooooooooo`3ooooo
ofkooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooolmooooo`03o`00
0?oooooooooo0?ooooooKoooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3ooooo003o
oooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooolkooooo`03o`000?oooooooooo
0?ooooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003ooooooc[ooooo
00?o0000ooooooooool0oooooombooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLooo
ool00?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000oooo
ooooool0oooooomeooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oooooo
=_ooool00ol0003oooooooooo`3oooooogKooooo003oooooocGooooo00?o0000ooooooooool0oooo
oomgooooo`00oooooolcooooo`;o0000oooooomjooooo`00oooooolbooooo`03o`000?oooooooooo
0?ooooooN_ooool00?oooooo<?ooool2o`000?ooooooOOooool00?oooooo;oooool00ol0003ooooo
ooooo`3ooooooggooooo003oooooobkooooo00?o0000ooooooooool0oooooomnooooo`00ooooool/
ooooo`;o0000oooooon1ooooo`00oooooolZooooo`;o0000oooooon3ooooo`00oooooolYooooo`03
o`000?oooooooooo0?ooooooPoooool00?oooooo9oooool2o`000?ooooooQ_ooool00?oooooo9?oo
ool3o`000?ooooooR?ooool00?oooooo8_ooool2o`000?ooooooRoooool00?oooooo8?ooool2o`00
0?ooooooSOooool00?oooooo7_ooool2o`000?ooooooSoooool00?oooooo7?ooool2o`000?oooooo
TOooool00?oooooo6_ooool2o`000?ooooooToooool00?oooooo6?ooool2o`000?ooooooUOooool0
0?oooooo5_ooool2o`000?ooooooUoooool00?oooooo4oooool3o`000?ooooooVOooool00?oooooo
4Oooool2o`000?ooooooW?ooool00?oooooo4?ooool00ol0003oooooooooo`3ooooooicooooo003o
ooooo`oooooo00?o0000ooooooooool0oooooonMooooo`00ooooool>ooooo`03o`000?oooooooooo
0?ooooooW_ooool00?oooooo3Oooool00ol0003oooooooooo`3ooooooioooooo003oooooo`gooooo
00?o0000ooooooooool0oooooonOooooo`00ooooool=ooooo`03o`000?oooooooooo0?ooooooWooo
ool00?oooooo3Oooool2o`000?ooooooX?ooool00?oooooo3oooool3o`000?ooooooWOooool00?oo
oooo4_ooool2o`000?ooooooVoooool00?oooooo5?ooool3o`000?ooooooV?ooool00?oooooo5ooo
ool4o`000?ooooooU?ooool00?oooooo6oooool4o`000?ooooooT?ooool00?oooooo7oooool3o`00
0?ooooooSOooool00?oooooo8_ooool5o`000?ooooooR?ooool00?oooooo9oooool7o`000?oooooo
POooool00?oooooo;_ooool6o`000?ooooooNoooool00?oooooo=?ooool6o`000?ooooooMOooool0
0?oooooo>_ooool7o`000?ooooooK_ooool00?oooooo@Oooool6o`000?ooooooJ?ooool00?oooooo
Aoooool6o`000?ooooooH_ooool00?ooooooCOooool6o`000?ooooooG?ooool00?ooooooDoooool6
o`000?ooooooE_ooool00?ooooooFOooool6o`000?ooooooD?ooool00?ooooooGoooool6o`000?oo
ooooB_ooool00?ooooooIOooool7o`000?oooooo@oooool00?ooooooK?ooool7o`000?oooooo??oo
ool00?ooooooLoooool5o`000?oooooo=oooool00?ooooooN?ooool3o`000?oooooo=?ooool00?oo
ooooNoooool4o`000?oooooo<?ooool00?ooooooOoooool4o`000?oooooo;?ooool00?ooooooPooo
ool3o`000?oooooo:Oooool00?ooooooQ_ooool2o`000?oooooo9oooool00?ooooooR?ooool00ol0
003oooooooooo`3oooooobCooooo003oooooohWooooo0_l0003oooooobCooooo003ooooooh[ooooo
00?o0000ooooooooool0oooooolRooooo`00oooooon;ooooo`03o`000?oooooooooo0?oooooo8Ooo
ool00?ooooooRoooool2o`000?oooooo8_ooool00?ooooooRoooool2o`000?oooooo8_ooool00?oo
ooooRoooool00ol0003oooooooooo`3oooooob7ooooo003ooooooh[ooooo0_l0003oooooob?ooooo
003ooooooh[ooooo00?o0000ooooooooool0oooooolRooooo`00oooooon8ooooo`;o0000oooooolU
ooooo`00oooooon6ooooo`;o0000oooooolWooooo`00oooooon5ooooo`03o`000?oooooooooo0?oo
oooo9oooool00?ooooooPoooool2o`000?oooooo:_ooool00?ooooooP_ooool00ol0003ooooooooo
o`3oooooob[ooooo003ooooooh3ooooo0_l0003oooooobgooooo003oooooogoooooo00?o0000oooo
ooooool0ooooool]ooooo`00oooooommooooo`;o0000ooooool`ooooo`00oooooomlooooo`03o`00
0?oooooooooo0?oooooo<?ooool00?ooooooN_ooool2o`000?oooooo<oooool00?ooooooNOooool0
0ol0003oooooooooo`3ooooooc?ooooo003oooooogSooooo00?o0000ooooooooool0ooooooldoooo
o`00oooooomgooooo`03o`000?oooooooooo0?oooooo=Oooool00?ooooooM_ooool00ol0003ooooo
ooooo`3oooooocKooooo003oooooogGooooo00?o0000ooooooooool0oooooolgooooo`00oooooomc
ooooo`;o0000ooooooljooooo`00oooooombooooo`03o`000?oooooooooo0?oooooo>_ooool00?oo
ooooLOooool00ol0003oooooooooo`3ooooooc_ooooo003oooooog3ooooo00?o0000ooooooooool0
oooooollooooo`00oooooom_ooooo`03o`000?oooooooooo0?oooooo?Oooool00?ooooooK_ooool0
0ol0003oooooooooo`3oooooockooooo003oooooofkooooo00?o0000ooooooooool0oooooolnoooo
o`00oooooom]ooooo`03o`000?oooooooooo0?oooooo?oooool00?ooooooK?ooool00ol0003ooooo
ooooo`3ooooood3ooooo003oooooof_ooooo00?o0000ooooooooool0oooooom1ooooo`00oooooomZ
ooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJ_ooool00ol0003oooooooooo`3ooooo
od;ooooo003oooooofWooooo00?o0000ooooooooool0oooooom3ooooo`00oooooomXooooo`03o`00
0?oooooooooo0?ooooooA?ooool00?ooooooJ?ooool00ol0003oooooooooo`3oooooodCooooo003o
ooooofOooooo00?o0000ooooooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oooooooooo
0?ooooooA_ooool00?ooooooI_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofGooooo
00?o0000ooooooooool0oooooom7ooooo`00oooooomUooooo`03o`000?oooooooooo0?ooooooAooo
ool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo003oooooofCooooo00?o0000oooo
ooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool00?oooooo
Hoooool00ol0003oooooooooo`3oooooodWooooo003oooooof?ooooo00?o0000ooooooooool0oooo
oom9ooooo`00oooooomSooooo`03o`000?oooooooooo0?ooooooBOooool00?ooooooH_ooool00ol0
003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000ooooooooool0oooooom:ooooo`00
oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003ooooooooo
o`3ooooood[ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomQoooo
o`03o`000?oooooooooo0?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooood_o
oooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomPooooo`03o`000?oo
oooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0003oooooooooo`3oooooodcooooo003ooooo
of3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomOooooo`03o`000?oooooooooo0?oo
ooooCOooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooeoooooo00?o
0000ooooooooool0oooooom=ooooo`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool0
0?ooooooG_ooool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000oooooooo
ool0oooooom>ooooo`00oooooomNooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_oo
ool00ol0003oooooooooo`3oooooodkooooo003ooooooekooooo00?o0000ooooooooool0oooooom>
ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003o
ooooooooo`3oooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooo
oomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3o
ooooodoooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03
o`000?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo
003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooo
oooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooeco
oooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?oooooo
D?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000
ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?oo
ooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0
oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool0
0ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAoooo
o`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooF_ooool00ol0003ooooo
ooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJ
ooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooo
oe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`00
0?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003o
oooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo
0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo
00?o0000ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDooo
ool00?ooooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000oooo
ooooool0oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oooooo
FOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooo
oomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003ooooooooo
o`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?oo
ooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o
0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool0
0?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000oooooooo
ool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?oo
ool00ol0003oooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomD
ooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOooool00?ooooooEoooool00ol0003o
ooooooooo`3ooooooeGooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooa?ooooo
0ol000000ol@413oooooooooo`3ooooooiKooooo003ooooooaGooooo00?o410@okZj^_ooool01ooo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0oooo
oomZooooo`00oooooolEooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<_ooooooJoooool00?oooooo5Oooool00ooM
gMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`Go00001?ooool00on7QhOo0000okZj^P04
ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0
003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c009ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooaCooooo003ooooooaGooooo00?oEEEEogMgMom4A4@01oooool01?l0003ooooo
ooooooooool2ogMgM`;ooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Wooooo00Ko0000ojVYZOoooooooooo
okZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgoooooooo
ooooQhN7oa0@4?oooooo5?ooool00?oooooo5?ooool01OoMgMgo410@oooooolQ8B7ogMgM00Kooooo
00?o0000ooooooooool00_ooool00omEEEGoV9RHooooo`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo
00Go0000ooooooooooooooooo`00000:ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo5oooool00?oooooo5?ooool01OmVIVKo
QhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;oooo
o`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9SooooooiRHV?lQ8B402Oooool0
1_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo
5oooool00?oooooo4oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00Go
0000ooooooooooooooooo`000002ooooo`03oc8b<_n7QhOooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2_ooool01Ol0003oEEEEo`000?l@413oc<c<00Wooooo00Ko0000okZj^_ooooook^k^ogMgMol00002
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`00
0?oooooo5?ooool00?oooooo4oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooooooo1Ol00009ooooo`03oa0@4?l0003o000000?o00001Oooool0
0ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00007?ooool00ol0003oooooooooo`0:
ooooo`03oeEEEOn7QhOooooo00_ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo5?oo
ool00?oooooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?ogMgM
oa0@4?nHV9P0ooooooleooooo`00oooooolOooooo`;o00004_ooool00ol0003oooooooooo`05oooo
o`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000gooooo00Coc<c<odA4
A?l0003o410@oooooolcooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.65) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49257 0 m
.49277 .00192 L
.49298 .00402 L
.49313 .00508 L
.49331 .00621 L
.4937 .00825 L
.49499 .01288 L
.49531 .01398 L
.49559 .01515 L
.49569 .01563 L
.49577 .01615 L
.49581 .01645 L
.49584 .01672 L
.49587 .01699 L
.49588 .01725 L
.49589 .01752 L
.4959 .01776 L
.4959 .01804 L
.49589 .0183 L
.49588 .01855 L
.49586 .01877 L
.49584 .01902 L
.49581 .01928 L
.49573 .01982 L
.49563 .02033 L
.49535 .02149 L
.49462 .02372 L
.49371 .0261 L
.4922 .03033 L
.49098 .03493 L
.49009 .03935 L
.48944 .04344 L
.4883 .05183 L
.48738 .05989 L
.48647 .06848 L
.48564 .07674 L
.48478 .08552 L
.48394 .09399 L
.48312 .10212 L
.48222 .11079 L
.48132 .11913 L
.48031 .12799 L
.47926 .13653 L
.4782 .14474 L
.47695 .15348 L
.47565 .16189 L
.47427 .16999 L
.47262 .1786 L
.47084 .18689 L
.46867 .19571 L
Mistroke
.46622 .2042 L
.46346 .21237 L
.45988 .22106 L
.45553 .22942 L
.45283 .2337 L
.44938 .23832 L
.4409 .24688 L
.4353 .25115 L
.4282 .25565 L
.41252 .26377 L
.40304 .2683 L
.39511 .27242 L
.3918 .27447 L
.39029 .27555 L
.38892 .27669 L
.38793 .27769 L
.38749 .27822 L
.38709 .27879 L
.3868 .27932 L
.38658 .2798 L
.38643 .28025 L
.38638 .28048 L
.38633 .28074 L
.38632 .28087 L
.38631 .28102 L
.3863 .28128 L
.38631 .28156 L
.38633 .28172 L
.38636 .28187 L
.38641 .28214 L
.38649 .28238 L
.38671 .28294 L
.38699 .28343 L
.38738 .28396 L
.38832 .28493 L
.3898 .28606 L
.39184 .28726 L
.39672 .28941 L
.40266 .29141 L
.41054 .29356 L
.42831 .29746 L
.47899 .30624 L
.52782 .3147 L
.54758 .31896 L
.56144 .32283 L
.56732 .32498 L
.57169 .32701 L
.57511 .32916 L
.57652 .33037 L
.57751 .33149 L
Mistroke
.57815 .33248 L
.57842 .33304 L
.5786 .33355 L
.57873 .33403 L
.57878 .3343 L
.57881 .33454 L
.57883 .33478 L
.57884 .335 L
.57884 .33525 L
.57883 .33549 L
.57881 .33574 L
.57877 .33602 L
.57872 .33632 L
.57866 .33659 L
.57851 .33708 L
.57832 .3376 L
.57771 .3388 L
.57699 .33989 L
.57518 .34201 L
.57311 .34397 L
.56747 .34841 L
.55543 .3568 L
.54471 .36486 L
.53551 .37345 L
.52879 .38172 L
.52343 .39051 L
.5195 .39898 L
.5165 .40712 L
.5139 .41579 L
.51179 .42413 L
.50985 .43299 L
.50821 .44154 L
.5068 .44976 L
.50543 .4585 L
.50421 .46692 L
.50311 .47501 L
.502 .48363 L
.50097 .49193 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomCooooo`03o`00
0?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003o
oooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo
0?ooooooFOooool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSooooo003ooooooeCooooo
00?o0000ooooooooool0oooooomHooooo`00oooooomDooooo`03o`000?oooooooooo0?ooooooF?oo
ool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSooooo003ooooooeCooooo00?o0000oooo
ooooool0oooooomHooooo`00oooooomDooooo`03o`000?oooooooooo0?ooooooF?ooool00?oooooo
E?ooool00ol0003oooooooooo`3ooooooeSooooo003ooooooeCooooo00?o0000ooooooooool0oooo
oomHooooo`00oooooomDooooo`03o`000?oooooooooo0?ooooooF?ooool00?ooooooDoooool00ol0
003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00
oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003ooooooooo
o`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomAoooo
o`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_o
oooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oo
oooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooo
oe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooom@ooooo`03o`000?oooooooooo0?oo
ooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o
0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool0
0?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000oooooooo
ool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?oo
ool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomL
ooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003o
ooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooo
oom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3o
oooooegooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03
o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo
003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooo
oooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodko
oooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?oooooo
G_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000
ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?oo
ooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0
oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool0
0ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOoooo
o`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003ooooo
ooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=
ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooo
oeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom<ooooo`03o`00
0?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003o
ooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo
0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo
00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?oo
ool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000oooo
ooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oooooo
C?ooool00ol0003oooooooooo`3oooooof3ooooo003ooooood_ooooo00?o0000ooooooooool0oooo
oomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0
003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00
oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooB_ooool00ol0003ooooooooo
o`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:oooo
o`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;o
oooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oo
oooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooo
od[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oo
ooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o
0000ooooooooool0oooooomRooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool0
0?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000oooooooo
ool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOoo
ool00ol0003oooooooooo`3oooooof?ooooo003oooooodSooooo00?o0000ooooooooool0oooooomT
ooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003o
ooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooo
oom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3o
ooooofCooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03
o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo
003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooo
oooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOo
oooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000
ooooooooool0oooooomUooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oo
ooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0
oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooAOooool0
0ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWoooo
o`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooA?ooool00ol0003ooooo
ooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4
ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3ooooo
ofSooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`00
0?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003o
oooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom2ooooo`03o`000?oooooooooo
0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood;ooooo
00?o0000ooooooooool0oooooomZooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJooo
ool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o0000oooo
ooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool00?oooooo
@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0oooo
oom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo@?ooool00ol0
003oooooooooo`3oooooofcooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00
ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?_ooool00ol0003ooooooooo
o`3oooooofkooooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00oooooolmoooo
o`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoo
oooo003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooollooooo`03o`000?oo
oooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3ooooo003ooooo
oc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkooooo`03o`000?oooooooooo0?oo
ooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003oooooocWooooo00?o
0000ooooooooool0oooooomcooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool0
0?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocKooooo0_l0003oooooogOo
oooo003oooooocGooooo00?o0000ooooooooool0oooooomgooooo`00ooooooldooooo`03o`000?oo
oooooooo0?ooooooN?ooool00?oooooo<oooool00ol0003oooooooooo`3oooooogWooooo003ooooo
oc;ooooo00?o0000ooooooooool0oooooomjooooo`00oooooolaooooo`03o`000?oooooooooo0?oo
ooooNoooool00?oooooo<?ooool00ol0003oooooooooo`3oooooogcooooo003ooooooboooooo00?o
0000ooooooooool0oooooommooooo`00ooooool]ooooo`;o0000oooooon0ooooo`00ooooool[oooo
o`;o0000oooooon2ooooo`00oooooolZooooo`03o`000?oooooooooo0?ooooooP_ooool00?oooooo
:?ooool2o`000?ooooooQOooool00?oooooo9_ooool2o`000?ooooooQoooool00?oooooo9?ooool2
o`000?ooooooROooool00?oooooo8_ooool2o`000?ooooooRoooool00?oooooo8?ooool2o`000?oo
ooooSOooool00?oooooo7_ooool2o`000?ooooooSoooool00?oooooo7?ooool2o`000?ooooooTOoo
ool00?oooooo6_ooool2o`000?ooooooToooool00?oooooo6?ooool2o`000?ooooooUOooool00?oo
oooo5Oooool3o`000?ooooooUoooool00?oooooo5?ooool00ol0003oooooooooo`3ooooooiSooooo
003ooooooa?ooooo00?o0000ooooooooool0oooooonIooooo`00oooooolAooooo`;o0000oooooonL
ooooo`00ooooool@ooooo`03o`000?oooooooooo0?ooooooW?ooool00?oooooo3oooool00ol0003o
ooooooooo`3ooooooigooooo003oooooo`kooooo0_l0003ooooooioooooo003oooooo`kooooo00?o
0000ooooooooool0oooooonNooooo`00ooooool?ooooo`03o`000?oooooooooo0?ooooooWOooool0
0?oooooo3oooool2o`000?ooooooW_ooool00?oooooo4Oooool00ol0003oooooooooo`3ooooooi_o
oooo003ooooooa;ooooo0ol0003ooooooi[ooooo003ooooooaGooooo0ol0003ooooooiOooooo003o
oooooaSooooo0ol0003ooooooiCooooo003ooooooa_ooooo0ol0003ooooooi7ooooo003ooooooako
oooo1?l0003oooooohgooooo003oooooob;ooooo1Ol0003oooooohSooooo003oooooobOooooo1_l0
003ooooooh;ooooo003oooooobgooooo1Ol0003ooooooggooooo003ooooooc;ooooo1_l0003ooooo
ogOooooo003oooooocSooooo1Ol0003oooooog;ooooo003oooooocgooooo1_l0003oooooofcooooo
003ooooood?ooooo1Ol0003oooooofOooooo003oooooodSooooo1_l0003oooooof7ooooo003ooooo
odkooooo1_l0003ooooooe_ooooo003ooooooeCooooo1ol0003ooooooeCooooo003ooooooe_ooooo
1_l0003oooooodkooooo003oooooof7ooooo1_l0003oooooodSooooo003oooooofOooooo1Ol0003o
oooood?ooooo003oooooofcooooo1?l0003oooooocoooooo003oooooog3ooooo1?l0003ooooooc_o
oooo003oooooogCooooo1?l0003oooooocOooooo003oooooogSooooo0ol0003oooooocCooooo003o
ooooog_ooooo0ol0003ooooooc7ooooo003oooooogkooooo0ol0003oooooobkooooo003ooooooh7o
oooo1?l0003oooooob[ooooo003oooooohGooooo00?o0000ooooooooool0oooooolWooooo`00oooo
oon6ooooo`03o`000?oooooooooo0?oooooo9_ooool00?ooooooQoooool2o`000?oooooo9_ooool0
0?ooooooR?ooool00ol0003oooooooooo`3oooooobCooooo003oooooohWooooo00?o0000oooooooo
ool0oooooolSooooo`00oooooon9ooooo`03o`000?oooooooooo0?oooooo8oooool00?ooooooROoo
ool00ol0003oooooooooo`3oooooob?ooooo003oooooohWooooo00?o0000ooooooooool0oooooolS
ooooo`00oooooon8ooooo`;o0000oooooolUooooo`00oooooon8ooooo`03o`000?oooooooooo0?oo
oooo9?ooool00?ooooooQoooool00ol0003oooooooooo`3oooooobGooooo003oooooohGooooo0_l0
003oooooobSooooo003oooooohCooooo00?o0000ooooooooool0oooooolXooooo`00oooooon3oooo
o`03o`000?oooooooooo0?oooooo:Oooool00?ooooooPOooool2o`000?oooooo;?ooool00?oooooo
P?ooool00ol0003oooooooooo`3oooooobcooooo003oooooogkooooo0_l0003ooooooboooooo003o
ooooogcooooo0_l0003ooooooc7ooooo003oooooog_ooooo00?o0000ooooooooool0oooooolaoooo
o`00oooooomiooooo`;o0000ooooooldooooo`00oooooomhooooo`03o`000?oooooooooo0?oooooo
=?ooool00?ooooooM_ooool2o`000?oooooo=oooool00?ooooooMOooool00ol0003oooooooooo`3o
ooooocOooooo003oooooogCooooo00?o0000ooooooooool0oooooolhooooo`00oooooomcooooo`03
o`000?oooooooooo0?oooooo>Oooool00?ooooooLoooool00ol0003oooooooooo`3oooooocWooooo
003oooooog;ooooo00?o0000ooooooooool0ooooooljooooo`00oooooomaooooo`03o`000?oooooo
oooo0?oooooo>oooool00?ooooooL?ooool00ol0003oooooooooo`3ooooooccooooo003oooooofoo
oooo00?o0000ooooooooool0oooooolmooooo`00oooooom^ooooo`03o`000?oooooooooo0?oooooo
?_ooool00?ooooooKOooool00ol0003oooooooooo`3oooooocoooooo003oooooofcooooo00?o0000
ooooooooool0oooooom0ooooo`00oooooom[ooooo`03o`000?oooooooooo0?oooooo@Oooool00?oo
ooooJ_ooool00ol0003oooooooooo`3ooooood;ooooo003oooooofWooooo00?o0000ooooooooool0
oooooom3ooooo`00oooooomYooooo`03o`000?oooooooooo0?oooooo@oooool00?ooooooJ?ooool0
0ol0003oooooooooo`3oooooodCooooo003oooooofSooooo00?o0000ooooooooool0oooooom4oooo
o`00oooooomWooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooIoooool00ol0003ooooo
ooooo`3oooooodGooooo003oooooofKooooo00?o0000ooooooooool0oooooom6ooooo`00oooooomV
ooooo`03o`000?oooooooooo0?ooooooA_ooool00?ooooooIOooool00ol0003oooooooooo`3ooooo
odOooooo003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`00
0?oooooooooo0?ooooooB?ooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003o
ooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00oooooomRooooo`03o`000?oooooooooo
0?ooooooB_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo
00?o0000ooooooooool0oooooom:ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBooo
ool00?ooooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof7ooooo00?o0000oooo
ooooool0oooooom;ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?oooooo
H?ooool00ol0003oooooooooo`3oooooodcooooo003oooooof3ooooo00?o0000ooooooooool0oooo
oom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool00ol0
003oooooooooo`3oooooodcooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=ooooo`00
oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003ooooooooo
o`3oooooodgooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNoooo
o`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3oooooodko
oooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomMooooo`03o`000?oo
oooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooo
oegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?oo
ooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool0
0?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o0000oooooooo
ool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo0?ooooooD?ooool00?ooooooFooo
ool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomA
ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooFoooool00ol0003o
ooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000ooooooooool0oooooomAooooo`00oooo
oomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooF_ooool00ol0003oooooooooo`3o
oooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03
o`000?oooooooooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo
003ooooooe[ooooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooo
oooo0?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[o
oooo00?o0000ooooooooool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?oooooo
D_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000
ooooooooool0oooooomBooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?oo
ooooFOooool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0
oooooomCooooo`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool0
0ol0003oooooooooo`3ooooooe?ooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDoooo
o`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomH
ooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooo
oeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`00
0?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003o
oooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oooooooooo
0?ooooooE?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo
00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?ooooooEOoo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
oooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_oooo
o`00ooooooooooooojoooooo003ooooooa3ooooo0ol000000ol@413oooooooooo`3ooooooiWooooo
003ooooooa;ooooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?oo
ool2o`0000Kooooo00?o0000okZj^_ooool0oooooom]ooooo`00oooooolBooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooK_ooool00?oooooo4_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo
00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@01_ooool00ol0003ooooo
ooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`000?l@41001Oooool01Ol@
413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@4004
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000ooooooooool01?oo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo00Oooooo
00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@4?oooooo4?ooool00?oooooo4Oooool01OoMgMgo410@
oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool00omEEEGoV9RHooooo`0<ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool0
0ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooo
oooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`03ogMgMolb<S;ooooo00Oooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3ooooooa?o
oooo003ooooooa3ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooo<S8bohN7Q`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[o
oooo00Go0000oeEEEOl0003o410@olc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool0
1_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82oooo
o`06ofIVI_mgMgOooooooooooon7QhOo0000ooooool@ooooo`00ooooool@ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`02ooooo`Go00002Ooo
ool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool02Oooool00ol@413o0000o`00
0003o`0001cooooo00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oo
oooooooo00[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo4?ooool00?oooooo6ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?ogMgMoa0@4?nHV9P01_oo
ool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000Cooooo`03o`000?oooooo
oooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEEofIVI_l000003Oooool0
1?o<c<coA4A4o`000?l@4104ooooo`Co0000ooooool_ooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.7) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49219 0 m
.49238 .00402 L
.4925 .00606 L
.49263 .00825 L
.49272 .00942 L
.49281 .01047 L
.49301 .01255 L
.49332 .01496 L
.49371 .01725 L
.49451 .02115 L
.49495 .02337 L
.49512 .02446 L
.49524 .02545 L
.49529 .02595 L
.49531 .02622 L
.49532 .0265 L
.49533 .02677 L
.49534 .02702 L
.49534 .02726 L
.49535 .02749 L
.49534 .02776 L
.49534 .02804 L
.49533 .02828 L
.49532 .02855 L
.4953 .02883 L
.49528 .02914 L
.49522 .02969 L
.49506 .0309 L
.49485 .03204 L
.49433 .03418 L
.49203 .04237 L
.49111 .04659 L
.49033 .05108 L
.48925 .05914 L
.48829 .06772 L
.48748 .07599 L
.48667 .08477 L
.48592 .09323 L
.4852 .10137 L
.48444 .11003 L
.48369 .11837 L
.48288 .12723 L
.48205 .13577 L
.48124 .14399 L
.48031 .15273 L
.47937 .16114 L
.47841 .16923 L
.47728 .17785 L
.47613 .18614 L
.47478 .19495 L
Mistroke
.47332 .20344 L
.47178 .21161 L
.46994 .2203 L
.46789 .22867 L
.46538 .23756 L
.46252 .24613 L
.45916 .25437 L
.45471 .26314 L
.44904 .27159 L
.44149 .27971 L
.43014 .28835 L
.41565 .29667 L
.40748 .30091 L
.39898 .30552 L
.39549 .30766 L
.39234 .30994 L
.39025 .31189 L
.38935 .313 L
.389 .31354 L
.38873 .31404 L
.38851 .31452 L
.38834 .31504 L
.38827 .31534 L
.38823 .31562 L
.3882 .31587 L
.38819 .31614 L
.38819 .31641 L
.3882 .31656 L
.38822 .3167 L
.38824 .31685 L
.38826 .31699 L
.38833 .31729 L
.38841 .31755 L
.38852 .31784 L
.38877 .31835 L
.38945 .31935 L
.39047 .32041 L
.3916 .32131 L
.39312 .32231 L
.39739 .32446 L
.40251 .32644 L
.4181 .33089 L
.45964 .33934 L
.5047 .34747 L
.52741 .35201 L
.54476 .35613 L
.55199 .35818 L
.55867 .36041 L
.56383 .3625 L
.56771 .36446 L
Mistroke
.57076 .36648 L
.572 .36755 L
.57307 .3687 L
.5735 .36928 L
.57389 .3699 L
.57418 .37046 L
.57442 .37105 L
.57451 .37135 L
.57459 .37163 L
.57465 .37191 L
.5747 .37216 L
.57473 .3724 L
.57475 .37266 L
.57476 .37291 L
.57476 .37319 L
.57475 .37347 L
.57473 .37373 L
.57472 .37386 L
.5747 .37401 L
.57465 .37431 L
.57452 .37486 L
.57436 .37538 L
.57397 .37633 L
.57342 .37736 L
.57173 .37969 L
.56973 .38183 L
.55935 .3903 L
.54845 .39844 L
.53818 .40711 L
.53028 .41545 L
.52384 .42432 L
.51908 .43286 L
.51543 .44108 L
.51225 .44982 L
.50966 .45824 L
.50748 .46633 L
.50537 .47495 L
.5035 .48325 L
.50162 .49207 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe?ooooo
00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOoo
ool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000oooo
ooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?oooooo
Doooool00ol0003oooooooooo`3ooooooeWooooo003ooooooeCooooo00?o0000ooooooooool0oooo
oomHooooo`00oooooomDooooo`03o`000?oooooooooo0?ooooooF?ooool00?ooooooE?ooool00ol0
003oooooooooo`3ooooooeSooooo003ooooooeCooooo00?o0000ooooooooool0oooooomHooooo`00
oooooomDooooo`03o`000?oooooooooo0?ooooooF?ooool00?ooooooE?ooool00ol0003ooooooooo
o`3ooooooeSooooo003ooooooeCooooo00?o0000ooooooooool0oooooomHooooo`00oooooomCoooo
o`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWo
oooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oo
oooooooo0?ooooooFOooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooo
oe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?oo
ooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe7ooooo00?o
0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool0
0?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooooooo
ool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOoo
ool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomL
ooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003o
ooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooo
oom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3o
oooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03
o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo
003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooo
oooo0?ooooooG?ooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoo
oooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?oooooo
GOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000
ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?oo
ooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0
oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool0
0ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNoooo
o`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003ooooo
ooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>
ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooo
oekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`00
0?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003o
ooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo
0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodgooooo
00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGooo
ool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000oooo
ooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oooooo
COooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooo
oomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0
003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00
oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooC?ooool00ol0003ooooooooo
o`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<oooo
o`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3o
oooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oo
oooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003ooooo
odcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?oo
ooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003ooooood_ooooo00?o
0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool0
0?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000oooooooo
ool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBooo
ool00ol0003oooooooooo`3oooooof7ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomR
ooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003o
ooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooo
oom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3o
ooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03
o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo
003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooo
oooo0?ooooooH_ooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWo
oooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?oooooo
Hoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000
ooooooooool0oooooomSooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?oo
ooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0
oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool0
0ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomToooo
o`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003ooooo
ooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8
ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3ooooo
ofCooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`00
0?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003o
ooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo
0?ooooooIOooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo
00?o0000ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_oo
ool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000oooo
ooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oooooo
AOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooo
oomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0
003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00
oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003ooooooooo
o`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4oooo
o`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWo
oooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oo
oooooooo0?ooooooJOooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooo
od;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?oo
ooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood7ooooo00?o
0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool0
0?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o0000oooooooo
ool0oooooom[ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo@?oo
ool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0oooooom/
ooooo`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?oooool00ol0003o
ooooooooo`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00oooo
oolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_ooool00ol0003oooooooooo`3o
ooooofkooooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00oooooolmooooo`03
o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoooooo
003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooolkooooo`03o`000?oooooo
oooo0?ooooooLOooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[o
oooo00?o0000ooooooooool0oooooombooooo`00ooooooljooooo`03o`000?oooooooooo0?oooooo
L_ooool00?oooooo>Oooool00ol0003oooooooooo`3oooooog?ooooo003oooooocSooooo00?o0000
ooooooooool0oooooomdooooo`00oooooolhooooo`03o`000?oooooooooo0?ooooooM?ooool00?oo
oooo=oooool00ol0003oooooooooo`3oooooogGooooo003oooooocKooooo00?o0000ooooooooool0
oooooomfooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oooooo=Oooool0
0ol0003oooooooooo`3oooooogOooooo003oooooocCooooo00?o0000ooooooooool0oooooomhoooo
o`00oooooolcooooo`03o`000?oooooooooo0?ooooooNOooool00?oooooo<Oooool2o`000?oooooo
O?ooool00?oooooo<?ooool00ol0003oooooooooo`3oooooogcooooo003ooooooboooooo00?o0000
ooooooooool0oooooommooooo`00ooooool]ooooo`;o0000oooooon0ooooo`00ooooool/ooooo`03
o`000?oooooooooo0?ooooooP?ooool00?oooooo:oooool00ol0003oooooooooo`3ooooooh7ooooo
003oooooobWooooo0_l0003oooooohCooooo003oooooobOooooo0_l0003oooooohKooooo003ooooo
obGooooo0_l0003oooooohSooooo003oooooobCooooo00?o0000ooooooooool0oooooon8ooooo`00
oooooolRooooo`;o0000oooooon;ooooo`00oooooolPooooo`;o0000oooooon=ooooo`00oooooolN
ooooo`;o0000oooooon?ooooo`00oooooolMooooo`03o`000?oooooooooo0?ooooooSoooool00?oo
oooo6oooool2o`000?ooooooT_ooool00?oooooo6?ooool3o`000?ooooooU?ooool00?oooooo5_oo
ool2o`000?ooooooUoooool00?oooooo5Oooool00ol0003oooooooooo`3ooooooiOooooo003ooooo
oa?ooooo0_l0003ooooooi[ooooo003ooooooa;ooooo00?o0000ooooooooool0oooooonJooooo`00
oooooolBooooo`03o`000?oooooooooo0?ooooooV_ooool00?oooooo4?ooool2o`000?ooooooWOoo
ool00?oooooo4?ooool00ol0003oooooooooo`3ooooooicooooo003ooooooa3ooooo00?o0000oooo
ooooool0oooooonLooooo`00ooooool@ooooo`03o`000?oooooooooo0?ooooooW?ooool00?oooooo
4?ooool00ol0003oooooooooo`3ooooooicooooo003ooooooa7ooooo00?o0000ooooooooool0oooo
oonKooooo`00oooooolBooooo`?o0000oooooonJooooo`00oooooolEooooo`03o`000?oooooooooo
0?ooooooUoooool00?oooooo5_ooool3o`000?ooooooU_ooool00?oooooo6Oooool3o`000?oooooo
Toooool00?oooooo7?ooool3o`000?ooooooT?ooool00?oooooo7oooool3o`000?ooooooSOooool0
0?oooooo8_ooool5o`000?ooooooR?ooool00?oooooo9oooool5o`000?ooooooPoooool00?oooooo
;?ooool5o`000?ooooooO_ooool00?oooooo<Oooool5o`000?ooooooNOooool00?oooooo=_ooool5
o`000?ooooooM?ooool00?oooooo>oooool6o`000?ooooooK_ooool00?oooooo@Oooool6o`000?oo
ooooJ?ooool00?ooooooAoooool6o`000?ooooooH_ooool00?ooooooCOooool5o`000?ooooooGOoo
ool00?ooooooD_ooool6o`000?ooooooEoooool00?ooooooF?ooool5o`000?ooooooD_ooool00?oo
ooooGOooool5o`000?ooooooCOooool00?ooooooH_ooool5o`000?ooooooB?ooool00?ooooooIooo
ool4o`000?ooooooA?ooool00?ooooooJoooool4o`000?oooooo@?ooool00?ooooooKoooool4o`00
0?oooooo??ooool00?ooooooLoooool4o`000?oooooo>?ooool00?ooooooMoooool4o`000?oooooo
=?ooool00?ooooooNoooool3o`000?oooooo<Oooool00?ooooooO_ooool2o`000?oooooo;oooool0
0?ooooooP?ooool2o`000?oooooo;Oooool00?ooooooP_ooool2o`000?oooooo:oooool00?oooooo
Q?ooool00ol0003oooooooooo`3oooooobSooooo003oooooohGooooo00?o0000ooooooooool0oooo
oolWooooo`00oooooon6ooooo`03o`000?oooooooooo0?oooooo9_ooool00?ooooooQ_ooool2o`00
0?oooooo9oooool00?ooooooQoooool00ol0003oooooooooo`3oooooobGooooo003oooooohOooooo
00?o0000ooooooooool0oooooolUooooo`00oooooon6ooooo`;o0000oooooolWooooo`00oooooon6
ooooo`03o`000?oooooooooo0?oooooo9_ooool00?ooooooQ_ooool00ol0003oooooooooo`3ooooo
obKooooo003oooooohCooooo0_l0003oooooobWooooo003ooooooh?ooooo00?o0000ooooooooool0
oooooolYooooo`00oooooon2ooooo`03o`000?oooooooooo0?oooooo:_ooool00?ooooooPOooool0
0ol0003oooooooooo`3oooooob_ooooo003ooooooh3ooooo00?o0000ooooooooool0ooooool/oooo
o`00oooooomoooooo`03o`000?oooooooooo0?oooooo;Oooool00?ooooooO_ooool00ol0003ooooo
ooooo`3oooooobkooooo003oooooogcooooo0_l0003ooooooc7ooooo003oooooog_ooooo00?o0000
ooooooooool0oooooolaooooo`00oooooomiooooo`;o0000ooooooldooooo`00oooooomhooooo`03
o`000?oooooooooo0?oooooo=?ooool00?ooooooMoooool00ol0003oooooooooo`3oooooocGooooo
003oooooogGooooo0_l0003oooooocSooooo003oooooogCooooo00?o0000ooooooooool0oooooolh
ooooo`00oooooombooooo`;o0000oooooolkooooo`00oooooomaooooo`03o`000?oooooooooo0?oo
oooo>oooool00?ooooooL?ooool00ol0003oooooooooo`3ooooooccooooo003oooooofoooooo00?o
0000ooooooooool0oooooolmooooo`00oooooom_ooooo`03o`000?oooooooooo0?oooooo?Oooool0
0?ooooooK_ooool00ol0003oooooooooo`3oooooockooooo003oooooofgooooo00?o0000oooooooo
ool0ooooooloooooo`00oooooom/ooooo`03o`000?oooooooooo0?oooooo@?ooool00?ooooooJooo
ool00ol0003oooooooooo`3ooooood7ooooo003oooooof[ooooo00?o0000ooooooooool0oooooom2
ooooo`00oooooomZooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJOooool00ol0003o
ooooooooo`3ooooood?ooooo003oooooofSooooo00?o0000ooooooooool0oooooom4ooooo`00oooo
oomWooooo`03o`000?oooooooooo0?ooooooAOooool00?ooooooI_ooool00ol0003oooooooooo`3o
ooooodKooooo003oooooofKooooo00?o0000ooooooooool0oooooom6ooooo`00oooooomUooooo`03
o`000?oooooooooo0?ooooooAoooool00?ooooooIOooool00ol0003oooooooooo`3oooooodOooooo
003oooooofCooooo00?o0000ooooooooool0oooooom8ooooo`00oooooomTooooo`03o`000?oooooo
oooo0?ooooooB?ooool00?ooooooHoooool00ol0003oooooooooo`3oooooodWooooo003oooooof?o
oooo00?o0000ooooooooool0oooooom9ooooo`00oooooomRooooo`03o`000?oooooooooo0?oooooo
B_ooool00?ooooooH_ooool00ol0003oooooooooo`3ooooood[ooooo003oooooof;ooooo00?o0000
ooooooooool0oooooom:ooooo`00oooooomQooooo`03o`000?oooooooooo0?ooooooBoooool00?oo
ooooHOooool00ol0003oooooooooo`3ooooood_ooooo003oooooof3ooooo00?o0000ooooooooool0
oooooom<ooooo`00oooooomPooooo`03o`000?oooooooooo0?ooooooC?ooool00?ooooooH?ooool0
0ol0003oooooooooo`3oooooodcooooo003ooooooeoooooo00?o0000ooooooooool0oooooom=oooo
o`00oooooomOooooo`03o`000?oooooooooo0?ooooooCOooool00?ooooooGoooool00ol0003ooooo
ooooo`3oooooodgooooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomN
ooooo`03o`000?oooooooooo0?ooooooC_ooool00?ooooooG_ooool00ol0003oooooooooo`3ooooo
odkooooo003ooooooegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`00
0?oooooooooo0?ooooooCoooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003o
oooooecooooo00?o0000ooooooooool0oooooom@ooooo`00oooooomLooooo`03o`000?oooooooooo
0?ooooooD?ooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo
00?o0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOoo
ool00?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe_ooooo00?o0000oooo
ooooool0oooooomAooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?oooooo
F_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooe[ooooo00?o0000ooooooooool0oooo
oomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooFOooool00ol0
003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00
oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooFOooool00ol0003ooooooooo
o`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCooooo`00oooooomHoooo
o`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCo
oooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomHooooo`03o`000?oo
oooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003oooooooooo`3ooooooeCooooo003ooooo
oeSooooo00?o0000ooooooooool0oooooomDooooo`00oooooomGooooo`03o`000?oooooooooo0?oo
ooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo4oooool3o`000003oa0@
4?oooooooooo0?ooooooU_ooool00?oooooo5Oooool00ol@413o^[Zjooooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`3oooooof[ooooo003o
oooooaGooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`03ooooo`;o<S8boooooom[ooooo`00oooooolEooooo`03omgMgOl0003o^[Zj
00Oooooo00Co0000oooooooooooooooo1Ol00004ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RH
o`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X01Ooo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1_ooool00ol0003ok^k^ooooo`09ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^
k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03ooooooaCooooo
003ooooooaGooooo00?oEEEEogMgMom4A4@01oooool01?l0003oooooooooooooool2ogMgM`;ooooo
00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^
k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04ooooo`;o8B4Q1_ooool00omE
EEGoZJVYooooo`09ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooaCooooo003ooooo
oaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEE
oiRHV?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03ojVYZOmEEEGooooo00[ooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003ooooooooo
o`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`000?oooooooooo00gooooo00?o
8B4Qooooooooool02?ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03
o`000?oooooooooo0?oooooo5oooool00?oooooo4oooool00oo^k^ko0000onk^kP02ooooo`03o`00
0?oMgMgooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03oc8b<_n7QhOooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03Oooool00omEEEGoc<c<ooooo`08ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0003ooooooaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001cooooo00?o0000
ooooooooool03Oooool00onYZJWoMgMgooooo`08ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000
0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0
003ooooooaCooooo003ooooooaoooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:
ooooo`05oa0@4?oooooooooooooooolb<S80oooooolcooooo`00oooooolOooooo`;o00004_ooool0
0ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo
000000cooooo1Ol0003ooooooc?ooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.75) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49199 0 m
.49207 .00402 L
.49217 .00825 L
.4923 .01255 L
.4924 .01498 L
.49252 .01725 L
.49265 .01949 L
.49281 .02161 L
.49323 .02558 L
.49378 .02948 L
.49413 .0317 L
.49444 .03378 L
.49458 .03483 L
.49469 .03582 L
.49474 .03637 L
.49478 .03697 L
.49482 .03751 L
.49484 .03802 L
.49485 .0383 L
.49485 .03845 L
.49486 .0386 L
.49486 .03874 L
.49486 .03889 L
.49486 .03916 L
.49486 .03941 L
.49486 .03969 L
.49485 .03995 L
.49484 .04019 L
.49483 .04049 L
.49482 .04076 L
.49478 .04138 L
.49474 .04193 L
.49468 .04251 L
.4944 .04451 L
.494 .04667 L
.49311 .05057 L
.49215 .05477 L
.49126 .05936 L
.49001 .06782 L
.48905 .07648 L
.48825 .08482 L
.48747 .09368 L
.48676 .10222 L
.4861 .11043 L
.48539 .11917 L
.48472 .12759 L
.48405 .13568 L
.48334 .14429 L
.48262 .15258 L
.48183 .1614 L
Mistroke
.48103 .16989 L
.48022 .17806 L
.47931 .18675 L
.47838 .19512 L
.4773 .20401 L
.47619 .21258 L
.47503 .22082 L
.47367 .22959 L
.47224 .23803 L
.47071 .24615 L
.46887 .2548 L
.46686 .26312 L
.46441 .27196 L
.46162 .28048 L
.4584 .28868 L
.45418 .2974 L
.44889 .3058 L
.44202 .31387 L
.43191 .32247 L
.41904 .33074 L
.40347 .33954 L
.39645 .34393 L
.39362 .34607 L
.39152 .34801 L
.39067 .34898 L
.38992 .35004 L
.38964 .35052 L
.38939 .35104 L
.3892 .35152 L
.38906 .35195 L
.389 .35221 L
.38896 .35245 L
.38892 .35271 L
.3889 .35299 L
.38889 .35323 L
.3889 .35349 L
.38891 .35371 L
.38895 .35396 L
.38897 .3541 L
.389 .35424 L
.38906 .3545 L
.38926 .35509 L
.3895 .3556 L
.38983 .35616 L
.39072 .35729 L
.39185 .35835 L
.39474 .36034 L
.39898 .36249 L
.40492 .36481 L
.41913 .36905 L
Mistroke
.43823 .37355 L
.47864 .38163 L
.52054 .39024 L
.53651 .3942 L
.55044 .39852 L
.55633 .40087 L
.56074 .40304 L
.56403 .40512 L
.56548 .40627 L
.56658 .40733 L
.56746 .40838 L
.56819 .40953 L
.56848 .41013 L
.5687 .41069 L
.56887 .41128 L
.56895 .41161 L
.569 .41191 L
.56903 .41217 L
.56905 .41231 L
.56906 .41246 L
.56907 .41272 L
.56907 .41297 L
.56907 .41311 L
.56906 .41326 L
.56904 .41352 L
.56903 .41367 L
.56901 .41381 L
.56897 .41412 L
.56886 .41465 L
.56873 .41513 L
.56833 .41622 L
.56782 .41725 L
.56716 .41835 L
.56568 .42032 L
.5613 .42476 L
.55127 .43285 L
.54027 .44147 L
.53094 .44977 L
.52284 .45859 L
.51659 .46708 L
.51165 .47526 L
.50716 .48395 L
.50331 .49232 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo
00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_oo
ool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooo
ooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
D_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooo
oomJooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0
003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00
oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003ooooooooo
o`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCoooo
o`03o`000?oooooooooo0?ooooooFOooool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSo
oooo003ooooooeCooooo00?o0000ooooooooool0oooooomHooooo`00oooooomDooooo`03o`000?oo
oooooooo0?ooooooF?ooool00?ooooooE?ooool00ol0003oooooooooo`3ooooooeSooooo003ooooo
oeCooooo00?o0000ooooooooool0oooooomHooooo`00oooooomDooooo`03o`000?oooooooooo0?oo
ooooF?ooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o
0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool0
0?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000oooooooo
ool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooD_oo
ool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJ
ooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooDOooool00ol0003o
ooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooo
oomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3o
oooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03
o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo
003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooo
oooo0?ooooooFoooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3o
oooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?oooooo
G?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000
ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?oo
ooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0
oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool0
0ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMoooo
o`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003ooooo
ooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?
ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooo
oegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`00
0?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003o
ooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo
0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodkooooo
00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_oo
ool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000oooo
ooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?oooooo
C_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooo
oomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0
003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00
oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooCOooool00ol0003ooooooooo
o`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=oooo
o`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoo
oooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oo
oooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003ooooo
odgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?oo
ooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o
0000ooooooooool0oooooomOooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool0
0?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000oooooooo
ool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?oo
ool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomP
ooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003o
ooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooo
oom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3o
ooooof3ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03
o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo
003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooo
oooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_o
oooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?oooooo
HOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000
ooooooooool0oooooomQooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?oo
ooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0
oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool0
0ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRoooo
o`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003ooooo
ooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:
ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3ooooo
of;ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`00
0?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003o
ooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo
0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodSooooo
00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?oo
ool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000oooo
ooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?oooooo
B?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooo
oomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0
003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00
oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003ooooooooo
o`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7oooo
o`03o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGo
oooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom6ooooo`03o`000?oo
oooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003ooooo
odKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?oo
ooooI_ooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodGooooo00?o
0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool0
0?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000oooooooo
ool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOoo
ool00ol0003oooooooooo`3oooooofOooooo003oooooodCooooo00?o0000ooooooooool0oooooomX
ooooo`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003o
ooooooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooo
oom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo@oooool00ol0003oooooooooo`3o
ooooofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03
o`000?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo
003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom2ooooo`03o`000?oooooo
oooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood;o
oooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?oooooo
J_ooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o0000
ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJoooool00?oo
oooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0
oooooom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool0
0ol0003oooooooooo`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]oooo
o`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?_ooool00ol0003ooooo
ooooo`3oooooofkooooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00oooooolm
ooooo`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3ooooo
ofoooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooollooooo`03o`00
0?oooooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3ooooo003o
oooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooolkooooo`03o`000?oooooooooo
0?ooooooLOooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc_ooooo
00?o0000ooooooooool0oooooomaooooo`00ooooooljooooo`03o`000?oooooooooo0?ooooooL_oo
ool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003oooooocWooooo00?o0000oooo
ooooool0oooooomcooooo`00oooooolhooooo`03o`000?oooooooooo0?ooooooM?ooool00?oooooo
>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000ooooooooool0oooo
oomeooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oooooo=_ooool00ol0
003oooooooooo`3oooooogKooooo003oooooocGooooo00?o0000ooooooooool0oooooomgooooo`00
ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo<oooool00ol0003ooooooooo
o`3oooooogWooooo003ooooooc7ooooo0_l0003oooooogcooooo003ooooooc3ooooo00?o0000oooo
ooooool0oooooomlooooo`00ooooool_ooooo`03o`000?oooooooooo0?ooooooOOooool00?oooooo
;_ooool00ol0003oooooooooo`3oooooogkooooo003oooooobgooooo00?o0000ooooooooool0oooo
oomoooooo`00ooooool[ooooo`;o0000oooooon2ooooo`00oooooolZooooo`03o`000?oooooooooo
0?ooooooP_ooool00?oooooo:?ooool2o`000?ooooooQOooool00?oooooo9oooool00ol0003ooooo
ooooo`3oooooohGooooo003oooooobGooooo0_l0003oooooohSooooo003oooooobCooooo00?o0000
ooooooooool0oooooon8ooooo`00oooooolRooooo`;o0000oooooon;ooooo`00oooooolPooooo`;o
0000oooooon=ooooo`00oooooolNooooo`;o0000oooooon?ooooo`00oooooolLooooo`;o0000oooo
oonAooooo`00oooooolJooooo`;o0000oooooonCooooo`00oooooolHooooo`;o0000oooooonEoooo
o`00oooooolGooooo`03o`000?oooooooooo0?ooooooUOooool00?oooooo5_ooool00ol0003ooooo
ooooo`3ooooooiKooooo003ooooooaCooooo0_l0003ooooooiWooooo003ooooooa?ooooo00?o0000
ooooooooool0oooooonIooooo`00oooooolCooooo`03o`000?oooooooooo0?ooooooVOooool00?oo
oooo4Oooool2o`000?ooooooW?ooool00?oooooo4?ooool2o`000?ooooooWOooool00?oooooo4?oo
ool00ol0003oooooooooo`3ooooooicooooo003ooooooa3ooooo00?o0000ooooooooool0oooooonL
ooooo`00ooooool@ooooo`03o`000?oooooooooo0?ooooooW?ooool00?oooooo4Oooool00ol0003o
ooooooooo`3ooooooi_ooooo003ooooooa;ooooo0_l0003ooooooi_ooooo003ooooooaCooooo0_l0
003ooooooiWooooo003ooooooaKooooo00?o0000ooooooooool0oooooonFooooo`00oooooolGoooo
o`?o0000oooooonEooooo`00oooooolJooooo`?o0000oooooonBooooo`00oooooolMooooo`?o0000
oooooon?ooooo`00oooooolPooooo`?o0000oooooon<ooooo`00oooooolSooooo`?o0000oooooon9
ooooo`00oooooolVooooo`Go0000oooooon4ooooo`00ooooool[ooooo`Co0000oooooon0ooooo`00
ooooool_ooooo`Go0000oooooomkooooo`00ooooooldooooo`Go0000oooooomfooooo`00ooooooli
ooooo`Go0000oooooomaooooo`00oooooolnooooo`Go0000oooooom/ooooo`00oooooom3ooooo`Go
0000oooooomWooooo`00oooooom8ooooo`Co0000oooooomSooooo`00oooooom<ooooo`Go0000oooo
oomNooooo`00oooooomAooooo`Co0000oooooomJooooo`00oooooomEooooo`Go0000oooooomEoooo
o`00oooooomJooooo`Co0000oooooomAooooo`00oooooomNooooo`Go0000oooooom<ooooo`00oooo
oomSooooo`Go0000oooooom7ooooo`00oooooomXooooo`Go0000oooooom2ooooo`00oooooom]oooo
o`Co0000oooooolnooooo`00oooooomaooooo`?o0000oooooolkooooo`00oooooomdooooo`?o0000
oooooolhooooo`00oooooomgooooo`?o0000ooooooleooooo`00oooooomjooooo`?o0000oooooolb
ooooo`00oooooommooooo`03o`000?oooooooooo0?oooooo;oooool00?ooooooO_ooool2o`000?oo
oooo;oooool00?ooooooP?ooool00ol0003oooooooooo`3oooooobcooooo003ooooooh7ooooo00?o
0000ooooooooool0ooooool[ooooo`00oooooon2ooooo`03o`000?oooooooooo0?oooooo:_ooool0
0?ooooooP_ooool2o`000?oooooo:oooool00?ooooooPoooool00ol0003oooooooooo`3oooooobWo
oooo003ooooooh?ooooo00?o0000ooooooooool0oooooolYooooo`00oooooon3ooooo`03o`000?oo
oooooooo0?oooooo:Oooool00?ooooooPoooool00ol0003oooooooooo`3oooooobWooooo003ooooo
oh;ooooo00?o0000ooooooooool0oooooolZooooo`00oooooon2ooooo`03o`000?oooooooooo0?oo
oooo:_ooool00?ooooooPOooool00ol0003oooooooooo`3oooooob_ooooo003ooooooh3ooooo00?o
0000ooooooooool0ooooool/ooooo`00oooooomoooooo`03o`000?oooooooooo0?oooooo;Oooool0
0?ooooooOOooool2o`000?oooooo<?ooool00?ooooooO?ooool00ol0003oooooooooo`3ooooooc3o
oooo003oooooog_ooooo00?o0000ooooooooool0oooooolaooooo`00oooooomjooooo`03o`000?oo
oooooooo0?oooooo<_ooool00?ooooooNOooool00ol0003oooooooooo`3ooooooc?ooooo003ooooo
ogOooooo0_l0003oooooocKooooo003oooooogKooooo00?o0000ooooooooool0oooooolfooooo`00
oooooomdooooo`;o0000ooooooliooooo`00oooooomcooooo`03o`000?oooooooooo0?oooooo>Ooo
ool00?ooooooL_ooool00ol0003oooooooooo`3ooooooc[ooooo003oooooog3ooooo0_l0003ooooo
ocgooooo003oooooofoooooo00?o0000ooooooooool0oooooolmooooo`00oooooom^ooooo`03o`00
0?oooooooooo0?oooooo?_ooool00?ooooooKOooool00ol0003oooooooooo`3oooooocoooooo003o
ooooofcooooo00?o0000ooooooooool0oooooom0ooooo`00oooooom[ooooo`03o`000?oooooooooo
0?oooooo@Oooool00?ooooooJoooool00ol0003oooooooooo`3ooooood7ooooo003oooooof[ooooo
00?o0000ooooooooool0oooooom2ooooo`00oooooomYooooo`03o`000?oooooooooo0?oooooo@ooo
ool00?ooooooJ?ooool00ol0003oooooooooo`3oooooodCooooo003oooooofOooooo00?o0000oooo
ooooool0oooooom5ooooo`00oooooomVooooo`03o`000?oooooooooo0?ooooooA_ooool00?oooooo
I_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofGooooo00?o0000ooooooooool0oooo
oom7ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?ooool00?ooooooI?ooool00ol0
003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9ooooo`00
oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH_ooool00ol0003ooooooooo
o`3ooooood[ooooo003oooooof7ooooo00?o0000ooooooooool0oooooom;ooooo`00oooooomPoooo
o`03o`000?oooooooooo0?ooooooC?ooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgo
oooo003ooooooekooooo00?o0000ooooooooool0oooooom>ooooo`00oooooomNooooo`03o`000?oo
oooooooo0?ooooooC_ooool00?ooooooGOooool00ol0003oooooooooo`3oooooodoooooo003ooooo
oegooooo00?o0000ooooooooool0oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?oo
ooooCoooool00?ooooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooecooooo00?o
0000ooooooooool0oooooom@ooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool0
0?ooooooFoooool00ol0003oooooooooo`3ooooooe7ooooo003ooooooe[ooooo00?o0000oooooooo
ool0oooooomBooooo`00oooooomJooooo`03o`000?oooooooooo0?ooooooD_ooool00?ooooooFOoo
ool00ol0003oooooooooo`3ooooooe?ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomC
ooooo`00oooooomHooooo`03o`000?oooooooooo0?ooooooE?ooool00?ooooooF?ooool00ol0003o
ooooooooo`3ooooooeCooooo003ooooooeSooooo00?o0000ooooooooool0oooooomDooooo`00oooo
oomGooooo`03o`000?oooooooooo0?ooooooEOooool00?oooooooooooon_ooooo`00oooooooooooo
ojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooa3ooooo
0ol000000ol@413oooooooooo`3ooooooiWooooo003ooooooa;ooooo00?o410@okZj^_ooool01_oo
ool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooo
oom]ooooo`00oooooolBooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000ooooooooool02_ooool2
oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooK_ooool00?oooooo4_ooool00ooM
gMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo1Ol00003ooooo`03ohN7Qol0003o^[Zj
00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7
o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
2?ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj
^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0ooooool@ooooo`00oooooolBooooo`03oeEEEOmg
MgOoA4A400Kooooo00?o0000ooooooooool00_ooool2ogMgM`;ooooo00Oo0000oooooooooooooooo
olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo
00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l0000<
ooooo`03o`000?oooooooooo00Cooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@ooooool@ooooo`00oooooolA
ooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`03oeEEEOnH
V9Sooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool03?ooool00onYZJWoEEEEooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolCooooo`00oooooolAooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1Oooool00ol0003oooooooooo`04ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o8B4Qooooooooool01_ooool00omgMgOo<S8booooo`07ooooo`06oc8b
<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolCoooo
o`00ooooool@ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?oooooooooooc8b<_n7QhL02oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=oooo
o`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06o`000?nj^[[o
ooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMg
MoooooooooooohN7Qol0003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009ooooo`03oa0@4?l0
003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o000000?o00007?oo
ool00ol0003oooooooooo`0=ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool02_oo
ool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2
ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@ooooo`00oooooolKooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo
00?o0000ooooooooool0ooooool`ooooo`00oooooolKooooo`;o00004oooool00ol0003ooooooooo
o`04ooooo`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo1Ol0
0004ooooo`Co0000ooooool_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49186 0 m
.49184 .00025 L
.49185 .00048 L
.49185 .00073 L
.49186 .00099 L
.49186 .00124 L
.49185 .00147 L
.49185 .00169 L
.49185 .00192 L
.49185 .00217 L
.49186 .00243 L
.49186 .00292 L
.49186 .00321 L
.49187 .00349 L
.49187 .00374 L
.49187 .00402 L
.49187 .00428 L
.49187 .00442 L
.49187 .00456 L
.49187 .00483 L
.49187 .00508 L
.49187 .00536 L
.49187 .00567 L
.49188 .00621 L
.4919 .00825 L
.49194 .01259 L
.49197 .01498 L
.49201 .01725 L
.49211 .02176 L
.49223 .02588 L
.49231 .02794 L
.49241 .03013 L
.49266 .03407 L
.49282 .03607 L
.49302 .03823 L
.49347 .04213 L
.49396 .04633 L
.49408 .04748 L
.49419 .0487 L
.49428 .04986 L
.49431 .05036 L
.49433 .05092 L
.49435 .05144 L
.49436 .05173 L
.49437 .052 L
.49437 .05225 L
.49437 .05249 L
.49437 .05275 L
.49437 .053 L
.49437 .05328 L
Mistroke
.49437 .05343 L
.49437 .05357 L
.49436 .05383 L
.49435 .05409 L
.49433 .05466 L
.4943 .05527 L
.49423 .05631 L
.49412 .05741 L
.49388 .05938 L
.49317 .06358 L
.49241 .0675 L
.49096 .07582 L
.48982 .08466 L
.48896 .09318 L
.48824 .10138 L
.48753 .1101 L
.48687 .1185 L
.48626 .12657 L
.48561 .13517 L
.48499 .14344 L
.48432 .15224 L
.48366 .16071 L
.483 .16886 L
.48229 .17753 L
.48156 .18588 L
.48076 .19476 L
.47996 .20331 L
.47913 .21153 L
.4782 .22028 L
.47725 .22871 L
.47626 .23681 L
.47514 .24544 L
.47397 .25374 L
.4726 .26257 L
.47116 .27107 L
.46964 .27925 L
.46782 .28795 L
.46586 .29633 L
.46372 .30438 L
.46109 .31296 L
.45812 .32122 L
.45431 .33 L
.44971 .33845 L
.44396 .34658 L
.43571 .35524 L
.42504 .36357 L
.41091 .37242 L
.40343 .37686 L
.39696 .38096 L
.3917 .38494 L
Mistroke
.38966 .38695 L
.38873 .38809 L
.38803 .38916 L
.38751 .3902 L
.3873 .39079 L
.38722 .39107 L
.38716 .39133 L
.38711 .39157 L
.38707 .39183 L
.38704 .39207 L
.38703 .39229 L
.38703 .39253 L
.38703 .39279 L
.38705 .39306 L
.38708 .39331 L
.38713 .39359 L
.3872 .39389 L
.38738 .39444 L
.38761 .39497 L
.38787 .39547 L
.38866 .39658 L
.38979 .39777 L
.3924 .39978 L
.39623 .40193 L
.4058 .40584 L
.41993 .41012 L
.43814 .41463 L
.47563 .42277 L
.51372 .43144 L
.5282 .43544 L
.54072 .43978 L
.54607 .44215 L
.55003 .44434 L
.55298 .44643 L
.55426 .44759 L
.55522 .44865 L
.55594 .44961 L
.55654 .45066 L
.55679 .45124 L
.55697 .45178 L
.55711 .45229 L
.55717 .45257 L
.55721 .45283 L
.55725 .45308 L
.55727 .45334 L
.55728 .45356 L
.55729 .4538 L
.55729 .45406 L
.55727 .45434 L
.55725 .45461 L
Mistroke
.55722 .45485 L
.55715 .45531 L
.55703 .45582 L
.55674 .45674 L
.55628 .45778 L
.55575 .45876 L
.55417 .46098 L
.54971 .46547 L
.53869 .47374 L
.52548 .48255 L
.51286 .49102 L
.50116 .49918 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo
00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_oo
ool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooo
ooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
D_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooo
oomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0
003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00
oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003ooooooooo
o`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBoooo
o`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[o
oooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomCooooo`03o`000?oo
oooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooo
oe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?oo
ooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o
0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool0
0?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000oooooooo
ool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDooo
ool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomI
ooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003o
ooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooo
oomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3o
oooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomBooooo`03
o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo
003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooo
oooo0?ooooooF_ooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7o
oooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oooooo
Foooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000
ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oo
ooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0
oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool0
0ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLoooo
o`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003ooooo
ooooo`3ooooooecooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@
ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooo
oecooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`00
0?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003o
ooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo
0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo
00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOoo
ool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000oooo
ooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?oooooo
Coooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooo
oomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0
003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00
oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003ooooooooo
o`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>oooo
o`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooeko
oooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oo
oooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003ooooo
odkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?oo
ooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodgooooo00?o
0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool0
0?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000oooooooo
ool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOoo
ool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomO
ooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003o
ooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooo
oom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3o
oooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03
o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo
003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom<ooooo`03o`000?oooooo
oooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodco
oooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?oooooo
H?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000
ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oo
ooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0
oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool0
0ol0003oooooooooo`3oooooof3ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQoooo
o`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003ooooo
ooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;
ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3ooooo
of7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`00
0?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003o
oooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo
0?ooooooHOooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo
00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_oo
ool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000oooo
ooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?oooooo
B_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooo
oomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0
003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00
oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003ooooooooo
o`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9oooo
o`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?o
oooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oo
oooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003ooooo
odSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?oo
ooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o
0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool0
0?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000oooooooo
ool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooAooo
ool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomU
ooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003o
ooooooooo`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooo
oom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003oooooooooo`3o
ooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom6ooooo`03
o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo
003oooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom5ooooo`03o`000?oooooo
oooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGo
oooo00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?oooooo
Ioooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000
ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?oo
ooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0
oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool0
0ol0003oooooooooo`3oooooofOooooo003oooooodCooooo00?o0000ooooooooool0oooooomXoooo
o`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003ooooo
ooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom3
ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003oooooooooo`3ooooo
ofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom2ooooo`03o`00
0?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003o
oooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo
0?ooooooJ_ooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo
00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJooo
ool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o0000oooo
ooooool0oooooom[ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo
@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0oooo
oom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool00ol0
003oooooooooo`3oooooofgooooo003oooooocoooooo00?o0000ooooooooool0oooooom]ooooo`00
ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?_ooool00ol0003ooooooooo
o`3oooooofkooooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00oooooolmoooo
o`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3oooooofoo
oooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooollooooo`03o`000?oo
oooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3ooooo003ooooo
oc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkooooo`03o`000?oooooooooo0?oo
ooooLOooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo003ooooooc[ooooo00?o
0000ooooooooool0oooooombooooo`00ooooooljooooo`03o`000?oooooooooo0?ooooooL_ooool0
0?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003oooooocWooooo00?o0000oooooooo
ool0oooooomcooooo`00oooooolhooooo`03o`000?oooooooooo0?ooooooM?ooool00?oooooo>?oo
ool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000ooooooooool0oooooome
ooooo`00oooooolgooooo`03o`000?oooooooooo0?ooooooMOooool00?oooooo=_ooool00ol0003o
ooooooooo`3oooooogKooooo003oooooocGooooo00?o0000ooooooooool0oooooomgooooo`00oooo
ooleooooo`03o`000?oooooooooo0?ooooooMoooool00?oooooo=?ooool00ol0003oooooooooo`3o
ooooogSooooo003ooooooc?ooooo00?o0000ooooooooool0oooooomiooooo`00oooooolbooooo`03
o`000?oooooooooo0?ooooooN_ooool00?oooooo<Oooool00ol0003oooooooooo`3oooooog_ooooo
003ooooooc3ooooo00?o0000ooooooooool0oooooomlooooo`00ooooool_ooooo`03o`000?oooooo
oooo0?ooooooOOooool00?oooooo;Oooool2o`000?ooooooP?ooool00?oooooo;?ooool00ol0003o
ooooooooo`3ooooooh3ooooo003oooooob[ooooo0_l0003ooooooh?ooooo003oooooobWooooo00?o
0000ooooooooool0oooooon3ooooo`00oooooolXooooo`03o`000?oooooooooo0?ooooooQ?ooool0
0?oooooo9_ooool2o`000?ooooooQoooool00?oooooo9Oooool00ol0003oooooooooo`3oooooohOo
oooo003oooooob?ooooo0_l0003ooooooh[ooooo003oooooob;ooooo00?o0000ooooooooool0oooo
oon:ooooo`00oooooolPooooo`;o0000oooooon=ooooo`00oooooolOooooo`03o`000?oooooooooo
0?ooooooSOooool00?oooooo7Oooool2o`000?ooooooT?ooool00?oooooo6oooool2o`000?oooooo
T_ooool00?oooooo6_ooool00ol0003oooooooooo`3ooooooi;ooooo003ooooooaSooooo0_l0003o
oooooiGooooo003ooooooaOooooo00?o0000ooooooooool0oooooonEooooo`00oooooolFooooo`03
o`000?oooooooooo0?ooooooU_ooool00?oooooo5?ooool2o`000?ooooooVOooool00?oooooo4ooo
ool00ol0003oooooooooo`3ooooooiWooooo003ooooooa;ooooo00?o0000ooooooooool0oooooonJ
ooooo`00oooooolAooooo`03o`000?oooooooooo0?ooooooVoooool00?oooooo4?ooool00ol0003o
ooooooooo`3ooooooicooooo003oooooo`oooooo0_l0003ooooooikooooo003oooooo`oooooo00?o
0000ooooooooool0oooooonMooooo`00ooooool?ooooo`03o`000?oooooooooo0?ooooooWOooool0
0?oooooo3oooool00ol0003oooooooooo`3ooooooigooooo003oooooo`oooooo00?o0000oooooooo
ool0oooooonMooooo`00ooooool@ooooo`;o0000oooooonMooooo`00oooooolAooooo`03o`000?oo
oooooooo0?ooooooVoooool00?oooooo4_ooool3o`000?ooooooV_ooool00?oooooo5Oooool3o`00
0?ooooooUoooool00?oooooo6?ooool3o`000?ooooooU?ooool00?oooooo6oooool3o`000?oooooo
TOooool00?oooooo7_ooool3o`000?ooooooS_ooool00?oooooo8Oooool3o`000?ooooooRoooool0
0?oooooo9?ooool3o`000?ooooooR?ooool00?oooooo9oooool4o`000?ooooooQ?ooool00?oooooo
:oooool4o`000?ooooooP?ooool00?oooooo;oooool4o`000?ooooooO?ooool00?oooooo<oooool5
o`000?ooooooMoooool00?oooooo>?ooool5o`000?ooooooL_ooool00?oooooo?Oooool4o`000?oo
ooooK_ooool00?oooooo@Oooool5o`000?ooooooJOooool00?ooooooA_ooool4o`000?ooooooIOoo
ool00?ooooooB_ooool4o`000?ooooooHOooool00?ooooooC_ooool4o`000?ooooooGOooool00?oo
ooooD_ooool5o`000?ooooooF?ooool00?ooooooEoooool4o`000?ooooooE?ooool00?ooooooFooo
ool4o`000?ooooooD?ooool00?ooooooGoooool4o`000?ooooooC?ooool00?ooooooHoooool5o`00
0?ooooooAoooool00?ooooooJ?ooool3o`000?ooooooA?ooool00?ooooooJoooool3o`000?oooooo
@Oooool00?ooooooK_ooool3o`000?oooooo?_ooool00?ooooooLOooool2o`000?oooooo??ooool0
0?ooooooLoooool00ol0003oooooooooo`3oooooocWooooo003oooooogCooooo0ol0003oooooocSo
oooo003oooooogOooooo0_l0003oooooocKooooo003oooooogWooooo00?o0000ooooooooool0oooo
oolcooooo`00oooooomjooooo`03o`000?oooooooooo0?oooooo<_ooool00?ooooooN_ooool2o`00
0?oooooo<oooool00?ooooooNoooool00ol0003oooooooooo`3ooooooc7ooooo003oooooog_ooooo
00?o0000ooooooooool0oooooolaooooo`00oooooomkooooo`;o0000oooooolbooooo`00oooooomk
ooooo`03o`000?oooooooooo0?oooooo<Oooool00?ooooooNoooool00ol0003oooooooooo`3ooooo
oc7ooooo003oooooog_ooooo00?o0000ooooooooool0oooooolaooooo`00oooooomkooooo`03o`00
0?oooooooooo0?oooooo<Oooool00?ooooooNOooool2o`000?oooooo=?ooool00?ooooooN?ooool0
0ol0003oooooooooo`3oooooocCooooo003oooooogKooooo0_l0003oooooocOooooo003oooooogGo
oooo00?o0000ooooooooool0oooooolgooooo`00oooooomdooooo`03o`000?oooooooooo0?oooooo
>?ooool00?ooooooLoooool00ol0003oooooooooo`3oooooocWooooo003oooooog;ooooo00?o0000
ooooooooool0ooooooljooooo`00oooooomaooooo`03o`000?oooooooooo0?oooooo>oooool00?oo
ooooKoooool2o`000?oooooo?_ooool00?ooooooKOooool2o`000?oooooo@?ooool00?ooooooJooo
ool2o`000?oooooo@_ooool00?ooooooJ_ooool00ol0003oooooooooo`3ooooood;ooooo003ooooo
ofSooooo0_l0003oooooodGooooo003oooooofKooooo0_l0003oooooodOooooo003oooooofGooooo
00?o0000ooooooooool0oooooom7ooooo`00oooooomTooooo`03o`000?oooooooooo0?ooooooB?oo
ool00?ooooooH_ooool2o`000?ooooooBoooool00?ooooooHOooool00ol0003oooooooooo`3ooooo
od_ooooo003oooooof3ooooo00?o0000ooooooooool0oooooom<ooooo`00oooooomNooooo`;o0000
oooooom?ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?ooooooFoooool2
o`000?ooooooD_ooool00?ooooooF_ooool00ol0003oooooooooo`3ooooooe;ooooo003ooooooeWo
oooo00?o0000ooooooooool0oooooomCooooo`00oooooomHooooo`03o`000?oooooooooo0?oooooo
E?ooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool0
0?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooo
oon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
oooooolCooooo`?o000000?o410@ooooooooool0oooooonFooooo`00oooooolEooooo`03oa0@4?nj
^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj
^[[ooooo0?ooooooJ_ooool00?oooooo5Oooool00onHV9So<S8booooo`07ooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S;oooooof_ooooo003ooooo
oaGooooo00?ogMgMo`000?nj^[X01oooool01?l0003oooooooooooooool5o`0000Cooooo00?oQhN7
o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00ooo
ool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`02Oooool01_l@413o
<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIV
I_l0003o0000odA4A?o<c<`0oooooolDooooo`00oooooolEooooo`03oeEEEOmgMgOoA4A400Oooooo
00Co0000oooooooooooooooo0_mgMgL2ooooo`03o`000?oooooooooo00;ooooo00?oc<c<o`000?l@
41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<
c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@09ooooo`06o`000?nY
ZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIV
ogMgMoooooooooooohN7Qol@413ooooooaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4Q
omgMg@06ooooo`03o`000?oooooooooo00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool000002_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooaOooooo003ooooooaCo
oooo00GoIVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRH
V?ooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool6o`0000cooooo00?o0000ooooooooool02_ooool01Olb<S;oV9RHoooooonHV9So
<S8b00Wooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003ooooo
ooooo`3ooooooaOooooo003ooooooa?ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMoooo
o`04ooooo`05o`000?ooooooooooooooool000000_ooool00olb<S;oQhN7ooooo`0:ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00[ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0003ooooooaCooooo003ooooooa?ooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`04o`000?ooooooooooooooo`Go00002Oooool00ol@413o0000o`000003
o`0000Gooooo00?o0000ooooooooool02Oooool00ol@413o0000o`000003o`0001cooooo00?o0000
ooooooooool02_ooool01Ol@413o^[Zjoooooonj^[[o410@00Wooooo00KoZJVYob4Q8Ol0003o0000
oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0
003oA4A4o`000?oooooo5?ooool00?oooooo7oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`00003ooooooc?ooooo003ooooooaoooooo0_l0
000Booooo`03o`000?oooooooooo00Gooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?o
EEEEofIVI_l000003?ooool01OnYZJWo410@o`000?l@413oZJVY0?oooooo<oooool00?oooooooooo
oon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.85) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49174 0 m
.49171 .00099 L
.4917 .00147 L
.4917 .0017 L
.49169 .00192 L
.49169 .00217 L
.49169 .00245 L
.4917 .00268 L
.4917 .00293 L
.4917 .0032 L
.4917 .00345 L
.4917 .00372 L
.4917 .00388 L
.4917 .00402 L
.49169 .00452 L
.49169 .00479 L
.49169 .00505 L
.49169 .0052 L
.49169 .00536 L
.49169 .00564 L
.49169 .00578 L
.49169 .00593 L
.49169 .00619 L
.49169 .00666 L
.49169 .00692 L
.49169 .00717 L
.49169 .00731 L
.4917 .00746 L
.4917 .00773 L
.49169 .008 L
.49169 .00825 L
.49169 .00925 L
.49168 .00952 L
.49168 .00967 L
.49168 .00981 L
.49168 .01006 L
.49168 .01032 L
.49168 .01048 L
.49168 .01062 L
.49168 .0109 L
.49168 .01105 L
.49168 .01119 L
.49169 .01151 L
.49169 .01208 L
.49169 .01236 L
.49169 .01261 L
.49169 .01286 L
.49169 .01313 L
.49169 .01328 L
.4917 .01342 L
Mistroke
.4917 .01369 L
.4917 .01384 L
.4917 .01399 L
.49169 .01426 L
.49169 .01441 L
.49169 .01455 L
.49169 .01487 L
.49169 .01516 L
.49169 .01547 L
.49169 .01562 L
.49169 .01576 L
.49169 .01603 L
.49169 .01631 L
.49169 .01646 L
.49169 .01661 L
.49169 .01676 L
.49169 .01692 L
.49169 .01725 L
.4917 .01775 L
.4917 .0183 L
.49171 .01941 L
.49172 .02139 L
.49172 .02259 L
.49173 .02318 L
.49173 .02373 L
.49173 .02422 L
.49173 .02474 L
.49174 .02585 L
.4918 .03004 L
.49182 .0322 L
.49184 .03339 L
.49186 .03452 L
.49191 .03671 L
.49196 .03871 L
.49208 .04262 L
.49216 .04468 L
.49227 .04687 L
.49253 .0508 L
.49324 .05886 L
.49344 .06103 L
.49362 .06333 L
.49369 .06428 L
.49374 .06529 L
.49376 .06587 L
.49378 .0664 L
.49379 .06666 L
.49379 .06693 L
.4938 .06719 L
.4938 .06743 L
.49381 .06768 L
Mistroke
.49381 .06795 L
.49381 .06819 L
.49381 .06843 L
.49381 .0687 L
.4938 .06895 L
.4938 .06923 L
.49379 .06952 L
.49378 .07012 L
.49376 .07068 L
.49371 .07173 L
.49364 .07272 L
.49357 .07363 L
.49336 .07569 L
.4928 .07971 L
.49207 .08413 L
.49072 .09276 L
.4897 .10108 L
.48883 .10991 L
.4881 .11843 L
.48745 .12662 L
.4868 .13533 L
.48617 .14372 L
.48558 .15179 L
.48495 .16038 L
.48433 .16864 L
.48367 .17743 L
.483 .1859 L
.48234 .19404 L
.48163 .20271 L
.4809 .21105 L
.48009 .21992 L
.47928 .22846 L
.47845 .23668 L
.47751 .24542 L
.47656 .25384 L
.47558 .26194 L
.47445 .27056 L
.47329 .27885 L
.47196 .28767 L
.47056 .29617 L
.46908 .30434 L
.46736 .31304 L
.46553 .32141 L
.46333 .3303 L
.46094 .33888 L
.45833 .34712 L
.45511 .3559 L
.45143 .36434 L
.44719 .37247 L
.44156 .38112 L
Mistroke
.43452 .38944 L
.42458 .39829 L
.41219 .40681 L
.39826 .41502 L
.39112 .41917 L
.38393 .42374 L
.38109 .42583 L
.37848 .42808 L
.37652 .4302 L
.37579 .43122 L
.37524 .43214 L
.37479 .43316 L
.3746 .43372 L
.37454 .43397 L
.37447 .43424 L
.37443 .43448 L
.3744 .43473 L
.37437 .43496 L
.37436 .43518 L
.37435 .43544 L
.37435 .43567 L
.37437 .43594 L
.37439 .43619 L
.37443 .43645 L
.37448 .43673 L
.37463 .43729 L
.37482 .43782 L
.37504 .43831 L
.3757 .43942 L
.37667 .44062 L
.37894 .44266 L
.38231 .4449 L
.39181 .4494 L
.40348 .45359 L
.41817 .45806 L
.44967 .46692 L
.4643 .47136 L
.47596 .47546 L
.48512 .47945 L
.48888 .48148 L
.49223 .48367 L
.49488 .48585 L
.49674 .48785 L
.49745 .48881 L
.4981 .48985 L
.49858 .49077 L
.499 .49176 L
.49935 .49284 L
.4996 .49385 L
.4997 .49433 L
Mistroke
.49978 .49484 L
.49984 .49532 L
.49989 .49575 L
.49993 .49626 L
.49995 .49652 L
.49996 .4968 L
.49997 .49706 L
.49998 .4973 L
.49999 .49753 L
.5 .49778 L
.5 .49804 L
.5 .49829 L
.50001 .49843 L
.50001 .49858 L
.50001 .49886 L
.50001 .49899 L
.50001 .49914 L
.5 .4994 L
.5 .49972 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo
00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_oo
ool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooo
ooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
D_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooo
oomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0
003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00
oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003ooooooooo
o`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBoooo
o`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[o
oooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oo
oooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooo
oe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?oo
ooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o
0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool0
0?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooooooo
ool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_oo
ool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomI
ooooo`00oooooomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003o
ooooooooo`3ooooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooo
oomCooooo`03o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3o
oooooeWooooo003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03
o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo
003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooo
oooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe?o
oooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooooooo0?oooooo
FOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe;ooooo00?o0000
ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oo
ooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0
oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool0
0ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJoooo
o`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooo
ooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomA
ooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooo
oe_ooooo003ooooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`00
0?oooooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003o
oooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo
0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo
00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?oo
ool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000oooo
ooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?oooooo
Coooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooo
oomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0
003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00
oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003ooooooooo
o`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?oooo
o`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooego
oooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oo
oooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003ooooo
odoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?oo
ooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodkooooo00?o
0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool0
0?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000oooooooo
ool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_oo
ool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomN
ooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003o
ooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooo
oom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooCOooool00ol0003oooooooooo`3o
oooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03
o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo
003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooo
oooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgo
oooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?oooooo
Goooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000
ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oo
ooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0
oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool0
0ol0003oooooooooo`3ooooooeoooooo003oooooodcooooo00?o0000ooooooooool0oooooomPoooo
o`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003ooooo
ooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<
ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3ooooo
of3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`00
0?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003o
ooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo
0?ooooooH?ooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo
00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOoo
ool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000oooo
ooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?oooooo
Boooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooo
oomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0
003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00
oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003ooooooooo
o`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:oooo
o`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;o
oooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oo
oooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooo
od[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oo
ooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003oooooodWooooo00?o
0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool0
0?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000oooooooo
ool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOoo
ool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomS
ooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003o
ooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooo
oom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3o
ooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03
o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo
003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooooom7ooooo`03o`000?oooooo
oooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOo
oooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000
ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?oo
ooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0
oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?ooooooA_ooool0
0ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVoooo
o`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003ooooo
ooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom6
ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooAOooool00ol0003oooooooooo`3ooooo
ofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`00
0?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003o
ooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom4ooooo`03o`000?oooooooooo
0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003oooooodCooooo
00?o0000ooooooooool0oooooomXooooo`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?oo
ool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003oooooodCooooo00?o0000oooo
ooooool0oooooomXooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo
@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood?ooooo00?o0000ooooooooool0oooo
oomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0
003oooooooooo`3oooooofWooooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00
oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003ooooooooo
o`3oooooof[ooooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2oooo
o`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[o
oooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oo
oooooooo0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooo
od7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?oo
ooooJoooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o
0000ooooooooool0oooooom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool0
0?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003oooooocoooooo00?o0000oooooooo
ool0oooooom]ooooo`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool00?oooooo?ooo
ool00ol0003oooooooooo`3oooooofgooooo003oooooockooooo00?o0000ooooooooool0oooooom^
ooooo`00oooooolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_ooool00ol0003o
ooooooooo`3oooooofkooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooo
oolmooooo`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003oooooooooo`3o
ooooofoooooo003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooollooooo`03
o`000?oooooooooo0?ooooooL?ooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo
003ooooooc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkooooo`03o`000?oooooo
oooo0?ooooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003ooooooc[o
oooo00?o0000ooooooooool0oooooombooooo`00ooooooljooooo`03o`000?oooooooooo0?oooooo
L_ooool00?oooooo>Oooool00ol0003oooooooooo`3oooooog?ooooo003oooooocWooooo00?o0000
ooooooooool0oooooomcooooo`00ooooooliooooo`03o`000?oooooooooo0?ooooooLoooool00?oo
oooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocSooooo00?o0000ooooooooool0
oooooomdooooo`00oooooolgooooo`03o`000?oooooooooo0?ooooooMOooool00?oooooo=_ooool0
0ol0003oooooooooo`3oooooogKooooo003oooooocKooooo00?o0000ooooooooool0oooooomfoooo
o`00ooooooleooooo`03o`000?oooooooooo0?ooooooMoooool00?oooooo=Oooool00ol0003ooooo
ooooo`3oooooogOooooo003oooooocCooooo00?o0000ooooooooool0oooooomhooooo`00oooooold
ooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo<oooool00ol0003oooooooooo`3ooooo
ogWooooo003ooooooc?ooooo00?o0000ooooooooool0oooooomiooooo`00oooooolbooooo`03o`00
0?oooooooooo0?ooooooN_ooool00?oooooo<Oooool00ol0003oooooooooo`3oooooog_ooooo003o
oooooc3ooooo00?o0000ooooooooool0oooooomlooooo`00ooooool_ooooo`03o`000?oooooooooo
0?ooooooOOooool00?oooooo;_ooool00ol0003oooooooooo`3oooooogkooooo003oooooobgooooo
00?o0000ooooooooool0oooooomoooooo`00ooooool/ooooo`03o`000?oooooooooo0?ooooooP?oo
ool00?oooooo:oooool00ol0003oooooooooo`3ooooooh7ooooo003oooooob[ooooo00?o0000oooo
ooooool0oooooon2ooooo`00oooooolYooooo`03o`000?oooooooooo0?ooooooPoooool00?oooooo
:?ooool00ol0003oooooooooo`3oooooohCooooo003oooooobKooooo0_l0003oooooohOooooo003o
ooooobGooooo00?o0000ooooooooool0oooooon7ooooo`00oooooolSooooo`;o0000oooooon:oooo
o`00oooooolQooooo`;o0000oooooon<ooooo`00oooooolPooooo`03o`000?oooooooooo0?oooooo
S?ooool00?oooooo7_ooool2o`000?ooooooSoooool00?oooooo7?ooool2o`000?ooooooTOooool0
0?oooooo6_ooool2o`000?ooooooToooool00?oooooo6Oooool00ol0003oooooooooo`3ooooooi?o
oooo003ooooooaOooooo0_l0003ooooooiKooooo003ooooooaGooooo0_l0003ooooooiSooooo003o
oooooaCooooo00?o0000ooooooooool0oooooonHooooo`00oooooolCooooo`03o`000?oooooooooo
0?ooooooVOooool00?oooooo4Oooool2o`000?ooooooW?ooool00?oooooo3oooool2o`000?oooooo
W_ooool00?oooooo3_ooool00ol0003oooooooooo`3ooooooikooooo003oooooo`cooooo0_l0003o
oooooj7ooooo003oooooo`_ooooo00?o0000ooooooooool0oooooonQooooo`00ooooool:ooooo`03
o`000?oooooooooo0?ooooooX_ooool00?oooooo2Oooool00ol0003oooooooooo`3ooooooj?ooooo
003oooooo`Sooooo00?o0000ooooooooool0oooooonTooooo`00ooooool7ooooo`;o0000oooooonV
ooooo`00ooooool7ooooo`03o`000?oooooooooo0?ooooooYOooool00?oooooo1oooool00ol0003o
ooooooooo`3oooooojGooooo003oooooo`Oooooo00?o0000ooooooooool0oooooonUooooo`00oooo
ool7ooooo`03o`000?oooooooooo0?ooooooYOooool00?oooooo2?ooool00ol0003oooooooooo`3o
ooooojCooooo003oooooo`Sooooo0_l0003oooooojGooooo003oooooo`[ooooo0_l0003ooooooj?o
oooo003oooooo`cooooo0_l0003ooooooj7ooooo003oooooo`kooooo0_l0003ooooooioooooo003o
oooooa3ooooo0_l0003ooooooigooooo003ooooooa;ooooo0_l0003ooooooi_ooooo003ooooooaCo
oooo0ol0003ooooooiSooooo003ooooooaOooooo0_l0003ooooooiKooooo003ooooooaWooooo0ol0
003ooooooi?ooooo003ooooooacooooo0ol0003ooooooi3ooooo003ooooooaoooooo0ol0003ooooo
ohgooooo003oooooob;ooooo1?l0003oooooohWooooo003oooooobKooooo1?l0003oooooohGooooo
003oooooob[ooooo1?l0003ooooooh7ooooo003oooooobkooooo1?l0003ooooooggooooo003ooooo
oc;ooooo1?l0003oooooogWooooo003oooooocKooooo1?l0003oooooogGooooo003ooooooc[ooooo
0ol0003oooooog;ooooo003oooooocgooooo0ol0003oooooofoooooo003ooooood3ooooo0_l0003o
ooooofgooooo003ooooood;ooooo0ol0003oooooof[ooooo003oooooodGooooo0ol0003oooooofOo
oooo003oooooodSooooo0_l0003oooooofGooooo003ooooood[ooooo0ol0003oooooof;ooooo003o
ooooodgooooo0_l0003oooooof3ooooo003oooooodoooooo00?o0000ooooooooool0oooooomMoooo
o`00oooooom@ooooo`;o0000oooooomMooooo`00oooooomBooooo`;o0000oooooomKooooo`00oooo
oomDooooo`03o`000?oooooooooo0?ooooooF?ooool00?ooooooE?ooool00ol0003oooooooooo`3o
oooooeSooooo003ooooooeGooooo00?o0000ooooooooool0oooooomGooooo`00oooooomFooooo`03
o`000?oooooooooo0?ooooooE_ooool00?ooooooE_ooool00ol0003oooooooooo`3ooooooeKooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooo
oooo0?ooooooEOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooeOo
oooo00?o0000ooooooooool0oooooomEooooo`00oooooomGooooo`03o`000?oooooooooo0?oooooo
EOooool00?ooooooEoooool00ol0003oooooooooo`3ooooooeGooooo003ooooooooooooo[oooool0
0?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooo
oon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooool@ooooo`?o000000?o410@ooooooooool0oooooonIooooo`00oooooolBooooo`03oa0@4?nj
^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj
^[[ooooo0?ooooooKOooool00?oooooo4_ooool00onHV9So<S8booooo`06ooooo`03o`000?oooooo
oooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S;oooooofkooooo003ooooo
oa;ooooo00?ogMgMo`000?nj^[X01_ooool00ol0003oooooooooo`02ooooo`Go00000oooool00on7
QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04
ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Iooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd02?ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0ooooool@ooooo`00
oooooolBooooo`03oeEEEOmgMgOoA4A400Kooooo00?o0000ooooooooool00_ooool2ogMgM`;ooooo
00Oo0000ooooooooooooooooolc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003
ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l0000<ooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05ob4Q8OnH
V9SooooooiRHV?lQ8B401oooool00omgMgOo<S8booooo`07ooooo`06o`000?nYZJWooooooooooonj
^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooooooooooo
ohN7Qol@413ooooooa3ooooo003ooooooa7ooooo00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03
o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`07ooooo`05okZj^_n7QhOoIVIV
ofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool0
0?oooooo4Oooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool01?ooool0
0omEEEGoV9RHooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`Ko00003?ooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801oooool00omgMgOo<S8booooo`07ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolCooooo`00ooooool@ooooo`03onk^
k_l0003ok^k^00;ooooo00?o0000omgMgOooool00oooool00ol0003oooooooooo`02ooooo`05o`00
0?oooooooooooc8b<_n7QhL02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05olc<c?l0003o0000o`00
0?o<c<`01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Sooooo00Ko0000okZj^_ooooook^k^ogMg
Mol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooooooo
QhN7o`000?oooooo4?ooool00?oooooo4?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool5o`0000Wooooo00?o410@o`000?l000000ol0
0004ooooo`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000Looooo`03o`000?oo
oooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03o`000?oooooooooo00[ooooo
00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_oo
ool01_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo4?ooool00?oooooo6oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03
o`000?oooooooooo0?oooooo<?ooool00?oooooo6oooool2o`0001?ooooo00?o0000ooooooooool0
1?ooool2o`0000gooooo00?o0000ooooooooool06oooool00omEEEGoIVIVo`00000<ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01?ooool4o`000?oooooo;oooool00?oooooooooooon_ooooo`00oooo
ooooooooojoooooo003ooooooooooooo[oooool00001\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -56 0 ]
[.5 .5125 56 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -117 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.9) show
153.000 13.000 moveto
(sec) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49158 0 m
.49155 .00099 L
.49154 .00147 L
.49153 .0017 L
.49153 .00192 L
.49153 .00217 L
.49153 .00245 L
.49153 .00268 L
.49153 .00293 L
.49153 .0032 L
.49153 .00345 L
.49153 .00372 L
.49153 .00388 L
.49153 .00402 L
.49152 .00452 L
.49151 .00479 L
.49151 .00505 L
.49151 .0052 L
.49151 .00536 L
.4915 .00564 L
.4915 .00578 L
.4915 .00593 L
.4915 .00619 L
.4915 .00643 L
.4915 .0067 L
.4915 .00694 L
.4915 .00717 L
.4915 .00744 L
.4915 .00759 L
.4915 .00773 L
.4915 .00798 L
.4915 .00825 L
.49148 .00931 L
.49148 .00987 L
.49147 .01015 L
.49147 .01046 L
.49147 .01073 L
.49147 .01088 L
.49147 .01102 L
.49147 .01128 L
.49147 .01154 L
.49147 .01201 L
.49147 .01228 L
.49147 .01253 L
.49147 .0128 L
.49147 .01296 L
.49147 .0131 L
.49146 .01371 L
.49146 .01426 L
.49145 .01479 L
Mistroke
.49145 .01546 L
.49144 .01608 L
.49144 .01664 L
.49144 .01696 L
.49143 .01725 L
.49143 .01748 L
.49143 .01773 L
.49143 .018 L
.49143 .01825 L
.49143 .0188 L
.49143 .0193 L
.49143 .01958 L
.49143 .01984 L
.49143 .02012 L
.49143 .02042 L
.49143 .02093 L
.49142 .02149 L
.49141 .0234 L
.49141 .02387 L
.49141 .02437 L
.4914 .02465 L
.4914 .02491 L
.4914 .02516 L
.4914 .02542 L
.4914 .02569 L
.4914 .02595 L
.4914 .02623 L
.4914 .02638 L
.4914 .02653 L
.4914 .02679 L
.4914 .02704 L
.4914 .02758 L
.4914 .02781 L
.4914 .02806 L
.4914 .02834 L
.4914 .02859 L
.4914 .02883 L
.4914 .02905 L
.4914 .02929 L
.4914 .02956 L
.4914 .02984 L
.4914 .0301 L
.4914 .03069 L
.4914 .03188 L
.49139 .03241 L
.49139 .03291 L
.49139 .03319 L
.49139 .03349 L
.49139 .03376 L
.49139 .03401 L
Mistroke
.49139 .03428 L
.49139 .03453 L
.49139 .03476 L
.49139 .03501 L
.49139 .03528 L
.49139 .03557 L
.49139 .03608 L
.4914 .0371 L
.4914 .03802 L
.49141 .04031 L
.49142 .04242 L
.49142 .04346 L
.49143 .04442 L
.49144 .04543 L
.49145 .04654 L
.49147 .04868 L
.49151 .05098 L
.49154 .05316 L
.49159 .05552 L
.49164 .05775 L
.4917 .05982 L
.49187 .06381 L
.49211 .06821 L
.49242 .07269 L
.49272 .0768 L
.49287 .07889 L
.49297 .08083 L
.49302 .08189 L
.49306 .08285 L
.49307 .0834 L
.49308 .08392 L
.49309 .08419 L
.49309 .08447 L
.49309 .08462 L
.49309 .08478 L
.4931 .08492 L
.4931 .08507 L
.4931 .08534 L
.4931 .0856 L
.4931 .08576 L
.4931 .0859 L
.4931 .08618 L
.49309 .08645 L
.49309 .08669 L
.49308 .08724 L
.49307 .0877 L
.49305 .0882 L
.49301 .08922 L
.49296 .09034 L
.49288 .09153 L
Mistroke
.49269 .09369 L
.49215 .09823 L
.49153 .10253 L
.49034 .11073 L
.48928 .11946 L
.48845 .12786 L
.48775 .13594 L
.48705 .14454 L
.48641 .15282 L
.48574 .16162 L
.4851 .1701 L
.48448 .17825 L
.48381 .18693 L
.48314 .19528 L
.48242 .20416 L
.48169 .21271 L
.48096 .22094 L
.48016 .2297 L
.47934 .23813 L
.47851 .24623 L
.47759 .25486 L
.47663 .26317 L
.47554 .272 L
.47443 .28051 L
.47328 .28869 L
.47194 .2974 L
.47055 .30578 L
.4691 .31384 L
.46741 .32242 L
.46559 .33068 L
.46346 .33947 L
.46116 .34792 L
.45866 .35606 L
.45561 .36472 L
.45221 .37306 L
.44795 .38192 L
.44296 .39045 L
.43705 .39866 L
.42913 .4074 L
.41935 .41581 L
.40745 .4239 L
.39185 .43251 L
.37463 .4408 L
.3563 .44961 L
.34853 .45402 L
.34541 .45616 L
.34308 .4581 L
.34211 .45908 L
.34124 .46014 L
.34058 .46114 L
Mistroke
.34014 .46206 L
.33997 .46256 L
.3399 .4628 L
.33985 .46303 L
.33981 .4633 L
.33978 .46355 L
.33976 .46382 L
.33976 .46397 L
.33976 .46411 L
.33977 .46436 L
.33979 .4646 L
.33984 .46487 L
.3399 .46515 L
.33998 .46544 L
.34008 .46574 L
.34032 .46627 L
.34064 .46682 L
.341 .46734 L
.34186 .46831 L
.34305 .46936 L
.34467 .47049 L
.34846 .47253 L
.35298 .47441 L
.366 .47843 L
.38559 .48284 L
.43771 .49146 L
.49821 .49976 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo
00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_oo
ool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooo
ooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
DOooool2o`000?ooooooG?ooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003o
oooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo
0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo
00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFooo
ool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooo
ooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oooooo
DOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooo
oomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003ooooooooo
o`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBoooo
o`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[o
oooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oo
oooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooo
oe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?oo
ooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o
0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool0
0?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooooooo
ool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_oo
ool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJ
ooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003o
ooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooo
oomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3o
oooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomCooooo`03
o`000?oooooooooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo
003ooooooe?ooooo00?o0000ooooooooool0oooooomIooooo`00oooooomCooooo`03o`000?oooooo
oooo0?ooooooFOooool00?ooooooDoooool00ol0003oooooooooo`3ooooooeWooooo003ooooooe;o
oooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?oooooo
F_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000
ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oo
ooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0
oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool0
0ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJoooo
o`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooDOooool00ol0003ooooo
ooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomA
ooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooo
oe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`00
0?oooooooooo0?ooooooFoooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003o
oooooe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo
0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo
00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?oo
ool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000oooo
ooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?oooooo
D?ooool00ol0003oooooooooo`3ooooooecooooo003oooooodoooooo00?o0000ooooooooool0oooo
oomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0
003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00
oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003ooooooooo
o`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?oooo
o`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooego
oooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oo
oooooooo0?ooooooGOooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003ooooo
odkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?oo
ooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o
0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool0
0?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000oooooooo
ool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?ooooooG_ooool00?ooooooC_oo
ool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomN
ooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003o
ooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooo
oom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3o
oooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03
o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo
003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooo
oooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgo
oooo00?o0000ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?oooooo
Goooool00?ooooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000
ooooooooool0oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oo
ooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0
oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool0
0ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPoooo
o`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003ooooo
ooooo`3oooooof3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<
ooooo`03o`000?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3ooooo
of3ooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom;ooooo`03o`00
0?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003o
oooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo
0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo
00?o0000ooooooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOoo
ool00?ooooooBoooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000oooo
ooooool0oooooomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?oooooo
Boooool00ol0003oooooooooo`3oooooof7ooooo003ooooood[ooooo00?o0000ooooooooool0oooo
oomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0
003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00
oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003ooooooooo
o`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:oooo
o`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;o
oooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oo
oooooooo0?ooooooH_ooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003ooooo
odWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?oo
ooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o
0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool0
0?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000oooooooo
ool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOoo
ool00ol0003oooooooooo`3oooooof?ooooo003oooooodSooooo00?o0000ooooooooool0oooooomT
ooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003o
ooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooo
oom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3o
ooooofCooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03
o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo
003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooo
oooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOo
oooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000
ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?oo
ooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0
oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool0
0ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVoooo
o`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003ooooo
ooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5
ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3ooooo
ofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom4ooooo`03o`00
0?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003o
ooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4ooooo`03o`000?oooooooooo
0?ooooooJ?ooool00?ooooooA?ooool00ol0003oooooooooo`3oooooofSooooo003ooooood?ooooo
00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOoo
ool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003ooooood?ooooo00?o0000oooo
ooooool0oooooomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo
@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood;ooooo00?o0000ooooooooool0oooo
oomZooooo`00oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0
003oooooooooo`3oooooof[ooooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00
oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@Oooool00ol0003ooooooooo
o`3oooooof_ooooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1oooo
o`03o`000?oooooooooo0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_o
oooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom0ooooo`03o`000?oo
oooooooo0?ooooooK?ooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooo
od3ooooo00?o0000ooooooooool0oooooom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?oo
ooooK?ooool00?oooooo?oooool00ol0003oooooooooo`3oooooofgooooo003oooooocoooooo00?o
0000ooooooooool0oooooom]ooooo`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool0
0?oooooo?_ooool00ol0003oooooooooo`3oooooofkooooo003oooooockooooo00?o0000oooooooo
ool0oooooom^ooooo`00oooooolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_oo
ool00ol0003oooooooooo`3oooooofkooooo003oooooocgooooo00?o0000ooooooooool0oooooom_
ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003o
ooooooooo`3oooooofoooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooo
oollooooo`03o`000?oooooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3o
ooooog3ooooo003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooooolkooooo`03
o`000?oooooooooo0?ooooooLOooool00?oooooo>oooool00ol0003oooooooooo`3oooooog7ooooo
003ooooooc[ooooo00?o0000ooooooooool0oooooombooooo`00ooooooljooooo`03o`000?oooooo
oooo0?ooooooL_ooool00?oooooo>Oooool00ol0003oooooooooo`3oooooog?ooooo003oooooocWo
oooo00?o0000ooooooooool0oooooomcooooo`00oooooolhooooo`03o`000?oooooooooo0?oooooo
M?ooool00?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o0000
ooooooooool0oooooomeooooo`00oooooolgooooo`03o`000?oooooooooo0?ooooooMOooool00?oo
oooo=oooool00ol0003oooooooooo`3oooooogGooooo003oooooocKooooo00?o0000ooooooooool0
oooooomfooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oooooo=Oooool0
0ol0003oooooooooo`3oooooogOooooo003oooooocGooooo00?o0000ooooooooool0oooooomgoooo
o`00ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo=?ooool00ol0003ooooo
ooooo`3oooooogSooooo003ooooooc?ooooo00?o0000ooooooooool0oooooomiooooo`00oooooolc
ooooo`03o`000?oooooooooo0?ooooooNOooool00?oooooo<_ooool00ol0003oooooooooo`3ooooo
og[ooooo003ooooooc7ooooo00?o0000ooooooooool0oooooomkooooo`00ooooool`ooooo`03o`00
0?oooooooooo0?ooooooO?ooool00?oooooo;oooool00ol0003oooooooooo`3ooooooggooooo003o
ooooobkooooo00?o0000ooooooooool0oooooomnooooo`00ooooool]ooooo`03o`000?oooooooooo
0?ooooooOoooool00?oooooo;?ooool00ol0003oooooooooo`3ooooooh3ooooo003oooooob_ooooo
00?o0000ooooooooool0oooooon1ooooo`00oooooolZooooo`03o`000?oooooooooo0?ooooooP_oo
ool00?oooooo:Oooool00ol0003oooooooooo`3ooooooh?ooooo003oooooobSooooo00?o0000oooo
ooooool0oooooon4ooooo`00oooooolWooooo`03o`000?oooooooooo0?ooooooQOooool00?oooooo
9_ooool00ol0003oooooooooo`3oooooohKooooo003oooooobGooooo00?o0000ooooooooool0oooo
oon7ooooo`00oooooolSooooo`;o0000oooooon:ooooo`00oooooolRooooo`03o`000?oooooooooo
0?ooooooR_ooool00?oooooo8?ooool2o`000?ooooooSOooool00?oooooo7_ooool2o`000?oooooo
Soooool00?oooooo7Oooool00ol0003oooooooooo`3oooooohoooooo003ooooooa_ooooo0_l0003o
oooooi;ooooo003ooooooaWooooo0_l0003ooooooiCooooo003ooooooaOooooo0_l0003ooooooiKo
oooo003ooooooaGooooo0_l0003ooooooiSooooo003ooooooa?ooooo0_l0003ooooooi[ooooo003o
oooooa7ooooo0_l0003ooooooicooooo003oooooo`oooooo0_l0003ooooooikooooo003oooooo`go
oooo0_l0003ooooooj3ooooo003oooooo`cooooo00?o0000ooooooooool0oooooonPooooo`00oooo
ool:ooooo`;o0000oooooonSooooo`00ooooool8ooooo`;o0000oooooonUooooo`00ooooool6oooo
o`;o0000oooooonWooooo`00ooooool3ooooo`?o0000oooooonYooooo`00ooooool1ooooo`;o0000
oooooon/ooooo`00o_ooool2o`000?oooooo[_ooool00?_ooooo0ol0003ooooook3ooooo003ioooo
o`;o0000ooooooncooooo`00moooool2o`000?oooooo]Oooool00?Kooooo00?o0000ooooooooool0
ooooooneooooo`00mOooool00ol0003oooooooooo`3ooooookKooooo003dooooo`03o`000?oooooo
oooo0?oooooo]oooool00??ooooo00?o0000ooooooooool0oooooonhooooo`00lOooool2o`000?oo
oooo^oooool00?7ooooo00?o0000ooooooooool0oooooonjooooo`00l?ooool00ol0003ooooooooo
o`3ooooook_ooooo003`ooooo`03o`000?oooooooooo0?oooooo^oooool00?3ooooo00?o0000oooo
ooooool0oooooonkooooo`00l?ooool00ol0003oooooooooo`3ooooook_ooooo003aooooo`03o`00
0?oooooooooo0?oooooo^_ooool00?;ooooo00?o0000ooooooooool0ooooooniooooo`00loooool2
o`000?oooooo^Oooool00?Gooooo0ol0003ooooookKooooo003hooooo`;o0000oooooondooooo`00
n_ooool3o`000?oooooo/Oooool00?gooooo0ol0003oooooojkooooo003oooooo`7ooooo0ol0003o
oooooj_ooooo003oooooo`Cooooo1Ol0003oooooojKooooo003oooooo`Wooooo1?l0003ooooooj;o
oooo003oooooo`gooooo1Ol0003ooooooigooooo003ooooooa;ooooo1ol0003ooooooiKooooo003o
oooooaWooooo1ol0003oooooohoooooo003oooooob3ooooo1_l0003oooooohWooooo003oooooobKo
oooo1ol0003ooooooh;ooooo003oooooobgooooo1ol0003oooooog_ooooo003oooooocCooooo2?l0
003oooooog?ooooo003ooooooccooooo2?l0003oooooof_ooooo003oooooodCooooo1ol0003ooooo
ofCooooo003ooooood_ooooo2?l0003ooooooecooooo003ooooooe?ooooo1?l0003ooooooeSooooo
003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooo
oooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[ooo
ool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo
4oooool3o`000003oa0@4?oooooooooo0?ooooooU_ooool00?oooooo5Oooool00ol@413o^[Zjoooo
o`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjoooo
o`3oooooof[ooooo003ooooooaGooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:
ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8boooooom[ooooo`00oooooolEoooo
o`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo1Ol00004ooooo`03ohN7Qol0003o
^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj01Wooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool01?l@413o0000odA4A?o<c<`:ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003o
A4A4olc<c03ooooooaCooooo003ooooooaGooooo00?oEEEEogMgMom4A4@01oooool01?l0003ooooo
ooooooooool2ogMgM`;ooooo00?o0000ooooooooool00_ooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00003?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q1_ooool00onHV9So410@omgMg@09ooooo`06o`000?nYZJWooooooooooonj^[[o0000
0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@
413ooooooaCooooo003ooooooaCooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oo
oooooooo00;ooooo00?oEEEEoiRHV?ooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomE
EEGooooo00Wooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolGooooo`00oooooolDooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1_ooool00ol0003oooooooooo`03ooooo`03oeEEEOnHV9Sooooo00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo1_l0000<ooooo`03o`00
0?oooooooooo00[ooooo00Goc<c<ob4Q8Ol0003oEEEEo`000009ooooo`06oc8b<_lQ8B7oMgMgogMg
Mon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0oooooolGooooo`00oooooolCoooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool01Ol0003ooooooooooooooooo
000000;ooooo00?o<S8bohN7Qoooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8On7QhOo
oooooiRHV?l000002Oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000oooooolDooooo`00oooo
oolCooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003ooooo
ooooooooool5o`0000Wooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo00Wo
oooo00?o410@o`000?l000000ol0000Looooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`000009ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooaCooooo003ooooo
oaoooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8OnHV9Sooooo
ogMgMomEEED0oooooolcooooo`00oooooolOooooo`;o00004_ooool00ol0003oooooooooo`05oooo
o`;o00003Oooool00ol0003oooooooooo`0Kooooo`03oeEEEOmVIVKo000000cooooo00Goc<c<oa0@
4?l0003o<S8bonk^kP3ooooooc?ooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00
ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -59 0 ]
[.5 .5125 59 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.95) show
159.000 13.000 moveto
(sec) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49137 0 m
.49127 .00825 L
.49118 .01725 L
.49109 .0257 L
.49102 .03383 L
.49095 .04248 L
.49092 .04647 L
.4909 .05081 L
.4909 .05317 L
.49089 .05421 L
.49089 .05536 L
.49089 .05643 L
.49089 .05695 L
.49088 .05744 L
.49088 .05771 L
.49088 .058 L
.49088 .05827 L
.49088 .05851 L
.49088 .05866 L
.49088 .0588 L
.49088 .05895 L
.49088 .0591 L
.49088 .05924 L
.49088 .05939 L
.49088 .05966 L
.49088 .05992 L
.49088 .06006 L
.49088 .0602 L
.49088 .06072 L
.49088 .06118 L
.49089 .06168 L
.49089 .06271 L
.49089 .06385 L
.4909 .06587 L
.49091 .06777 L
.49093 .06987 L
.49095 .07208 L
.49098 .07396 L
.49102 .07603 L
.49113 .08022 L
.49129 .08469 L
.49175 .09355 L
.49186 .09571 L
.49198 .098 L
.49205 .09995 L
.49209 .10105 L
.49211 .10209 L
.49212 .1026 L
.49213 .10287 L
.49213 .10315 L
Mistroke
.49213 .10343 L
.49213 .10368 L
.49214 .10393 L
.49214 .10416 L
.49214 .10439 L
.49214 .10463 L
.49214 .10484 L
.49214 .10507 L
.49213 .10531 L
.49213 .10558 L
.49213 .10605 L
.49212 .1066 L
.4921 .1072 L
.49207 .10828 L
.49203 .10933 L
.49197 .11031 L
.49184 .11237 L
.49167 .1143 L
.49119 .1187 L
.49006 .12698 L
.48891 .13577 L
.48796 .14425 L
.48717 .1524 L
.4864 .16107 L
.48568 .16942 L
.48493 .17829 L
.48421 .18684 L
.4835 .19507 L
.48273 .20382 L
.48195 .21224 L
.48118 .22035 L
.48032 .22897 L
.47945 .23727 L
.47846 .2461 L
.47744 .2546 L
.47639 .26278 L
.47519 .27148 L
.47393 .27986 L
.47261 .28792 L
.47107 .2965 L
.46942 .30475 L
.46745 .31353 L
.4653 .32199 L
.46292 .33012 L
.45997 .33877 L
.45656 .3471 L
.45206 .35596 L
.44654 .36449 L
.43972 .3727 L
.43048 .38143 L
Mistroke
.41974 .38984 L
.40867 .39792 L
.40298 .40242 L
.39865 .40653 L
.39697 .40856 L
.39624 .40964 L
.3956 .41078 L
.39512 .41188 L
.39494 .4124 L
.39481 .41287 L
.3947 .41335 L
.39466 .41361 L
.39462 .41387 L
.3946 .41411 L
.39459 .41432 L
.39458 .41456 L
.39458 .41482 L
.39459 .41508 L
.3946 .41522 L
.39461 .41536 L
.39464 .41564 L
.39469 .41595 L
.39481 .41649 L
.39496 .41699 L
.39517 .41754 L
.39546 .41814 L
.39622 .41936 L
.3971 .42043 L
.39827 .42158 L
.40097 .42365 L
.40467 .42584 L
.40969 .42822 L
.42135 .43252 L
.45341 .44126 L
.4891 .44968 L
.51983 .45778 L
.53194 .46193 L
.53725 .46425 L
.54119 .4664 L
.54417 .46856 L
.54534 .46971 L
.54583 .47029 L
.54627 .47092 L
.54662 .47153 L
.54687 .47208 L
.54705 .47261 L
.54712 .47288 L
.54718 .47318 L
.54722 .47344 L
.54724 .47369 L
Mistroke
.54725 .47397 L
.54724 .47423 L
.54723 .47448 L
.5472 .4747 L
.54716 .47495 L
.5471 .47522 L
.54694 .47575 L
.54674 .47626 L
.54623 .47722 L
.54549 .47826 L
.54447 .47939 L
.5421 .48141 L
.53933 .48329 L
.52195 .49165 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomA
ooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooo
oe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`00
0?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003o
oooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo
0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo
00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFooo
ool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooo
ooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oooooo
DOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooo
oomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooooooo
o`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAoooo
o`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_o
oooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oo
oooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooo
oe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oo
ooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o
0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool0
0?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooooooo
ool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOoo
ool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomK
ooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003o
ooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooo
oomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3o
oooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03
o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo
003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooo
oooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7o
oooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oooooo
Foooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000
ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oo
ooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0
oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool0
0ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKoooo
o`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003ooooo
ooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomB
ooooo`03o`000?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooo
oe[ooooo003ooooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`00
0?oooooooooo0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003o
oooooe;ooooo00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo
0?ooooooF_ooool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo
00?o0000ooooooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_oo
ool00?ooooooD_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe;ooooo00?o0000oooo
ooooool0oooooomJooooo`00oooooomBooooo`03o`000?oooooooooo0?ooooooF_ooool00?oooooo
D_ooool00ol0003oooooooooo`3ooooooe[ooooo003ooooooe7ooooo00?o0000ooooooooool0oooo
oomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooooooo
o`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAoooo
o`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_o
oooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooom@ooooo`03o`000?oo
oooooooo0?ooooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooo
oe3ooooo00?o0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?oo
ooooG?ooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o
0000ooooooooool0oooooomLooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool0
0?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000oooooooo
ool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCooo
ool00ol0003oooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomM
ooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003o
ooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooo
oom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooC_ooool00ol0003oooooooooo`3o
oooooekooooo003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03
o`000?oooooooooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo
003oooooodkooooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooo
oooo0?ooooooG_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodko
oooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?oooooo
G_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000
ooooooooool0oooooomNooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oo
ooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0
oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool0
0ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOoooo
o`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003ooooo
ooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=
ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooo
oeoooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`00
0?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003o
ooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo
0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo
00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?oo
ool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000oooo
ooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oooooo
Boooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooo
oomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0
003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00
oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003ooooooooo
o`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom;oooo
o`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0003oooooooooo`3oooooof7o
oooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00oooooom:ooooo`03o`000?oo
oooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooo
od[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oo
ooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o
0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool0
0?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooood[ooooo00?o0000oooooooo
ool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_oo
ool00ol0003oooooooooo`3oooooof;ooooo003oooooodWooooo00?o0000ooooooooool0oooooomS
ooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003o
ooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooo
oom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3o
ooooof?ooooo003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03
o`000?oooooooooo0?ooooooHoooool00?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo
003oooooodWooooo00?o0000ooooooooool0oooooomSooooo`00oooooom8ooooo`03o`000?oooooo
oooo0?ooooooI?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSo
oooo00?o0000ooooooooool0oooooomTooooo`00oooooom8ooooo`03o`000?oooooooooo0?oooooo
I?ooool00?ooooooB?ooool00ol0003oooooooooo`3oooooofCooooo003oooooodSooooo00?o0000
ooooooooool0oooooomTooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?oo
ooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOooooo00?o0000ooooooooool0
oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool0
0ol0003oooooooooo`3oooooofGooooo003oooooodKooooo00?o0000ooooooooool0oooooomVoooo
o`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooA_ooool00ol0003ooooo
ooooo`3oooooofKooooo003oooooodKooooo00?o0000ooooooooool0oooooomVooooo`00oooooom6
ooooo`03o`000?oooooooooo0?ooooooI_ooool00?ooooooAOooool00ol0003oooooooooo`3ooooo
ofOooooo003oooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`00
0?oooooooooo0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003o
ooooodGooooo00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo
0?ooooooIoooool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo
00?o0000ooooooooool0oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIooo
ool00?ooooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodCooooo00?o0000oooo
ooooool0oooooomXooooo`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo
A?ooool00ol0003oooooooooo`3oooooofSooooo003ooooood?ooooo00?o0000ooooooooool0oooo
oomYooooo`00oooooom3ooooo`03o`000?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0
003oooooooooo`3oooooofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00
oooooom2ooooo`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003ooooooooo
o`3oooooof[ooooo003ooooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2oooo
o`03o`000?oooooooooo0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[o
oooo003ooooood7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oo
oooooooo0?ooooooJoooool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooo
od7ooooo00?o0000ooooooooool0oooooom[ooooo`00oooooom0ooooo`03o`000?oooooooooo0?oo
ooooK?ooool00?oooooo@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o
0000ooooooooool0oooooom/ooooo`00ooooooloooooo`03o`000?oooooooooo0?ooooooKOooool0
0?oooooo?oooool00ol0003oooooooooo`3oooooofgooooo003oooooockooooo00?o0000oooooooo
ool0oooooom^ooooo`00oooooolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?_oo
ool00ol0003oooooooooo`3oooooofkooooo003oooooocgooooo00?o0000ooooooooool0oooooom_
ooooo`00oooooolmooooo`03o`000?oooooooooo0?ooooooKoooool00?oooooo?Oooool00ol0003o
ooooooooo`3oooooofoooooo003ooooooccooooo00?o0000ooooooooool0oooooom`ooooo`00oooo
oollooooo`03o`000?oooooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3o
ooooog3ooooo003ooooooc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkooooo`03
o`000?oooooooooo0?ooooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo
003ooooooc[ooooo00?o0000ooooooooool0oooooombooooo`00ooooooliooooo`03o`000?oooooo
oooo0?ooooooLoooool00?oooooo>Oooool00ol0003oooooooooo`3oooooog?ooooo003oooooocSo
oooo00?o0000ooooooooool0oooooomdooooo`00oooooolhooooo`03o`000?oooooooooo0?oooooo
M?ooool00?oooooo=oooool00ol0003oooooooooo`3oooooogGooooo003oooooocKooooo00?o0000
ooooooooool0oooooomfooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool00?oo
oooo=Oooool00ol0003oooooooooo`3oooooogOooooo003oooooocGooooo00?o0000ooooooooool0
oooooomgooooo`00ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo<oooool0
0ol0003oooooooooo`3oooooogWooooo003ooooooc;ooooo00?o0000ooooooooool0oooooomjoooo
o`00oooooolaooooo`03o`000?oooooooooo0?ooooooNoooool00?oooooo<?ooool00ol0003ooooo
ooooo`3oooooogcooooo003ooooooboooooo00?o0000ooooooooool0oooooommooooo`00ooooool^
ooooo`03o`000?oooooooooo0?ooooooO_ooool00?oooooo;Oooool00ol0003oooooooooo`3ooooo
ogoooooo003oooooobcooooo00?o0000ooooooooool0oooooon0ooooo`00oooooolZooooo`;o0000
oooooon3ooooo`00oooooolYooooo`03o`000?oooooooooo0?ooooooPoooool00?oooooo9oooool2
o`000?ooooooQ_ooool00?oooooo9_ooool00ol0003oooooooooo`3oooooohKooooo003oooooobGo
oooo00?o0000ooooooooool0oooooon7ooooo`00oooooolSooooo`;o0000oooooon:ooooo`00oooo
oolRooooo`03o`000?oooooooooo0?ooooooR_ooool00?oooooo8?ooool2o`000?ooooooSOooool0
0?oooooo7oooool00ol0003oooooooooo`3oooooohgooooo003ooooooakooooo00?o0000oooooooo
ool0oooooon>ooooo`00oooooolLooooo`;o0000oooooonAooooo`00oooooolKooooo`03o`000?oo
oooooooo0?ooooooTOooool00?oooooo6_ooool00ol0003oooooooooo`3ooooooi;ooooo003ooooo
oaWooooo00?o0000ooooooooool0oooooonCooooo`00oooooolHooooo`03o`000?oooooooooo0?oo
ooooU?ooool00?oooooo5oooool00ol0003oooooooooo`3ooooooiGooooo003ooooooaKooooo00?o
0000ooooooooool0oooooonFooooo`00oooooolEooooo`03o`000?oooooooooo0?ooooooUoooool0
0?oooooo5Oooool00ol0003oooooooooo`3ooooooiOooooo003ooooooaCooooo00?o0000oooooooo
ool0oooooonHooooo`00oooooolDooooo`03o`000?oooooooooo0?ooooooV?ooool00?oooooo5?oo
ool00ol0003oooooooooo`3ooooooiSooooo003ooooooaCooooo00?o0000ooooooooool0oooooonH
ooooo`00oooooolDooooo`03o`000?oooooooooo0?ooooooV?ooool00?oooooo5Oooool00ol0003o
ooooooooo`3ooooooiOooooo003ooooooaGooooo0_l0003ooooooiSooooo003ooooooaOooooo00?o
0000ooooooooool0oooooonEooooo`00oooooolHooooo`;o0000oooooonEooooo`00oooooolJoooo
o`;o0000oooooonCooooo`00oooooolLooooo`03o`000?oooooooooo0?ooooooT?ooool00?oooooo
7Oooool3o`000?ooooooSoooool00?oooooo8?ooool4o`000?ooooooRoooool00?oooooo9?ooool4
o`000?ooooooQoooool00?oooooo:?ooool3o`000?ooooooQ?ooool00?oooooo:oooool3o`000?oo
ooooPOooool00?oooooo;_ooool4o`000?ooooooOOooool00?oooooo<_ooool3o`000?ooooooN_oo
ool00?oooooo=Oooool3o`000?ooooooMoooool00?oooooo>?ooool4o`000?ooooooLoooool00?oo
oooo??ooool5o`000?ooooooK_ooool00?oooooo@Oooool5o`000?ooooooJOooool00?ooooooA_oo
ool4o`000?ooooooIOooool00?ooooooB_ooool5o`000?ooooooH?ooool00?ooooooCoooool4o`00
0?ooooooG?ooool00?ooooooDoooool3o`000?ooooooFOooool00?ooooooE_ooool3o`000?oooooo
E_ooool00?ooooooFOooool4o`000?ooooooD_ooool00?ooooooGOooool3o`000?ooooooCoooool0
0?ooooooH?ooool3o`000?ooooooC?ooool00?ooooooHoooool4o`000?ooooooB?ooool00?oooooo
Ioooool3o`000?ooooooAOooool00?ooooooJ_ooool3o`000?oooooo@_ooool00?ooooooKOooool2
o`000?oooooo@?ooool00?ooooooKoooool2o`000?oooooo?_ooool00?ooooooLOooool2o`000?oo
oooo??ooool00?ooooooLoooool00ol0003oooooooooo`3oooooocWooooo003oooooogCooooo00?o
0000ooooooooool0oooooolhooooo`00oooooomdooooo`;o0000ooooooliooooo`00oooooomeoooo
o`03o`000?oooooooooo0?oooooo=oooool00?ooooooMOooool00ol0003oooooooooo`3oooooocOo
oooo003oooooogGooooo00?o0000ooooooooool0oooooolgooooo`00oooooomdooooo`03o`000?oo
oooooooo0?oooooo>?ooool00?ooooooLoooool2o`000?oooooo>_ooool00?ooooooLoooool00ol0
003oooooooooo`3oooooocWooooo003oooooog7ooooo0_l0003ooooooccooooo003oooooofoooooo
0_l0003oooooockooooo003oooooofgooooo0_l0003ooooood3ooooo003oooooof[ooooo0ol0003o
oooood;ooooo003oooooofSooooo0_l0003oooooodGooooo003oooooofKooooo0_l0003oooooodOo
oooo003oooooofCooooo0_l0003oooooodWooooo003oooooof7ooooo0ol0003ooooood_ooooo003o
oooooeoooooo0_l0003oooooodkooooo003ooooooegooooo0_l0003ooooooe3ooooo003ooooooe[o
oooo0ol0003ooooooe;ooooo003ooooooeSooooo0_l0003ooooooeGooooo003ooooooeOooooo00?o
0000ooooooooool0oooooomEooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oo
oooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_
ooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool00?oooooo4?ooool3o`000003oa0@
4?oooooooooo0?ooooooVOooool00?oooooo4_ooool00ol@413o^[Zjooooo`06ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`3oooooofgooooo003o
oooooa;ooooo00?oV9RHoc8b<_ooool01_ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool0
0ol0003oooooooooo`04ooooo`;o<S8boooooom^ooooo`00oooooolBooooo`03omgMgOl0003o^[Zj
00Kooooo00?o0000ooooooooool00_ooool5o`0000?ooooo00?oQhN7o`000?nj^[X01Oooool01OnH
V9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P04
ooooo`05oiRHV?l0003o0000odA4A?nj^[X06Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B44ooooo`04oa0@4?l0003oA4A4olc<c0Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`06
oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo
00GoIVIVo`000?l0003oA4A4olc<c03ooooooa3ooooo003ooooooa;ooooo00?oEEEEogMgMom4A4@0
1_ooool00ol0003oooooooooo`02ooooo`;oMgMg0_ooool01ol0003oooooooooooooooooc<c<o`00
0?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool0
0oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000cooooo00?o
0000ooooooooool01?ooool2ob4Q8@Kooooo00?oV9RHoa0@4?oMgMd01oooool00omgMgOo<S8boooo
o`07ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413ooooooa3ooooo003ooooooa7ooooo00Go
gMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool0
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0=ooooo`03ohN7QomEEEGooooo00Oooooo00?o0000ooooooooool0
1oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3ooooooa?ooooo003ooooooa7ooooo00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03
o`000?oooooooooo00Cooooo00?oEEEEoiRHV?ooool02oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000cooooo00?o0000oooooooo
ool02_ooool01Oo<c<co8B4Qo`000?mEEEGo000000Oooooo00?oMgMgoc8b<_ooool01oooool01_lb
<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0?oooooo4ooo
ool00?oooooo4?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooolb<S;oQhN700_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_oo
ool01OlQ8B7oQhN7oooooonHV9So000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`06
o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo
00KoIVIVogMgMoooooooooooohN7Qol0003ooooooa3ooooo003ooooooa3ooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1Ol00009oooo
o`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`09ooooo`03oa0@4?l0003o0000
00?o00007?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0:ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003ooooooa3ooooo003o
oooooa_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`05ob4Q8OnHV9So
ooooogMgMomEEED01?ooool00ol0003oooooooooo`3ooooooc3ooooo003ooooooa_ooooo0_l0000C
ooooo`03o`000?oooooooooo00Cooooo0_l0000=ooooo`03o`000?oooooooooo01_ooooo00?oEEEE
ofIVI_l000003?ooool01Oo<c<co410@o`000?lb<S;ok^k^00Cooooo1?l0003ooooooboooooo003o
oooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo0000\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[.5 .5125 -53 0 ]
[.5 .5125 53 12 ]
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .5125 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
147.000 13.000 moveto
(sec) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.49111 0 m
.49101 .00825 L
.49088 .01725 L
.49075 .0257 L
.49063 .03383 L
.4905 .04248 L
.49038 .05081 L
.49027 .05966 L
.49016 .06818 L
.49007 .07639 L
.49005 .07858 L
.49004 .08062 L
.49003 .08276 L
.49002 .0839 L
.49002 .08512 L
.49001 .08566 L
.49001 .08623 L
.49001 .08673 L
.49001 .08727 L
.49001 .0876 L
.49001 .08791 L
.49001 .0882 L
.49001 .08835 L
.49001 .08851 L
.49001 .08879 L
.49001 .08895 L
.49001 .08909 L
.49001 .08937 L
.49001 .08963 L
.49001 .08987 L
.49001 .09015 L
.49001 .09043 L
.49001 .0907 L
.49001 .09117 L
.49001 .09168 L
.49002 .09225 L
.49002 .09285 L
.49002 .09392 L
.49003 .09499 L
.49004 .09596 L
.49006 .09814 L
.49009 .10015 L
.49013 .10206 L
.49024 .10633 L
.49037 .11027 L
.49052 .11462 L
.49059 .11675 L
.49065 .11869 L
.49067 .11964 L
.4907 .12069 L
Mistroke
.49072 .12167 L
.49072 .12211 L
.49073 .12259 L
.49073 .12287 L
.49073 .12314 L
.49074 .12338 L
.49074 .12365 L
.49074 .1239 L
.49074 .12412 L
.49074 .12436 L
.49074 .12462 L
.49074 .1249 L
.49074 .12505 L
.49074 .1252 L
.49073 .12547 L
.49073 .12575 L
.49073 .12624 L
.49072 .12678 L
.49069 .12783 L
.49066 .12894 L
.49057 .13092 L
.49045 .13305 L
.49026 .13538 L
.48984 .13957 L
.48929 .14405 L
.48807 .15292 L
.48693 .16147 L
.48597 .1697 L
.48501 .17845 L
.48412 .18687 L
.48328 .19498 L
.48234 .2036 L
.48142 .2119 L
.48039 .22073 L
.47932 .22923 L
.47823 .23741 L
.47698 .24611 L
.47565 .25449 L
.47424 .26255 L
.47259 .27113 L
.47078 .27938 L
.46857 .28816 L
.46608 .29662 L
.46324 .30475 L
.4595 .3134 L
.45492 .32173 L
.44853 .33059 L
.44036 .33912 L
.43043 .34733 L
.41836 .35606 L
Mistroke
.41249 .3604 L
.40766 .36447 L
.40568 .36647 L
.40414 .36837 L
.40345 .36941 L
.40284 .37055 L
.40262 .37106 L
.40243 .37159 L
.4023 .37205 L
.40218 .37255 L
.40214 .37284 L
.4021 .37311 L
.40209 .37326 L
.40208 .37339 L
.40207 .37355 L
.40207 .3737 L
.40207 .37396 L
.40208 .3742 L
.4021 .37447 L
.40212 .3746 L
.40214 .37475 L
.4022 .37506 L
.40226 .37534 L
.40246 .37598 L
.40269 .37654 L
.40299 .37713 L
.40371 .3782 L
.40457 .37919 L
.40724 .38144 L
.41095 .38369 L
.41544 .38581 L
.42638 .38978 L
.45831 .398 L
.49999 .40674 L
.5377 .41516 L
.55281 .41939 L
.56346 .42326 L
.56794 .42539 L
.57126 .42741 L
.57261 .42845 L
.57379 .42955 L
.5748 .43076 L
.57547 .43188 L
.57571 .43244 L
.57582 .43274 L
.5759 .43303 L
.57597 .43329 L
.57601 .43353 L
.57605 .4338 L
.57607 .43394 L
Mistroke
.57608 .43408 L
.57609 .43422 L
.5761 .43437 L
.5761 .43453 L
.57609 .43467 L
.57608 .43494 L
.57607 .43509 L
.57605 .43522 L
.576 .43553 L
.57594 .43586 L
.57577 .43646 L
.57556 .43703 L
.57532 .43754 L
.57466 .4387 L
.57301 .44077 L
.5708 .44291 L
.56837 .44488 L
.56192 .44933 L
.54814 .45776 L
.53549 .46586 L
.52406 .47449 L
.51501 .4828 L
.50691 .49163 L
.5 .5 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{548.75, 274.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:]0001ER000`400?l00000o`00003ooooooomA
ooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooo
oe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`00
0?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003o
oooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo
0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo
00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFooo
ool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooo
ooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oooooo
DOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooo
oomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooooooo
o`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAoooo
o`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_o
oooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oo
oooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooo
oe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oo
ooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o
0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool0
0?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooooooo
ool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOoo
ool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomK
ooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003o
ooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooo
oomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3o
oooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03
o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo
003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooo
oooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7o
oooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oooooo
Foooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000
ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oo
ooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0
oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool0
0ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKoooo
o`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooo
ooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomA
ooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooo
oe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`00
0?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003o
oooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo
0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo
00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFooo
ool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000oooo
ooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?oooooo
DOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooo
oomKooooo`00oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0
003oooooooooo`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00
oooooomAooooo`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003ooooooooo
o`3ooooooe_ooooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAoooo
o`03o`000?oooooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_o
oooo003ooooooe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oo
oooooooo0?ooooooFoooool00?ooooooDOooool00ol0003oooooooooo`3ooooooe_ooooo003ooooo
oe7ooooo00?o0000ooooooooool0oooooomKooooo`00oooooomAooooo`03o`000?oooooooooo0?oo
ooooFoooool00?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o
0000ooooooooool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool0
0?ooooooD?ooool00ol0003oooooooooo`3ooooooecooooo003ooooooe3ooooo00?o0000oooooooo
ool0oooooomLooooo`00oooooom@ooooo`03o`000?oooooooooo0?ooooooG?ooool00?ooooooD?oo
ool00ol0003oooooooooo`3ooooooecooooo003oooooodoooooo00?o0000ooooooooool0oooooomM
ooooo`00oooooom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003o
ooooooooo`3ooooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooo
oom?ooooo`03o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3o
oooooegooooo003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03
o`000?oooooooooo0?ooooooGOooool00?ooooooCoooool00ol0003oooooooooo`3ooooooegooooo
003oooooodoooooo00?o0000ooooooooool0oooooomMooooo`00oooooom?ooooo`03o`000?oooooo
oooo0?ooooooGOooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodko
oooo00?o0000ooooooooool0oooooomNooooo`00oooooom>ooooo`03o`000?oooooooooo0?oooooo
G_ooool00?ooooooC_ooool00ol0003oooooooooo`3ooooooekooooo003oooooodkooooo00?o0000
ooooooooool0oooooomNooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?oo
ooooCOooool00ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0
oooooomOooooo`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool0
0ol0003oooooooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOoooo
o`00oooooom=ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003ooooo
ooooo`3ooooooeoooooo003oooooodgooooo00?o0000ooooooooool0oooooomOooooo`00oooooom=
ooooo`03o`000?oooooooooo0?ooooooGoooool00?ooooooCOooool00ol0003oooooooooo`3ooooo
oeoooooo003oooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`00
0?oooooooooo0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003o
ooooodcooooo00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo
0?ooooooH?ooool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo
00?o0000ooooooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?oo
ool00?ooooooC?ooool00ol0003oooooooooo`3oooooof3ooooo003oooooodcooooo00?o0000oooo
ooooool0oooooomPooooo`00oooooom<ooooo`03o`000?oooooooooo0?ooooooH?ooool00?oooooo
Boooool00ol0003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooo
oomQooooo`00oooooom;ooooo`03o`000?oooooooooo0?ooooooHOooool00?ooooooBoooool00ol0
003oooooooooo`3oooooof7ooooo003ooooood_ooooo00?o0000ooooooooool0oooooomQooooo`00
oooooom:ooooo`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003ooooooooo
o`3oooooof;ooooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:oooo
o`03o`000?oooooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;o
oooo003ooooood[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oo
oooooooo0?ooooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003ooooo
od[ooooo00?o0000ooooooooool0oooooomRooooo`00oooooom:ooooo`03o`000?oooooooooo0?oo
ooooH_ooool00?ooooooB_ooool00ol0003oooooooooo`3oooooof;ooooo003oooooodWooooo00?o
0000ooooooooool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool0
0?ooooooBOooool00ol0003oooooooooo`3oooooof?ooooo003oooooodWooooo00?o0000oooooooo
ool0oooooomSooooo`00oooooom9ooooo`03o`000?oooooooooo0?ooooooHoooool00?ooooooBOoo
ool00ol0003oooooooooo`3oooooof?ooooo003oooooodSooooo00?o0000ooooooooool0oooooomT
ooooo`00oooooom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooB?ooool00ol0003o
ooooooooo`3oooooofCooooo003oooooodSooooo00?o0000ooooooooool0oooooomTooooo`00oooo
oom8ooooo`03o`000?oooooooooo0?ooooooI?ooool00?ooooooAoooool00ol0003oooooooooo`3o
ooooofGooooo003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03
o`000?oooooooooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo
003oooooodOooooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooo
oooo0?ooooooIOooool00?ooooooAoooool00ol0003oooooooooo`3oooooofGooooo003oooooodOo
oooo00?o0000ooooooooool0oooooomUooooo`00oooooom7ooooo`03o`000?oooooooooo0?oooooo
IOooool00?ooooooA_ooool00ol0003oooooooooo`3oooooofKooooo003oooooodKooooo00?o0000
ooooooooool0oooooomVooooo`00oooooom6ooooo`03o`000?oooooooooo0?ooooooI_ooool00?oo
ooooAOooool00ol0003oooooooooo`3oooooofOooooo003oooooodGooooo00?o0000ooooooooool0
oooooomWooooo`00oooooom5ooooo`03o`000?oooooooooo0?ooooooIoooool00?ooooooAOooool0
0ol0003oooooooooo`3oooooofOooooo003oooooodCooooo00?o0000ooooooooool0oooooomXoooo
o`00oooooom4ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?ooooooA?ooool00ol0003ooooo
ooooo`3oooooofSooooo003oooooodCooooo00?o0000ooooooooool0oooooomXooooo`00oooooom4
ooooo`03o`000?oooooooooo0?ooooooJ?ooool00?oooooo@oooool00ol0003oooooooooo`3ooooo
ofWooooo003ooooood?ooooo00?o0000ooooooooool0oooooomYooooo`00oooooom3ooooo`03o`00
0?oooooooooo0?ooooooJOooool00?oooooo@oooool00ol0003oooooooooo`3oooooofWooooo003o
oooood;ooooo00?o0000ooooooooool0oooooomZooooo`00oooooom2ooooo`03o`000?oooooooooo
0?ooooooJ_ooool00?oooooo@_ooool00ol0003oooooooooo`3oooooof[ooooo003ooooood7ooooo
00?o0000ooooooooool0oooooom[ooooo`00oooooom1ooooo`03o`000?oooooooooo0?ooooooJooo
ool00?oooooo@Oooool00ol0003oooooooooo`3oooooof_ooooo003ooooood7ooooo00?o0000oooo
ooooool0oooooom[ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo
@?ooool00ol0003oooooooooo`3oooooofcooooo003ooooood3ooooo00?o0000ooooooooool0oooo
oom/ooooo`00oooooom0ooooo`03o`000?oooooooooo0?ooooooK?ooool00?oooooo?oooool00ol0
003oooooooooo`3oooooofgooooo003oooooockooooo00?o0000ooooooooool0oooooom^ooooo`00
oooooolnooooo`03o`000?oooooooooo0?ooooooK_ooool00?oooooo?Oooool00ol0003ooooooooo
o`3oooooofoooooo003oooooocgooooo00?o0000ooooooooool0oooooom_ooooo`00oooooolloooo
o`03o`000?oooooooooo0?ooooooL?ooool00?oooooo??ooool00ol0003oooooooooo`3oooooog3o
oooo003ooooooc_ooooo00?o0000ooooooooool0oooooomaooooo`00oooooolkooooo`03o`000?oo
oooooooo0?ooooooLOooool00?oooooo>_ooool00ol0003oooooooooo`3oooooog;ooooo003ooooo
oc[ooooo00?o0000ooooooooool0oooooombooooo`00ooooooliooooo`03o`000?oooooooooo0?oo
ooooLoooool00?oooooo>?ooool00ol0003oooooooooo`3oooooogCooooo003oooooocOooooo00?o
0000ooooooooool0oooooomeooooo`00oooooolfooooo`03o`000?oooooooooo0?ooooooM_ooool0
0?oooooo=_ooool00ol0003oooooooooo`3oooooogKooooo003oooooocGooooo00?o0000oooooooo
ool0oooooomgooooo`00ooooooldooooo`03o`000?oooooooooo0?ooooooN?ooool00?oooooo<ooo
ool00ol0003oooooooooo`3oooooogWooooo003ooooooc;ooooo00?o0000ooooooooool0oooooomj
ooooo`00ooooool`ooooo`;o0000oooooommooooo`00ooooool_ooooo`03o`000?oooooooooo0?oo
ooooOOooool00?oooooo;_ooool00ol0003oooooooooo`3oooooogkooooo003oooooobgooooo00?o
0000ooooooooool0oooooomoooooo`00ooooool/ooooo`03o`000?oooooooooo0?ooooooP?ooool0
0?oooooo:_ooool2o`000?ooooooPoooool00?oooooo:Oooool00ol0003oooooooooo`3ooooooh?o
oooo003oooooobSooooo00?o0000ooooooooool0oooooon4ooooo`00oooooolVooooo`;o0000oooo
oon7ooooo`00oooooolUooooo`03o`000?oooooooooo0?ooooooQoooool00?oooooo9?ooool00ol0
003oooooooooo`3oooooohSooooo003oooooob;ooooo0_l0003ooooooh_ooooo003oooooob3ooooo
0_l0003oooooohgooooo003ooooooaoooooo00?o0000ooooooooool0oooooon=ooooo`00oooooolN
ooooo`03o`000?oooooooooo0?ooooooS_ooool00?oooooo7Oooool00ol0003oooooooooo`3ooooo
ohoooooo003ooooooacooooo00?o0000ooooooooool0oooooon@ooooo`00oooooolKooooo`03o`00
0?oooooooooo0?ooooooTOooool00?oooooo6oooool00ol0003oooooooooo`3ooooooi7ooooo003o
oooooaWooooo0_l0003ooooooiCooooo003ooooooaWooooo00?o0000ooooooooool0oooooonCoooo
o`00oooooolIooooo`03o`000?oooooooooo0?ooooooToooool00?oooooo6?ooool2o`000?oooooo
UOooool00?oooooo6Oooool00ol0003oooooooooo`3ooooooi?ooooo003ooooooaWooooo00?o0000
ooooooooool0oooooonCooooo`00oooooolJooooo`03o`000?oooooooooo0?ooooooT_ooool00?oo
oooo6oooool00ol0003oooooooooo`3ooooooi7ooooo003ooooooacooooo0_l0003ooooooi7ooooo
003ooooooakooooo0_l0003oooooohoooooo003oooooob3ooooo00?o0000ooooooooool0oooooon<
ooooo`00oooooolQooooo`?o0000oooooon;ooooo`00oooooolTooooo`?o0000oooooon8ooooo`00
oooooolWooooo`Co0000oooooon4ooooo`00ooooool[ooooo`Co0000oooooon0ooooo`00ooooool_
ooooo`Co0000oooooomlooooo`00oooooolcooooo`Co0000oooooomhooooo`00oooooolgooooo`Co
0000oooooomdooooo`00oooooolkooooo`Co0000oooooom`ooooo`00ooooooloooooo`Go0000oooo
oom[ooooo`00oooooom4ooooo`Co0000oooooomWooooo`00oooooom8ooooo`Go0000oooooomRoooo
o`00oooooom=ooooo`Co0000oooooomNooooo`00oooooomAooooo`Go0000oooooomIooooo`00oooo
oomFooooo`Co0000oooooomEooooo`00oooooomJooooo`Go0000oooooom@ooooo`00oooooomOoooo
o`Go0000oooooom;ooooo`00oooooomTooooo`Go0000oooooom6ooooo`00oooooomYooooo`Go0000
oooooom1ooooo`00oooooom^ooooo`Co0000oooooolmooooo`00oooooombooooo`?o0000oooooolj
ooooo`00oooooomeooooo`?o0000oooooolgooooo`00oooooomhooooo`?o0000ooooooldooooo`00
oooooomkooooo`;o0000oooooolbooooo`00oooooommooooo`;o0000ooooool`ooooo`00oooooomo
ooooo`?o0000ooooool]ooooo`00oooooon2ooooo`;o0000ooooool[ooooo`00oooooon4ooooo`03
o`000?oooooooooo0?oooooo:?ooool00?ooooooQOooool00ol0003oooooooooo`3oooooobOooooo
003oooooohKooooo0_l0003oooooobOooooo003oooooohOooooo00?o0000ooooooooool0oooooolU
ooooo`00oooooon7ooooo`;o0000oooooolVooooo`00oooooon7ooooo`;o0000oooooolVooooo`00
oooooon7ooooo`03o`000?oooooooooo0?oooooo9Oooool00?ooooooQoooool00ol0003ooooooooo
o`3oooooobGooooo003oooooohOooooo00?o0000ooooooooool0oooooolUooooo`00oooooon5oooo
o`;o0000oooooolXooooo`00oooooon4ooooo`03o`000?oooooooooo0?oooooo:?ooool00?oooooo
P_ooool2o`000?oooooo:oooool00?ooooooP?ooool2o`000?oooooo;Oooool00?ooooooOoooool0
0ol0003oooooooooo`3oooooobgooooo003ooooooggooooo0_l0003ooooooc3ooooo003oooooogco
oooo00?o0000ooooooooool0ooooool`ooooo`00oooooomkooooo`03o`000?oooooooooo0?oooooo
<Oooool00?ooooooNOooool2o`000?oooooo=?ooool00?ooooooN?ooool00ol0003oooooooooo`3o
ooooocCooooo003oooooogOooooo00?o0000ooooooooool0ooooooleooooo`00oooooomeooooo`;o
0000oooooolhooooo`00oooooomdooooo`03o`000?oooooooooo0?oooooo>?ooool00?ooooooL_oo
ool2o`000?oooooo>oooool00?ooooooL?ooool2o`000?oooooo?Oooool00?ooooooKoooool00ol0
003oooooooooo`3oooooocgooooo003oooooofgooooo0_l0003ooooood3ooooo003oooooofcooooo
00?o0000ooooooooool0oooooom0ooooo`00oooooomZooooo`;o0000oooooom3ooooo`00oooooomX
ooooo`;o0000oooooom5ooooo`00oooooomWooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooI_ooool00ol0003oooooooooo`3oooooodKooooo003oooooofKooooo00?o0000ooooooooool0
oooooom6ooooo`00oooooomUooooo`03o`000?oooooooooo0?ooooooAoooool00?ooooooI?ooool0
0ol0003oooooooooo`3oooooodSooooo003oooooof?ooooo00?o0000ooooooooool0oooooom9oooo
o`00oooooomRooooo`03o`000?oooooooooo0?ooooooB_ooool00?ooooooH?ooool2o`000?oooooo
COooool00?ooooooGoooool00ol0003oooooooooo`3oooooodgooooo003ooooooekooooo00?o0000
ooooooooool0oooooom>ooooo`00oooooomMooooo`03o`000?oooooooooo0?ooooooCoooool00?oo
ooooG?ooool00ol0003oooooooooo`3ooooooe3ooooo003ooooooe_ooooo00?o0000ooooooooool0
oooooomAooooo`00oooooomKooooo`03o`000?oooooooooo0?ooooooDOooool00?ooooooF_ooool0
0ol0003oooooooooo`3ooooooe;ooooo003ooooooeWooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomIooooo`03o`000?oooooooooo0?ooooooDoooool00?ooooooF?ooool00ol0003ooooo
ooooo`3ooooooeCooooo003ooooooeOooooo00?o0000ooooooooool0oooooomEooooo`00oooooooo
ooooojoooooo003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo
003ooooooooooooo[oooool00?oooooooooooon_ooooo`00ooooooooooooojoooooo003ooooooooo
oooo[oooool00?oooooo5oooool3o`000003oa0@4?oooooooooo0?ooooooT_ooool00?oooooo6Ooo
ool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Ooo
ool00ol0003o^[Zjooooo`3oooooofKooooo003ooooooaWooooo00?oV9RHoc8b<_ooool01oooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8boooooomW
ooooo`00oooooolIooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo1Ol00004
ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oo
oooooooo00?ooooo00?oQhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
1Ol00005ooooo`;o8B4Q2_ooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0oooooolHooooo`00oooo
oolIooooo`03oeEEEOmgMgOoA4A400Oooooo00Co0000oooooooooooooooo0_mgMgL2ooooo`03o`00
0?oooooooooo00;ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Co
oooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[ok^k^ogMg
Mol@41002Oooool6o`0000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2_ooool0
1_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102oooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@oooooolHooooo`00oooooolHooooo`05omgMgOl@413o
ooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`03oeEEEOnHV9Sooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o
V9RHob4Q8Oo^k^h04oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooooa_ooooo003ooooooaSooooo00GoIVIVohN7QoooooooV9RH
oeEEE@06ooooo`03o`000?oooooooooo00?ooooo00?oEEEEoiRHV?ooool02oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool6o`0000_ooooo
00?oV9RHob4Q8Oo^k^h04Oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002oooo
o`03o`000?oooooooooo0?oooooo6oooool00?oooooo5oooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03oc8b<_n7QhOooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01gooooo00?oMgMgofIVI_ooool04?ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000oooooolH
ooooo`00oooooolGooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool0
1?l0003oooooooooooooool5o`0000Wooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oo
oooooooo00Wooooo00?o410@o`000?l000000ol0000Mooooo`03o`000?oooooooooo00oooooo00Ko
ZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool0
1_o^k^koIVIVo`000?l0003oA4A4o`000?oooooo6?ooool00?oooooo8oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Jooooo`05o`000?nj^[[ooooooiRHV?l@4100ooooooloooooo`00oooooolSooooo`;o00004_oo
ool00ol0003oooooooooo`05ooooo`;o00003Oooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`0ooooooloooooo`00ooooooooooooojoooooo003ooooooooooooo[oooool0
0?oooooooooooon_ooooo`00\
\>"],
  ImageRangeCache->{{{0, 684.938}, {341.938, 0}} -> {-3.2211, -1.53751*^-5, \
0.0117569, 0.0117569}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The pulse travels toward the free end of the string, where a whipcrack \
phenomenon occurs. The propagation speed ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  " of the pulse   decreases as it approaches the free end, due to the \
decrease in the tension. Thus, the back of the pulse catches up with the \
front, and as the pulse compresses, there is a buildup of the amplitude that \
causes extremely rapid motion of the string tip. "
}], "Text",
  CellTags->"i:42"],

Cell[TextData[{
  "\t The speed of the string tip can actually exceed the speed of sound in \
air (roughly 700 miles per hour, or 340 m/s), causing a distinctive whipcrack \
sound as the string tip breaks the sound barrier. The velocity of the end of \
the string is  plotted in Cell ",
  ButtonBox["4.19",
    ButtonData:>"Cell 4.19",
    ButtonStyle->"Hyperlink"],
  " in the vicinity of the first whipcrack. This velocity is in units of the \
maximum initial pulse amplitude per second. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[D[y[0, t], t]], {t, 0.5, 1. }, PlotRange \[Rule] All, 
        PlotLabel -> "\<string tip velocity\>", \ 
        AxesLabel \[Rule] {"\<t (sec)\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.19"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 1.90476 0.390902 0.0010111 [
[.02381 .3784 -9 -9 ]
[.02381 .3784 9 0 ]
[.21429 .3784 -9 -9 ]
[.21429 .3784 9 0 ]
[.40476 .3784 -9 -9 ]
[.40476 .3784 9 0 ]
[.59524 .3784 -9 -9 ]
[.59524 .3784 9 0 ]
[.78571 .3784 -9 -9 ]
[.78571 .3784 9 0 ]
[1.025 .3909 0 -6 ]
[1.025 .3909 46 6 ]
[.96369 .08757 -24 -4.5 ]
[.96369 .08757 0 4.5 ]
[.96369 .18868 -24 -4.5 ]
[.96369 .18868 0 4.5 ]
[.96369 .28979 -24 -4.5 ]
[.96369 .28979 0 4.5 ]
[.96369 .49201 -18 -4.5 ]
[.96369 .49201 0 4.5 ]
[.96369 .59312 -18 -4.5 ]
[.96369 .59312 0 4.5 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .3909 m
.02381 .39715 L
s
[(0.5)] .02381 .3784 0 1 Mshowa
.21429 .3909 m
.21429 .39715 L
s
[(0.6)] .21429 .3784 0 1 Mshowa
.40476 .3909 m
.40476 .39715 L
s
[(0.7)] .40476 .3784 0 1 Mshowa
.59524 .3909 m
.59524 .39715 L
s
[(0.8)] .59524 .3784 0 1 Mshowa
.78571 .3909 m
.78571 .39715 L
s
[(0.9)] .78571 .3784 0 1 Mshowa
.125 Mabswid
.0619 .3909 m
.0619 .39465 L
s
.1 .3909 m
.1 .39465 L
s
.1381 .3909 m
.1381 .39465 L
s
.17619 .3909 m
.17619 .39465 L
s
.25238 .3909 m
.25238 .39465 L
s
.29048 .3909 m
.29048 .39465 L
s
.32857 .3909 m
.32857 .39465 L
s
.36667 .3909 m
.36667 .39465 L
s
.44286 .3909 m
.44286 .39465 L
s
.48095 .3909 m
.48095 .39465 L
s
.51905 .3909 m
.51905 .39465 L
s
.55714 .3909 m
.55714 .39465 L
s
.63333 .3909 m
.63333 .39465 L
s
.67143 .3909 m
.67143 .39465 L
s
.70952 .3909 m
.70952 .39465 L
s
.74762 .3909 m
.74762 .39465 L
s
.82381 .3909 m
.82381 .39465 L
s
.8619 .3909 m
.8619 .39465 L
s
.9 .3909 m
.9 .39465 L
s
.9381 .3909 m
.9381 .39465 L
s
.25 Mabswid
0 .3909 m
1 .3909 L
s
gsave
1.025 .3909 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(L) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 .08757 m
.98244 .08757 L
s
[(-300)] .96369 .08757 1 0 Mshowa
.97619 .18868 m
.98244 .18868 L
s
[(-200)] .96369 .18868 1 0 Mshowa
.97619 .28979 m
.98244 .28979 L
s
[(-100)] .96369 .28979 1 0 Mshowa
.97619 .49201 m
.98244 .49201 L
s
[(100)] .96369 .49201 1 0 Mshowa
.97619 .59312 m
.98244 .59312 L
s
[(200)] .96369 .59312 1 0 Mshowa
.125 Mabswid
.97619 .1078 m
.97994 .1078 L
s
.97619 .12802 m
.97994 .12802 L
s
.97619 .14824 m
.97994 .14824 L
s
.97619 .16846 m
.97994 .16846 L
s
.97619 .2089 m
.97994 .2089 L
s
.97619 .22913 m
.97994 .22913 L
s
.97619 .24935 m
.97994 .24935 L
s
.97619 .26957 m
.97994 .26957 L
s
.97619 .31001 m
.97994 .31001 L
s
.97619 .33024 m
.97994 .33024 L
s
.97619 .35046 m
.97994 .35046 L
s
.97619 .37068 m
.97994 .37068 L
s
.97619 .41112 m
.97994 .41112 L
s
.97619 .43135 m
.97994 .43135 L
s
.97619 .45157 m
.97994 .45157 L
s
.97619 .47179 m
.97994 .47179 L
s
.97619 .51223 m
.97994 .51223 L
s
.97619 .53246 m
.97994 .53246 L
s
.97619 .55268 m
.97994 .55268 L
s
.97619 .5729 m
.97994 .5729 L
s
.97619 .06735 m
.97994 .06735 L
s
.97619 .04713 m
.97994 .04713 L
s
.97619 .02691 m
.97994 .02691 L
s
.97619 .00669 m
.97994 .00669 L
s
.97619 .61334 m
.97994 .61334 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(string) show
105.000 13.000 moveto
(tip) show
129.000 13.000 moveto
(velocity) show
177.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .39096 m
.03279 .39092 L
.04262 .39087 L
.04758 .39085 L
.05035 .39084 L
.05167 .39084 L
.05288 .39084 L
.054 .39083 L
.05524 .39083 L
.05648 .39083 L
.0578 .39083 L
.05895 .39083 L
.0602 .39083 L
.06137 .39083 L
.06244 .39084 L
.0638 .39084 L
.06504 .39084 L
.0678 .39085 L
.07277 .39087 L
.08405 .39093 L
.08912 .39095 L
.09199 .39097 L
.09335 .39097 L
.09462 .39097 L
.09573 .39097 L
.09693 .39098 L
.09761 .39098 L
.09825 .39098 L
.09946 .39098 L
.10074 .39098 L
.10191 .39098 L
.10321 .39098 L
.10386 .39097 L
.10458 .39097 L
.10693 .39097 L
.1095 .39096 L
.11467 .39093 L
.12393 .39088 L
.12915 .39085 L
.13202 .39084 L
.13343 .39084 L
.13473 .39083 L
.13593 .39083 L
.13726 .39082 L
.1379 .39082 L
.13859 .39082 L
.13932 .39082 L
.14 .39082 L
.14128 .39082 L
.1425 .39082 L
Mistroke
.14359 .39082 L
.14478 .39082 L
.14543 .39083 L
.14612 .39083 L
.14735 .39083 L
.15011 .39084 L
.15513 .39086 L
.16449 .39092 L
.16933 .39095 L
.17199 .39096 L
.17451 .39097 L
.17593 .39098 L
.17748 .39098 L
.17889 .39099 L
.18019 .39099 L
.18141 .39099 L
.1821 .39099 L
.18275 .39099 L
.18407 .39099 L
.18481 .39099 L
.18548 .39099 L
.18676 .39099 L
.18797 .39098 L
.19024 .39098 L
.19267 .39097 L
.19531 .39095 L
.20444 .39089 L
.20968 .39086 L
.21255 .39084 L
.21523 .39083 L
.21751 .39082 L
.21868 .39082 L
.21996 .39081 L
.22068 .39081 L
.22135 .39081 L
.222 .39081 L
.22268 .39081 L
.22386 .39081 L
.22516 .39081 L
.22637 .39081 L
.2275 .39081 L
.22874 .39082 L
.23006 .39082 L
.23277 .39083 L
.23523 .39084 L
.24448 .39091 L
.24974 .39095 L
.25532 .39099 L
.25762 .39101 L
.26009 .39102 L
Mistroke
.2615 .39102 L
.26279 .39103 L
.26402 .39103 L
.26533 .39103 L
.26661 .39104 L
.26777 .39104 L
.26893 .39104 L
.27003 .39104 L
.27131 .39104 L
.27249 .39104 L
.27379 .39103 L
.27515 .39103 L
.27966 .39102 L
.28214 .39102 L
.28449 .39101 L
.28577 .39101 L
.2865 .39101 L
.28717 .39101 L
.28836 .39101 L
.28962 .39101 L
.29079 .39101 L
.29189 .39101 L
.2931 .39101 L
.2944 .39102 L
.29572 .39103 L
.29717 .39104 L
.30008 .39107 L
.30277 .3911 L
.30528 .39115 L
.31033 .39128 L
.31318 .39137 L
.31581 .39148 L
.32064 .39172 L
.32575 .39204 L
.33461 .39282 L
.33964 .39342 L
.34434 .39409 L
.34933 .39497 L
.35476 .39616 L
.35955 .39745 L
.36465 .39914 L
.3697 .40121 L
.37427 .40347 L
.38319 .40922 L
.39325 .41831 L
.40249 .42962 L
.41263 .44582 L
.42333 .46743 L
.44324 .51834 L
.46137 .56792 L
Mistroke
.46619 .57932 L
.47142 .58984 L
.47382 .59384 L
.47637 .59741 L
.47854 .59985 L
.47968 .6009 L
.48093 .60184 L
.48165 .60228 L
.48233 .60263 L
.48302 .60291 L
.48365 .60311 L
.48485 .60332 L
.48614 .60329 L
.48686 .60315 L
.48752 .60295 L
.48825 .60264 L
.48902 .60221 L
.49032 .60126 L
.49174 .59986 L
.49427 .59643 L
.49698 .59137 L
.50187 .57844 L
.50715 .55877 L
.51203 .53521 L
.5231 .46376 L
.54321 .28797 L
.55295 .19802 L
.56346 .11234 L
.56829 .08003 L
.57337 .05228 L
.57772 .03432 L
.58018 .02665 L
.58247 .02119 L
.5837 .01895 L
.58483 .01729 L
.58607 .01595 L
.58738 .01505 L
.58853 .01472 L
.58959 .01477 L
.59077 .01524 L
.59203 .01622 L
.59314 .01749 L
.59435 .0193 L
.59656 .02373 L
.59872 .02938 L
.60071 .03577 L
.60567 .05605 L
.61015 .07926 L
.62021 .14383 L
.6411 .29683 L
Mistroke
.65027 .35598 L
.65512 .3829 L
.66031 .40782 L
.6654 .42811 L
.67003 .44305 L
.67468 .45481 L
.67909 .4631 L
.68148 .46654 L
.68402 .46943 L
.68619 .47131 L
.68858 .47281 L
.68992 .4734 L
.69115 .47379 L
.69179 .47395 L
.69249 .47408 L
.69323 .47417 L
.69391 .47421 L
.69518 .4742 L
.69633 .47409 L
.69696 .47399 L
.69765 .47384 L
.6989 .47351 L
.70127 .47262 L
.70381 .47133 L
.70839 .46831 L
.71881 .45927 L
.73986 .43926 L
.75001 .43097 L
.76107 .42347 L
.77062 .41825 L
.78118 .41371 L
.79136 .41035 L
.80092 .40791 L
.82192 .4041 L
.84206 .40141 L
.86056 .39949 L
.87034 .39873 L
.87945 .39815 L
.90014 .39716 L
.92019 .39626 L
.93914 .39544 L
.94776 .39514 L
.95691 .3949 L
.96693 .3947 L
.97619 .39455 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooolPooooo`03o`000?oooooooooo04Kooooo003oooooob3ooooo
00?o0000ooooooooool0A_ooool00?oooooo8?ooool2o`0004Oooooo003oooooob3ooooo00?o0000
ooooooooool0A_ooool00:kooooo0_l0001_ooooo`03o`000?oooooooooo04Kooooo002]ooooo`Co
0000K_ooool00ol0003oooooooooo`16ooooo`00[Oooool01?l0003oooooooooool0001^ooooo`03
o`000?oooooooooo04Kooooo002]ooooo`05o`000?ooooooooooooooool00000KOooool00ol0003o
ooooooooo`16ooooo`00[?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06_ooooo
0_l00017ooooo`00[?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06_ooooo00?o
0000ooooooooool0A_ooool00:_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Z
ooooo`03o`000?oooooooooo04Kooooo002[ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`16ooooo`00Zoooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0A_ooool00:[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04Kooooo002Zooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0JOooool2o`0004Oooooo002Zooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`16ooooo`00Z_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0A_ooool00:[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo04Ko
oooo002Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0JOooool00ol0003ooooo
ooooo`16ooooo`00Z_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Sooooo0_l0
0017ooooo`00ZOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooooooool0A_ooool00:Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Xoooo
o`03o`000?oooooooooo04Kooooo002Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`16ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo04cooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A_ooool0
0:Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo04Kooooo002Yooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0A?ooool6o`0000Kooooo00Go0000oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`?o0000A_ooool00:Sooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`03ojVYZOl@413ooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`16ooooo`00Z?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04go
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo04Kooooo002Xooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0C_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0A_oo
ool00:Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1;ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo04Kooooo002Xooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0Boooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`16
ooooo`00Yoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Kooooo0_l00017oooo
o`00Yoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Kooooo00?o0000oooooooo
ool0A_ooool00:Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo04Kooooo002Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`16ooooo`00Yoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0A_ooool00:Oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo04Kooooo002Wooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0IOooool2o`0004Oooooo002Vooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`16ooooo`00Y_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0A_ooool00:Kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo04Kooooo002Voooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`16oooo
o`00Y_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0A_ooool00:Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`;o0000
Aoooool00:Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo04Kooooo002Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`16ooooo`00YOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0A_ooool00:Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo04Kooooo002Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`16ooooo`00YOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo06?ooooo0_l00017ooooo`00YOooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0A_ooool00:Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo04Kooooo002Uooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0B?ooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`16
ooooo`00YOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0A_ooool00:Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0oooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool0A_ooool00:Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`0004Kooooo002Tooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A_ooool00:Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1;ooooo`05o`000?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`16ooooo`00Y?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Oooooo00Go0000
okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0A_ooool00:Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`17ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo04Kooooo002Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`16ooooo`00Y?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo067o
oooo0_l00017ooooo`00Xoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0A_ooool00:?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo04Kooooo002Sooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`16ooooo`00Xoooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0A_ooool00:?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1Qooooo`;o0000Aoooool00:?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04Kooooo002Sooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`16ooooo`00Xoooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0A_ooool0
0:?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
04Kooooo002Rooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`16ooooo`00X_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo063ooooo
0_l00017ooooo`00X_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo063ooooo00?o
0000ooooooooool0A_ooool00:;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo04Kooooo002Rooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`16ooooo`00X_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0A_ooool00:;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04Kooooo002Rooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0Goooool2o`0004Oooooo002Rooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`16ooooo`00XOooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0A_ooool00:7o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo04Kooooo002Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0A_ooool00:7ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0kooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0A_ooool00:7ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool3o`0004Kooooo002Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0A_ooool00:7ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`16ooooo`00XOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo04Kooooo002Pooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0A?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A_ooool00:3o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo04Ko
oooo002Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0G_ooool2o`0004Oooooo
002Pooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0GOooool00ol0003ooooooooo
o`16ooooo`00X?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0A_ooool00:3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo04Kooooo002Pooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`16ooooo`00X?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0A_ooool00:3ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Mooooo`;o0000Aoooool009oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Kooooo002Oooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`16ooooo`00Woooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0A_ooool009oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo04Kooooo
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd08Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^
k^kooooo01cooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Jooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Co410@o`000?m4A4Coc<c<;_ooool0
0ol0003oooooooooo`16ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0Rooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Ko
oooo00?oEEEEojVYZOooool07?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooo
oooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00onHV9So410@omgM
g@0]ooooo`;o0000Aoooool00005oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Oooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo01cooooo00?o0000oooo
ooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ohN7
QomEEEGooooo02cooooo00?o0000ooooooooool0A_ooool00005o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`0Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
V9RHoooooonHV9So8B4Q02;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooo
oooo01_ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05olc<c?lQ8B7o0000oeEEEOl00000;Oooool00ol0003oooooooooo`16oooo
o`0000Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`08Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Rooooo`05o`00
0?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool0
0ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01OlQ8B7oQhN7oooo
oonHV9So000002gooooo00?o0000ooooooooool0A_ooool00005oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0Sooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`0Tooooo`05oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`0Joooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[o
oooookZj^_l@41001oooool00ol0003oooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000002gooooo00?o0000ooooooooool0A_ooool00005ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Sooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ooMgMgo410@oiRHV00Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol@413ooooooooooooooooo<S8b01_ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000007ooooo`03o`000?oooooooooo01Wo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0;Oooool2
o`0004Oooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000Rooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Rooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0001_ooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@07ooooo`03o`000?oooooooooo01Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h0;Oooool00ol0003ooooo
ooooo`16ooooo`00W_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool08_ooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo00Oooooo002N
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Q
ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^oa0@4?oMgMd01oooool009kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo013ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0<ooooo`06oeEEEOnHV9Soooooooooool@413o<S8b0_l000001_l@413oZJVY
ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00_ooool01OmVIVKo0000o`000?m4A4Co
c<c<00;ooooo00?oQhN7ofIVI_ooool01_ooool009kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo013ooooo00Go410@okZj^_o^k^koMgMgoa0@400<
ooooo`06o`000?ooooooooooooooool0003oZJVY0_ooool02_nj^[[o0000ooooooooooooEEEEogMg
Moooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0_ooool00oo^k^ko
0000ooooo`06ooooo`001?ooooooo`0002Co00002oooool00ol0003oooooooooo`0>ooooo`03oc8b
<_oooooooooo00;ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`002oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo2_l00003ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ool000002Ol0000Booooo`03o`000?oooooooooo00kooooo00Ko<S8boooooooooooooooooc8b<_lQ
8B42ogMgM`04ohN7Qoo^k^koooooooooo`Ko00000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo000;ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_oo
ool3o`0000_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0GoooooaCo00002Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00[o0000onk^k_oooooooooo
o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo
00KoIVIVogMgMoooooooooooohN7Qol00002ooooo`03onk^k_l0003ooooo00Kooooo001^ooooo`;o
0000;Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo3Ol0000Mooooo`03
o`000?oooooooooo00kooooo00?o410@o`000?l000000ol0000=ooooo`06oeEEEOmgMgOooooooooo
oonYZJWo8B4Q0_l000001_lb<S;o0000ooooooooooook^k^oeEEE@;o000000KoA4A4onk^k_oooooo
ooooonk^k_mVIVH2o`000006odA4A?l0003ooooooooooomgMgOoEEEE1oooool0073ooooo0_l0000[
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:Oooool6o`0002[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03omgMgOl@413ok^k^01Sooooo00?ok^k^
oa0@4?oMgMd01oooool007;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo02Gooooo1?l0000`ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00omgMgOoIVIVooooo`0Gooooo`03ofIVI_mgMgOooooo00Oooooo001cooooo`;o
0000:?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo0ol0000dooooo`;o
0000Aoooool007Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01kooooo0ol0000gooooo`03o`000?oooooooooo04Kooooo001fooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`?o0000>_oo
ool00ol0003oooooooooo`16ooooo`00Moooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo04Kooooo001hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Gooooo`;o0000?_ooool00ol0003oooooooooo`16ooooo`00NOooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo04Kooooo001iooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Dooooo`;o0000@Oooool2o`0004Oooooo
001jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0A_ooool007[ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`16ooooo`00N_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo04Kooooo001kooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0A_ooool007_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`16ooooo`00O?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`16ooooo`;o0000Aoooool007gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`16ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
04Kooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0A_ooool007oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`16ooooo`00Ooooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo04Kooooo0020ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0;Oooool6o`0004kooooo0_l00017ooooo`00P?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0A_ooool0083ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo04Kooooo0021ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0J?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`16ooooo`00POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo04Kooooo0021ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0J_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0A_ooool008;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
04Kooooo0022ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0A_ooool008;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`16ooooo`00Poooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo04Kooooo0023ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOoo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A_ooool008?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`23ooooo`;o0000Aoooool008Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo04Kooooo0024ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`16ooooo`00Q?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0A_ooool008Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo04Ko
oooo0025ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`16ooooo`00QOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Cooooo0_l0
0017ooooo`00Q_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool0A_ooool008Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo04Kooooo0027ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooooooo`16ooooo`00Qoooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo08Cooooo00?o0000ooooooooool0A_ooool008Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo04Kooooo0028ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0QOooool2o`0004Oooooo0028ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`16ooooo`00ROooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0A_ooool008Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo04Kooooo
0029ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`16ooooo`00R_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Kooooo00?o0000
ooooooooool0A_ooool008[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`26oooo
o`;o0000Aoooool008_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`27ooooo`03
o`000?oooooooooo04Kooooo002;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Qoooool00ol0003oooooooooo`16ooooo`00Roooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A_ooool008cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1]ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo04Kooooo002=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K_ooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0A_ooool008gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1_ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001_ooool3o`0004Kooooo002>ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0LOooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0A_ooool008oooooo00Co0000oooooooooooo0000MOooool01Ol0003ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0A_ooool008oooooo1?l0001aooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo04Kooooo003oooooo`Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0A_ooool00?oooooo8?ooool00ol0003oooooooooo`16ooooo`00oooooolPooooo`;o0000
Aoooool00?oooooo8?ooool00ol0003oooooooooo`16ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00N?ooool01OlQ8B7o0000o`000?m4A4CogMgM01Kooooo
00Co410@o`000?l0003o0000@Oooool3o`000003oa0@4?oooooooooo08[ooooo001kooooo`03ogMg
Molb<S;ooooo01Kooooo00?o0000ooooooooool0@oooool00ol@413o^[Zjooooo`2;ooooo`00O?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04?ooooo00?oV9RHoc8b<_ooool0Rooo
ool004oooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3ooooo`07oiRHV?l0003o0000odA4A?nj
^[[ooooooa0@4005o`0000Cooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000So410@
ooooooo^k^koEEEEo`000?l@413oc<c<o`0000Oooooo00GoV9RHo`000?l0003oA4A4okZj^P03oooo
o`Go00000oooool01_l0003oMgMgo`000?l0003oEEEEonk^kPWooooo00?o8B4Qoc8b<_ooool00ooo
ool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo1Ol00003ooooo`06onk^k_mEEEGo0000o`00
0?mEEEGok^k^0oooool01OmVIVKo0000o`000?m4A4Coc<c<00?ooooo1Ol00003ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00oooool00ooMgMgo0000okZj^P2;ooooo`00Coooool01_l0003oZJVYoooo
oooooooo^[Zjo`0000?ooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEE
ogMgMoooooook^k^oeEEEOl00007ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003o
ooooooooo`03ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE2?ooool01?nHV9So<S8boa0@4?nj
^[X3ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`03ooooo`06
oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Gooooo
00?o0000ooooooooool00oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?oEEEEogMgMom4
A4@0Roooool0053ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000000_ooool01_l0003oooooooooooooooook^k^o`0000Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool01_oo
ool01?l@413o^[ZjoiRHV?lb<S83ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05omgMgOl@413oooooob4Q8OoMgMd0R_ooool004oo
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h3ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_oo
ool01_l0003oooooooooooooooook^k^o`0000Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`03ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool01Oooool01_nHV9So
<S8boooooooooooo410@okZj^P;ooooo1_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01OmVIVKoQhN7oooooonHV9SoEEEE08[ooooo001?ooooo`06o`000?nj
^[[oooooonk^k_mgMgOo00000oooool00ol0003oooooooooo`05ooooo`03o`000?lb<S;ogMgM00Oo
oooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMg
Moooooook^k^oeEEEOl00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool01_l0003oEEEEonk^k_ooooooMgMgofIVIPKooooo00?ok^k^o`000?oMgMd00_ooool02_nHV9So
<S8booooooooooooEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00?ooooo
00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06ofIVI_mgMgOooooooooooon7QhOo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`28ooooo`00Coooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?oooooo
410@1Ol00003ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000004oooo
o`03oa0@4?l0003oMgMg00;o000000[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o
410@1?ooool00ol@413o0000o`000003o`0000Cooooo00?o410@o`000?l000001?ooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo00Gooooo00?o410@o`000?l000000_ooool3o`000003
ooooooo^k^koEEEE00;o000000?oA4A4onk^k_ooool00oooool00ol0003oooooooooo`03ooooo`06
onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000?ooooo
00?o410@o`000?l000000oooool00ol@413o0000o`000003o`0000;ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`27ooooo`00F?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`2Cooooo`00F?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2Cooooo`00J_ooool00ol@413oooooooooo`0Qooooo`03oa0@4?oooooo
oooo023ooooo00?o410@o`000?l000006?ooool00ol@413oooooooooo`2Iooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0.479625, -426.732, \
0.0022637, 4.26446}}]
}, Open  ]],

Cell[TextData[{
  "\tThe plot shows that, for our Gaussian initial condition, an initial \
amplitude of 1 meter  would theoretically produce a maximum tip speed that \
exceeds 300 m/s, which would break the sound barrier. However, such \
large-amplitude disturbances cannot be properly treated with our linear wave \
equation, which assumes small pulse amplitudes. We have also neglected many \
effects of importance in the motion of real whips, such as the effect of the \
pulse itself on the tension in the whip, the elasticity and plasticity of the \
whip material, and the effect of tapering the whip to small diameter at the \
tip end.  The physics of whipcracks is, believe it or not, still an active \
area of research. Interested readers can find several recent references in \
the very clear paper by ",
  ButtonBox["Goriely and MacMillan (2002)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 4.2", "Subsubtitle",
  CellTags->{"Ex. 4.2", "c:22"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Put the following problems defined on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 1\)]],
  " into standard form (if necessary) and find a solution via a sum of \
eigenmodes:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = 
        2 \[PartialD]\^2 T\/\[PartialD]x\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]T\/\[PartialD]x\) \((0, t)\) = 0\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]T\/\[PartialD]x\) \((1, t)\) = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0) = x\^4/4\)]],
  ". Animate the solution with a table of plots for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ".\n"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            
            FormBox[\(\[PartialD]T\/\[PartialD]t = \[PartialD]T\/\[PartialD]x \
+ \[PartialD]\^2 T\/\[PartialD]x\^2\),
              "TraditionalForm"], ",", 
            FormBox[\(T(0, t) = t\ \[ExponentialE]\^\(\(-4\)\ t\)\),
              "TraditionalForm"], ",", 
            RowBox[{
              FormBox[\(\(T(1, t) = 0\)\(,\)\),
                "TraditionalForm"], " ", 
              RowBox[{
                FormBox[\(\(\ \ \)\(T(x, 0) = 0\)\),
                  "TraditionalForm"], "."}]}]}]}], TraditionalForm]]],
  " Animate the solution with a table of plots for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ". (Hint: You must put the spatial operator in Sturm-Liouville form.)\n"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(z, 
            t)\) = \(\[PartialD]\/\[PartialD]z\) \((z\ \(\[PartialD]\/\
\[PartialD]z\) \(y(z, t)\))\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(z, 0)\  = \ 0.25\ \ \((1 - z)\)\), ",", 
          " ", \(\(y\& . \)(z, 0) = 0\), ",", " ", 
          RowBox[{\(y(0, t)\), "=", Cell[TextData[{
              Cell[BoxData[
                  \(TraditionalForm\`y(1, t) = 0\)]],
              "."
            }]]}]}], TraditionalForm]]],
  " Animate the solution with a table of plots for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " When one cooks using radiant heat (under a broiler, for example), there \
is a heat flux ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_r\)]],
  " due to the radiation, incident on the surface of the food. On the other \
hand, the food is typically suspended (on a grill or spit for example)  in \
such a way that it cannot conduct heat very well to the environment, so that \
little heat is reradiated.  Under these conditions, find the time required to \
raise the internal temperature of a slab of meat  of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`L = 5\ cm\)]],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`T = 20\ \[Degree]C\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`T = 90\ \[Degree]C\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " up to this time. Take",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[Chi]", "=", " ", 
            FormBox[
              RowBox[{"3", "\[Times]", \(10\^\(-7\)\), " ", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "2"], "/", 
                  StyleBox["s",
                    FontSlant->"Plain"]}]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "=", 
          RowBox[{"3", "\[Times]", \(10\^6\), " ", 
            RowBox[{
              StyleBox["J",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                RowBox[{
                  SuperscriptBox[
                    StyleBox["m",
                      FontSlant->"Plain"], "3"], 
                  StyleBox["K",
                    FontSlant->"Plain"]}], ")"}]}]}]}], TraditionalForm]]],
  ", and assume that both faces of the meat are subjected to the same flux of \
heat, equal to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"10", " ", 
          RowBox[{"kW", "/", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "2"]}]}], TraditionalForm]]],
  "(a typical value in an oven)."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " In a microwave oven, the microwave power ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " (in watts) is dissipated near the food surface, in a ",
  StyleBox["skin depth",
    FontSlant->"Italic"],
  " \[Lambda] on the order of the wavelength of the microwaves. The power \
density in the food falls off as ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-2\) x/\[Lambda]\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is the distance from the food's surface. "
}], "Text",
  CellTags->"i:117"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  Assuming that all microwave power ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(P\)\(\ \)\)\)]],
  "is dissipated in a slab of meat, that the meat has surface area ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\)\(\ \)\)\)]],
  " on each side of the slab, and the slab thickness is everywhere much \
larger than ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", find ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A slab of cold roast beef, thickness 10 cm and surface area per side ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(A\)\(=\)\),
            "TraditionalForm"], " ", "5000", " ", 
          FormBox[\(cm\^2\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", with initially uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = \(\(10\)\(\ \)\(\[Degree]C\)\(\ \)\)\)]],
  ", is placed in the microwave. The microwave is turned on high, with a \
power  ",
  Cell[BoxData[
      \(TraditionalForm\`P = 5\ \(\(kW\)\(.\)\)\)]],
  " Taking",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Lambda] = 1\ cm\)\)\)]],
  ",  and assuming that both faces of the meat are heated equally, find ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " and determine the time required to heat the roast to at least ",
  Cell[BoxData[
      \(TraditionalForm\`T = \(\(50\)\(\ \)\(\[Degree]C\)\(\ \)\)\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, t)\)]],
  " up to this time. Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "=", " ", 
          FormBox[
            RowBox[{"2", "\[Times]", \(10\^\(-7\)\), " ", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["m",
                    FontSlant->"Plain"], "2"], "/", 
                StyleBox["s",
                  FontSlant->"Plain"]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", and assume insulating boundary conditions at the faces of the meat. "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A child launches a wave on a skipping rope by flicking one end up and \
down. The other end is held fixed by a friend. The speed of waves on the rope \
is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"2", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and the rope is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", " ", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " long. The end held by the child moves according to ",
  Cell[BoxData[
      \(TraditionalForm\`u(x = 0, 
          t) = \[ExponentialE]\^\(\(-50\)\ \((t - 0.2)\)\^2\)\)]],
  ", and at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " the rope is stationary, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(u(x, 0)\), "=", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[PartialD]u\), \(\[PartialD]t\),
                MultilineFunction->None], \((x, 0)\)}], "=", "0"}]}], 
        TraditionalForm]]],
  ". Solve the wave equation for this problem using eigenmodes, and make an \
animation of the resulting motion of the rope for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"1.5", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text",
  CellTags->"i:43"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " A child rotates a skipping rope with a frequency of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(\ \)\(\(f\)\(=\)\)\),
            "TraditionalForm"], 
          FormBox[\(1\ hertz\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". She does so by applying a displacement to the end of the rope (at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ") of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(0, t\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"a", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{
                  StyleBox[
                    OverscriptBox[
                      StyleBox["x",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Bold"], 
                  StyleBox["cos",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["2",
                    FontWeight->"Plain"], 
                  StyleBox["\[Pi]",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["f",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox[
                    OverscriptBox[
                      StyleBox["y",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Bold"], "sin2\[Pi]", " ", "f", " ", "t"}]}], 
              ")"}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"0.05", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The tension in the rope is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"2", " ", 
            StyleBox["N",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The mass per unit length is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "=", 
          RowBox[{"0.5", " ", 
            RowBox[{"kg", "/", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", and the length is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"3", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The other end of the rope is tied to a door handle: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", \(L, t\), ")"}], "=", "0"}], 
        TraditionalForm]]],
  ". Find the solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(t, z\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", assuming that initially the rope satisfies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(z, 0\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(a(1 - z/L)\),
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "."],
              FontWeight->"Bold"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(z, 0\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], "0"}], TraditionalForm]]],
  ", and neglecting gravity. Animate the solution  (using a table of ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "'s) over the time range ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"5", "  ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "). (Careful: there is an exact resonance.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " A stiff wooden rod is fixed to the wall at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and is free at the other end, at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". The rod vibrates in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction (these are compressional vibrations, or sound waves, in the \
rod). These compressional vibrations satisfy the wave equation, "
}], "Text",
  CellTags->"i:46"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(\[PartialD]\^2\/\[PartialD]t\^2\) \(\[Eta](x, t)\)\), 
            "=", 
            RowBox[{
              StyleBox[\(c\^2\),
                
                FontWeight->
                  "Plain"], \(\[PartialD]\^2\/\[PartialD]x\^2\), \(\[Eta](x, 
                t)\)}]}], ","}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  " where \[Eta] is the displacement from equilibrium of an element of the \
rod in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction, and where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of sound in the rod. ['This speed is given in terms of \
Young's modulus ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  ", the mass density per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ", and the cross-sectional area ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 = E\ A/\[Rho]\)]],
  ".] The boundary condition at the free end is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[Eta]\/\[PartialD]x\) \((L, t)\) = 
        0\)]],
  ", and at the fixed end it is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](0, t) = 0\)]],
  ". Find the eigenmodes and their frequencies. Plot the first three \
eigenmodes. "
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " The horizontal wooden rod of the previous problem also supports \
transverse displacements (in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction). However, these transverse displacements ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " satisfy a ",
  StyleBox["biharmonic wave equation",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:44"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
          t)\) = \(-\(D\/\[Rho]\)\) \(\[PartialD]\^4\/\[PartialD]x\^4\) \(y(
          x, t)\)\)\(,\)\)\)]]], "NE3",
  CellTags->"(4.2.47)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(D\)\(=\)\),
            "TraditionalForm"], " ", "\[Pi]", " ", 
          FormBox[\(a\^4\ E/4\),
            "TraditionalForm"]}], TraditionalForm]]],
  " for a cylindrical rod of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " is Young's modulus. [See ",
  ButtonBox["Landau and Lifshitz (1986, Sec. 25)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] The boundary condition at the fixed end, ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", is ",
  Cell[BoxData[
      \(TraditionalForm\`y = \(\[PartialD]y\/\[PartialD]x = 0\)\)]],
  ". At the free end, ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", the correct boundary condition is"
}], "Text"],

Cell[TextData[{
  " \t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 y\/\[PartialD]x\^2 = \(\[PartialD]\^3 \
y\/\[PartialD]x\^3 = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find the first three eigenfrequencies of the rod, and plot the \
corresponding eigenmodes. (Hint: The eigenfrequencies satisfy a \
transcendental equation. Solve this equation numerically using ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", after choosing suitable dimensionless variables.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show numerically that these three eigenmodes are orthogonal with respect \
to the integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\[DifferentialD]x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find and plot the equilibrium shape of the rod if it is subjected to a \
uniform gravitational acceleration ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-y\)\)]],
  "-direction. How does the maximum sag scale with the length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " of the rod? [You may wish to compare this result with that obtained in \
Exercise (6) of Sec. ",
  ButtonBox["9.10",
    ButtonData:>{"Chapter9.nb", "c:59"},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text",
  CellTags->"i:45"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Sound waves are compressional waves that satisfy the wave equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\(\(\[PartialD]t\^2\)\(\ \)\)\) \(\
\[Eta](x, t)\) = \(c\^2\) \(\[PartialD]\^2\/\[PartialD]x\^2\) \(\[Eta](x, 
            t)\)\)]],
  ", "
}], "NE3",
  CellTags->"(4.2.48)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](x, t)\)]],
  " is the displacement of a fluid element from its equilibrium position \
(this displacement is in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction, along the direction of the wave). In a gas the sound speed is \
given by the equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(\[Gamma]\ p/\[ScriptCapitalM]\)\)]],
  ","
}], "NE3",
  CellTags->{"i:47", "(4.2.49)"}],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is the pressure of the equilibrium fluid, \[ScriptCapitalM] is the mass \
density, and \[Gamma] is the ratio of specific heats (equal to 5/3 for an \
ideal gas of point particles). "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the speed of sound in an ideal gas consisting of helium atoms at 1 \
atmosphere and a temperature of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"300", " ", 
          StyleBox["K",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". (Recall that ",
  Cell[BoxData[
      \(TraditionalForm\`p = n\ k\_B\ T\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the number density)."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A simple gas-filled piston consists of two flat parallel plates. One is \
fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and the other oscillates according to ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\ sin\ \[Omega]\_o\ t\)]],
  ". The boundary conditions are determined by the fact that the gas adjacent \
to the plates must move with the plates. Therefore, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](0, t)\  = \ a\ sin\ \(\[Omega]\_o\) t\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](L, t)\  = \ 0\)]],
  " "
}], "Text"],

Cell[TextData[{
  "(provided that ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is small). Solve for the motion of the gas between the plates, assuming \
that the gas is initially stationary."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " for which secular growth of the sound wave occurs (i.e., determine when \
there is an exact resonance)"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Water collects in a long straight channel with a sloping bottom and a \
vertical wall at ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " (see Fig. ",
  ButtonBox["4.2",
    ButtonData:>"Fig. 4.2",
    ButtonStyle->"Hyperlink"],
  "). The water depth as function of transverse position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\  = \[Alpha]\ x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < a\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a dimensionless constant giving the slope of the channel bottom."
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Assuming that we can use the shallow water equations, show that the \
horizontal fluid displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](x, t)\)]],
  ", and wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, t)\)]],
  " are related by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z = \(-\[PartialD]\((\(h(
                    x)\) \[Eta])\)\)/\(\(\[PartialD]x\)\(\ \)\)\)]],
  ","
}], "NE3",
  CellTags->"(4.2.50)"],

Cell[" and are determined by the wave equation", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( z(x, t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{
            FractionBox["\[PartialD]", \(\[PartialD]x\),
              MultilineFunction->None], 
            RowBox[{"(", 
              RowBox[{\(\(c\^2\)(x)\), 
                FractionBox[\(\[PartialD]z\), \(\[PartialD]x\),
                  MultilineFunction->None]}], ")"}]}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->{"i:48", "(4.2.51)"}],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"where", 
          FormBox[\(c(x) = \@\(g\ \(h(x)\)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45249 
%%ImageSize: 884 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00107735 0.0107735 0.00107735 [
[ 0 0 0 0 ]
[ 1 .45249 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45249 L
0 .45249 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01077 translate
.95238 .43095 scale
2652 string
884 400 8 [884 0 0 400 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001164951164951164950F748F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000276F93
276F93276F93286091286091286091286091155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000011528F11528F276F93276F93
276F93276F93286091286091286091286091155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000019649311528F11528F11528F11528F11528F276F93276F93
276F93276F93286091286091286091286091155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
115B8F19649319649319649319649311528F11528F11528F11528F11528F276F93276F93
276F93276F93286091286091286091286091155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000E7C8D0E7C8D0E7C8D
0E7C8D0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96116C962A2F6C2A2F6C
2A2F6C2A2F6C1558831558831558831558830F748F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001558831558831558831558830E7C8D0E7C8D0E7C8D
0E7C8D0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96116C962A2F6C2A2F6C
2A2F6C2A2F6C1558831558831558831558830F748F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000115B8F115B8F115B8F115B8F1558831558831558831558830E7C8D0E7C8D0E7C8D
0E7C8D0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96116C962A2F6C2A2F6C
2A2F6C2A2F6C1558831558831558831558830F748F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000196493196493196493
196493115B8F115B8F115B8F115B8F1558831558831558831558830E7C8D0E7C8D0E7C8D
0E7C8D0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96116C962A2F6C2A2F6C
2A2F6C2A2F6C1558831558831558831558830F748F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000155883155883155883116C96116C96116C96
116C960F748F0F748F0F748F0F748F2D54802D54802D54802D5480005B8D005B8D005B8D
005B8D19649319649319649319649305538A05538A05538A05538A05538A05538A05538A
05538A05538A2B83992B83992B83992B8399116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000005538A05538A155883155883155883155883155883116C96116C96116C96
116C960F748F0F748F0F748F0F748F2D54802D54802D54802D5480005B8D005B8D005B8D
005B8D19649319649319649319649305538A05538A05538A05538A05538A05538A05538A
05538A05538A2B83992B83992B83992B8399116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000C8E870C8E87
05538A05538A05538A05538A155883155883155883155883155883116C96116C96116C96
116C960F748F0F748F0F748F0F748F2D54802D54802D54802D5480005B8D005B8D005B8D
005B8D19649319649319649319649305538A05538A05538A05538A05538A05538A05538A
05538A05538A2B83992B83992B83992B8399116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000011528F0C8E870C8E870C8E870C8E87
05538A05538A05538A05538A155883155883155883155883155883116C96116C96116C96
116C960F748F0F748F0F748F0F748F2D54802D54802D54802D5480005B8D005B8D005B8D
005B8D19649319649319649319649305538A05538A05538A05538A05538A05538A05538A
05538A05538A2B83992B83992B83992B8399116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000115B8F115B8F115B8F115B8F115B8F196493196493196493196493
085B95085B95085B95085B95155883155883155883155883155883276F93276F93276F93
276F93276F93276F93276F93276F9316427B16427B16427B16427B116C96116C96116C96
116C96276F93276F93276F93276F93045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000005538A
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F196493196493196493196493
085B95085B95085B95085B95155883155883155883155883155883276F93276F93276F93
276F93276F93276F93276F93276F9316427B16427B16427B16427B116C96116C96116C96
116C96276F93276F93276F93276F93045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000005538A05538A05538A05538A
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F196493196493196493196493
085B95085B95085B95085B95155883155883155883155883155883276F93276F93276F93
276F93276F93276F93276F93276F9316427B16427B16427B16427B116C96116C96116C96
116C96276F93276F93276F93276F93045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000F748F0F748F0F748F05538A05538A05538A05538A
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F196493196493196493196493
085B95085B95085B95085B95155883155883155883155883155883276F93276F93276F93
276F93276F93276F93276F93276F9316427B16427B16427B16427B116C96116C96116C96
116C96276F93276F93276F93276F93045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000002A2F6C116495116495116495116495116495044582044582044582044582
16427B16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F
11528F11528F11528F11528F2D54802D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D438CA2438CA2438CA2438CA22B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA211648D11648D
11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000002A2F6C
2A2F6C2A2F6C2A2F6C116495116495116495116495116495044582044582044582044582
16427B16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F
11528F11528F11528F11528F2D54802D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D438CA2438CA2438CA2438CA22B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA211648D11648D
11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000005538A05538A05538A2A2F6C
2A2F6C2A2F6C2A2F6C116495116495116495116495116495044582044582044582044582
16427B16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F
11528F11528F11528F11528F2D54802D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D438CA2438CA2438CA2438CA22B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA211648D11648D
11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000011648D11648D05538A05538A05538A05538A2A2F6C
2A2F6C2A2F6C2A2F6C116495116495116495116495116495044582044582044582044582
16427B16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F
11528F11528F11528F11528F2D54802D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D438CA2438CA2438CA2438CA22B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA211648D11648D
11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000005538A05538A11648D11648D11648D11648D05538A05538A05538A05538A2A2F6C
2A2F6C2A2F6C2A2F6C116495116495116495116495116495044582044582044582044582
16427B16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F
11528F11528F11528F11528F2D54802D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D438CA2438CA2438CA2438CA22B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA2438CA211648D11648D
11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000002A2F6C05538A
05538A05538A05538A04648304648304648304648316427B16427B16427B16427B2A2F6C
2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D11648D116C96116C96116C96116C96
276F93276F93276F93276F93116C96116C96116C96116C965B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F276F93276F93276F93276F93276F930C8E870C8E870C8E87
0C8E87276F93276F93276F93276F9311648D11648D11648D11648D2A729D2A729D2A729D
2A729D05538A05538A05538A05538A05538A05538A05538A05538A05538A0E7C8D0E7C8D
0E7C8D0E7C8D11648D11648D11648D11648D19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002A2F6C2A2F6C2A2F6C2A2F6C05538A
05538A05538A05538A04648304648304648304648316427B16427B16427B16427B2A2F6C
2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D11648D116C96116C96116C96116C96
276F93276F93276F93276F93116C96116C96116C96116C965B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F276F93276F93276F93276F93276F930C8E870C8E870C8E87
0C8E87276F93276F93276F93276F9311648D11648D11648D11648D2A729D2A729D2A729D
2A729D05538A05538A05538A05538A05538A05538A05538A05538A05538A0E7C8D0E7C8D
0E7C8D0E7C8D11648D11648D11648D11648D19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000019588F19588F19588F19588F2A2F6C2A2F6C2A2F6C2A2F6C05538A
05538A05538A05538A04648304648304648304648316427B16427B16427B16427B2A2F6C
2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D11648D116C96116C96116C96116C96
276F93276F93276F93276F93116C96116C96116C96116C965B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F276F93276F93276F93276F93276F930C8E870C8E870C8E87
0C8E87276F93276F93276F93276F9311648D11648D11648D11648D2A729D2A729D2A729D
2A729D05538A05538A05538A05538A05538A05538A05538A05538A05538A0E7C8D0E7C8D
0E7C8D0E7C8D11648D11648D11648D11648D19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000016427B
16427B16427B19588F19588F19588F19588F19588F2A2F6C2A2F6C2A2F6C2A2F6C05538A
05538A05538A05538A04648304648304648304648316427B16427B16427B16427B2A2F6C
2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D11648D116C96116C96116C96116C96
276F93276F93276F93276F93116C96116C96116C96116C965B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F276F93276F93276F93276F93276F930C8E870C8E870C8E87
0C8E87276F93276F93276F93276F9311648D11648D11648D11648D2A729D2A729D2A729D
2A729D05538A05538A05538A05538A05538A05538A05538A05538A05538A0E7C8D0E7C8D
0E7C8D0E7C8D11648D11648D11648D11648D19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002A729D2A729D2A729D0C8E870C8E87
0C8E870C8E87116495116495116495116495116495095B8D095B8D095B8D095B8D045B84
045B84045B84045B8419649319649319649319649305538A05538A05538A05538A155883
1558831558831558832A729D2A729D2A729D2A729D2A729D286091286091286091286091
11648D11648D11648D11648D1558831558831558831558830C8E870C8E870C8E870C8E87
40779A40779A40779A40779A2B83992B83992B83992B83992B839919588F19588F19588F
19588F19588F19588F19588F19588F19649319649319649319649340779A40779A40779A
40779A5B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D2A729D116495116495
11649511649516427B16427B16427B16427B2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E87
0C8E870C8E87116495116495116495116495116495095B8D095B8D095B8D095B8D045B84
045B84045B84045B8419649319649319649319649305538A05538A05538A05538A155883
1558831558831558832A729D2A729D2A729D2A729D2A729D286091286091286091286091
11648D11648D11648D11648D1558831558831558831558830C8E870C8E870C8E870C8E87
40779A40779A40779A40779A2B83992B83992B83992B83992B839919588F19588F19588F
19588F19588F19588F19588F19588F19649319649319649319649340779A40779A40779A
40779A5B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D2A729D116495116495
11649511649516427B16427B16427B16427B2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000019588F
19588F19588F0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E87
0C8E870C8E87116495116495116495116495116495095B8D095B8D095B8D095B8D045B84
045B84045B84045B8419649319649319649319649305538A05538A05538A05538A155883
1558831558831558832A729D2A729D2A729D2A729D2A729D286091286091286091286091
11648D11648D11648D11648D1558831558831558831558830C8E870C8E870C8E870C8E87
40779A40779A40779A40779A2B83992B83992B83992B83992B839919588F19588F19588F
19588F19588F19588F19588F19588F19649319649319649319649340779A40779A40779A
40779A5B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D2A729D116495116495
11649511649516427B16427B16427B16427B2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000005B8D005B8D005B8D19588F19588F
19588F19588F0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E87
0C8E870C8E87116495116495116495116495116495095B8D095B8D095B8D095B8D045B84
045B84045B84045B8419649319649319649319649305538A05538A05538A05538A155883
1558831558831558832A729D2A729D2A729D2A729D2A729D286091286091286091286091
11648D11648D11648D11648D1558831558831558831558830C8E870C8E870C8E870C8E87
40779A40779A40779A40779A2B83992B83992B83992B83992B839919588F19588F19588F
19588F19588F19588F19588F19588F19649319649319649319649340779A40779A40779A
40779A5B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D2A729D116495116495
11649511649516427B16427B16427B16427B2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000155883155883155883286091286091286091286091046483046483
0464830464830C8E870C8E870C8E870C8E8719588F19588F19588F19588F11648D11648D
11648D11648D40779A40779A40779A40779A40779A0F748F0F748F0F748F0F748F40779A
40779A40779A40779A15588315588315588315588311648D11648D11648D11648D16427B
16427B16427B16427B196493196493196493196493196493095B8D095B8D095B8D095B8D
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D
276F93276F93276F93276F932860912860912860912860912860912A2F6C2A2F6C2A2F6C
2A2F6C0464830464830464830464832860912860912860912860910C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B8399276F93276F93276F93276F93276F93276F93276F93
276F93276F932B83992B83992B83992B83992D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000002A729D2A729D
2A729D155883155883155883155883155883286091286091286091286091046483046483
0464830464830C8E870C8E870C8E870C8E8719588F19588F19588F19588F11648D11648D
11648D11648D40779A40779A40779A40779A40779A0F748F0F748F0F748F0F748F40779A
40779A40779A40779A15588315588315588315588311648D11648D11648D11648D16427B
16427B16427B16427B196493196493196493196493196493095B8D095B8D095B8D095B8D
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D
276F93276F93276F93276F932860912860912860912860912860912A2F6C2A2F6C2A2F6C
2A2F6C0464830464830464830464832860912860912860912860910C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B8399276F93276F93276F93276F93276F93276F93276F93
276F93276F932B83992B83992B83992B83992D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000019588F19588F19588F2A729D2A729D2A729D
2A729D155883155883155883155883155883286091286091286091286091046483046483
0464830464830C8E870C8E870C8E870C8E8719588F19588F19588F19588F11648D11648D
11648D11648D40779A40779A40779A40779A40779A0F748F0F748F0F748F0F748F40779A
40779A40779A40779A15588315588315588315588311648D11648D11648D11648D16427B
16427B16427B16427B196493196493196493196493196493095B8D095B8D095B8D095B8D
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D
276F93276F93276F93276F932860912860912860912860912860912A2F6C2A2F6C2A2F6C
2A2F6C0464830464830464830464832860912860912860912860910C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B8399276F93276F93276F93276F93276F93276F93276F93
276F93276F932B83992B83992B83992B83992D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000E7C8D0E7C8D0E7C8D19588F19588F19588F19588F2A729D2A729D2A729D
2A729D155883155883155883155883155883286091286091286091286091046483046483
0464830464830C8E870C8E870C8E870C8E8719588F19588F19588F19588F11648D11648D
11648D11648D40779A40779A40779A40779A40779A0F748F0F748F0F748F0F748F40779A
40779A40779A40779A15588315588315588315588311648D11648D11648D11648D16427B
16427B16427B16427B196493196493196493196493196493095B8D095B8D095B8D095B8D
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D
276F93276F93276F93276F932860912860912860912860912860912A2F6C2A2F6C2A2F6C
2A2F6C0464830464830464830464832860912860912860912860910C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B8399276F93276F93276F93276F93276F93276F93276F93
276F93276F932B83992B83992B83992B83992D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000019588F19588F
19588F005B8D005B8D005B8D005B8D085B95085B95085B95085B950E7C8D0E7C8D0E7C8D
0E7C8D19649319649319649319649319649311648D11648D11648D11648D276F93276F93
276F93276F9315588315588315588315588316427B16427B16427B16427B08648D08648D
08648D08648D438CA2438CA2438CA2438CA2438CA2196493196493196493196493196493
1964931964931964932D54802D54802D54802D54802A2F6C2A2F6C2A2F6C2A2F6C196493
196493196493196493276F93276F93276F93276F93276F9319588F19588F19588F19588F
28609128609128609128609105538A05538A05538A05538A095B8D095B8D095B8D095B8D
2860912860912860912860910445820445820445820445820445820C6C8A0C6C8A0C6C8A
0C6C8A19649319649319649319649319588F19588F19588F19588F276F93276F93276F93
276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F0F748F2D54802D5480
2D54802D548016427B16427B16427B16427B2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000F748F0F748F0F748F19588F19588F19588F
19588F005B8D005B8D005B8D005B8D085B95085B95085B95085B950E7C8D0E7C8D0E7C8D
0E7C8D19649319649319649319649319649311648D11648D11648D11648D276F93276F93
276F93276F9315588315588315588315588316427B16427B16427B16427B08648D08648D
08648D08648D438CA2438CA2438CA2438CA2438CA2196493196493196493196493196493
1964931964931964932D54802D54802D54802D54802A2F6C2A2F6C2A2F6C2A2F6C196493
196493196493196493276F93276F93276F93276F93276F9319588F19588F19588F19588F
28609128609128609128609105538A05538A05538A05538A095B8D095B8D095B8D095B8D
2860912860912860912860910445820445820445820445820445820C6C8A0C6C8A0C6C8A
0C6C8A19649319649319649319649319588F19588F19588F19588F276F93276F93276F93
276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F0F748F2D54802D5480
2D54802D548016427B16427B16427B16427B2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000001558831558831558830F748F0F748F0F748F0F748F19588F19588F19588F
19588F005B8D005B8D005B8D005B8D085B95085B95085B95085B950E7C8D0E7C8D0E7C8D
0E7C8D19649319649319649319649319649311648D11648D11648D11648D276F93276F93
276F93276F9315588315588315588315588316427B16427B16427B16427B08648D08648D
08648D08648D438CA2438CA2438CA2438CA2438CA2196493196493196493196493196493
1964931964931964932D54802D54802D54802D54802A2F6C2A2F6C2A2F6C2A2F6C196493
196493196493196493276F93276F93276F93276F93276F9319588F19588F19588F19588F
28609128609128609128609105538A05538A05538A05538A095B8D095B8D095B8D095B8D
2860912860912860912860910445820445820445820445820445820C6C8A0C6C8A0C6C8A
0C6C8A19649319649319649319649319588F19588F19588F19588F276F93276F93276F93
276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F0F748F2D54802D5480
2D54802D548016427B16427B16427B16427B2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000115B8F
1558831558831558831558831558830F748F0F748F0F748F0F748F19588F19588F19588F
19588F005B8D005B8D005B8D005B8D085B95085B95085B95085B950E7C8D0E7C8D0E7C8D
0E7C8D19649319649319649319649319649311648D11648D11648D11648D276F93276F93
276F93276F9315588315588315588315588316427B16427B16427B16427B08648D08648D
08648D08648D438CA2438CA2438CA2438CA2438CA2196493196493196493196493196493
1964931964931964932D54802D54802D54802D54802A2F6C2A2F6C2A2F6C2A2F6C196493
196493196493196493276F93276F93276F93276F93276F9319588F19588F19588F19588F
28609128609128609128609105538A05538A05538A05538A095B8D095B8D095B8D095B8D
2860912860912860912860910445820445820445820445820445820C6C8A0C6C8A0C6C8A
0C6C8A19649319649319649319649319588F19588F19588F19588F276F93276F93276F93
276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F0F748F2D54802D5480
2D54802D548016427B16427B16427B16427B2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002B83992A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F93276F9319649319649319649319649319588F19588F19588F
19588F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A438CA2438CA2438CA2438CA2438CA2196493196493196493196493438CA2438CA2
438CA2438CA22D54802D54802D54802D5480095B8D095B8D095B8D095B8D2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D0C8E87
0C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F276F93
276F93276F93276F9319588F19588F19588F19588F19588F0F748F0F748F0F748F0F748F
05538A05538A05538A05538A1164951164951164951164950F748F0F748F0F748F0F748F
0C8E870C8E870C8E870C8E8719588F19588F19588F19588F19588F2A729D2A729D2A729D
2A729D2A2F6C2A2F6C2A2F6C2A2F6C0C8E870C8E870C8E870C8E870C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F0F748F2B83992B8399
2B83992B83992D54802D54802D54802D5480116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002B83992B83992B83992B83992B83992A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F93276F9319649319649319649319649319588F19588F19588F
19588F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A438CA2438CA2438CA2438CA2438CA2196493196493196493196493438CA2438CA2
438CA2438CA22D54802D54802D54802D5480095B8D095B8D095B8D095B8D2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D0C8E87
0C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F276F93
276F93276F93276F9319588F19588F19588F19588F19588F0F748F0F748F0F748F0F748F
05538A05538A05538A05538A1164951164951164951164950F748F0F748F0F748F0F748F
0C8E870C8E870C8E870C8E8719588F19588F19588F19588F19588F2A729D2A729D2A729D
2A729D2A2F6C2A2F6C2A2F6C2A2F6C0C8E870C8E870C8E870C8E870C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F0F748F2B83992B8399
2B83992B83992D54802D54802D54802D5480116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000002A729D
2B83992B83992B83992B83992B83992B83992B83992B83992A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F93276F9319649319649319649319649319588F19588F19588F
19588F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A438CA2438CA2438CA2438CA2438CA2196493196493196493196493438CA2438CA2
438CA2438CA22D54802D54802D54802D5480095B8D095B8D095B8D095B8D2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D0C8E87
0C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F276F93
276F93276F93276F9319588F19588F19588F19588F19588F0F748F0F748F0F748F0F748F
05538A05538A05538A05538A1164951164951164951164950F748F0F748F0F748F0F748F
0C8E870C8E870C8E870C8E8719588F19588F19588F19588F19588F2A729D2A729D2A729D
2A729D2A2F6C2A2F6C2A2F6C2A2F6C0C8E870C8E870C8E870C8E870C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F0F748F2B83992B8399
2B83992B83992D54802D54802D54802D5480116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000002A729D2A729D2A729D2A729D
2B83992B83992B83992B83992B83992B83992B83992B83992A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F93276F9319649319649319649319649319588F19588F19588F
19588F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A438CA2438CA2438CA2438CA2438CA2196493196493196493196493438CA2438CA2
438CA2438CA22D54802D54802D54802D5480095B8D095B8D095B8D095B8D2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D0C8E87
0C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F276F93
276F93276F93276F9319588F19588F19588F19588F19588F0F748F0F748F0F748F0F748F
05538A05538A05538A05538A1164951164951164951164950F748F0F748F0F748F0F748F
0C8E870C8E870C8E870C8E8719588F19588F19588F19588F19588F2A729D2A729D2A729D
2A729D2A2F6C2A2F6C2A2F6C2A2F6C0C8E870C8E870C8E870C8E870C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F0F748F2B83992B8399
2B83992B83992D54802D54802D54802D5480116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000F748F0F748F0F748F0F748F155883155883155883155883
2A729D2A729D2A729D2A729D84A8B284A8B284A8B284A8B2286091286091286091286091
115B8F115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D11648D11648D11648D11648D11649511649511649511649511648D11648D11648D
11648D11648D11648D11648D11648D11648D15588315588315588315588384A8B284A8B2
84A8B284A8B204458204458204458204458240779A40779A40779A40779A11648D11648D
11648D11648D1964931964931964931964931964932B83992B83992B83992B8399116495
116495116495116495095B8D095B8D095B8D095B8D116C96116C96116C96116C96116495
1164951164951164951164951164951164951164951164950F748F0F748F0F748F0F748F
40779A40779A40779A40779A2A729D2A729D2A729D2A729D116C96116C96116C96116C96
16427B16427B16427B16427B11648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D1558831558831558831558831164951164951164951164955B90A55B90A55B90A5
5B90A540779A40779A40779A40779A1964931964931964931964931964932B83992B8399
2B83992B83992B83992B83992B83992B83992A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1558831558831558831558830F748F0F748F0F748F0F748F155883155883155883155883
2A729D2A729D2A729D2A729D84A8B284A8B284A8B284A8B2286091286091286091286091
115B8F115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D11648D11648D11648D11648D11649511649511649511649511648D11648D11648D
11648D11648D11648D11648D11648D11648D15588315588315588315588384A8B284A8B2
84A8B284A8B204458204458204458204458240779A40779A40779A40779A11648D11648D
11648D11648D1964931964931964931964931964932B83992B83992B83992B8399116495
116495116495116495095B8D095B8D095B8D095B8D116C96116C96116C96116C96116495
1164951164951164951164951164951164951164951164950F748F0F748F0F748F0F748F
40779A40779A40779A40779A2A729D2A729D2A729D2A729D116C96116C96116C96116C96
16427B16427B16427B16427B11648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D1558831558831558831558831164951164951164951164955B90A55B90A55B90A5
5B90A540779A40779A40779A40779A1964931964931964931964931964932B83992B8399
2B83992B83992B83992B83992B83992B83992A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000F748F0F748F155883
1558831558831558831558830F748F0F748F0F748F0F748F155883155883155883155883
2A729D2A729D2A729D2A729D84A8B284A8B284A8B284A8B2286091286091286091286091
115B8F115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D11648D11648D11648D11648D11649511649511649511649511648D11648D11648D
11648D11648D11648D11648D11648D11648D15588315588315588315588384A8B284A8B2
84A8B284A8B204458204458204458204458240779A40779A40779A40779A11648D11648D
11648D11648D1964931964931964931964931964932B83992B83992B83992B8399116495
116495116495116495095B8D095B8D095B8D095B8D116C96116C96116C96116C96116495
1164951164951164951164951164951164951164951164950F748F0F748F0F748F0F748F
40779A40779A40779A40779A2A729D2A729D2A729D2A729D116C96116C96116C96116C96
16427B16427B16427B16427B11648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D1558831558831558831558831164951164951164951164955B90A55B90A55B90A5
5B90A540779A40779A40779A40779A1964931964931964931964931964932B83992B8399
2B83992B83992B83992B83992B83992B83992A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001964931964930F748F0F748F0F748F0F748F155883
1558831558831558831558830F748F0F748F0F748F0F748F155883155883155883155883
2A729D2A729D2A729D2A729D84A8B284A8B284A8B284A8B2286091286091286091286091
115B8F115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D11648D11648D11648D11648D11649511649511649511649511648D11648D11648D
11648D11648D11648D11648D11648D11648D15588315588315588315588384A8B284A8B2
84A8B284A8B204458204458204458204458240779A40779A40779A40779A11648D11648D
11648D11648D1964931964931964931964931964932B83992B83992B83992B8399116495
116495116495116495095B8D095B8D095B8D095B8D116C96116C96116C96116C96116495
1164951164951164951164951164951164951164951164950F748F0F748F0F748F0F748F
40779A40779A40779A40779A2A729D2A729D2A729D2A729D116C96116C96116C96116C96
16427B16427B16427B16427B11648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D1558831558831558831558831164951164951164951164955B90A55B90A55B90A5
5B90A540779A40779A40779A40779A1964931964931964931964931964932B83992B8399
2B83992B83992B83992B83992B83992B83992A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002B83992B83991964931964931964931964930F748F0F748F0F748F0F748F155883
1558831558831558831558830F748F0F748F0F748F0F748F155883155883155883155883
2A729D2A729D2A729D2A729D84A8B284A8B284A8B284A8B2286091286091286091286091
115B8F115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D11648D11648D11648D11648D11649511649511649511649511648D11648D11648D
11648D11648D11648D11648D11648D11648D15588315588315588315588384A8B284A8B2
84A8B284A8B204458204458204458204458240779A40779A40779A40779A11648D11648D
11648D11648D1964931964931964931964931964932B83992B83992B83992B8399116495
116495116495116495095B8D095B8D095B8D095B8D116C96116C96116C96116C96116495
1164951164951164951164951164951164951164951164950F748F0F748F0F748F0F748F
40779A40779A40779A40779A2A729D2A729D2A729D2A729D116C96116C96116C96116C96
16427B16427B16427B16427B11648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D1558831558831558831558831164951164951164951164955B90A55B90A55B90A5
5B90A540779A40779A40779A40779A1964931964931964931964931964932B83992B8399
2B83992B83992B83992B83992B83992B83992A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000019649311648D
11648D11648D11648D116C96116C96116C96116C9684A8B284A8B284A8B284A8B20F748F
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
04458204458204458204458211648D11648D11648D11648D046483046483046483046483
04458204458204458204458204458240779A40779A40779A40779A438CA2438CA2438CA2
438CA2196493196493196493196493196493196493196493196493116C96116C96116C96
116C960C8E870C8E870C8E870C8E870C8E871164951164951164951164952D54802D5480
2D54802D5480116495116495116495116495276F93276F93276F93276F932B83992B8399
2B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F116495
11649511649511649511528F11528F11528F11528F11528F286091286091286091286091
438CA2438CA2438CA2438CA211648D11648D11648D11648D84A8B284A8B284A8B284A8B2
16427B16427B16427B16427B2D54802D54802D54802D54802D5480276F93276F93276F93
276F93095B8D095B8D095B8D095B8D2860912860912860912860912A729D2A729D2A729D
2A729D19588F19588F19588F19588F11528F11528F11528F11528F11528F5B90A55B90A5
5B90A55B90A5095B8D095B8D095B8D095B8D16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000045B8419649319649319649319649311648D
11648D11648D11648D116C96116C96116C96116C9684A8B284A8B284A8B284A8B20F748F
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
04458204458204458204458211648D11648D11648D11648D046483046483046483046483
04458204458204458204458204458240779A40779A40779A40779A438CA2438CA2438CA2
438CA2196493196493196493196493196493196493196493196493116C96116C96116C96
116C960C8E870C8E870C8E870C8E870C8E871164951164951164951164952D54802D5480
2D54802D5480116495116495116495116495276F93276F93276F93276F932B83992B8399
2B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F116495
11649511649511649511528F11528F11528F11528F11528F286091286091286091286091
438CA2438CA2438CA2438CA211648D11648D11648D11648D84A8B284A8B284A8B284A8B2
16427B16427B16427B16427B2D54802D54802D54802D54802D5480276F93276F93276F93
276F93095B8D095B8D095B8D095B8D2860912860912860912860912A729D2A729D2A729D
2A729D19588F19588F19588F19588F11528F11528F11528F11528F11528F5B90A55B90A5
5B90A55B90A5095B8D095B8D095B8D095B8D16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000F748F045B84045B84045B84045B8419649319649319649319649311648D
11648D11648D11648D116C96116C96116C96116C9684A8B284A8B284A8B284A8B20F748F
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
04458204458204458204458211648D11648D11648D11648D046483046483046483046483
04458204458204458204458204458240779A40779A40779A40779A438CA2438CA2438CA2
438CA2196493196493196493196493196493196493196493196493116C96116C96116C96
116C960C8E870C8E870C8E870C8E870C8E871164951164951164951164952D54802D5480
2D54802D5480116495116495116495116495276F93276F93276F93276F932B83992B8399
2B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F116495
11649511649511649511528F11528F11528F11528F11528F286091286091286091286091
438CA2438CA2438CA2438CA211648D11648D11648D11648D84A8B284A8B284A8B284A8B2
16427B16427B16427B16427B2D54802D54802D54802D54802D5480276F93276F93276F93
276F93095B8D095B8D095B8D095B8D2860912860912860912860912A729D2A729D2A729D
2A729D19588F19588F19588F19588F11528F11528F11528F11528F11528F5B90A55B90A5
5B90A55B90A5095B8D095B8D095B8D095B8D16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000F748F
0F748F0F748F0F748F045B84045B84045B84045B8419649319649319649319649311648D
11648D11648D11648D116C96116C96116C96116C9684A8B284A8B284A8B284A8B20F748F
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
04458204458204458204458211648D11648D11648D11648D046483046483046483046483
04458204458204458204458204458240779A40779A40779A40779A438CA2438CA2438CA2
438CA2196493196493196493196493196493196493196493196493116C96116C96116C96
116C960C8E870C8E870C8E870C8E870C8E871164951164951164951164952D54802D5480
2D54802D5480116495116495116495116495276F93276F93276F93276F932B83992B8399
2B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F116495
11649511649511649511528F11528F11528F11528F11528F286091286091286091286091
438CA2438CA2438CA2438CA211648D11648D11648D11648D84A8B284A8B284A8B284A8B2
16427B16427B16427B16427B2D54802D54802D54802D54802D5480276F93276F93276F93
276F93095B8D095B8D095B8D095B8D2860912860912860912860912A729D2A729D2A729D
2A729D19588F19588F19588F19588F11528F11528F11528F11528F11528F5B90A55B90A5
5B90A55B90A5095B8D095B8D095B8D095B8D16427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000040779A40779A40779A155883155883
1558831558831558831558831558831558831558830C6C8A0C6C8A0C6C8A0C6C8A11528F
11528F11528F11528F116495116495116495116495095B8D095B8D095B8D095B8D11648D
11648D11648D11648D11648D11649511649511649511649519588F19588F19588F19588F
0E7C8D0E7C8D0E7C8D0E7C8D005B8D005B8D005B8D005B8D196493196493196493196493
2B83992B83992B83992B83992B8399116C96116C96116C96116C96276F93276F93276F93
276F935B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A55B90A55B90A5
5B90A5116495116495116495116495116495196493196493196493196493005B8D005B8D
005B8D005B8D08648D08648D08648D08648D11648D11648D11648D11648D116C96116C96
116C96116C9619588F19588F19588F19588F19588F2A729D2A729D2A729D2A729D116C96
116C96116C96116C96196493196493196493196493276F93276F93276F93276F93155883
1558831558831558831164951164951164951164951164955B90A55B90A55B90A55B90A5
40779A40779A40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C96
2D54802D54802D54802D548011648D11648D11648D11648D11648D2B83992B83992B8399
2B8399155883155883155883155883116C96116C96116C96116C9616427B16427B16427B
16427B095B8D095B8D095B8D095B8D11528F11528F11528F11528F11528F2B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000005538A05538A05538A40779A40779A40779A40779A155883155883
1558831558831558831558831558831558831558830C6C8A0C6C8A0C6C8A0C6C8A11528F
11528F11528F11528F116495116495116495116495095B8D095B8D095B8D095B8D11648D
11648D11648D11648D11648D11649511649511649511649519588F19588F19588F19588F
0E7C8D0E7C8D0E7C8D0E7C8D005B8D005B8D005B8D005B8D196493196493196493196493
2B83992B83992B83992B83992B8399116C96116C96116C96116C96276F93276F93276F93
276F935B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A55B90A55B90A5
5B90A5116495116495116495116495116495196493196493196493196493005B8D005B8D
005B8D005B8D08648D08648D08648D08648D11648D11648D11648D11648D116C96116C96
116C96116C9619588F19588F19588F19588F19588F2A729D2A729D2A729D2A729D116C96
116C96116C96116C96196493196493196493196493276F93276F93276F93276F93155883
1558831558831558831164951164951164951164951164955B90A55B90A55B90A55B90A5
40779A40779A40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C96
2D54802D54802D54802D548011648D11648D11648D11648D11648D2B83992B83992B8399
2B8399155883155883155883155883116C96116C96116C96116C9616427B16427B16427B
16427B095B8D095B8D095B8D095B8D11528F11528F11528F11528F11528F2B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
11648D11648D05538A05538A05538A05538A40779A40779A40779A40779A155883155883
1558831558831558831558831558831558831558830C6C8A0C6C8A0C6C8A0C6C8A11528F
11528F11528F11528F116495116495116495116495095B8D095B8D095B8D095B8D11648D
11648D11648D11648D11648D11649511649511649511649519588F19588F19588F19588F
0E7C8D0E7C8D0E7C8D0E7C8D005B8D005B8D005B8D005B8D196493196493196493196493
2B83992B83992B83992B83992B8399116C96116C96116C96116C96276F93276F93276F93
276F935B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A55B90A55B90A5
5B90A5116495116495116495116495116495196493196493196493196493005B8D005B8D
005B8D005B8D08648D08648D08648D08648D11648D11648D11648D11648D116C96116C96
116C96116C9619588F19588F19588F19588F19588F2A729D2A729D2A729D2A729D116C96
116C96116C96116C96196493196493196493196493276F93276F93276F93276F93155883
1558831558831558831164951164951164951164951164955B90A55B90A55B90A55B90A5
40779A40779A40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C96
2D54802D54802D54802D548011648D11648D11648D11648D11648D2B83992B83992B8399
2B8399155883155883155883155883116C96116C96116C96116C9616427B16427B16427B
16427B095B8D095B8D095B8D095B8D11528F11528F11528F11528F11528F2B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000C8E870C8E8711648D11648D
11648D11648D05538A05538A05538A05538A40779A40779A40779A40779A155883155883
1558831558831558831558831558831558831558830C6C8A0C6C8A0C6C8A0C6C8A11528F
11528F11528F11528F116495116495116495116495095B8D095B8D095B8D095B8D11648D
11648D11648D11648D11648D11649511649511649511649519588F19588F19588F19588F
0E7C8D0E7C8D0E7C8D0E7C8D005B8D005B8D005B8D005B8D196493196493196493196493
2B83992B83992B83992B83992B8399116C96116C96116C96116C96276F93276F93276F93
276F935B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A55B90A55B90A5
5B90A5116495116495116495116495116495196493196493196493196493005B8D005B8D
005B8D005B8D08648D08648D08648D08648D11648D11648D11648D11648D116C96116C96
116C96116C9619588F19588F19588F19588F19588F2A729D2A729D2A729D2A729D116C96
116C96116C96116C96196493196493196493196493276F93276F93276F93276F93155883
1558831558831558831164951164951164951164951164955B90A55B90A55B90A55B90A5
40779A40779A40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C96
2D54802D54802D54802D548011648D11648D11648D11648D11648D2B83992B83992B8399
2B8399155883155883155883155883116C96116C96116C96116C9616427B16427B16427B
16427B095B8D095B8D095B8D095B8D11528F11528F11528F11528F11528F2B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000115B8F115B8F1558831558831558831558830C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA2116495116495
1164951164951164950C6C8A0C6C8A0C6C8A0C6C8A005B8D005B8D005B8D005B8D19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D085B95
085B95085B95085B95085B9511648D11648D11648D11648D16427B16427B16427B16427B
28609128609128609128609111648D11648D11648D11648D11528F11528F11528F11528F
2A729D2A729D2A729D2A729D2A729D276F93276F93276F93276F93155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93116C96116C96116C96
116C96076495076495076495076495076495196493196493196493196493076495076495
07649507649515588315588315588315588311648D11648D11648D11648D286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B2D5480
2D54802D54802D5480116495116495116495116495276F93276F93276F93276F93196493
196493196493196493115B8F115B8F115B8F115B8F115B8F0C8E870C8E870C8E870C8E87
11648D11648D11648D11648D05538A05538A05538A05538A5B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F11649511649511649511649511649505538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93116C96116C96116C96
116C9640779A40779A40779A40779A045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D0C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
08648D08648D115B8F115B8F115B8F115B8F1558831558831558831558830C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA2116495116495
1164951164951164950C6C8A0C6C8A0C6C8A0C6C8A005B8D005B8D005B8D005B8D19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D085B95
085B95085B95085B95085B9511648D11648D11648D11648D16427B16427B16427B16427B
28609128609128609128609111648D11648D11648D11648D11528F11528F11528F11528F
2A729D2A729D2A729D2A729D2A729D276F93276F93276F93276F93155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93116C96116C96116C96
116C96076495076495076495076495076495196493196493196493196493076495076495
07649507649515588315588315588315588311648D11648D11648D11648D286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B2D5480
2D54802D54802D5480116495116495116495116495276F93276F93276F93276F93196493
196493196493196493115B8F115B8F115B8F115B8F115B8F0C8E870C8E870C8E870C8E87
11648D11648D11648D11648D05538A05538A05538A05538A5B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F11649511649511649511649511649505538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93116C96116C96116C96
116C9640779A40779A40779A40779A045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D0C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000008648D08648D08648D
08648D08648D115B8F115B8F115B8F115B8F1558831558831558831558830C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA2116495116495
1164951164951164950C6C8A0C6C8A0C6C8A0C6C8A005B8D005B8D005B8D005B8D19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D085B95
085B95085B95085B95085B9511648D11648D11648D11648D16427B16427B16427B16427B
28609128609128609128609111648D11648D11648D11648D11528F11528F11528F11528F
2A729D2A729D2A729D2A729D2A729D276F93276F93276F93276F93155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93116C96116C96116C96
116C96076495076495076495076495076495196493196493196493196493076495076495
07649507649515588315588315588315588311648D11648D11648D11648D286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B2D5480
2D54802D54802D5480116495116495116495116495276F93276F93276F93276F93196493
196493196493196493115B8F115B8F115B8F115B8F115B8F0C8E870C8E870C8E870C8E87
11648D11648D11648D11648D05538A05538A05538A05538A5B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F11649511649511649511649511649505538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93116C96116C96116C96
116C9640779A40779A40779A40779A045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D0C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000019649319649319649308648D08648D08648D
08648D08648D115B8F115B8F115B8F115B8F1558831558831558831558830C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA2116495116495
1164951164951164950C6C8A0C6C8A0C6C8A0C6C8A005B8D005B8D005B8D005B8D19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D085B95
085B95085B95085B95085B9511648D11648D11648D11648D16427B16427B16427B16427B
28609128609128609128609111648D11648D11648D11648D11528F11528F11528F11528F
2A729D2A729D2A729D2A729D2A729D276F93276F93276F93276F93155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93116C96116C96116C96
116C96076495076495076495076495076495196493196493196493196493076495076495
07649507649515588315588315588315588311648D11648D11648D11648D286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B2D5480
2D54802D54802D5480116495116495116495116495276F93276F93276F93276F93196493
196493196493196493115B8F115B8F115B8F115B8F115B8F0C8E870C8E870C8E870C8E87
11648D11648D11648D11648D05538A05538A05538A05538A5B90A55B90A55B90A55B90A5
0F748F0F748F0F748F0F748F11649511649511649511649511649505538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93116C96116C96116C96
116C9640779A40779A40779A40779A045B84045B84045B84045B84045B84196493196493
1964931964932A729D2A729D2A729D2A729D0C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000438CA2438CA2438CA2155883155883155883155883005B8D005B8D005B8D
005B8D005B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D11648D
11648D11648D1558831558831558831558832860912860912860912860912D54802D5480
2D54802D54802D5480276F93276F93276F93276F930445820445820445820445822A729D
2A729D2A729D2A729D15588315588315588315588319649319649319649319649319588F
19588F19588F19588F19588F095B8D095B8D095B8D095B8D044582044582044582044582
2A729D2A729D2A729D2A729D1558831558831558831558830C8E870C8E870C8E870C8E87
276F93276F93276F93276F93276F9311648D11648D11648D11648D08648D08648D08648D
08648D1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D5480
2D5480276F93276F93276F93276F93276F932B83992B83992B83992B8399116495116495
11649511649519588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B840F748F
0F748F0F748F0F748F276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D115B8F
115B8F115B8F115B8F0C8E870C8E870C8E870C8E870C8E87116495116495116495116495
1558831558831558831558831964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
04458204458204458204458211648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D116C96116C96116C96116C9605538A05538A05538A05538A0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A05538A05538A0C8E870C8E87
0C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000040779A40779A
40779A438CA2438CA2438CA2438CA2155883155883155883155883005B8D005B8D005B8D
005B8D005B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D11648D
11648D11648D1558831558831558831558832860912860912860912860912D54802D5480
2D54802D54802D5480276F93276F93276F93276F930445820445820445820445822A729D
2A729D2A729D2A729D15588315588315588315588319649319649319649319649319588F
19588F19588F19588F19588F095B8D095B8D095B8D095B8D044582044582044582044582
2A729D2A729D2A729D2A729D1558831558831558831558830C8E870C8E870C8E870C8E87
276F93276F93276F93276F93276F9311648D11648D11648D11648D08648D08648D08648D
08648D1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D5480
2D5480276F93276F93276F93276F93276F932B83992B83992B83992B8399116495116495
11649511649519588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B840F748F
0F748F0F748F0F748F276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D115B8F
115B8F115B8F115B8F0C8E870C8E870C8E870C8E870C8E87116495116495116495116495
1558831558831558831558831964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
04458204458204458204458211648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D116C96116C96116C96116C9605538A05538A05538A05538A0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A05538A05538A0C8E870C8E87
0C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000011648D11648D11648D40779A40779A40779A
40779A438CA2438CA2438CA2438CA2155883155883155883155883005B8D005B8D005B8D
005B8D005B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D11648D
11648D11648D1558831558831558831558832860912860912860912860912D54802D5480
2D54802D54802D5480276F93276F93276F93276F930445820445820445820445822A729D
2A729D2A729D2A729D15588315588315588315588319649319649319649319649319588F
19588F19588F19588F19588F095B8D095B8D095B8D095B8D044582044582044582044582
2A729D2A729D2A729D2A729D1558831558831558831558830C8E870C8E870C8E870C8E87
276F93276F93276F93276F93276F9311648D11648D11648D11648D08648D08648D08648D
08648D1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D5480
2D5480276F93276F93276F93276F93276F932B83992B83992B83992B8399116495116495
11649511649519588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B840F748F
0F748F0F748F0F748F276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D115B8F
115B8F115B8F115B8F0C8E870C8E870C8E870C8E870C8E87116495116495116495116495
1558831558831558831558831964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
04458204458204458204458211648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D116C96116C96116C96116C9605538A05538A05538A05538A0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A05538A05538A0C8E870C8E87
0C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000015588315588315588311648D11648D11648D11648D40779A40779A40779A
40779A438CA2438CA2438CA2438CA2155883155883155883155883005B8D005B8D005B8D
005B8D005B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D11648D
11648D11648D1558831558831558831558832860912860912860912860912D54802D5480
2D54802D54802D5480276F93276F93276F93276F930445820445820445820445822A729D
2A729D2A729D2A729D15588315588315588315588319649319649319649319649319588F
19588F19588F19588F19588F095B8D095B8D095B8D095B8D044582044582044582044582
2A729D2A729D2A729D2A729D1558831558831558831558830C8E870C8E870C8E870C8E87
276F93276F93276F93276F93276F9311648D11648D11648D11648D08648D08648D08648D
08648D1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D5480
2D5480276F93276F93276F93276F93276F932B83992B83992B83992B8399116495116495
11649511649519588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B840F748F
0F748F0F748F0F748F276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D115B8F
115B8F115B8F115B8F0C8E870C8E870C8E870C8E870C8E87116495116495116495116495
1558831558831558831558831964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
04458204458204458204458211648D11648D11648D11648D11648D2A729D2A729D2A729D
2A729D116C96116C96116C96116C9605538A05538A05538A05538A0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A05538A05538A0C8E870C8E87
0C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000196493
196493095B8D095B8D095B8D095B8D276F93276F93276F93276F930F748F0F748F0F748F
0F748F116C96116C96116C96116C96115B8F115B8F115B8F115B8F276F93276F93276F93
276F93276F93276F93276F93276F93276F931964931964931964931964932B83992B8399
2B83992B839911648D11648D11648D11648D2D54802D54802D54802D5480116495116495
11649511649511649516427B16427B16427B16427B085B95085B95085B95085B95115B8F
115B8F115B8F115B8F11648D11648D11648D11648D2B83992B83992B83992B83992A729D
2A729D2A729D2A729D2A729D11648D11648D11648D11648D095B8D095B8D095B8D095B8D
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D
276F93276F93276F93276F93276F93116C96116C96116C96116C9619588F19588F19588F
19588F0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C044582044582044582
0445820F748F0F748F0F748F0F748F0F748F11648D11648D11648D11648D0E7C8D0E7C8D
0E7C8D0E7C8D05538A05538A05538A05538A438CA2438CA2438CA2438CA2438CA2438CA2
438CA2438CA20764950764950764950764950764955B90A55B90A55B90A55B90A540779A
40779A40779A40779A11648D11648D11648D11648D2B83992B83992B83992B83992B8399
2B83992B83992B8399115B8F115B8F115B8F115B8F115B8F196493196493196493196493
15588315588315588315588384A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B155883155883155883155883155883196493196493196493
19649340779A40779A40779A40779A2B83992B83992B83992B83990E7C8D0E7C8D0E7C8D
0E7C8D2A729D2A729D2A729D2A729D1964931964931964931964931964932B83992B8399
2B83992B839905538A05538A05538A05538A196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000115B8F196493196493196493196493
196493095B8D095B8D095B8D095B8D276F93276F93276F93276F930F748F0F748F0F748F
0F748F116C96116C96116C96116C96115B8F115B8F115B8F115B8F276F93276F93276F93
276F93276F93276F93276F93276F93276F931964931964931964931964932B83992B8399
2B83992B839911648D11648D11648D11648D2D54802D54802D54802D5480116495116495
11649511649511649516427B16427B16427B16427B085B95085B95085B95085B95115B8F
115B8F115B8F115B8F11648D11648D11648D11648D2B83992B83992B83992B83992A729D
2A729D2A729D2A729D2A729D11648D11648D11648D11648D095B8D095B8D095B8D095B8D
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D
276F93276F93276F93276F93276F93116C96116C96116C96116C9619588F19588F19588F
19588F0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C044582044582044582
0445820F748F0F748F0F748F0F748F0F748F11648D11648D11648D11648D0E7C8D0E7C8D
0E7C8D0E7C8D05538A05538A05538A05538A438CA2438CA2438CA2438CA2438CA2438CA2
438CA2438CA20764950764950764950764950764955B90A55B90A55B90A55B90A540779A
40779A40779A40779A11648D11648D11648D11648D2B83992B83992B83992B83992B8399
2B83992B83992B8399115B8F115B8F115B8F115B8F115B8F196493196493196493196493
15588315588315588315588384A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B155883155883155883155883155883196493196493196493
19649340779A40779A40779A40779A2B83992B83992B83992B83990E7C8D0E7C8D0E7C8D
0E7C8D2A729D2A729D2A729D2A729D1964931964931964931964931964932B83992B8399
2B83992B839905538A05538A05538A05538A196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000276F93115B8F115B8F115B8F115B8F196493196493196493196493
196493095B8D095B8D095B8D095B8D276F93276F93276F93276F930F748F0F748F0F748F
0F748F116C96116C96116C96116C96115B8F115B8F115B8F115B8F276F93276F93276F93
276F93276F93276F93276F93276F93276F931964931964931964931964932B83992B8399
2B83992B839911648D11648D11648D11648D2D54802D54802D54802D5480116495116495
11649511649511649516427B16427B16427B16427B085B95085B95085B95085B95115B8F
115B8F115B8F115B8F11648D11648D11648D11648D2B83992B83992B83992B83992A729D
2A729D2A729D2A729D2A729D11648D11648D11648D11648D095B8D095B8D095B8D095B8D
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D
276F93276F93276F93276F93276F93116C96116C96116C96116C9619588F19588F19588F
19588F0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C044582044582044582
0445820F748F0F748F0F748F0F748F0F748F11648D11648D11648D11648D0E7C8D0E7C8D
0E7C8D0E7C8D05538A05538A05538A05538A438CA2438CA2438CA2438CA2438CA2438CA2
438CA2438CA20764950764950764950764950764955B90A55B90A55B90A55B90A540779A
40779A40779A40779A11648D11648D11648D11648D2B83992B83992B83992B83992B8399
2B83992B83992B8399115B8F115B8F115B8F115B8F115B8F196493196493196493196493
15588315588315588315588384A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B155883155883155883155883155883196493196493196493
19649340779A40779A40779A40779A2B83992B83992B83992B83990E7C8D0E7C8D0E7C8D
0E7C8D2A729D2A729D2A729D2A729D1964931964931964931964931964932B83992B8399
2B83992B839905538A05538A05538A05538A196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
276F93276F93276F93276F93115B8F115B8F115B8F115B8F196493196493196493196493
196493095B8D095B8D095B8D095B8D276F93276F93276F93276F930F748F0F748F0F748F
0F748F116C96116C96116C96116C96115B8F115B8F115B8F115B8F276F93276F93276F93
276F93276F93276F93276F93276F93276F931964931964931964931964932B83992B8399
2B83992B839911648D11648D11648D11648D2D54802D54802D54802D5480116495116495
11649511649511649516427B16427B16427B16427B085B95085B95085B95085B95115B8F
115B8F115B8F115B8F11648D11648D11648D11648D2B83992B83992B83992B83992A729D
2A729D2A729D2A729D2A729D11648D11648D11648D11648D095B8D095B8D095B8D095B8D
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D
276F93276F93276F93276F93276F93116C96116C96116C96116C9619588F19588F19588F
19588F0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C044582044582044582
0445820F748F0F748F0F748F0F748F0F748F11648D11648D11648D11648D0E7C8D0E7C8D
0E7C8D0E7C8D05538A05538A05538A05538A438CA2438CA2438CA2438CA2438CA2438CA2
438CA2438CA20764950764950764950764950764955B90A55B90A55B90A55B90A540779A
40779A40779A40779A11648D11648D11648D11648D2B83992B83992B83992B83992B8399
2B83992B83992B8399115B8F115B8F115B8F115B8F115B8F196493196493196493196493
15588315588315588315588384A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B155883155883155883155883155883196493196493196493
19649340779A40779A40779A40779A2B83992B83992B83992B83990E7C8D0E7C8D0E7C8D
0E7C8D2A729D2A729D2A729D2A729D1964931964931964931964931964932B83992B8399
2B83992B839905538A05538A05538A05538A196493000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000095B8D095B8D095B8D095B8D
095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C116C96116C96116C96116C96
116C9611528F11528F11528F11528F2B83992B83992B83992B839940779A40779A40779A
40779A0C8E870C8E870C8E870C8E8711648D11648D11648D11648D044582044582044582
04458204458211528F11528F11528F11528F1964931964931964931964930C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F196493196493196493196493286091286091
286091286091286091276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D40779A
40779A40779A40779A40779A11648D11648D11648D11648D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D196493196493196493196493
11528F11528F11528F11528F11528F15588315588315588315588316427B16427B16427B
16427B0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D5B90A55B90A55B90A55B90A55B90A511528F11528F11528F11528F286091286091
2860912860912D54802D54802D54802D5480044582044582044582044582276F93276F93
276F93276F93045B84045B84045B84045B84045B84276F93276F93276F93276F9340779A
40779A40779A40779A2A729D2A729D2A729D2A729D1164951164951164951164952B8399
2B83992B83992B83992A729D2A729D2A729D2A729D2A729D196493196493196493196493
286091286091286091286091116495116495116495116495116495116495116495116495
15588315588315588315588305538A05538A05538A05538A05538A40779A40779A40779A
40779A11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
1558830F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F115B8F095B8D095B8D
095B8D095B8D155883155883155883155883155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000276F93276F93276F93276F93095B8D095B8D095B8D095B8D
095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C116C96116C96116C96116C96
116C9611528F11528F11528F11528F2B83992B83992B83992B839940779A40779A40779A
40779A0C8E870C8E870C8E870C8E8711648D11648D11648D11648D044582044582044582
04458204458211528F11528F11528F11528F1964931964931964931964930C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F196493196493196493196493286091286091
286091286091286091276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D40779A
40779A40779A40779A40779A11648D11648D11648D11648D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D196493196493196493196493
11528F11528F11528F11528F11528F15588315588315588315588316427B16427B16427B
16427B0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D5B90A55B90A55B90A55B90A55B90A511528F11528F11528F11528F286091286091
2860912860912D54802D54802D54802D5480044582044582044582044582276F93276F93
276F93276F93045B84045B84045B84045B84045B84276F93276F93276F93276F9340779A
40779A40779A40779A2A729D2A729D2A729D2A729D1164951164951164951164952B8399
2B83992B83992B83992A729D2A729D2A729D2A729D2A729D196493196493196493196493
286091286091286091286091116495116495116495116495116495116495116495116495
15588315588315588315588305538A05538A05538A05538A05538A40779A40779A40779A
40779A11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
1558830F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F115B8F095B8D095B8D
095B8D095B8D155883155883155883155883155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000438CA2438CA2438CA2276F93276F93276F93276F93095B8D095B8D095B8D095B8D
095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C116C96116C96116C96116C96
116C9611528F11528F11528F11528F2B83992B83992B83992B839940779A40779A40779A
40779A0C8E870C8E870C8E870C8E8711648D11648D11648D11648D044582044582044582
04458204458211528F11528F11528F11528F1964931964931964931964930C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F196493196493196493196493286091286091
286091286091286091276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D40779A
40779A40779A40779A40779A11648D11648D11648D11648D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D196493196493196493196493
11528F11528F11528F11528F11528F15588315588315588315588316427B16427B16427B
16427B0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D5B90A55B90A55B90A55B90A55B90A511528F11528F11528F11528F286091286091
2860912860912D54802D54802D54802D5480044582044582044582044582276F93276F93
276F93276F93045B84045B84045B84045B84045B84276F93276F93276F93276F9340779A
40779A40779A40779A2A729D2A729D2A729D2A729D1164951164951164951164952B8399
2B83992B83992B83992A729D2A729D2A729D2A729D2A729D196493196493196493196493
286091286091286091286091116495116495116495116495116495116495116495116495
15588315588315588315588305538A05538A05538A05538A05538A40779A40779A40779A
40779A11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
1558830F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F115B8F095B8D095B8D
095B8D095B8D155883155883155883155883155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000276F93276F93276F93
438CA2438CA2438CA2438CA2276F93276F93276F93276F93095B8D095B8D095B8D095B8D
095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C116C96116C96116C96116C96
116C9611528F11528F11528F11528F2B83992B83992B83992B839940779A40779A40779A
40779A0C8E870C8E870C8E870C8E8711648D11648D11648D11648D044582044582044582
04458204458211528F11528F11528F11528F1964931964931964931964930C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F196493196493196493196493286091286091
286091286091286091276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D40779A
40779A40779A40779A40779A11648D11648D11648D11648D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D196493196493196493196493
11528F11528F11528F11528F11528F15588315588315588315588316427B16427B16427B
16427B0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D5B90A55B90A55B90A55B90A55B90A511528F11528F11528F11528F286091286091
2860912860912D54802D54802D54802D5480044582044582044582044582276F93276F93
276F93276F93045B84045B84045B84045B84045B84276F93276F93276F93276F9340779A
40779A40779A40779A2A729D2A729D2A729D2A729D1164951164951164951164952B8399
2B83992B83992B83992A729D2A729D2A729D2A729D2A729D196493196493196493196493
286091286091286091286091116495116495116495116495116495116495116495116495
15588315588315588315588305538A05538A05538A05538A05538A40779A40779A40779A
40779A11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
1558830F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F115B8F095B8D095B8D
095B8D095B8D155883155883155883155883155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000155883155883276F93276F93276F93276F93276F93
438CA2438CA2438CA2438CA2276F93276F93276F93276F93095B8D095B8D095B8D095B8D
095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C116C96116C96116C96116C96
116C9611528F11528F11528F11528F2B83992B83992B83992B839940779A40779A40779A
40779A0C8E870C8E870C8E870C8E8711648D11648D11648D11648D044582044582044582
04458204458211528F11528F11528F11528F1964931964931964931964930C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F196493196493196493196493286091286091
286091286091286091276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D40779A
40779A40779A40779A40779A11648D11648D11648D11648D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D196493196493196493196493
11528F11528F11528F11528F11528F15588315588315588315588316427B16427B16427B
16427B0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D5B90A55B90A55B90A55B90A55B90A511528F11528F11528F11528F286091286091
2860912860912D54802D54802D54802D5480044582044582044582044582276F93276F93
276F93276F93045B84045B84045B84045B84045B84276F93276F93276F93276F9340779A
40779A40779A40779A2A729D2A729D2A729D2A729D1164951164951164951164952B8399
2B83992B83992B83992A729D2A729D2A729D2A729D2A729D196493196493196493196493
286091286091286091286091116495116495116495116495116495116495116495116495
15588315588315588315588305538A05538A05538A05538A05538A40779A40779A40779A
40779A11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
1558830F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F115B8F095B8D095B8D
095B8D095B8D155883155883155883155883155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000019588F19588F095B8D095B8D095B8D095B8D196493196493196493196493196493
116C96116C96116C96116C9640779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
0F748F0F748F0F748F0F748F84A8B284A8B284A8B284A8B20C8E870C8E870C8E870C8E87
0C8E87095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA215588315588315588315588308648D08648D08648D08648D276F93276F93276F93
276F93276F932B83992B83992B83992B83991558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D115B8F115B8F115B8F115B8F005B8D005B8D005B8D005B8D116495116495
116495116495116495286091286091286091286091276F93276F93276F93276F93276F93
276F93276F93276F9311648D11648D11648D11648D116C96116C96116C96116C9611648D
11648D11648D11648D11648D2B83992B83992B83992B8399286091286091286091286091
286091286091286091286091095B8D095B8D095B8D095B8D40779A40779A40779A40779A
16427B16427B16427B16427B16427B115B8F115B8F115B8F115B8F196493196493196493
19649315588315588315588315588316427B16427B16427B16427B16427B16427B16427B
16427B40779A40779A40779A40779A40779A0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F16427B16427B16427B16427B2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A84A8B284A8B284A8B284A8B284A8B2155883155883155883155883196493
19649319649319649340779A40779A40779A40779A0F748F0F748F0F748F0F748F16427B
16427B16427B16427B11648D11648D11648D11648D11648D155883155883155883155883
116495116495116495116495155883155883155883155883438CA2438CA2438CA2438CA2
116495116495116495116495095B8D095B8D095B8D095B8D095B8D196493196493196493
1964932B83992B83992B83992B8399276F93276F93276F93276F935B90A55B90A55B90A5
5B90A505538A05538A05538A05538A40779A40779A40779A40779A40779A40779A40779A
40779A40779A19588F19588F19588F19588F095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000040779A19588F
19588F19588F19588F095B8D095B8D095B8D095B8D196493196493196493196493196493
116C96116C96116C96116C9640779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
0F748F0F748F0F748F0F748F84A8B284A8B284A8B284A8B20C8E870C8E870C8E870C8E87
0C8E87095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA215588315588315588315588308648D08648D08648D08648D276F93276F93276F93
276F93276F932B83992B83992B83992B83991558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D115B8F115B8F115B8F115B8F005B8D005B8D005B8D005B8D116495116495
116495116495116495286091286091286091286091276F93276F93276F93276F93276F93
276F93276F93276F9311648D11648D11648D11648D116C96116C96116C96116C9611648D
11648D11648D11648D11648D2B83992B83992B83992B8399286091286091286091286091
286091286091286091286091095B8D095B8D095B8D095B8D40779A40779A40779A40779A
16427B16427B16427B16427B16427B115B8F115B8F115B8F115B8F196493196493196493
19649315588315588315588315588316427B16427B16427B16427B16427B16427B16427B
16427B40779A40779A40779A40779A40779A0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F16427B16427B16427B16427B2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A84A8B284A8B284A8B284A8B284A8B2155883155883155883155883196493
19649319649319649340779A40779A40779A40779A0F748F0F748F0F748F0F748F16427B
16427B16427B16427B11648D11648D11648D11648D11648D155883155883155883155883
116495116495116495116495155883155883155883155883438CA2438CA2438CA2438CA2
116495116495116495116495095B8D095B8D095B8D095B8D095B8D196493196493196493
1964932B83992B83992B83992B8399276F93276F93276F93276F935B90A55B90A55B90A5
5B90A505538A05538A05538A05538A40779A40779A40779A40779A40779A40779A40779A
40779A40779A19588F19588F19588F19588F095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000040779A40779A40779A40779A40779A19588F
19588F19588F19588F095B8D095B8D095B8D095B8D196493196493196493196493196493
116C96116C96116C96116C9640779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
0F748F0F748F0F748F0F748F84A8B284A8B284A8B284A8B20C8E870C8E870C8E870C8E87
0C8E87095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA215588315588315588315588308648D08648D08648D08648D276F93276F93276F93
276F93276F932B83992B83992B83992B83991558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D115B8F115B8F115B8F115B8F005B8D005B8D005B8D005B8D116495116495
116495116495116495286091286091286091286091276F93276F93276F93276F93276F93
276F93276F93276F9311648D11648D11648D11648D116C96116C96116C96116C9611648D
11648D11648D11648D11648D2B83992B83992B83992B8399286091286091286091286091
286091286091286091286091095B8D095B8D095B8D095B8D40779A40779A40779A40779A
16427B16427B16427B16427B16427B115B8F115B8F115B8F115B8F196493196493196493
19649315588315588315588315588316427B16427B16427B16427B16427B16427B16427B
16427B40779A40779A40779A40779A40779A0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F16427B16427B16427B16427B2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A84A8B284A8B284A8B284A8B284A8B2155883155883155883155883196493
19649319649319649340779A40779A40779A40779A0F748F0F748F0F748F0F748F16427B
16427B16427B16427B11648D11648D11648D11648D11648D155883155883155883155883
116495116495116495116495155883155883155883155883438CA2438CA2438CA2438CA2
116495116495116495116495095B8D095B8D095B8D095B8D095B8D196493196493196493
1964932B83992B83992B83992B8399276F93276F93276F93276F935B90A55B90A55B90A5
5B90A505538A05538A05538A05538A40779A40779A40779A40779A40779A40779A40779A
40779A40779A19588F19588F19588F19588F095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000005538A40779A40779A40779A40779A40779A40779A40779A40779A19588F
19588F19588F19588F095B8D095B8D095B8D095B8D196493196493196493196493196493
116C96116C96116C96116C9640779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
0F748F0F748F0F748F0F748F84A8B284A8B284A8B284A8B20C8E870C8E870C8E870C8E87
0C8E87095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA215588315588315588315588308648D08648D08648D08648D276F93276F93276F93
276F93276F932B83992B83992B83992B83991558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D115B8F115B8F115B8F115B8F005B8D005B8D005B8D005B8D116495116495
116495116495116495286091286091286091286091276F93276F93276F93276F93276F93
276F93276F93276F9311648D11648D11648D11648D116C96116C96116C96116C9611648D
11648D11648D11648D11648D2B83992B83992B83992B8399286091286091286091286091
286091286091286091286091095B8D095B8D095B8D095B8D40779A40779A40779A40779A
16427B16427B16427B16427B16427B115B8F115B8F115B8F115B8F196493196493196493
19649315588315588315588315588316427B16427B16427B16427B16427B16427B16427B
16427B40779A40779A40779A40779A40779A0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F16427B16427B16427B16427B2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A84A8B284A8B284A8B284A8B284A8B2155883155883155883155883196493
19649319649319649340779A40779A40779A40779A0F748F0F748F0F748F0F748F16427B
16427B16427B16427B11648D11648D11648D11648D11648D155883155883155883155883
116495116495116495116495155883155883155883155883438CA2438CA2438CA2438CA2
116495116495116495116495095B8D095B8D095B8D095B8D095B8D196493196493196493
1964932B83992B83992B83992B8399276F93276F93276F93276F935B90A55B90A55B90A5
5B90A505538A05538A05538A05538A40779A40779A40779A40779A40779A40779A40779A
40779A40779A19588F19588F19588F19588F095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000045B84
045B84045B84045B842B83992B83992B83992B839915588315588315588315588305538A
05538A05538A05538A2D54802D54802D54802D548016427B16427B16427B16427B16427B
11528F11528F11528F11528F11648D11648D11648D11648D16427B16427B16427B16427B
0C8E870C8E870C8E870C8E87276F93276F93276F93276F935B90A55B90A55B90A55B90A5
5B90A50C8E870C8E870C8E870C8E872860912860912860912860912B83992B83992B8399
2B839940779A40779A40779A40779A05538A05538A05538A05538A095B8D095B8D095B8D
095B8D095B8D085B95085B95085B95085B95044582044582044582044582045B84045B84
045B84045B84116C96116C96116C96116C962B83992B83992B83992B83992D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F095B8D
095B8D095B8D095B8D19649319649319649319649311649511649511649511649516427B
16427B16427B16427B16427B0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D
2B83992B83992B83992B8399155883155883155883155883196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A
0C6C8A2A2F6C2A2F6C2A2F6C2A2F6C1558831558831558831558835B90A55B90A55B90A5
5B90A50F748F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0F748F0F748F0F748F0F748F40779A40779A40779A40779A0C8E870C8E87
0C8E870C8E8711648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F16427B
16427B16427B16427B2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A16427B
16427B16427B16427B286091286091286091286091286091286091286091286091286091
15588315588315588315588384A8B284A8B284A8B284A8B2438CA2438CA2438CA2438CA2
005B8D005B8D005B8D005B8D196493196493196493196493196493116495116495116495
11649584A8B284A8B284A8B284A8B21558831558831558831558832D54802D54802D5480
2D5480045B84045B84045B84045B842B83992B83992B83992B83992B8399155883155883
15588315588305538A05538A05538A05538A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000002D54802D54802D54802D5480045B84
045B84045B84045B842B83992B83992B83992B839915588315588315588315588305538A
05538A05538A05538A2D54802D54802D54802D548016427B16427B16427B16427B16427B
11528F11528F11528F11528F11648D11648D11648D11648D16427B16427B16427B16427B
0C8E870C8E870C8E870C8E87276F93276F93276F93276F935B90A55B90A55B90A55B90A5
5B90A50C8E870C8E870C8E870C8E872860912860912860912860912B83992B83992B8399
2B839940779A40779A40779A40779A05538A05538A05538A05538A095B8D095B8D095B8D
095B8D095B8D085B95085B95085B95085B95044582044582044582044582045B84045B84
045B84045B84116C96116C96116C96116C962B83992B83992B83992B83992D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F095B8D
095B8D095B8D095B8D19649319649319649319649311649511649511649511649516427B
16427B16427B16427B16427B0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D
2B83992B83992B83992B8399155883155883155883155883196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A
0C6C8A2A2F6C2A2F6C2A2F6C2A2F6C1558831558831558831558835B90A55B90A55B90A5
5B90A50F748F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0F748F0F748F0F748F0F748F40779A40779A40779A40779A0C8E870C8E87
0C8E870C8E8711648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F16427B
16427B16427B16427B2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A16427B
16427B16427B16427B286091286091286091286091286091286091286091286091286091
15588315588315588315588384A8B284A8B284A8B284A8B2438CA2438CA2438CA2438CA2
005B8D005B8D005B8D005B8D196493196493196493196493196493116495116495116495
11649584A8B284A8B284A8B284A8B21558831558831558831558832D54802D54802D5480
2D5480045B84045B84045B84045B842B83992B83992B83992B83992B8399155883155883
15588315588305538A05538A05538A05538A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001558831558831558832D54802D54802D54802D54802D5480045B84
045B84045B84045B842B83992B83992B83992B839915588315588315588315588305538A
05538A05538A05538A2D54802D54802D54802D548016427B16427B16427B16427B16427B
11528F11528F11528F11528F11648D11648D11648D11648D16427B16427B16427B16427B
0C8E870C8E870C8E870C8E87276F93276F93276F93276F935B90A55B90A55B90A55B90A5
5B90A50C8E870C8E870C8E870C8E872860912860912860912860912B83992B83992B8399
2B839940779A40779A40779A40779A05538A05538A05538A05538A095B8D095B8D095B8D
095B8D095B8D085B95085B95085B95085B95044582044582044582044582045B84045B84
045B84045B84116C96116C96116C96116C962B83992B83992B83992B83992D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F095B8D
095B8D095B8D095B8D19649319649319649319649311649511649511649511649516427B
16427B16427B16427B16427B0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D
2B83992B83992B83992B8399155883155883155883155883196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A
0C6C8A2A2F6C2A2F6C2A2F6C2A2F6C1558831558831558831558835B90A55B90A55B90A5
5B90A50F748F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0F748F0F748F0F748F0F748F40779A40779A40779A40779A0C8E870C8E87
0C8E870C8E8711648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F16427B
16427B16427B16427B2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A16427B
16427B16427B16427B286091286091286091286091286091286091286091286091286091
15588315588315588315588384A8B284A8B284A8B284A8B2438CA2438CA2438CA2438CA2
005B8D005B8D005B8D005B8D196493196493196493196493196493116495116495116495
11649584A8B284A8B284A8B284A8B21558831558831558831558832D54802D54802D5480
2D5480045B84045B84045B84045B842B83992B83992B83992B83992B8399155883155883
15588315588305538A05538A05538A05538A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
84A8B284A8B21558831558831558831558832D54802D54802D54802D54802D5480045B84
045B84045B84045B842B83992B83992B83992B839915588315588315588315588305538A
05538A05538A05538A2D54802D54802D54802D548016427B16427B16427B16427B16427B
11528F11528F11528F11528F11648D11648D11648D11648D16427B16427B16427B16427B
0C8E870C8E870C8E870C8E87276F93276F93276F93276F935B90A55B90A55B90A55B90A5
5B90A50C8E870C8E870C8E870C8E872860912860912860912860912B83992B83992B8399
2B839940779A40779A40779A40779A05538A05538A05538A05538A095B8D095B8D095B8D
095B8D095B8D085B95085B95085B95085B95044582044582044582044582045B84045B84
045B84045B84116C96116C96116C96116C962B83992B83992B83992B83992D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F095B8D
095B8D095B8D095B8D19649319649319649319649311649511649511649511649516427B
16427B16427B16427B16427B0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D
2B83992B83992B83992B8399155883155883155883155883196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A
0C6C8A2A2F6C2A2F6C2A2F6C2A2F6C1558831558831558831558835B90A55B90A55B90A5
5B90A50F748F0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D19588F19588F
19588F19588F0F748F0F748F0F748F0F748F40779A40779A40779A40779A0C8E870C8E87
0C8E870C8E8711648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F16427B
16427B16427B16427B2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A16427B
16427B16427B16427B286091286091286091286091286091286091286091286091286091
15588315588315588315588384A8B284A8B284A8B284A8B2438CA2438CA2438CA2438CA2
005B8D005B8D005B8D005B8D196493196493196493196493196493116495116495116495
11649584A8B284A8B284A8B284A8B21558831558831558831558832D54802D54802D5480
2D5480045B84045B84045B84045B842B83992B83992B83992B83992B8399155883155883
15588315588305538A05538A05538A05538A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000011648D11648D0C8E870C8E87
0C8E870C8E87116495116495116495116495095B8D095B8D095B8D095B8D095B8D116495
11649511649511649540779A40779A40779A40779A11648D11648D11648D11648D05538A
05538A05538A05538A076495076495076495076495438CA2438CA2438CA2438CA2438CA2
2B83992B83992B83992B839916427B16427B16427B16427B11648D11648D11648D11648D
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F93155883155883155883155883
1558835B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D40779A40779A40779A
40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2D54802D54802D54802D548015588315588315588315588311648D11648D
11648D11648D05538A05538A05538A05538A276F93276F93276F93276F9311648D11648D
11648D11648D11648D2B83992B83992B83992B839911648D11648D11648D11648D16427B
16427B16427B16427B276F93276F93276F93276F9308648D08648D08648D08648D40779A
40779A40779A40779A40779A155883155883155883155883196493196493196493196493
11648D11648D11648D11648D155883155883155883155883115B8F115B8F115B8F115B8F
276F93276F93276F93276F93276F931964931964931964931964932A729D2A729D2A729D
2A729D1558831558831558831558831964931964931964931964930E7C8D0E7C8D0E7C8D
0E7C8D84A8B284A8B284A8B284A8B284A8B22B83992B83992B83992B8399276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493196493
1964931964930E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493
1964931964931964932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
155883155883155883115B8F115B8F115B8F115B8F115B8F5B90A55B90A55B90A55B90A5
438CA2438CA2438CA2438CA2116C96116C96116C96116C9616427B16427B16427B16427B
19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D0C8E870C8E870C8E870C8E87116495116495116495116495095B8D095B8D095B8D
095B8D11649511649511649511649540779A40779A40779A40779A40779A11648D11648D
11648D11648D05538A05538A05538A05538A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000C6C8A0C6C8A11648D11648D11648D11648D0C8E870C8E87
0C8E870C8E87116495116495116495116495095B8D095B8D095B8D095B8D095B8D116495
11649511649511649540779A40779A40779A40779A11648D11648D11648D11648D05538A
05538A05538A05538A076495076495076495076495438CA2438CA2438CA2438CA2438CA2
2B83992B83992B83992B839916427B16427B16427B16427B11648D11648D11648D11648D
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F93155883155883155883155883
1558835B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D40779A40779A40779A
40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2D54802D54802D54802D548015588315588315588315588311648D11648D
11648D11648D05538A05538A05538A05538A276F93276F93276F93276F9311648D11648D
11648D11648D11648D2B83992B83992B83992B839911648D11648D11648D11648D16427B
16427B16427B16427B276F93276F93276F93276F9308648D08648D08648D08648D40779A
40779A40779A40779A40779A155883155883155883155883196493196493196493196493
11648D11648D11648D11648D155883155883155883155883115B8F115B8F115B8F115B8F
276F93276F93276F93276F93276F931964931964931964931964932A729D2A729D2A729D
2A729D1558831558831558831558831964931964931964931964930E7C8D0E7C8D0E7C8D
0E7C8D84A8B284A8B284A8B284A8B284A8B22B83992B83992B83992B8399276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493196493
1964931964930E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493
1964931964931964932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
155883155883155883115B8F115B8F115B8F115B8F115B8F5B90A55B90A55B90A55B90A5
438CA2438CA2438CA2438CA2116C96116C96116C96116C9616427B16427B16427B16427B
19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D0C8E870C8E870C8E870C8E87116495116495116495116495095B8D095B8D095B8D
095B8D11649511649511649511649540779A40779A40779A40779A40779A11648D11648D
11648D11648D05538A05538A05538A05538A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000019588F0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D0C8E870C8E87
0C8E870C8E87116495116495116495116495095B8D095B8D095B8D095B8D095B8D116495
11649511649511649540779A40779A40779A40779A11648D11648D11648D11648D05538A
05538A05538A05538A076495076495076495076495438CA2438CA2438CA2438CA2438CA2
2B83992B83992B83992B839916427B16427B16427B16427B11648D11648D11648D11648D
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F93155883155883155883155883
1558835B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D40779A40779A40779A
40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2D54802D54802D54802D548015588315588315588315588311648D11648D
11648D11648D05538A05538A05538A05538A276F93276F93276F93276F9311648D11648D
11648D11648D11648D2B83992B83992B83992B839911648D11648D11648D11648D16427B
16427B16427B16427B276F93276F93276F93276F9308648D08648D08648D08648D40779A
40779A40779A40779A40779A155883155883155883155883196493196493196493196493
11648D11648D11648D11648D155883155883155883155883115B8F115B8F115B8F115B8F
276F93276F93276F93276F93276F931964931964931964931964932A729D2A729D2A729D
2A729D1558831558831558831558831964931964931964931964930E7C8D0E7C8D0E7C8D
0E7C8D84A8B284A8B284A8B284A8B284A8B22B83992B83992B83992B8399276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493196493
1964931964930E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493
1964931964931964932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
155883155883155883115B8F115B8F115B8F115B8F115B8F5B90A55B90A55B90A55B90A5
438CA2438CA2438CA2438CA2116C96116C96116C96116C9616427B16427B16427B16427B
19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D0C8E870C8E870C8E870C8E87116495116495116495116495095B8D095B8D095B8D
095B8D11649511649511649511649540779A40779A40779A40779A40779A11648D11648D
11648D11648D05538A05538A05538A05538A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000016427B19588F19588F
19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D0C8E870C8E87
0C8E870C8E87116495116495116495116495095B8D095B8D095B8D095B8D095B8D116495
11649511649511649540779A40779A40779A40779A11648D11648D11648D11648D05538A
05538A05538A05538A076495076495076495076495438CA2438CA2438CA2438CA2438CA2
2B83992B83992B83992B839916427B16427B16427B16427B11648D11648D11648D11648D
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F93155883155883155883155883
1558835B90A55B90A55B90A55B90A52A729D2A729D2A729D2A729D40779A40779A40779A
40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2D54802D54802D54802D548015588315588315588315588311648D11648D
11648D11648D05538A05538A05538A05538A276F93276F93276F93276F9311648D11648D
11648D11648D11648D2B83992B83992B83992B839911648D11648D11648D11648D16427B
16427B16427B16427B276F93276F93276F93276F9308648D08648D08648D08648D40779A
40779A40779A40779A40779A155883155883155883155883196493196493196493196493
11648D11648D11648D11648D155883155883155883155883115B8F115B8F115B8F115B8F
276F93276F93276F93276F93276F931964931964931964931964932A729D2A729D2A729D
2A729D1558831558831558831558831964931964931964931964930E7C8D0E7C8D0E7C8D
0E7C8D84A8B284A8B284A8B284A8B284A8B22B83992B83992B83992B8399276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493196493
1964931964930E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D196493
1964931964931964932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
155883155883155883115B8F115B8F115B8F115B8F115B8F5B90A55B90A55B90A55B90A5
438CA2438CA2438CA2438CA2116C96116C96116C96116C9616427B16427B16427B16427B
19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D
11648D0C8E870C8E870C8E870C8E87116495116495116495116495095B8D095B8D095B8D
095B8D11649511649511649511649540779A40779A40779A40779A40779A11648D11648D
11648D11648D05538A05538A05538A05538A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000015588315588315588315588315588319588F19588F
19588F19588F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A05538A05538A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F932B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D5480276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F16427B16427B16427B16427B84A8B284A8B284A8B284A8B2
276F93276F93276F93276F9340779A40779A40779A40779A044582044582044582044582
044582115B8F115B8F115B8F115B8F276F93276F93276F93276F932B83992B83992B8399
2B839907649507649507649507649584A8B284A8B284A8B284A8B22D54802D54802D5480
2D54802D548015588315588315588315588319588F19588F19588F19588F276F93276F93
276F93276F9328609128609128609128609104458204458204458204458205538A05538A
05538A05538A05538A0F748F0F748F0F748F0F748F16427B16427B16427B16427B05538A
05538A05538A05538A08648D08648D08648D08648D11648D11648D11648D11648D84A8B2
84A8B284A8B284A8B284A8B2276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
116C96116C96116C96116C96116C9619588F19588F19588F19588F196493196493196493
1964932B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D095B8D095B8D
095B8D40779A40779A40779A40779A40779A2D54802D54802D54802D54800F748F0F748F
0F748F0F748F19588F19588F19588F19588F40779A40779A40779A40779A2D54802D5480
2D54802D548019649319649319649319649319649328609128609128609128609111528F
11528F11528F11528F2860912860912860912860912B83992B83992B83992B83992B8399
2B83992B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F93
08648D08648D08648D08648D044582044582044582044582155883155883155883155883
19588F19588F19588F19588F115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D
0E7C8D11648D11648D11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F932B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000004458204458204458215588315588315588315588315588319588F19588F
19588F19588F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A05538A05538A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F932B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D5480276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F16427B16427B16427B16427B84A8B284A8B284A8B284A8B2
276F93276F93276F93276F9340779A40779A40779A40779A044582044582044582044582
044582115B8F115B8F115B8F115B8F276F93276F93276F93276F932B83992B83992B8399
2B839907649507649507649507649584A8B284A8B284A8B284A8B22D54802D54802D5480
2D54802D548015588315588315588315588319588F19588F19588F19588F276F93276F93
276F93276F9328609128609128609128609104458204458204458204458205538A05538A
05538A05538A05538A0F748F0F748F0F748F0F748F16427B16427B16427B16427B05538A
05538A05538A05538A08648D08648D08648D08648D11648D11648D11648D11648D84A8B2
84A8B284A8B284A8B284A8B2276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
116C96116C96116C96116C96116C9619588F19588F19588F19588F196493196493196493
1964932B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D095B8D095B8D
095B8D40779A40779A40779A40779A40779A2D54802D54802D54802D54800F748F0F748F
0F748F0F748F19588F19588F19588F19588F40779A40779A40779A40779A2D54802D5480
2D54802D548019649319649319649319649319649328609128609128609128609111528F
11528F11528F11528F2860912860912860912860912B83992B83992B83992B83992B8399
2B83992B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F93
08648D08648D08648D08648D044582044582044582044582155883155883155883155883
19588F19588F19588F19588F115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D
0E7C8D11648D11648D11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F932B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000008648D08648D
08648D04458204458204458204458215588315588315588315588315588319588F19588F
19588F19588F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A05538A05538A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F932B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D5480276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F16427B16427B16427B16427B84A8B284A8B284A8B284A8B2
276F93276F93276F93276F9340779A40779A40779A40779A044582044582044582044582
044582115B8F115B8F115B8F115B8F276F93276F93276F93276F932B83992B83992B8399
2B839907649507649507649507649584A8B284A8B284A8B284A8B22D54802D54802D5480
2D54802D548015588315588315588315588319588F19588F19588F19588F276F93276F93
276F93276F9328609128609128609128609104458204458204458204458205538A05538A
05538A05538A05538A0F748F0F748F0F748F0F748F16427B16427B16427B16427B05538A
05538A05538A05538A08648D08648D08648D08648D11648D11648D11648D11648D84A8B2
84A8B284A8B284A8B284A8B2276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
116C96116C96116C96116C96116C9619588F19588F19588F19588F196493196493196493
1964932B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D095B8D095B8D
095B8D40779A40779A40779A40779A40779A2D54802D54802D54802D54800F748F0F748F
0F748F0F748F19588F19588F19588F19588F40779A40779A40779A40779A2D54802D5480
2D54802D548019649319649319649319649319649328609128609128609128609111528F
11528F11528F11528F2860912860912860912860912B83992B83992B83992B83992B8399
2B83992B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F93
08648D08648D08648D08648D044582044582044582044582155883155883155883155883
19588F19588F19588F19588F115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D
0E7C8D11648D11648D11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F932B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000276F93276F93276F9308648D08648D08648D
08648D04458204458204458204458215588315588315588315588315588319588F19588F
19588F19588F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A05538A05538A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F932B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D5480276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F16427B16427B16427B16427B84A8B284A8B284A8B284A8B2
276F93276F93276F93276F9340779A40779A40779A40779A044582044582044582044582
044582115B8F115B8F115B8F115B8F276F93276F93276F93276F932B83992B83992B8399
2B839907649507649507649507649584A8B284A8B284A8B284A8B22D54802D54802D5480
2D54802D548015588315588315588315588319588F19588F19588F19588F276F93276F93
276F93276F9328609128609128609128609104458204458204458204458205538A05538A
05538A05538A05538A0F748F0F748F0F748F0F748F16427B16427B16427B16427B05538A
05538A05538A05538A08648D08648D08648D08648D11648D11648D11648D11648D84A8B2
84A8B284A8B284A8B284A8B2276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
116C96116C96116C96116C96116C9619588F19588F19588F19588F196493196493196493
1964932B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D095B8D095B8D
095B8D40779A40779A40779A40779A40779A2D54802D54802D54802D54800F748F0F748F
0F748F0F748F19588F19588F19588F19588F40779A40779A40779A40779A2D54802D5480
2D54802D548019649319649319649319649319649328609128609128609128609111528F
11528F11528F11528F2860912860912860912860912B83992B83992B83992B83992B8399
2B83992B83992B839911648D11648D11648D11648D11648D276F93276F93276F93276F93
08648D08648D08648D08648D044582044582044582044582155883155883155883155883
19588F19588F19588F19588F115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D
0E7C8D11648D11648D11648D11648D0C8E870C8E870C8E870C8E8705538A05538A05538A
05538A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F932B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000005B90A55B90A55B90A5286091286091286091286091196493196493196493
196493196493196493196493196493095B8D095B8D095B8D095B8D095B8D044582044582
0445820445820F748F0F748F0F748F0F748F28609128609128609128609184A8B284A8B2
84A8B284A8B2044582044582044582044582276F93276F93276F93276F93276F93116495
1164951164951164952D54802D54802D54802D5480155883155883155883155883115B8F
115B8F115B8F115B8F2D54802D54802D54802D5480438CA2438CA2438CA2438CA2438CA2
05538A05538A05538A05538A11528F11528F11528F11528F286091286091286091286091
1164951164951164951164950C8E870C8E870C8E870C8E8705538A05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E8740779A40779A40779A
40779A2D54802D54802D54802D5480196493196493196493196493155883155883155883
15588315588308648D08648D08648D08648D276F93276F93276F93276F93196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548016427B16427B
16427B16427B16427B276F93276F93276F93276F9311528F11528F11528F11528F276F93
276F93276F93276F9316427B16427B16427B16427B28609128609128609128609140779A
40779A40779A40779A40779A115B8F115B8F115B8F115B8F11648D11648D11648D11648D
05538A05538A05538A05538A085B95085B95085B95085B95196493196493196493196493
2B83992B83992B83992B83992B8399095B8D095B8D095B8D095B8D19588F19588F19588F
19588F0E7C8D0E7C8D0E7C8D0E7C8D1164951164951164951164955B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96076495076495
07649507649511648D11648D11648D11648D2B83992B83992B83992B839905538A05538A
05538A05538A28609128609128609128609128609115588315588315588315588305538A
05538A05538A05538A276F93276F93276F93276F931164951164951164951164950F748F
0F748F0F748F0F748F5B90A55B90A55B90A55B90A55B90A5286091286091286091286091
196493196493196493196493196493196493196493196493095B8D095B8D095B8D095B8D
0445820445820445820445820F748F0F748F0F748F0F748F0F748F286091286091286091
28609184A8B284A8B284A8B284A8B2044582044582044582044582276F93276F93276F93
276F931164951164951164951164952D54802D54802D54802D54802D5480155883155883
155883155883115B8F115B8F115B8F115B8F2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000F748F
0F748F5B90A55B90A55B90A55B90A5286091286091286091286091196493196493196493
196493196493196493196493196493095B8D095B8D095B8D095B8D095B8D044582044582
0445820445820F748F0F748F0F748F0F748F28609128609128609128609184A8B284A8B2
84A8B284A8B2044582044582044582044582276F93276F93276F93276F93276F93116495
1164951164951164952D54802D54802D54802D5480155883155883155883155883115B8F
115B8F115B8F115B8F2D54802D54802D54802D5480438CA2438CA2438CA2438CA2438CA2
05538A05538A05538A05538A11528F11528F11528F11528F286091286091286091286091
1164951164951164951164950C8E870C8E870C8E870C8E8705538A05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E8740779A40779A40779A
40779A2D54802D54802D54802D5480196493196493196493196493155883155883155883
15588315588308648D08648D08648D08648D276F93276F93276F93276F93196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548016427B16427B
16427B16427B16427B276F93276F93276F93276F9311528F11528F11528F11528F276F93
276F93276F93276F9316427B16427B16427B16427B28609128609128609128609140779A
40779A40779A40779A40779A115B8F115B8F115B8F115B8F11648D11648D11648D11648D
05538A05538A05538A05538A085B95085B95085B95085B95196493196493196493196493
2B83992B83992B83992B83992B8399095B8D095B8D095B8D095B8D19588F19588F19588F
19588F0E7C8D0E7C8D0E7C8D0E7C8D1164951164951164951164955B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96076495076495
07649507649511648D11648D11648D11648D2B83992B83992B83992B839905538A05538A
05538A05538A28609128609128609128609128609115588315588315588315588305538A
05538A05538A05538A276F93276F93276F93276F931164951164951164951164950F748F
0F748F0F748F0F748F5B90A55B90A55B90A55B90A55B90A5286091286091286091286091
196493196493196493196493196493196493196493196493095B8D095B8D095B8D095B8D
0445820445820445820445820F748F0F748F0F748F0F748F0F748F286091286091286091
28609184A8B284A8B284A8B284A8B2044582044582044582044582276F93276F93276F93
276F931164951164951164951164952D54802D54802D54802D54802D5480155883155883
155883155883115B8F115B8F115B8F115B8F2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000001164951164950F748F0F748F0F748F
0F748F5B90A55B90A55B90A55B90A5286091286091286091286091196493196493196493
196493196493196493196493196493095B8D095B8D095B8D095B8D095B8D044582044582
0445820445820F748F0F748F0F748F0F748F28609128609128609128609184A8B284A8B2
84A8B284A8B2044582044582044582044582276F93276F93276F93276F93276F93116495
1164951164951164952D54802D54802D54802D5480155883155883155883155883115B8F
115B8F115B8F115B8F2D54802D54802D54802D5480438CA2438CA2438CA2438CA2438CA2
05538A05538A05538A05538A11528F11528F11528F11528F286091286091286091286091
1164951164951164951164950C8E870C8E870C8E870C8E8705538A05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E8740779A40779A40779A
40779A2D54802D54802D54802D5480196493196493196493196493155883155883155883
15588315588308648D08648D08648D08648D276F93276F93276F93276F93196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548016427B16427B
16427B16427B16427B276F93276F93276F93276F9311528F11528F11528F11528F276F93
276F93276F93276F9316427B16427B16427B16427B28609128609128609128609140779A
40779A40779A40779A40779A115B8F115B8F115B8F115B8F11648D11648D11648D11648D
05538A05538A05538A05538A085B95085B95085B95085B95196493196493196493196493
2B83992B83992B83992B83992B8399095B8D095B8D095B8D095B8D19588F19588F19588F
19588F0E7C8D0E7C8D0E7C8D0E7C8D1164951164951164951164955B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96076495076495
07649507649511648D11648D11648D11648D2B83992B83992B83992B839905538A05538A
05538A05538A28609128609128609128609128609115588315588315588315588305538A
05538A05538A05538A276F93276F93276F93276F931164951164951164951164950F748F
0F748F0F748F0F748F5B90A55B90A55B90A55B90A55B90A5286091286091286091286091
196493196493196493196493196493196493196493196493095B8D095B8D095B8D095B8D
0445820445820445820445820F748F0F748F0F748F0F748F0F748F286091286091286091
28609184A8B284A8B284A8B284A8B2044582044582044582044582276F93276F93276F93
276F931164951164951164951164952D54802D54802D54802D54802D5480155883155883
155883155883115B8F115B8F115B8F115B8F2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000276F931164951164951164951164951164950F748F0F748F0F748F
0F748F5B90A55B90A55B90A55B90A5286091286091286091286091196493196493196493
196493196493196493196493196493095B8D095B8D095B8D095B8D095B8D044582044582
0445820445820F748F0F748F0F748F0F748F28609128609128609128609184A8B284A8B2
84A8B284A8B2044582044582044582044582276F93276F93276F93276F93276F93116495
1164951164951164952D54802D54802D54802D5480155883155883155883155883115B8F
115B8F115B8F115B8F2D54802D54802D54802D5480438CA2438CA2438CA2438CA2438CA2
05538A05538A05538A05538A11528F11528F11528F11528F286091286091286091286091
1164951164951164951164950C8E870C8E870C8E870C8E8705538A05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E8740779A40779A40779A
40779A2D54802D54802D54802D5480196493196493196493196493155883155883155883
15588315588308648D08648D08648D08648D276F93276F93276F93276F93196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548016427B16427B
16427B16427B16427B276F93276F93276F93276F9311528F11528F11528F11528F276F93
276F93276F93276F9316427B16427B16427B16427B28609128609128609128609140779A
40779A40779A40779A40779A115B8F115B8F115B8F115B8F11648D11648D11648D11648D
05538A05538A05538A05538A085B95085B95085B95085B95196493196493196493196493
2B83992B83992B83992B83992B8399095B8D095B8D095B8D095B8D19588F19588F19588F
19588F0E7C8D0E7C8D0E7C8D0E7C8D1164951164951164951164955B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116C96116C96116C96116C96076495076495
07649507649511648D11648D11648D11648D2B83992B83992B83992B839905538A05538A
05538A05538A28609128609128609128609128609115588315588315588315588305538A
05538A05538A05538A276F93276F93276F93276F931164951164951164951164950F748F
0F748F0F748F0F748F5B90A55B90A55B90A55B90A55B90A5286091286091286091286091
196493196493196493196493196493196493196493196493095B8D095B8D095B8D095B8D
0445820445820445820445820F748F0F748F0F748F0F748F0F748F286091286091286091
28609184A8B284A8B284A8B284A8B2044582044582044582044582276F93276F93276F93
276F931164951164951164951164952D54802D54802D54802D54802D5480155883155883
155883155883115B8F115B8F115B8F115B8F2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1164951164951164951164952B83992B83992B83992B83992B8399155883155883155883
1558830C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B155883155883155883
15588319588F19588F19588F19588F1964931964931964931964931964930E7C8D0E7C8D
0E7C8D0E7C8D438CA2438CA2438CA2438CA2115B8F115B8F115B8F115B8F115B8F115B8F
115B8F115B8F1558831558831558831558835B90A55B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F276F93276F93276F93276F9311528F11528F11528F11528F11528F
2B83992B83992B83992B83992D54802D54802D54802D5480438CA2438CA2438CA2438CA2
40779A40779A40779A40779A11528F11528F11528F11528F2A729D2A729D2A729D2A729D
2A729D11648D11648D11648D11648D276F93276F93276F93276F93116C96116C96116C96
116C9611648D11648D11648D11648D2A729D2A729D2A729D2A729D116C96116C96116C96
116C96116C961558831558831558831558832860912860912860912860912A729D2A729D
2A729D2A729D2B83992B83992B83992B839908648D08648D08648D08648D276F93276F93
276F93276F93276F93116495116495116495116495196493196493196493196493155883
1558831558831558830E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA240779A
40779A40779A40779A40779A15588315588315588315588319588F19588F19588F19588F
115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A438CA2438CA2438CA2438CA2
11648D11648D11648D11648D11648D11528F11528F11528F11528F19588F19588F19588F
19588F115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A115B8F115B8F115B8F115B8F115B8F286091286091286091286091286091286091
28609128609140779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609111528F11528F11528F11528F11528F155883155883155883155883116495
1164951164951164951164951164951164951164952B83992B83992B83992B8399155883
1558831558831558830C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B
15588315588315588315588319588F19588F19588F19588F196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2115B8F115B8F115B8F
115B8F115B8F115B8F115B8F115B8F1558831558831558831558835B90A55B90A55B90A5
5B90A52B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F276F93000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000116495116495116495116495
1164951164951164951164952B83992B83992B83992B83992B8399155883155883155883
1558830C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B155883155883155883
15588319588F19588F19588F19588F1964931964931964931964931964930E7C8D0E7C8D
0E7C8D0E7C8D438CA2438CA2438CA2438CA2115B8F115B8F115B8F115B8F115B8F115B8F
115B8F115B8F1558831558831558831558835B90A55B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F276F93276F93276F93276F9311528F11528F11528F11528F11528F
2B83992B83992B83992B83992D54802D54802D54802D5480438CA2438CA2438CA2438CA2
40779A40779A40779A40779A11528F11528F11528F11528F2A729D2A729D2A729D2A729D
2A729D11648D11648D11648D11648D276F93276F93276F93276F93116C96116C96116C96
116C9611648D11648D11648D11648D2A729D2A729D2A729D2A729D116C96116C96116C96
116C96116C961558831558831558831558832860912860912860912860912A729D2A729D
2A729D2A729D2B83992B83992B83992B839908648D08648D08648D08648D276F93276F93
276F93276F93276F93116495116495116495116495196493196493196493196493155883
1558831558831558830E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA240779A
40779A40779A40779A40779A15588315588315588315588319588F19588F19588F19588F
115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A438CA2438CA2438CA2438CA2
11648D11648D11648D11648D11648D11528F11528F11528F11528F19588F19588F19588F
19588F115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A115B8F115B8F115B8F115B8F115B8F286091286091286091286091286091286091
28609128609140779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609111528F11528F11528F11528F11528F155883155883155883155883116495
1164951164951164951164951164951164951164952B83992B83992B83992B8399155883
1558831558831558830C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B
15588315588315588315588319588F19588F19588F19588F196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2115B8F115B8F115B8F
115B8F115B8F115B8F115B8F115B8F1558831558831558831558835B90A55B90A55B90A5
5B90A52B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F276F93000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000155883155883155883155883116495116495116495116495
1164951164951164951164952B83992B83992B83992B83992B8399155883155883155883
1558830C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B155883155883155883
15588319588F19588F19588F19588F1964931964931964931964931964930E7C8D0E7C8D
0E7C8D0E7C8D438CA2438CA2438CA2438CA2115B8F115B8F115B8F115B8F115B8F115B8F
115B8F115B8F1558831558831558831558835B90A55B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F276F93276F93276F93276F9311528F11528F11528F11528F11528F
2B83992B83992B83992B83992D54802D54802D54802D5480438CA2438CA2438CA2438CA2
40779A40779A40779A40779A11528F11528F11528F11528F2A729D2A729D2A729D2A729D
2A729D11648D11648D11648D11648D276F93276F93276F93276F93116C96116C96116C96
116C9611648D11648D11648D11648D2A729D2A729D2A729D2A729D116C96116C96116C96
116C96116C961558831558831558831558832860912860912860912860912A729D2A729D
2A729D2A729D2B83992B83992B83992B839908648D08648D08648D08648D276F93276F93
276F93276F93276F93116495116495116495116495196493196493196493196493155883
1558831558831558830E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA240779A
40779A40779A40779A40779A15588315588315588315588319588F19588F19588F19588F
115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A438CA2438CA2438CA2438CA2
11648D11648D11648D11648D11648D11528F11528F11528F11528F19588F19588F19588F
19588F115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A115B8F115B8F115B8F115B8F115B8F286091286091286091286091286091286091
28609128609140779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609111528F11528F11528F11528F11528F155883155883155883155883116495
1164951164951164951164951164951164951164952B83992B83992B83992B8399155883
1558831558831558830C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B
15588315588315588315588319588F19588F19588F19588F196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2115B8F115B8F115B8F
115B8F115B8F115B8F115B8F115B8F1558831558831558831558835B90A55B90A55B90A5
5B90A52B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F276F93000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000011528F11528F11528F155883155883155883155883116495116495116495116495
1164951164951164951164952B83992B83992B83992B83992B8399155883155883155883
1558830C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B155883155883155883
15588319588F19588F19588F19588F1964931964931964931964931964930E7C8D0E7C8D
0E7C8D0E7C8D438CA2438CA2438CA2438CA2115B8F115B8F115B8F115B8F115B8F115B8F
115B8F115B8F1558831558831558831558835B90A55B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F276F93276F93276F93276F9311528F11528F11528F11528F11528F
2B83992B83992B83992B83992D54802D54802D54802D5480438CA2438CA2438CA2438CA2
40779A40779A40779A40779A11528F11528F11528F11528F2A729D2A729D2A729D2A729D
2A729D11648D11648D11648D11648D276F93276F93276F93276F93116C96116C96116C96
116C9611648D11648D11648D11648D2A729D2A729D2A729D2A729D116C96116C96116C96
116C96116C961558831558831558831558832860912860912860912860912A729D2A729D
2A729D2A729D2B83992B83992B83992B839908648D08648D08648D08648D276F93276F93
276F93276F93276F93116495116495116495116495196493196493196493196493155883
1558831558831558830E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA240779A
40779A40779A40779A40779A15588315588315588315588319588F19588F19588F19588F
115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A438CA2438CA2438CA2438CA2
11648D11648D11648D11648D11648D11528F11528F11528F11528F19588F19588F19588F
19588F115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A115B8F115B8F115B8F115B8F115B8F286091286091286091286091286091286091
28609128609140779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609111528F11528F11528F11528F11528F155883155883155883155883116495
1164951164951164951164951164951164951164952B83992B83992B83992B8399155883
1558831558831558830C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B
15588315588315588315588319588F19588F19588F19588F196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2115B8F115B8F115B8F
115B8F115B8F115B8F115B8F115B8F1558831558831558831558835B90A55B90A55B90A5
5B90A52B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F276F93000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000286091286091286091
11528F11528F11528F11528F155883155883155883155883116495116495116495116495
1164951164951164951164952B83992B83992B83992B83992B8399155883155883155883
1558830C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B155883155883155883
15588319588F19588F19588F19588F1964931964931964931964931964930E7C8D0E7C8D
0E7C8D0E7C8D438CA2438CA2438CA2438CA2115B8F115B8F115B8F115B8F115B8F115B8F
115B8F115B8F1558831558831558831558835B90A55B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F276F93276F93276F93276F9311528F11528F11528F11528F11528F
2B83992B83992B83992B83992D54802D54802D54802D5480438CA2438CA2438CA2438CA2
40779A40779A40779A40779A11528F11528F11528F11528F2A729D2A729D2A729D2A729D
2A729D11648D11648D11648D11648D276F93276F93276F93276F93116C96116C96116C96
116C9611648D11648D11648D11648D2A729D2A729D2A729D2A729D116C96116C96116C96
116C96116C961558831558831558831558832860912860912860912860912A729D2A729D
2A729D2A729D2B83992B83992B83992B839908648D08648D08648D08648D276F93276F93
276F93276F93276F93116495116495116495116495196493196493196493196493155883
1558831558831558830E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA240779A
40779A40779A40779A40779A15588315588315588315588319588F19588F19588F19588F
115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A438CA2438CA2438CA2438CA2
11648D11648D11648D11648D11648D11528F11528F11528F11528F19588F19588F19588F
19588F115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A115B8F115B8F115B8F115B8F115B8F286091286091286091286091286091286091
28609128609140779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609111528F11528F11528F11528F11528F155883155883155883155883116495
1164951164951164951164951164951164951164952B83992B83992B83992B8399155883
1558831558831558830C6C8A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B
15588315588315588315588319588F19588F19588F19588F196493196493196493196493
0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2115B8F115B8F115B8F
115B8F115B8F115B8F115B8F115B8F1558831558831558831558835B90A55B90A55B90A5
5B90A52B83992B83992B83992B8399095B8D095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F276F93000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000196493196493196493116495116495116495116495
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A5
5B90A516427B16427B16427B16427B2860912860912860912860910C8E870C8E870C8E87
0C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C155883155883
155883155883438CA2438CA2438CA2438CA211648D11648D11648D11648D40779A40779A
40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A115B8F
115B8F115B8F115B8F16427B16427B16427B16427B2D54802D54802D54802D54800C6C8A
0C6C8A0C6C8A0C6C8A19588F19588F19588F19588F11648D11648D11648D11648D11648D
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C438CA2438CA2438CA2438CA2
2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C196493196493196493196493116C96116C96116C96
116C961558831558831558831558832D54802D54802D54802D5480085B95085B95085B95
085B95085B95276F93276F93276F93276F9340779A40779A40779A40779A155883155883
1558831558830F748F0F748F0F748F0F748F1164951164951164951164950E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93276F93276F93155883
155883155883155883155883155883155883155883276F93276F93276F93276F93115B8F
115B8F115B8F115B8F115B8F2D54802D54802D54802D5480286091286091286091286091
1558831558831558831558832860912860912860912860912B83992B83992B83992B8399
2D54802D54802D54802D54802D5480116495116495116495116495276F93276F93276F93
276F93115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D286091286091286091
286091115B8F115B8F115B8F115B8F115B8F2B83992B83992B83992B8399286091286091
286091286091286091286091286091286091196493196493196493196493116495116495
1164951164951558831558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091
286091286091286091095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A516427B16427B16427B16427B16427B286091286091286091286091
0C8E870C8E870C8E870C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C
155883155883155883155883438CA2438CA2438CA2438CA2438CA211648D11648D11648D
11648D40779A40779A40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B2D54802D5480
2D54802D54800C6C8A0C6C8A0C6C8A0C6C8A19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000286091196493196493196493196493196493116495116495116495116495
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A5
5B90A516427B16427B16427B16427B2860912860912860912860910C8E870C8E870C8E87
0C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C155883155883
155883155883438CA2438CA2438CA2438CA211648D11648D11648D11648D40779A40779A
40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A115B8F
115B8F115B8F115B8F16427B16427B16427B16427B2D54802D54802D54802D54800C6C8A
0C6C8A0C6C8A0C6C8A19588F19588F19588F19588F11648D11648D11648D11648D11648D
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C438CA2438CA2438CA2438CA2
2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C196493196493196493196493116C96116C96116C96
116C961558831558831558831558832D54802D54802D54802D5480085B95085B95085B95
085B95085B95276F93276F93276F93276F9340779A40779A40779A40779A155883155883
1558831558830F748F0F748F0F748F0F748F1164951164951164951164950E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93276F93276F93155883
155883155883155883155883155883155883155883276F93276F93276F93276F93115B8F
115B8F115B8F115B8F115B8F2D54802D54802D54802D5480286091286091286091286091
1558831558831558831558832860912860912860912860912B83992B83992B83992B8399
2D54802D54802D54802D54802D5480116495116495116495116495276F93276F93276F93
276F93115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D286091286091286091
286091115B8F115B8F115B8F115B8F115B8F2B83992B83992B83992B8399286091286091
286091286091286091286091286091286091196493196493196493196493116495116495
1164951164951558831558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091
286091286091286091095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A516427B16427B16427B16427B16427B286091286091286091286091
0C8E870C8E870C8E870C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C
155883155883155883155883438CA2438CA2438CA2438CA2438CA211648D11648D11648D
11648D40779A40779A40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B2D54802D5480
2D54802D54800C6C8A0C6C8A0C6C8A0C6C8A19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000286091286091
286091286091286091196493196493196493196493196493116495116495116495116495
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A5
5B90A516427B16427B16427B16427B2860912860912860912860910C8E870C8E870C8E87
0C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C155883155883
155883155883438CA2438CA2438CA2438CA211648D11648D11648D11648D40779A40779A
40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A115B8F
115B8F115B8F115B8F16427B16427B16427B16427B2D54802D54802D54802D54800C6C8A
0C6C8A0C6C8A0C6C8A19588F19588F19588F19588F11648D11648D11648D11648D11648D
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C438CA2438CA2438CA2438CA2
2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C196493196493196493196493116C96116C96116C96
116C961558831558831558831558832D54802D54802D54802D5480085B95085B95085B95
085B95085B95276F93276F93276F93276F9340779A40779A40779A40779A155883155883
1558831558830F748F0F748F0F748F0F748F1164951164951164951164950E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93276F93276F93155883
155883155883155883155883155883155883155883276F93276F93276F93276F93115B8F
115B8F115B8F115B8F115B8F2D54802D54802D54802D5480286091286091286091286091
1558831558831558831558832860912860912860912860912B83992B83992B83992B8399
2D54802D54802D54802D54802D5480116495116495116495116495276F93276F93276F93
276F93115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D286091286091286091
286091115B8F115B8F115B8F115B8F115B8F2B83992B83992B83992B8399286091286091
286091286091286091286091286091286091196493196493196493196493116495116495
1164951164951558831558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091
286091286091286091095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A516427B16427B16427B16427B16427B286091286091286091286091
0C8E870C8E870C8E870C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C
155883155883155883155883438CA2438CA2438CA2438CA2438CA211648D11648D11648D
11648D40779A40779A40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B2D54802D5480
2D54802D54800C6C8A0C6C8A0C6C8A0C6C8A19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002B8399286091286091286091286091286091
286091286091286091196493196493196493196493196493116495116495116495116495
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A5
5B90A516427B16427B16427B16427B2860912860912860912860910C8E870C8E870C8E87
0C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C155883155883
155883155883438CA2438CA2438CA2438CA211648D11648D11648D11648D40779A40779A
40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A115B8F
115B8F115B8F115B8F16427B16427B16427B16427B2D54802D54802D54802D54800C6C8A
0C6C8A0C6C8A0C6C8A19588F19588F19588F19588F11648D11648D11648D11648D11648D
1558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C438CA2438CA2438CA2438CA2
2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C196493196493196493196493116C96116C96116C96
116C961558831558831558831558832D54802D54802D54802D5480085B95085B95085B95
085B95085B95276F93276F93276F93276F9340779A40779A40779A40779A155883155883
1558831558830F748F0F748F0F748F0F748F1164951164951164951164950E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93276F93276F93155883
155883155883155883155883155883155883155883276F93276F93276F93276F93115B8F
115B8F115B8F115B8F115B8F2D54802D54802D54802D5480286091286091286091286091
1558831558831558831558832860912860912860912860912B83992B83992B83992B8399
2D54802D54802D54802D54802D5480116495116495116495116495276F93276F93276F93
276F93115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D286091286091286091
286091115B8F115B8F115B8F115B8F115B8F2B83992B83992B83992B8399286091286091
286091286091286091286091286091286091196493196493196493196493116495116495
1164951164951558831558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C286091
286091286091286091095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A516427B16427B16427B16427B16427B286091286091286091286091
0C8E870C8E870C8E870C8E872860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C
155883155883155883155883438CA2438CA2438CA2438CA2438CA211648D11648D11648D
11648D40779A40779A40779A40779A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B2D54802D5480
2D54802D54800C6C8A0C6C8A0C6C8A0C6C8A19588F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000005B90A55B90A55B90A55B90A5196493196493196493196493438CA2
438CA2438CA2438CA211648D11648D11648D11648D11648D2B83992B83992B83992B8399
2D54802D54802D54802D54802860912860912860912860912A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A55B90A5115B8F115B8F115B8F
115B8F2B83992B83992B83992B839919588F19588F19588F19588F196493196493196493
19649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A196493196493196493196493286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B84045B84276F93
276F93276F93276F935B90A55B90A55B90A55B90A5095B8D095B8D095B8D095B8D0C6C8A
0C6C8A0C6C8A0C6C8A2D54802D54802D54802D5480286091286091286091286091286091
115B8F115B8F115B8F115B8F276F93276F93276F93276F93116495116495116495116495
5B90A55B90A55B90A55B90A5115B8F115B8F115B8F115B8F196493196493196493196493
1964931964931964931964931964932A729D2A729D2A729D2A729D5B90A55B90A55B90A5
5B90A52B83992B83992B83992B839940779A40779A40779A40779A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D19649319649319649319649316427B16427B16427B16427B11528F11528F
11528F11528F2B83992B83992B83992B8399276F93276F93276F93276F93196493196493
19649319649319649304648304648304648304648340779A40779A40779A40779A16427B
16427B16427B16427B155883155883155883155883046483046483046483046483115B8F
115B8F115B8F115B8F115B8F19588F19588F19588F19588F286091286091286091286091
11528F11528F11528F11528F2A2F6C2A2F6C2A2F6C2A2F6C2A729D2A729D2A729D2A729D
276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93
276F935B90A55B90A55B90A55B90A511528F11528F11528F11528F276F93276F93276F93
276F930464830464830464830464830464835B90A55B90A55B90A55B90A5196493196493
196493196493438CA2438CA2438CA2438CA211648D11648D11648D11648D2B83992B8399
2B83992B83992D54802D54802D54802D54802D54802860912860912860912860912A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A5115B8F
115B8F115B8F115B8F2B83992B83992B83992B83992B839919588F19588F19588F19588F
19649319649319649319649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
1964932860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84
045B84276F93276F93276F93276F935B90A55B90A55B90A55B90A55B90A5095B8D095B8D
095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000046483
0464830464830464835B90A55B90A55B90A55B90A5196493196493196493196493438CA2
438CA2438CA2438CA211648D11648D11648D11648D11648D2B83992B83992B83992B8399
2D54802D54802D54802D54802860912860912860912860912A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A55B90A5115B8F115B8F115B8F
115B8F2B83992B83992B83992B839919588F19588F19588F19588F196493196493196493
19649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A196493196493196493196493286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B84045B84276F93
276F93276F93276F935B90A55B90A55B90A55B90A5095B8D095B8D095B8D095B8D0C6C8A
0C6C8A0C6C8A0C6C8A2D54802D54802D54802D5480286091286091286091286091286091
115B8F115B8F115B8F115B8F276F93276F93276F93276F93116495116495116495116495
5B90A55B90A55B90A55B90A5115B8F115B8F115B8F115B8F196493196493196493196493
1964931964931964931964931964932A729D2A729D2A729D2A729D5B90A55B90A55B90A5
5B90A52B83992B83992B83992B839940779A40779A40779A40779A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D19649319649319649319649316427B16427B16427B16427B11528F11528F
11528F11528F2B83992B83992B83992B8399276F93276F93276F93276F93196493196493
19649319649319649304648304648304648304648340779A40779A40779A40779A16427B
16427B16427B16427B155883155883155883155883046483046483046483046483115B8F
115B8F115B8F115B8F115B8F19588F19588F19588F19588F286091286091286091286091
11528F11528F11528F11528F2A2F6C2A2F6C2A2F6C2A2F6C2A729D2A729D2A729D2A729D
276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93
276F935B90A55B90A55B90A55B90A511528F11528F11528F11528F276F93276F93276F93
276F930464830464830464830464830464835B90A55B90A55B90A55B90A5196493196493
196493196493438CA2438CA2438CA2438CA211648D11648D11648D11648D2B83992B8399
2B83992B83992D54802D54802D54802D54802D54802860912860912860912860912A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A5115B8F
115B8F115B8F115B8F2B83992B83992B83992B83992B839919588F19588F19588F19588F
19649319649319649319649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
1964932860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84
045B84276F93276F93276F93276F935B90A55B90A55B90A55B90A55B90A5095B8D095B8D
095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000276F93276F93276F93276F93046483
0464830464830464835B90A55B90A55B90A55B90A5196493196493196493196493438CA2
438CA2438CA2438CA211648D11648D11648D11648D11648D2B83992B83992B83992B8399
2D54802D54802D54802D54802860912860912860912860912A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A55B90A5115B8F115B8F115B8F
115B8F2B83992B83992B83992B839919588F19588F19588F19588F196493196493196493
19649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A196493196493196493196493286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B84045B84276F93
276F93276F93276F935B90A55B90A55B90A55B90A5095B8D095B8D095B8D095B8D0C6C8A
0C6C8A0C6C8A0C6C8A2D54802D54802D54802D5480286091286091286091286091286091
115B8F115B8F115B8F115B8F276F93276F93276F93276F93116495116495116495116495
5B90A55B90A55B90A55B90A5115B8F115B8F115B8F115B8F196493196493196493196493
1964931964931964931964931964932A729D2A729D2A729D2A729D5B90A55B90A55B90A5
5B90A52B83992B83992B83992B839940779A40779A40779A40779A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D19649319649319649319649316427B16427B16427B16427B11528F11528F
11528F11528F2B83992B83992B83992B8399276F93276F93276F93276F93196493196493
19649319649319649304648304648304648304648340779A40779A40779A40779A16427B
16427B16427B16427B155883155883155883155883046483046483046483046483115B8F
115B8F115B8F115B8F115B8F19588F19588F19588F19588F286091286091286091286091
11528F11528F11528F11528F2A2F6C2A2F6C2A2F6C2A2F6C2A729D2A729D2A729D2A729D
276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93
276F935B90A55B90A55B90A55B90A511528F11528F11528F11528F276F93276F93276F93
276F930464830464830464830464830464835B90A55B90A55B90A55B90A5196493196493
196493196493438CA2438CA2438CA2438CA211648D11648D11648D11648D2B83992B8399
2B83992B83992D54802D54802D54802D54802D54802860912860912860912860912A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A5115B8F
115B8F115B8F115B8F2B83992B83992B83992B83992B839919588F19588F19588F19588F
19649319649319649319649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
1964932860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84
045B84276F93276F93276F93276F935B90A55B90A55B90A55B90A55B90A5095B8D095B8D
095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000011528F11528F11528F276F93276F93276F93276F93046483
0464830464830464835B90A55B90A55B90A55B90A5196493196493196493196493438CA2
438CA2438CA2438CA211648D11648D11648D11648D11648D2B83992B83992B83992B8399
2D54802D54802D54802D54802860912860912860912860912A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A55B90A5115B8F115B8F115B8F
115B8F2B83992B83992B83992B839919588F19588F19588F19588F196493196493196493
19649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
1964931964930C6C8A0C6C8A0C6C8A0C6C8A196493196493196493196493286091286091
2860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84045B84045B84276F93
276F93276F93276F935B90A55B90A55B90A55B90A5095B8D095B8D095B8D095B8D0C6C8A
0C6C8A0C6C8A0C6C8A2D54802D54802D54802D5480286091286091286091286091286091
115B8F115B8F115B8F115B8F276F93276F93276F93276F93116495116495116495116495
5B90A55B90A55B90A55B90A5115B8F115B8F115B8F115B8F196493196493196493196493
1964931964931964931964931964932A729D2A729D2A729D2A729D5B90A55B90A55B90A5
5B90A52B83992B83992B83992B839940779A40779A40779A40779A0E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D19649319649319649319649316427B16427B16427B16427B11528F11528F
11528F11528F2B83992B83992B83992B8399276F93276F93276F93276F93196493196493
19649319649319649304648304648304648304648340779A40779A40779A40779A16427B
16427B16427B16427B155883155883155883155883046483046483046483046483115B8F
115B8F115B8F115B8F115B8F19588F19588F19588F19588F286091286091286091286091
11528F11528F11528F11528F2A2F6C2A2F6C2A2F6C2A2F6C2A729D2A729D2A729D2A729D
276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93276F93
276F935B90A55B90A55B90A55B90A511528F11528F11528F11528F276F93276F93276F93
276F930464830464830464830464830464835B90A55B90A55B90A55B90A5196493196493
196493196493438CA2438CA2438CA2438CA211648D11648D11648D11648D2B83992B8399
2B83992B83992D54802D54802D54802D54802D54802860912860912860912860912A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A5B90A55B90A55B90A55B90A5115B8F
115B8F115B8F115B8F2B83992B83992B83992B83992B839919588F19588F19588F19588F
19649319649319649319649319588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
1964932860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A045B84045B84045B84
045B84276F93276F93276F93276F935B90A55B90A55B90A55B90A55B90A5095B8D095B8D
095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A2D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002B83992B83992B83992B83992B83992B83992D54802D54802D54802D5480155883
155883155883155883095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F2A729D2A729D2A729D2A729D2A729D2D54802D54802D54802D5480
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B839919588F19588F19588F19588F005B8D005B8D005B8D005B8D05538A05538A05538A
05538A11648D11648D11648D11648D155883155883155883155883155883286091286091
2860912860912A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D2D54802D5480
2D54802D54802D54802D54802D54802D5480286091286091286091286091286091115B8F
115B8F115B8F115B8F2D54802D54802D54802D54805B90A55B90A55B90A55B90A50E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091286091286091286091286091
0E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2D54802D54802D54802D5480
095B8D095B8D095B8D095B8D155883155883155883155883155883155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D196493196493196493
1964931964932B83992B83992B83992B8399155883155883155883155883286091286091
286091286091286091286091286091286091155883155883155883155883276F93276F93
276F93276F93276F9340779A40779A40779A40779A16427B16427B16427B16427B276F93
276F93276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399116495
1164951164951164951164950F748F0F748F0F748F0F748F11528F11528F11528F11528F
286091286091286091286091276F93276F93276F93276F9311648D11648D11648D11648D
276F93276F93276F93276F93276F93155883155883155883155883116C96116C96116C96
116C962B83992B83992B83992B83992B83992B83992B83992B83992D54802D54802D5480
2D5480155883155883155883155883155883095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D2D54802D5480
2D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93
276F93276F93276F9340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B839919588F19588F19588F19588F19588F005B8D005B8D005B8D005B8D
05538A05538A05538A05538A11648D11648D11648D11648D155883155883155883155883
2860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D2D54802D54802D54802D54802D54802D54802D54802D5480286091286091286091
286091115B8F115B8F115B8F115B8F2D54802D54802D54802D54802D54805B90A55B90A5
5B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000116C962B83992B8399
2B83992B83992B83992B83992B83992B83992B83992D54802D54802D54802D5480155883
155883155883155883095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F2A729D2A729D2A729D2A729D2A729D2D54802D54802D54802D5480
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B839919588F19588F19588F19588F005B8D005B8D005B8D005B8D05538A05538A05538A
05538A11648D11648D11648D11648D155883155883155883155883155883286091286091
2860912860912A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D2D54802D5480
2D54802D54802D54802D54802D54802D5480286091286091286091286091286091115B8F
115B8F115B8F115B8F2D54802D54802D54802D54805B90A55B90A55B90A55B90A50E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091286091286091286091286091
0E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2D54802D54802D54802D5480
095B8D095B8D095B8D095B8D155883155883155883155883155883155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D196493196493196493
1964931964932B83992B83992B83992B8399155883155883155883155883286091286091
286091286091286091286091286091286091155883155883155883155883276F93276F93
276F93276F93276F9340779A40779A40779A40779A16427B16427B16427B16427B276F93
276F93276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399116495
1164951164951164951164950F748F0F748F0F748F0F748F11528F11528F11528F11528F
286091286091286091286091276F93276F93276F93276F9311648D11648D11648D11648D
276F93276F93276F93276F93276F93155883155883155883155883116C96116C96116C96
116C962B83992B83992B83992B83992B83992B83992B83992B83992D54802D54802D5480
2D5480155883155883155883155883155883095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D2D54802D5480
2D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93
276F93276F93276F9340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B839919588F19588F19588F19588F19588F005B8D005B8D005B8D005B8D
05538A05538A05538A05538A11648D11648D11648D11648D155883155883155883155883
2860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D2D54802D54802D54802D54802D54802D54802D54802D5480286091286091286091
286091115B8F115B8F115B8F115B8F2D54802D54802D54802D54802D54805B90A55B90A5
5B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000116C96116C96116C96116C962B83992B8399
2B83992B83992B83992B83992B83992B83992B83992D54802D54802D54802D5480155883
155883155883155883095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F2A729D2A729D2A729D2A729D2A729D2D54802D54802D54802D5480
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B839919588F19588F19588F19588F005B8D005B8D005B8D005B8D05538A05538A05538A
05538A11648D11648D11648D11648D155883155883155883155883155883286091286091
2860912860912A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D2D54802D5480
2D54802D54802D54802D54802D54802D5480286091286091286091286091286091115B8F
115B8F115B8F115B8F2D54802D54802D54802D54805B90A55B90A55B90A55B90A50E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091286091286091286091286091
0E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2D54802D54802D54802D5480
095B8D095B8D095B8D095B8D155883155883155883155883155883155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D196493196493196493
1964931964932B83992B83992B83992B8399155883155883155883155883286091286091
286091286091286091286091286091286091155883155883155883155883276F93276F93
276F93276F93276F9340779A40779A40779A40779A16427B16427B16427B16427B276F93
276F93276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399116495
1164951164951164951164950F748F0F748F0F748F0F748F11528F11528F11528F11528F
286091286091286091286091276F93276F93276F93276F9311648D11648D11648D11648D
276F93276F93276F93276F93276F93155883155883155883155883116C96116C96116C96
116C962B83992B83992B83992B83992B83992B83992B83992B83992D54802D54802D5480
2D5480155883155883155883155883155883095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D2D54802D5480
2D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93
276F93276F93276F9340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B839919588F19588F19588F19588F19588F005B8D005B8D005B8D005B8D
05538A05538A05538A05538A11648D11648D11648D11648D155883155883155883155883
2860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D2D54802D54802D54802D54802D54802D54802D54802D5480286091286091286091
286091115B8F115B8F115B8F115B8F2D54802D54802D54802D54802D54805B90A55B90A5
5B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000155883155883155883116C96116C96116C96116C962B83992B8399
2B83992B83992B83992B83992B83992B83992B83992D54802D54802D54802D5480155883
155883155883155883095B8D095B8D095B8D095B8D40779A40779A40779A40779A115B8F
115B8F115B8F115B8F2A729D2A729D2A729D2A729D2A729D2D54802D54802D54802D5480
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B839919588F19588F19588F19588F005B8D005B8D005B8D005B8D05538A05538A05538A
05538A11648D11648D11648D11648D155883155883155883155883155883286091286091
2860912860912A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D2D54802D5480
2D54802D54802D54802D54802D54802D5480286091286091286091286091286091115B8F
115B8F115B8F115B8F2D54802D54802D54802D54805B90A55B90A55B90A55B90A50E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091286091286091286091286091
0E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2D54802D54802D54802D5480
095B8D095B8D095B8D095B8D155883155883155883155883155883155883155883155883
155883276F93276F93276F93276F93276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D196493196493196493
1964931964932B83992B83992B83992B8399155883155883155883155883286091286091
286091286091286091286091286091286091155883155883155883155883276F93276F93
276F93276F93276F9340779A40779A40779A40779A16427B16427B16427B16427B276F93
276F93276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399116495
1164951164951164951164950F748F0F748F0F748F0F748F11528F11528F11528F11528F
286091286091286091286091276F93276F93276F93276F9311648D11648D11648D11648D
276F93276F93276F93276F93276F93155883155883155883155883116C96116C96116C96
116C962B83992B83992B83992B83992B83992B83992B83992B83992D54802D54802D5480
2D5480155883155883155883155883155883095B8D095B8D095B8D095B8D40779A40779A
40779A40779A115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D2D54802D5480
2D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091276F93
276F93276F93276F9340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B839919588F19588F19588F19588F19588F005B8D005B8D005B8D005B8D
05538A05538A05538A05538A11648D11648D11648D11648D155883155883155883155883
2860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D2D54802D54802D54802D54802D54802D54802D54802D5480286091286091286091
286091115B8F115B8F115B8F115B8F2D54802D54802D54802D54802D54805B90A55B90A5
5B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
11648D11648D40779A40779A40779A40779A1558831558831558831558832D54802D5480
2D54802D548040779A40779A40779A40779A40779A40779A40779A40779A40779A05538A
05538A05538A05538A16427B16427B16427B16427B2B83992B83992B83992B839905538A
05538A05538A05538A196493196493196493196493196493044582044582044582044582
095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883155883155883155883
155883155883155883155883045B84045B84045B84045B84045B840E7C8D0E7C8D0E7C8D
0E7C8D0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A
05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D0F748F0F748F0F748F0F748F1558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D155883155883155883155883155883155883155883155883155883196493
1964931964931964930C8E870C8E870C8E870C8E872860912860912860912860915B90A5
5B90A55B90A55B90A516427B16427B16427B16427B5B90A55B90A55B90A55B90A55B90A5
1164951164951164951164951558831558831558831558832D54802D54802D54802D5480
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F930F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D085B95085B95085B95085B95196493196493196493
196493438CA2438CA2438CA2438CA240779A40779A40779A40779A2B83992B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D08648D08648D08648D08648D0C8E870C8E87
0C8E870C8E8708648D08648D08648D08648D5B90A55B90A55B90A55B90A5276F93276F93
276F93276F93276F93116C96116C96116C96116C962A2F6C2A2F6C2A2F6C2A2F6C286091
2860912860912860910C8E870C8E870C8E870C8E871164951164951164951164950C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D40779A40779A40779A40779A
15588315588315588315588305538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D
11648D11648D11648D11648D11648D40779A40779A40779A40779A155883155883155883
1558832D54802D54802D54802D548040779A40779A40779A40779A40779A40779A40779A
40779A05538A05538A05538A05538A05538A16427B16427B16427B16427B2B83992B8399
2B83992B839905538A05538A05538A05538A196493196493196493196493044582044582
044582044582095B8D095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883
155883155883155883155883155883155883155883045B84045B84045B84045B840E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F0F748F155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D155883155883155883155883155883155883155883
1558831964931964931964931964930C8E870C8E870C8E870C8E870C8E87286091286091
2860912860915B90A55B90A55B90A55B90A516427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000E7C8D11648D11648D
11648D11648D40779A40779A40779A40779A1558831558831558831558832D54802D5480
2D54802D548040779A40779A40779A40779A40779A40779A40779A40779A40779A05538A
05538A05538A05538A16427B16427B16427B16427B2B83992B83992B83992B839905538A
05538A05538A05538A196493196493196493196493196493044582044582044582044582
095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883155883155883155883
155883155883155883155883045B84045B84045B84045B84045B840E7C8D0E7C8D0E7C8D
0E7C8D0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A
05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D0F748F0F748F0F748F0F748F1558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D155883155883155883155883155883155883155883155883155883196493
1964931964931964930C8E870C8E870C8E870C8E872860912860912860912860915B90A5
5B90A55B90A55B90A516427B16427B16427B16427B5B90A55B90A55B90A55B90A55B90A5
1164951164951164951164951558831558831558831558832D54802D54802D54802D5480
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F930F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D085B95085B95085B95085B95196493196493196493
196493438CA2438CA2438CA2438CA240779A40779A40779A40779A2B83992B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D08648D08648D08648D08648D0C8E870C8E87
0C8E870C8E8708648D08648D08648D08648D5B90A55B90A55B90A55B90A5276F93276F93
276F93276F93276F93116C96116C96116C96116C962A2F6C2A2F6C2A2F6C2A2F6C286091
2860912860912860910C8E870C8E870C8E870C8E871164951164951164951164950C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D40779A40779A40779A40779A
15588315588315588315588305538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D
11648D11648D11648D11648D11648D40779A40779A40779A40779A155883155883155883
1558832D54802D54802D54802D548040779A40779A40779A40779A40779A40779A40779A
40779A05538A05538A05538A05538A05538A16427B16427B16427B16427B2B83992B8399
2B83992B839905538A05538A05538A05538A196493196493196493196493044582044582
044582044582095B8D095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883
155883155883155883155883155883155883155883045B84045B84045B84045B840E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F0F748F155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D155883155883155883155883155883155883155883
1558831964931964931964931964930C8E870C8E870C8E870C8E870C8E87286091286091
2860912860915B90A55B90A55B90A55B90A516427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000005538A0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D40779A40779A40779A40779A1558831558831558831558832D54802D5480
2D54802D548040779A40779A40779A40779A40779A40779A40779A40779A40779A05538A
05538A05538A05538A16427B16427B16427B16427B2B83992B83992B83992B839905538A
05538A05538A05538A196493196493196493196493196493044582044582044582044582
095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883155883155883155883
155883155883155883155883045B84045B84045B84045B84045B840E7C8D0E7C8D0E7C8D
0E7C8D0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A
05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D0F748F0F748F0F748F0F748F1558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D155883155883155883155883155883155883155883155883155883196493
1964931964931964930C8E870C8E870C8E870C8E872860912860912860912860915B90A5
5B90A55B90A55B90A516427B16427B16427B16427B5B90A55B90A55B90A55B90A55B90A5
1164951164951164951164951558831558831558831558832D54802D54802D54802D5480
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F930F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D085B95085B95085B95085B95196493196493196493
196493438CA2438CA2438CA2438CA240779A40779A40779A40779A2B83992B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D08648D08648D08648D08648D0C8E870C8E87
0C8E870C8E8708648D08648D08648D08648D5B90A55B90A55B90A55B90A5276F93276F93
276F93276F93276F93116C96116C96116C96116C962A2F6C2A2F6C2A2F6C2A2F6C286091
2860912860912860910C8E870C8E870C8E870C8E871164951164951164951164950C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D40779A40779A40779A40779A
15588315588315588315588305538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D
11648D11648D11648D11648D11648D40779A40779A40779A40779A155883155883155883
1558832D54802D54802D54802D548040779A40779A40779A40779A40779A40779A40779A
40779A05538A05538A05538A05538A05538A16427B16427B16427B16427B2B83992B8399
2B83992B839905538A05538A05538A05538A196493196493196493196493044582044582
044582044582095B8D095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883
155883155883155883155883155883155883155883045B84045B84045B84045B840E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F0F748F155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D155883155883155883155883155883155883155883
1558831964931964931964931964930C8E870C8E870C8E870C8E870C8E87286091286091
2860912860915B90A55B90A55B90A55B90A516427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000005538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D40779A40779A40779A40779A1558831558831558831558832D54802D5480
2D54802D548040779A40779A40779A40779A40779A40779A40779A40779A40779A05538A
05538A05538A05538A16427B16427B16427B16427B2B83992B83992B83992B839905538A
05538A05538A05538A196493196493196493196493196493044582044582044582044582
095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883155883155883155883
155883155883155883155883045B84045B84045B84045B84045B840E7C8D0E7C8D0E7C8D
0E7C8D0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C05538A05538A05538A
05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D0F748F0F748F0F748F0F748F1558831558831558831558830E7C8D0E7C8D
0E7C8D0E7C8D155883155883155883155883155883155883155883155883155883196493
1964931964931964930C8E870C8E870C8E870C8E872860912860912860912860915B90A5
5B90A55B90A55B90A516427B16427B16427B16427B5B90A55B90A55B90A55B90A55B90A5
1164951164951164951164951558831558831558831558832D54802D54802D54802D5480
0C6C8A0C6C8A0C6C8A0C6C8A276F93276F93276F93276F930F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D085B95085B95085B95085B95196493196493196493
196493438CA2438CA2438CA2438CA240779A40779A40779A40779A2B83992B83992B8399
2B83992B8399005B8D005B8D005B8D005B8D08648D08648D08648D08648D0C8E870C8E87
0C8E870C8E8708648D08648D08648D08648D5B90A55B90A55B90A55B90A5276F93276F93
276F93276F93276F93116C96116C96116C96116C962A2F6C2A2F6C2A2F6C2A2F6C286091
2860912860912860910C8E870C8E870C8E870C8E871164951164951164951164950C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D40779A40779A40779A40779A
15588315588315588315588305538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D
11648D11648D11648D11648D11648D40779A40779A40779A40779A155883155883155883
1558832D54802D54802D54802D548040779A40779A40779A40779A40779A40779A40779A
40779A05538A05538A05538A05538A05538A16427B16427B16427B16427B2B83992B8399
2B83992B839905538A05538A05538A05538A196493196493196493196493044582044582
044582044582095B8D095B8D095B8D095B8D095B8D11648D11648D11648D11648D155883
155883155883155883155883155883155883155883045B84045B84045B84045B840E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A0E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2438CA2438CA2
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F0F748F155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D155883155883155883155883155883155883155883
1558831964931964931964931964930C8E870C8E870C8E870C8E870C8E87286091286091
2860912860915B90A55B90A55B90A55B90A516427B000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000196493
1964932D54802D54802D54802D54802D548040779A40779A40779A40779A11528F11528F
11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93276F9316427B16427B
16427B16427B2A729D2A729D2A729D2A729D2A729D16427B16427B16427B16427B05538A
05538A05538A05538A0445820445820445820445825B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399155883155883155883155883155883115B8F115B8F115B8F115B8F
08648D08648D08648D08648D40779A40779A40779A40779A16427B16427B16427B16427B
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E8711648D11648D11648D
11648D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B16427B16427B16427B16427B196493196493196493196493196493155883155883
1558831558830F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5196493196493
196493196493276F93276F93276F93276F93438CA2438CA2438CA2438CA2438CA2095B8D
095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
11528F11528F11528F11528F005B8D005B8D005B8D005B8D438CA2438CA2438CA2438CA2
116C96116C96116C96116C9616427B16427B16427B16427B0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D2B83992B83992B83992B83990F748F0F748F0F748F0F748F196493196493196493
196493155883155883155883155883155883155883155883155883286091286091286091
286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D155883155883
155883155883115B8F115B8F115B8F115B8F05538A05538A05538A05538A2A729D2A729D
2A729D2A729D2A729D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A196493
19649319649319649311649511649511649511649515588315588315588315588311648D
11648D11648D11648D11648D19649319649319649319649319588F19588F19588F19588F
1964931964931964931964932D54802D54802D54802D548040779A40779A40779A40779A
11528F11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93
276F9316427B16427B16427B16427B2A729D2A729D2A729D2A729D16427B16427B16427B
16427B05538A05538A05538A05538A05538A0445820445820445820445825B90A55B90A5
5B90A55B90A52B83992B83992B83992B8399155883155883155883155883115B8F115B8F
115B8F115B8F08648D08648D08648D08648D08648D40779A40779A40779A40779A16427B
16427B16427B16427B095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D
11648D11648D11648D095B8D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B16427B16427B16427B16427B196493196493196493196493
1558831558831558831558830F748F0F748F0F748F0F748F0F748F5B90A55B90A55B90A5
5B90A5196493196493196493196493276F93276F93276F93276F93438CA2438CA2438CA2
438CA2095B8D095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000019588F196493196493196493
1964932D54802D54802D54802D54802D548040779A40779A40779A40779A11528F11528F
11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93276F9316427B16427B
16427B16427B2A729D2A729D2A729D2A729D2A729D16427B16427B16427B16427B05538A
05538A05538A05538A0445820445820445820445825B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399155883155883155883155883155883115B8F115B8F115B8F115B8F
08648D08648D08648D08648D40779A40779A40779A40779A16427B16427B16427B16427B
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E8711648D11648D11648D
11648D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B16427B16427B16427B16427B196493196493196493196493196493155883155883
1558831558830F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5196493196493
196493196493276F93276F93276F93276F93438CA2438CA2438CA2438CA2438CA2095B8D
095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
11528F11528F11528F11528F005B8D005B8D005B8D005B8D438CA2438CA2438CA2438CA2
116C96116C96116C96116C9616427B16427B16427B16427B0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D2B83992B83992B83992B83990F748F0F748F0F748F0F748F196493196493196493
196493155883155883155883155883155883155883155883155883286091286091286091
286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D155883155883
155883155883115B8F115B8F115B8F115B8F05538A05538A05538A05538A2A729D2A729D
2A729D2A729D2A729D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A196493
19649319649319649311649511649511649511649515588315588315588315588311648D
11648D11648D11648D11648D19649319649319649319649319588F19588F19588F19588F
1964931964931964931964932D54802D54802D54802D548040779A40779A40779A40779A
11528F11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93
276F9316427B16427B16427B16427B2A729D2A729D2A729D2A729D16427B16427B16427B
16427B05538A05538A05538A05538A05538A0445820445820445820445825B90A55B90A5
5B90A55B90A52B83992B83992B83992B8399155883155883155883155883115B8F115B8F
115B8F115B8F08648D08648D08648D08648D08648D40779A40779A40779A40779A16427B
16427B16427B16427B095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D
11648D11648D11648D095B8D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B16427B16427B16427B16427B196493196493196493196493
1558831558831558831558830F748F0F748F0F748F0F748F0F748F5B90A55B90A55B90A5
5B90A5196493196493196493196493276F93276F93276F93276F93438CA2438CA2438CA2
438CA2095B8D095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000019588F19588F19588F19588F196493196493196493
1964932D54802D54802D54802D54802D548040779A40779A40779A40779A11528F11528F
11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93276F9316427B16427B
16427B16427B2A729D2A729D2A729D2A729D2A729D16427B16427B16427B16427B05538A
05538A05538A05538A0445820445820445820445825B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399155883155883155883155883155883115B8F115B8F115B8F115B8F
08648D08648D08648D08648D40779A40779A40779A40779A16427B16427B16427B16427B
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E8711648D11648D11648D
11648D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B16427B16427B16427B16427B196493196493196493196493196493155883155883
1558831558830F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5196493196493
196493196493276F93276F93276F93276F93438CA2438CA2438CA2438CA2438CA2095B8D
095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
11528F11528F11528F11528F005B8D005B8D005B8D005B8D438CA2438CA2438CA2438CA2
116C96116C96116C96116C9616427B16427B16427B16427B0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D2B83992B83992B83992B83990F748F0F748F0F748F0F748F196493196493196493
196493155883155883155883155883155883155883155883155883286091286091286091
286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D155883155883
155883155883115B8F115B8F115B8F115B8F05538A05538A05538A05538A2A729D2A729D
2A729D2A729D2A729D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A196493
19649319649319649311649511649511649511649515588315588315588315588311648D
11648D11648D11648D11648D19649319649319649319649319588F19588F19588F19588F
1964931964931964931964932D54802D54802D54802D548040779A40779A40779A40779A
11528F11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93
276F9316427B16427B16427B16427B2A729D2A729D2A729D2A729D16427B16427B16427B
16427B05538A05538A05538A05538A05538A0445820445820445820445825B90A55B90A5
5B90A55B90A52B83992B83992B83992B8399155883155883155883155883115B8F115B8F
115B8F115B8F08648D08648D08648D08648D08648D40779A40779A40779A40779A16427B
16427B16427B16427B095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D
11648D11648D11648D095B8D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B16427B16427B16427B16427B196493196493196493196493
1558831558831558831558830F748F0F748F0F748F0F748F0F748F5B90A55B90A55B90A5
5B90A5196493196493196493196493276F93276F93276F93276F93438CA2438CA2438CA2
438CA2095B8D095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000019649319649319649319588F19588F19588F19588F196493196493196493
1964932D54802D54802D54802D54802D548040779A40779A40779A40779A11528F11528F
11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93276F9316427B16427B
16427B16427B2A729D2A729D2A729D2A729D2A729D16427B16427B16427B16427B05538A
05538A05538A05538A0445820445820445820445825B90A55B90A55B90A55B90A52B8399
2B83992B83992B8399155883155883155883155883155883115B8F115B8F115B8F115B8F
08648D08648D08648D08648D40779A40779A40779A40779A16427B16427B16427B16427B
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E8711648D11648D11648D
11648D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B16427B16427B16427B16427B196493196493196493196493196493155883155883
1558831558830F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5196493196493
196493196493276F93276F93276F93276F93438CA2438CA2438CA2438CA2438CA2095B8D
095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B83992B8399196493
1964931964931964932D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
11528F11528F11528F11528F005B8D005B8D005B8D005B8D438CA2438CA2438CA2438CA2
116C96116C96116C96116C9616427B16427B16427B16427B0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D2B83992B83992B83992B83990F748F0F748F0F748F0F748F196493196493196493
196493155883155883155883155883155883155883155883155883286091286091286091
286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D155883155883
155883155883115B8F115B8F115B8F115B8F05538A05538A05538A05538A2A729D2A729D
2A729D2A729D2A729D11648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A196493
19649319649319649311649511649511649511649515588315588315588315588311648D
11648D11648D11648D11648D19649319649319649319649319588F19588F19588F19588F
1964931964931964931964932D54802D54802D54802D548040779A40779A40779A40779A
11528F11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93276F93276F93
276F9316427B16427B16427B16427B2A729D2A729D2A729D2A729D16427B16427B16427B
16427B05538A05538A05538A05538A05538A0445820445820445820445825B90A55B90A5
5B90A55B90A52B83992B83992B83992B8399155883155883155883155883115B8F115B8F
115B8F115B8F08648D08648D08648D08648D08648D40779A40779A40779A40779A16427B
16427B16427B16427B095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D
11648D11648D11648D095B8D095B8D095B8D095B8D095B8D2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B16427B16427B16427B16427B196493196493196493196493
1558831558831558831558830F748F0F748F0F748F0F748F0F748F5B90A55B90A55B90A5
5B90A5196493196493196493196493276F93276F93276F93276F93438CA2438CA2438CA2
438CA2095B8D095B8D095B8D095B8D2B83992B83992B83992B83992B83992B83992B8399
2B83992B83991964931964931964931964932D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000046483
046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D2D54802D54802D5480
2D54802860912860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A19588F19588F
19588F19588F196493196493196493196493276F93276F93276F93276F93276F93276F93
276F93276F93116C96116C96116C96116C96116C96095B8D095B8D095B8D095B8D286091
2860912860912860912D54802D54802D54802D5480116495116495116495116495115B8F
115B8F115B8F115B8F438CA2438CA2438CA2438CA2438CA2095B8D095B8D095B8D095B8D
15588315588315588315588311648D11648D11648D11648D2A729D2A729D2A729D2A729D
11528F11528F11528F11528F276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588316427B16427B16427B16427B116495116495116495
1164952D54802D54802D54802D54802D54802D54802D54802D54802D5480155883155883
15588315588340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A05538A05538A276F93
276F93276F93276F930C8E870C8E870C8E870C8E87115B8F115B8F115B8F115B8F2A729D
2A729D2A729D2A729D438CA2438CA2438CA2438CA22A2F6C2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B05538A05538A05538A05538A0C8E870C8E870C8E870C8E87
1164951164951164951164951964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F1558831558831558831558832B83992B83992B8399
2B839940779A40779A40779A40779A438CA2438CA2438CA2438CA211648D11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2D54802D54802D54802D548084A8B284A8B2
84A8B284A8B2116495116495116495116495276F93276F93276F93276F93286091286091
286091286091286091276F93276F93276F93276F932D54802D54802D54802D548011648D
11648D11648D11648D2D54802D54802D54802D54802B83992B83992B83992B8399046483
046483046483046483046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D
2D54802D54802D54802D54802860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A
19588F19588F19588F19588F19588F196493196493196493196493276F93276F93276F93
276F93276F93276F93276F93276F93116C96116C96116C96116C96095B8D095B8D095B8D
095B8D2860912860912860912860912860912D54802D54802D54802D5480116495116495
116495116495115B8F115B8F115B8F115B8F438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D15588315588315588315588315588311648D11648D11648D11648D2A729D
2A729D2A729D2A729D11528F11528F11528F11528F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F15588315588315588315588315588316427B16427B16427B16427B
1164951164951164951164952D54802D54802D54802D54802D54802D54802D54802D5480
15588315588315588315588340779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A
0C6C8A16427B16427B16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E870C8E87115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D438CA2000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000046483046483046483
046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D2D54802D54802D5480
2D54802860912860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A19588F19588F
19588F19588F196493196493196493196493276F93276F93276F93276F93276F93276F93
276F93276F93116C96116C96116C96116C96116C96095B8D095B8D095B8D095B8D286091
2860912860912860912D54802D54802D54802D5480116495116495116495116495115B8F
115B8F115B8F115B8F438CA2438CA2438CA2438CA2438CA2095B8D095B8D095B8D095B8D
15588315588315588315588311648D11648D11648D11648D2A729D2A729D2A729D2A729D
11528F11528F11528F11528F276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588316427B16427B16427B16427B116495116495116495
1164952D54802D54802D54802D54802D54802D54802D54802D54802D5480155883155883
15588315588340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A05538A05538A276F93
276F93276F93276F930C8E870C8E870C8E870C8E87115B8F115B8F115B8F115B8F2A729D
2A729D2A729D2A729D438CA2438CA2438CA2438CA22A2F6C2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B05538A05538A05538A05538A0C8E870C8E870C8E870C8E87
1164951164951164951164951964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F1558831558831558831558832B83992B83992B8399
2B839940779A40779A40779A40779A438CA2438CA2438CA2438CA211648D11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2D54802D54802D54802D548084A8B284A8B2
84A8B284A8B2116495116495116495116495276F93276F93276F93276F93286091286091
286091286091286091276F93276F93276F93276F932D54802D54802D54802D548011648D
11648D11648D11648D2D54802D54802D54802D54802B83992B83992B83992B8399046483
046483046483046483046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D
2D54802D54802D54802D54802860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A
19588F19588F19588F19588F19588F196493196493196493196493276F93276F93276F93
276F93276F93276F93276F93276F93116C96116C96116C96116C96095B8D095B8D095B8D
095B8D2860912860912860912860912860912D54802D54802D54802D5480116495116495
116495116495115B8F115B8F115B8F115B8F438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D15588315588315588315588315588311648D11648D11648D11648D2A729D
2A729D2A729D2A729D11528F11528F11528F11528F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F15588315588315588315588315588316427B16427B16427B16427B
1164951164951164951164952D54802D54802D54802D54802D54802D54802D54802D5480
15588315588315588315588340779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A
0C6C8A16427B16427B16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E870C8E87115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D438CA2000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002B83992B83992B8399046483046483046483
046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D2D54802D54802D5480
2D54802860912860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A19588F19588F
19588F19588F196493196493196493196493276F93276F93276F93276F93276F93276F93
276F93276F93116C96116C96116C96116C96116C96095B8D095B8D095B8D095B8D286091
2860912860912860912D54802D54802D54802D5480116495116495116495116495115B8F
115B8F115B8F115B8F438CA2438CA2438CA2438CA2438CA2095B8D095B8D095B8D095B8D
15588315588315588315588311648D11648D11648D11648D2A729D2A729D2A729D2A729D
11528F11528F11528F11528F276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588316427B16427B16427B16427B116495116495116495
1164952D54802D54802D54802D54802D54802D54802D54802D54802D5480155883155883
15588315588340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A05538A05538A276F93
276F93276F93276F930C8E870C8E870C8E870C8E87115B8F115B8F115B8F115B8F2A729D
2A729D2A729D2A729D438CA2438CA2438CA2438CA22A2F6C2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B05538A05538A05538A05538A0C8E870C8E870C8E870C8E87
1164951164951164951164951964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F1558831558831558831558832B83992B83992B8399
2B839940779A40779A40779A40779A438CA2438CA2438CA2438CA211648D11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2D54802D54802D54802D548084A8B284A8B2
84A8B284A8B2116495116495116495116495276F93276F93276F93276F93286091286091
286091286091286091276F93276F93276F93276F932D54802D54802D54802D548011648D
11648D11648D11648D2D54802D54802D54802D54802B83992B83992B83992B8399046483
046483046483046483046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D
2D54802D54802D54802D54802860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A
19588F19588F19588F19588F19588F196493196493196493196493276F93276F93276F93
276F93276F93276F93276F93276F93116C96116C96116C96116C96095B8D095B8D095B8D
095B8D2860912860912860912860912860912D54802D54802D54802D5480116495116495
116495116495115B8F115B8F115B8F115B8F438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D15588315588315588315588315588311648D11648D11648D11648D2A729D
2A729D2A729D2A729D11528F11528F11528F11528F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F15588315588315588315588315588316427B16427B16427B16427B
1164951164951164951164952D54802D54802D54802D54802D54802D54802D54802D5480
15588315588315588315588340779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A
0C6C8A16427B16427B16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E870C8E87115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D438CA2000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002D54802D54802B83992B83992B83992B8399046483046483046483
046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D2D54802D54802D5480
2D54802860912860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A19588F19588F
19588F19588F196493196493196493196493276F93276F93276F93276F93276F93276F93
276F93276F93116C96116C96116C96116C96116C96095B8D095B8D095B8D095B8D286091
2860912860912860912D54802D54802D54802D5480116495116495116495116495115B8F
115B8F115B8F115B8F438CA2438CA2438CA2438CA2438CA2095B8D095B8D095B8D095B8D
15588315588315588315588311648D11648D11648D11648D2A729D2A729D2A729D2A729D
11528F11528F11528F11528F276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588316427B16427B16427B16427B116495116495116495
1164952D54802D54802D54802D54802D54802D54802D54802D54802D5480155883155883
15588315588340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A05538A05538A276F93
276F93276F93276F930C8E870C8E870C8E870C8E87115B8F115B8F115B8F115B8F2A729D
2A729D2A729D2A729D438CA2438CA2438CA2438CA22A2F6C2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B05538A05538A05538A05538A0C8E870C8E870C8E870C8E87
1164951164951164951164951964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F1558831558831558831558832B83992B83992B8399
2B839940779A40779A40779A40779A438CA2438CA2438CA2438CA211648D11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2D54802D54802D54802D548084A8B284A8B2
84A8B284A8B2116495116495116495116495276F93276F93276F93276F93286091286091
286091286091286091276F93276F93276F93276F932D54802D54802D54802D548011648D
11648D11648D11648D2D54802D54802D54802D54802B83992B83992B83992B8399046483
046483046483046483046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D
2D54802D54802D54802D54802860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A
19588F19588F19588F19588F19588F196493196493196493196493276F93276F93276F93
276F93276F93276F93276F93276F93116C96116C96116C96116C96095B8D095B8D095B8D
095B8D2860912860912860912860912860912D54802D54802D54802D5480116495116495
116495116495115B8F115B8F115B8F115B8F438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D15588315588315588315588315588311648D11648D11648D11648D2A729D
2A729D2A729D2A729D11528F11528F11528F11528F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F15588315588315588315588315588316427B16427B16427B16427B
1164951164951164951164952D54802D54802D54802D54802D54802D54802D54802D5480
15588315588315588315588340779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A
0C6C8A16427B16427B16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E870C8E87115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D438CA2000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
2D54802D54802D54802D54802D54802B83992B83992B83992B8399046483046483046483
046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D2D54802D54802D5480
2D54802860912860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A19588F19588F
19588F19588F196493196493196493196493276F93276F93276F93276F93276F93276F93
276F93276F93116C96116C96116C96116C96116C96095B8D095B8D095B8D095B8D286091
2860912860912860912D54802D54802D54802D5480116495116495116495116495115B8F
115B8F115B8F115B8F438CA2438CA2438CA2438CA2438CA2095B8D095B8D095B8D095B8D
15588315588315588315588311648D11648D11648D11648D2A729D2A729D2A729D2A729D
11528F11528F11528F11528F276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588316427B16427B16427B16427B116495116495116495
1164952D54802D54802D54802D54802D54802D54802D54802D54802D5480155883155883
15588315588340779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A05538A05538A276F93
276F93276F93276F930C8E870C8E870C8E870C8E87115B8F115B8F115B8F115B8F2A729D
2A729D2A729D2A729D438CA2438CA2438CA2438CA22A2F6C2A2F6C2A2F6C2A2F6C2A2F6C
16427B16427B16427B16427B05538A05538A05538A05538A0C8E870C8E870C8E870C8E87
1164951164951164951164951964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A115B8F115B8F115B8F115B8F1558831558831558831558832B83992B83992B8399
2B839940779A40779A40779A40779A438CA2438CA2438CA2438CA211648D11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2D54802D54802D54802D548084A8B284A8B2
84A8B284A8B2116495116495116495116495276F93276F93276F93276F93286091286091
286091286091286091276F93276F93276F93276F932D54802D54802D54802D548011648D
11648D11648D11648D2D54802D54802D54802D54802B83992B83992B83992B8399046483
046483046483046483046483095B8D095B8D095B8D095B8D11648D11648D11648D11648D
2D54802D54802D54802D54802860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A
19588F19588F19588F19588F19588F196493196493196493196493276F93276F93276F93
276F93276F93276F93276F93276F93116C96116C96116C96116C96095B8D095B8D095B8D
095B8D2860912860912860912860912860912D54802D54802D54802D5480116495116495
116495116495115B8F115B8F115B8F115B8F438CA2438CA2438CA2438CA2095B8D095B8D
095B8D095B8D15588315588315588315588315588311648D11648D11648D11648D2A729D
2A729D2A729D2A729D11528F11528F11528F11528F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F15588315588315588315588315588316427B16427B16427B16427B
1164951164951164951164952D54802D54802D54802D54802D54802D54802D54802D5480
15588315588315588315588340779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A
0C6C8A16427B16427B16427B16427B115B8F115B8F115B8F115B8F05538A05538A05538A
05538A276F93276F93276F93276F930C8E870C8E870C8E870C8E870C8E87115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D438CA2000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000276F93276F93276F93
15588315588315588315588315588305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A155883155883155883
155883115B8F115B8F115B8F115B8F115B8F046483046483046483046483115B8F115B8F
115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A16427B16427B16427B16427B16427B1964931964931964931964932D5480
2D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A516427B
16427B16427B16427B1164951164951164951164951164952A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A276F93276F93276F93276F9305538A05538A05538A05538A
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D5B90A55B90A55B90A5
5B90A52D54802D54802D54802D54800464830464830464830464832B83992B83992B8399
2B839928609128609128609128609116427B16427B16427B16427B16427B5B90A55B90A5
5B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B16427B438CA2438CA2
438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A729D
2A729D2A729D2A729D16427B16427B16427B16427B1558831558831558831558830C6C8A
0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399116C96116C96116C96116C96116C96
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A2B83992B83992B83992B8399
116495116495116495116495276F93276F93276F93276F9316427B16427B16427B16427B
16427B276F93276F93276F93276F9311648D11648D11648D11648D286091286091286091
286091438CA2438CA2438CA2438CA20C8E870C8E870C8E870C8E8711528F11528F11528F
11528F11528F5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2
438CA2438CA2276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A155883155883
155883155883155883276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93
276F93276F93276F9315588315588315588315588305538A05538A05538A05538A0C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A
155883155883155883155883115B8F115B8F115B8F115B8F046483046483046483046483
115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B196493196493196493
1964932D54802D54802D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A516427B16427B16427B16427B1164951164951164951164952A2F6C2A2F6C
2A2F6C2A2F6C05538A05538A05538A05538A05538A276F93276F93276F93276F9305538A
05538A05538A05538A2B83992B83992B83992B8399005B8D005B8D005B8D005B8D5B90A5
5B90A55B90A55B90A52D54802D54802D54802D54802D5480046483046483046483046483
2B83992B83992B83992B839928609128609128609128609116427B16427B16427B16427B
5B90A55B90A55B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B438CA2438CA2438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C
2A2F6C2A729D2A729D2A729D2A729D16427B16427B16427B16427B16427B155883155883
1558831558830C6C8A0C6C8A0C6C8A0C6C8A2B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000005B8D005B8D276F93276F93276F93276F93
15588315588315588315588315588305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A155883155883155883
155883115B8F115B8F115B8F115B8F115B8F046483046483046483046483115B8F115B8F
115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A16427B16427B16427B16427B16427B1964931964931964931964932D5480
2D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A516427B
16427B16427B16427B1164951164951164951164951164952A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A276F93276F93276F93276F9305538A05538A05538A05538A
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D5B90A55B90A55B90A5
5B90A52D54802D54802D54802D54800464830464830464830464832B83992B83992B8399
2B839928609128609128609128609116427B16427B16427B16427B16427B5B90A55B90A5
5B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B16427B438CA2438CA2
438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A729D
2A729D2A729D2A729D16427B16427B16427B16427B1558831558831558831558830C6C8A
0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399116C96116C96116C96116C96116C96
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A2B83992B83992B83992B8399
116495116495116495116495276F93276F93276F93276F9316427B16427B16427B16427B
16427B276F93276F93276F93276F9311648D11648D11648D11648D286091286091286091
286091438CA2438CA2438CA2438CA20C8E870C8E870C8E870C8E8711528F11528F11528F
11528F11528F5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2
438CA2438CA2276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A155883155883
155883155883155883276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93
276F93276F93276F9315588315588315588315588305538A05538A05538A05538A0C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A
155883155883155883155883115B8F115B8F115B8F115B8F046483046483046483046483
115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B196493196493196493
1964932D54802D54802D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A516427B16427B16427B16427B1164951164951164951164952A2F6C2A2F6C
2A2F6C2A2F6C05538A05538A05538A05538A05538A276F93276F93276F93276F9305538A
05538A05538A05538A2B83992B83992B83992B8399005B8D005B8D005B8D005B8D5B90A5
5B90A55B90A55B90A52D54802D54802D54802D54802D5480046483046483046483046483
2B83992B83992B83992B839928609128609128609128609116427B16427B16427B16427B
5B90A55B90A55B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B438CA2438CA2438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C
2A2F6C2A729D2A729D2A729D2A729D16427B16427B16427B16427B16427B155883155883
1558831558830C6C8A0C6C8A0C6C8A0C6C8A2B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000276F93005B8D005B8D005B8D005B8D276F93276F93276F93276F93
15588315588315588315588315588305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A155883155883155883
155883115B8F115B8F115B8F115B8F115B8F046483046483046483046483115B8F115B8F
115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A16427B16427B16427B16427B16427B1964931964931964931964932D5480
2D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A516427B
16427B16427B16427B1164951164951164951164951164952A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A276F93276F93276F93276F9305538A05538A05538A05538A
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D5B90A55B90A55B90A5
5B90A52D54802D54802D54802D54800464830464830464830464832B83992B83992B8399
2B839928609128609128609128609116427B16427B16427B16427B16427B5B90A55B90A5
5B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B16427B438CA2438CA2
438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A729D
2A729D2A729D2A729D16427B16427B16427B16427B1558831558831558831558830C6C8A
0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399116C96116C96116C96116C96116C96
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A2B83992B83992B83992B8399
116495116495116495116495276F93276F93276F93276F9316427B16427B16427B16427B
16427B276F93276F93276F93276F9311648D11648D11648D11648D286091286091286091
286091438CA2438CA2438CA2438CA20C8E870C8E870C8E870C8E8711528F11528F11528F
11528F11528F5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2
438CA2438CA2276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A155883155883
155883155883155883276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93
276F93276F93276F9315588315588315588315588305538A05538A05538A05538A0C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A
155883155883155883155883115B8F115B8F115B8F115B8F046483046483046483046483
115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B196493196493196493
1964932D54802D54802D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A516427B16427B16427B16427B1164951164951164951164952A2F6C2A2F6C
2A2F6C2A2F6C05538A05538A05538A05538A05538A276F93276F93276F93276F9305538A
05538A05538A05538A2B83992B83992B83992B8399005B8D005B8D005B8D005B8D5B90A5
5B90A55B90A55B90A52D54802D54802D54802D54802D5480046483046483046483046483
2B83992B83992B83992B839928609128609128609128609116427B16427B16427B16427B
5B90A55B90A55B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B438CA2438CA2438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C
2A2F6C2A729D2A729D2A729D2A729D16427B16427B16427B16427B16427B155883155883
1558831558830C6C8A0C6C8A0C6C8A0C6C8A2B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93276F93276F93276F93
15588315588315588315588315588305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A
0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A155883155883155883
155883115B8F115B8F115B8F115B8F115B8F046483046483046483046483115B8F115B8F
115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A16427B16427B16427B16427B16427B1964931964931964931964932D5480
2D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A516427B
16427B16427B16427B1164951164951164951164951164952A2F6C2A2F6C2A2F6C2A2F6C
05538A05538A05538A05538A276F93276F93276F93276F9305538A05538A05538A05538A
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D5B90A55B90A55B90A5
5B90A52D54802D54802D54802D54800464830464830464830464832B83992B83992B8399
2B839928609128609128609128609116427B16427B16427B16427B16427B5B90A55B90A5
5B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B16427B438CA2438CA2
438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C2A2F6C2A2F6C2A729D
2A729D2A729D2A729D16427B16427B16427B16427B1558831558831558831558830C6C8A
0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399116C96116C96116C96116C96116C96
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A2B83992B83992B83992B8399
116495116495116495116495276F93276F93276F93276F9316427B16427B16427B16427B
16427B276F93276F93276F93276F9311648D11648D11648D11648D286091286091286091
286091438CA2438CA2438CA2438CA20C8E870C8E870C8E870C8E8711528F11528F11528F
11528F11528F5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D438CA2438CA2
438CA2438CA2276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A155883155883
155883155883155883276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93
276F93276F93276F9315588315588315588315588305538A05538A05538A05538A0C6C8A
0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B839940779A40779A40779A40779A
155883155883155883155883115B8F115B8F115B8F115B8F046483046483046483046483
115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D0C6C8A0C6C8A0C6C8A0C6C8A16427B16427B16427B16427B196493196493196493
1964932D54802D54802D54802D54802D54800F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A516427B16427B16427B16427B1164951164951164951164952A2F6C2A2F6C
2A2F6C2A2F6C05538A05538A05538A05538A05538A276F93276F93276F93276F9305538A
05538A05538A05538A2B83992B83992B83992B8399005B8D005B8D005B8D005B8D5B90A5
5B90A55B90A55B90A52D54802D54802D54802D54802D5480046483046483046483046483
2B83992B83992B83992B839928609128609128609128609116427B16427B16427B16427B
5B90A55B90A55B90A55B90A52A2F6C2A2F6C2A2F6C2A2F6C2A2F6C16427B16427B16427B
16427B438CA2438CA2438CA2438CA21558831558831558831558832A2F6C2A2F6C2A2F6C
2A2F6C2A729D2A729D2A729D2A729D16427B16427B16427B16427B16427B155883155883
1558831558830C6C8A0C6C8A0C6C8A0C6C8A2B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000286091286091286091286091
40779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A0C6C8A0C6C8A0C6C8A
1558831558831558831558831558831964931964931964931964932B83992B83992B8399
2B8399085B95085B95085B95085B9515588315588315588315588340779A40779A40779A
40779A2B83992B83992B83992B83992B839905538A05538A05538A05538A19588F19588F
19588F19588F116C96116C96116C96116C9605538A05538A05538A05538A286091286091
28609128609128609128609128609128609128609116427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B1558831558831558831558832B8399
2B83992B83992B83991964931964931964931964931964935B90A55B90A55B90A55B90A5
11528F11528F11528F11528F076495076495076495076495005B8D005B8D005B8D005B8D
19588F19588F19588F19588F2D54802D54802D54802D54802D5480116495116495116495
116495116C96116C96116C96116C96276F93276F93276F93276F932A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F15588315588315588315588315588311648D11648D
11648D11648D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B8399
2B83992B839911528F11528F11528F11528F116C96116C96116C96116C96116C9605538A
05538A05538A05538A16427B16427B16427B16427B276F93276F93276F93276F9340779A
40779A40779A40779A0764950764950764950764955B90A55B90A55B90A55B90A55B90A5
19588F19588F19588F19588F04458204458204458204458216427B16427B16427B16427B
11528F11528F11528F11528F116495116495116495116495286091286091286091286091
2860911164951164951164951164952B83992B83992B83992B839911648D11648D11648D
11648D438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C
2A2F6C2A2F6C095B8D095B8D095B8D095B8D155883155883155883155883276F93276F93
276F93276F93276F93276F93276F93276F93116495116495116495116495286091286091
28609128609128609140779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A
0C6C8A0C6C8A0C6C8A1558831558831558831558831964931964931964931964932B8399
2B83992B83992B83992B8399085B95085B95085B95085B95155883155883155883155883
40779A40779A40779A40779A2B83992B83992B83992B839905538A05538A05538A05538A
19588F19588F19588F19588F19588F116C96116C96116C96116C9605538A05538A05538A
05538A28609128609128609128609128609128609128609128609116427B16427B16427B
16427B276F93276F93276F93276F93276F9316427B16427B16427B16427B155883155883
1558831558832B83992B83992B83992B83991964931964931964931964935B90A55B90A5
5B90A55B90A511528F11528F11528F11528F11528F076495076495076495076495005B8D
005B8D005B8D005B8D19588F19588F19588F19588F2D54802D54802D54802D5480116495
116495116495116495116C96116C96116C96116C96116C96276F93276F93276F93276F93
2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F19588F19588F155883155883155883155883
11648D11648D11648D11648D0F748F0F748F0F748F0F748F0F748F05538A05538A05538A
05538A2B83992B83992B83992B839911528F11528F11528F11528F116C96116C96116C96
116C9605538A05538A05538A05538A16427B16427B16427B16427B16427B276F93276F93
276F93276F9340779A40779A40779A40779A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000116495116495116495286091286091286091286091
40779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A0C6C8A0C6C8A0C6C8A
1558831558831558831558831558831964931964931964931964932B83992B83992B8399
2B8399085B95085B95085B95085B9515588315588315588315588340779A40779A40779A
40779A2B83992B83992B83992B83992B839905538A05538A05538A05538A19588F19588F
19588F19588F116C96116C96116C96116C9605538A05538A05538A05538A286091286091
28609128609128609128609128609128609128609116427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B1558831558831558831558832B8399
2B83992B83992B83991964931964931964931964931964935B90A55B90A55B90A55B90A5
11528F11528F11528F11528F076495076495076495076495005B8D005B8D005B8D005B8D
19588F19588F19588F19588F2D54802D54802D54802D54802D5480116495116495116495
116495116C96116C96116C96116C96276F93276F93276F93276F932A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F15588315588315588315588315588311648D11648D
11648D11648D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B8399
2B83992B839911528F11528F11528F11528F116C96116C96116C96116C96116C9605538A
05538A05538A05538A16427B16427B16427B16427B276F93276F93276F93276F9340779A
40779A40779A40779A0764950764950764950764955B90A55B90A55B90A55B90A55B90A5
19588F19588F19588F19588F04458204458204458204458216427B16427B16427B16427B
11528F11528F11528F11528F116495116495116495116495286091286091286091286091
2860911164951164951164951164952B83992B83992B83992B839911648D11648D11648D
11648D438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C
2A2F6C2A2F6C095B8D095B8D095B8D095B8D155883155883155883155883276F93276F93
276F93276F93276F93276F93276F93276F93116495116495116495116495286091286091
28609128609128609140779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A
0C6C8A0C6C8A0C6C8A1558831558831558831558831964931964931964931964932B8399
2B83992B83992B83992B8399085B95085B95085B95085B95155883155883155883155883
40779A40779A40779A40779A2B83992B83992B83992B839905538A05538A05538A05538A
19588F19588F19588F19588F19588F116C96116C96116C96116C9605538A05538A05538A
05538A28609128609128609128609128609128609128609128609116427B16427B16427B
16427B276F93276F93276F93276F93276F9316427B16427B16427B16427B155883155883
1558831558832B83992B83992B83992B83991964931964931964931964935B90A55B90A5
5B90A55B90A511528F11528F11528F11528F11528F076495076495076495076495005B8D
005B8D005B8D005B8D19588F19588F19588F19588F2D54802D54802D54802D5480116495
116495116495116495116C96116C96116C96116C96116C96276F93276F93276F93276F93
2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F19588F19588F155883155883155883155883
11648D11648D11648D11648D0F748F0F748F0F748F0F748F0F748F05538A05538A05538A
05538A2B83992B83992B83992B839911528F11528F11528F11528F116C96116C96116C96
116C9605538A05538A05538A05538A16427B16427B16427B16427B16427B276F93276F93
276F93276F9340779A40779A40779A40779A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000276F93276F93276F93116495116495116495116495286091286091286091286091
40779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A0C6C8A0C6C8A0C6C8A
1558831558831558831558831558831964931964931964931964932B83992B83992B8399
2B8399085B95085B95085B95085B9515588315588315588315588340779A40779A40779A
40779A2B83992B83992B83992B83992B839905538A05538A05538A05538A19588F19588F
19588F19588F116C96116C96116C96116C9605538A05538A05538A05538A286091286091
28609128609128609128609128609128609128609116427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B1558831558831558831558832B8399
2B83992B83992B83991964931964931964931964931964935B90A55B90A55B90A55B90A5
11528F11528F11528F11528F076495076495076495076495005B8D005B8D005B8D005B8D
19588F19588F19588F19588F2D54802D54802D54802D54802D5480116495116495116495
116495116C96116C96116C96116C96276F93276F93276F93276F932A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F15588315588315588315588315588311648D11648D
11648D11648D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B8399
2B83992B839911528F11528F11528F11528F116C96116C96116C96116C96116C9605538A
05538A05538A05538A16427B16427B16427B16427B276F93276F93276F93276F9340779A
40779A40779A40779A0764950764950764950764955B90A55B90A55B90A55B90A55B90A5
19588F19588F19588F19588F04458204458204458204458216427B16427B16427B16427B
11528F11528F11528F11528F116495116495116495116495286091286091286091286091
2860911164951164951164951164952B83992B83992B83992B839911648D11648D11648D
11648D438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C
2A2F6C2A2F6C095B8D095B8D095B8D095B8D155883155883155883155883276F93276F93
276F93276F93276F93276F93276F93276F93116495116495116495116495286091286091
28609128609128609140779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A
0C6C8A0C6C8A0C6C8A1558831558831558831558831964931964931964931964932B8399
2B83992B83992B83992B8399085B95085B95085B95085B95155883155883155883155883
40779A40779A40779A40779A2B83992B83992B83992B839905538A05538A05538A05538A
19588F19588F19588F19588F19588F116C96116C96116C96116C9605538A05538A05538A
05538A28609128609128609128609128609128609128609128609116427B16427B16427B
16427B276F93276F93276F93276F93276F9316427B16427B16427B16427B155883155883
1558831558832B83992B83992B83992B83991964931964931964931964935B90A55B90A5
5B90A55B90A511528F11528F11528F11528F11528F076495076495076495076495005B8D
005B8D005B8D005B8D19588F19588F19588F19588F2D54802D54802D54802D5480116495
116495116495116495116C96116C96116C96116C96116C96276F93276F93276F93276F93
2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F19588F19588F155883155883155883155883
11648D11648D11648D11648D0F748F0F748F0F748F0F748F0F748F05538A05538A05538A
05538A2B83992B83992B83992B839911528F11528F11528F11528F116C96116C96116C96
116C9605538A05538A05538A05538A16427B16427B16427B16427B16427B276F93276F93
276F93276F9340779A40779A40779A40779A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000276F93276F93
276F93276F93276F93276F93116495116495116495116495286091286091286091286091
40779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A0C6C8A0C6C8A0C6C8A
1558831558831558831558831558831964931964931964931964932B83992B83992B8399
2B8399085B95085B95085B95085B9515588315588315588315588340779A40779A40779A
40779A2B83992B83992B83992B83992B839905538A05538A05538A05538A19588F19588F
19588F19588F116C96116C96116C96116C9605538A05538A05538A05538A286091286091
28609128609128609128609128609128609128609116427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B1558831558831558831558832B8399
2B83992B83992B83991964931964931964931964931964935B90A55B90A55B90A55B90A5
11528F11528F11528F11528F076495076495076495076495005B8D005B8D005B8D005B8D
19588F19588F19588F19588F2D54802D54802D54802D54802D5480116495116495116495
116495116C96116C96116C96116C96276F93276F93276F93276F932A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F15588315588315588315588315588311648D11648D
11648D11648D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B8399
2B83992B839911528F11528F11528F11528F116C96116C96116C96116C96116C9605538A
05538A05538A05538A16427B16427B16427B16427B276F93276F93276F93276F9340779A
40779A40779A40779A0764950764950764950764955B90A55B90A55B90A55B90A55B90A5
19588F19588F19588F19588F04458204458204458204458216427B16427B16427B16427B
11528F11528F11528F11528F116495116495116495116495286091286091286091286091
2860911164951164951164951164952B83992B83992B83992B839911648D11648D11648D
11648D438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C
2A2F6C2A2F6C095B8D095B8D095B8D095B8D155883155883155883155883276F93276F93
276F93276F93276F93276F93276F93276F93116495116495116495116495286091286091
28609128609128609140779A40779A40779A40779A0F748F0F748F0F748F0F748F0C6C8A
0C6C8A0C6C8A0C6C8A1558831558831558831558831964931964931964931964932B8399
2B83992B83992B83992B8399085B95085B95085B95085B95155883155883155883155883
40779A40779A40779A40779A2B83992B83992B83992B839905538A05538A05538A05538A
19588F19588F19588F19588F19588F116C96116C96116C96116C9605538A05538A05538A
05538A28609128609128609128609128609128609128609128609116427B16427B16427B
16427B276F93276F93276F93276F93276F9316427B16427B16427B16427B155883155883
1558831558832B83992B83992B83992B83991964931964931964931964935B90A55B90A5
5B90A55B90A511528F11528F11528F11528F11528F076495076495076495076495005B8D
005B8D005B8D005B8D19588F19588F19588F19588F2D54802D54802D54802D5480116495
116495116495116495116C96116C96116C96116C96116C96276F93276F93276F93276F93
2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F19588F19588F155883155883155883155883
11648D11648D11648D11648D0F748F0F748F0F748F0F748F0F748F05538A05538A05538A
05538A2B83992B83992B83992B839911528F11528F11528F11528F116C96116C96116C96
116C9605538A05538A05538A05538A16427B16427B16427B16427B16427B276F93276F93
276F93276F9340779A40779A40779A40779A076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000016427B095B8D095B8D095B8D095B8D276F93
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
11528F11528F11528F11528F095B8D095B8D095B8D095B8D2D54802D54802D54802D5480
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D005B8D005B8D
005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883095B8D095B8D095B8D
095B8D276F93276F93276F93276F93276F9311528F11528F11528F11528F286091286091
286091286091155883155883155883155883196493196493196493196493196493196493
196493196493045B84045B84045B84045B84045B8419588F19588F19588F19588F116495
1164951164951164955B90A55B90A55B90A55B90A5276F93276F93276F93276F930C6C8A
0C6C8A0C6C8A0C6C8A28609128609128609128609128609108648D08648D08648D08648D
155883155883155883155883116495116495116495116495276F93276F93276F93276F93
2A729D2A729D2A729D2A729D1558831558831558831558831558832B83992B83992B8399
2B83992D54802D54802D54802D5480095B8D095B8D095B8D095B8D40779A40779A40779A
40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93276F9311648D11648D
11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E87
0C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D045B84
045B84045B84045B8419588F19588F19588F19588F005B8D005B8D005B8D005B8D40779A
40779A40779A40779A286091286091286091286091438CA2438CA2438CA2438CA2438CA2
0C8E870C8E870C8E870C8E8711648D11648D11648D11648D19588F19588F19588F19588F
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A196493196493196493196493
1964930C8E870C8E870C8E870C8E872B83992B83992B83992B8399046483046483046483
046483045B84045B84045B84045B8440779A40779A40779A40779A155883155883155883
15588315588328609128609128609128609116427B16427B16427B16427B095B8D095B8D
095B8D095B8D276F93276F93276F93276F932B83992B83992B83992B8399155883155883
15588315588315588311528F11528F11528F11528F095B8D095B8D095B8D095B8D2D5480
2D54802D54802D5480438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D
005B8D005B8D005B8D005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
095B8D095B8D095B8D095B8D276F93276F93276F93276F9311528F11528F11528F11528F
286091286091286091286091286091155883155883155883155883196493196493196493
196493196493196493196493196493045B84045B84045B84045B8419588F19588F19588F
19588F1164951164951164951164951164955B90A55B90A55B90A55B90A5276F93276F93
276F93276F930C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609108648D08648D
08648D08648D155883155883155883155883155883116495116495116495116495276F93
276F93276F93276F932A729D2A729D2A729D2A729D1558831558831558831558832B8399
2B83992B83992B83992D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D
40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93
11648D11648D11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D0C8E870C8E870C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D
005B8D045B84045B84045B84045B8419588F19588F19588F19588F19588F005B8D005B8D
005B8D005B8D40779A40779A40779A40779A286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000016427B16427B16427B16427B095B8D095B8D095B8D095B8D276F93
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
11528F11528F11528F11528F095B8D095B8D095B8D095B8D2D54802D54802D54802D5480
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D005B8D005B8D
005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883095B8D095B8D095B8D
095B8D276F93276F93276F93276F93276F9311528F11528F11528F11528F286091286091
286091286091155883155883155883155883196493196493196493196493196493196493
196493196493045B84045B84045B84045B84045B8419588F19588F19588F19588F116495
1164951164951164955B90A55B90A55B90A55B90A5276F93276F93276F93276F930C6C8A
0C6C8A0C6C8A0C6C8A28609128609128609128609128609108648D08648D08648D08648D
155883155883155883155883116495116495116495116495276F93276F93276F93276F93
2A729D2A729D2A729D2A729D1558831558831558831558831558832B83992B83992B8399
2B83992D54802D54802D54802D5480095B8D095B8D095B8D095B8D40779A40779A40779A
40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93276F9311648D11648D
11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E87
0C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D045B84
045B84045B84045B8419588F19588F19588F19588F005B8D005B8D005B8D005B8D40779A
40779A40779A40779A286091286091286091286091438CA2438CA2438CA2438CA2438CA2
0C8E870C8E870C8E870C8E8711648D11648D11648D11648D19588F19588F19588F19588F
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A196493196493196493196493
1964930C8E870C8E870C8E870C8E872B83992B83992B83992B8399046483046483046483
046483045B84045B84045B84045B8440779A40779A40779A40779A155883155883155883
15588315588328609128609128609128609116427B16427B16427B16427B095B8D095B8D
095B8D095B8D276F93276F93276F93276F932B83992B83992B83992B8399155883155883
15588315588315588311528F11528F11528F11528F095B8D095B8D095B8D095B8D2D5480
2D54802D54802D5480438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D
005B8D005B8D005B8D005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
095B8D095B8D095B8D095B8D276F93276F93276F93276F9311528F11528F11528F11528F
286091286091286091286091286091155883155883155883155883196493196493196493
196493196493196493196493196493045B84045B84045B84045B8419588F19588F19588F
19588F1164951164951164951164951164955B90A55B90A55B90A55B90A5276F93276F93
276F93276F930C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609108648D08648D
08648D08648D155883155883155883155883155883116495116495116495116495276F93
276F93276F93276F932A729D2A729D2A729D2A729D1558831558831558831558832B8399
2B83992B83992B83992D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D
40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93
11648D11648D11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D0C8E870C8E870C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D
005B8D045B84045B84045B84045B8419588F19588F19588F19588F19588F005B8D005B8D
005B8D005B8D40779A40779A40779A40779A286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
28609128609128609116427B16427B16427B16427B095B8D095B8D095B8D095B8D276F93
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
11528F11528F11528F11528F095B8D095B8D095B8D095B8D2D54802D54802D54802D5480
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D005B8D005B8D
005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883095B8D095B8D095B8D
095B8D276F93276F93276F93276F93276F9311528F11528F11528F11528F286091286091
286091286091155883155883155883155883196493196493196493196493196493196493
196493196493045B84045B84045B84045B84045B8419588F19588F19588F19588F116495
1164951164951164955B90A55B90A55B90A55B90A5276F93276F93276F93276F930C6C8A
0C6C8A0C6C8A0C6C8A28609128609128609128609128609108648D08648D08648D08648D
155883155883155883155883116495116495116495116495276F93276F93276F93276F93
2A729D2A729D2A729D2A729D1558831558831558831558831558832B83992B83992B8399
2B83992D54802D54802D54802D5480095B8D095B8D095B8D095B8D40779A40779A40779A
40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93276F9311648D11648D
11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E87
0C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D045B84
045B84045B84045B8419588F19588F19588F19588F005B8D005B8D005B8D005B8D40779A
40779A40779A40779A286091286091286091286091438CA2438CA2438CA2438CA2438CA2
0C8E870C8E870C8E870C8E8711648D11648D11648D11648D19588F19588F19588F19588F
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A196493196493196493196493
1964930C8E870C8E870C8E870C8E872B83992B83992B83992B8399046483046483046483
046483045B84045B84045B84045B8440779A40779A40779A40779A155883155883155883
15588315588328609128609128609128609116427B16427B16427B16427B095B8D095B8D
095B8D095B8D276F93276F93276F93276F932B83992B83992B83992B8399155883155883
15588315588315588311528F11528F11528F11528F095B8D095B8D095B8D095B8D2D5480
2D54802D54802D5480438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D
005B8D005B8D005B8D005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
095B8D095B8D095B8D095B8D276F93276F93276F93276F9311528F11528F11528F11528F
286091286091286091286091286091155883155883155883155883196493196493196493
196493196493196493196493196493045B84045B84045B84045B8419588F19588F19588F
19588F1164951164951164951164951164955B90A55B90A55B90A55B90A5276F93276F93
276F93276F930C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609108648D08648D
08648D08648D155883155883155883155883155883116495116495116495116495276F93
276F93276F93276F932A729D2A729D2A729D2A729D1558831558831558831558832B8399
2B83992B83992B83992D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D
40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93
11648D11648D11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D0C8E870C8E870C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D
005B8D045B84045B84045B84045B8419588F19588F19588F19588F19588F005B8D005B8D
005B8D005B8D40779A40779A40779A40779A286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000155883155883155883286091
28609128609128609116427B16427B16427B16427B095B8D095B8D095B8D095B8D276F93
276F93276F93276F93276F932B83992B83992B83992B8399155883155883155883155883
11528F11528F11528F11528F095B8D095B8D095B8D095B8D2D54802D54802D54802D5480
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D005B8D005B8D
005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883095B8D095B8D095B8D
095B8D276F93276F93276F93276F93276F9311528F11528F11528F11528F286091286091
286091286091155883155883155883155883196493196493196493196493196493196493
196493196493045B84045B84045B84045B84045B8419588F19588F19588F19588F116495
1164951164951164955B90A55B90A55B90A55B90A5276F93276F93276F93276F930C6C8A
0C6C8A0C6C8A0C6C8A28609128609128609128609128609108648D08648D08648D08648D
155883155883155883155883116495116495116495116495276F93276F93276F93276F93
2A729D2A729D2A729D2A729D1558831558831558831558831558832B83992B83992B8399
2B83992D54802D54802D54802D5480095B8D095B8D095B8D095B8D40779A40779A40779A
40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93276F9311648D11648D
11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E87
0C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D005B8D005B8D045B84
045B84045B84045B8419588F19588F19588F19588F005B8D005B8D005B8D005B8D40779A
40779A40779A40779A286091286091286091286091438CA2438CA2438CA2438CA2438CA2
0C8E870C8E870C8E870C8E8711648D11648D11648D11648D19588F19588F19588F19588F
0C8E870C8E870C8E870C8E8705538A05538A05538A05538A196493196493196493196493
1964930C8E870C8E870C8E870C8E872B83992B83992B83992B8399046483046483046483
046483045B84045B84045B84045B8440779A40779A40779A40779A155883155883155883
15588315588328609128609128609128609116427B16427B16427B16427B095B8D095B8D
095B8D095B8D276F93276F93276F93276F932B83992B83992B83992B8399155883155883
15588315588315588311528F11528F11528F11528F095B8D095B8D095B8D095B8D2D5480
2D54802D54802D5480438CA2438CA2438CA2438CA22B83992B83992B83992B8399005B8D
005B8D005B8D005B8D005B8D2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
095B8D095B8D095B8D095B8D276F93276F93276F93276F9311528F11528F11528F11528F
286091286091286091286091286091155883155883155883155883196493196493196493
196493196493196493196493196493045B84045B84045B84045B8419588F19588F19588F
19588F1164951164951164951164951164955B90A55B90A55B90A55B90A5276F93276F93
276F93276F930C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609108648D08648D
08648D08648D155883155883155883155883155883116495116495116495116495276F93
276F93276F93276F932A729D2A729D2A729D2A729D1558831558831558831558832B8399
2B83992B83992B83992D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D
40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93
11648D11648D11648D11648D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0E7C8D0C8E870C8E870C8E870C8E872B83992B83992B83992B8399005B8D005B8D005B8D
005B8D045B84045B84045B84045B8419588F19588F19588F19588F19588F005B8D005B8D
005B8D005B8D40779A40779A40779A40779A286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000011648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2B8399
2B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A286091
28609128609128609128609140779A40779A40779A40779A438CA2438CA2438CA2438CA2
2D54802D54802D54802D5480196493196493196493196493116495116495116495116495
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93276F93276F93
276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A0C8E870C8E870C8E87
0C8E870F748F0F748F0F748F0F748F0F748F286091286091286091286091438CA2438CA2
438CA2438CA22B83992B83992B83992B839916427B16427B16427B16427B045B84045B84
045B84045B842A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D196493
196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A276F93
276F93276F93276F93005B8D005B8D005B8D005B8D005B8D276F93276F93276F93276F93
16427B16427B16427B16427B16427B16427B16427B16427B11528F11528F11528F11528F
07649507649507649507649516427B16427B16427B16427B16427B276F93276F93276F93
276F9316427B16427B16427B16427B11528F11528F11528F11528F0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091286091116495116495
11649511649511648D11648D11648D11648D116C96116C96116C96116C960C6C8A0C6C8A
0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D2A729D196493
19649319649319649311648D11648D11648D11648D28609128609128609128609140779A
40779A40779A40779A5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
196493196493196493196493044582044582044582044582196493196493196493196493
19649328609128609128609128609140779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2B83992B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A28609128609128609128609140779A40779A40779A40779A438CA2438CA2
438CA2438CA2438CA22D54802D54802D54802D5480196493196493196493196493116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A
0C8E870C8E870C8E870C8E870F748F0F748F0F748F0F748F286091286091286091286091
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B839916427B16427B16427B
16427B045B84045B84045B84045B842A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D196493196493196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A
0C6C8A0C6C8A276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93276F93
276F93276F9316427B16427B16427B16427B16427B16427B16427B16427B16427B11528F
11528F11528F11528F07649507649507649507649516427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B16427B11528F11528F11528F11528F
0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
11649511649511649511649511648D11648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D
2A729D19649319649319649319649311648D11648D11648D11648D11648D286091286091
28609128609140779A40779A40779A40779A5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002D548011648D11648D
11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2B8399
2B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A286091
28609128609128609128609140779A40779A40779A40779A438CA2438CA2438CA2438CA2
2D54802D54802D54802D5480196493196493196493196493116495116495116495116495
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93276F93276F93
276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A0C8E870C8E870C8E87
0C8E870F748F0F748F0F748F0F748F0F748F286091286091286091286091438CA2438CA2
438CA2438CA22B83992B83992B83992B839916427B16427B16427B16427B045B84045B84
045B84045B842A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D196493
196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A276F93
276F93276F93276F93005B8D005B8D005B8D005B8D005B8D276F93276F93276F93276F93
16427B16427B16427B16427B16427B16427B16427B16427B11528F11528F11528F11528F
07649507649507649507649516427B16427B16427B16427B16427B276F93276F93276F93
276F9316427B16427B16427B16427B11528F11528F11528F11528F0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091286091116495116495
11649511649511648D11648D11648D11648D116C96116C96116C96116C960C6C8A0C6C8A
0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D2A729D196493
19649319649319649311648D11648D11648D11648D28609128609128609128609140779A
40779A40779A40779A5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
196493196493196493196493044582044582044582044582196493196493196493196493
19649328609128609128609128609140779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2B83992B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A28609128609128609128609140779A40779A40779A40779A438CA2438CA2
438CA2438CA2438CA22D54802D54802D54802D5480196493196493196493196493116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A
0C8E870C8E870C8E870C8E870F748F0F748F0F748F0F748F286091286091286091286091
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B839916427B16427B16427B
16427B045B84045B84045B84045B842A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D196493196493196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A
0C6C8A0C6C8A276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93276F93
276F93276F9316427B16427B16427B16427B16427B16427B16427B16427B16427B11528F
11528F11528F11528F07649507649507649507649516427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B16427B11528F11528F11528F11528F
0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
11649511649511649511649511648D11648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D
2A729D19649319649319649319649311648D11648D11648D11648D11648D286091286091
28609128609140779A40779A40779A40779A5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000040779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2B8399
2B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A286091
28609128609128609128609140779A40779A40779A40779A438CA2438CA2438CA2438CA2
2D54802D54802D54802D5480196493196493196493196493116495116495116495116495
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93276F93276F93
276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A0C8E870C8E870C8E87
0C8E870F748F0F748F0F748F0F748F0F748F286091286091286091286091438CA2438CA2
438CA2438CA22B83992B83992B83992B839916427B16427B16427B16427B045B84045B84
045B84045B842A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D196493
196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A276F93
276F93276F93276F93005B8D005B8D005B8D005B8D005B8D276F93276F93276F93276F93
16427B16427B16427B16427B16427B16427B16427B16427B11528F11528F11528F11528F
07649507649507649507649516427B16427B16427B16427B16427B276F93276F93276F93
276F9316427B16427B16427B16427B11528F11528F11528F11528F0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091286091116495116495
11649511649511648D11648D11648D11648D116C96116C96116C96116C960C6C8A0C6C8A
0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D2A729D196493
19649319649319649311648D11648D11648D11648D28609128609128609128609140779A
40779A40779A40779A5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
196493196493196493196493044582044582044582044582196493196493196493196493
19649328609128609128609128609140779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2B83992B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A28609128609128609128609140779A40779A40779A40779A438CA2438CA2
438CA2438CA2438CA22D54802D54802D54802D5480196493196493196493196493116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A
0C8E870C8E870C8E870C8E870F748F0F748F0F748F0F748F286091286091286091286091
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B839916427B16427B16427B
16427B045B84045B84045B84045B842A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D196493196493196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A
0C6C8A0C6C8A276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93276F93
276F93276F9316427B16427B16427B16427B16427B16427B16427B16427B16427B11528F
11528F11528F11528F07649507649507649507649516427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B16427B11528F11528F11528F11528F
0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
11649511649511649511649511648D11648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D
2A729D19649319649319649319649311648D11648D11648D11648D11648D286091286091
28609128609140779A40779A40779A40779A5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000286091286091
28609128609140779A40779A40779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D0E7C8D2B8399
2B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A0C6C8A0C6C8A286091
28609128609128609128609140779A40779A40779A40779A438CA2438CA2438CA2438CA2
2D54802D54802D54802D5480196493196493196493196493116495116495116495116495
0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93276F93276F93
276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A0C8E870C8E870C8E87
0C8E870F748F0F748F0F748F0F748F0F748F286091286091286091286091438CA2438CA2
438CA2438CA22B83992B83992B83992B839916427B16427B16427B16427B045B84045B84
045B84045B842A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D196493
196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A0C6C8A0C6C8A276F93
276F93276F93276F93005B8D005B8D005B8D005B8D005B8D276F93276F93276F93276F93
16427B16427B16427B16427B16427B16427B16427B16427B11528F11528F11528F11528F
07649507649507649507649516427B16427B16427B16427B16427B276F93276F93276F93
276F9316427B16427B16427B16427B11528F11528F11528F11528F0F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091286091116495116495
11649511649511648D11648D11648D11648D116C96116C96116C96116C960C6C8A0C6C8A
0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D2A729D2A729D196493
19649319649319649311648D11648D11648D11648D28609128609128609128609140779A
40779A40779A40779A5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
196493196493196493196493044582044582044582044582196493196493196493196493
19649328609128609128609128609140779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D276F93276F93276F93276F930E7C8D0E7C8D0E7C8D
0E7C8D0E7C8D2B83992B83992B83992B839911648D11648D11648D11648D0C6C8A0C6C8A
0C6C8A0C6C8A28609128609128609128609140779A40779A40779A40779A438CA2438CA2
438CA2438CA2438CA22D54802D54802D54802D5480196493196493196493196493116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D2A729D2A729D2A729D2A729D276F93
276F93276F93276F93276F930C6C8A0C6C8A0C6C8A0C6C8A40779A40779A40779A40779A
0C8E870C8E870C8E870C8E870F748F0F748F0F748F0F748F286091286091286091286091
438CA2438CA2438CA2438CA2438CA22B83992B83992B83992B839916427B16427B16427B
16427B045B84045B84045B84045B842A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D196493196493196493196493196493115B8F115B8F115B8F115B8F0C6C8A0C6C8A
0C6C8A0C6C8A276F93276F93276F93276F93005B8D005B8D005B8D005B8D276F93276F93
276F93276F9316427B16427B16427B16427B16427B16427B16427B16427B16427B11528F
11528F11528F11528F07649507649507649507649516427B16427B16427B16427B276F93
276F93276F93276F9316427B16427B16427B16427B16427B11528F11528F11528F11528F
0F748F0F748F0F748F0F748F2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
11649511649511649511649511648D11648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802A729D2A729D2A729D
2A729D19649319649319649319649311648D11648D11648D11648D11648D286091286091
28609128609140779A40779A40779A40779A5B90A5000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000002860910F748F0F748F0F748F0F748F11648D11648D
11648D11648D155883155883155883155883276F93276F93276F93276F932B83992B8399
2B83992B83992B83992B83992B83992B83992B83992860912860912860912860910C8E87
0C8E870C8E870C8E872B83992B83992B83992B839940779A40779A40779A40779A2B8399
2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D11648D11648D
5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D08648D08648D08648D
095B8D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D0E7C8D0E7C8D
0E7C8D28609128609128609128609119588F19588F19588F19588F276F93276F93276F93
276F932B83992B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D196493196493
196493196493276F93276F93276F93276F935B90A55B90A55B90A55B90A50C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D095B8D15588315588315588315588340779A
40779A40779A40779A276F93276F93276F93276F93276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091095B8D095B8D095B8D095B8D
2B83992B83992B83992B839911648D11648D11648D11648D276F93276F93276F93276F93
1164951164951164951164952B83992B83992B83992B83992B83992A729D2A729D2A729D
2A729D16427B16427B16427B16427B095B8D095B8D095B8D095B8D0F748F0F748F0F748F
0F748F07649507649507649507649511648D11648D11648D11648D11648D40779A40779A
40779A40779A11648D11648D11648D11648D116C96116C96116C96116C96286091286091
286091286091095B8D095B8D095B8D095B8D08648D08648D08648D08648D08648D11648D
11648D11648D11648D2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A11648D
11648D11648D11648D1558831558831558831558832D54802D54802D54802D54802D5480
11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
005B8D005B8D005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D155883155883155883155883276F93276F93276F93
276F932B83992B83992B83992B83992B83992B83992B83992B8399286091286091286091
2860912860910C8E870C8E870C8E870C8E872B83992B83992B83992B839940779A40779A
40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D
11648D11648D11648D5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D
08648D08648D08648D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D28609128609128609128609119588F19588F19588F19588F
276F93276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D
196493196493196493196493196493276F93276F93276F93276F935B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D155883155883155883
15588340779A40779A40779A40779A40779A276F93276F93276F93276F93276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091095B8D095B8D
095B8D095B8D2B83992B83992B83992B83992B839911648D11648D11648D11648D276F93
276F93276F93276F931164951164951164951164952B83992B83992B83992B83992A729D
2A729D2A729D2A729D16427B16427B16427B16427B16427B095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F07649507649507649507649511648D11648D11648D11648D
40779A40779A40779A40779A11648D11648D11648D11648D11648D116C96116C96116C96
116C96286091286091286091286091095B8D095B8D095B8D095B8D08648D08648D08648D
08648D11648D11648D11648D11648D2860912860912860912860912860910C6C8A0C6C8A
0C6C8A0C6C8A11648D11648D11648D11648D155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F11648D11648D
11648D11648D155883155883155883155883276F93276F93276F93276F932B83992B8399
2B83992B83992B83992B83992B83992B83992B83992860912860912860912860910C8E87
0C8E870C8E870C8E872B83992B83992B83992B839940779A40779A40779A40779A2B8399
2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D11648D11648D
5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D08648D08648D08648D
095B8D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D0E7C8D0E7C8D
0E7C8D28609128609128609128609119588F19588F19588F19588F276F93276F93276F93
276F932B83992B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D196493196493
196493196493276F93276F93276F93276F935B90A55B90A55B90A55B90A50C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D095B8D15588315588315588315588340779A
40779A40779A40779A276F93276F93276F93276F93276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091095B8D095B8D095B8D095B8D
2B83992B83992B83992B839911648D11648D11648D11648D276F93276F93276F93276F93
1164951164951164951164952B83992B83992B83992B83992B83992A729D2A729D2A729D
2A729D16427B16427B16427B16427B095B8D095B8D095B8D095B8D0F748F0F748F0F748F
0F748F07649507649507649507649511648D11648D11648D11648D11648D40779A40779A
40779A40779A11648D11648D11648D11648D116C96116C96116C96116C96286091286091
286091286091095B8D095B8D095B8D095B8D08648D08648D08648D08648D08648D11648D
11648D11648D11648D2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A11648D
11648D11648D11648D1558831558831558831558832D54802D54802D54802D54802D5480
11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
005B8D005B8D005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D155883155883155883155883276F93276F93276F93
276F932B83992B83992B83992B83992B83992B83992B83992B8399286091286091286091
2860912860910C8E870C8E870C8E870C8E872B83992B83992B83992B839940779A40779A
40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D
11648D11648D11648D5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D
08648D08648D08648D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D28609128609128609128609119588F19588F19588F19588F
276F93276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D
196493196493196493196493196493276F93276F93276F93276F935B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D155883155883155883
15588340779A40779A40779A40779A40779A276F93276F93276F93276F93276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091095B8D095B8D
095B8D095B8D2B83992B83992B83992B83992B839911648D11648D11648D11648D276F93
276F93276F93276F931164951164951164951164952B83992B83992B83992B83992A729D
2A729D2A729D2A729D16427B16427B16427B16427B16427B095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F07649507649507649507649511648D11648D11648D11648D
40779A40779A40779A40779A11648D11648D11648D11648D11648D116C96116C96116C96
116C96286091286091286091286091095B8D095B8D095B8D095B8D08648D08648D08648D
08648D11648D11648D11648D11648D2860912860912860912860912860910C6C8A0C6C8A
0C6C8A0C6C8A11648D11648D11648D11648D155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000286091286091005B8D005B8D005B8D
005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F11648D11648D
11648D11648D155883155883155883155883276F93276F93276F93276F932B83992B8399
2B83992B83992B83992B83992B83992B83992B83992860912860912860912860910C8E87
0C8E870C8E870C8E872B83992B83992B83992B839940779A40779A40779A40779A2B8399
2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D11648D11648D
5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D08648D08648D08648D
095B8D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D0E7C8D0E7C8D
0E7C8D28609128609128609128609119588F19588F19588F19588F276F93276F93276F93
276F932B83992B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D196493196493
196493196493276F93276F93276F93276F935B90A55B90A55B90A55B90A50C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D095B8D15588315588315588315588340779A
40779A40779A40779A276F93276F93276F93276F93276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091095B8D095B8D095B8D095B8D
2B83992B83992B83992B839911648D11648D11648D11648D276F93276F93276F93276F93
1164951164951164951164952B83992B83992B83992B83992B83992A729D2A729D2A729D
2A729D16427B16427B16427B16427B095B8D095B8D095B8D095B8D0F748F0F748F0F748F
0F748F07649507649507649507649511648D11648D11648D11648D11648D40779A40779A
40779A40779A11648D11648D11648D11648D116C96116C96116C96116C96286091286091
286091286091095B8D095B8D095B8D095B8D08648D08648D08648D08648D08648D11648D
11648D11648D11648D2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A11648D
11648D11648D11648D1558831558831558831558832D54802D54802D54802D54802D5480
11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
005B8D005B8D005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D155883155883155883155883276F93276F93276F93
276F932B83992B83992B83992B83992B83992B83992B83992B8399286091286091286091
2860912860910C8E870C8E870C8E870C8E872B83992B83992B83992B839940779A40779A
40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D
11648D11648D11648D5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D
08648D08648D08648D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D28609128609128609128609119588F19588F19588F19588F
276F93276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D
196493196493196493196493196493276F93276F93276F93276F935B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D155883155883155883
15588340779A40779A40779A40779A40779A276F93276F93276F93276F93276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091095B8D095B8D
095B8D095B8D2B83992B83992B83992B83992B839911648D11648D11648D11648D276F93
276F93276F93276F931164951164951164951164952B83992B83992B83992B83992A729D
2A729D2A729D2A729D16427B16427B16427B16427B16427B095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F07649507649507649507649511648D11648D11648D11648D
40779A40779A40779A40779A11648D11648D11648D11648D11648D116C96116C96116C96
116C96286091286091286091286091095B8D095B8D095B8D095B8D08648D08648D08648D
08648D11648D11648D11648D11648D2860912860912860912860912860910C6C8A0C6C8A
0C6C8A0C6C8A11648D11648D11648D11648D155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000002A2F6C2A2F6C2A2F6C286091286091286091286091005B8D005B8D005B8D
005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F11648D11648D
11648D11648D155883155883155883155883276F93276F93276F93276F932B83992B8399
2B83992B83992B83992B83992B83992B83992B83992860912860912860912860910C8E87
0C8E870C8E870C8E872B83992B83992B83992B839940779A40779A40779A40779A2B8399
2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D11648D11648D
5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D08648D08648D08648D
095B8D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D0E7C8D0E7C8D
0E7C8D28609128609128609128609119588F19588F19588F19588F276F93276F93276F93
276F932B83992B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D196493196493
196493196493276F93276F93276F93276F935B90A55B90A55B90A55B90A50C6C8A0C6C8A
0C6C8A0C6C8A095B8D095B8D095B8D095B8D095B8D15588315588315588315588340779A
40779A40779A40779A276F93276F93276F93276F93276F93276F93276F93276F930E7C8D
0E7C8D0E7C8D0E7C8D286091286091286091286091286091095B8D095B8D095B8D095B8D
2B83992B83992B83992B839911648D11648D11648D11648D276F93276F93276F93276F93
1164951164951164951164952B83992B83992B83992B83992B83992A729D2A729D2A729D
2A729D16427B16427B16427B16427B095B8D095B8D095B8D095B8D0F748F0F748F0F748F
0F748F07649507649507649507649511648D11648D11648D11648D11648D40779A40779A
40779A40779A11648D11648D11648D11648D116C96116C96116C96116C96286091286091
286091286091095B8D095B8D095B8D095B8D08648D08648D08648D08648D08648D11648D
11648D11648D11648D2860912860912860912860910C6C8A0C6C8A0C6C8A0C6C8A11648D
11648D11648D11648D1558831558831558831558832D54802D54802D54802D54802D5480
11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091
005B8D005B8D005B8D005B8D2860912860912860912860910F748F0F748F0F748F0F748F
0F748F11648D11648D11648D11648D155883155883155883155883276F93276F93276F93
276F932B83992B83992B83992B83992B83992B83992B83992B8399286091286091286091
2860912860910C8E870C8E870C8E870C8E872B83992B83992B83992B839940779A40779A
40779A40779A2B83992B83992B83992B8399116C96116C96116C96116C9611648D11648D
11648D11648D11648D5B90A55B90A55B90A55B90A5276F93276F93276F93276F9308648D
08648D08648D08648D095B8D095B8D095B8D095B8D16427B16427B16427B16427B0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D28609128609128609128609119588F19588F19588F19588F
276F93276F93276F93276F932B83992B83992B83992B83990E7C8D0E7C8D0E7C8D0E7C8D
196493196493196493196493196493276F93276F93276F93276F935B90A55B90A55B90A5
5B90A50C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D095B8D155883155883155883
15588340779A40779A40779A40779A40779A276F93276F93276F93276F93276F93276F93
276F93276F930E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091095B8D095B8D
095B8D095B8D2B83992B83992B83992B83992B839911648D11648D11648D11648D276F93
276F93276F93276F931164951164951164951164952B83992B83992B83992B83992A729D
2A729D2A729D2A729D16427B16427B16427B16427B16427B095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F07649507649507649507649511648D11648D11648D11648D
40779A40779A40779A40779A11648D11648D11648D11648D11648D116C96116C96116C96
116C96286091286091286091286091095B8D095B8D095B8D095B8D08648D08648D08648D
08648D11648D11648D11648D11648D2860912860912860912860912860910C6C8A0C6C8A
0C6C8A0C6C8A11648D11648D11648D11648D155883000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A5
5B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F05538A05538A
05538A05538A2B83992B83992B83992B839911648D11648D11648D11648D155883155883
155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B16427B438CA2
438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A40779A40779A196493
196493196493196493196493046483046483046483046483276F93276F93276F93276F93
2860912860912860912860910F748F0F748F0F748F0F748F286091286091286091286091
2A729D2A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D2A729D2A729D
2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2B83992B83992B8399
2B839919649319649319649319649319649311528F11528F11528F11528F11648D11648D
11648D11648D276F93276F93276F93276F9315588315588315588315588340779A40779A
40779A40779A116C96116C96116C96116C96116C962D54802D54802D54802D54802D5480
2D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F11528F11528F116C96
116C96116C96116C9611648D11648D11648D11648D11648D115B8F115B8F115B8F115B8F
2D54802D54802D54802D548040779A40779A40779A40779A0F748F0F748F0F748F0F748F
2B83992B83992B83992B8399276F93276F93276F93276F93276F9311648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F11648D11648D11648D
11648D286091286091286091286091005B8D005B8D005B8D005B8D005B8D40779A40779A
40779A40779A2860912860912860912860915B90A55B90A55B90A55B90A50E7C8D0E7C8D
0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D5B90A5
5B90A55B90A55B90A52B83992B83992B83992B8399116495116495116495116495116495
2B83992B83992B83992B8399095B8D095B8D095B8D095B8D196493196493196493196493
5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F
115B8F05538A05538A05538A05538A2B83992B83992B83992B839911648D11648D11648D
11648D155883155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B
16427B16427B438CA2438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A
40779A40779A196493196493196493196493046483046483046483046483276F93276F93
276F93276F93276F932860912860912860912860910F748F0F748F0F748F0F748F286091
2860912860912860912A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D
2A729D2A729D2A729D2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
2B83992B83992B83992B839919649319649319649319649311528F11528F11528F11528F
11648D11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
15588340779A40779A40779A40779A116C96116C96116C96116C962D54802D54802D5480
2D54802D54802D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F
11528F11528F116C96116C96116C96116C9611648D11648D11648D11648D115B8F115B8F
115B8F115B8F2D54802D54802D54802D54802D548040779A40779A40779A40779A0F748F
0F748F0F748F0F748F2B83992B83992B83992B8399276F93276F93276F93276F9311648D
11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F
11648D11648D11648D11648D286091286091286091286091005B8D005B8D005B8D005B8D
40779A40779A40779A40779A2860912860912860912860912860915B90A55B90A55B90A5
5B90A50E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F155883155883155883155883155883095B8D095B8D
095B8D095B8D5B90A55B90A55B90A55B90A52B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002B83991164951164951164951164952B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A5
5B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F05538A05538A
05538A05538A2B83992B83992B83992B839911648D11648D11648D11648D155883155883
155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B16427B438CA2
438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A40779A40779A196493
196493196493196493196493046483046483046483046483276F93276F93276F93276F93
2860912860912860912860910F748F0F748F0F748F0F748F286091286091286091286091
2A729D2A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D2A729D2A729D
2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2B83992B83992B8399
2B839919649319649319649319649319649311528F11528F11528F11528F11648D11648D
11648D11648D276F93276F93276F93276F9315588315588315588315588340779A40779A
40779A40779A116C96116C96116C96116C96116C962D54802D54802D54802D54802D5480
2D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F11528F11528F116C96
116C96116C96116C9611648D11648D11648D11648D11648D115B8F115B8F115B8F115B8F
2D54802D54802D54802D548040779A40779A40779A40779A0F748F0F748F0F748F0F748F
2B83992B83992B83992B8399276F93276F93276F93276F93276F9311648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F11648D11648D11648D
11648D286091286091286091286091005B8D005B8D005B8D005B8D005B8D40779A40779A
40779A40779A2860912860912860912860915B90A55B90A55B90A55B90A50E7C8D0E7C8D
0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D5B90A5
5B90A55B90A55B90A52B83992B83992B83992B8399116495116495116495116495116495
2B83992B83992B83992B8399095B8D095B8D095B8D095B8D196493196493196493196493
5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F
115B8F05538A05538A05538A05538A2B83992B83992B83992B839911648D11648D11648D
11648D155883155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B
16427B16427B438CA2438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A
40779A40779A196493196493196493196493046483046483046483046483276F93276F93
276F93276F93276F932860912860912860912860910F748F0F748F0F748F0F748F286091
2860912860912860912A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D
2A729D2A729D2A729D2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
2B83992B83992B83992B839919649319649319649319649311528F11528F11528F11528F
11648D11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
15588340779A40779A40779A40779A116C96116C96116C96116C962D54802D54802D5480
2D54802D54802D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F
11528F11528F116C96116C96116C96116C9611648D11648D11648D11648D115B8F115B8F
115B8F115B8F2D54802D54802D54802D54802D548040779A40779A40779A40779A0F748F
0F748F0F748F0F748F2B83992B83992B83992B8399276F93276F93276F93276F9311648D
11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F
11648D11648D11648D11648D286091286091286091286091005B8D005B8D005B8D005B8D
40779A40779A40779A40779A2860912860912860912860912860915B90A55B90A55B90A5
5B90A50E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F155883155883155883155883155883095B8D095B8D
095B8D095B8D5B90A55B90A55B90A55B90A52B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
5B90A52B83992B83992B83992B83991164951164951164951164952B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A5
5B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F05538A05538A
05538A05538A2B83992B83992B83992B839911648D11648D11648D11648D155883155883
155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B16427B438CA2
438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A40779A40779A196493
196493196493196493196493046483046483046483046483276F93276F93276F93276F93
2860912860912860912860910F748F0F748F0F748F0F748F286091286091286091286091
2A729D2A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D2A729D2A729D
2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2B83992B83992B8399
2B839919649319649319649319649319649311528F11528F11528F11528F11648D11648D
11648D11648D276F93276F93276F93276F9315588315588315588315588340779A40779A
40779A40779A116C96116C96116C96116C96116C962D54802D54802D54802D54802D5480
2D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F11528F11528F116C96
116C96116C96116C9611648D11648D11648D11648D11648D115B8F115B8F115B8F115B8F
2D54802D54802D54802D548040779A40779A40779A40779A0F748F0F748F0F748F0F748F
2B83992B83992B83992B8399276F93276F93276F93276F93276F9311648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F11648D11648D11648D
11648D286091286091286091286091005B8D005B8D005B8D005B8D005B8D40779A40779A
40779A40779A2860912860912860912860915B90A55B90A55B90A55B90A50E7C8D0E7C8D
0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D5B90A5
5B90A55B90A55B90A52B83992B83992B83992B8399116495116495116495116495116495
2B83992B83992B83992B8399095B8D095B8D095B8D095B8D196493196493196493196493
5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F
115B8F05538A05538A05538A05538A2B83992B83992B83992B839911648D11648D11648D
11648D155883155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B
16427B16427B438CA2438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A
40779A40779A196493196493196493196493046483046483046483046483276F93276F93
276F93276F93276F932860912860912860912860910F748F0F748F0F748F0F748F286091
2860912860912860912A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D
2A729D2A729D2A729D2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
2B83992B83992B83992B839919649319649319649319649311528F11528F11528F11528F
11648D11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
15588340779A40779A40779A40779A116C96116C96116C96116C962D54802D54802D5480
2D54802D54802D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F
11528F11528F116C96116C96116C96116C9611648D11648D11648D11648D115B8F115B8F
115B8F115B8F2D54802D54802D54802D54802D548040779A40779A40779A40779A0F748F
0F748F0F748F0F748F2B83992B83992B83992B8399276F93276F93276F93276F9311648D
11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F
11648D11648D11648D11648D286091286091286091286091005B8D005B8D005B8D005B8D
40779A40779A40779A40779A2860912860912860912860912860915B90A55B90A55B90A5
5B90A50E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F155883155883155883155883155883095B8D095B8D
095B8D095B8D5B90A55B90A55B90A55B90A52B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000005B90A55B90A55B90A55B90A5
5B90A52B83992B83992B83992B83991164951164951164951164952B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A5
5B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F05538A05538A
05538A05538A2B83992B83992B83992B839911648D11648D11648D11648D155883155883
155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B16427B438CA2
438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A40779A40779A196493
196493196493196493196493046483046483046483046483276F93276F93276F93276F93
2860912860912860912860910F748F0F748F0F748F0F748F286091286091286091286091
2A729D2A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D2A729D2A729D
2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2B83992B83992B8399
2B839919649319649319649319649319649311528F11528F11528F11528F11648D11648D
11648D11648D276F93276F93276F93276F9315588315588315588315588340779A40779A
40779A40779A116C96116C96116C96116C96116C962D54802D54802D54802D54802D5480
2D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F11528F11528F116C96
116C96116C96116C9611648D11648D11648D11648D11648D115B8F115B8F115B8F115B8F
2D54802D54802D54802D548040779A40779A40779A40779A0F748F0F748F0F748F0F748F
2B83992B83992B83992B8399276F93276F93276F93276F93276F9311648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F11648D11648D11648D
11648D286091286091286091286091005B8D005B8D005B8D005B8D005B8D40779A40779A
40779A40779A2860912860912860912860915B90A55B90A55B90A55B90A50E7C8D0E7C8D
0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D5B90A5
5B90A55B90A55B90A52B83992B83992B83992B8399116495116495116495116495116495
2B83992B83992B83992B8399095B8D095B8D095B8D095B8D196493196493196493196493
5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F
115B8F05538A05538A05538A05538A2B83992B83992B83992B839911648D11648D11648D
11648D155883155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B
16427B16427B438CA2438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A
40779A40779A196493196493196493196493046483046483046483046483276F93276F93
276F93276F93276F932860912860912860912860910F748F0F748F0F748F0F748F286091
2860912860912860912A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D
2A729D2A729D2A729D2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
2B83992B83992B83992B839919649319649319649319649311528F11528F11528F11528F
11648D11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
15588340779A40779A40779A40779A116C96116C96116C96116C962D54802D54802D5480
2D54802D54802D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F
11528F11528F116C96116C96116C96116C9611648D11648D11648D11648D115B8F115B8F
115B8F115B8F2D54802D54802D54802D54802D548040779A40779A40779A40779A0F748F
0F748F0F748F0F748F2B83992B83992B83992B8399276F93276F93276F93276F9311648D
11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F
11648D11648D11648D11648D286091286091286091286091005B8D005B8D005B8D005B8D
40779A40779A40779A40779A2860912860912860912860912860915B90A55B90A55B90A5
5B90A50E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F155883155883155883155883155883095B8D095B8D
095B8D095B8D5B90A55B90A55B90A55B90A52B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000095B8D095B8D095B8D5B90A55B90A55B90A55B90A5
5B90A52B83992B83992B83992B83991164951164951164951164952B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A5
5B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F05538A05538A
05538A05538A2B83992B83992B83992B839911648D11648D11648D11648D155883155883
155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B16427B438CA2
438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A40779A40779A196493
196493196493196493196493046483046483046483046483276F93276F93276F93276F93
2860912860912860912860910F748F0F748F0F748F0F748F286091286091286091286091
2A729D2A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D2A729D2A729D
2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2B83992B83992B8399
2B839919649319649319649319649319649311528F11528F11528F11528F11648D11648D
11648D11648D276F93276F93276F93276F9315588315588315588315588340779A40779A
40779A40779A116C96116C96116C96116C96116C962D54802D54802D54802D54802D5480
2D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F11528F11528F116C96
116C96116C96116C9611648D11648D11648D11648D11648D115B8F115B8F115B8F115B8F
2D54802D54802D54802D548040779A40779A40779A40779A0F748F0F748F0F748F0F748F
2B83992B83992B83992B8399276F93276F93276F93276F93276F9311648D11648D11648D
11648D2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F11648D11648D11648D
11648D286091286091286091286091005B8D005B8D005B8D005B8D005B8D40779A40779A
40779A40779A2860912860912860912860915B90A55B90A55B90A55B90A50E7C8D0E7C8D
0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F
19588F19588F19588F155883155883155883155883095B8D095B8D095B8D095B8D5B90A5
5B90A55B90A55B90A52B83992B83992B83992B8399116495116495116495116495116495
2B83992B83992B83992B8399095B8D095B8D095B8D095B8D196493196493196493196493
5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F115B8F115B8F
115B8F05538A05538A05538A05538A2B83992B83992B83992B839911648D11648D11648D
11648D155883155883155883155883115B8F115B8F115B8F115B8F16427B16427B16427B
16427B16427B438CA2438CA2438CA2438CA20E7C8D0E7C8D0E7C8D0E7C8D40779A40779A
40779A40779A196493196493196493196493046483046483046483046483276F93276F93
276F93276F93276F932860912860912860912860910F748F0F748F0F748F0F748F286091
2860912860912860912A729D2A729D2A729D2A729D11528F11528F11528F11528F2A729D
2A729D2A729D2A729D2A729D40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C
2B83992B83992B83992B839919649319649319649319649311528F11528F11528F11528F
11648D11648D11648D11648D11648D276F93276F93276F93276F93155883155883155883
15588340779A40779A40779A40779A116C96116C96116C96116C962D54802D54802D5480
2D54802D54802D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D11528F11528F
11528F11528F116C96116C96116C96116C9611648D11648D11648D11648D115B8F115B8F
115B8F115B8F2D54802D54802D54802D54802D548040779A40779A40779A40779A0F748F
0F748F0F748F0F748F2B83992B83992B83992B8399276F93276F93276F93276F9311648D
11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0F748F0F748F0F748F0F748F
11648D11648D11648D11648D286091286091286091286091005B8D005B8D005B8D005B8D
40779A40779A40779A40779A2860912860912860912860912860915B90A55B90A55B90A5
5B90A50E7C8D0E7C8D0E7C8D0E7C8D0C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C
2A2F6C19588F19588F19588F19588F155883155883155883155883155883095B8D095B8D
095B8D095B8D5B90A55B90A55B90A55B90A52B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000438CA2438CA2438CA22B83992B83992B83992B8399276F93276F93276F93276F93
276F9340779A40779A40779A40779A40779A40779A40779A40779A095B8D095B8D095B8D
095B8D286091286091286091286091438CA2438CA2438CA2438CA2196493196493196493
19649319649311649511649511649511649528609128609128609128609111648D11648D
11648D11648D276F93276F93276F93276F932860912860912860912860912B83992B8399
2B83992B83992B839928609128609128609128609119588F19588F19588F19588F286091
28609128609128609140779A40779A40779A40779A15588315588315588315588384A8B2
84A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96116C96116C96
11528F11528F11528F11528F04458204458204458204458216427B16427B16427B16427B
155883155883155883155883155883115B8F115B8F115B8F115B8F116495116495116495
1164952D54802D54802D54802D5480196493196493196493196493196493196493196493
196493276F93276F93276F93276F93276F93196493196493196493196493095B8D095B8D
095B8D095B8D40779A40779A40779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D08648D
08648D08648D08648D11648D11648D11648D11648D155883155883155883155883005B8D
005B8D005B8D005B8D0F748F0F748F0F748F0F748F0F748F19588F19588F19588F19588F
095B8D095B8D095B8D095B8D15588315588315588315588316427B16427B16427B16427B
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802D548084A8B284A8B284A8B2
84A8B2196493196493196493196493115B8F115B8F115B8F115B8F116C96116C96116C96
116C96286091286091286091286091005B8D005B8D005B8D005B8D005B8D276F93276F93
276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F16427B
16427B16427B16427B438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93
276F93276F93276F9340779A40779A40779A40779A40779A40779A40779A40779A40779A
095B8D095B8D095B8D095B8D286091286091286091286091438CA2438CA2438CA2438CA2
196493196493196493196493116495116495116495116495286091286091286091286091
28609111648D11648D11648D11648D276F93276F93276F93276F93286091286091286091
2860912B83992B83992B83992B839928609128609128609128609119588F19588F19588F
19588F19588F28609128609128609128609140779A40779A40779A40779A155883155883
15588315588384A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96
116C96116C96116C9611528F11528F11528F11528F04458204458204458204458216427B
16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F116495
1164951164951164951164952D54802D54802D54802D5480196493196493196493196493
196493196493196493196493276F93276F93276F93276F93196493196493196493196493
095B8D095B8D095B8D095B8D095B8D40779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D
11648D08648D08648D08648D08648D08648D11648D11648D11648D11648D155883155883
155883155883005B8D005B8D005B8D005B8D0F748F0F748F0F748F0F748F19588F19588F
19588F19588F095B8D095B8D095B8D095B8D095B8D15588315588315588315588316427B
16427B16427B16427B0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548084A8B2
84A8B284A8B284A8B2196493196493196493196493196493115B8F115B8F115B8F115B8F
116C96116C96116C96116C96286091286091286091286091005B8D005B8D005B8D005B8D
276F93276F93276F93276F93095B8D095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83990C6C8A0C6C8A0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F16427B16427B16427B16427B438CA2438CA2438CA2438CA2438CA22B83992B8399
2B83992B8399276F93276F93276F93276F9340779A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000016427B16427B16427B
438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93276F93276F93276F93
276F9340779A40779A40779A40779A40779A40779A40779A40779A095B8D095B8D095B8D
095B8D286091286091286091286091438CA2438CA2438CA2438CA2196493196493196493
19649319649311649511649511649511649528609128609128609128609111648D11648D
11648D11648D276F93276F93276F93276F932860912860912860912860912B83992B8399
2B83992B83992B839928609128609128609128609119588F19588F19588F19588F286091
28609128609128609140779A40779A40779A40779A15588315588315588315588384A8B2
84A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96116C96116C96
11528F11528F11528F11528F04458204458204458204458216427B16427B16427B16427B
155883155883155883155883155883115B8F115B8F115B8F115B8F116495116495116495
1164952D54802D54802D54802D5480196493196493196493196493196493196493196493
196493276F93276F93276F93276F93276F93196493196493196493196493095B8D095B8D
095B8D095B8D40779A40779A40779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D08648D
08648D08648D08648D11648D11648D11648D11648D155883155883155883155883005B8D
005B8D005B8D005B8D0F748F0F748F0F748F0F748F0F748F19588F19588F19588F19588F
095B8D095B8D095B8D095B8D15588315588315588315588316427B16427B16427B16427B
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802D548084A8B284A8B284A8B2
84A8B2196493196493196493196493115B8F115B8F115B8F115B8F116C96116C96116C96
116C96286091286091286091286091005B8D005B8D005B8D005B8D005B8D276F93276F93
276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F16427B
16427B16427B16427B438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93
276F93276F93276F9340779A40779A40779A40779A40779A40779A40779A40779A40779A
095B8D095B8D095B8D095B8D286091286091286091286091438CA2438CA2438CA2438CA2
196493196493196493196493116495116495116495116495286091286091286091286091
28609111648D11648D11648D11648D276F93276F93276F93276F93286091286091286091
2860912B83992B83992B83992B839928609128609128609128609119588F19588F19588F
19588F19588F28609128609128609128609140779A40779A40779A40779A155883155883
15588315588384A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96
116C96116C96116C9611528F11528F11528F11528F04458204458204458204458216427B
16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F116495
1164951164951164951164952D54802D54802D54802D5480196493196493196493196493
196493196493196493196493276F93276F93276F93276F93196493196493196493196493
095B8D095B8D095B8D095B8D095B8D40779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D
11648D08648D08648D08648D08648D08648D11648D11648D11648D11648D155883155883
155883155883005B8D005B8D005B8D005B8D0F748F0F748F0F748F0F748F19588F19588F
19588F19588F095B8D095B8D095B8D095B8D095B8D15588315588315588315588316427B
16427B16427B16427B0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548084A8B2
84A8B284A8B284A8B2196493196493196493196493196493115B8F115B8F115B8F115B8F
116C96116C96116C96116C96286091286091286091286091005B8D005B8D005B8D005B8D
276F93276F93276F93276F93095B8D095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83990C6C8A0C6C8A0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F16427B16427B16427B16427B438CA2438CA2438CA2438CA2438CA22B83992B8399
2B83992B8399276F93276F93276F93276F9340779A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000F748F0F748F16427B16427B16427B16427B
438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93276F93276F93276F93
276F9340779A40779A40779A40779A40779A40779A40779A40779A095B8D095B8D095B8D
095B8D286091286091286091286091438CA2438CA2438CA2438CA2196493196493196493
19649319649311649511649511649511649528609128609128609128609111648D11648D
11648D11648D276F93276F93276F93276F932860912860912860912860912B83992B8399
2B83992B83992B839928609128609128609128609119588F19588F19588F19588F286091
28609128609128609140779A40779A40779A40779A15588315588315588315588384A8B2
84A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96116C96116C96
11528F11528F11528F11528F04458204458204458204458216427B16427B16427B16427B
155883155883155883155883155883115B8F115B8F115B8F115B8F116495116495116495
1164952D54802D54802D54802D5480196493196493196493196493196493196493196493
196493276F93276F93276F93276F93276F93196493196493196493196493095B8D095B8D
095B8D095B8D40779A40779A40779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D08648D
08648D08648D08648D11648D11648D11648D11648D155883155883155883155883005B8D
005B8D005B8D005B8D0F748F0F748F0F748F0F748F0F748F19588F19588F19588F19588F
095B8D095B8D095B8D095B8D15588315588315588315588316427B16427B16427B16427B
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802D548084A8B284A8B284A8B2
84A8B2196493196493196493196493115B8F115B8F115B8F115B8F116C96116C96116C96
116C96286091286091286091286091005B8D005B8D005B8D005B8D005B8D276F93276F93
276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F16427B
16427B16427B16427B438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93
276F93276F93276F9340779A40779A40779A40779A40779A40779A40779A40779A40779A
095B8D095B8D095B8D095B8D286091286091286091286091438CA2438CA2438CA2438CA2
196493196493196493196493116495116495116495116495286091286091286091286091
28609111648D11648D11648D11648D276F93276F93276F93276F93286091286091286091
2860912B83992B83992B83992B839928609128609128609128609119588F19588F19588F
19588F19588F28609128609128609128609140779A40779A40779A40779A155883155883
15588315588384A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96
116C96116C96116C9611528F11528F11528F11528F04458204458204458204458216427B
16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F116495
1164951164951164951164952D54802D54802D54802D5480196493196493196493196493
196493196493196493196493276F93276F93276F93276F93196493196493196493196493
095B8D095B8D095B8D095B8D095B8D40779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D
11648D08648D08648D08648D08648D08648D11648D11648D11648D11648D155883155883
155883155883005B8D005B8D005B8D005B8D0F748F0F748F0F748F0F748F19588F19588F
19588F19588F095B8D095B8D095B8D095B8D095B8D15588315588315588315588316427B
16427B16427B16427B0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548084A8B2
84A8B284A8B284A8B2196493196493196493196493196493115B8F115B8F115B8F115B8F
116C96116C96116C96116C96286091286091286091286091005B8D005B8D005B8D005B8D
276F93276F93276F93276F93095B8D095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83990C6C8A0C6C8A0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F16427B16427B16427B16427B438CA2438CA2438CA2438CA2438CA22B83992B8399
2B83992B8399276F93276F93276F93276F9340779A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000F748F0F748F0F748F0F748F0F748F0F748F16427B16427B16427B16427B
438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93276F93276F93276F93
276F9340779A40779A40779A40779A40779A40779A40779A40779A095B8D095B8D095B8D
095B8D286091286091286091286091438CA2438CA2438CA2438CA2196493196493196493
19649319649311649511649511649511649528609128609128609128609111648D11648D
11648D11648D276F93276F93276F93276F932860912860912860912860912B83992B8399
2B83992B83992B839928609128609128609128609119588F19588F19588F19588F286091
28609128609128609140779A40779A40779A40779A15588315588315588315588384A8B2
84A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96116C96116C96
11528F11528F11528F11528F04458204458204458204458216427B16427B16427B16427B
155883155883155883155883155883115B8F115B8F115B8F115B8F116495116495116495
1164952D54802D54802D54802D5480196493196493196493196493196493196493196493
196493276F93276F93276F93276F93276F93196493196493196493196493095B8D095B8D
095B8D095B8D40779A40779A40779A40779A2D54802D54802D54802D548011648D11648D
11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D08648D
08648D08648D08648D11648D11648D11648D11648D155883155883155883155883005B8D
005B8D005B8D005B8D0F748F0F748F0F748F0F748F0F748F19588F19588F19588F19588F
095B8D095B8D095B8D095B8D15588315588315588315588316427B16427B16427B16427B
0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D54802D548084A8B284A8B284A8B2
84A8B2196493196493196493196493115B8F115B8F115B8F115B8F116C96116C96116C96
116C96286091286091286091286091005B8D005B8D005B8D005B8D005B8D276F93276F93
276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B83992B83990C6C8A0C6C8A
0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F16427B
16427B16427B16427B438CA2438CA2438CA2438CA22B83992B83992B83992B8399276F93
276F93276F93276F9340779A40779A40779A40779A40779A40779A40779A40779A40779A
095B8D095B8D095B8D095B8D286091286091286091286091438CA2438CA2438CA2438CA2
196493196493196493196493116495116495116495116495286091286091286091286091
28609111648D11648D11648D11648D276F93276F93276F93276F93286091286091286091
2860912B83992B83992B83992B839928609128609128609128609119588F19588F19588F
19588F19588F28609128609128609128609140779A40779A40779A40779A155883155883
15588315588384A8B284A8B284A8B284A8B219588F19588F19588F19588F116C96116C96
116C96116C96116C9611528F11528F11528F11528F04458204458204458204458216427B
16427B16427B16427B155883155883155883155883115B8F115B8F115B8F115B8F116495
1164951164951164951164952D54802D54802D54802D5480196493196493196493196493
196493196493196493196493276F93276F93276F93276F93196493196493196493196493
095B8D095B8D095B8D095B8D095B8D40779A40779A40779A40779A2D54802D54802D5480
2D548011648D11648D11648D11648D11648D11648D11648D11648D11648D11648D11648D
11648D08648D08648D08648D08648D08648D11648D11648D11648D11648D155883155883
155883155883005B8D005B8D005B8D005B8D0F748F0F748F0F748F0F748F19588F19588F
19588F19588F095B8D095B8D095B8D095B8D095B8D15588315588315588315588316427B
16427B16427B16427B0C6C8A0C6C8A0C6C8A0C6C8A2D54802D54802D54802D548084A8B2
84A8B284A8B284A8B2196493196493196493196493196493115B8F115B8F115B8F115B8F
116C96116C96116C96116C96286091286091286091286091005B8D005B8D005B8D005B8D
276F93276F93276F93276F93095B8D095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83990C6C8A0C6C8A0C6C8A0C6C8A0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F16427B16427B16427B16427B438CA2438CA2438CA2438CA2438CA22B83992B8399
2B83992B8399276F93276F93276F93276F9340779A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000005538A05538A
115B8F115B8F115B8F115B8F16427B16427B16427B16427B05538A05538A05538A05538A
2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93276F93276F93276F93
276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87115B8F115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D15588315588315588315588305538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D076495076495
07649507649507649540779A40779A40779A40779A095B8D095B8D095B8D095B8D155883
1558831558831558832B83992B83992B83992B8399116C96116C96116C96116C9611648D
11648D11648D11648D11648D116C96116C96116C96116C9605538A05538A05538A05538A
28609128609128609128609111648D11648D11648D11648D196493196493196493196493
438CA2438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F11528F11528F
11528F40779A40779A40779A40779A08648D08648D08648D08648D286091286091286091
286091116495116495116495116495116495286091286091286091286091196493196493
196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F93196493196493
1964931964930F748F0F748F0F748F0F748F0F748F0C8E870C8E870C8E870C8E8705538A
05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A005B8D
005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883155883155883155883
11648D11648D11648D11648D1964931964931964931964931964932A2F6C2A2F6C2A2F6C
2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F
19588F19588F40779A40779A40779A40779A28609128609128609128609105538A05538A
05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B05538A
05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93
276F93276F93276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87
115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D155883155883155883155883
15588305538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D
095B8D07649507649507649507649540779A40779A40779A40779A095B8D095B8D095B8D
095B8D095B8D1558831558831558831558832B83992B83992B83992B8399116C96116C96
116C96116C9611648D11648D11648D11648D116C96116C96116C96116C9605538A05538A
05538A05538A05538A28609128609128609128609111648D11648D11648D11648D196493
196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F
11528F11528F11528F11528F40779A40779A40779A40779A08648D08648D08648D08648D
286091286091286091286091116495116495116495116495286091286091286091286091
196493196493196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93
276F931964931964931964931964930F748F0F748F0F748F0F748F0C8E870C8E870C8E87
0C8E8705538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A0C6C8A005B8D005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495
116495116495005B8D005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883
15588315588315588311648D11648D11648D11648D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D
1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C
19588F19588F19588F19588F40779A40779A40779A40779A40779A286091286091286091
28609105538A05538A05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B
16427B05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C286091286091
286091286091276F93276F93276F93276F93095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000028609105538A05538A05538A05538A05538A
115B8F115B8F115B8F115B8F16427B16427B16427B16427B05538A05538A05538A05538A
2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93276F93276F93276F93
276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87115B8F115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D15588315588315588315588305538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D076495076495
07649507649507649540779A40779A40779A40779A095B8D095B8D095B8D095B8D155883
1558831558831558832B83992B83992B83992B8399116C96116C96116C96116C9611648D
11648D11648D11648D11648D116C96116C96116C96116C9605538A05538A05538A05538A
28609128609128609128609111648D11648D11648D11648D196493196493196493196493
438CA2438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F11528F11528F
11528F40779A40779A40779A40779A08648D08648D08648D08648D286091286091286091
286091116495116495116495116495116495286091286091286091286091196493196493
196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F93196493196493
1964931964930F748F0F748F0F748F0F748F0F748F0C8E870C8E870C8E870C8E8705538A
05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A005B8D
005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883155883155883155883
11648D11648D11648D11648D1964931964931964931964931964932A2F6C2A2F6C2A2F6C
2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F
19588F19588F40779A40779A40779A40779A28609128609128609128609105538A05538A
05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B05538A
05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93
276F93276F93276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87
115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D155883155883155883155883
15588305538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D
095B8D07649507649507649507649540779A40779A40779A40779A095B8D095B8D095B8D
095B8D095B8D1558831558831558831558832B83992B83992B83992B8399116C96116C96
116C96116C9611648D11648D11648D11648D116C96116C96116C96116C9605538A05538A
05538A05538A05538A28609128609128609128609111648D11648D11648D11648D196493
196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F
11528F11528F11528F11528F40779A40779A40779A40779A08648D08648D08648D08648D
286091286091286091286091116495116495116495116495286091286091286091286091
196493196493196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93
276F931964931964931964931964930F748F0F748F0F748F0F748F0C8E870C8E870C8E87
0C8E8705538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A0C6C8A005B8D005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495
116495116495005B8D005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883
15588315588315588311648D11648D11648D11648D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D
1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C
19588F19588F19588F19588F40779A40779A40779A40779A40779A286091286091286091
28609105538A05538A05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B
16427B05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C286091286091
286091286091276F93276F93276F93276F93095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000028609128609128609128609105538A05538A05538A05538A05538A
115B8F115B8F115B8F115B8F16427B16427B16427B16427B05538A05538A05538A05538A
2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93276F93276F93276F93
276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87115B8F115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D15588315588315588315588305538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D076495076495
07649507649507649540779A40779A40779A40779A095B8D095B8D095B8D095B8D155883
1558831558831558832B83992B83992B83992B8399116C96116C96116C96116C9611648D
11648D11648D11648D11648D116C96116C96116C96116C9605538A05538A05538A05538A
28609128609128609128609111648D11648D11648D11648D196493196493196493196493
438CA2438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F11528F11528F
11528F40779A40779A40779A40779A08648D08648D08648D08648D286091286091286091
286091116495116495116495116495116495286091286091286091286091196493196493
196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F93196493196493
1964931964930F748F0F748F0F748F0F748F0F748F0C8E870C8E870C8E870C8E8705538A
05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A005B8D
005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883155883155883155883
11648D11648D11648D11648D1964931964931964931964931964932A2F6C2A2F6C2A2F6C
2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F
19588F19588F40779A40779A40779A40779A28609128609128609128609105538A05538A
05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B05538A
05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93
276F93276F93276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87
115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D155883155883155883155883
15588305538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D
095B8D07649507649507649507649540779A40779A40779A40779A095B8D095B8D095B8D
095B8D095B8D1558831558831558831558832B83992B83992B83992B8399116C96116C96
116C96116C9611648D11648D11648D11648D116C96116C96116C96116C9605538A05538A
05538A05538A05538A28609128609128609128609111648D11648D11648D11648D196493
196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F
11528F11528F11528F11528F40779A40779A40779A40779A08648D08648D08648D08648D
286091286091286091286091116495116495116495116495286091286091286091286091
196493196493196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93
276F931964931964931964931964930F748F0F748F0F748F0F748F0C8E870C8E870C8E87
0C8E8705538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A0C6C8A005B8D005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495
116495116495005B8D005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883
15588315588315588311648D11648D11648D11648D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D
1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C
19588F19588F19588F19588F40779A40779A40779A40779A40779A286091286091286091
28609105538A05538A05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B
16427B05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C286091286091
286091286091276F93276F93276F93276F93095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000040779A
40779A40779A40779A28609128609128609128609105538A05538A05538A05538A05538A
115B8F115B8F115B8F115B8F16427B16427B16427B16427B05538A05538A05538A05538A
2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93276F93276F93276F93
276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87115B8F115B8F115B8F
115B8F115B8F2A729D2A729D2A729D2A729D15588315588315588315588305538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D076495076495
07649507649507649540779A40779A40779A40779A095B8D095B8D095B8D095B8D155883
1558831558831558832B83992B83992B83992B8399116C96116C96116C96116C9611648D
11648D11648D11648D11648D116C96116C96116C96116C9605538A05538A05538A05538A
28609128609128609128609111648D11648D11648D11648D196493196493196493196493
438CA2438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F11528F11528F
11528F40779A40779A40779A40779A08648D08648D08648D08648D286091286091286091
286091116495116495116495116495116495286091286091286091286091196493196493
196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F93196493196493
1964931964930F748F0F748F0F748F0F748F0F748F0C8E870C8E870C8E870C8E8705538A
05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A005B8D
005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A116495116495116495116495
005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883155883155883155883
11648D11648D11648D11648D1964931964931964931964931964932A2F6C2A2F6C2A2F6C
2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D155883155883155883
1558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C19588F19588F
19588F19588F40779A40779A40779A40779A28609128609128609128609105538A05538A
05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B16427B16427B05538A
05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C286091286091286091286091276F93
276F93276F93276F93095B8D095B8D095B8D095B8D0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F2A729D2A729D2A729D2A729D0C8E870C8E870C8E870C8E87
115B8F115B8F115B8F115B8F2A729D2A729D2A729D2A729D155883155883155883155883
15588305538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D
095B8D07649507649507649507649540779A40779A40779A40779A095B8D095B8D095B8D
095B8D095B8D1558831558831558831558832B83992B83992B83992B8399116C96116C96
116C96116C9611648D11648D11648D11648D116C96116C96116C96116C9605538A05538A
05538A05538A05538A28609128609128609128609111648D11648D11648D11648D196493
196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93276F9311528F
11528F11528F11528F11528F40779A40779A40779A40779A08648D08648D08648D08648D
286091286091286091286091116495116495116495116495286091286091286091286091
196493196493196493196493196493438CA2438CA2438CA2438CA2276F93276F93276F93
276F931964931964931964931964930F748F0F748F0F748F0F748F0C8E870C8E870C8E87
0C8E8705538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A
0C6C8A0C6C8A005B8D005B8D005B8D005B8D0C6C8A0C6C8A0C6C8A0C6C8A116495116495
116495116495005B8D005B8D005B8D005B8D005B8D2B83992B83992B83992B8399155883
15588315588315588311648D11648D11648D11648D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D
1558831558831558831558830E7C8D0E7C8D0E7C8D0E7C8D2A2F6C2A2F6C2A2F6C2A2F6C
19588F19588F19588F19588F40779A40779A40779A40779A40779A286091286091286091
28609105538A05538A05538A05538A115B8F115B8F115B8F115B8F16427B16427B16427B
16427B05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C286091286091
286091286091276F93276F93276F93276F93095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000084A8B284A8B284A8B284A8B22D5480
2D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D11648D11648D11648D
40779A40779A40779A40779A044582044582044582044582276F93276F93276F93276F93
11648D11648D11648D11648D438CA2438CA2438CA2438CA2286091286091286091286091
2860910C8E870C8E870C8E870C8E87076495076495076495076495196493196493196493
196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A005B8D005B8D005B8D
005B8D005B8D16427B16427B16427B16427B076495076495076495076495438CA2438CA2
438CA2438CA20F748F0F748F0F748F0F748F2860912860912860912860910F748F0F748F
0F748F0F748F0F748F155883155883155883155883276F93276F93276F93276F93438CA2
438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93276F93276F93438CA2
438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493196493196493
276F93276F93276F93276F9311528F11528F11528F11528F155883155883155883155883
11648D11648D11648D11648D11648D276F93276F93276F93276F9308648D08648D08648D
08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F40779A40779A40779A40779A40779A
40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609105538A
05538A05538A05538A2B83992B83992B83992B83992B8399155883155883155883155883
2B83992B83992B83992B8399196493196493196493196493044582044582044582044582
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802B83992B83992B8399
2B83992D54802D54802D54802D548028609128609128609128609105538A05538A05538A
05538A2A2F6C2A2F6C2A2F6C2A2F6C15588315588315588315588315588384A8B284A8B2
84A8B284A8B22D54802D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D
11648D11648D40779A40779A40779A40779A044582044582044582044582044582276F93
276F93276F93276F9311648D11648D11648D11648D438CA2438CA2438CA2438CA2286091
2860912860912860910C8E870C8E870C8E870C8E87076495076495076495076495076495
196493196493196493196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A
005B8D005B8D005B8D005B8D16427B16427B16427B16427B076495076495076495076495
076495438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F286091286091286091
2860910F748F0F748F0F748F0F748F155883155883155883155883276F93276F93276F93
276F93276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93
276F93276F93438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493
196493196493196493276F93276F93276F93276F9311528F11528F11528F11528F155883
15588315588315588311648D11648D11648D11648D276F93276F93276F93276F9308648D
08648D08648D08648D08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F93276F93276F93276F932B83992B83992B8399
2B8399276F93276F93276F93276F93115B8F115B8F115B8F115B8F40779A40779A40779A
40779A40779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609105538A05538A05538A05538A2B83992B83992B83992B8399155883155883
1558831558832B83992B83992B83992B83992B8399196493196493196493196493044582
0445820445820445825B90A55B90A55B90A55B90A52D54802D54802D54802D54802B8399
2B83992B83992B83992D54802D54802D54802D54802D5480286091286091286091286091
05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
84A8B284A8B284A8B284A8B22D54802D54802D54802D54802D5480438CA2438CA2438CA2
438CA211648D11648D11648D11648D40779A40779A40779A40779A044582044582044582
044582276F93276F93276F93276F9311648D11648D11648D11648D11648D438CA2438CA2
438CA2438CA22860912860912860912860910C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000015588315588315588384A8B284A8B284A8B284A8B22D5480
2D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D11648D11648D11648D
40779A40779A40779A40779A044582044582044582044582276F93276F93276F93276F93
11648D11648D11648D11648D438CA2438CA2438CA2438CA2286091286091286091286091
2860910C8E870C8E870C8E870C8E87076495076495076495076495196493196493196493
196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A005B8D005B8D005B8D
005B8D005B8D16427B16427B16427B16427B076495076495076495076495438CA2438CA2
438CA2438CA20F748F0F748F0F748F0F748F2860912860912860912860910F748F0F748F
0F748F0F748F0F748F155883155883155883155883276F93276F93276F93276F93438CA2
438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93276F93276F93438CA2
438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493196493196493
276F93276F93276F93276F9311528F11528F11528F11528F155883155883155883155883
11648D11648D11648D11648D11648D276F93276F93276F93276F9308648D08648D08648D
08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F40779A40779A40779A40779A40779A
40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609105538A
05538A05538A05538A2B83992B83992B83992B83992B8399155883155883155883155883
2B83992B83992B83992B8399196493196493196493196493044582044582044582044582
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802B83992B83992B8399
2B83992D54802D54802D54802D548028609128609128609128609105538A05538A05538A
05538A2A2F6C2A2F6C2A2F6C2A2F6C15588315588315588315588315588384A8B284A8B2
84A8B284A8B22D54802D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D
11648D11648D40779A40779A40779A40779A044582044582044582044582044582276F93
276F93276F93276F9311648D11648D11648D11648D438CA2438CA2438CA2438CA2286091
2860912860912860910C8E870C8E870C8E870C8E87076495076495076495076495076495
196493196493196493196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A
005B8D005B8D005B8D005B8D16427B16427B16427B16427B076495076495076495076495
076495438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F286091286091286091
2860910F748F0F748F0F748F0F748F155883155883155883155883276F93276F93276F93
276F93276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93
276F93276F93438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493
196493196493196493276F93276F93276F93276F9311528F11528F11528F11528F155883
15588315588315588311648D11648D11648D11648D276F93276F93276F93276F9308648D
08648D08648D08648D08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F93276F93276F93276F932B83992B83992B8399
2B8399276F93276F93276F93276F93115B8F115B8F115B8F115B8F40779A40779A40779A
40779A40779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609105538A05538A05538A05538A2B83992B83992B83992B8399155883155883
1558831558832B83992B83992B83992B83992B8399196493196493196493196493044582
0445820445820445825B90A55B90A55B90A55B90A52D54802D54802D54802D54802B8399
2B83992B83992B83992D54802D54802D54802D54802D5480286091286091286091286091
05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
84A8B284A8B284A8B284A8B22D54802D54802D54802D54802D5480438CA2438CA2438CA2
438CA211648D11648D11648D11648D40779A40779A40779A40779A044582044582044582
044582276F93276F93276F93276F9311648D11648D11648D11648D11648D438CA2438CA2
438CA2438CA22860912860912860912860910C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
2A2F6C2A2F6C2A2F6C15588315588315588315588384A8B284A8B284A8B284A8B22D5480
2D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D11648D11648D11648D
40779A40779A40779A40779A044582044582044582044582276F93276F93276F93276F93
11648D11648D11648D11648D438CA2438CA2438CA2438CA2286091286091286091286091
2860910C8E870C8E870C8E870C8E87076495076495076495076495196493196493196493
196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A005B8D005B8D005B8D
005B8D005B8D16427B16427B16427B16427B076495076495076495076495438CA2438CA2
438CA2438CA20F748F0F748F0F748F0F748F2860912860912860912860910F748F0F748F
0F748F0F748F0F748F155883155883155883155883276F93276F93276F93276F93438CA2
438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93276F93276F93438CA2
438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493196493196493
276F93276F93276F93276F9311528F11528F11528F11528F155883155883155883155883
11648D11648D11648D11648D11648D276F93276F93276F93276F9308648D08648D08648D
08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F40779A40779A40779A40779A40779A
40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609105538A
05538A05538A05538A2B83992B83992B83992B83992B8399155883155883155883155883
2B83992B83992B83992B8399196493196493196493196493044582044582044582044582
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802B83992B83992B8399
2B83992D54802D54802D54802D548028609128609128609128609105538A05538A05538A
05538A2A2F6C2A2F6C2A2F6C2A2F6C15588315588315588315588315588384A8B284A8B2
84A8B284A8B22D54802D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D
11648D11648D40779A40779A40779A40779A044582044582044582044582044582276F93
276F93276F93276F9311648D11648D11648D11648D438CA2438CA2438CA2438CA2286091
2860912860912860910C8E870C8E870C8E870C8E87076495076495076495076495076495
196493196493196493196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A
005B8D005B8D005B8D005B8D16427B16427B16427B16427B076495076495076495076495
076495438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F286091286091286091
2860910F748F0F748F0F748F0F748F155883155883155883155883276F93276F93276F93
276F93276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93
276F93276F93438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493
196493196493196493276F93276F93276F93276F9311528F11528F11528F11528F155883
15588315588315588311648D11648D11648D11648D276F93276F93276F93276F9308648D
08648D08648D08648D08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F93276F93276F93276F932B83992B83992B8399
2B8399276F93276F93276F93276F93115B8F115B8F115B8F115B8F40779A40779A40779A
40779A40779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609105538A05538A05538A05538A2B83992B83992B83992B8399155883155883
1558831558832B83992B83992B83992B83992B8399196493196493196493196493044582
0445820445820445825B90A55B90A55B90A55B90A52D54802D54802D54802D54802B8399
2B83992B83992B83992D54802D54802D54802D54802D5480286091286091286091286091
05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
84A8B284A8B284A8B284A8B22D54802D54802D54802D54802D5480438CA2438CA2438CA2
438CA211648D11648D11648D11648D40779A40779A40779A40779A044582044582044582
044582276F93276F93276F93276F9311648D11648D11648D11648D11648D438CA2438CA2
438CA2438CA22860912860912860912860910C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000005538A05538A05538A2A2F6C
2A2F6C2A2F6C2A2F6C15588315588315588315588384A8B284A8B284A8B284A8B22D5480
2D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D11648D11648D11648D
40779A40779A40779A40779A044582044582044582044582276F93276F93276F93276F93
11648D11648D11648D11648D438CA2438CA2438CA2438CA2286091286091286091286091
2860910C8E870C8E870C8E870C8E87076495076495076495076495196493196493196493
196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A005B8D005B8D005B8D
005B8D005B8D16427B16427B16427B16427B076495076495076495076495438CA2438CA2
438CA2438CA20F748F0F748F0F748F0F748F2860912860912860912860910F748F0F748F
0F748F0F748F0F748F155883155883155883155883276F93276F93276F93276F93438CA2
438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93276F93276F93438CA2
438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493196493196493
276F93276F93276F93276F9311528F11528F11528F11528F155883155883155883155883
11648D11648D11648D11648D11648D276F93276F93276F93276F9308648D08648D08648D
08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F0E7C8D0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F932B83992B83992B83992B8399276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F40779A40779A40779A40779A40779A
40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A28609128609128609128609105538A
05538A05538A05538A2B83992B83992B83992B83992B8399155883155883155883155883
2B83992B83992B83992B8399196493196493196493196493044582044582044582044582
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802B83992B83992B8399
2B83992D54802D54802D54802D548028609128609128609128609105538A05538A05538A
05538A2A2F6C2A2F6C2A2F6C2A2F6C15588315588315588315588315588384A8B284A8B2
84A8B284A8B22D54802D54802D54802D5480438CA2438CA2438CA2438CA211648D11648D
11648D11648D40779A40779A40779A40779A044582044582044582044582044582276F93
276F93276F93276F9311648D11648D11648D11648D438CA2438CA2438CA2438CA2286091
2860912860912860910C8E870C8E870C8E870C8E87076495076495076495076495076495
196493196493196493196493115B8F115B8F115B8F115B8F40779A40779A40779A40779A
005B8D005B8D005B8D005B8D16427B16427B16427B16427B076495076495076495076495
076495438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F286091286091286091
2860910F748F0F748F0F748F0F748F155883155883155883155883276F93276F93276F93
276F93276F93438CA2438CA2438CA2438CA20F748F0F748F0F748F0F748F276F93276F93
276F93276F93438CA2438CA2438CA2438CA2116C96116C96116C96116C96196493196493
196493196493196493276F93276F93276F93276F9311528F11528F11528F11528F155883
15588315588315588311648D11648D11648D11648D276F93276F93276F93276F9308648D
08648D08648D08648D08648D1164951164951164951164950E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F0E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93276F93
276F93276F93276F93276F93276F93276F93276F93276F93276F932B83992B83992B8399
2B8399276F93276F93276F93276F93115B8F115B8F115B8F115B8F40779A40779A40779A
40779A40779A40779A40779A40779A40779A0C6C8A0C6C8A0C6C8A0C6C8A286091286091
28609128609105538A05538A05538A05538A2B83992B83992B83992B8399155883155883
1558831558832B83992B83992B83992B83992B8399196493196493196493196493044582
0445820445820445825B90A55B90A55B90A55B90A52D54802D54802D54802D54802B8399
2B83992B83992B83992D54802D54802D54802D54802D5480286091286091286091286091
05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C155883155883155883155883
84A8B284A8B284A8B284A8B22D54802D54802D54802D54802D5480438CA2438CA2438CA2
438CA211648D11648D11648D11648D40779A40779A40779A40779A044582044582044582
044582276F93276F93276F93276F9311648D11648D11648D11648D11648D438CA2438CA2
438CA2438CA22860912860912860912860910C8E87000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000286091116495116495116495116495116495076495
07649507649507649505538A05538A05538A05538A116495116495116495116495076495
07649507649507649516427B16427B16427B16427B196493196493196493196493196493
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C116C96116C96116C96116C962D54802D54802D54802D548011528F11528F11528F
11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F095B8D095B8D095B8D
095B8D095B8D28609128609128609128609105538A05538A05538A05538A155883155883
1558831558832D54802D54802D54802D54800F748F0F748F0F748F0F748F2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493196493155883
155883155883155883045B84045B84045B84045B842B83992B83992B83992B8399286091
286091286091286091286091116C96116C96116C96116C96155883155883155883155883
0F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B16427B16427B16427B
276F93276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
19649315588315588315588315588315588319588F19588F19588F19588F438CA2438CA2
438CA2438CA240779A40779A40779A40779A28609128609128609128609111648D11648D
11648D11648D116C96116C96116C96116C96116C96116495116495116495116495116495
1164951164951164955B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F11648D
11648D11648D11648D40779A40779A40779A40779A40779A116495116495116495116495
1558831558831558831558832A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B8399155883155883155883155883286091286091286091286091116495116495116495
11649507649507649507649507649505538A05538A05538A05538A05538A116495116495
11649511649507649507649507649507649516427B16427B16427B16427B196493196493
1964931964935B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C116C96116C96116C96116C962D54802D54802D54802D54802D5480
11528F11528F11528F11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F
095B8D095B8D095B8D095B8D28609128609128609128609105538A05538A05538A05538A
05538A1558831558831558831558832D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493
196493196493155883155883155883155883045B84045B84045B84045B842B83992B8399
2B83992B8399286091286091286091286091116C96116C96116C96116C96155883155883
1558831558831558830F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B
16427B16427B16427B276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B8399
2B83992B83992B83992B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649315588315588315588315588319588F19588F19588F19588F
438CA2438CA2438CA2438CA2438CA240779A40779A40779A40779A286091286091286091
28609111648D11648D11648D11648D116C96116C96116C96116C96116495116495116495
1164951164951164951164951164951164955B90A55B90A55B90A55B90A50F748F0F748F
0F748F0F748F11648D11648D11648D11648D40779A40779A40779A40779A116495116495
1164951164951558831558831558831558831558832A729D2A729D2A729D2A729D2A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B8399155883155883155883155883155883286091286091286091286091
11649511649511649511649507649507649507649507649505538A05538A05538A05538A
11649511649511649511649507649507649507649507649507649516427B16427B16427B
16427B1964931964931964931964935B90A55B90A55B90A55B90A52D54802D54802D5480
2D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D095B8D196493196493
1964931964932A2F6C2A2F6C2A2F6C2A2F6C116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000155883286091286091286091286091116495116495116495116495116495076495
07649507649507649505538A05538A05538A05538A116495116495116495116495076495
07649507649507649516427B16427B16427B16427B196493196493196493196493196493
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C116C96116C96116C96116C962D54802D54802D54802D548011528F11528F11528F
11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F095B8D095B8D095B8D
095B8D095B8D28609128609128609128609105538A05538A05538A05538A155883155883
1558831558832D54802D54802D54802D54800F748F0F748F0F748F0F748F2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493196493155883
155883155883155883045B84045B84045B84045B842B83992B83992B83992B8399286091
286091286091286091286091116C96116C96116C96116C96155883155883155883155883
0F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B16427B16427B16427B
276F93276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
19649315588315588315588315588315588319588F19588F19588F19588F438CA2438CA2
438CA2438CA240779A40779A40779A40779A28609128609128609128609111648D11648D
11648D11648D116C96116C96116C96116C96116C96116495116495116495116495116495
1164951164951164955B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F11648D
11648D11648D11648D40779A40779A40779A40779A40779A116495116495116495116495
1558831558831558831558832A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B8399155883155883155883155883286091286091286091286091116495116495116495
11649507649507649507649507649505538A05538A05538A05538A05538A116495116495
11649511649507649507649507649507649516427B16427B16427B16427B196493196493
1964931964935B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C116C96116C96116C96116C962D54802D54802D54802D54802D5480
11528F11528F11528F11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F
095B8D095B8D095B8D095B8D28609128609128609128609105538A05538A05538A05538A
05538A1558831558831558831558832D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493
196493196493155883155883155883155883045B84045B84045B84045B842B83992B8399
2B83992B8399286091286091286091286091116C96116C96116C96116C96155883155883
1558831558831558830F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B
16427B16427B16427B276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B8399
2B83992B83992B83992B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649315588315588315588315588319588F19588F19588F19588F
438CA2438CA2438CA2438CA2438CA240779A40779A40779A40779A286091286091286091
28609111648D11648D11648D11648D116C96116C96116C96116C96116495116495116495
1164951164951164951164951164951164955B90A55B90A55B90A55B90A50F748F0F748F
0F748F0F748F11648D11648D11648D11648D40779A40779A40779A40779A116495116495
1164951164951558831558831558831558831558832A729D2A729D2A729D2A729D2A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B8399155883155883155883155883155883286091286091286091286091
11649511649511649511649507649507649507649507649505538A05538A05538A05538A
11649511649511649511649507649507649507649507649507649516427B16427B16427B
16427B1964931964931964931964935B90A55B90A55B90A55B90A52D54802D54802D5480
2D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D095B8D196493196493
1964931964932A2F6C2A2F6C2A2F6C2A2F6C116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002B8399155883155883
155883155883286091286091286091286091116495116495116495116495116495076495
07649507649507649505538A05538A05538A05538A116495116495116495116495076495
07649507649507649516427B16427B16427B16427B196493196493196493196493196493
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C116C96116C96116C96116C962D54802D54802D54802D548011528F11528F11528F
11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F095B8D095B8D095B8D
095B8D095B8D28609128609128609128609105538A05538A05538A05538A155883155883
1558831558832D54802D54802D54802D54800F748F0F748F0F748F0F748F2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493196493155883
155883155883155883045B84045B84045B84045B842B83992B83992B83992B8399286091
286091286091286091286091116C96116C96116C96116C96155883155883155883155883
0F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B16427B16427B16427B
276F93276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
19649315588315588315588315588315588319588F19588F19588F19588F438CA2438CA2
438CA2438CA240779A40779A40779A40779A28609128609128609128609111648D11648D
11648D11648D116C96116C96116C96116C96116C96116495116495116495116495116495
1164951164951164955B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F11648D
11648D11648D11648D40779A40779A40779A40779A40779A116495116495116495116495
1558831558831558831558832A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B8399155883155883155883155883286091286091286091286091116495116495116495
11649507649507649507649507649505538A05538A05538A05538A05538A116495116495
11649511649507649507649507649507649516427B16427B16427B16427B196493196493
1964931964935B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C116C96116C96116C96116C962D54802D54802D54802D54802D5480
11528F11528F11528F11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F
095B8D095B8D095B8D095B8D28609128609128609128609105538A05538A05538A05538A
05538A1558831558831558831558832D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493
196493196493155883155883155883155883045B84045B84045B84045B842B83992B8399
2B83992B8399286091286091286091286091116C96116C96116C96116C96155883155883
1558831558831558830F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B
16427B16427B16427B276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B8399
2B83992B83992B83992B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649315588315588315588315588319588F19588F19588F19588F
438CA2438CA2438CA2438CA2438CA240779A40779A40779A40779A286091286091286091
28609111648D11648D11648D11648D116C96116C96116C96116C96116495116495116495
1164951164951164951164951164951164955B90A55B90A55B90A55B90A50F748F0F748F
0F748F0F748F11648D11648D11648D11648D40779A40779A40779A40779A116495116495
1164951164951558831558831558831558831558832A729D2A729D2A729D2A729D2A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B8399155883155883155883155883155883286091286091286091286091
11649511649511649511649507649507649507649507649505538A05538A05538A05538A
11649511649511649511649507649507649507649507649507649516427B16427B16427B
16427B1964931964931964931964935B90A55B90A55B90A55B90A52D54802D54802D5480
2D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D095B8D196493196493
1964931964932A2F6C2A2F6C2A2F6C2A2F6C116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000002B83992B83992B83992B8399155883155883
155883155883286091286091286091286091116495116495116495116495116495076495
07649507649507649505538A05538A05538A05538A116495116495116495116495076495
07649507649507649516427B16427B16427B16427B196493196493196493196493196493
5B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D54802D54802D5480
095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C116C96116C96116C96116C962D54802D54802D54802D548011528F11528F11528F
11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F095B8D095B8D095B8D
095B8D095B8D28609128609128609128609105538A05538A05538A05538A155883155883
1558831558832D54802D54802D54802D54800F748F0F748F0F748F0F748F2A2F6C2A2F6C
2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493196493155883
155883155883155883045B84045B84045B84045B842B83992B83992B83992B8399286091
286091286091286091286091116C96116C96116C96116C96155883155883155883155883
0F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B16427B16427B16427B
276F93276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B83992B83992B8399
2B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A196493196493196493
19649315588315588315588315588315588319588F19588F19588F19588F438CA2438CA2
438CA2438CA240779A40779A40779A40779A28609128609128609128609111648D11648D
11648D11648D116C96116C96116C96116C96116C96116495116495116495116495116495
1164951164951164955B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F11648D
11648D11648D11648D40779A40779A40779A40779A40779A116495116495116495116495
1558831558831558831558832A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D
0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B8399
2B8399155883155883155883155883286091286091286091286091116495116495116495
11649507649507649507649507649505538A05538A05538A05538A05538A116495116495
11649511649507649507649507649507649516427B16427B16427B16427B196493196493
1964931964935B90A55B90A55B90A55B90A52D54802D54802D54802D54802D54802D5480
2D54802D54802D5480095B8D095B8D095B8D095B8D1964931964931964931964932A2F6C
2A2F6C2A2F6C2A2F6C116C96116C96116C96116C962D54802D54802D54802D54802D5480
11528F11528F11528F11528F438CA2438CA2438CA2438CA219588F19588F19588F19588F
095B8D095B8D095B8D095B8D28609128609128609128609105538A05538A05538A05538A
05538A1558831558831558831558832D54802D54802D54802D54800F748F0F748F0F748F
0F748F2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F93196493196493196493
196493196493155883155883155883155883045B84045B84045B84045B842B83992B8399
2B83992B8399286091286091286091286091116C96116C96116C96116C96155883155883
1558831558831558830F748F0F748F0F748F0F748F40779A40779A40779A40779A16427B
16427B16427B16427B276F93276F93276F93276F93095B8D095B8D095B8D095B8D2B8399
2B83992B83992B83992B83992D54802D54802D54802D54800C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649315588315588315588315588319588F19588F19588F19588F
438CA2438CA2438CA2438CA2438CA240779A40779A40779A40779A286091286091286091
28609111648D11648D11648D11648D116C96116C96116C96116C96116495116495116495
1164951164951164951164951164951164955B90A55B90A55B90A55B90A50F748F0F748F
0F748F0F748F11648D11648D11648D11648D40779A40779A40779A40779A116495116495
1164951164951558831558831558831558831558832A729D2A729D2A729D2A729D2A729D
2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B8399155883155883155883155883155883286091286091286091286091
11649511649511649511649507649507649507649507649505538A05538A05538A05538A
11649511649511649511649507649507649507649507649507649516427B16427B16427B
16427B1964931964931964931964935B90A55B90A55B90A55B90A52D54802D54802D5480
2D54802D54802D54802D54802D5480095B8D095B8D095B8D095B8D095B8D196493196493
1964931964932A2F6C2A2F6C2A2F6C2A2F6C116C96000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000015588315588315588315588384A8B284A8B284A8B284A8B219588F19588F
19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F196493
19649319649319649340779A40779A40779A40779A84A8B284A8B284A8B284A8B22A729D
2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A40779A40779A
2A729D2A729D2A729D2A729D19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964932B83992B83992B83992B8399438CA2438CA2438CA2438CA2
438CA22B83992B83992B83992B839911648D11648D11648D11648D0E7C8D0E7C8D0E7C8D
0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2085B95085B95085B95
085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D085B95085B95
085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D5B90A55B90A5
5B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A05538A11648D
11648D11648D11648D1964931964931964931964935B90A55B90A55B90A55B90A5044582
0445820445820445820445822D54802D54802D54802D5480155883155883155883155883
115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F115B8F115B8F115B8F
196493196493196493196493196493196493196493196493196493095B8D095B8D095B8D
095B8D2A729D2A729D2A729D2A729D116495116495116495116495438CA2438CA2438CA2
438CA2286091286091286091286091286091276F93276F93276F93276F9340779A40779A
40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B16427B11648D11648D
11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B16427B095B8D
095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D08648D08648D2A2F6C
2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D005B8D196493196493196493196493
2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F19588F19588F19588F
19649319649319649319649315588315588315588315588315588384A8B284A8B284A8B2
84A8B219588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F19649319649319649319649340779A40779A40779A40779A40779A84A8B284A8B2
84A8B284A8B22A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A
40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F19588F19588F0C6C8A
0C6C8A0C6C8A0C6C8A1964931964931964931964932B83992B83992B83992B8399438CA2
438CA2438CA2438CA22B83992B83992B83992B839911648D11648D11648D11648D11648D
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2
085B95085B95085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D
2A729D085B95085B95085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D
11648D5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A05538A11648D11648D11648D11648D1964931964931964931964935B90A55B90A5
5B90A55B90A50445820445820445820445822D54802D54802D54802D5480155883155883
155883155883155883115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F196493196493196493196493196493196493196493196493095B8D
095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D116495116495116495116495
438CA2438CA2438CA2438CA2286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B
16427B11648D11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B
16427B095B8D095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D
08648D08648D2A2F6C2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D196493196493
1964931964932A729D2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F
19588F19588F19588F19649319649319649319649315588315588315588315588384A8B2
84A8B284A8B284A8B219588F19588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
84A8B284A8B284A8B284A8B22A729D2A729D2A729D2A729D2A729D2B83992B83992B8399
2B839940779A40779A40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F
19588F0C6C8A0C6C8A0C6C8A0C6C8A1964931964931964931964931964932B83992B8399
2B83992B8399438CA2438CA2438CA2438CA22B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000196493196493
19649319649315588315588315588315588384A8B284A8B284A8B284A8B219588F19588F
19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F196493
19649319649319649340779A40779A40779A40779A84A8B284A8B284A8B284A8B22A729D
2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A40779A40779A
2A729D2A729D2A729D2A729D19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964932B83992B83992B83992B8399438CA2438CA2438CA2438CA2
438CA22B83992B83992B83992B839911648D11648D11648D11648D0E7C8D0E7C8D0E7C8D
0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2085B95085B95085B95
085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D085B95085B95
085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D5B90A55B90A5
5B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A05538A11648D
11648D11648D11648D1964931964931964931964935B90A55B90A55B90A55B90A5044582
0445820445820445820445822D54802D54802D54802D5480155883155883155883155883
115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F115B8F115B8F115B8F
196493196493196493196493196493196493196493196493196493095B8D095B8D095B8D
095B8D2A729D2A729D2A729D2A729D116495116495116495116495438CA2438CA2438CA2
438CA2286091286091286091286091286091276F93276F93276F93276F9340779A40779A
40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B16427B11648D11648D
11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B16427B095B8D
095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D08648D08648D2A2F6C
2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D005B8D196493196493196493196493
2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F19588F19588F19588F
19649319649319649319649315588315588315588315588315588384A8B284A8B284A8B2
84A8B219588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F19649319649319649319649340779A40779A40779A40779A40779A84A8B284A8B2
84A8B284A8B22A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A
40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F19588F19588F0C6C8A
0C6C8A0C6C8A0C6C8A1964931964931964931964932B83992B83992B83992B8399438CA2
438CA2438CA2438CA22B83992B83992B83992B839911648D11648D11648D11648D11648D
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2
085B95085B95085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D
2A729D085B95085B95085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D
11648D5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A05538A11648D11648D11648D11648D1964931964931964931964935B90A55B90A5
5B90A55B90A50445820445820445820445822D54802D54802D54802D5480155883155883
155883155883155883115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F196493196493196493196493196493196493196493196493095B8D
095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D116495116495116495116495
438CA2438CA2438CA2438CA2286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B
16427B11648D11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B
16427B095B8D095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D
08648D08648D2A2F6C2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D196493196493
1964931964932A729D2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F
19588F19588F19588F19649319649319649319649315588315588315588315588384A8B2
84A8B284A8B284A8B219588F19588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
84A8B284A8B284A8B284A8B22A729D2A729D2A729D2A729D2A729D2B83992B83992B8399
2B839940779A40779A40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F
19588F0C6C8A0C6C8A0C6C8A0C6C8A1964931964931964931964931964932B83992B8399
2B83992B8399438CA2438CA2438CA2438CA22B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000019588F19588F19588F196493196493
19649319649315588315588315588315588384A8B284A8B284A8B284A8B219588F19588F
19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F196493
19649319649319649340779A40779A40779A40779A84A8B284A8B284A8B284A8B22A729D
2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A40779A40779A
2A729D2A729D2A729D2A729D19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964932B83992B83992B83992B8399438CA2438CA2438CA2438CA2
438CA22B83992B83992B83992B839911648D11648D11648D11648D0E7C8D0E7C8D0E7C8D
0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2085B95085B95085B95
085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D085B95085B95
085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D5B90A55B90A5
5B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A05538A11648D
11648D11648D11648D1964931964931964931964935B90A55B90A55B90A55B90A5044582
0445820445820445820445822D54802D54802D54802D5480155883155883155883155883
115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F115B8F115B8F115B8F
196493196493196493196493196493196493196493196493196493095B8D095B8D095B8D
095B8D2A729D2A729D2A729D2A729D116495116495116495116495438CA2438CA2438CA2
438CA2286091286091286091286091286091276F93276F93276F93276F9340779A40779A
40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B16427B11648D11648D
11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B16427B095B8D
095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D08648D08648D2A2F6C
2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D005B8D196493196493196493196493
2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F19588F19588F19588F
19649319649319649319649315588315588315588315588315588384A8B284A8B284A8B2
84A8B219588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F19649319649319649319649340779A40779A40779A40779A40779A84A8B284A8B2
84A8B284A8B22A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A
40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F19588F19588F0C6C8A
0C6C8A0C6C8A0C6C8A1964931964931964931964932B83992B83992B83992B8399438CA2
438CA2438CA2438CA22B83992B83992B83992B839911648D11648D11648D11648D11648D
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2
085B95085B95085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D
2A729D085B95085B95085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D
11648D5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A05538A11648D11648D11648D11648D1964931964931964931964935B90A55B90A5
5B90A55B90A50445820445820445820445822D54802D54802D54802D5480155883155883
155883155883155883115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F196493196493196493196493196493196493196493196493095B8D
095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D116495116495116495116495
438CA2438CA2438CA2438CA2286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B
16427B11648D11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B
16427B095B8D095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D
08648D08648D2A2F6C2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D196493196493
1964931964932A729D2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F
19588F19588F19588F19649319649319649319649315588315588315588315588384A8B2
84A8B284A8B284A8B219588F19588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
84A8B284A8B284A8B284A8B22A729D2A729D2A729D2A729D2A729D2B83992B83992B8399
2B839940779A40779A40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F
19588F0C6C8A0C6C8A0C6C8A0C6C8A1964931964931964931964931964932B83992B8399
2B83992B8399438CA2438CA2438CA2438CA22B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000095B8D095B8D19588F19588F19588F19588F19588F196493196493
19649319649315588315588315588315588384A8B284A8B284A8B284A8B219588F19588F
19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F0F748F196493
19649319649319649340779A40779A40779A40779A84A8B284A8B284A8B284A8B22A729D
2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A40779A40779A
2A729D2A729D2A729D2A729D19588F19588F19588F19588F0C6C8A0C6C8A0C6C8A0C6C8A
1964931964931964931964932B83992B83992B83992B8399438CA2438CA2438CA2438CA2
438CA22B83992B83992B83992B839911648D11648D11648D11648D0E7C8D0E7C8D0E7C8D
0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2085B95085B95085B95
085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D085B95085B95
085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D11648D5B90A55B90A5
5B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A05538A11648D
11648D11648D11648D1964931964931964931964935B90A55B90A55B90A55B90A5044582
0445820445820445820445822D54802D54802D54802D5480155883155883155883155883
115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F115B8F115B8F115B8F
196493196493196493196493196493196493196493196493196493095B8D095B8D095B8D
095B8D2A729D2A729D2A729D2A729D116495116495116495116495438CA2438CA2438CA2
438CA2286091286091286091286091286091276F93276F93276F93276F9340779A40779A
40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B16427B11648D11648D
11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B16427B095B8D
095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D08648D08648D2A2F6C
2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D005B8D196493196493196493196493
2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F19588F19588F19588F
19649319649319649319649315588315588315588315588315588384A8B284A8B284A8B2
84A8B219588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F
0F748F19649319649319649319649340779A40779A40779A40779A40779A84A8B284A8B2
84A8B284A8B22A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A
40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F19588F19588F0C6C8A
0C6C8A0C6C8A0C6C8A1964931964931964931964932B83992B83992B83992B8399438CA2
438CA2438CA2438CA22B83992B83992B83992B839911648D11648D11648D11648D11648D
0E7C8D0E7C8D0E7C8D0E7C8D286091286091286091286091438CA2438CA2438CA2438CA2
085B95085B95085B95085B9508648D08648D08648D08648D2A729D2A729D2A729D2A729D
2A729D085B95085B95085B95085B952A2F6C2A2F6C2A2F6C2A2F6C11648D11648D11648D
11648D5B90A55B90A55B90A55B90A50E7C8D0E7C8D0E7C8D0E7C8D05538A05538A05538A
05538A05538A11648D11648D11648D11648D1964931964931964931964935B90A55B90A5
5B90A55B90A50445820445820445820445822D54802D54802D54802D5480155883155883
155883155883155883115B8F115B8F115B8F115B8F276F93276F93276F93276F93115B8F
115B8F115B8F115B8F196493196493196493196493196493196493196493196493095B8D
095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D116495116495116495116495
438CA2438CA2438CA2438CA2286091286091286091286091276F93276F93276F93276F93
40779A40779A40779A40779A40779A2A729D2A729D2A729D2A729D16427B16427B16427B
16427B11648D11648D11648D11648D11648D11648D11648D11648D16427B16427B16427B
16427B095B8D095B8D095B8D095B8D095B8D438CA2438CA2438CA2438CA208648D08648D
08648D08648D2A2F6C2A2F6C2A2F6C2A2F6C005B8D005B8D005B8D005B8D196493196493
1964931964932A729D2A729D2A729D2A729D2A729D095B8D095B8D095B8D095B8D19588F
19588F19588F19588F19649319649319649319649315588315588315588315588384A8B2
84A8B284A8B284A8B219588F19588F19588F19588F19588F0E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A
84A8B284A8B284A8B284A8B22A729D2A729D2A729D2A729D2A729D2B83992B83992B8399
2B839940779A40779A40779A40779A2A729D2A729D2A729D2A729D19588F19588F19588F
19588F0C6C8A0C6C8A0C6C8A0C6C8A1964931964931964931964931964932B83992B8399
2B83992B8399438CA2438CA2438CA2438CA22B8399000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000115B8F
115B8F15588315588315588315588305538A05538A05538A05538A05538A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F11648D11648D11648D11648D115B8F115B8F
115B8F115B8F085B95085B95085B95085B9515588315588315588315588315588319588F
19588F19588F19588F11649511649511649511649516427B16427B16427B16427B40779A
40779A40779A40779A1164951164951164951164955B90A55B90A55B90A55B90A55B90A5
11528F11528F11528F11528F2A729D2A729D2A729D2A729D0F748F0F748F0F748F0F748F
05538A05538A05538A05538A40779A40779A40779A40779A19588F19588F19588F19588F
19588F11649511649511649511649511528F11528F11528F11528F2A729D2A729D2A729D
2A729D276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C116495116495116495
116495116495046483046483046483046483095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F05538A05538A05538A05538A2B83992B83992B83992B839919588F19588F
19588F19588F19588F19588F19588F19588F19588F196493196493196493196493115B8F
115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883155883155883116495
1164951164951164951164952B83992B83992B83992B8399276F93276F93276F93276F93
286091286091286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D
1964931964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F19649319649319649319649319588F19588F19588F
19588F276F93276F93276F93276F93276F93044582044582044582044582276F93276F93
276F93276F93286091286091286091286091115B8F115B8F115B8F115B8F2A729D2A729D
2A729D2A729D40779A40779A40779A40779A40779A095B8D095B8D095B8D095B8D0F748F
0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F15588315588315588315588305538A05538A05538A05538A
16427B16427B16427B16427B115B8F115B8F115B8F115B8F115B8F11648D11648D11648D
11648D115B8F115B8F115B8F115B8F085B95085B95085B95085B95155883155883155883
15588319588F19588F19588F19588F11649511649511649511649511649516427B16427B
16427B16427B40779A40779A40779A40779A1164951164951164951164955B90A55B90A5
5B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D2A729D2A729D0F748F
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000002A2F6C2A2F6C2A2F6C2A2F6C
116495116495116495116495046483046483046483046483095B8D095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B83992B8399
2B839919588F19588F19588F19588F19588F19588F19588F19588F196493196493196493
196493196493115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883
1558831558831164951164951164951164952B83992B83992B83992B8399276F93276F93
276F93276F93276F93286091286091286091286091276F93276F93276F93276F93095B8D
095B8D095B8D095B8D1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F196493196493196493196493
19588F19588F19588F19588F276F93276F93276F93276F93044582044582044582044582
276F93276F93276F93276F93276F93286091286091286091286091115B8F115B8F115B8F
115B8F2A729D2A729D2A729D2A729D40779A40779A40779A40779A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A
40779A40779A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F15588315588315588315588305538A
05538A05538A05538A16427B16427B16427B16427B115B8F115B8F115B8F115B8F11648D
11648D11648D11648D115B8F115B8F115B8F115B8F115B8F085B95085B95085B95085B95
15588315588315588315588319588F19588F19588F19588F116495116495116495116495
16427B16427B16427B16427B40779A40779A40779A40779A40779A116495116495116495
1164955B90A55B90A55B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D
2A729D0F748F0F748F0F748F0F748F05538A05538A05538A05538A05538A40779A40779A
40779A40779A19588F19588F19588F19588F116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588305538A05538A05538A05538A05538A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F11648D11648D11648D11648D115B8F115B8F
115B8F115B8F085B95085B95085B95085B9515588315588315588315588315588319588F
19588F19588F19588F11649511649511649511649516427B16427B16427B16427B40779A
40779A40779A40779A1164951164951164951164955B90A55B90A55B90A55B90A55B90A5
11528F11528F11528F11528F2A729D2A729D2A729D2A729D0F748F0F748F0F748F0F748F
05538A05538A05538A05538A40779A40779A40779A40779A19588F19588F19588F19588F
19588F11649511649511649511649511528F11528F11528F11528F2A729D2A729D2A729D
2A729D276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C116495116495116495
116495116495046483046483046483046483095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F05538A05538A05538A05538A2B83992B83992B83992B839919588F19588F
19588F19588F19588F19588F19588F19588F19588F196493196493196493196493115B8F
115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883155883155883116495
1164951164951164951164952B83992B83992B83992B8399276F93276F93276F93276F93
286091286091286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D
1964931964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F19649319649319649319649319588F19588F19588F
19588F276F93276F93276F93276F93276F93044582044582044582044582276F93276F93
276F93276F93286091286091286091286091115B8F115B8F115B8F115B8F2A729D2A729D
2A729D2A729D40779A40779A40779A40779A40779A095B8D095B8D095B8D095B8D0F748F
0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F15588315588315588315588305538A05538A05538A05538A
16427B16427B16427B16427B115B8F115B8F115B8F115B8F115B8F11648D11648D11648D
11648D115B8F115B8F115B8F115B8F085B95085B95085B95085B95155883155883155883
15588319588F19588F19588F19588F11649511649511649511649511649516427B16427B
16427B16427B40779A40779A40779A40779A1164951164951164951164955B90A55B90A5
5B90A55B90A511528F11528F11528F11528F2A729D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000116495116495116495046483046483046483046483095B8D095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B83992B8399
2B839919588F19588F19588F19588F19588F19588F19588F19588F196493196493196493
196493196493115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883
1558831558831164951164951164951164952B83992B83992B83992B8399276F93276F93
276F93276F93276F93286091286091286091286091276F93276F93276F93276F93095B8D
095B8D095B8D095B8D1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F196493196493196493196493
19588F19588F19588F19588F276F93276F93276F93276F93044582044582044582044582
276F93276F93276F93276F93276F93286091286091286091286091115B8F115B8F115B8F
115B8F2A729D2A729D2A729D2A729D40779A40779A40779A40779A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A
40779A40779A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F15588315588315588315588305538A
05538A05538A05538A16427B16427B16427B16427B115B8F115B8F115B8F115B8F11648D
11648D11648D11648D115B8F115B8F115B8F115B8F115B8F085B95085B95085B95085B95
15588315588315588315588319588F19588F19588F19588F116495116495116495116495
16427B16427B16427B16427B40779A40779A40779A40779A40779A116495116495116495
1164955B90A55B90A55B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D
2A729D0F748F0F748F0F748F0F748F05538A05538A05538A05538A05538A40779A40779A
40779A40779A19588F19588F19588F19588F116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588305538A05538A05538A05538A05538A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F11648D11648D11648D11648D115B8F115B8F
115B8F115B8F085B95085B95085B95085B9515588315588315588315588315588319588F
19588F19588F19588F11649511649511649511649516427B16427B16427B16427B40779A
40779A40779A40779A1164951164951164951164955B90A55B90A55B90A55B90A55B90A5
11528F11528F11528F11528F2A729D2A729D2A729D2A729D0F748F0F748F0F748F0F748F
05538A05538A05538A05538A40779A40779A40779A40779A19588F19588F19588F19588F
19588F11649511649511649511649511528F11528F11528F11528F2A729D2A729D2A729D
2A729D276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C116495116495116495
116495116495046483046483046483046483095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F05538A05538A05538A05538A2B83992B83992B83992B839919588F19588F
19588F19588F19588F19588F19588F19588F19588F196493196493196493196493115B8F
115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883155883155883116495
1164951164951164951164952B83992B83992B83992B8399276F93276F93276F93276F93
286091286091286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D
1964931964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F19649319649319649319649319588F19588F19588F
19588F276F93276F93276F93276F93276F93044582044582044582044582276F93276F93
276F93276F93286091286091286091286091115B8F115B8F115B8F115B8F2A729D2A729D
2A729D2A729D40779A40779A40779A40779A40779A095B8D095B8D095B8D095B8D0F748F
0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F15588315588315588315588305538A05538A05538A05538A
16427B16427B16427B16427B115B8F115B8F115B8F115B8F115B8F11648D11648D11648D
11648D115B8F115B8F115B8F115B8F085B95085B95085B95085B95155883155883155883
15588319588F19588F19588F19588F11649511649511649511649511649516427B16427B
16427B16427B40779A40779A40779A40779A1164951164951164951164955B90A55B90A5
5B90A55B90A511528F11528F000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000046483095B8D095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B83992B8399
2B839919588F19588F19588F19588F19588F19588F19588F19588F196493196493196493
196493196493115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883
1558831558831164951164951164951164952B83992B83992B83992B8399276F93276F93
276F93276F93276F93286091286091286091286091276F93276F93276F93276F93095B8D
095B8D095B8D095B8D1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F196493196493196493196493
19588F19588F19588F19588F276F93276F93276F93276F93044582044582044582044582
276F93276F93276F93276F93276F93286091286091286091286091115B8F115B8F115B8F
115B8F2A729D2A729D2A729D2A729D40779A40779A40779A40779A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A
40779A40779A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F15588315588315588315588305538A
05538A05538A05538A16427B16427B16427B16427B115B8F115B8F115B8F115B8F11648D
11648D11648D11648D115B8F115B8F115B8F115B8F115B8F085B95085B95085B95085B95
15588315588315588315588319588F19588F19588F19588F116495116495116495116495
16427B16427B16427B16427B40779A40779A40779A40779A40779A116495116495116495
1164955B90A55B90A55B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D
2A729D0F748F0F748F0F748F0F748F05538A05538A05538A05538A05538A40779A40779A
40779A40779A19588F19588F19588F19588F116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
5B90A5276F93276F93276F93276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588305538A05538A05538A05538A05538A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F11648D11648D11648D11648D115B8F115B8F
115B8F115B8F085B95085B95085B95085B9515588315588315588315588315588319588F
19588F19588F19588F11649511649511649511649516427B16427B16427B16427B40779A
40779A40779A40779A1164951164951164951164955B90A55B90A55B90A55B90A55B90A5
11528F11528F11528F11528F2A729D2A729D2A729D2A729D0F748F0F748F0F748F0F748F
05538A05538A05538A05538A40779A40779A40779A40779A19588F19588F19588F19588F
19588F11649511649511649511649511528F11528F11528F11528F2A729D2A729D2A729D
2A729D276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C116495116495116495
116495116495046483046483046483046483095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F05538A05538A05538A05538A2B83992B83992B83992B839919588F19588F
19588F19588F19588F19588F19588F19588F19588F196493196493196493196493115B8F
115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883155883155883116495
1164951164951164951164952B83992B83992B83992B8399276F93276F93276F93276F93
286091286091286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D
1964931964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F19649319649319649319649319588F19588F19588F
19588F276F93276F93276F93276F93276F93044582044582044582044582276F93276F93
276F93276F93286091286091286091286091115B8F115B8F115B8F115B8F2A729D2A729D
2A729D2A729D40779A40779A40779A40779A40779A095B8D095B8D095B8D095B8D0F748F
0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F15588315588315588315588305538A05538A05538A05538A
16427B16427B16427B16427B115B8F115B8F115B8F115B8F115B8F11648D11648D11648D
11648D115B8F115B8F115B8F115B8F085B95085B95085B95085B95155883155883155883
15588319588F19588F19588F19588F11649511649511649511649511649516427B16427B
16427B16427B40779A40779A40779A40779A1164951164951164951164955B90A55B90A5
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
095B8D0F748F0F748F0F748F0F748F05538A05538A05538A05538A2B83992B83992B8399
2B839919588F19588F19588F19588F19588F19588F19588F19588F196493196493196493
196493196493115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883
1558831558831164951164951164951164952B83992B83992B83992B8399276F93276F93
276F93276F93276F93286091286091286091286091276F93276F93276F93276F93095B8D
095B8D095B8D095B8D1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F196493196493196493196493
19588F19588F19588F19588F276F93276F93276F93276F93044582044582044582044582
276F93276F93276F93276F93276F93286091286091286091286091115B8F115B8F115B8F
115B8F2A729D2A729D2A729D2A729D40779A40779A40779A40779A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A
40779A40779A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F15588315588315588315588305538A
05538A05538A05538A16427B16427B16427B16427B115B8F115B8F115B8F115B8F11648D
11648D11648D11648D115B8F115B8F115B8F115B8F115B8F085B95085B95085B95085B95
15588315588315588315588319588F19588F19588F19588F116495116495116495116495
16427B16427B16427B16427B40779A40779A40779A40779A40779A116495116495116495
1164955B90A55B90A55B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D
2A729D0F748F0F748F0F748F0F748F05538A05538A05538A05538A05538A40779A40779A
40779A40779A19588F19588F19588F19588F116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000040779A5B90A55B90A55B90A5
5B90A5276F93276F93276F93276F93276F93276F93276F93276F93115B8F115B8F115B8F
115B8F15588315588315588315588305538A05538A05538A05538A05538A16427B16427B
16427B16427B115B8F115B8F115B8F115B8F11648D11648D11648D11648D115B8F115B8F
115B8F115B8F085B95085B95085B95085B9515588315588315588315588315588319588F
19588F19588F19588F11649511649511649511649516427B16427B16427B16427B40779A
40779A40779A40779A1164951164951164951164955B90A55B90A55B90A55B90A55B90A5
11528F11528F11528F11528F2A729D2A729D2A729D2A729D0F748F0F748F0F748F0F748F
05538A05538A05538A05538A40779A40779A40779A40779A19588F19588F19588F19588F
19588F11649511649511649511649511528F11528F11528F11528F2A729D2A729D2A729D
2A729D276F93276F93276F93276F932A2F6C2A2F6C2A2F6C2A2F6C116495116495116495
116495116495046483046483046483046483095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F05538A05538A05538A05538A2B83992B83992B83992B839919588F19588F
19588F19588F19588F19588F19588F19588F19588F196493196493196493196493115B8F
115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883155883155883116495
1164951164951164951164952B83992B83992B83992B8399276F93276F93276F93276F93
286091286091286091286091276F93276F93276F93276F93095B8D095B8D095B8D095B8D
1964931964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F19649319649319649319649319588F19588F19588F
19588F276F93276F93276F93276F93276F93044582044582044582044582276F93276F93
276F93276F93286091286091286091286091115B8F115B8F115B8F115B8F2A729D2A729D
2A729D2A729D40779A40779A40779A40779A40779A095B8D095B8D095B8D095B8D0F748F
0F748F0F748F0F748F19649319649319649319649340779A40779A40779A40779A5B90A5
5B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93276F93276F93276F93
115B8F115B8F115B8F115B8F15588315588315588315588305538A05538A05538A05538A
16427B16427B16427B16427B115B8F115B8F115B8F115B8F115B8F11648D11648D11648D
11648D115B8F115B8F115B8F115B8F085B95085B95085B95085B95155883155883155883
15588319588F19588F19588F19588F11649511649511649511649511649516427B16427B
16427B16427B40779A40779A40779A40779A116495116495000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000F748F05538A05538A05538A05538A2B83992B83992B8399
2B839919588F19588F19588F19588F19588F19588F19588F19588F196493196493196493
196493196493115B8F115B8F115B8F115B8F0F748F0F748F0F748F0F748F155883155883
1558831558831164951164951164951164952B83992B83992B83992B8399276F93276F93
276F93276F93276F93286091286091286091286091276F93276F93276F93276F93095B8D
095B8D095B8D095B8D1964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A095B8D
095B8D095B8D095B8D095B8D0F748F0F748F0F748F0F748F196493196493196493196493
19588F19588F19588F19588F276F93276F93276F93276F93044582044582044582044582
276F93276F93276F93276F93276F93286091286091286091286091115B8F115B8F115B8F
115B8F2A729D2A729D2A729D2A729D40779A40779A40779A40779A095B8D095B8D095B8D
095B8D0F748F0F748F0F748F0F748F0F748F19649319649319649319649340779A40779A
40779A40779A5B90A55B90A55B90A55B90A5276F93276F93276F93276F93276F93276F93
276F93276F93115B8F115B8F115B8F115B8F115B8F15588315588315588315588305538A
05538A05538A05538A16427B16427B16427B16427B115B8F115B8F115B8F115B8F11648D
11648D11648D11648D115B8F115B8F115B8F115B8F115B8F085B95085B95085B95085B95
15588315588315588315588319588F19588F19588F19588F116495116495116495116495
16427B16427B16427B16427B40779A40779A40779A40779A40779A116495116495116495
1164955B90A55B90A55B90A55B90A511528F11528F11528F11528F2A729D2A729D2A729D
2A729D0F748F0F748F0F748F0F748F05538A05538A05538A05538A05538A40779A40779A
40779A40779A19588F19588F19588F19588F116495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000116C96116C96116C96116C9616427B16427B16427B
16427B11649511649511649511649511648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B83992B8399155883155883
1558831558832A729D2A729D2A729D2A729D005B8D005B8D005B8D005B8D2B83992B8399
2B83992B839919588F19588F19588F19588F2B83992B83992B83992B83992B8399005B8D
005B8D005B8D005B8D115B8F115B8F115B8F115B8F046483046483046483046483286091
286091286091286091115B8F115B8F115B8F115B8F116495116495116495116495116495
0F748F0F748F0F748F0F748F19588F19588F19588F19588F116495116495116495116495
1164951164951164951164950C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C076495076495076495076495116C96116C96116C96116C965B90A55B90A55B90A5
5B90A519649319649319649319649305538A05538A05538A05538A84A8B284A8B284A8B2
84A8B284A8B284A8B284A8B284A8B284A8B20E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D16427B16427B16427B16427B2D54802D54802D54802D5480196493196493
1964931964931964930C6C8A0C6C8A0C6C8A0C6C8A1558831558831558831558832B8399
2B83992B83992B839940779A40779A40779A40779A116495116495116495116495286091
28609128609128609128609140779A40779A40779A40779A2B83992B83992B83992B8399
1558831558831558831558830F748F0F748F0F748F0F748F2B83992B83992B83992B8399
438CA2438CA2438CA2438CA2438CA21558831558831558831558832A729D2A729D2A729D
2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D40779A40779A40779A
40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93276F93116495116495
116495116495276F93276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96116C96116C9616427B
16427B16427B16427B11649511649511649511649511649511648D11648D11648D11648D
116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399
1558831558831558831558832A729D2A729D2A729D2A729D2A729D005B8D005B8D005B8D
005B8D2B83992B83992B83992B839919588F19588F19588F19588F2B83992B83992B8399
2B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F115B8F046483046483
046483046483286091286091000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000016427B2D54802D54802D5480
2D54801964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A155883155883155883
1558831558832B83992B83992B83992B839940779A40779A40779A40779A116495116495
11649511649528609128609128609128609140779A40779A40779A40779A2B83992B8399
2B83992B83992B83991558831558831558831558830F748F0F748F0F748F0F748F2B8399
2B83992B83992B8399438CA2438CA2438CA2438CA21558831558831558831558832A729D
2A729D2A729D2A729D2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D
40779A40779A40779A40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93
276F93116495116495116495116495276F93276F93276F93276F9340779A40779A40779A
40779A276F93276F93276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96
116C96116C9616427B16427B16427B16427B11649511649511649511649511648D11648D
11648D11648D116C96116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B83991558831558831558831558832A729D2A729D2A729D2A729D005B8D
005B8D005B8D005B8D2B83992B83992B83992B83992B839919588F19588F19588F19588F
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F
046483046483046483046483286091286091286091286091286091115B8F115B8F115B8F
115B8F1164951164951164951164950F748F0F748F0F748F0F748F19588F19588F19588F
19588F1164951164951164951164951164951164951164951164951164950C8E870C8E87
0C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000F748F0F748F0F748F116C96116C96116C96116C96116C9616427B16427B16427B
16427B11649511649511649511649511648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B83992B8399155883155883
1558831558832A729D2A729D2A729D2A729D005B8D005B8D005B8D005B8D2B83992B8399
2B83992B839919588F19588F19588F19588F2B83992B83992B83992B83992B8399005B8D
005B8D005B8D005B8D115B8F115B8F115B8F115B8F046483046483046483046483286091
286091286091286091115B8F115B8F115B8F115B8F116495116495116495116495116495
0F748F0F748F0F748F0F748F19588F19588F19588F19588F116495116495116495116495
1164951164951164951164950C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C076495076495076495076495116C96116C96116C96116C965B90A55B90A55B90A5
5B90A519649319649319649319649305538A05538A05538A05538A84A8B284A8B284A8B2
84A8B284A8B284A8B284A8B284A8B284A8B20E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D16427B16427B16427B16427B2D54802D54802D54802D5480196493196493
1964931964931964930C6C8A0C6C8A0C6C8A0C6C8A1558831558831558831558832B8399
2B83992B83992B839940779A40779A40779A40779A116495116495116495116495286091
28609128609128609128609140779A40779A40779A40779A2B83992B83992B83992B8399
1558831558831558831558830F748F0F748F0F748F0F748F2B83992B83992B83992B8399
438CA2438CA2438CA2438CA2438CA21558831558831558831558832A729D2A729D2A729D
2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D40779A40779A40779A
40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93276F93116495116495
116495116495276F93276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96116C96116C9616427B
16427B16427B16427B11649511649511649511649511649511648D11648D11648D11648D
116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399
1558831558831558831558832A729D2A729D2A729D2A729D2A729D005B8D005B8D005B8D
005B8D2B83992B83992B83992B839919588F19588F19588F19588F2B83992B83992B8399
2B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F115B8F046483046483
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000002D5480
2D54801964931964931964931964930C6C8A0C6C8A0C6C8A0C6C8A155883155883155883
1558831558832B83992B83992B83992B839940779A40779A40779A40779A116495116495
11649511649528609128609128609128609140779A40779A40779A40779A2B83992B8399
2B83992B83992B83991558831558831558831558830F748F0F748F0F748F0F748F2B8399
2B83992B83992B8399438CA2438CA2438CA2438CA21558831558831558831558832A729D
2A729D2A729D2A729D2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D
40779A40779A40779A40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93
276F93116495116495116495116495276F93276F93276F93276F9340779A40779A40779A
40779A276F93276F93276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96
116C96116C9616427B16427B16427B16427B11649511649511649511649511648D11648D
11648D11648D116C96116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B83991558831558831558831558832A729D2A729D2A729D2A729D005B8D
005B8D005B8D005B8D2B83992B83992B83992B83992B839919588F19588F19588F19588F
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F
046483046483046483046483286091286091286091286091286091115B8F115B8F115B8F
115B8F1164951164951164951164950F748F0F748F0F748F0F748F19588F19588F19588F
19588F1164951164951164951164951164951164951164951164951164950C8E870C8E87
0C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000276F93276F93276F93
0F748F0F748F0F748F0F748F116C96116C96116C96116C96116C9616427B16427B16427B
16427B11649511649511649511649511648D11648D11648D11648D116C96116C96116C96
116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B83992B8399155883155883
1558831558832A729D2A729D2A729D2A729D005B8D005B8D005B8D005B8D2B83992B8399
2B83992B839919588F19588F19588F19588F2B83992B83992B83992B83992B8399005B8D
005B8D005B8D005B8D115B8F115B8F115B8F115B8F046483046483046483046483286091
286091286091286091115B8F115B8F115B8F115B8F116495116495116495116495116495
0F748F0F748F0F748F0F748F19588F19588F19588F19588F116495116495116495116495
1164951164951164951164950C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C076495076495076495076495116C96116C96116C96116C965B90A55B90A55B90A5
5B90A519649319649319649319649305538A05538A05538A05538A84A8B284A8B284A8B2
84A8B284A8B284A8B284A8B284A8B284A8B20E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D16427B16427B16427B16427B2D54802D54802D54802D5480196493196493
1964931964931964930C6C8A0C6C8A0C6C8A0C6C8A1558831558831558831558832B8399
2B83992B83992B839940779A40779A40779A40779A116495116495116495116495286091
28609128609128609128609140779A40779A40779A40779A2B83992B83992B83992B8399
1558831558831558831558830F748F0F748F0F748F0F748F2B83992B83992B83992B8399
438CA2438CA2438CA2438CA2438CA21558831558831558831558832A729D2A729D2A729D
2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D40779A40779A40779A
40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93276F93116495116495
116495116495276F93276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96116C96116C9616427B
16427B16427B16427B11649511649511649511649511649511648D11648D11648D11648D
116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399
1558831558831558831558832A729D2A729D2A729D2A729D2A729D005B8D005B8D005B8D
005B8D2B83992B83992B83992B839919588F19588F19588F19588F2B83992B83992B8399
2B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000001964931964930C6C8A0C6C8A0C6C8A0C6C8A155883155883155883
1558831558832B83992B83992B83992B839940779A40779A40779A40779A116495116495
11649511649528609128609128609128609140779A40779A40779A40779A2B83992B8399
2B83992B83992B83991558831558831558831558830F748F0F748F0F748F0F748F2B8399
2B83992B83992B8399438CA2438CA2438CA2438CA21558831558831558831558832A729D
2A729D2A729D2A729D2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D
40779A40779A40779A40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93
276F93116495116495116495116495276F93276F93276F93276F9340779A40779A40779A
40779A276F93276F93276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96
116C96116C9616427B16427B16427B16427B11649511649511649511649511648D11648D
11648D11648D116C96116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B83991558831558831558831558832A729D2A729D2A729D2A729D005B8D
005B8D005B8D005B8D2B83992B83992B83992B83992B839919588F19588F19588F19588F
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F
046483046483046483046483286091286091286091286091286091115B8F115B8F115B8F
115B8F1164951164951164951164950F748F0F748F0F748F0F748F19588F19588F19588F
19588F1164951164951164951164951164951164951164951164951164950C8E870C8E87
0C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000040779A40779A000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000155883
1558831558832A729D2A729D2A729D2A729D005B8D005B8D005B8D005B8D2B83992B8399
2B83992B839919588F19588F19588F19588F2B83992B83992B83992B83992B8399005B8D
005B8D005B8D005B8D115B8F115B8F115B8F115B8F046483046483046483046483286091
286091286091286091115B8F115B8F115B8F115B8F116495116495116495116495116495
0F748F0F748F0F748F0F748F19588F19588F19588F19588F116495116495116495116495
1164951164951164951164950C8E870C8E870C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C
2A2F6C076495076495076495076495116C96116C96116C96116C965B90A55B90A55B90A5
5B90A519649319649319649319649305538A05538A05538A05538A84A8B284A8B284A8B2
84A8B284A8B284A8B284A8B284A8B284A8B20E7C8D0E7C8D0E7C8D0E7C8D11648D11648D
11648D11648D16427B16427B16427B16427B2D54802D54802D54802D5480196493196493
1964931964931964930C6C8A0C6C8A0C6C8A0C6C8A1558831558831558831558832B8399
2B83992B83992B839940779A40779A40779A40779A116495116495116495116495286091
28609128609128609128609140779A40779A40779A40779A2B83992B83992B83992B8399
1558831558831558831558830F748F0F748F0F748F0F748F2B83992B83992B83992B8399
438CA2438CA2438CA2438CA2438CA21558831558831558831558832A729D2A729D2A729D
2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D40779A40779A40779A
40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D0F748F0F748F
0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93276F93116495116495
116495116495276F93276F93276F93276F93276F9340779A40779A40779A40779A276F93
276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96116C96116C9616427B
16427B16427B16427B11649511649511649511649511649511648D11648D11648D11648D
116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B83992B83992B83992B8399
1558831558831558831558832A729D2A729D2A729D2A729D2A729D005B8D005B8D005B8D
005B8D2B83992B83992B83992B839919588F19588F19588F19588F2B83992B83992B8399
2B8399005B8D005B8D005B8D005B8D000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000C6C8A0C6C8A155883155883155883
1558831558832B83992B83992B83992B839940779A40779A40779A40779A116495116495
11649511649528609128609128609128609140779A40779A40779A40779A2B83992B8399
2B83992B83992B83991558831558831558831558830F748F0F748F0F748F0F748F2B8399
2B83992B83992B8399438CA2438CA2438CA2438CA21558831558831558831558832A729D
2A729D2A729D2A729D2A729D5B90A55B90A55B90A55B90A511648D11648D11648D11648D
40779A40779A40779A40779A095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D
0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F0F748F276F93276F93276F93
276F93116495116495116495116495276F93276F93276F93276F9340779A40779A40779A
40779A276F93276F93276F93276F93276F930F748F0F748F0F748F0F748F116C96116C96
116C96116C9616427B16427B16427B16427B11649511649511649511649511648D11648D
11648D11648D116C96116C96116C96116C96116C960C6C8A0C6C8A0C6C8A0C6C8A2B8399
2B83992B83992B83991558831558831558831558832A729D2A729D2A729D2A729D005B8D
005B8D005B8D005B8D2B83992B83992B83992B83992B839919588F19588F19588F19588F
2B83992B83992B83992B8399005B8D005B8D005B8D005B8D115B8F115B8F115B8F115B8F
046483046483046483046483286091286091286091286091286091115B8F115B8F115B8F
115B8F1164951164951164951164950F748F0F748F0F748F0F748F19588F19588F19588F
19588F1164951164951164951164951164951164951164951164951164950C8E870C8E87
0C8E870C8E872A2F6C2A2F6C2A2F6C2A2F6C076495000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000276F93276F93276F93276F9316427B16427B
16427B16427B19649319649319649319649384A8B284A8B284A8B284A8B284A8B2196493
1964931964931964932860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C11528F
11528F11528F11528F0445820445820445820445825B90A55B90A55B90A55B90A55B90A5
05538A05538A05538A05538A116C96116C96116C96116C96196493196493196493196493
19649319649319649319649384A8B284A8B284A8B284A8B22B83992B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F11528F11528F11528F11528F076495076495076495
07649507649519649319649319649319649305538A05538A05538A05538A116495116495
1164951164950F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5155883155883
155883155883155883276F93276F93276F93276F93196493196493196493196493286091
2860912860912860910464830464830464830464830C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D11648D11648D
044582044582044582044582155883155883155883155883155883155883155883155883
19649319649319649319649319649305538A05538A05538A05538A286091286091286091
2860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93
276F93116C96116C96116C96116C96116C9616427B16427B16427B16427B045B84045B84
045B84045B84276F93276F93276F93276F93116495116495116495116495155883155883
155883155883276F93276F93276F93276F93276F932A729D2A729D2A729D2A729D046483
04648304648304648311648D11648D11648D11648D05538A05538A05538A05538A11528F
11528F11528F11528F276F93276F93276F93276F93276F932B83992B83992B83992B8399
116495116495116495116495196493196493196493196493116495116495116495116495
095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B284A8B2276F93276F93276F93
276F9316427B16427B16427B16427B19649319649319649319649384A8B284A8B284A8B2
84A8B2000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1964931964932860912860912860912860910464830464830464830464830C6C8A0C6C8A
0C6C8A0C6C8A5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D
11648D11648D11648D044582044582044582044582155883155883155883155883155883
15588315588315588319649319649319649319649305538A05538A05538A05538A286091
2860912860912860912860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
276F93276F93276F93276F93116C96116C96116C96116C9616427B16427B16427B16427B
045B84045B84045B84045B84045B84276F93276F93276F93276F93116495116495116495
116495155883155883155883155883276F93276F93276F93276F932A729D2A729D2A729D
2A729D04648304648304648304648304648311648D11648D11648D11648D05538A05538A
05538A05538A11528F11528F11528F11528F276F93276F93276F93276F932B83992B8399
2B83992B8399116495116495116495116495116495196493196493196493196493116495
116495116495116495095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B2276F93
276F93276F93276F9316427B16427B16427B16427B16427B196493196493196493196493
84A8B284A8B284A8B284A8B2196493196493196493196493286091286091286091286091
2A2F6C2A2F6C2A2F6C2A2F6C11528F11528F11528F11528F11528F044582044582044582
0445825B90A55B90A55B90A55B90A505538A05538A05538A05538A116C96116C96116C96
116C9619649319649319649319649319649319649319649319649319649384A8B284A8B2
84A8B284A8B22B83992B83992B83992B8399095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000019649319649319649319649384A8B284A8B284A8B284A8B284A8B2196493
1964931964931964932860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C11528F
11528F11528F11528F0445820445820445820445825B90A55B90A55B90A55B90A55B90A5
05538A05538A05538A05538A116C96116C96116C96116C96196493196493196493196493
19649319649319649319649384A8B284A8B284A8B284A8B22B83992B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F11528F11528F11528F11528F076495076495076495
07649507649519649319649319649319649305538A05538A05538A05538A116495116495
1164951164950F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5155883155883
155883155883155883276F93276F93276F93276F93196493196493196493196493286091
2860912860912860910464830464830464830464830C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D11648D11648D
044582044582044582044582155883155883155883155883155883155883155883155883
19649319649319649319649319649305538A05538A05538A05538A286091286091286091
2860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93
276F93116C96116C96116C96116C96116C9616427B16427B16427B16427B045B84045B84
045B84045B84276F93276F93276F93276F93116495116495116495116495155883155883
155883155883276F93276F93276F93276F93276F932A729D2A729D2A729D2A729D046483
04648304648304648311648D11648D11648D11648D05538A05538A05538A05538A11528F
11528F11528F11528F276F93276F93276F93276F93276F932B83992B83992B83992B8399
116495116495116495116495196493196493196493196493116495116495116495116495
095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B284A8B2276F93276F93276F93
276F9316427B16427B16427B16427B196493196493196493196493000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002860912860910464830464830464830464830C6C8A0C6C8A
0C6C8A0C6C8A5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D
11648D11648D11648D044582044582044582044582155883155883155883155883155883
15588315588315588319649319649319649319649305538A05538A05538A05538A286091
2860912860912860912860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
276F93276F93276F93276F93116C96116C96116C96116C9616427B16427B16427B16427B
045B84045B84045B84045B84045B84276F93276F93276F93276F93116495116495116495
116495155883155883155883155883276F93276F93276F93276F932A729D2A729D2A729D
2A729D04648304648304648304648304648311648D11648D11648D11648D05538A05538A
05538A05538A11528F11528F11528F11528F276F93276F93276F93276F932B83992B8399
2B83992B8399116495116495116495116495116495196493196493196493196493116495
116495116495116495095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B2276F93
276F93276F93276F9316427B16427B16427B16427B16427B196493196493196493196493
84A8B284A8B284A8B284A8B2196493196493196493196493286091286091286091286091
2A2F6C2A2F6C2A2F6C2A2F6C11528F11528F11528F11528F11528F044582044582044582
0445825B90A55B90A55B90A55B90A505538A05538A05538A05538A116C96116C96116C96
116C9619649319649319649319649319649319649319649319649319649384A8B284A8B2
84A8B284A8B22B83992B83992B83992B8399095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000084A8B284A8B284A8B284A8B2196493
1964931964931964932860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C11528F
11528F11528F11528F0445820445820445820445825B90A55B90A55B90A55B90A55B90A5
05538A05538A05538A05538A116C96116C96116C96116C96196493196493196493196493
19649319649319649319649384A8B284A8B284A8B284A8B22B83992B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F11528F11528F11528F11528F076495076495076495
07649507649519649319649319649319649305538A05538A05538A05538A116495116495
1164951164950F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5155883155883
155883155883155883276F93276F93276F93276F93196493196493196493196493286091
2860912860912860910464830464830464830464830C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D11648D11648D
044582044582044582044582155883155883155883155883155883155883155883155883
19649319649319649319649319649305538A05538A05538A05538A286091286091286091
2860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93
276F93116C96116C96116C96116C96116C9616427B16427B16427B16427B045B84045B84
045B84045B84276F93276F93276F93276F93116495116495116495116495155883155883
155883155883276F93276F93276F93276F93276F932A729D2A729D2A729D2A729D046483
04648304648304648311648D11648D11648D11648D05538A05538A05538A05538A11528F
11528F11528F11528F276F93276F93276F93276F93276F932B83992B83992B83992B8399
116495116495116495116495196493196493196493196493116495116495116495116495
095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B284A8B2276F93276F93276F93
276F9316427B16427B16427B16427B000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000464830464830C6C8A0C6C8A
0C6C8A0C6C8A5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D
11648D11648D11648D044582044582044582044582155883155883155883155883155883
15588315588315588319649319649319649319649305538A05538A05538A05538A286091
2860912860912860912860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
276F93276F93276F93276F93116C96116C96116C96116C9616427B16427B16427B16427B
045B84045B84045B84045B84045B84276F93276F93276F93276F93116495116495116495
116495155883155883155883155883276F93276F93276F93276F932A729D2A729D2A729D
2A729D04648304648304648304648304648311648D11648D11648D11648D05538A05538A
05538A05538A11528F11528F11528F11528F276F93276F93276F93276F932B83992B8399
2B83992B8399116495116495116495116495116495196493196493196493196493116495
116495116495116495095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B2276F93
276F93276F93276F9316427B16427B16427B16427B16427B196493196493196493196493
84A8B284A8B284A8B284A8B2196493196493196493196493286091286091286091286091
2A2F6C2A2F6C2A2F6C2A2F6C11528F11528F11528F11528F11528F044582044582044582
0445825B90A55B90A55B90A55B90A505538A05538A05538A05538A116C96116C96116C96
116C9619649319649319649319649319649319649319649319649319649384A8B284A8B2
84A8B284A8B22B83992B83992B83992B8399095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1964931964931964932860912860912860912860912A2F6C2A2F6C2A2F6C2A2F6C11528F
11528F11528F11528F0445820445820445820445825B90A55B90A55B90A55B90A55B90A5
05538A05538A05538A05538A116C96116C96116C96116C96196493196493196493196493
19649319649319649319649384A8B284A8B284A8B284A8B22B83992B83992B83992B8399
2B8399095B8D095B8D095B8D095B8D276F93276F93276F93276F93438CA2438CA2438CA2
438CA20F748F0F748F0F748F0F748F11528F11528F11528F11528F076495076495076495
07649507649519649319649319649319649305538A05538A05538A05538A116495116495
1164951164950F748F0F748F0F748F0F748F5B90A55B90A55B90A55B90A5155883155883
155883155883155883276F93276F93276F93276F93196493196493196493196493286091
2860912860912860910464830464830464830464830C6C8A0C6C8A0C6C8A0C6C8A5B90A5
5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D11648D11648D
044582044582044582044582155883155883155883155883155883155883155883155883
19649319649319649319649319649305538A05538A05538A05538A286091286091286091
2860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D276F93276F93276F93
276F93116C96116C96116C96116C96116C9616427B16427B16427B16427B045B84045B84
045B84045B84276F93276F93276F93276F93116495116495116495116495155883155883
155883155883276F93276F93276F93276F93276F932A729D2A729D2A729D2A729D046483
04648304648304648311648D11648D11648D11648D05538A05538A05538A05538A11528F
11528F11528F11528F276F93276F93276F93276F93276F932B83992B83992B83992B8399
116495116495116495116495196493196493196493196493116495116495116495116495
095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B284A8B2276F93276F93276F93
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0C6C8A0C6C8A5B90A55B90A55B90A55B90A511649511649511649511649511648D11648D
11648D11648D11648D044582044582044582044582155883155883155883155883155883
15588315588315588319649319649319649319649305538A05538A05538A05538A286091
2860912860912860912860911964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
276F93276F93276F93276F93116C96116C96116C96116C9616427B16427B16427B16427B
045B84045B84045B84045B84045B84276F93276F93276F93276F93116495116495116495
116495155883155883155883155883276F93276F93276F93276F932A729D2A729D2A729D
2A729D04648304648304648304648304648311648D11648D11648D11648D05538A05538A
05538A05538A11528F11528F11528F11528F276F93276F93276F93276F932B83992B8399
2B83992B8399116495116495116495116495116495196493196493196493196493116495
116495116495116495095B8D095B8D095B8D095B8D84A8B284A8B284A8B284A8B2276F93
276F93276F93276F9316427B16427B16427B16427B16427B196493196493196493196493
84A8B284A8B284A8B284A8B2196493196493196493196493286091286091286091286091
2A2F6C2A2F6C2A2F6C2A2F6C11528F11528F11528F11528F11528F044582044582044582
0445825B90A55B90A55B90A55B90A505538A05538A05538A05538A116C96116C96116C96
116C9619649319649319649319649319649319649319649319649319649384A8B284A8B2
84A8B284A8B22B83992B83992B83992B8399095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000085B95085B95438CA2438CA2438CA2438CA22D5480
2D54802D54802D54802A729D2A729D2A729D2A729D116495116495116495116495116495
095B8D095B8D095B8D095B8D196493196493196493196493115B8F115B8F115B8F115B8F
095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A55B90A5
5B90A5115B8F115B8F115B8F115B8F16427B16427B16427B16427B155883155883155883
1558832B83992B83992B83992B83992D54802D54802D54802D54802B83992B83992B8399
2B83992B83990C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D095B8D095B8D
095B8D095B8D2B83992B83992B83992B8399115B8F115B8F115B8F115B8F155883155883
155883155883155883276F93276F93276F93276F932860912860912860912860912B8399
2B83992B83992B8399276F93276F93276F93276F9319588F19588F19588F19588F0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D11648D11648D11648D
116C96116C96116C96116C96116C96276F93276F93276F93276F93155883155883155883
1558832D54802D54802D54802D54802B83992B83992B83992B83992B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA216427B16427B16427B16427B5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F40779A40779A
40779A40779A276F93276F93276F93276F93276F9328609128609128609128609111648D
11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D05538A
05538A05538A05538A095B8D095B8D095B8D095B8D095B8D155883155883155883155883
28609128609128609128609105538A05538A05538A05538A276F93276F93276F93276F93
2A729D2A729D2A729D2A729D40779A40779A40779A40779A000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000E7C8D2D54802D54802D54802D54800E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D
11648D11648D11648D116C96116C96116C96116C96276F93276F93276F93276F93155883
1558831558831558831558832D54802D54802D54802D54802B83992B83992B83992B8399
2B83992B83992B83992B8399438CA2438CA2438CA2438CA216427B16427B16427B16427B
5B90A55B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F
115B8F40779A40779A40779A40779A276F93276F93276F93276F93286091286091286091
28609111648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D
095B8D095B8D05538A05538A05538A05538A095B8D095B8D095B8D095B8D155883155883
15588315588328609128609128609128609128609105538A05538A05538A05538A276F93
276F93276F93276F932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
1558831558831558832B83992B83992B83992B83992B83992D54802D54802D54802D5480
19588F19588F19588F19588F276F93276F93276F93276F93085B95085B95085B95085B95
438CA2438CA2438CA2438CA22D54802D54802D54802D54802D54802A729D2A729D2A729D
2A729D116495116495116495116495095B8D095B8D095B8D095B8D196493196493196493
196493115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D095B8D196493196493
1964931964935B90A55B90A55B90A55B90A5115B8F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000438CA22D5480
2D54802D54802D54802A729D2A729D2A729D2A729D116495116495116495116495116495
095B8D095B8D095B8D095B8D196493196493196493196493115B8F115B8F115B8F115B8F
095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A55B90A5
5B90A5115B8F115B8F115B8F115B8F16427B16427B16427B16427B155883155883155883
1558832B83992B83992B83992B83992D54802D54802D54802D54802B83992B83992B8399
2B83992B83990C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D095B8D095B8D
095B8D095B8D2B83992B83992B83992B8399115B8F115B8F115B8F115B8F155883155883
155883155883155883276F93276F93276F93276F932860912860912860912860912B8399
2B83992B83992B8399276F93276F93276F93276F9319588F19588F19588F19588F0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D11648D11648D11648D
116C96116C96116C96116C96116C96276F93276F93276F93276F93155883155883155883
1558832D54802D54802D54802D54802B83992B83992B83992B83992B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA216427B16427B16427B16427B5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F40779A40779A
40779A40779A276F93276F93276F93276F93276F9328609128609128609128609111648D
11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D05538A
05538A05538A05538A095B8D095B8D095B8D095B8D095B8D155883155883155883155883
28609128609128609128609105538A05538A05538A05538A276F93276F93276F93276F93
2A729D2A729D2A729D2A729D000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002D54800E7C8D0E7C8D
0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D
11648D11648D11648D116C96116C96116C96116C96276F93276F93276F93276F93155883
1558831558831558831558832D54802D54802D54802D54802B83992B83992B83992B8399
2B83992B83992B83992B8399438CA2438CA2438CA2438CA216427B16427B16427B16427B
5B90A55B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F
115B8F40779A40779A40779A40779A276F93276F93276F93276F93286091286091286091
28609111648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D
095B8D095B8D05538A05538A05538A05538A095B8D095B8D095B8D095B8D155883155883
15588315588328609128609128609128609128609105538A05538A05538A05538A276F93
276F93276F93276F932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
1558831558831558832B83992B83992B83992B83992B83992D54802D54802D54802D5480
19588F19588F19588F19588F276F93276F93276F93276F93085B95085B95085B95085B95
438CA2438CA2438CA2438CA22D54802D54802D54802D54802D54802A729D2A729D2A729D
2A729D116495116495116495116495095B8D095B8D095B8D095B8D196493196493196493
196493115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D095B8D196493196493
1964931964935B90A55B90A55B90A55B90A5115B8F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000002A729D2A729D2A729D2A729D116495116495116495116495116495
095B8D095B8D095B8D095B8D196493196493196493196493115B8F115B8F115B8F115B8F
095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A55B90A5
5B90A5115B8F115B8F115B8F115B8F16427B16427B16427B16427B155883155883155883
1558832B83992B83992B83992B83992D54802D54802D54802D54802B83992B83992B8399
2B83992B83990C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D095B8D095B8D
095B8D095B8D2B83992B83992B83992B8399115B8F115B8F115B8F115B8F155883155883
155883155883155883276F93276F93276F93276F932860912860912860912860912B8399
2B83992B83992B8399276F93276F93276F93276F9319588F19588F19588F19588F0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D11648D11648D11648D
116C96116C96116C96116C96116C96276F93276F93276F93276F93155883155883155883
1558832D54802D54802D54802D54802B83992B83992B83992B83992B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA216427B16427B16427B16427B5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F40779A40779A
40779A40779A276F93276F93276F93276F93276F9328609128609128609128609111648D
11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D05538A
05538A05538A05538A095B8D095B8D095B8D095B8D095B8D155883155883155883155883
28609128609128609128609105538A05538A05538A05538A276F93276F93276F93276F93
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000F748F11648D11648D11648D11648D11648D
11648D11648D11648D116C96116C96116C96116C96276F93276F93276F93276F93155883
1558831558831558831558832D54802D54802D54802D54802B83992B83992B83992B8399
2B83992B83992B83992B8399438CA2438CA2438CA2438CA216427B16427B16427B16427B
5B90A55B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F
115B8F40779A40779A40779A40779A276F93276F93276F93276F93286091286091286091
28609111648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D
095B8D095B8D05538A05538A05538A05538A095B8D095B8D095B8D095B8D155883155883
15588315588328609128609128609128609128609105538A05538A05538A05538A276F93
276F93276F93276F932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
1558831558831558832B83992B83992B83992B83992B83992D54802D54802D54802D5480
19588F19588F19588F19588F276F93276F93276F93276F93085B95085B95085B95085B95
438CA2438CA2438CA2438CA22D54802D54802D54802D54802D54802A729D2A729D2A729D
2A729D116495116495116495116495095B8D095B8D095B8D095B8D196493196493196493
196493115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D095B8D196493196493
1964931964935B90A55B90A55B90A55B90A5115B8F000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
095B8D095B8D095B8D095B8D196493196493196493196493115B8F115B8F115B8F115B8F
095B8D095B8D095B8D095B8D1964931964931964931964935B90A55B90A55B90A55B90A5
5B90A5115B8F115B8F115B8F115B8F16427B16427B16427B16427B155883155883155883
1558832B83992B83992B83992B83992D54802D54802D54802D54802B83992B83992B8399
2B83992B83990C6C8A0C6C8A0C6C8A0C6C8A11648D11648D11648D11648D095B8D095B8D
095B8D095B8D2B83992B83992B83992B8399115B8F115B8F115B8F115B8F155883155883
155883155883155883276F93276F93276F93276F932860912860912860912860912B8399
2B83992B83992B8399276F93276F93276F93276F9319588F19588F19588F19588F0E7C8D
0E7C8D0E7C8D0E7C8D0E7C8D2D54802D54802D54802D54800E7C8D0E7C8D0E7C8D0E7C8D
0F748F0F748F0F748F0F748F11648D11648D11648D11648D11648D11648D11648D11648D
116C96116C96116C96116C96116C96276F93276F93276F93276F93155883155883155883
1558832D54802D54802D54802D54802B83992B83992B83992B83992B83992B83992B8399
2B8399438CA2438CA2438CA2438CA2438CA216427B16427B16427B16427B5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F115B8F40779A40779A
40779A40779A276F93276F93276F93276F93276F9328609128609128609128609111648D
11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D095B8D095B8D05538A
05538A05538A05538A095B8D095B8D095B8D095B8D095B8D155883155883155883155883
28609128609128609128609105538A05538A05538A000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000116C96116C96116C96276F93276F93276F93276F93155883
1558831558831558831558832D54802D54802D54802D54802B83992B83992B83992B8399
2B83992B83992B83992B8399438CA2438CA2438CA2438CA216427B16427B16427B16427B
5B90A55B90A55B90A55B90A55B90A50F748F0F748F0F748F0F748F115B8F115B8F115B8F
115B8F40779A40779A40779A40779A276F93276F93276F93276F93286091286091286091
28609111648D11648D11648D11648D11648D0F748F0F748F0F748F0F748F095B8D095B8D
095B8D095B8D05538A05538A05538A05538A095B8D095B8D095B8D095B8D155883155883
15588315588328609128609128609128609128609105538A05538A05538A05538A276F93
276F93276F93276F932A729D2A729D2A729D2A729D40779A40779A40779A40779A155883
1558831558831558832B83992B83992B83992B83992B83992D54802D54802D54802D5480
19588F19588F19588F19588F276F93276F93276F93276F93085B95085B95085B95085B95
438CA2438CA2438CA2438CA22D54802D54802D54802D54802D54802A729D2A729D2A729D
2A729D116495116495116495116495095B8D095B8D095B8D095B8D196493196493196493
196493115B8F115B8F115B8F115B8F095B8D095B8D095B8D095B8D095B8D196493196493
196493000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000F748F0F748F0F748F
2A729D2A729D2A729D2A729D11648D11648D11648D11648D116495116495116495116495
1164952A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A
40779A2A729D2A729D2A729D2A729D085B95085B95085B95085B952B83992B83992B8399
2B83992B83990E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F40779A40779A40779A40779A155883155883
15588315588315588305538A05538A05538A05538A196493196493196493196493095B8D
095B8D095B8D095B8D11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
04648304648304648304648311648D11648D11648D11648D276F93276F93276F93276F93
11648D11648D11648D11648D11648D07649507649507649507649505538A05538A05538A
05538A115B8F115B8F115B8F115B8F2B83992B83992B83992B8399276F93276F93276F93
276F9305538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
19649319649328609128609128609128609140779A40779A40779A40779A40779A40779A
40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D1164951164951164951164950F748F0F748F0F748F0F748F19588F
19588F19588F19588F2D54802D54802D54802D54802D548016427B16427B16427B16427B
116495116495116495000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000005538A05538A05538A115B8F115B8F115B8F115B8F2B83992B83992B83992B8399
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649319649328609128609128609128609140779A40779A40779A
40779A40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D095B8D095B8D095B8D095B8D095B8D1164951164951164951164950F748F0F748F
0F748F0F748F19588F19588F19588F19588F2D54802D54802D54802D548016427B16427B
16427B16427B1164951164951164951164951164952A729D2A729D2A729D2A729D2A2F6C
2A2F6C2A2F6C2A2F6C2B83992B83992B83992B839916427B16427B16427B16427B076495
076495076495076495115B8F115B8F115B8F115B8F115B8F196493196493196493196493
116C96116C96116C96116C961964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
2A729D2A729D2A729D2A729D286091286091286091286091286091286091286091286091
286091115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A0F748F0F748F0F748F0F748F2A729D2A729D2A729D000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000011648D11648D116495116495116495116495
1164952A729D2A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A
40779A2A729D2A729D2A729D2A729D085B95085B95085B95085B952B83992B83992B8399
2B83992B83990E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F40779A40779A40779A40779A155883155883
15588315588315588305538A05538A05538A05538A196493196493196493196493095B8D
095B8D095B8D095B8D11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
04648304648304648304648311648D11648D11648D11648D276F93276F93276F93276F93
11648D11648D11648D11648D11648D07649507649507649507649505538A05538A05538A
05538A115B8F115B8F115B8F115B8F2B83992B83992B83992B8399276F93276F93276F93
276F9305538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
19649319649328609128609128609128609140779A40779A40779A40779A40779A40779A
40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D1164951164951164951164950F748F0F748F0F748F0F748F19588F
19588F19588F19588F2D54802D54802D54802D5480000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000115B8F115B8F2B83992B83992B83992B8399
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649319649328609128609128609128609140779A40779A40779A
40779A40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D095B8D095B8D095B8D095B8D095B8D1164951164951164951164950F748F0F748F
0F748F0F748F19588F19588F19588F19588F2D54802D54802D54802D548016427B16427B
16427B16427B1164951164951164951164951164952A729D2A729D2A729D2A729D2A2F6C
2A2F6C2A2F6C2A2F6C2B83992B83992B83992B839916427B16427B16427B16427B076495
076495076495076495115B8F115B8F115B8F115B8F115B8F196493196493196493196493
116C96116C96116C96116C961964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
2A729D2A729D2A729D2A729D286091286091286091286091286091286091286091286091
286091115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A05538A
05538A0F748F0F748F000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000002A729D2A729D2A729D2B83992B83992B83992B839940779A40779A40779A
40779A2A729D2A729D2A729D2A729D085B95085B95085B95085B952B83992B83992B8399
2B83992B83990E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F40779A40779A40779A40779A155883155883
15588315588315588305538A05538A05538A05538A196493196493196493196493095B8D
095B8D095B8D095B8D11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
04648304648304648304648311648D11648D11648D11648D276F93276F93276F93276F93
11648D11648D11648D11648D11648D07649507649507649507649505538A05538A05538A
05538A115B8F115B8F115B8F115B8F2B83992B83992B83992B8399276F93276F93276F93
276F9305538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
19649319649328609128609128609128609140779A40779A40779A40779A40779A40779A
40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D1164951164951164951164950F748F0F748F0F748F0F748F000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000002B83992B83992B8399
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649319649328609128609128609128609140779A40779A40779A
40779A40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D095B8D095B8D095B8D095B8D095B8D1164951164951164951164950F748F0F748F
0F748F0F748F19588F19588F19588F19588F2D54802D54802D54802D548016427B16427B
16427B16427B1164951164951164951164951164952A729D2A729D2A729D2A729D2A2F6C
2A2F6C2A2F6C2A2F6C2B83992B83992B83992B839916427B16427B16427B16427B076495
076495076495076495115B8F115B8F115B8F115B8F115B8F196493196493196493196493
116C96116C96116C96116C961964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
2A729D2A729D2A729D2A729D286091286091286091286091286091286091286091286091
286091115B8F115B8F115B8F115B8F28609128609128609128609105538A05538A000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000040779A40779A40779A
40779A2A729D2A729D2A729D2A729D085B95085B95085B95085B952B83992B83992B8399
2B83992B83990E7C8D0E7C8D0E7C8D0E7C8D0F748F0F748F0F748F0F748F5B90A55B90A5
5B90A55B90A50F748F0F748F0F748F0F748F40779A40779A40779A40779A155883155883
15588315588315588305538A05538A05538A05538A196493196493196493196493095B8D
095B8D095B8D095B8D11528F11528F11528F11528F0F748F0F748F0F748F0F748F276F93
276F93276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
04648304648304648304648311648D11648D11648D11648D276F93276F93276F93276F93
11648D11648D11648D11648D11648D07649507649507649507649505538A05538A05538A
05538A115B8F115B8F115B8F115B8F2B83992B83992B83992B8399276F93276F93276F93
276F9305538A05538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A196493196493
19649319649328609128609128609128609140779A40779A40779A40779A40779A40779A
40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D116495116495116495000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000276F93276F93276F9305538A05538A05538A05538A0C6C8A0C6C8A0C6C8A0C6C8A
19649319649319649319649319649328609128609128609128609140779A40779A40779A
40779A40779A40779A40779A40779A2A2F6C2A2F6C2A2F6C2A2F6C0E7C8D0E7C8D0E7C8D
0E7C8D095B8D095B8D095B8D095B8D095B8D1164951164951164951164950F748F0F748F
0F748F0F748F19588F19588F19588F19588F2D54802D54802D54802D548016427B16427B
16427B16427B1164951164951164951164951164952A729D2A729D2A729D2A729D2A2F6C
2A2F6C2A2F6C2A2F6C2B83992B83992B83992B839916427B16427B16427B16427B076495
076495076495076495115B8F115B8F115B8F115B8F115B8F196493196493196493196493
116C96116C96116C96116C961964931964931964931964930E7C8D0E7C8D0E7C8D0E7C8D
2A729D2A729D2A729D2A729D286091286091286091286091286091286091286091286091
286091115B8F115B8F115B8F115B8F286091286091000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000005538A05538A05538A0C8E870C8E870C8E870C8E872D54802D54802D5480
2D54802D54801164951164951164951164950C8E870C8E870C8E870C8E872A729D2A729D
2A729D2A729D11528F11528F11528F11528F05538A05538A05538A05538A005B8D005B8D
005B8D005B8D005B8D5B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A5
5B90A55B90A55B90A5115B8F115B8F115B8F115B8F116C96116C96116C96116C96196493
19649319649319649319649384A8B284A8B284A8B284A8B2115B8F115B8F115B8F115B8F
0C8E870C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F
84A8B284A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C286091286091286091
2860912A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D116495116495116495
116495286091286091286091286091286091155883155883155883155883044582044582
0445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D05538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93276F932A729D
2A729D000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000286091286091286091286091155883155883155883155883
0445820445820445820445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93
276F932A729D2A729D2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D095B8D095B8D
095B8D095B8D095B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D
11648D11648D11648D16427B16427B16427B16427B196493196493196493196493115B8F
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F11528F11528F11528F11528F
16427B16427B16427B16427B116C96116C96116C96116C96116495116495116495116495
40779A40779A40779A40779A085B95085B95085B95085B95085B950C8E870C8E870C8E87
0C8E87095B8D095B8D000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000C8E872D54802D54802D5480
2D54802D54801164951164951164951164950C8E870C8E870C8E870C8E872A729D2A729D
2A729D2A729D11528F11528F11528F11528F05538A05538A05538A05538A005B8D005B8D
005B8D005B8D005B8D5B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A5
5B90A55B90A55B90A5115B8F115B8F115B8F115B8F116C96116C96116C96116C96196493
19649319649319649319649384A8B284A8B284A8B284A8B2115B8F115B8F115B8F115B8F
0C8E870C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F
84A8B284A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C286091286091286091
2860912A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D116495116495116495
116495286091286091286091286091286091155883155883155883155883044582044582
0445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D05538A05538A
05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000155883155883155883155883
0445820445820445820445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93
276F932A729D2A729D2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D095B8D095B8D
095B8D095B8D095B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D
11648D11648D11648D16427B16427B16427B16427B196493196493196493196493115B8F
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F11528F11528F11528F11528F
16427B16427B16427B16427B116C96116C96116C96116C96116495116495116495116495
40779A40779A40779A40779A085B95085B95085B95085B95085B950C8E870C8E87000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002D54801164951164951164951164950C8E870C8E870C8E870C8E872A729D2A729D
2A729D2A729D11528F11528F11528F11528F05538A05538A05538A05538A005B8D005B8D
005B8D005B8D005B8D5B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A5
5B90A55B90A55B90A5115B8F115B8F115B8F115B8F116C96116C96116C96116C96196493
19649319649319649319649384A8B284A8B284A8B284A8B2115B8F115B8F115B8F115B8F
0C8E870C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F
84A8B284A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C286091286091286091
2860912A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D116495116495116495
116495286091286091286091286091286091155883155883155883155883044582044582
0445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D05538A05538A
05538A05538A2A2F6C000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000155883
0445820445820445820445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93
276F932A729D2A729D2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D095B8D095B8D
095B8D095B8D095B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D
11648D11648D11648D16427B16427B16427B16427B196493196493196493196493115B8F
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F11528F11528F11528F11528F
16427B16427B16427B16427B116C96116C96116C96116C96116495116495116495116495
40779A40779A40779A40779A085B95085B95085B95085B95000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000C8E870C8E870C8E870C8E872A729D2A729D
2A729D2A729D11528F11528F11528F11528F05538A05538A05538A05538A005B8D005B8D
005B8D005B8D005B8D5B90A55B90A55B90A55B90A52B83992B83992B83992B83995B90A5
5B90A55B90A55B90A5115B8F115B8F115B8F115B8F116C96116C96116C96116C96196493
19649319649319649319649384A8B284A8B284A8B284A8B2115B8F115B8F115B8F115B8F
0C8E870C8E870C8E870C8E87196493196493196493196493115B8F115B8F115B8F115B8F
84A8B284A8B284A8B284A8B284A8B22A2F6C2A2F6C2A2F6C2A2F6C286091286091286091
2860912A729D2A729D2A729D2A729D2A729D2A729D2A729D2A729D116495116495116495
116495286091286091286091286091286091155883155883155883155883044582044582
0445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D11648D05538A000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000445820445820E7C8D0E7C8D0E7C8D0E7C8D11648D11648D11648D
11648D05538A05538A05538A05538A2A2F6C2A2F6C2A2F6C2A2F6C276F93276F93276F93
276F932A729D2A729D2A729D2A729D2A729D0C6C8A0C6C8A0C6C8A0C6C8A11648D11648D
11648D11648D095B8D095B8D095B8D095B8D2A729D2A729D2A729D2A729D095B8D095B8D
095B8D095B8D095B8D095B8D095B8D095B8D095B8D19649319649319649319649311648D
11648D11648D11648D16427B16427B16427B16427B196493196493196493196493115B8F
115B8F115B8F115B8F115B8F115B8F115B8F115B8F115B8F11528F11528F11528F11528F
16427B16427B16427B16427B116C96116C96116C96116C96116495116495116495116495
40779A40779A40779A40779A085B95000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
1164951164950C6C8A0C6C8A0C6C8A0C6C8A1964931964931964931964930F748F0F748F
0F748F0F748F0F748F11649511649511649511649528609128609128609128609116427B
16427B16427B16427B2D54802D54802D54802D548005538A05538A05538A05538A095B8D
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D0E7C8D
19649319649319649319649311648D11648D11648D11648D276F93276F93276F93276F93
438CA2438CA2438CA2438CA2438CA2005B8D005B8D005B8D005B8D196493196493196493
19649316427B16427B16427B16427B0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F115B8F115B8F115B8F115B8F115B8F196493196493196493196493115B8F115B8F
115B8F115B8F005B8D005B8D005B8D005B8D2A2F6C000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000005B8D005B8D005B8D2A2F6C2A2F6C2A2F6C
2A2F6C11649511649511649511649584A8B284A8B284A8B284A8B2276F93276F93276F93
276F9311648D11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D
11648D11648D5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F
115B8F115B8F05538A05538A05538A05538A05538A116495116495116495116495116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D085B95085B95085B95085B95095B8D
095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D
2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D095B8D095B8D095B8D095B8D
0C8E870C8E87000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000C6C8A1964931964931964931964930F748F0F748F
0F748F0F748F0F748F11649511649511649511649528609128609128609128609116427B
16427B16427B16427B2D54802D54802D54802D548005538A05538A05538A05538A095B8D
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D0E7C8D
19649319649319649319649311648D11648D11648D11648D276F93276F93276F93276F93
438CA2438CA2438CA2438CA2438CA2005B8D005B8D005B8D005B8D196493196493196493
19649316427B16427B16427B16427B0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F115B8F115B8F115B8F115B8F115B8F196493196493196493196493115B8F115B8F
115B8F115B8F005B8D000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000002A2F6C2A2F6C
2A2F6C11649511649511649511649584A8B284A8B284A8B284A8B2276F93276F93276F93
276F9311648D11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D
11648D11648D5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F
115B8F115B8F05538A05538A05538A05538A05538A116495116495116495116495116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D085B95085B95085B95085B95095B8D
095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D
2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D095B8D095B8D095B8D095B8D000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000001964931964930F748F0F748F
0F748F0F748F0F748F11649511649511649511649528609128609128609128609116427B
16427B16427B16427B2D54802D54802D54802D548005538A05538A05538A05538A095B8D
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D0E7C8D
19649319649319649319649311648D11648D11648D11648D276F93276F93276F93276F93
438CA2438CA2438CA2438CA2438CA2005B8D005B8D005B8D005B8D196493196493196493
19649316427B16427B16427B16427B0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F115B8F115B8F115B8F115B8F115B8F196493196493196493196493115B8F115B8F
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000011649511649511649511649584A8B284A8B284A8B284A8B2276F93276F93276F93
276F9311648D11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D
11648D11648D5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F
115B8F115B8F05538A05538A05538A05538A05538A116495116495116495116495116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D085B95085B95085B95085B95095B8D
095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D
2A2F6C2A2F6C2A2F6C2A2F6C095B8D095B8D095B8D000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000F748F
0F748F0F748F0F748F11649511649511649511649528609128609128609128609116427B
16427B16427B16427B2D54802D54802D54802D548005538A05538A05538A05538A095B8D
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D0E7C8D
19649319649319649319649311648D11648D11648D11648D276F93276F93276F93276F93
438CA2438CA2438CA2438CA2438CA2005B8D005B8D005B8D005B8D196493196493196493
19649316427B16427B16427B16427B0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F115B8F115B8F115B8F115B8F115B8F196493196493196493000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000084A8B284A8B284A8B284A8B2276F93276F93276F93
276F9311648D11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D
11648D11648D5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F
115B8F115B8F05538A05538A05538A05538A05538A116495116495116495116495116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D085B95085B95085B95085B95095B8D
095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D
2A2F6C2A2F6C2A2F6C2A2F6C000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000011649511649511649511649528609128609128609128609116427B
16427B16427B16427B2D54802D54802D54802D548005538A05538A05538A05538A095B8D
095B8D095B8D095B8D095B8D0C6C8A0C6C8A0C6C8A0C6C8A0E7C8D0E7C8D0E7C8D0E7C8D
19649319649319649319649311648D11648D11648D11648D276F93276F93276F93276F93
438CA2438CA2438CA2438CA2438CA2005B8D005B8D005B8D005B8D196493196493196493
19649316427B16427B16427B16427B0F748F0F748F0F748F0F748F0F748F0F748F0F748F
0F748F115B8F115B8F115B8F115B8F115B8F000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000276F93276F93276F93
276F9311648D11648D11648D11648D11648D2A2F6C2A2F6C2A2F6C2A2F6C11648D11648D
11648D11648D5B90A55B90A55B90A55B90A511648D11648D11648D11648D115B8F115B8F
115B8F115B8F05538A05538A05538A05538A05538A116495116495116495116495116495
1164951164951164950E7C8D0E7C8D0E7C8D0E7C8D085B95085B95085B95085B95095B8D
095B8D095B8D095B8D0C8E870C8E870C8E870C8E870C8E870E7C8D0E7C8D0E7C8D0E7C8D
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000438CA240779A40779A40779A40779A095B8D
095B8D095B8D095B8D1558831558831558831558832D54802D54802D54802D5480095B8D
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D11648D11648D11648D
116495116495116495116495286091286091286091286091286091286091286091286091
05538A05538A05538A05538A05538A276F93276F93276F93276F9311528F11528F11528F
11528F2D54802D54802D54802D54800F748F0F748F0F748F0F748F11648D11648D11648D
11648D276F93276F93000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000002B83992B83992B83992B83992B8399045B84045B84045B84045B84076495076495
07649507649519588F19588F19588F19588F11528F11528F11528F11528F116495116495
116495116495115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D005B8D005B8D005B8D005B8D11648D11648D11648D11648D438CA2
438CA2438CA2438CA2196493196493196493196493196493000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
00000000000000000000000000000000000000000000000000000040779A40779A095B8D
095B8D095B8D095B8D1558831558831558831558832D54802D54802D54802D5480095B8D
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D11648D11648D11648D
116495116495116495116495286091286091286091286091286091286091286091286091
05538A05538A05538A05538A05538A276F93276F93276F93276F9311528F11528F11528F
11528F2D54802D54802D54802D54800F748F0F748F0F748F0F748F11648D11648D11648D
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000002B83992B8399045B84045B84045B84045B84076495076495
07649507649519588F19588F19588F19588F11528F11528F11528F11528F116495116495
116495116495115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D005B8D005B8D005B8D005B8D11648D11648D11648D11648D438CA2
438CA2438CA2438CA2196493000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000001558831558832D54802D54802D54802D5480095B8D
095B8D095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D11648D11648D11648D
116495116495116495116495286091286091286091286091286091286091286091286091
05538A05538A05538A05538A05538A276F93276F93276F93276F9311528F11528F11528F
11528F2D54802D54802D54802D5480000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000045B84045B84076495076495
07649507649519588F19588F19588F19588F11528F11528F11528F11528F116495116495
116495116495115B8F115B8F115B8F115B8F115B8F0E7C8D0E7C8D0E7C8D0E7C8D095B8D
095B8D095B8D095B8D005B8D005B8D005B8D000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000095B8D095B8D095B8D0C8E870C8E870C8E870C8E8711648D11648D11648D11648D
116495116495116495116495286091286091286091286091286091286091286091286091
05538A05538A05538A05538A05538A276F93276F93276F93276F93000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{197.875, 89.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003g0000Kb000`400?l00000o`00003omoooool0
0?Oooooo003gooooo`001_ooooo60?ooo`030<o?c`2@T900D51@00@0000000<0_kno0?ooo`3oool0
6@3oool8ooooo`001_ooooo20?ooo`040<o?c`2@T900EEEE010@40L0000000<0_kno0?ooo`3oool0
6@3oool8ooooo`001_oooono0?ooo`030<K6aP20P800:b/[00/0000000<0_kno0?ooo`3oool06@3o
ool8ooooo`001_oooonk0?ooo`040=oOg`2PX:00H61P020P80T0000000<011XU0000000000000P00
00000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooookL0oooo00@0kno_0:2PX01PH600:b/[2@00
00001@0562D02BM0010nH`0WJi<08ej>00@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oo
oonc0?ooo`040>o_k`2PX:00H61P02/[:`T0000000T01A<L00PY?`0>?E`03fj200eaR`0?K9005ef<
02DiLP0DGhH0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooook00oooo00<0j^[Z08j>
SP10@4002P00000030037b801S5?01=>M00BIi4047:A02ILQ00;FHX04F6A00mLS`05DhX03en>02Ek
V0@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooon]0?ooo`030;no_`1`L700<30`00T0
000001000@/B00@T>`0;>EX045Am019ZT@0;FHh05ER301mYT00QL9<07E62015PSP0LJi<056>=00QK
R@0JIY@0<WZM100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006ooooojT0oooo00<0_kno071`
L00`<3002P0000004`013QL041La01=8L@0;FH`02TV301E<PP0DFXT04U^@01EDS@0WEH406Vb<02Ab
V00dN9T0:WbH03B2W00hPid0:gVH01UKR@0YAW`0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo
0006ooooojD0oooo00<0_kno0820P010@4002`0000005P0>3b8013AG00UHM`0>Bh<08cIb01MGR00>
Ghl04UV:01aKR@0LIi00;G6G01MSSP0ZHXX05GV;029eU@0ZMYP0:gZJ02IdV00TL9H07g2D01AWR@0M
Bgl4000000030;no_`3oool0oooo01T0oooo2?ooool000KoooooX@3oool00`2o_kl0P820051@D00:
0000000K00472@0:93003dAA00eCIP0EGY806TEm00EGQ`0?I8/03T^301a6N`0OHHh07VVE01eWT`0J
J8l06ff?0369UP0XMiD0:GVF01UeSP0MJ90066B@02eaV@0bLiT096^F01IVT`0AJHh065B500@00000
00<0_kno0?ooo`3oool06@3oool8ooooo`001_oooonN0?ooo`030;no_`1ZJVX05ADE00X0000001h0
10lF00/Y?P0>AVT046f<01UcTP0IMI4057V>025ZU`0;Hhh066B;01QPSP09FH/04U>3021VU00QIYD0
6F6?01=SRP0KHhD07h6A03EeV00ZMiH08UF801EHR@0KHI00:fnD04:4W@0jOih09FnI01UTT00QEh@4
000000030;no_`3oool0oooo01T0oooo2?ooool000KoooooVP3oool0103?cll0T92@051@D00E5AD9
0000000R00HF9003;Sh03CiT025^S`0FFhL07Un=01QTS00>M8L04fZ801ALS00PK980@GbL019`T00f
LYP06eN201MGQ@0GCX80762?01EQT@0?Ghd05fB:02=JR@0SK9P09FNB01mIS@0RAGX045^201ePS`0G
JHd09gfF02UkU`0SKY40:6^?02QYS0@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooonF
0?ooo`040=oOg`2@T900EEEE020P80T0000002H020hG00hU>P0CBfP056Z@01UHS`04HHh02V>C00ab
S00TKYL06FNB025]T`0UIhd05e21019@P`0PHHX0?GFE01MTTP0FKi00:5R502@jM@0OG8`08VVB01iT
T@0JGXl06Eb?00UJS@0AI8h06fB=00U:Q@0AIHd06ef;01QRS00NK900;gZI02=jUP0GKhd0:EZ401i5
N`@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooonB0?ooo`040=oOg`2PX:00EEEE020P
80T0000002X00aHK00d^?`0OFW<0>XRM03ITRP0VDh@07fVB01IST@0EFHl0472?00mfS`08Eh/0=h:M
029/U00fNY/0>g:D01eIR@0NCh809Cae02HlMP0HK9003HB;01ERTP0AGi407VVC01YOTP0CJ9004Fb?
01EOT00EJiH047B>015cQ`0GFhl09FbJ02I7O@0CLHD06gV@01iXTP0HJI4067FB02ajU00XGhP40000
00030;no_`3oool0oooo01T0oooo2?ooool000KoooooS`3oool00`3Shn<0P82002/[:`0:0000000>
00DJ9@08@4l04e5h015]S00DGhH09FbG06JFZ`1FQ:807Ej@011OSP0;J8/02E^=015TS@0AI9D2015T
S@0M01ALQP1=P9/0A7NJ029NSP0YKY@056B?01UTT`0[PiT04FBE00UKS@0AK9H04FJE015TU@0@K980
7gFC03]fV`0TLI/04V:?01E;P00AI8d096nI01YORP0BHI40BHFQ04UoWP0]KYL07VbE02^3V@0[KXh0
100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooooh/0oooo00@0kno_0:n_[`1PH600820P
2@000000<@024AL012@d00loF`0DHhP0:7JJ06NKZ@0AKH`05VVA02i]U00HF8`08fVB01i/S`0:EhH0
4UF903AgV00eP9d05fBB01MTU00AJY@03HB9011]SP0[IHl0:F>?01iWT`0YMYH07g>D01=TS`0XM9D0
3gJ?00i^S`0@LY404FRD015JTP0JGY40;G2F03MoW00[M9P0Dh>O01Y8O@0VF8<0:6ZA01=PSP0MGi00
<GBL02UYUP0KG9408VFE0423WP0DFhX0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooo
ohL0oooo00@0kno_0:n_[`1PH600:b/[2@000000=@0120`00b4d0256G`0JEWT04ef5015MQ@0@IHd0
4E^A01MXU@0XKYH04FR>01=UT`0OHI<04V^<00MSS00<HHh06fbA021cU00QLIL0;WJG04^5X@0WNiP0
BHNQ011_TP0EJ9<04En?00]OS@0AIXl066fC01QZU00GFhl0:G6K011`U00GJ9808G2B01MPR`0BGi40
<7:J04Z1W`0jO9/09g^H02a`UP0SE880662:02IgU@0HHX/05VFA01YER00BEX/03eJ?01]OTP0ZNiP0
1EZ<00@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooon30?ooo`040>o_k`2_[jl0P820
030`<0T0000003T00@H900<V=@0;>EX04UAc00eZR`09GH`0=7bK01i[U@0AHhh02fF900QMS@0FF8d0
4E^900UKS@0:GI<03f:@01I?Q00OGh`056B>011MS`0OIiH0:7BJ021ZT@0JGXL0=7NH02QdU@0TMIX0
2VBE01ATU00?Hi<035n=019PRP0JI90076B@00mWR`0KCX@09UZ601=TU@0WKi<076F@01=NT@0IMY00
7h:?01YWT00NJI<0?H2L01IZS@0AI9<0462?03]iV@0/LiH05VF@02M[U00MIHl03Ej;01m/UP0KLID0
100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooooh40oooo00<0ZZZZ05EEE@0000002@00
0000?0052Pd06cM202=BI@0AGHT00ej=00aKSP0HH8h03fN<015MR00YJY<09en;029PRP0GIXh02e>;
021UT`0EFXL0566A01=IT@0>GHh02d^3025RT`0KHH`04F^801]eT00TKY@05FJ>00aPRP0KH8P05WR?
02ALQ`0LJi@08WBF01Y_UP0CGY0056J<01MXS`0HHHh036b:00YCP@0IJHX086^D01IhS`0EII0047F<
00mhS@0AJhd055f901aJS00^DH402UV9015TT00KIiD09gBJ01MST@0@K9009UF201]?PP08HHT04Wj=
01MgT@@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooomm0?ooo`030;no_`20P800<30`
00T0000004000@H900HI9@0:=U404U5c029`T`0YNIT08W6F01=MR`0DII0066F@01UTT`0NM9<05VB;
02EKR@0RG8/07e^:01UGR00<EXl06fFC01MTS00RM9H08VFF019QS`09E8T08FVD01UWS@0>K8T06G:?
029]T`0AIY404Ej>015cQ@0LEWd06Df101]bT@0MLi805g:B011SS`0LKI<0;7^I029_UP0:J900<7JE
02QfU@0LJY007H2C01icU00CM8d04Vf@01EPSP0TI8/0AW2E02<dL@0?Bh404ej801iXU00WL9P076fD
015eS`0QGXP07EN:019WS`0HPHl03VN>100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooo
ogT0oooo00@0_kno0820P010@400410@2@000000@`0:72D01Bi7015@M00NAGh05FRE015PTP0KJ980
:GRF01ajTP0@Lhl04Un=01IJR`0LHI406FBC01ahTP0CKhl07V2;01mQT@0NGhl085f;029XUP0MJI80
7WNC01f0T`0eMI`06VRA00]MS@0GK9004f^>011TSP0GHI406V6@01AMR`0HCHD037f901]>N`0;EHP0
=H:J01eXTP0FIHl06V6:01mOS00]M9L09GBF00IPS@11P9`0@7NJ01i[U@0NM9L0:7nI025^U`0LIYD0
6f6@02YWT@10Mi/074^101A?P@0=EXL09FRC02Y^U@0YMYH066j<01U`T@0IJY@05VBB01MYT00@F8P0
100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006ooooogD0oooo00@0clo?0820P01@D500410@
2@000000A`045b@0335701eEL00gQ9l0;G6E015@Q@0;HHh0@Den011eTP0@II407FVD03ImVP0XOi40
3WN800mOR`0=D8H065jB01QQS`0=L8/03fn>019UT@0NHI8096BB02a^U00eM9L09g:D021jU00?N8l0
=7:G01m^TP0CH8l056Z@015VSP0IIY406eb@01=AR@0EEXD05d^100iWR00?HXH04Ub905B:XP0WK9D0
6Uj@02IGR00KDh@05f:=025^T@0TKY008fV?03IbV00`Li`04FRD025`T`0UL9L07VRD01]QT00NHI80
5FBC01aYU00AFXT01UF;02Y[U@0PKY808fjB02MXSP0FJXd05FN@01aRTP0GH8h05ER600@0000000<0
_kno0?ooo`3oool06@3oool8ooooo`001_ooooma0?ooo`040<o?c`2EUID0D51@010@40T0000004/0
0A4I01DjB`0WEG008Eb801=HS00EFh`05Un?015VU00dLYL09CA`00ikS@1]VZX088n?01ElSP0IJY00
<W^J02meU@0HH8X03F>>021ZTP0RNIP04E>300adR`0@I9003FB@01EQT00KH90086>A025_TP0MJI40
4fJA015ZUP0BG8T087JD025WTP0WIi805Un>025VTP0UHX`04eB4019OT00FIY406Tim01I8O@0WEXH0
=7JG01]jT00DJXh05eB8029XS@0NNi40:X2D06NGZ@0DGhH065b=03YaV00>LXh054j001MKR@0IGh/0
5eb:01YTT@0fM9@0=X:N00eQTP0=GHl05F:C03N2W00[LY<0AG^I01iTS`0PJ980>WNI02eYT`0DF8d0
100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006ooooofh0oooo00<0eMGE06YZJP0E5AD02P00
0000CP0M9BL033A<02U=M@0>FH<08GVD01aVRP0=EXL06EB5029;OP0EAX004E:?015TS@0F@W/038j7
02M_T`1KT:D0=8nF01YgS00ZLYD0=WfJ02a[U@06EH/02E^=00QKU@04AH8015^400iXTP0UOIP0;F26
025FQ00;HHh03Vj?00eMS`0GI9@04FBE01I2N`0AJ8X02f6>02=iUP0LIXX05ej;01A`T00?MXd046J<
00a/RP0Z;f`05ER305^@Y@0?M8l03WV>01AZSP0DIXl0:7JE02J3T@0>P8T04FB=00mdS`0F@W/0:62A
00a/RP0DCGl095V<02QPT@0RGH`0<Fb?07BQ[P0bP9d01Uf?01UTT`0CI9D0IiN[035/S`0WEH404UV3
01Q_S`0VN9@04EN500mCR0@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooomZ0?ooo`04
0=oOg`2PX:00D51@01DE5@T0000005800`XA00PT=@09BF003fR300b>Q`0AI9D02E^=00mRT`0dLYT0
8FZA00]LS006G9009GRL03f:X00[PiT05T9k015TS@0<K8X09fnC01EHP`0hM9@0@h6Q03EeW00VLY80
36b:00e`R`0>O8d0;EB001EHP`0AI8d025N;01mXT@0GIhl06VjA02EkUP0BG8T06Tf101m/TP08I8d0
@7NJ021PR@0HHHl04fB?01ALQP0CFXT076FA02A/T`0MJ9H0:W:M01EHP`0II9<03Wb=08BX/P19Sj40
:GVF01]fT00LMiD08V^H01E/T@0>O8d0:W:M01UTT`0ZLYd0@7NJ021PR@0BFX`0=WJJ05>?Y00gQ9l0
4V:?01M8P00FGHh036b:011VS00=Q8T046nB00]MS`0>HI80:FjH03AbU`0>H8`01UN=100000000`2o
_kl0oooo0?ooo`0I0?ooo`Sooooo0006ooooofH0oooo00@0gmoO0:2PX01EEED0820P2@000000=P05
3Q<01BHf00<_D`0?C7P05UR601MIS`0@Hhl03gJ=015TS@0<SXL01E>:04J1WP0dMiP0:WbG029dUP0S
G8X0:V::029ZTP0AFhl05T9k08BX/P0WKi<0@7NJ00A5PP0;D8T076FA02UiUP0IM9L0<G^O06jCYP0]
E8005ER301UHS`0WKi<0:6BB00e<QP05D8P025j<015XRP0BAWl01UN;00YTS@0AI8d0Q:Rb03imV`0Y
?gH0:5n902YlU`0PKXh04f:=01=WU00IFi006FBC02^3V@802E^=00/0@7NJ03=PR@0NI8P056J?02eX
U@0gIXd09UV601UTT`0XH9404E:?02QPT@0202^3V@0A01Q/T00LJY007F^A00MLRP08BX805UR601MI
S`0AFhl03gB>011ZS@0=Q8T01f:903ilW011P9`0:7BE02MkV00NH8h0100000000`2o_kl0oooo0?oo
o`0I0?ooo`Sooooo0006ooooof80oooo00@0gmoO0:ZZZP1`L700820P2@000000FP043A<01bHh00Y9
FP1CQ9L0=FbF01eST`0II9<03Uj?00QFRP07DHD05Fn@03mbV@24Z;8014F202M_T`0GIiD09UR501eG
PP0CFXT07eR803Q`T@0dOY`01E>:015BS`0XH9404FBE00b>Q`05DhX05V6?01YoS@0VPi40=fJ=02II
QP0HHHl05ER300QTS@0WKi<06FBC00mZS00UFX<074Ml01aAP`0RJ9805eV@02=TS@0KBX40:62A041g
VP0MHY804F:>00QGR`07F9404F2D029dUP0SNIH03EZ>01UHS`0>O8d04FBE05^@Y@0<K8X03fbB00aX
UP0<I9407WBC01Q[TP0AEh`0:62A01EHP`05DhX09fnC015TU@0@L940B8VP049hV`0SHI806FBC01ER
TP08EXX01e6500mdS`0RII40KIJZ02ANSP0NIHl066RD01mLR`0WEH4055V601QIR`@0000000<0_kno
0?ooo`3oool06@3oool8ooooo`001_oooomO0?ooo`030>[ZjP2EUID0@41000X0000000h010lF00PZ
?P0=Bg0066bF02^3V@0EF8<036b:01A=O`0EDh4065R<01UPTP0FJY806h2B03N0W@804E^?03P05ER3
05^@Y@0gQY`04VF@02i^UP0YJID076FA01aQT@0HGY80:h>I02eDP013S:80@7NJ015BS`0ZLYd07V^E
01aZT00LKYD04FRB01UYTP0TLI/04FbF01EHP`0XH940:W:M02]oVP0AK9007fbB021[U00CI9D0666?
01=QQP0KP980@hbR041gVP0PH8T065R<01=JS`0>IX`0:7bF02YhV00AH8h04eB?01UHS`0AFhl0:62A
00ECRP0AFhl085j@02QPT@0dK9H09W:B01YVSP0PFi004E:?01EHP`804FBE01<0:h>I01]SR@0>IhP0
4EN301I9OP0FF8H06E^@01IZTP0KP980@hbR01iWU00AFhl055V604Z2W@0kQid06VnC01MRT00dL9L0
5f2@00@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_ooool60?ooo`070;2`/02EUID0oooo
0?ooo`3_knl0P8200;no_`0;0?ooo`050<o?c`1PH600@410071`L03_knl0?P3oool0103_knl0[jn_
071`L00[:b/:0000001P00TO;P0>>5@04T]c01Y=P@0OCX406F:C015VT@0LN980>7BD015GP`0LDhD0
5F^501eRS@0RD8D07U:201icS`0gPId05f:@02UYU@0=EXL0=7jH02AcU@0DEhP0:Uj:02=US@0HI8l0
6F2@01EPSP0PKXh0;49f04><XP0gIXd046N>01i[U@0NFhT07eZ801U[U@0BIHl06f2:02AST@0=I9H0
7VB;03A/UP0PII007WJC015ZTP0HLY006g:A01eZU00MIXl055f401]_S@0eOY/0:FVE02=KQ`0QFhd0
5e^;01QRS00YMiH0:g:C01aLRP0EGI8086BA015KS`0IGXl05eZ>015KS`0RJY<0:FVC02iVU00TJY<0
66FA01YNT00CEHT084Ah01eRT`0=H94077RB035eU00KGXL065B501YLQP0EKHP08ER<01iBPP0NLhl0
@hbR01i[T`0SIi<055^;02YdU00UM9D05en<01YEQP0]IXd04fB>100000000`2o_kl0oooo0?ooo`0I
0?ooo`Sooooo0006ooooo`H0oooo00H0gmoO01DE5@2`/;00oooo071`L00`<30;0?ooo`070<o?c`00
0000T92@0;no_`1PH600820P0>o_k`0i0?ooo`040>o_k`2_[jl0P8200410@0X0000006@00ATQ035@
G@0JD7L0=WJJ01eYT`0JK9@086F=02E?P@0YDhL08VRD01E[S`0dOYP0=WJJ025SRP0QGXl05g:>01iS
S`0MDh806U9o01]VSP0SMYD07FJB03A/UP09H8X026B701MUS`0bJ9009Ej:01ARR@0HHHT085b<01]P
SP0CFXT0:Dn002YhW014LY<046b>01ETT00LEhP08U^<02aeV`0[MYH0:6^>02aXSP0;K94086ZC02]M
R`0CEHT06g:A01a_U00FKi405Fj>01i/SP0]JY405U2001EMQ@0FJX/04E^?01mGRP0WGXl065R;029<
PP0ZHXd0:fnC02MTS@0OJi@09fnC03IfVP0=Ehh0:6RB00]PR@0`O9P0<WJI02a/UP0VKID06VbD01mZ
T00QEX80:DQo02UYU`0;I8`0=7jH03IhVP0VJ8h08F2=01aVS`0GLXh085V;01YBO`0KIXh0:7bF01YZ
TP0/JYD056>=00QSR00EIHh0:fNA039USP0GGHP04VN:100000001@2o_kl0oooo0?ooo`3?cll0D51@
00<0oooo00<0D51@0:2PX03oool02@3oool01P20P800410@020P802`/;00D51@09FEU@80oooo2?oo
ool000Kooooo1`3oool01`3EeMD0820P0:n_[`000000clo?0?ooo`3Ogml01P20P8001@2PX:00oooo
0?ooo`10@400L71`00<0oooo00<0<30`0820P03oool0=@3oool00`2o_kl0P8200410@00:0000001X
00LG7@0C>T<06UI`02YRRP0=GX<0<WJI02e^U`0ZM9T08FfF02E/T@0UJXX08fB<02QVT`0XLIL0:WFD
03AnV00NKi@08VjD019OT00?G8l055j>019QR@0EHXX085f<01UGP00JJhh0:eZ901ePQ@0FGX/06f>@
03Y_T`0hMIL087FC01aWR`0ZGHd08V>@011/SP0YCh007eb;039fV@0CFXT05ej;01aTS`0UKYH0?82N
03J5W00PNi@08WRC01A`T00RM9H05Teo01eIT00WK9@08FR>021YT@0QJi8096Z>02QLRP0OG8P07FR<
01QdSP0AH9804fF@01]LT00MFI009E:502AMR`0SKI@09FbA01iWSP0LKYD0@hZO01i[U00ZHXX03Ej3
02I^TP0`LYP0;76H02A`U`0UK9409f^;01iXQ`0XH940:G6H02IbTP0dOYP097>E025^U00HI9403U^>
015MS`0DGh`05F::021MS00KCW/05VR;02EPR`0QGhH065n:01YSS`0`K980@7>E02UfUP0EKX/40000
000:0;no_`3oool0oooo0?ooo`1PH600P8200?ooo`20P800820P0>o_k`T0oooo00L0clo?0000002@
T900kno_061PH0000000ZZZZ0080oooo2?ooool000Kooooo203oool00`2@T9000000071`L0020?oo
o`030=oOg`20P800P82000@0P82000D0X:2P0?ooo`3_knl000000<o?c`030?ooo`03092@T00`<300
oooo0340oooo00<0_kno092@T010@4002`000000J`046b<05SeB01aJOP0PIhd0<GFD03ImVP0gIXd0
3EJ7011?Q00fOIX02eN=01aVU@0NG8d04ef701EWSP0MHhh08FF<029WS@08I8L07H2C01AVS`0ECH80
2E2700eYS00SLI409ffB01YKR`0JF8405FZ801iXQ`0QEX807eb:01QOS`0KKHL0=WJC03aoVP0ZK900
<FFA03IfV@0@L94084Ah02eDP00;I8`07VB;019VR@0GJ8d06VRB02=_V00/O9X0:7jG02IiU@0RM9H0
5VnC00mNR00JMh`06FN>031`T`0[L9<0:72E02MTS`0RAG`09FjA01]lT00NM9L03fR@011[S`0SIi<0
8Uj=01UOS@0CJHh05Vf?021ZT00UIhl04f:=02a/S@0fOIX0=fJ=00eFQ`0?DHD08fJ?025ZU00GHI<0
7Ub=01EGQ@0<K8d07F:?01iTR`0[J8l026B701QiT00FKI005EJ6011:P@08FX/05g6?02M]TP0JFh/0
7E9n01ETQP0KJHL085^3021KR00HGhl06FV;02IcRP0oO9/0<7VD00@0000000/0_kno0?ooo`3oool0
oooo0>o_k`0P8200UIFE0000002o_kl0oooo0<o?c`070410@0080?ooo`3Ogml00000071`L03oool0
kno_0000002ZZZX20?ooo`Sooooo0006ooooo`P0oooo00<0P8200000002ZZZX02`3oool00`2o_kl0
00000?ooo`030?ooo`030;no_`000000oooo02h0oooo00<0_kno05EEE@0000002`000000KP044AT0
4C5>01a`S`0FIhl08FZB02I[S`0PEh<0;f:=03UeV`0bII001E>:0113O@0kQid04V>?01MQSP0@EXX0
2EF:01ETS`0MHX/055>200mNQP07K8D03gB=00e/SP0S?WD04dIo011RQ`0YN9H0:gJH00iQR`0FLXl0
9Vf>019dS`0KH8P096V=01QST00FP8h08gJB03MgVP0bIHh0<6V=03EnV`0AGY<03UV603AWR`0>K8h0
8F2;00mgSP0ELi004VVB019TT`0WL9H0<gJF031`T`0ZMiH03F:?00QQS@0?O8H036R<035eV@0^LiP0
86jE01EPS00QBgd07VVA00mhS@0BH8l03VV;01=USP0[Ji@07F2<01=FQ`0IIh`066b@01UTT00[LI<0
6f2802E>OP0iMI/0<VF@00ECRP0<B8409VF=02MeUP0EHXl045J:00QBR009GXd08FZA01EAP00AFHH0
1fb500ebR`0>KXh074im020iM00=E8H06Vn=02]fV00>HH/03gB?02E]SP0ILXl06FF:029WS00II900
5GJ?01^3S`0`LIL0>g>G100000000`2o_kl0oooo0?ooo`020?ooo`030:ZZZP000000@4100080oooo
00<0j^[Z0:ZZZP2ZZZX01@2ZZZX20?ooo`060:ZZZP000000:b/[0820P0000000ZZZZ0P3oool8oooo
o`001_ooool70?ooo`070>[ZjP0@4100H61P020P803_knl0oooo0;no_`06000000040410@03oool0
_kno000000@0oooo00<0_kno0000003oool0:P3oool0103?cll0T92@0410@00@410;0000001a004B
6@09<4P04d]d01iPSP0/Eh@0<FfB01iOT@0CHY007G2B025NRP0OGhh0976K01=8P00>EX`03TV204V5
X@0UNIL08VZ>01QPS@0=GXd086ZA02aVT@0GDHL03FB=01>6RP0AHXh035Z;01lnM`0IAGh06TQn01eH
R00LGX/05en702IjU@0kO9X065b=029ZTP0dOY`06VRB01mmU00TOIH08G6G02QUT00TIXL056:6019>
RP01FH`0=HfK015ZUP0GBh403WR<01YiTP0KLi8066fA01mVS`0PHXX08FB<029QT00PJY804UV:035/
S`0IHI403e^=02=YU`0TK9H05VN=01EVR`0GHi806F6>01]SR@0>I8/04f>@01MMT00LGhh09eZ7031V
S@0SI9<04e^?01M`T@0WKi<06Tf102AaV`0CB8003UJ<00i=Q@0/Ii80=gnL02=_T@0HH8d03Uf>00]Q
R`0dLYL06dj400]ISP0CQXX04V^=00eLS00IAgh083af01M:P@0MCH4075j;01MOQ`0KMI80?8>K02AW
T@0PIi40<7VJ01eZT`0JLi8098>F02=eU`0SIi<0100000000`2o_kl0oooo0?ooo`020?ooo`03071`
L0000000D51@0080oooo00<0kno_0;no_`2o_kl01@2o_kl30?ooo`050>o_k`2PX:00H61P0000002Z
ZZX00P3oool8ooooo`001_ooool60?ooo`060>o_k`0[:b/0@4100?ooo`20P800H61P2P3oool00`2o
_kl000000?ooo`030?ooo`030;no_`000000oooo02H0oooo00@0clo?09FEU@1@D500410@30000000
DP062a0052/k01USM`05HXH02E^=015TS@0]E800:62A01=YS00EGhd06EjA021ZT`0WKi<076jE015/
UP09Fhd0:62A02eDP00AI9D04E^?03N0W@0VM9P03eZ801=NR00IJI8096ZJ01MIT00WKi<04E^?01EH
P`0FB7d04Ub?02IHQ@0]E8009eF1021PR@0cM9H03f:601I2N`0AFhl01E>:01mXT@0CQXX03fb<01iW
UP0gOj00=ej702DdL00F@W/01E>:00b>Q`0AI9D06FBC00a/RP0?I8d04eZ9021^SP0fOIX0@GjM03N2
W@0AI8d02E^=02eDP024Z;80;WFL029/U00XI980:6FB02UXSP0VF8<0662:02ePQP0[PiT016B300QM
R`0?HXd09UR302YLR`0JIXh04f:=01UKT00MIi<202M_T`0P015/UP09Fhd0:62A02]HQP0OG8/04F2B
02YdV@0VM9P03EZ:01EHP`0AI8d0:W:M015BS`0WKi<05f2@01AIQP0FCGl054f401QPT00]E8009eF1
021PR@10MiX06Fn>01A=O`0BEHX025F;01aVT00JOhd03H6901MQT`0`NIh40000000;0;no_`3oool0
oooo0?ooo`3?cll000000:ZZZP0`<300/;2`0?ooo`3?cll01`10@400103oool0kno_0;no_`3_knl2
0?ooo`040000002ZZZX0oooo0?ooo`Sooooo0006ooooo`H0oooo00<0X:2P0410@03Ogml00P3oool0
0`1@D500_kno0?ooo`090?ooo`030000002_[jl0oooo0080oooo00<0L71`0410@03oool08P3oool0
103De=@0X:2P061PH00@410=0000001A00PE7005=U405eMi01iTR`0AEhD01eV:01AbSP0[PiT0@7NJ
01EHP`0AFhl01f:600eNR`0@K8h0472=00mXS00AEh<05T9k01UTT`0]E8003gB?05^@Y@0F@W/04Ub?
01i:P@0H@G/05V6?01aVT00?Ghh087VF001KS@1KT:D0;EB000iPPP0QNi@0:FVC01a<PP0WEXH0CgRG
02DdL00QEHD0@hbR01EHP`0Z;f`0:V6A01]>Q00EDH004F:701ahTP0NN9P047FB00b>Q`05DhX0:h>I
015TU@0WKi<05T9k01mIQ`0LJY007F:?03IfVP0aSIT03Gn9015BS`1KT:D03Wb=04><XP0^MYL04ff<
01=MQ@0KH8P07FZB00YPS`0SJHl04EN500ECRP0<K8X08gfE03]jVP0PH8T04UZ;00802f2902@046>?
00mfS@0AI8d036b:01I2N`0II9<0;EB001UYRP0ePYX0>FV@01ACR00NBX407S]f00ECRP0WKi<01E>:
02^3V@00Fhd0A8>O03USR@0IG8804Fj:02YjU`0TFH`09eJ604mhU`0Z;f`06ceg03QjV00QIH/09CUb
02YLS@0PFX`05TQm01=MQ@0DLXh40000000:0;no_`3oool0oooo0?ooo`0`<300L71`0?ooo`3Ogml0
820P0=oOg`T0oooo00L0kno_01DE5@1@D500_kno0820P0000000eMGE0080oooo2?ooool000Kooooo
5`3oool00`1EEED0JVYZ0?ooo`020?ooo`0302/[:`2EUID0oooo01l0oooo00<0eMGE0820P00[:b/0
3P0000004`0:72D02CQC025IQP0jLIP06gFB00e_S00AHXL05U^701i/U@0RNIP025^E01EHP`10MiX0
:h>I00mOSP0BEXd05F:C00]PT00GFXh00P0XH940<00F@W/09fnC01I2N`0EF8<0:h>I01i/U@0jNY`0
=W6J00aKTP05HI801UZ>01iGR`0]E8004FBE015/UP0RKY@0:Cmf01e>QP0FF8L055^6015XSP0=K8h0
3en>02^3V@0ADXl04FbF00QIS@0BAWl08F2;03AcU`0TKYP0<GZM04^2X00IF8l014F201I2N`0ADXl0
4FBE02QPT@0MHY<07WBG01idT`0ZN9P0<XBL01ISQP0Z;f`02E^=01EHP`809fnC01805fNE029QTP0`
J9@0=7JG00ibSP0>IhP05U^701UTT`0[PiT04FFF019IR00eKi@0<WnI01Q[TP0?EXd05efA00iVT`05
DhX202QPT@0O01I2N`0WKi<0756301I=O`0PKXh08WBF03YjW012Nih04E:?00MTU@00Fhd06ER?02eD
P00HH9004FZF01a^U@0XFXH09SUe01QHS00DFhH04FR>00mdS`08Fh/08WNE01QNTP0AIY@02E^>00i;
P`0JCH40;G6E039bV@04000000060;no_`3oool0oooo0;no_`1EEED0j^[Z0P3oool209FEU@X0oooo
00D0hn?S0410@00000005ADE09FEU@030?ooo`Sooooo0006oooooaL0oooo00L0clo?0000002@T900
_kno061PH00P8200kno_01`0oooo00@0gmoO0:2PX01[Jf/0820P3P000000O@0:6R/032iA019FOP0W
Ki<09G^H01eRR`0LFhl0462?01aLQ`0_KHl0=7jJ021fUP0AFXX08SYf01EHP`0GHY00:7BE01EKT00M
FY0075j=01AOS@0IHY805F2=00eLQ`0HDhX05fNE04YmV`0SJHl057:>021UT@0QJ9<06F>=019NSP0D
IY@07f^D02=WU00KEh809G^H02IJQP0FGhd0<FB?02]4O00TFHH07fR?011ZS@0>N8h03WR<01B;S00U
MiL015n?00AKR00CEHT03eb=02E/U@0`K9H0=GNK03^:W@0?PHT03Ub:01QCRP0=OhT025N=01eST`0E
M8l078BB01UdT00>IXT07fb@02i/T@0JCWd085n@01I8O@0AH8l08V^B02IhU`0MHX/06eZ;01UMT@0B
Gh/0:V>903AnVP0WNiP02fF@01a5O@0HDH005f2=029^T`0KHi806ER@021NS`0DGXX0562A01eST`0=
G8L065>:01MWU@0iMYT0=g>E01a^S`0LJY008FRC01YWS`0DEhH03fBE01eZTP0VK9X06eN202=bT`0V
HX/075f;01mRS`0fFXT09DEl01mXS`0@JXd03WZ>00edS@0BQH`08GbD00aUT@04FhT03UJ801EFR`0H
IY80>7:H00@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_oooolH0?ooo`050<o?c`1@D500
@410061PH03_knl06@3oool0103_knl0ZZZZ071`L00`<30<0000002300D:3@0<5b803C1501A9H`0E
GW@06GF?02AcU00@GhX04VN=02QTTP0kNYX0>GjJ02]ORP0IGhl05f6A01Y`T@0OOYD09g>J01]WSP0D
GH<0=FnD00^1R@0ELi007f>A03=eVP0aOIT07f:;011DQ@0EC7d08CYb015cSP0GI9@096RE01=]S00P
KY40466?01ETT00KFXP05TZ001I@Q`0EGI804V2A01I8O@0XM9D074Ml019ARP0HKI409T5f02UBQ@0R
I9804FJB011/S`0?LI4037F902ePQP0PK9T05fFB01=QSP0JH8l0;f^E04MnW@11LiD0:FB:00YXS00=
JX/04f6D01I_T004BH@06FBC01eXT@0^LiD0;fV>01UMQP0HIhh09W:C011cR`0ZNYL04Ub900]XR`0Q
II00=WFH03UnVP0bLI<08UR801IRTP0IJ9407gjE02YfW00MJY805V2702e[T00FOH`04WR>01aXT@0_
KiP0=gnL029]S`0GBh402Ef8024jLP0ALhh05fBD021WU@0LJi406Vj?01EUT00EI900762;01I8O@0E
Bh805eV@011XU`0FB7d096V?01mBPP0FCXH04en@01mTR@0Z?7H08VBB015VTP0@JXd046nB00edS00U
IHL08fVD01QUTP0DHXl05V6?02MUT`14NY`0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006
oooooc<0oooo00<0[jn_071`L00`<3002`000000R00762@002<e01LfDP0;Ef/05f>>021PR@0WIXd0
9WJD02QmU`0VLi@07G>?01R7S`0YNIH0<GJF02YjU`0MKiL07VjC04AlVP0_LID04fN@00YTSP0>GX/0
6EV701MdS`0QHhl08f2B021gT00TOiL06GR@01m`U00VLIH0>GVH02YcTP0>G8L04E2501=QQP0fLYP0
8VZB021^T@0DNHl076J@01QPT00LJY4076R>01MPS00MIi<05FRD02IcTP0YLI/05T9k00iCR@0>KHl0
45j<01EOS@0NIi40:fnF015VS`0EJY@08F>?019IRP0AJ9404fF@01iRT00HIXd066V>029XSP0ZGHH0
9UR300mRS@0S?W@08V6B00IMS`0OFHd04W2@01EZS`0LHX`09FB<02MbTP0WO9L0:7RF029WT00DRh`0
9G^F03=dUP0/NIL087:G01i^T`0_M9D0AGbJ01iZTP0:I8l03Uj;01]>Q00DNHl07VV?02=QT@0QLI40
8gbE01ejT`0MLY<09G2G035fU`1:OI/02VR9015@Q@0CHHH0=W:H02U]U00QK9806WB@01U/T00HH900
66J@02IcTP0BG8T08VRB00mTU@0VLi80:7:I01]>P`0ACXD036:>00m]SP0BFX`07VNA02]_UP0AI8d0
4FZD01eUT@0FG8/04FB?019UT00KHi007V>?01IYS@0PJ8l4000000030;no_`3oool0oooo01T0oooo
2?ooool000Kooooo<03oool00`2EUID0@4100000000:0000002<00LL9P0B?4`05Di[01UHRP0XK9H0
?GjM01USSP0@Hhl02EV;02AeTP0KJi006fN;01]WSP0KFXX08f::02^9U`0RO9<0>7FI01m^U@08IhT0
6VZ?03=_UP0PLY806fN@01iVU00LHi@05eN<02MdV00hKiL093eh02YlU`0OKYD056B@01=SS`0NJY40
:VfA02i_TP0OKI@03VJC02EEP@0cH8T05WR?01QLT00@LI<05fN?01AOSP0MH8/0;V^?02QaU00JM980
97RG02QfU@0IJI808cEa01=NQ`0?JXh06V>A00iOS`0EI900>7:H02UZU00gP9`05g>>00]mR@0O@GL0
65F801YKRP0@Gh/09W6E03=kV00OJY0076J@029iU@0DC8807V>B03enW@0IHhh046>?00eNS@0GIhl0
7VnA01YWS@0KIhd06f6>01a<PP0aSIT067jA041gVP0WL9H03VV<01YZS`0XKI<0<G6F01U^T00NHi80
76>D01==R00QMIP0<W6G02U:P00YK8l08g>F01QWTP0BHXl06FN@02Q^TP0/Jhh0;g>E00iVT`0UEH40
<f29021`S@0GJY0056NB01EZT@0DGhh065j<02aTR00`LIH05g:@029iV00XMYD07FbC0252N@0HDH00
3V^>01=WS`0GH9405FB@03QbV00PHI00>W^L029gT`0>NhX06U1l01UCQP0IG8/05ef901QYT00kOYX4
000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo;03oool00`2_[jl0L71`0410@00:0000
002@00dJ7`0=<T40=fAg03Z3W00WMIP0876F01Y[TP0KII<0<GJJ04^5X@0AI8l05eb@00QGR`0ZOYP0
76ZA01YSRP0IH8d05e:802=KRP0dP9/08WRA03EaUP0dMI/02F6601a[T@0RHI804VF=01aNS00UHi80
86JE01IKTP0ZKiT0>fjD02HlMP0WNiP07FNC01IKT@0@GXh07VZA02ATS00XIHd08fjF015ZU00VF8<0
95R300mfS@0BE8`03FRD011XT00BHHl075R902eSS00YKI405Vf=02EhT`0YJ8h0;WFF02HlMP0FHXT0
4FR?029RT@0=GHh03f:@03A`UP0/JiD0?hRM00ihS00=R8T08d1e01]>Q@0OHH/05fF>031gV@0oQ9d0
9gFH01m]UP0SNIH04Eb>02A^U`1;QJ404FB?01MLT00@FXh06F^B025aT`0IHh`06V6;01MGS00GB800
?86N01]kT00eKi@0=7BI01AVR`0LJi408VRC01ePT00BI8`095j?021VU@0AE8l096nK03E^UP0[BGh0
9f^@021^U@0HGi804Ef?01MVS`0YJi006eN203AbU`0AJY@09UR302AHP`0FK8X04FF=011NT00?J940
4V6?01UIR`0TEX<0=FnD015XRP0SOID0:FR>02ebU00XBWh06eF3011[S`0GII007Un@00mRT00dL9H0
85n@04>2WP0NOI803HB:01iBNP0LCH<07Eb;01eUS00QKY@0AhJO100000000`2o_kl0oooo0?ooo`0I
0?ooo`Sooooo0006ooooobP0oooo00<0_kno0820P010@4002P000000U00241/01b/n00a1FP0A@WL0
?GFE02YjU`0WKi<0;W2F03=dU`0PKI<06V>A02miV00[OiP05f:B01MXU`0SGXh03V2<02QOR@0RGhh0
8WBF02QaUP0RH9406U^?02UUT@0aLiH0:Fb@06NGZ@0GGI4046BC01EJT@0;ChP04Tb201aHQP0OI8`0
5V2A01UOT@0bGHL05FBB01eST`0RK9@07VFC019OT00WKIH0=fbA021PRP0BIXl04FR>011_S007H8`0
46J<01=MQ@00Fhd02fb>01=WT00?Fhl04En;01UJQ@0DDH4056J:02QHQ@1^RZ405VJA019OT00BII40
7VN@01=HR@0AEXP08FNB01aXTP0RMI@02VJ:011^S`0AJ8X04Tn2039YT00`N9H0:GFE02e`U@0cM9L0
:W:E00]QSP0YII@0=HfK01MRTP0GJ9L08ej>01UOS@0KH8/095n=025]U00VM9H0:6>B01EIS`0SGXh0
>gZJ01AMR01BRJ40:fbG011TT`0AHI804eB=00]=Q00JDX@07fB<01MPT00AH9@0:Uj:01aRS`0KHi<0
86VD021XU00EH9406VFB03adUP0/FhD04fB?015XSP0@Kh`01f2<00eTS00BHXT02Ub900MWSP0CIi00
4U^@00MKS@0KHhT05TQm00eZR`0XF8D0GGjJ02a_U@0DHY004F2@01IWT@0LHHd04EJ8025WTP0GHY00
9GBE019[S@0?K8h04FZ;019AP`0XGXX0>7JF02UgUP0ZKi@4000000030;no_`3oool0oooo01T0oooo
2?ooool000Kooooo903oool00`2o_kl0T92@051@D00:0000002H01TP8P0M<3h084=L01UKQ`0=FXd0
6UZ=0193O@0>FX`093ad02m[U@0WJi<056V>00]_SP0?Li006fjE01mjT`0ENHd03E^?02EVU@0BFhP0
5F6@02=0M@0FEHP02fFC01m/U00SJ9805V:>029/SP0QNiL06FfD01i^TP0AK9H035b?025QT@0GHHl0
5V6?02QbUP0cOI/08FVB01QNTP0dLYT02VZ=029UT@0@JY<08VJB025VT`0]MYT0<WfJ02=^U00GJi40
46j?01V8S00DG8h036b:01=YS001FH`03fb>01=ZT00?Hi406G2D021^T@0FFXL08f^B01iPSP0ZA7L0
56J801ITS@0CFXL056F50219N00YAW`0=VfG03Q]U00UIY<025N;01eRTP0B@gd03eB801m4NP0[FhX0
:f^D01UZT00;Khh03WF?019`T00TK9X06HR<00eKS`0UIYD04U^801ANS00LDH<06Tj200eRT@0HJY@0
;6^C015PS`0QIH/097nG01M]U@0LKY<056fE00aLS`0DFhh08V>A01=PSP0PJI<0<gfK02M_T`0?Ehl0
:f^G01E/T00LIY005VRB01aWT`0SIY<09FnF03N1W00XM9D07FNC011^S`0IR8`055b>00mWR`0@Jh/0
2V6<00]VS@0CJY0046:A00]UT00WNiP04E>302A_T`0NH8h09d]m01YNQ00FIH/05En;019LQ@0IGH00
:DIl03I]U`0kKY@0<VbE019LSP0HGi005D^200mBQ`0IBh009dQl02e[U@0PJY44000000030;no_`3o
ool0oooo01T0oooo2?ooool000Kooooo803oool00`3?cll0T92@051@D00:0000000g00@<4P059c`0
42e@0158LP1BQj80>VfB02iYS`0VKi@086ZC03U`UP0>BH80:FR>00mRS@0iPYh0:EB801IeRP0?Lhh0
562A01]TT`0ZJiH09FRD009KS@0KBX401f2B03QoVP0GK8/07fN@01UTR@0HHHL07fF=02]bU@0]NiL0
4g2>02egU`0lPIh04FbF01ITT@0OK9407V2B01QFQ`0FGHP06FR@01a[TP0CJI00662@00ihS00BL900
47>;01m/T00[LYD0;WBF02afUP0VLiD06VJB015OT@0203AbV@14021eT@0RII4025N;02IfUP0RKY40
7FZ>029`U@0HH98075j>03mlU`0UFX<0:h>I02MEP@0XGHd045V>01]3O00FCX009fN?05J7XP0YHHX0
;gFF01=TS`17OId03TV2029PR`0FI8d0:gNH035[T`0KKHX03g>>01=PT@0GH9807VND03I_U`02Fhd0
6dZ100MPTP0PL9H0:7JC01eYSP0LI8`05f6601eRRP0TK9<0>7nJ00a^S00XM9D0=gjL01aaV00FI940
6fJ@021[TP0KFHh05UR501UXT00PJY804Fb@01IST00ALXd04G:?015bS@0JKXl0:G2E02ieU`0/LiH0
:WZG029/TP0AGi4203AbV@0M02MdU00QKI405Ej>01a/TP0RKY406VF<02IhU00MJ9H03U2904N7WP0U
FX<0:WVD02QQQ`0XFhT07Ef@00i@Q`0M@gX09fN?05J7XP0TF8D0<g:C01aZT@0jMiX075J9021NRP0L
IHh06VZA03EgV@0RHHT0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooooad0oooo00<0
_kno06YZJP0L71`02P0000003@042`d04S]901I<L@0RHI804FBE00YTU@06Ehd03V2B00YTU@0?DhP0
65>702Y_V01@PI`00P0]E800:`09Fhd06FBC02X_K00IF8P07f2;01mCR00ZKiT0;W:I01AISP09Fhd0
:62A00ECRP0EF8<0;EB001M/R`0S@7D0:Dn0021ZT`0HH8h04EV300iUR@0ZNYL0:62A015/UP0DGHP0
4Ff<03AfU`0TE8D07eV7021ZTP0BII00;7NC02eDP00<K8X06FBC01EHP`0HF8`0=G^L04:2WP0dK9H0
7F:?015XTP0AK9H00P0AI9D02@1KT:D03gB?015TS@0dLYL0:FjH01=NS00PII00:W:M02=aV00200a/
RP0<02^3V@0EF8<08ej>01MSU00:I9D01UV>00QGS@0?I9D02eb?01M;P@0II9<0Fi2U0P0]E800:`0B
FHX0566A029:P00NCX407f2;02IDQ00ADXl0@hbR01UHS`09Fhd0:62A00ECRP0=EXL08EJ201iTR00M
DWh0:DAi02A/T`0II9<05ER300AKQ00[PiT0:FVC01MYU@0DGHP04f6701]eTP0fJY806Tf1021ZTP09
Fhd0:h>I02ePQP0DIXP05VJA01ILR00GF8T0;W:I04:7X00jLIP0:62A015TS@0AK9H00P0AI9D01`12
PJ00=H:J011/SP0YKY@0:FjH019PS`0EF8<00P0ZLYd200a/RP0B02=mU@0KHhT07eb:021QTP0?I9D0
1f2B00QGS@0?I9D01fBE019;PP0HG8d0BhFQ03USR@0]E8006eR700eMS`0MEhT093ig100000000`2o
_kl0oooo0?ooo`0I0?ooo`Sooooo0006oooooaT0oooo00@0clo?09FEU@1PH600410@2@000000?001
1PT01a`]010lF`0DCgD0<Fb?06VDZ@0FHHl03WZ>00mdS`0GJ980=W:H07>L[018Q:@0:g^K03ImVP0k
MY/09VbJ01UHS`0<K8X06FBC02^3V@13S:80<hJL01idT`0@L8d06fj?03IfVP0_O9h025^E00QTS@0Z
LYd025^E02X_K00GEhD0BHFO03F6V@0:J8`02EV;01=TS`0ZKiP0AGfL00A5PP0]E8006eN2019JS00R
JY8066:@01EPT@0II9<05F:B015QT@0ZLYd04FBE04><XP0XH9409f^C03QdV00eMI`085Z<01ACQ080
4FB=01d05T9k00UKS@13S:8026B=02X_K00;D8D03F2@029[V00JIiD03UZ>01UKT00HHHl05ER308BX
/P0IF8l04G>>00mfS`0GJ980<g6H0563X01^Vjd0:WJL0320V@10MiX0:W:M01UHS`0?Ih/05VJA02Ei
U`0203N8WP0I01idT`0@JXd03Wb=02QPT@13S:8025^E00QTS@0ZLYd06FNI01U5P@0NBWd0=WZI0469
W@0<LX`01E>:015TS@0II9<0Fi2U01YHR`0SD8406eN201AIQ`0GH9008VZB01=MT00201UTT`0:00UK
S@0RK9T05fRG03N2W`0aKiL0:6RB03AcU`0kMY/09FJE01I2N`804FB=01l05T9k00UKS@0`O9/09WRH
01U:O@0EAGd03F2@01mYUP0ZLYd02E^=01UHS`0II9<05ER306RDYP0dK9P056Z>00iiSP0BL9008fVE
0563X01^Vjd0:W:M02]oVP0kNYX0<7>L01eOT`0@IH`04fR?01i/U@0aQI/0?HZP00@0000000<0_kno
0?ooo`3oool06@3oool8ooooo`001_oooolE0?ooo`040>[ZjP2PX:00H61P020P80T0000005d01PT:
00dS;P0G@EH04Tie01AIQP09E8P03T^301A:PP0AGHl04F:>00mKT@0;FY405ER301QHS00CHI@05D^2
039UT00YKYP0=WZM04V1X00GFY<0:W:M00mdS`05DhX0@7NJ01UHS`0DH9<04E^B01iRUP0YLIP0:Dn0
0291NP0AI9D016B300UKS@0?M8l01E>:029gU@0NHi806ER?01UNT@0FHI804F6?015]S00DFhP04FBE
02^3V@0XM9D0:6BB02M[T`0CHXl04F2@01IVT@0;J8/02f6>00mdS`0II9<06ER?02M_T`0=D8H06f6=
02QXTP0MGY007VNF03EeW010MiX02E^=00mdS`0II9<0@7NJ05^@Y@0dMiP09fnC01aUT@0CFXT045J5
00U?QP0EB8004E^?015TS@0AFhl02U^D019IR00HF8`0562C019LS`0QCh<0=7:I02A_V@1<N8X02cAJ
00hT<@043a<020000000700;31/022a2008hBP07A6X036:500YTS@0HJi808VjD01UHS`0IFi006FBC
015KS`0?M8l05ER3019QT@0UNiP0:7BE02MZTP0XI98086ZB00eMS`0FIY4036b:00UKS@0>KXl05fRB
01UKT00RIi8201IJR`0T02M[T`0RGi404E^?02YbW@10MiX02E^=00mdS`0FJI80;FjG04j4X011P9`0
9fnC021XTP0AFhl05ER300ECRP0F@W/04E^?015RSP0AGHl03E^B00aJS`0FF8H05e^A019LS`0QCh<0
@7NJ01eYUP19QJ4096:E02AZVP0HLi@02VB=01ALSP0fKiL05e^A100000000`2o_kl0oooo0?ooo`0I
0?ooo`Sooooo0006oooooa40oooo00@0kno_0:2PX01PH600820P2@000000H@031`T021`U00PiB@0A
FG/09eJ601MWU@0GIhl04fRC00mWR`0MLi8076F;01YKR@0LJ9L036B@025aUP0IHI809WRD00iRT00>
G9002eb5029SS@0PHY806fJE01m^U`0CJI007EnC015XU00>H9806HR<02HiM@0CEXX03VFE031hW00f
N9/05UV;02aTT01WUj/0I9NV00edS@0AJ8h04TIo02IJQ00NHHl056B?01=QR@0KIH`0:GRG02aaUP0F
HI408V6B03]jVP0^OIT07V>;01I]SP0NMi@0;WjJ031iV00GHHX0;7>K04R9X00CI8l0=VnG015PS`0:
FH/04FV>01EaT00LKI407FVE029]UP0]LID0<W2G025`TP0BL9007FnG02MFQP0KHi405fNB01AXTP0@
J8h05Fb<01m^T00IFHL096bJ00AMS@0UNIL06F6C029`T`0>HY003Eb@00iAO00<<d/042<`00462@0E
5AD0D51@0:2PX03Ogml01@3oool01@3_knl0_kno0:n_[`20P800L71`0080@41003h00000008B6`0=
:S`06TYZ01IST00AI8X05U^702EiU`0dMYL04V6A01iQTP0eM9P0;WfI02EbTP0IH8T06GFB02UkV00`
NIP04ef5029/V@0oPYh086fC02e/U@0MII803E^=00mUS@0ELY0066jA029ZTP0GJ9L0;G6E039`U`0Q
L9805g2A01Q`U00RHhl07en>01MWTP0EIi404FRD00iWR00RMiD05E>102A/VP0<HI007G:E01eYU00K
Hi807W6C00UKS`0?GHd04Un602iVT`0HGi807f^G01E]TP0JHY805FFD011TT`0AJY4077B601m4O@@0
000000<0_kno0?ooo`3oool06@3oool8ooooo`001_ooool>0?ooo`030>[ZjP20P800>CTi00d00000
00<02a@J0000000000001`00000040021`/02B0_00h]?`0?@el05dYZ02a_V01VW:X09W2G01aOT00N
B7/06U27015BR`0UIi<0=7RK00]PSP0DII@201ITU01105bOY00[IhX0566>01AVTP0fOY`0;gjJ011Q
S`0IH9<0<G^O03ekW@08HH/04FBB015SR00mMYD096B<01YUS00KIhl07VB@02E/TP0FJX`07FnB04Z0
WP0QJYL076fC00iDQP0AG8H06FB9029/T@0PJY@04UV;02]YUP0_LiT03gB=02mbU@0>IY<04E6600]K
QP0DJXd076fC01IRS`0NIXh09fnC035dW00@J8P046V>00UKSP0CCHP07FBA025bU@0JL9D04fNC01MY
TP0GJI<08fVB06JFZ`0JJ9407ER501YNS`0bHgL03c0o000:40000000:b/[0820P03EeMD04@3oool0
?@2ZZZX0@41000000000000011TR00/^A@0SG7`066Z;00iYSP0kNYX0:g2I01a]T`0EHX`0356301ER
R00OJHh086ZD00YER00YIYD0;W2H01MdT00WLi<06FZD011HRP0=EhD03VN;01e_T`0HJ9@055b902M_
T`0aM9`046R8011YS00=HXh03UB;01YLSP0QLYD077>E015WU@0EIi006VjF00eJRP1VUZ/0;GBH01aL
R00KG8`0<gBJ056=Y00EH9407eN901a7N`0IEi0034n903AdVP0GIi404F>B01ETU00FI9@0:7>H052A
WP0RIH`0100000000`2o_kl0oooo0?ooo`0I0?ooo`Sooooo0006ooooo`X0oooo00@0kno_0:2PX01[
Jf/0<30`3P0000001010@400D51@0820P02EUID60;no_`040:2PX020P800P82006][J`80@41004`0
<30`0000000Q:Rd042Xj01<fD`0R?V<09eN801]HS00WJiL0:W6I00]KSP0EJ9D05F2A015PT01?QZ<0
@hZO01m[U00FFX/09VJ=02EgU00NJ8h07Ej=01UdU`0CJ8l02eb<00ePT@0MO9@0<7RI01ePR@0NI8/0
96VC02AWT`0UL9<05FR<01a[T00eQYT07eb;01A[S@0<HXX04Ej801=NR00DHhl05FJD01QPSP0PG8X0
8eb:01f0T`0YNIH0:WbL01]AP`0WIH`09WBC01IYTP0NI940:FbA02M_T`0YJIL02fB8011/SP07Eh`0
2e>=01EQS`0LJXl07fRA01IOT@0CHI4076VD02QZT01>JgH04S5100HA7`0210P0820P061PH02EUID0
clo?5P3oool0>`3_knl0_kno0820P01@D500410@004=4@0492h094A@01]?KP0DJhd03VZ<00aMR@0C
GXP0566;01EVU00FHHl07eb:029LRP0OMi409W^E02YkVP0PGh`08eb802]eU00IKY404F2B02]XS`0W
Ki<0:FVG00]TR00>JH`036:=00UES@0BG8l076Z?01mZT00MHY<03eb?01aZU00JIiD0HY2V02m_TP0P
HhX08V2:039XTP13Nih07VNC021NT00aFhL07e>801UJSP0^LiX04f2@019TT`0EHi804f2A025ZU@1<
Qj80=WjK00@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_ooool60?ooo`040>o_k`2o_kl0
L71`030`<0`0000000D0<30`051@D020P800[jn_0=CDe00C0?ooo`160;no_`2PX:00L71`0410@000
00001PlD00PK9P047Rh01bm800dbBP0;A6803dY^01=HO`0fNYd09VfH021UT00VIXd0:g:E02=ZT`0P
IY00:h>I00edS00@K8h0<WJI01elU00VKYD06Ub801IMR@0LHY407fJB01]/T`0JHY405VZ?01]fT00I
E8D046b:00]^RP0?IX`066R?01MYT@0CJI<05FFA019GQ`0OF8P0:h>I02UiUP0TL9H05Uf802a^U00[
LYH08fZC03E`V00eHhd0:Dn001]^S`0=H8d046bB00aXSP0?EXd065R901=5K00D@fL03C=@00DN;`08
5A`000000410@020P800_kno0=oOgal0oooo00@0clo?09FEU@1`L700<30`0P000000<0023Q8011TS
00@J900<=d/053Q:00`gD`0HAfd0:7RE02YlU`0VLiH06fB=02IYT00cMYT07fZA02UYU@10MiX0:Dn0
01]^S`0=H8d03fR@00iZT00>Ghh05EN:01UCP`0HE8H07F:C01QSU00YCh00:g^K02]MR`0EGX`06V^B
025VS`0NGXd066BC01][T`0FLID0=7JJ02]JR@0ZII@05f:C01MOT00BGHl046B?00i;K@0:=U803RPi
018Q:0@0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_ooool30?ooo`030;no_`20P800<30`
00X0000000D0:b/[051@D020P800_kno0>o_k`0N0?ooo`030=oOg`2o_kl0[jn_0080P8200300D51@
0410@00P8200000000@:3@0;7bL05Rlj01]0E`0?D6l056J202a/S@0@L9403X6;04>1X@0@Hhl07VFA
015MR`0NIY00:G>G02MeU`0ZKYL04Ef@01A_T`0PJY<0AGjN01e[T@0:M8L04VV=01YUT@0dMYT0?gNH
01U>Q00IGI007VNF02]kV`0LJY@05eZ>01=PR@0@FHX05F:=029^TP0VJY<09dYo02X_K00AFV/02SaK
00P/@P047B@200000005020P8010@400H61P09FEU@2o_kl0:@3oool0;`3Zj^X0_kno0:n_[`20P800
H61P0410@00P8200000000HA4`0?:cP03cmO00mBN00@G8T04U^<01m^T00YKY@08fFB02X_K00KMY00
6VNE01=XTP0@JXl04F>>01mOS`0NFHX03eF800ePT@0RJiP07TYm025SRP0HDhL03ef?011LT00CFi00
5EZ>01AKS00DJY@06G6D02i_VP0HGY<06FR500i3HP0?:T000a4K0000000`<300H61P0080P82000D0
_kno00000000000000000;no_`0K0?ooo`Sooooo0006ooooo`030820P00`<300000000T0000000@0
:b/[061PH02PX:00kno_;03oool0;@3Zj^X0_kno092@T01PH600@410000000031@P011TU00I7A00G
AV8034AZ00mMS`0:IHh07g6F031fV@0_Ki<0<fF>01YJRP0=H9004F2@04R:WP0NM9804WJ=01EYS`0J
II40@82N0525W`0HC8808F2A021JS00MLiH046bB01eNT00IGX`03eF:00UHPP0;Ael01RTn00<>6000
0000<30`051@D020P800_kno0>[ZjP0f0?ooo`0U0=oOg`2PX:00H61P02/[:`0000000PhI00<U>`0:
CfP07TYm00]LT01GK8l09fnC01i[U@0LF8@05UV4029]T`0XLIL05V>B00]JS@07Eh`05FBD015TT@0B
Gh@04F2D00iLT00?Kh`046j=01EHQ@0KA7`03F>B019JP00J@ED00QLU0000000`<300P8200;no_`06
0?ooo`<0000000<0_kno0?ooo`3oool06@3oool8ooooo`001_ooool00`0[:b/00000000000060000
000302/[:`20P800eMGE03H0oooo01P0eMGE09FEU@1EEED05ADE0000000220`023U800iINP0MHY<0
8UJ:01a7O00SE8<01UF;00UKS@0<K8X03WR<01IZTP0CI8l086^A03EnV`0bP9d01Uf?01QLS@0F@W/2
00mdS`03015KS`0ABFd01al`0080000000<0EEEE0:ZZZP3oool0?`3oool00`3Zj^X0UIFE0410@002
0000000600HQ<P1HL7L09fnC015TS@0R@GL07TYm0P0fNYT00`0AH8h03ER=00ECRP02015TU@0<00il
S@08FiD02E^?00^1R@0=QHX04eef01HO@P023aP0000002/[:`1aLG40eMGE2@3oool3000000030;no
_`3oool0oooo01T0oooo2?ooool000Kooooo00<0H61P0000000000000P000000100P8200H61P09FE
U@3?cllm0?ooo`0K0>[ZjP2PX:00D51@010@400<61h05cM;00L^AP0C?5X06d1S00UEQ00<SXL046n<
015TT`0RHI80:62A01MJSP0>FX`08F>9018nJ00R?f0023Y800P/?P053Q<0410@05EEE@2PX:00kno_
04D0oooo01P0kno_0:ZZZP1`L700<30`0000000>:C002CE600A8JP0<Afh0441[00e5KP0=BFh03DA[
00]MJP07A6X003mQ00TbA`0L@Dl03b/i00<=4`000000@410092@T03?cll<0?ooo`<0000000<0_kno
0?ooo`3oool06@3oool8ooooo`001_ooool01@2PX:00410@05EEE@2@T900clo?04D0oooo00H0[jn_
0820P020P800D51@0410@00@410700000003010@4010@400@4100080P82000<0clo?0?ooo`3oool0
B`3oool00`3_knl0X:2P06][J`080410@005051@D020P800P820092@T03?cll0403oool300000003
0;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo
2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3
000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo
01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo
bP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3o
ool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool0
00KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool300000003
0;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo
2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3
000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo
01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo
bP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3o
ool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool0
00KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool300000003
0;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo
2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3
000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo
01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo
bP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3o
ool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool0
00KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool300000003
0;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo
2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3
000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo
01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo
bP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3o
ool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool0
00KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool300000003
0;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo
2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3
000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo
01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000Kooooo
bP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3o
ool0oooo01T0oooo2?ooool000KooooobP3oool3000000030;no_`3oool0oooo01T0oooo2?ooool0
0?Oooooo003gooooo`00\
\>"],
  ImageRangeCache->{{{0, 246.312}, {110.875, 0}} -> {-24.5281, -10.0021, \
4.73514, 4.73514}}],

Cell["Fig. 4.2 Exercise (4).", "Caption",
  CellTags->"Fig. 4.2"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Identify the proper boundary conditions for this problem,  determine the \
eigenmodes, and show that the frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " are given by solutions to"
}], "Text",
  CellTags->"i:49"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_1\)(2\ \[Omega]\_n\ \@\(\[Alpha]\ a/g\)) = 
        0\)]],
  "."
}], "Text"],

Cell[TextData[{
  " Find these frequencies for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"10", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1/4\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". Plot the wave height and horizontal fluid displacement associated with \
the first three eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". (Hint: The horizontal fluid displacement does ",
  "not",
  " vanish at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ": waves can move up and down the \"beach\" where the wave depth vanishes. \
You can, of course, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help solve the required differential equation for the spatial \
dependence of the modes. )"
}], "Text"],

Cell[TextData[{
  StyleBox["(c) ",
    FontWeight->"Bold"],
  " Find the inner product with respect to which these eigenmodes are \
orthogonal, and solve the following initial value problem, animating the \
solution for wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\ \(\(sec\)\(.\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z(x, 0)\  = 
        0.3\ \[ExponentialE]\^\(\(-3\) \((x - 5)\)\^2\)\)]],
  ",\t  ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\& . \)(x, 0)\  = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)(a)",
    FontWeight->"Bold"],
  " Suppose that a tidal estuary extends from ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ", where it meets the open sea. Suppose the floor of the estuary is level,  \
but its width is proportional to cylindrical radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " (a wedge-shaped estuary, like Moray Firth in Scotland; see Fig. ",
  ButtonBox["4.3",
    ButtonData:>"Fig. 4.3",
    ButtonStyle->"Hyperlink"],
  "). Then using the same method as that which led to Eq. ",
  ButtonBox["(3.1.78)",
    ButtonData:>{"Chapter3.nb", "(3.1.78)"},
    ButtonStyle->"Hyperlink"],
  ", show that  the water depth ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, t)\)]],
  " satisfies the following wave equation:"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) z = 
        g\ h \( 1\/r\) \(\[PartialD]\/\[PartialD]r\) \((r \(\[PartialD]\/\
\[PartialD]r\) z)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity and ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the equilibrium depth. (Note that no \[Theta] dependence is assumed; \
boundary conditions along the upper and lower sides of the estuary are ",
  "von Neumann",
  ", so this ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  "-independent solution is allowed.)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000^b000`400?l00000o`00003obP3oool0
0<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3o
ool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00I@3oool00`20P800000000000002
00000080P8200`3oool00`20P8000000000000020820P5H0oooo001T0?ooo`030820P00000000000
00D0000000<0P8200?ooo`0000001@0000000`20P800oooo0?ooo`1C0?ooo`00I03oool400000004
0820P03oool0oooo0?ooo`D000000`3oool00`20P800oooo0?ooo`1C0?ooo`00I03oool4000000D0
oooo1000001I0?ooo`00I03oool3000000L0oooo0`00001I0?ooo`00I03oool3000000L0oooo0`00
001I0?ooo`00I03oool00`20P8000000000000070?ooo`<00000F@3oool006D0oooo0`0000060?oo
o`<00000F@3oool006H0oooo00<0P82000000010@4001@3oool3000005T0oooo001Y0?ooo`800000
0`3oool3000005T0oooo001[0?ooo`80000000@0oooo0000000000000000F@3oool006d0oooo1000
001I0?ooo`00I@3oool20820P0L0oooo0`00001I0?ooo`00I03oool01020P8000000000000000006
0?ooo`<00000F@3oool006@0oooo00@0P82000000000000000001P3oool3000005T0oooo001T0?oo
o`040820P00000000000000000H0oooo0P0000000`20P800oooo0?ooo`1G0?ooo`00I@3oool01020
P800000000000030`<030?ooo`050<30`0000000000000000030`<00F@3oool006P0oooo00<0P820
0000000000000`00001L0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?oo
o`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo0005
0?oookd00000203oool000D0oooo_@0000020820P0H0oooo00050?oookl000001P3oool000L0oooo
00<0P8200000000000000P00002e0?ooo`<000001P3oool000P0oooo1@00000^0?ooo`040820P000
0000000000000880oooo0`0000060?ooo`002@3oool00`20P800000000000002000000030820P03o
ool0oooo02X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000;0?ooo`@0000000<0
P8200?ooo`3oool0:@3oool01020P80000000000000000220?ooo`<000001P3oool000/0oooo00<0
P8200000000000000P00000[0?ooo`040820P0000000000000000880oooo0`0000060?ooo`00303o
ool5000002X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000=0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool09P3oool01010@40000000000000000220?ooo`<00000
1P3oool000l0oooo100000000`20P800oooo0?ooo`0U0?ooo`<00000P`3oool3000000H0oooo000?
0?ooo`030820P00000000000008000009`3oool300000880oooo0`0000070?ooo`00403oool50000
02H0oooo0`0000220?ooo`<000001`3oool00140oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0R0?ooo`<00000PP3oool3000000L0oooo000C0?ooo`@0000000<0P8200?ooo`3oool0
8@3oool300000880oooo0`0000070?ooo`004`3oool00`20P80000000000000200000280oooo1000
00220?ooo`<000001`3oool001@0oooo1@00000Q0?ooo`@00000PP3oool3000000L0oooo000E0?oo
o`D00000803oool3000008<0oooo0`0000070?ooo`005P3oool00`20P80000000000000200000003
0<30`03oool0oooo01/0oooo100000230?ooo`<000001`3oool001L0oooo00<0P820000000000000
0P00002T0?ooo`<000001`3oool001P0oooo1@00002S0?ooo`<000001`3oool001T0oooo1@00002R
0?ooo`<000001`3oool001X0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2M0?oo
o`040820P00000000000000000L0oooo000K0?ooo`030820P0000000000000800000W`3oool40000
00L0oooo000L0?ooo`D00000WP3oool3000000P0oooo000M0?ooo`D00000W@3oool3000000P0oooo
000N0?ooo`030820P000000000000080000000<0`<300?ooo`3oool09P3oool40820P0030<30`03o
ool0oooo00D0oooo0`20P81S0?ooo`040820P00000000000000000P0oooo000O0?ooo`030820P000
00000000008000009P3oool2000000050820P03oool0oooo0?ooo`20P8000P0000050?ooo`@00000
HP3oool4000000P0oooo000P0?ooo`D000004@3oool00`000000P8200?ooo`0?0?ooo`040820P000
00000000000000H0oooo0P0000030?ooo`D00000HP3oool4000000P0oooo000Q0?ooo`D000003`3o
ool4000000l0oooo00<0P820000000000000203oool010000000P8200?ooo`3oool5000000030820
P03oool0oooo05l0oooo100000080?ooo`008P3oool00`20P800000000000002000000030<30`03o
ool0oooo00X0oooo100000000`20P800oooo0?ooo`0<0?ooo`040820P00000000000000000T0oooo
00D000000820P03oool000000410@0020?ooo`80P820H@3oool3000000030820P03oool0oooo00H0
oooo000S0?ooo`030820P00000000000008000002`3oool01@20P8000000000000000000P82000l0
oooo100000090?ooo`040820P00000000000000006D0oooo00D0P82000000000000000000820P008
0?ooo`00903oool5000000X0oooo00D0P82000000000000000000820P00?0?ooo`@000002@3oool0
1020P800000000000000001U0?ooo`050820P0000000000000000020P800203oool002D0oooo1@00
00090?ooo`@00000403oool4000000X0oooo0`00001U0?ooo`050820P0000000000000000020P800
203oool002H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`040?ooo`@0000000<0
P8200?ooo`3oool03P3oool4000000X0oooo00@0P820000000000000@410I03oool01@20P8000000
000000000000P82000P0oooo000W0?ooo`030820P00000000000008000001@3oool400000180oooo
1000000;0?ooo`<00000I03oool01@20P8000000000000000000P82000P0oooo000X0?ooo`D00000
0`3oool4000001@0oooo1000000:0?ooo`@00000H`3oool4000000T0oooo000Y0?ooo`D0000000<0
oooo0820P00000000P0000000`20P800oooo0?ooo`0B0?ooo`@000002P3oool4000006<0oooo1000
00090?ooo`00:P3oool00`20P800000000000006000001D0oooo00D0@41000000000000000000<30
`0090?ooo`0300000020P800000000800000HP3oool4000000T0oooo000[0?ooo`030820P0000000
000000@000005`3oool3000000030820P03oool0oooo00L0oooo00<000000?ooo`0000000`00001Q
0?ooo`<000002P3oool002`0oooo1@00000I0?ooo`<00000203oool2000000030?ooo`20P8000000
00800000H03oool4000000X0oooo000/0?ooo`H000006@3oool3000000L0oooo0P0000000`3oool0
P82000000002000000030820P03oool0oooo05d0oooo0`00000;0?ooo`00;P3oool00`20P8000000
00000002000000030<30`03oool0oooo01H0oooo00@0P820000000000000P820103oool00`10@400
P8200?ooo`020?ooo`<0000000<0@4100?ooo`3oool0G@3oool3000000/0oooo000_0?ooo`030820
P00000000000008000006`3oool5000006L0oooo1000000;0?ooo`00<03oool5000008H0oooo0`00
000<0?ooo`00<@3oool5000008D0oooo0`00000<0?ooo`00<P3oool5000008@0oooo0`00000<0?oo
o`00<`3oool01@10@4000000000000000000@4100880oooo00@0P8200000000000000000303oool0
03@0oooo1@0000210?ooo`<0000000<0P8200?ooo`3oool02P3oool003D0oooo1@0000200?ooo`<0
000000<0P8200?ooo`3oool02P3oool003H0oooo1@00001o0?ooo`<0000000<0P8200?ooo`3oool0
2P3oool003L0oooo00D0@41000000000000000000410@01m0?ooo`050820P0000000000000000030
`<00303oool003P0oooo1@00001l0?ooo`040820P00000000000000000d0oooo000i0?ooo`D00000
N`3oool01020P800000000000000000=0?ooo`00>P3oool5000007X0oooo1000000=0?ooo`00>`3o
ool01@10@4000000000000000000@41007T0oooo0`00000>0?ooo`00?03oool5000007P0oooo0`00
000>0?ooo`00?@3oool5000007H0oooo1000000>0?ooo`00?P3oool5000007D0oooo0`00000?0?oo
o`00?`3oool01@10@4000000000000000000@41007<0oooo00@0P82000000000000000003`3oool0
0400oooo1@00001b0?ooo`<00000403oool00440oooo1@00001a0?ooo`<00000403oool00480oooo
1@00001_0?ooo`@00000403oool004<0oooo00<0@4100000000000000P0000000`30`<00oooo0?oo
o`1[0?ooo`<0000000<0P8200?ooo`3oool03P3oool004@0oooo1@00001/0?ooo`050820P0000000
000000000020P800403oool004D0oooo1@00001[0?ooo`040820P0000000000000000140oooo0016
0?ooo`D00000JP3oool01020P800000000000000000A0?ooo`00A`3oool00`20P800000000000002
000000030<30`03oool0oooo06H0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`00B03oool00`20
P800000000000002000006P0oooo0`00000B0?ooo`00B@3oool5000006H0oooo1000000B0?ooo`00
BP3oool5000006D0oooo0`00000C0?ooo`00B`3oool00`20P800000000000002000000030<30`03o
ool0oooo0600oooo00@0P82000000000000000004`3oool004`0oooo00<0P8200000000000000P00
001R0?ooo`<00000503oool004d0oooo1@00001P0?ooo`@00000503oool004h0oooo1@00001O0?oo
o`@00000503oool003T0oooo1020P8060?ooo`80P8202P3oool00`20P80000000000000200000003
0<30`03oool0oooo05X0oooo00D0P82000000000000000000820P00D0?ooo`00>03oool7000000<0
oooo1@0000090?ooo`030820P0000000000000800000G03oool4000001D0oooo000g0?ooo`030820
P0000000000000D0000000<0P8200?ooo`0000001P0000090?ooo`D00000F`3oool4000001D0oooo
000g0?ooo`@0000000@0P8200?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo00P0oooo
1@00001I0?ooo`@000005P3oool003L0oooo100000050?ooo`@000003`3oool5000005P0oooo1000
000F0?ooo`00=`3oool3000000L0oooo0`00000@0?ooo`050410@0000000000000000010@400EP3o
ool4000001L0oooo000g0?ooo`<000001`3oool300000140oooo1@00001D0?ooo`@00000603oool0
03L0oooo00<0P8200000000000001`3oool300000180oooo1@00001C0?ooo`@00000603oool003P0
oooo0`0000060?ooo`<000004`3oool500000540oooo00D0P82000000000000000000820P00H0?oo
o`00>@3oool00`20P80000000410@0050?ooo`<00000503oool01@10@4000000000000000000@410
0500oooo00D0@41000000000000000000<30`00H0?ooo`00?03oool2000000<0oooo0`00000E0?oo
o`D00000C`3oool4000001T0oooo000n0?ooo`80000000@0oooo00000000000000005P3oool50000
04d0oooo1000000J0?ooo`00@03oool4000001L0oooo1@00001<0?ooo`@000006P3oool003P0oooo
0P20P8070?ooo`<00000603oool01@10@4000000000000000000@41004T0oooo0P20P803000001/0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000I0?ooo`D00000B03oool4000001`0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000J0?ooo`D00000AP3oool01@20P800
0000000000000000P82001`0oooo000g0?ooo`040820P00000000000000000H0oooo0P0000000`20
P800oooo0?ooo`0I0?ooo`D00000A@3oool01@20P8000000000000000000P82001`0oooo000h0?oo
o`040820P000000000000<30`0<0oooo00D0`<3000000000000000000<30`00L0?ooo`050410@000
0000000000000010@400A03oool4000001d0oooo000k0?ooo`030820P0000000000000<00000803o
ool500000480oooo1000000N0?ooo`00HP3oool500000440oooo0`00000O0?ooo`00H`3oool50000
03l0oooo1000000O0?ooo`00I03oool01@10@4000000000000000000@41003d0oooo00@0P8200000
000000000000803oool006D0oooo1@00000k0?ooo`050820P0000000000000000020P800803oool0
06H0oooo1@00000j0?ooo`040820P0000000000000000240oooo001W0?ooo`D00000>@3oool40000
0240oooo001X0?ooo`050410@0000000000000000010@400=`3oool01020P800000000000000000R
0?ooo`00J@3oool5000003H0oooo0`00000S0?ooo`00JP3oool5000003@0oooo0`00000T0?ooo`00
J`3oool5000003<0oooo0`00000T0?ooo`00K03oool01@10@4000000000000000000@4100300oooo
00D0P82000000000000000000820P00T0?ooo`00K@3oool5000002l0oooo1000000U0?ooo`00KP3o
ool5000002d0oooo1000000V0?ooo`00K`3oool5000002/0oooo1000000W0?ooo`00L03oool40000
00030820P03oool0oooo02P0oooo1000000W0?ooo`00L03oool00`30`<0000000000000200000003
0820P03oool0oooo02D0oooo00D0`<3000000000000000000410@00X0?ooo`00LP3oool5000002H0
oooo1000000Y0?ooo`00L`3oool5000002D0oooo1000000Y0?ooo`00M03oool4000000030820P03o
ool0oooo0240oooo1000000Z0?ooo`00M03oool00`30`<00000000000002000000030820P03oool0
oooo01h0oooo00D0P82000000000000000000820P00[0?ooo`00MP3oool5000001l0oooo0`000000
0`20P800oooo0?ooo`0Z0?ooo`00M`3oool5000001d0oooo00D0P82000000000000000000820P00/
0?ooo`00N03oool4000000030820P03oool0oooo01X0oooo1000000]0?ooo`00N03oool00`30`<00
000000000002000000030820P03oool0oooo01P0oooo00@0P820000000000000P820;P3oool007X0
oooo1@00000H0?ooo`@00000;`3oool007/0oooo1@00000F0?ooo`@00000<03oool007`0oooo1000
00000`20P800oooo0?ooo`0B0?ooo`050820P0000000000000000020P800<03oool007`0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0@0?ooo`050820P0000000000000000020P800
<@3oool007h0oooo1@00000@0?ooo`@00000<`3oool007l0oooo1@00000>0?ooo`@00000=03oool0
0800oooo1@00000<0?ooo`030820P0000000000000800000=03oool00800oooo00<0`<3000000000
00000P0000000`10@400oooo0?ooo`090?ooo`050410@0000000000000000030`<00=03oool00880
oooo1@0000090?ooo`@00000=P3oool008<0oooo1@0000070?ooo`@00000=`3oool008@0oooo1@00
00050?ooo`@00000>03oool008D0oooo00D0@41000000000000000000410@0030?ooo`050410@000
0000000000000030`<00>03oool008H0oooo1@0000000`3oool0000000000002000003X0oooo0027
0?ooo`T00000>P3oool008P0oooo1`00000k0?ooo`00R@3oool01@10@4000000000000000000@410
03`0oooo002:0?ooo`800000?P3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{67.5625, 62.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.3 Exercise (10).", "Caption",
  CellTags->"Fig. 4.3"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The tidal motion of the open sea is represented by the following \
Dirichlet boundary condition at the end of the estuary:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z(a, t)\  = \ h\  + \ d\ Cos\ \[Omega]\ t\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Find a bounded solution of the PDE that satisfies this boundary condition, \
along with the initial conditions\n\t ",
  Cell[BoxData[
      \(TraditionalForm\`y(r, 0) = h + d\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((r, 0)\) = 0\)]],
  ".\n Assume that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  \[NotEqual] \ \[Omega]\_n\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_n\)]],
  " are the eigenfrequencies of the normal modes."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " repeat part (b)",
  Cell[BoxData[
      \(TraditionalForm\`, \)]],
  " assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega]\_0\)]],
  ", the lowest eigenfrequency. "
}], "Text"],

Cell[TextData[{
  StyleBox["(11)(a)",
    FontWeight->"Bold"],
  " Find how much energy it takes to pluck a uniform string of mass density \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " and tension ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`T\)]]]], TraditionalForm]]],
  ", giving it a deformation of the form"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\_o\)(x)\), "=", " ", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(\(a\ x\)\(,\)\), \(\(\ \)\(\(0 < x < L/2\)\(,\)\)\)},
                    {\(\(a(L - x)\)\(,\)\), \(L/2 < x < \(\(L\)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " What fraction of the energy goes into each normal mode? "
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " A quantum particle is confined in a harmonic well of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V(x)\), "=", 
          RowBox[{\(1/2\), " ", Cell[TextData[{
              Cell[BoxData[
                  \(TraditionalForm\`m\)]],
              " ",
              Cell[BoxData[
                  \(TraditionalForm\`\[Omega]\_o\^2\)]]
            }]], \(x\^2\)}]}], TraditionalForm]]],
  " . Using the results of Eq. ",
  ButtonBox["(4.1.32)",
    ButtonData:>"(4.1.32)",
    ButtonStyle->"Hyperlink"],
  " for the eigenfunctions and the energy levels of the quantum harmonic \
oscillator, determine the  evolution  of the particle wavefunction ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  ", starting with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](x, 0)\)\(\ \)\(=\)\(\[Delta](
          x - x\_o)\)\(\ \)\)\)]],
  ". Animate this evolution with a table of  plots of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0.01 < t < 6\)]],
  ", taking dimensionless units ",
  Cell[BoxData[
      \(TraditionalForm\`m = \(\[Omega]\_o = \(\[HBar] = 1. \)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  "  A thick  rope of length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  " and with mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is spliced at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " to a thin rope of the same length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " with mass per unit length ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\^\[Prime]\)]],
  ". The ropes are tied to posts at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]L\)\)]],
  " and subjected to uniform tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". Analytically find the form and the frequency of the first three \
eigenmodes of this composite rope. Plot the eigenmodes, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\^\[Prime] = \[Rho]/4\)]],
  ". (Hint: Match separate trigonometric solutions for the modes across the \
splice. To do so, consider the mass elements in the two ropes that are \
adjacent to one another at the splice. According to Newton's third law, the \
forces of each element on the other must be equal and opposite. What does \
this say about the angle \[Theta] each element makes with the horizontal? \
[See. Fig. ",
  ButtonBox["3.3",
    ButtonData:>{"Chapter3.nb", "Fig. 3.3"},
    ButtonStyle->"Hyperlink"],
  " and Eq. ",
  ButtonBox["(3.1.5)",
    ButtonData:>{"Chapter3.nb", "(3.1.5)"},
    ButtonStyle->"Hyperlink"],
  ".])"
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " A nonuniform rope is stretched between posts at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ", and is subjected to uniform tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ".  The mass density of the rope varies as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho]\_o\ \((L/x)\)\^4\)]],
  ". Find the eigenmodes and eigenfrequencies for this rope. Plot the first \
three eigenmodes. "
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A hanging string is attached to the ceiling at ",
  Cell[BoxData[
      \(TraditionalForm\`z = L\)]],
  " and has uniform mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " and nonuniform tension due to the acceleration of gravity ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ". To the end of the rope at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " is attached a mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". The string motion is described by the function ",
  Cell[BoxData[
      \(TraditionalForm\`y(z, t)\)]],
  " as it moves in the ",
  Cell[BoxData[
      \(TraditionalForm\`y - z\)]],
  " plane, and the mass also moves in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " with position ",
  Cell[BoxData[
      \(TraditionalForm\`Y(t) = y(0, t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  Find the equations of motion of this coupled mass-string system, and \
find the eigenmodes of the system. Determine and plot the first three  \
eigenmodes numerically  for the case where ",
  Cell[BoxData[
      \(TraditionalForm\`m = 2\ \[Rho]\ L\)]],
  ".  (Hint: The string eigenmodes satisfy a ",
  StyleBox["mixed",
    FontSlant->"Italic"],
  " boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ", obtained by considering the horizontal acceleration of the mass due to \
the string tension.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show numerically that the eigenmodes are orthogonal with respect to the \
inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\( \[Rho](
            z)\) \[DifferentialD]z\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](z) = \ \[Rho] + m\ \(\[Delta](z)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " An initially straight, horizontal rope of mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", length ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  ", and tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " runs from ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-L\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  ". A mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is placed on the center of the rope at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ".The gravitational force causes the rope to sag, and then bounce up and \
down. Call the vertical position of the mass ",
  Cell[BoxData[
      \(TraditionalForm\`Y(t)\)]],
  ", and of the rope ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ".  The point of the problem is to study the motion of this coupled \
mass-string system."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Assuming that the rope takes on a triangular shape as it is depressed by \
the mass, and neglecting the mass of the rope itself, find the restoring \
force on the mass and show that the mass oscillates sinusoidally about an \
equilibrium position ",
  Cell[BoxData[
      \(TraditionalForm\`\(-y\_eq\)\)]],
  " at a frequency of ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2  T/m\ L\)\)]],
  ". [We found ",
  Cell[BoxData[
      \(TraditionalForm\`y\_eq\)]],
  " in Exercise (11) of Sec. ",
  ButtonBox["3.1",
    ButtonData:>{"Chapter3.nb", "c:23"},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In fact, the rope does not  have a triangular shape during the motion. We \
will now do this problem properly, expanding in the eigenmodes of the system. \
 Using symmetry, we expect that ",
  Cell[BoxData[
      \(TraditionalForm\`y(\(-x\), t) = y(x, t)\)]],
  " during the motion, so we solve only for the motion in the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ". Show that the string is described by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"y", "=", 
            RowBox[{\(\(y\_eq\)(x)\), "+", " ", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], "(", \(x, t\), ")"}]}]}], 
          ","}], TraditionalForm]]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`y\_eq\)]],
  " is the equilibrium string displacement due to gravity (including the \
effect of the mass), and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the deviation from equilibrium, described by  a superposition of \
eigenmodes of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(x) = 
        sin\ \(\(\[Omega]\_n\)(L - x)\)/c\)]],
  ", where the eigenfrequencies satisfy the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_n\) L\)\/c\ \(tan(\[Omega]\_n\ L/
                c)\)\  = M/m\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " For ",
  Cell[BoxData[
      \(TraditionalForm\`M/m\  = \ 1\)]],
  " find the first 10 eigenmodes numerically, and show that they are \
orthogonal.  with respect to the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\( \[Rho](
            x)\) \[DifferentialD]x\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) = \ \[Rho] + m\ \(\[Delta](x)\)/2\)]],
  "(the factor of two arises because only half the mass is supported by the \
right half of the string)."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Using these eigenmodes, find and plot ",
  Cell[BoxData[
      \(TraditionalForm\`Y(t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  " s,  assuming that the string is initially straight and that the mass \
starts from rest at ",
  Cell[BoxData[
      \(TraditionalForm\`Y = 0\)]],
  ".  Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"L", "=", 
            RowBox[{"1", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], ",", \(m = \(M = 0.5  kg\)\), ",", 
          " ", 
          RowBox[{"g", "=", 
            RowBox[{"0.3", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], "/", 
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], "2"]}]}]}], ",", "  ", 
          RowBox[{\(and\ T\), "=", 
            RowBox[{"0.25", 
              StyleBox["N",
                FontSlant->"Plain"], " "}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Sometimes the mass does not quite make it back to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["Y",
            "TraditionalForm"], "=", "0"}], TraditionalForm]]],
  " during its motion, and sometimes it actually gets to ",
  Cell[BoxData[
      \(TraditionalForm\`y > 0\)]],
  ". This is in contrast with the sinusoidal oscillation found in part (a).  \
Why is the energy of the mass not conserved?"
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " Write an expression for the total energy as a sum over the eigenmodes and \
the energy of the mass involving its position ",
  Cell[BoxData[
      \(TraditionalForm\`Y(t)\)]],
  " and velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\& . \)(t)\)]],
  ". Show directly that this energy is conserved in your simulation by \
evaluating it as a function of time."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " In a bow, a bowstring under tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " with length ",
  Cell[BoxData[
      \(TraditionalForm\`2  L\)]],
  " carries a mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " at its center. The mass is pulled back a distance ",
  Cell[BoxData[
      FormBox[
        RowBox[{"d", 
          RowBox[{"<<", 
            StyleBox["L",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ", and released, starting from rest. Use energy conservation to determine \
the speed of the mass as it leaves the string, assuming that the string takes \
on a triangular shape at all times during its motion. (Hint: at some point \
the mass comes off the string. You will need to identify this point.)"
}], "Text",
  CellTags->"i:50"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " Repeat the previous exercise but do it properly using the eigenmode \
approach of Exercise (16). Solve the equations of motion numerically, keeping \
20 modes, using the same parameters as Exercise (16), and taking ",
  Cell[BoxData[
      \(TraditionalForm\`d = 10\ cm\)]],
  ".  Compare the final energy of the mass to that obtained in Exercise (17). \
"
}], "Text"],

Cell[TextData[{
  StyleBox["(19)(a)",
    FontWeight->"Bold"],
  " A sound oscillation in a cubic enclosure of length ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\ m\)]],
  " and volume ",
  Cell[BoxData[
      FormBox[
        RowBox[{"V", "=", " ", 
          RowBox[{"1", " ", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "3"]}]}], TraditionalForm]]],
  "has the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](x, 
          t)\  = \ \[Eta]\_o\ sin\ \((\[Pi]\ x/
                L)\)\ \(cos(\[Omega]\ t)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \ c\ \[Pi]/L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(\ \)\)\)]],
  "= 340 m/sec,  and the  maximum displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_o\)]],
  " of the air is  0.1 mm.  Find the kinetic energy ",
  Cell[BoxData[
      \(TraditionalForm\`K(t)\)]],
  " (in Joules), where",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(K(
          t)\  = \[Integral]\_V\[DifferentialD]\^3 
              r\ \[ScriptCapitalM]\ \ \(\(\[Eta]\& . \^2\)(x, t)\)\)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptCapitalM]\)]],
  " is the mass density of air at atmospheric pressure."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U(t)\)]],
  " in Joules , and find the total energy in this sound oscillation. [Hint: \
Sound waves satisfy Eq. ",
  ButtonBox["(4.2.48)",
    ButtonData:>"(4.2.48)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3 Poisson's Equation in Two and Three Dimensions", "Subtitle",
  CellTags->"c:23"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["4.3.1 Introduction. Uniqueness and Standard Form", "Subsubtitle",
  CellTags->"c:24"],

Cell[TextData[{
  ButtonBox["Poisson's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Poisson.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " equation is the following partial differential equation:"
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \(-\[Rho]\)/\[Epsilon]\_o\)]],
  "."
}], "NE4",
  CellTags->"(4.3.1)"],

Cell[TextData[{
  "The constant  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Epsilon]\_o = \ \(8.85 ... \)\[Cross]10\^\(-12\)\),
            "TraditionalForm"], 
          RowBox[{
            StyleBox["F",
              FontSlant->"Plain"], "/", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "  is the permittivity of free space. This PDE determines the electrostatic \
potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " (measured in volts) within a specified volume, given a charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " (in ",
  Cell[BoxData[
      \(TraditionalForm\`Coulombs\ per\ cubic\ meter\)]],
  ")  and boundary conditions on \[Phi] at the surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " of the volume (see Fig. ",
  ButtonBox["3.8",
    ButtonData:>{"Chapter3.nb", "Fig. 3.8"},
    ButtonStyle->"Hyperlink"],
  "). The boundary conditions are either Dirichlet, von Neumann, or mixed \
(see the introduction to  Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:24"},
    ButtonStyle->"Hyperlink"],
  " for a  description of these boundary conditions.)"
}], "Text",
  CellTags->"i:109"],

Cell[TextData[{
  "\tFor Dirichlet and mixed boundary conditions, the solution of Eq. ",
  ButtonBox["(4.3.1)",
    ButtonData:>"(4.3.1)",
    ButtonStyle->"Hyperlink"],
  " exists and is unique. The proof of uniqueness is the same as that given \
for the Laplace equation in Sec. ",
  ButtonBox["3.2.1",
    ButtonData:>{"Chapter3.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  ". Existence will be shown by construction in  Sec. ",
  ButtonBox["4.3.3",
    ButtonData:>"c:26",
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  "\tHowever, for the von Neumann conditions that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"], 
              "\[CenterDot]", \(\[Del]\[Phi]\)}], \( | \_S\)}], "=", 
          RowBox[{\(E\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is unique only up to an additive constant: if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfies Eq. ",
  ButtonBox["(4.3.1)",
    ButtonData:>"(4.3.1)",
    ButtonStyle->"Hyperlink"],
  " with von Neumann conditions, then  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] + C\)]],
  " also satisfies it. Also,  for von Neumann boundary conditions, a solution \
only exists if the boundary conditions are consistent with Gauss's law,"
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Integral]\_S\), 
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["n",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"], 
                "\[CenterDot]", \(\[Del]\[Phi]\)}], \(\[DifferentialD]\^2 
                r\)}]}], "=", \(\(-Q\_enc\)/\[Epsilon]\_o\)}], 
        TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`Q\_enc = \[Integral]\_V \[Rho] \[DifferentialD]\^3 
              r\)]],
  " is the charge enclosed by the domain.  Gauss's law is merely the integral \
form of Eq. ",
  ButtonBox["(4.3.1)",
    ButtonData:>"(4.3.1)",
    ButtonStyle->"Hyperlink"],
  ", obtained by applying the divergence theorem to this equation. An \
analogous result was obtained for the Laplace equation [see Eq. ",
  ButtonBox["(3.2.3)",
    ButtonData:>{"Chapter3.nb", "(3.2.3)"},
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tIn order to solve Eq. ",
  ButtonBox["(4.3.1)",
    ButtonData:>"(4.3.1)",
    ButtonStyle->"Hyperlink"],
  ", we first put the PDE in standard form, by converting the inhomogeneous \
boundary conditions to a source function, just as we did  for the wave and \
heat equations. That is, we write"
}], "Text",
  CellTags->"i:54"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[CapitalDelta]\[Phi]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["+",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["u",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.3)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is a function chosen to match the boundary conditions. The remainder, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ", then satisfies Poisson's equation with a new source,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[Del]\^2 \[CapitalDelta]\[Phi] = \(-\[Rho]\&_\)/\
\[Epsilon]\_o\)\(,\)\)\)]]], "NE4",
  CellTags->"(4.3.4)"],

Cell["where ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_ = \[Rho]\  + \ \(\[Epsilon]\_o\) \[Del]\^2 
              u\)]],
  "."
}], "NE4",
  CellTags->"(4.3.5)"],

Cell["\<\
The boundary conditions on \[CapitalDelta]\[Phi] are homogeneous \
conditions of either Dirichlet, von Neumann, or mixed type. \
\>", "Text"],

Cell[TextData[{
  "\tThe choice for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is arbitrary, but, as always, the simpler the choice, the better. \
Sometimes it is convenient to choose ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " to satisfy Laplace's equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = 0\)]],
  ".  As we will see in Sec. ",
  ButtonBox["4.3.4",
    ButtonData:>"i:67",
    ButtonStyle->"Hyperlink"],
  ", this choice for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is particularly useful if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  ", or if the inhomogeneous boundary conditions are rapidly varying. \
Techniques specific to the solution of Laplace's equation were developed in \
Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:24"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3.2 Green's Function", "Subsubtitle",
  CellTags->"c:25"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(4.3.4)",
    ButtonData:>"(4.3.4)",
    ButtonStyle->"Hyperlink"],
  " can be solved using a ",
  ButtonBox["Green's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Green.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " function. The Green's function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox[
              SubscriptBox["r", 
                StyleBox["o",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[")",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              SubscriptBox["\[Del]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]], "2"], 
            RowBox[{"g", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "o"]}], ")"}]}], "=", 
          RowBox[{"\[Delta]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], ")"}]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->{"i:55", "(4.3.6)"}],

Cell[TextData[{
  "where the subscript ",
  StyleBox["r ",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "on ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          SubscriptBox["\[Del]", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"]], "2"], TraditionalForm]]],
  "is placed there to remind us that the derivatives in the Laplacian are \
with respect to ",
  StyleBox["r",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " rather than ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ". The boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " are the same homogeneous boundary conditions required for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi]\)]],
  ". The vector \[Delta]-function in Eq. ",
  ButtonBox["(4.3.6)",
    ButtonData:>"(4.3.6)",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "-", 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"],
              FontSlant->"Italic"]}], ")"}], TraditionalForm]]],
  ", is a \[Delta]-function at a point in space, i.e.,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], ")"}], 
          "=", \(\(\[Delta](x - x\_o)\) \(\[Delta](y - y\_o)\) \(\[Delta](
              z - z\_o)\)\)}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.7)"],

Cell[TextData[{
  "One can see that this Green's function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Italic"], 
                StyleBox["o",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[")",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " is simply the potential at position ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " produced by a point charge at position ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " with \"charge\" -",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_o\)]],
  ". In free space, with the boundary condition that the potential equals \
zero at infinity, we know that this Green's function is simply the ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  " ",
  ButtonBox["Coulomb",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Coulomb.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " potential:"
}], "Text",
  CellTags->"i:111"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain",
                FontSlant->"Plain"], 
              StyleBox[
                SubscriptBox["r", 
                  StyleBox["o",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]],
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontSlant->"Plain"]}], "=", 
          RowBox[{"-", 
            FractionBox["1", 
              RowBox[{\(4  \[Pi]\), "|", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}], "|"}]]}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->{"i:56", "(4.3.8)"}],

Cell[TextData[{
  "However, when the potential and or its normal derivative is specified on a \
finite bounding surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", the Green's function is more complicated because of image charges \
induced in the surface."
}], "Text"],

Cell[TextData[{
  "\tAssuming that the Green's function has been determined, the potential \
\[CapitalDelta]",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " can  then be obtained using a multi-dimensional version of Eq. ",
  ButtonBox["(2.4.30)",
    ButtonData:>{"Chapter2.nb", "(2.4.30)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], " ", "=", " ", 
          RowBox[{\(-\(1\/\[Epsilon]\_o\)\), 
            RowBox[{\(\[Integral]\_V\), 
              RowBox[{
                RowBox[{"g", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain",
                      FontSlant->"Plain"], 
                    StyleBox[
                      SubscriptBox["r", 
                        StyleBox["o",
                          FontWeight->"Plain",
                          FontSlant->"Italic"]],
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], 
                  StyleBox[")",
                    FontSlant->"Plain"]}], 
                RowBox[{\(\[Rho]\&_\), "(", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], ")"}], 
                RowBox[{\(\[DifferentialD]\^3\), 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}]}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE4",
  CellTags->{"i:59", "(4.3.9)"}],

Cell[TextData[{
  "where the volume integral extends over the volume ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " .  To prove Eq. ",
  ButtonBox["(4.3.9)",
    ButtonData:>"(4.3.9)",
    ButtonStyle->"Hyperlink"],
  ", we simply apply the Laplacian ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          SubscriptBox["\[Del]", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"]], "2"], TraditionalForm]]],
  " to each side, and using Eq. ",
  ButtonBox["(4.3.6)",
    ButtonData:>"(4.3.6)",
    ButtonStyle->"Hyperlink"],
  " we have"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              SubscriptBox["\[Del]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]], "2"], 
            RowBox[{"\[CapitalDelta]\[Phi]", "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}], " ", "=", 
          RowBox[{
            RowBox[{\(-\(1\/\[Epsilon]\_o\)\), " ", 
              RowBox[{\(\[Integral]\_V\), 
                RowBox[{
                  RowBox[{
                    SuperscriptBox[
                      SubscriptBox["\[Del]", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]], "2"], 
                    RowBox[{"g", "(", 
                      RowBox[{
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontWeight->"Plain",
                          FontSlant->"Plain"], 
                        StyleBox[
                          SubscriptBox["r", 
                            StyleBox["o",
                              FontWeight->"Plain",
                              FontSlant->"Italic"]],
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}], 
                      StyleBox[")",
                        FontSlant->"Plain"]}]}], 
                  RowBox[{\(\[Rho]\&_\), "(", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"], ")"}], 
                  RowBox[{\(\[DifferentialD]\^3\), 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"]}]}]}]}], "=", 
            RowBox[{
              RowBox[{\(-\(1\/\[Epsilon]\_o\)\), 
                RowBox[{\(\[Integral]\_V\), 
                  RowBox[{
                    RowBox[{"\[Delta]", "(", 
                      RowBox[{
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "-", 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "o"],
                          FontSlant->"Italic"]}], ")"}], 
                    RowBox[{\(\[Rho]\&_\), "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], ")"}], 
                    RowBox[{\(\[DifferentialD]\^3\), 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"]}]}]}]}], "=", 
              RowBox[{"-", 
                FractionBox[
                  RowBox[{\(\[Rho]\&_\), "(", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ")"}], \(\[Epsilon]\_o\)]}]}]}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.10)"],

Cell[TextData[{
  "Also, the homogenous boundary conditions for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi]\)]],
  " are satisfied, because these same boundary conditions apply to ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ". For example, if the boundary conditions are Dirichlet, then ",
  Cell[BoxData[
      \(TraditionalForm\`g\  = \ 0\)]],
  " for any point ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " on the surface ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(,\)\)\)]],
  " and then Eq. ",
  ButtonBox["(4.3.9)",
    ButtonData:>"(4.3.9)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi] = 0\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " as well."
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(4.3.10)",
    ButtonData:>"(4.3.10)",
    ButtonStyle->"Hyperlink"],
  " has a simple physical interpretation: since -",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain",
                FontSlant->"Plain"], 
              StyleBox[
                SubscriptBox["r", 
                  StyleBox["o",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]],
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontSlant->"Plain"]}], "/", \(\[Epsilon]\_o\)}], 
        TraditionalForm]]],
  " is the potential at ",
  StyleBox["r",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " due to a unit charge at position ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ", we can use the superposition principle to determine the total potential \
at ",
  StyleBox["r",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " by superimposing the potentials due to all of the charges. When the \
charges form a continuous distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\)]],
  ", this sum becomes the integral given in Eq. ",
  ButtonBox["(4.3.10)",
    ButtonData:>"(4.3.10)",
    ButtonStyle->"Hyperlink"],
  "  If the charges are discrete, at positions ",
  Cell[BoxData[
      \(TraditionalForm\`r\_j\)]],
  ", each with charge ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(e\_j\)\(\ \)\)\)]],
  ", then the charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\)]],
  " is a sum of \[Delta] functions,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Rho]\&_\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{\(\[Sum]\+\(j = 1\)\%N\), 
            RowBox[{\(e\_j\), 
              RowBox[{"\[Delta]", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "j"]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "and  Eq. ",
  ButtonBox["(4.3.9)",
    ButtonData:>"(4.3.9)",
    ButtonStyle->"Hyperlink"],
  " implies that this collection of discrete charges produces the following \
potential:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], " ", "=", 
          RowBox[{"-", 
            RowBox[{\(\[Sum]\+\(j = 1\)\%N\), 
              RowBox[{\(e\_j\/\[Epsilon]\_o\), 
                RowBox[{"g", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ",", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "j"]}], ")"}]}]}]}]}], 
        TraditionalForm]]],
  " ."
}], "NE4",
  CellTags->"(4.3.11)"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.3.3 Expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " and \[Phi] in Eigenmodes of the Laplacian Operator"
}], "Subsubtitle",
  CellTags->"c:26"],

Cell[TextData[{
  "The Green's function can be determined as an expansion in eigenmodes ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " of the Laplacian operator. These eigenmodes are functions of the vector \
position ",
  StyleBox["r",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  ",  and are defined by the eigenvalue problem"
}], "Text",
  CellTags->"i:107"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Del]\^2\), 
            RowBox[{
              SubscriptBox["\[Psi]", 
                StyleBox["\[Alpha]",
                  FontSlant->"Plain"]], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}], "=", 
          RowBox[{\(\[Lambda]\_\[Alpha]\), 
            RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.12)"],

Cell[TextData[{
  "This PDE, the ",
  StyleBox["Helmholtz equation",
    FontSlant->"Italic"],
  ",  is subject to the previously described homogeneous boundary conditions. \
 Each eigenfunction ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " has an associated eigenvalue ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Lambda]\_\[Alpha]\)\(\ \)\)\)]],
  ". The subscript \[Alpha] is merely a counter that enumerates all the \
different modes. (We will see presently that this counter can be represented \
as a list of integers that take on different values for the different \
modes.)"
}], "Text",
  CellTags->"i:71"],

Cell["\<\
\tThese eigenmodes form a complete orthogonal set with respect to \
the following inner product:\
\>", "Text",
  CellTags->"i:73"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), "=", 
          RowBox[{\(\[Integral]\_V\), 
            RowBox[{
              RowBox[{\(f\^*\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{"g", "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{\(\[DifferentialD]\^3\), 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.13)"],

Cell["\<\
The proof is straightforward, given what we already know about \
eigenmodes of Hermitian operators. All we need do is show that the Laplacian \
operator is Hermitian with respect to the above inner product and with \
respect to functions that satisfy homogeneous  boundary conditions. We may \
then apply Theorems 4.1 and 4.2 (there is nothing in the proofs of these \
theorems that limits the operators in question to ODE operators as opposed to \
PDE operators).\
\>", "Text",
  CellTags->"i:72"],

Cell[TextData[{
  "\tIn order to show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " is Hermitian, consider the following quantity:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, \[Del]\^2 g)\), "=", 
          RowBox[{\(\[Integral]\_V\), 
            RowBox[{
              RowBox[{\(f\^*\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{\(\[Del]\^2\), 
                RowBox[{"g", "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}]}], 
              RowBox[{\(\[DifferentialD]\^3\), 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
By application of Green's theorem, this inner product can be \
written as \
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, \[Del]\^2 g)\), "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              "\[CenterDot]", \((\(f\^*\) \[Del]g - 
                  g \[Del]\(f\^*\))\)}], \( | \_S\), 
            RowBox[{"+", 
              FormBox[
                RowBox[{\(\[Integral]\_V\), 
                  RowBox[{
                    RowBox[{"g", "(", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}], " ", 
                    RowBox[{\(\[Del]\^2\), 
                      RowBox[{\(f\^*\), "(", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], ")"}]}], 
                    RowBox[{\(\[DifferentialD]\^3\), 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]}]}],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "However, the surface term on the ",
  "right-hand",
  " side vanishes for homogeneous boundary conditions of the Dirichlet, von \
Neumann, or mixed type, and the volume term is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((g, \[Del]\^2 f)\)\^*\)\)]],
  ". This proves that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " is Hermitian, and therefore the eigenmodes of  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " form a complete, orthogonal set with respect to the inner product of Eq. \
",
  ButtonBox["(4.3.13)",
    ButtonData:>"(4.3.13)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell["\<\
\tWe can use the eigenmodes to express the Green's function as a \
generalized Fourier series:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], ")"}], "=", 
          RowBox[{\(\[Sum]\+\[Alpha]\), 
            RowBox[{\(c\_\[Alpha]\), 
              RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}]}]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.14)"],

Cell[TextData[{
  "The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Alpha]\)]],
  " are obtained by substituting Eq. ",
  ButtonBox["(4.3.14)",
    ButtonData:>"(4.3.14)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(4.3.6)",
    ButtonData:>"(4.3.6)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sum]\+\[Alpha]\), 
            RowBox[{\(c\_\[Alpha]\), 
              RowBox[{
                SuperscriptBox[
                  SubscriptBox["\[Del]", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]], "2"], 
                RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}]}]}]}], "=", 
          RowBox[{"\[Delta]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], ")"}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "If we then take an inner product of the equation with respect to one of \
the eigenmodes, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi]\_\[Beta]\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ", and apply Eq. ",
  ButtonBox["(4.3.12)",
    ButtonData:>"(4.3.12)",
    ButtonStyle->"Hyperlink"],
  ", we obtain "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\[Alpha]\( 
                  c\_\[Alpha]\) \[Lambda]\_\[Alpha]\ \((\[Psi]\_\[Beta], \
\[Psi]\_\[Alpha])\)\), "=", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(\[Psi]\_\[Beta]\), "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}], ",", 
                RowBox[{"\[Delta]", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "-", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"]}], ")"}]}], ")"}], "=", 
            RowBox[{\(\[Psi]\_\[Beta]\%*\), "(", 
              StyleBox[
                SubscriptBox["r", 
                  StyleBox["o",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]],
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where in the last step we used Eqs. ",
  ButtonBox["(4.3.7)",
    ButtonData:>"(4.3.7)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(4.3.13)",
    ButtonData:>"(4.3.13)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(2.3.29)",
    ButtonData:>{"Chapter2.nb", "(2.3.29)"},
    ButtonStyle->"Hyperlink"],
  ". However, orthogonality of the eigenmodes implies that the only term in \
the sum that survives is the one for which ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \ \[Beta]\)]],
  ", which allows us to extract a single Fourier coefficient:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_\[Beta]\), "=", 
          RowBox[{
            RowBox[{\(\[Psi]\_\[Beta]\%*\), "(", 
              StyleBox[
                SubscriptBox["r", 
                  StyleBox["o",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]],
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], 
            "/", \([\[Lambda]\_\[Beta]\ \((\[Psi]\_\[Beta], \
\[Psi]\_\[Beta])\)]\)}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.15)"],

Cell[TextData[{
  "Applying this equation to ",
  ButtonBox["(4.3.14)",
    ButtonData:>"(4.3.14)",
    ButtonStyle->"Hyperlink"],
  ", we arrive at an eigenmode expansion for the Greens function:"
}], "Text",
  CellTags->"i:57"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"]}], ")"}], "=", 
        RowBox[{\(\[Sum]\+\[Alpha]\), 
          FractionBox[
            RowBox[{
              RowBox[{\(\[Psi]\_\[Alpha]\%*\), "(", 
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["o",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                ")"}]}], \(\[Lambda]\_\[Alpha]\ \((\[Psi]\_\[Alpha], \[Psi]\_\
\[Alpha])\)\)]}]}], TraditionalForm]]]], "NE4",
  CellTags->"(4.3.16)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(4.3.16)",
    ButtonData:>"(4.3.16)",
    ButtonStyle->"Hyperlink"],
  " is a general expression for the Greens function of the Poisson equation, \
and is called the bilinear equation. A similar expression can be obtained for \
the Green's function associated with any linear boundary value problem. This \
equation can be used in Eq. ",
  ButtonBox["(4.3.9)",
    ButtonData:>"(4.3.9)",
    ButtonStyle->"Hyperlink"],
  " to determine the potential \[CapitalDelta]\[Phi] from an arbitrary charge \
distribution ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\&_\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], " ", "=", " ", 
          RowBox[{\(-\(1\/\[Epsilon]\_o\)\), 
            RowBox[{\(\[Sum]\+\[Alpha]\), 
              
              RowBox[{\(\((\[Psi]\_\[Alpha], \[Rho]\&_)\)\/\(\[Lambda]\_\
\[Alpha]\ \((\[Psi]\_\[Alpha], \[Psi]\_\[Alpha])\)\)\), 
                RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ")"}]}]}]}]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.17)"],

Cell[TextData[{
  "where we have converted the volume integral over ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox["r", 
            StyleBox["o",
              FontWeight->"Plain",
              FontSlant->"Italic"]],
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to an inner product using Eq. ",
  ButtonBox["(4.3.13)",
    ButtonData:>"(4.3.13)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " is a generalized Fourier series for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi]\)]],
  " due to a charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\)]],
  ". It applies to any geometry, with arbitrary homogeneous boundary \
conditions. Inhomogeneous boundary conditions can be easily accommodated \
using Eqs. ",
  ButtonBox["(4.3.3)",
    ButtonData:>"(4.3.3)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.5)",
    ButtonData:>"(4.3.5)",
    ButtonStyle->"Hyperlink"],
  ". The only outstanding issue is the form of the eigenmodes ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi]\_\[Alpha]\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " and their associated eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\)]],
  "."
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\tIt appears from Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " that a solution for the potential can always be constructed. On the other \
hand, we already know that the solution does not necessarily exist; boundary \
conditions must satisfy Gauss's law, Eq. ",
  ButtonBox["(4.3.2)",
    ButtonData:>"(4.3.2)",
    ButtonStyle->"Hyperlink"],
  ". In fact, Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " only works if the eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\)]],
  " are not equal to zero.  For Dirichlet and mixed boundary conditions, it \
can be proven that this is actually true: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\  \[NotEqual] \ 0\)]],
  " for all modes.  The proof is simple: if some ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\  = \ 0\)]],
  ", then the corresponding eigenmode satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Psi]\_\[Alpha] = 0\)]],
  ", with ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " Dirichlet or mixed boundary conditions. However, we proved in Sec. ",
  ButtonBox["3.2.1",
    ButtonData:>{"Chapter3.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  " that this problem only has the trivial solution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha] = 0\)]],
  ". Therefore, the solution to Poissons equation with Dirichlet or mixed \
boundary conditions always exists."
}], "Text",
  CellTags->"i:61"],

Cell[TextData[{
  "\tOn the other hand, for the homogeneous von Neuman boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["n",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], 
            "\[CenterDot]", \(\[Del]\[Psi]\_\[Alpha]\)}], "=", "0"}], 
        TraditionalForm]]],
  ", the following eigenfunction satisfies the boundary conditions :  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_o = 1\)]],
  ". This eigenfunction also satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Psi]\_o = 0\)]],
  ", so the corresponding eigenvalue is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_o = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor von Neuman boundary conditions, a solution can only be obtained if \
the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_\)]],
  " satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_o, \[Rho]\&_)\) = 0\)]],
  ", so that the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_o\)]],
  " term in Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " can be dropped and division by zero can be avoided. This inner product \
implies  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_V\( \[Rho]\&_\) \[DifferentialD]\^3 r = 
        0\)]],
  ". Using Eq. ",
  ButtonBox["(4.3.5)",
    ButtonData:>"(4.3.5)",
    ButtonStyle->"Hyperlink"],
  " and applying the divergence theorem,  this  equation  can be shown to be \
the same as our previous condition for the existence of a solution, namely, \
Gauss's law,  Eq. ",
  ButtonBox["(4.3.2)",
    ButtonData:>"(4.3.2)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.3.4 Eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  "in Separable Geometries"
}], "Subsubtitle",
  CellTags->{"i:63", "c:27"}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:28"],

Cell[TextData[{
  "\t   In order to apply the generalized Fourier series, Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  ", for the potential within a specified domain ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " due to a given charge density and boundary condition on the surface of ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", we require the eigenmodes of  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  "in this domain.  For certain domain geometries, these eigenmodes can be \
determined analytically, using the method of separation of variables. We will \
consider three such geometries in the following sections: rectangular, \
cylindrical and spherical domains. These by no means exhaust the \
possibilities:  using separation of variables, analytic eigenmodes can be \
found in 11 different coordinate systems. [See ",
  ButtonBox["Morse and Feshbach (1953, Chapter 5)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  " .] "
}], "Text",
  CellTags->"i:120"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rectangular Geometry", "Section",
  CellTags->"c:29"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Rectangular Eigenmodes",
  FontWeight->"Bold"]], "Subsubsection",
  CellTags->"i:64"],

Cell[TextData[{
  "\tWe first solve for the eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " in a rectangular domain, as shown in Fig. ",
  ButtonBox["4.4",
    ButtonData:>"Fig. 4.4",
    ButtonStyle->"Hyperlink"],
  ". We will assume that the eigenmodes satisfy homogeneous Dirichlet \
boundary conditions at the surface of the domain,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\( | \_S\)\) = 0\)]],
  ". In physical terms, we are considering the ",
  StyleBox["z",
    FontSlant->"Italic"],
  "-independent eigenmodes inside a long grounded conducting tube with \
rectangular cross section. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:n0003Gb000`400?l00000o`00003oo`3ooooo
0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo
003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0
oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool0
0?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3o
ooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00
o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oo
ol00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o
0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo
`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0
ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo0
0?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3o
oooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooX@3oool4000000030820P03oool0oooo
00X0oooo0`00003o0?ooo`/0oooo003o0?oooil0oooo00<0P8200000000000001@0000000`20P800
oooo0?ooo`070?ooo`H00000o`3oool90?ooo`00o`3ooonM0?ooo`030<30`0000000000000T00000
00<0P8200?ooo`3oool01@3oool6000000030410@03oool0oooo0?l0oooo1P3oool00?l0ooooW@3o
ool00`20P80000000000000;000000H0oooo2000003o0?ooo`L0oooo003o0?oooid0oooo20000003
0820P0@0000000<0`<300?ooo`3oool00P3oool500000080oooo00<000000410@03oool0o`3oool5
0?ooo`00;@3oool00`20P80000000000000300000?l0ooooJ@3oool8000000H0oooo00<0P8200000
00000000103oool5000000<0oooo0P00003o0?ooo`D0oooo000[0?ooo`030820P0000000000000L0
0000o`3ooomW0?ooo`L00000203oool3000000<0oooo1@0000030?ooo`030820P0000000oooo0?l0
oooo103oool002T0oooo0P20P803000000@0P820100000000`20P800oooo0?ooo`3o0?ooof<0oooo
1P0000000`20P800oooo0?ooo`070?ooo`060<30`000000000000<30`03oool0P8201@0000020?oo
o`030<30`0000000P8200?l0oooo103oool002P0oooo00<0P8200000000000000P0000060?ooo`03
0820P0000000000000800000o`3ooomT0?ooo`H0000000<0P8200?ooo`3oool02@3oool200000080
oooo1@00003o0?ooo`T0oooo000W0?ooo`050820P0000000000000000010@400203oool00`20P800
000000000002000000030820P03oool0oooo0?l0ooooH03oool6000000030<30`03oool0oooo00X0
oooo00@0@41000000020P800@410100000000`20P800oooo0?ooo`3o0?ooo`H0oooo000W0?ooo`@0
000000<0P8200?ooo`3oool01`3oool00`20P80000000000000200000?l0ooooHP3oool600000003
0820P03oool0oooo00/0oooo1`0000000`20P800oooo0?ooo`3o0?ooo`H0oooo000V0?ooo`030820
P00000000000008000002`3oool4000000030820P03oool0oooo0?l0ooooG`3oool6000000030820
P03oool0oooo00/0oooo1`0000000`20P800oooo0?ooo`3o0?ooo`H0oooo000V0?ooo`@0000000<0
P8200?ooo`3oool02@3oool00`20P80000000000000200000?l0ooooHP3oool5000000030820P03o
ool0oooo00`0oooo00<0P8200000000000001000003o0?ooo`P0oooo000U0?ooo`D000003@3oool5
00000?l0ooooH@3oool5000000030820P03oool0oooo00d0oooo1P00003o0?ooo`P0oooo000U0?oo
o`D000003@3oool500000?l0ooooH@3oool5000000030820P03oool0oooo00d0oooo00<0P8200000
000000000`00003o0?ooo`P0oooo000T0?ooo`D000003`3oool500000?l0ooooH03oool00`20P800
000000000003000000l0oooo00<0`<300000000000001000003o0?ooo`L0oooo000S0?ooo`030820
P0000000000000<000003`3oool5000000030820P03oool0oooo0?l0ooooG@3oool00`20P8000000
0000000300000100oooo1P00003o0?ooo`L0oooo000S0?ooo`030410@000000000000080000000<0
@4100?ooo`3oool03@3oool00`10@400000000000002000000030410@03oool0oooo0?l0ooooGP3o
ool5000000030820P03oool0oooo00h0oooo1@0000000`20P800oooo0?ooo`3o0?ooo`@0oooo000S
0?ooo`D0000000<0P8200?ooo`3oool03@3oool00`20P80000000000000300000?l0ooooH@3oool5
00000100oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?ooo`@0oooo000S0?oo
o`D0000000<0P8200?ooo`3oool03@3oool00`20P80000000000000300000?l0ooooH@3oool60000
00l0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?ooo`@0oooo000R0?ooo`03
0820P0000000000000<0000000<0P8200?ooo`3oool03@3oool00`20P80000000000000300000003
0820P03oool0oooo0?l0ooooGP3oool00`20P800000000000003000000030<30`03oool0oooo00`0
oooo00<0`<300000000000000`00003o0?ooo`H0oooo000R0?ooo`H0000000<0P8200?ooo`3oool0
3@3oool00`20P80000000000000400000?l0ooooH@3oool5000000030820P03oool0oooo00d0oooo
1@00003o0?ooo`H0oooo000R0?ooo`H00000403oool00`30`<0000000000000400000?l0ooooHP3o
ool5000000l0oooo1P00003o0?ooo`D0oooo000R0?ooo`H000004@3oool600000?l0ooooH`3oool5
000000h0oooo1P00003o0?ooo`D0oooo000Q0?ooo`L000004@3oool600000?l0ooooH`3oool00`20
P800000000000002000000h0oooo1P00003o0?ooo`D0oooo000Q0?ooo`L000004@3oool700000?l0
ooooH`3oool4000000030410@03oool0oooo00/0oooo1`00003o0?ooo`@0oooo000Q0?ooo`L00000
4@3oool700000?l0ooooI03oool5000000`0oooo1`00003o0?ooo`@0oooo000Q0?ooo`L000004@3o
ool700000?l0ooooI@3oool4000000`0oooo1`0000000`20P800oooo0?ooo`3o0?ooo`40oooo000Q
0?ooo`L000004@3oool700000?l0ooooI@3oool00`30`<00P82000000002000000030<30`03oool0
oooo00P0oooo0P0000000`20P800000000000002000000030820P03oool0oooo0?l0oooo0@3oool0
0240oooo1`00000A0?ooo`L00000o`3ooomW0?ooo`040820P00000000000000000X0oooo0P000000
0`20P800000000000002000000030820P03oool0oooo0?l0oooo0@3oool00240oooo1`00000A0?oo
o`L00000o`3ooomX0?ooo`80P8200P0000000`10@400oooo0?ooo`050?ooo`040410@0000000oooo
0<30`0D00000o`3oool30?ooo`008@3oool700000140oooo1`00003o0?ooofX0oooo00<0P8200000
000000000P0000040?ooo`8000000`3oool500000?l0oooo0`3oool00240oooo1`00000A0?ooo`L0
0000o`3ooom/0?ooo`P0000000<0P8200?ooo`3oool00P3oool00`20P80000000000000200000?l0
oooo0P3oool00240oooo1`00000A0?ooo`L00000o`3ooom^0?ooo`D0P8202@3oool00`30`<00P820
0?ooo`3o0?ooo`40oooo000Q0?ooo`L000004@3oool700000?l0ooooo`3ooon00?ooo`008@3oool0
0`20P80000000000000400000140oooo1`00003o0?ooool0ooooP03oool00280oooo1P0000000`20
P800oooo0?ooo`0>0?ooo`H00000o`3ooooo0?oooh40oooo000R0?ooo`H0000000<0P8200?ooo`3o
ool03P3oool600000?l0ooooo`3ooon10?ooo`008P3oool6000000030820P03oool0oooo00h0oooo
1P00003o0?ooool0ooooP@3oool00280oooo1P0000000`20P800oooo0?ooo`0=0?ooo`030820P000
0000000000@00000o`3ooooo0?oooh40oooo000S0?ooo`D0000000<0P8200?ooo`3oool03@3oool0
0`20P80000000000000300000?l0ooooo`3ooon20?ooo`008`3oool5000000030820P03oool0oooo
00d0oooo00<0P8200000000000000`00003o0?ooool0ooooPP3oool002<0oooo00<0P82000000000
00000`00000?0?ooo`030820P0000000000000<00000o`3ooooo0?oooh80oooo000S0?ooo`030820
P0000000000000<000003`3oool00`10@400000000000002000000030820P03oool0oooo0?l0oooo
o`3ooon00?ooo`00903oool5000000l0oooo1@00003o0?ooool0ooooP`3oool002@0oooo1@00000?
0?ooo`D00000o`3ooooo0?oooh<0oooo000U0?ooo`D000003@3oool00`20P8000000000000020000
00030820P03oool0oooo0?l0ooooo`3ooon10?ooo`009P3oool4000000d0oooo1000003o0?ooool0
ooooQ@3oool002H0oooo00<0@4100000000000000P00000;0?ooo`@0000000<0@4100?ooo`3oool0
o`3ooooo0?oooh<0oooo000W0?ooo`@0000000<0P8200?ooo`3oool01`3oool00`20P80000000000
000200000?l0ooooo`3ooon60?ooo`00:03oool4000000T0oooo00<0P8200000000000000P00003o
0?ooool0ooooQP3oool002P0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`040?oo
o`050820P0000000000000000010@400o`3ooooo0?ooohL0oooo000Z0?ooo`D00000103oool40000
0?l0ooooo`3ooon90?ooo`00:`3oool;00000?l0ooooo`3ooon:0?ooo`00;03oool20820P0D00000
00<0@4100820P03oool0o`3ooooo0?ooohX0oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo0
0?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3ooom^0?ooo`030<30
`000000000000080P820C@3oool00?l0ooooo`3ooom^0?ooo`030820P0000000000000@00000B`3o
ool00480oooo00<0`<300820P020P800o`20P81Z0820P0030<30`03oool0oooo0;/0oooo00<0@410
0000000000001P0000020820P4L0oooo00120?ooo`030820P000000000000?l00000JP0000000`20
P800oooo0?ooo`2k0?ooo`d00000A@3oool00480oooo00<0P820000000000000o`00001Z00000003
0820P03oool0oooo0;/0oooo3`0000130?ooo`00@P3oool00`20P80000000000003o000006X00000
00<0P8200?ooo`3oool0^`3ooolB000000<0P820?@3oool00480oooo00<0P820000000000000o`00
001Z000000030820P03oool0oooo0;X0oooo5`00000l0?ooo`00@P3oool00`20P80000000000003o
000006X0000000<0P8200?ooo`3oool0^P3ooolI000003X0oooo00120?ooo`030820P00000000000
0?l00000JP0000000`20P800oooo0?ooo`2j0?oooa/000000P20P80f0?ooo`00@P3oool00`20P800
00000000003o000006X0000000<0P8200?ooo`3oool0^P3ooolO000003@0oooo00120?ooo`030820
P000000000000?l00000o`00001900000080P820<03oool00480oooo00<0P820000000000000o`00
003o000004/0000000<0P8200?ooo`3oool0;@3oool00480oooo00<0P820000000000000o`00003o
000004T00000<P3oool00480oooo00<0P820000000000000o`00001Z000000030820P03oool0oooo
0;T0oooo00<0P8200000000000006`0000020820P3@0oooo00120?ooo`030820P000000000000?l0
0000JP0000000`20P800oooo0?ooo`2j0?oooa/0000000<0P8200?ooo`3oool0=@3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`2j0?oooaL00000
0P20P80j0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0;X0oooo5@00000n0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0;/0oooo4P0000100?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0;/0oooo3@0000000`10@400P8200<30`0120?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0;/0
oooo2`0000170?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0;/0oooo00<0P8200000000000001`0000180?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0;/0oooo00<0P8200000000000000P00
00000`10@400P8200820P01:0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0;/0oooo00<0P820000000000000C`3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0c@3oool3
000000l0oooo0`00000[0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0<`0oooo1@00000=0?ooo`D00000:P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3<0?ooo`H0000000<0`<300?ooo`3o
ool0203oool00`20P800000000000004000000030<30`03oool0oooo02H0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0c03oool7000000X0oooo
2000000X0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0<`0oooo200000090?ooo`T000009`3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3<0?ooo`<0000000@0P8200?ooo`3oool0@4100P00
00070?ooo`030820P0000000000000<000000P3oool00`10@40000000000000V0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0<`0oooo0P000005
0?ooo`80000000<0P8200?ooo`3oool0103oool6000000<0oooo0P0000000`20P800oooo0?ooo`0S
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0=<0oooo00<0P8200000000000001P3oool5000000D0oooo00<0P8200000003oool0903oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3E0?ooo`80
0000103oool6000000H0oooo00<0P8200000003oool08`3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3E0?ooo`030820P0000000P82000<0oooo
1P0000060?ooo`030820P03oool0oooo02<0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0e@3oool00`30`<0000000410@0030?ooo`D00000;@3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3G
0?ooo`040000003oool0oooo0820P0D00000;@3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3G0?ooo`040410@0000000oooo0820P0@0000000<0
P8200?ooo`3oool0:`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3G0?ooo`040820P000000000000820P0@0000000<0P8200?ooo`3oool0:`3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3H
0?ooo`L0000000<0P8200?ooo`3oool0:`3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3I0?ooo`H00000;P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3J0?ooo`D00000;P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3I0?ooo`H00000
;P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3I0?ooo`D00000;`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3H0?ooo`H00000;`3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3H0?ooo`D0000000<0@4100?ooo`3oool0;@3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3H0?ooo`L0
0000;P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3G0?ooo`030820P0000000000000D00000;P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3G0?ooo`030820P0000000000000<0000000<0
`<3000000010@400;@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3G0?ooo`H0000000<0oooo000000000000;@3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3G0?ooo`D0000000H0P8200?oo
o`3oool0@41000000020P80[0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0=H0oooo1P0000030?ooo`040820P000000000000820P2X0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0eP3oool6
000000@0oooo0`0000040?ooo`040820P000000000000820P280oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0e@3oool00`10@400000000000003
000000H0oooo00<0P8200000000000000P20P805000000030820P03oool0oooo01l0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0d`3oool80000
00L0oooo2P00000Q0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0<l0oooo2`0000000`20P800oooo0?ooo`050?ooo`030820P0000000000000L0
00008@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3?0?ooo`030820P010@400000000P0000000<0`<300?ooo`3oool01P3oool00`20P800@410
0000000600000240oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0e03oool5000000`0oooo1P00000R0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0=L0oooo0P20P80>0?ooo`<0P82000<0`<30
0?ooo`3oool0803oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0
oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0
oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0
oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0
oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000H0P8200?oo
o`3oool0oooo0820P030`<3o0?ooo`/0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool00P3oool200000?l0oooo2P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`020?ooo`040410@00000000000
0410@?l0oooo203oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`020?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3oool40?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo00<0
oooo1P00003o0?ooo`D0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool00`3oool00`20P800000000000004000000030410@020P800oooo0?l0oooo
0@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`040?ooo`T0000000<0P8200?ooo`3oool0o@3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`050?ooo`X0000000<0`<300?ooo`3oool0n`3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`050?oo
o`030820P0000000000000T00000o03oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`050?ooo`030820P0000000000000X0000000<0P8200?ooo`3o
ool0n03oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`060?ooo`h0000000<0P8200?ooo`3oool0mP3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`070?oooa000000mP3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`070?oooa400000m@3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`070?oo
o`030820P000000000000100000000<0`<300?ooo`3oool0l03oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`080?oooa@00000l@3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`080?ooo`030820
P00000000000018000000P20P83^0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo00T0oooo5`00003]0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo00X0oooo5`0000000`20P800oooo0?ooo`3Y
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
00X0oooo00<0@4100000000000005P0000000`20P800oooo0?ooo`3W0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo00X0oooo00<0P82000000000
00006000003X0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo00/0oooo700000000`20P800oooo0?ooo`110?ooo`X0P820V03oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`0<0?oooad0000000<0
P8200?ooo`3oool0?P3oool00`20P80000000000000:000009H0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0303ooolO000003l0oooo3`00002D
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
00d0oooo7`0000000`10@400oooo0?ooo`0i0?ooo`030<30`00000000000008000001`20P8070000
00030820P030`<00oooo08l0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool03@3oool00`20P80000000000000N000000030820P03oool0oooo03L0
oooo100000090?ooo`030820P0000000000000H00000S`3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`0=0?ooo`030820P0000000000000l00000
3@3oool4000003L0oooo1000000=0?ooo`L00000SP3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`0>0?ooo`h0000000<0@4100?ooo`3oool0B03o
ool3000000030<30`03oool0oooo00d0oooo00<0P8200000000000000`0000020820P8/0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool03`3oool?
000004P0oooo1000000B0?ooo`030820P0000000000000@00000RP3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`0?0?ooo`030410@00000000000
00P0000000<0oooo0820P00000000P0000000`30`<00oooo0?ooo`140?ooo`<0000000<0P8200?oo
o`3oool04P3oool00`20P800@41000000003000000030820P03oool0oooo08H0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0403oool:00000080
oooo0`0000000`20P800oooo0?ooo`140?ooo`<00000603oool6000008H0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0403oool:00000080oooo
00@0P8200000000000000000A@3oool01020P800000000000000000I0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0P`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`0A0?ooo`T000000`3oool01@20P8000000000000000000`<30
04<0oooo00@0P820000000000000P8206`3oool00`10@400000000000002000000030820P03oool0
oooo0840oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool04P3oool7000000H0oooo0`0000130?ooo`040820P000000000000820P1d0oooo1@000022
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0180oooo00<0@410000000000000100000060?ooo`030410@000000000000080000000<0`<300?oo
o`3oool0?P3oool01020P800000000000020P80N0?ooo`030820P000000000000080000000<0@410
0820P03oool0OP3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`0B0?ooo`030820P0000000000000@000001`3oool500000400oooo00@0P8200000
00000000P820803oool6000007h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool04`3oool6000000P0oooo1@00000o0?ooo`<0000000<0P8200?oo
o`3oool07P3oool00`20P800000000000004000007d0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool04`3oool00`20P800000000000003000000P0
oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0l0?ooo`<000008`3oool00`20P800
000000000003000000030820P03oool0oooo07T0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0503oool00`20P800000000000002000000X0oooo
100000000`20P800oooo0?ooo`0k0?ooo`<000009@3oool6000007X0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0503oool00`20P80000000000
0002000000/0oooo1000000m0?ooo`<000009P3oool6000007T0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool05@3oool4000000/0oooo00<0`<30
0000000000000P0000000`30`<00oooo0?ooo`0i0?ooo`<000009`3oool00`20P800000000000002
000000030410@020P800oooo07H0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool05P3oool4000000`0oooo1000000k0?ooo`<00000:@3oool50000
00030820P03oool0oooo07@0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool05P3oool01020P800000000000000000=0?ooo`050410@00000000000
00000020P800>@3oool3000002X0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`1c
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
01L0oooo0`00000>0?ooo`@0000000<0P8200?ooo`3oool0=P3oool3000002`0oooo1@0000000`20
P800oooo0?ooo`1a0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo01L0oooo00<0P8200000000000003`3oool4000003L0oooo0`00000^0?ooo`D0
0000L`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`0H0?ooo`8000003`3oool00`30`<00000000000002000000030<30`03oool0oooo03<0oooo
0`00000_0?ooo`030820P000000000000080000000<0P8200<30`03oool0K`3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`0I0?ooo`030000003o
ool0oooo00l0oooo1000000e0?ooo`<00000<@3oool500000700oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool06@3oool20820P140oooo00D0@410
00000000000000000820P00c0?ooo`<00000<P3oool00`20P800000000000002000000030820P03o
ool0oooo06`0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool06P3oool00`20P800oooo0?ooo`0@0?ooo`@0000000<0P8200?ooo`3oool0<03oool3
000003@0oooo1@00001]0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo02h0oooo1000000b0?ooo`<00000=@3oool5000006`0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0;P3oool00`30`<00
000000000002000000030820P03oool0oooo02h0oooo0`00000U0?ooo`D0P820303oool00`20P800
000000000002000000030820P03oool0oooo06P0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0<03oool4000000030820P03oool0oooo02d0oooo
0`00000U0?ooo`D000003@3oool00`20P800000000000002000000030820P03oool0oooo06L0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0<@3o
ool4000002h0oooo1000000U0?ooo`D000003P3oool5000006T0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0<@3oool00`30`<00000000000002
000000030820P03oool0oooo02X0oooo0`00000V0?ooo`030410@000000000000080000000<0`<30
0?ooo`3oool03@3oool01@10@4000000000000000000P82006L0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0<`3oool5000002/0oooo0`00000V
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool03P3oool5000006H0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0=03oool00`10
@400000000000002000000030820P03oool0oooo02L0oooo0`00000V0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool03`3oool00`30`<00000000000002000000030820P03oool0oooo
0680oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0=P3oool5000002P0oooo0`00000V0?ooo`030820P000000000000080000000<0P8200?ooo`3o
ool04@3oool4000000030820P03oool0oooo0640oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0=P3oool00`20P800000000000002000000030820
P03oool0oooo02@0oooo00@0P82000000000000000009`3oool5000001@0oooo1000001S0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo03L0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`0R0?ooo`040820P000000000000820P2L0
oooo1@00000E0?ooo`050820P0000000000000000020P800H@3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`0i0?ooo`D0000000<0P8200?ooo`3o
ool08@3oool01020P800000000000020P80W0?ooo`D000005`3oool400000600oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0>P3oool00`20P800
000000000003000000030820P03oool0oooo01l0oooo00@0@410000000000000P8209`3oool00`20
P800000000000002000000030820P03oool0oooo01@0oooo00<0`<300000000000000P0000000`10
@400oooo0?ooo`1L0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo03/0oooo00<0P8200000000000001000000P0?ooo`<00000:@3oool5000001P0
oooo00@0P820000000000000P820GP3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`0m0?ooo`H000007`3oool3000002T0oooo1@00000I0?ooo`80
0000G`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`0n0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool06P3oool3000000030820
P03oool0oooo02L0oooo1@00001j0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0400oooo1P0000000`20P800oooo0?ooo`0H0?ooo`<00000:`3o
ool5000007T0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0@@3oool00`20P800000000000003000001T0oooo00@0P8200000000000000000:`3o
ool500000500oooo1@00000T0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0480oooo00<0P8200410@00000000`0000000`10@400P8200?ooo`0E
0?ooo`040820P000000000000820P2D0oooo00@0`<300820P020P800@4102@0000030820P4P0oooo
00<0P8200000000000001`0000000`20P800`<300?ooo`0O0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo04@0oooo2000000D0?ooo`80000000<0
P8200?ooo`3oool0903ooolA000004D0oooo00<0P8200000000000000P0000001020P800oooo0?oo
o`3oool500000200oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0AP3oool00`20P800000000000005000000030820P03oool0oooo00d0oooo00D0
P82000000000000000000<30`00T0?ooo`030410@000000000000080000000@0@4100820P03oool0
P820100000000`20P800oooo0820P005000000030820P03oool0oooo03l0oooo00D0P82000000000
000000000410@0070?ooo`060410@0000000000000000020P800`<307@3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`180?ooo`030820P0000000
000000H00000303oool00`20P800000000000002000002@0oooo1P0000030?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool00P3oool5000003l0oooo00<0P8200000000000000P000009
0?ooo`D000007@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`1;0?ooo`P0000000<0P8200?ooo`3oool01@3oool00`20P8000000000000030000
02@0oooo1P0000040?ooo`030820P000000000000080000000<0P8200?ooo`3oool00P3oool00`20
P800000000000002000000030820P03oool0oooo03`0oooo00<0P8200000000000000P00000:0?oo
o`@000007@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`1<0?ooo`80P8201`0000001010@400P8200820P020P807000000030<30`03oool0oooo
0240oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`030?ooo`@0000000<0@4100?oo
o`3oool00`3oool00`20P800000000000002000000030820P03oool0oooo03X0oooo00<0P8200000
000000000P00000;0?ooo`030820P000000000000080000000<0`<300?ooo`3oool06@3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`1@0?ooo`l0
00009@3oool6000000H0oooo1@0000070?ooo`D00000>`3oool4000000d0oooo100000000`20P800
oooo0?ooo`0I0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0580oooo0P20P80700000080P8209`3oool5000000030410@03oool0oooo00@0oooo
1@0000070?ooo`030410@000000000000080000000<0@4100?ooo`3oool0=`3oool5000000d0oooo
1@00000K0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo08<0oooo1P0000000`20P800oooo0?ooo`050?ooo`@00000203oool5000003P0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0<0?ooo`D000006P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`230?ooo`H0000000<0P820
0?ooo`3oool01@3oool4000000P0oooo1P00000g0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0303oool5000001X0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0P`3oool6000000030820P03oool0oooo00D0oooo1@0000080?oo
o`D0000000<0P8200?ooo`3oool0=03oool5000000030820P03oool0oooo00`0oooo1P00000I0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo08<0
oooo1P0000000`20P800oooo0?ooo`050?ooo`030820P0000000000000800000203oool00`20P800
000000000003000003D0oooo1P00000@0?ooo`D0000000<0P8200?ooo`3oool05P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`230?ooo`H00000
00<0P8200?ooo`3oool01@3oool00`20P800000000000002000000P0oooo00<0P820000000000000
0`00000e0?ooo`H00000403oool5000000030820P03oool0oooo01H0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0P`3oool6000000030820P03o
ool0oooo00D0oooo00<0P8200000000000000P0000080?ooo`030<30`0000000000000<0000000<0
P8200?ooo`3oool0<P3oool600000100oooo1@0000000`20P800oooo0?ooo`0F0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo08<0oooo1P000000
0`20P800oooo0?ooo`060?ooo`@0000000<0P8200?ooo`3oool01P3oool6000003<0oooo1`00000@
0?ooo`H00000603oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`230?ooo`030820P0000000000000<0000000<0@4100?ooo`3oool01P3oool40000
00030820P03oool0oooo00H0oooo1P00000c0?ooo`H0000000<0P8200?ooo`3oool03P3oool60000
01P0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0Q03oool6000000P0oooo100000000`20P800oooo0?ooo`070?ooo`H000001@3ooolU00000003
0820P03oool0oooo00D0oooo1P00000A0?ooo`030820P0000000000000<00000603oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`240?ooo`H00000
203oool4000000030820P03oool0oooo00L0oooo1P0000050?ooobD0000000<0P8200?ooo`3oool0
1@3oool600000140oooo00<0P8200000000000000`00000H0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo08@0oooo00<0@4100000000000000`00
00090?ooo`@000002@3oool6000000D0oooo9@20P8000`30`<00oooo0?ooo`040?ooo`030820P000
0000000000@000004@3oool00`20P800000000000003000000030820P03oool0oooo01D0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0Q03oool0
0`20P800000000000004000000P0oooo100000090?ooo`H00000<@3oool00`20P800000000000004
00000140oooo00<0P8200000000000001000000G0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo08@0oooo00<0`<30000000000000100000080?oo
o`040820P00000000000000000T0oooo1P00000a0?ooo`030820P0000000000000@000004@3oool0
0`20P800000000000004000001L0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0Q@3oool7000000P0oooo0`0000090?ooo`H00000<@3oool00`20
P80000000000000400000140oooo00<0P8200000000000001000000G0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo08H0oooo1P0000080?ooo`@0
0000203oool600000340oooo00<0P8200000000000001000000A0?ooo`030820P0000000000000@0
00005`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`260?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool4000000P0oooo
1P00000a0?ooo`030820P0000000000000@000004@3oool00`20P800000000000004000001L0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0Q`3o
ool6000000L0oooo00@0P8200000000000000000203oool500000380oooo00<0P820000000000000
1000000A0?ooo`030820P0000000000000@000005`3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`270?ooo`030820P0000000000000@000001P3o
ool01020P80000000000000000070?ooo`H00000<P3oool00`20P80000000000000400000140oooo
00<0P8200000000000001000000G0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo08P0oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`030?ooo`050820P0000000000000000020P8001@3oool00`30`<00000000000003000000030820
P03oool0oooo0300oooo00<0P8200000000000001000000A0?ooo`030820P0000000000000@00000
5`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`290?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool00`3oool4000000D0oooo00<0
P8200000000000000`0000070?ooobD0000000<0P8200?ooo`3oool0103oool00`20P80000000000
000400000140oooo00<0P8200000000000001000000G0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo08X0oooo00<0P8200000000000000`000000
0`20P800oooo0?ooo`020?ooo`@00000103oool00`20P800000000000003000000030<30`03oool0
oooo00D0oooo9@0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000@000004@3oool0
0`20P800000000000004000001L0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0S03oool6000000<0oooo100000030?ooo`030820P00000000000
00<00000=P3oool600000140oooo00<0P8200000000000001000000G0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo08d0oooo1`0000000`3oool0
00000000000200000080oooo1P0000000`20P800oooo0?ooo`0d0?ooo`L00000403oool00`20P800
000000000003000001P0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0S`3oool00`20P80000000000000=00000080P820=`3oool700000100oooo
00<0P8200000000000000`00000H0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo09<0oooo2@0000000`20P800oooo0?ooo`0i0?ooo`L00000403o
ool00`20P800000000000003000001P0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0UP3oool01010@400000000000020P80n0?ooo`030820P000
0000000000@00000403oool5000000030410@03oool0oooo01H0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0UP3oool01020P800000000000000
000o0?ooo`H00000403oool5000000030820P03oool0oooo01H0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0UP3oool01020P800000000000000
000o0?ooo`H00000403oool5000000030820P03oool0oooo01H0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0UP3oool01020P800000000000000
00100?ooo`D0000000<0P8200?ooo`3oool03@3oool5000000030<30`03oool0oooo01H0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0U`3oool3
00000400oooo1@0000000`20P800oooo0?ooo`0<0?ooo`H000006@3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`2G0?ooo`<00000@03oool00`20
P800000000000002000000030820P03oool0oooo00`0oooo1@00000J0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo09L0oooo1000000o0?ooo`03
0<30`000000000000080000000<0@4100?ooo`3oool0303oool5000001X0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0V03oool300000400oooo
1@00000=0?ooo`D000006`3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`2H0?ooo`<00000@@3oool4000000030820P03oool0oooo00T0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0I0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo09P0oooo0`0000120?ooo`@000002`3oool0
0`20P800000000000002000001`0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0V@3oool300000440oooo00<0P8200000000000000P00000:0?oo
o`@000007@3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`2I0?ooo`<00000@P3oool01@20P8000000000000000000@41000P0oooo00D0P8200000
0000000000000410@00M0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo09T0oooo0`0000130?ooo`030820P00000000000008000001P3oool00`20
P800000000000002000001h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0V@3oool01010@400000000000030`<130?ooo`030820P00000000000
008000001020P803000000030410@03oool0oooo01h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0hP3oool00`20P80000000000000600000280
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
i03oool00`20P800000000000003000002<0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000
000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?oo
o`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo
0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0
P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<
000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0
P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo0012
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>
0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo
0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P800
00000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0
oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20
P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0oooo
E03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20
P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0
oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0
o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03o
ool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0
ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool0
0480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3o
ool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820
P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:0000
0?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3o
ool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o
0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<00000003
0820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:
00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo3P3oool00480oooo00<0P8200000
000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo00120?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00
@P3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool00480oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?oo
o`3o0?ooo`h0oooo00120?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0000000<0P820
0?ooo`3oool0o`3oool>0?ooo`00@P3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00030820P03oool0oooo0?l0oooo3P3oool001X0oooo1P20P80R0?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``0000000<0P8200?ooo`3oool0o`3oool>0?ooo`00603oool:00000200oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
000E0?ooo`060820P010@400000000000010@400P820103oool20820P0<0000000<0P8200?ooo`3o
ool06`3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0
oooo3P3oool001<0oooo00<0P8200000000000000P00000;0?ooo`<0000000<0P8200?ooo`3oool0
6@3oool00`20P80000000000000:00000?l0ooooE03oool<000000030820P03oool0oooo0?l0oooo
3P3oool001<0oooo1000000<0?ooo`040820P00000000000000001/0oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo000B0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool02P3oool01@20P8000000000000000000@41001T0oooo
00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo
000C0?ooo`D000003P3oool4000001P0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00000`20P800oooo0?ooo`3o0?ooo`h0oooo000C0?ooo`030410@000000000000080000000<0P820
0?ooo`3oool02`3oool00`30`<00000000000002000001L0oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo000C0?ooo`030820P00000000000
00<000003P3oool4000000030820P03oool0oooo01@0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo000C0?ooo`030820P0000000000000<0
00003`3oool4000001H0oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800
oooo0?ooo`3o0?ooo`h0oooo000C0?ooo`030<30`0000000000000<0000000<0`<300?ooo`3oool0
303oool00`10@400000000000002000001D0oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000000`20P800oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`D0000000<0P8200?ooo`3oool0303o
ool00`20P800000000000002000000030820P03oool0oooo0180oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?ooo`h0oooo000D0?ooo`D0000000<0P820
0?ooo`3oool03@3oool5000001@0oooo00<0P8200000000000002P00003o0?oooe@0oooo30000000
0`20P800oooo0?ooo`3o0?ooo`h0oooo000E0?ooo`D000003`3oool5000000030820P03oool0oooo
0140oooo00<0P8200000000000002P00003o0?oooe@0oooo300000000`20P800oooo0?ooo`3o0?oo
o`h0oooo000E0?ooo`D00000403oool5000001<0oooo00<0P820000000000000o`00001Z00000003
0820P03oool0oooo0?l0oooo3P3oool001D0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`0=0?ooo`D0000000<0P8200?ooo`3oool0403oool00`20P80000000000003o000006X00000
00<0P8200?ooo`3oool0o`3oool>0?ooo`005P3oool500000100oooo1@00000B0?ooo`030820P000
000000000?l00000JP0000000`20P800oooo0?ooo`3o0?ooo`h0oooo000F0?ooo`D00000403oool5
000000030820P03oool0oooo00l0oooo00<0P820000000000000o`00001Z000000030820P03oool0
oooo0?l0oooo3P3oool001H0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0=0?oo
o`D0000000<0P8200?ooo`3oool03`3oool00`20P80000000000003o000006X0000000<0P8200?oo
o`3oool0o`3oool>0?ooo`005P3oool00`20P800000000000002000000030820P03oool0oooo00d0
oooo1@0000000`20P800oooo0?ooo`0?0?ooo`030820P000000000000?l00000JP0000000`20P800
oooo0?ooo`3o0?ooo`h0oooo000F0?ooo`030820P0000000000000<000003`3oool600000140oooo
00<0P820000000000000o`00001Z000000030820P03oool0oooo0?l0oooo3P3oool001L0oooo1@00
000?0?ooo`H000004@3oool00`20P80000000000003o000006X0000000<0P8200?ooo`3oool0o`3o
ool>0?ooo`005`3oool6000000h0oooo00<0P8200000000000000`00000A0?ooo`030820P0000000
00000?l00000JP0000000`20P800oooo0?ooo`3o0?ooo`h0oooo000H0?ooo`D0000000<0P8200?oo
o`3oool02`3oool600000140oooo00<0P820000000000000o`00001Z000000030820P03oool0oooo
0?l0oooo3P3oool001P0oooo1P00000=0?ooo`H000004@3oool00`20P80000000000003o000006X0
000000<0P8200?ooo`3oool0o`3oool>0?ooo`00603oool6000000030820P03oool0oooo00X0oooo
1P00000A0?ooo`030820P000000000000?l00000JP0000000`20P800oooo0?ooo`3o0?ooo`h0oooo
000I0?ooo`H0000000<0P8200?ooo`3oool0203oool00`20P80000000000000400000140oooo00<0
`<300820P020P8000P20P8001010@400000000000010@43o0820P6@0P82000<0`<300?ooo`3oool0
o`3oool>0?ooo`006@3oool5000000030820P0000000P82000P0oooo1`0000000`20P800oooo0?oo
o`0D0?ooo`040820P000000000000820P?l0ooooo`3ooome0?ooo`006@3oool00`20P80000000000
000200000080P8200P0000000`20P800`<300?ooo`030?ooo`030410@0000000000000D0000000<0
P8200?ooo`3oool0503oool01020P800000000000020P83o0?ooool0ooooM@3oool001T0oooo00<0
P8200000000000000P0000000`20P800oooo0820P00?000001L0oooo00@0P820000000000000P820
o`3ooooo0?ooogD0oooo000I0?ooo`030820P0000000000000<000000P3oool>000001P0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo000J0?ooo`D000000`3oool00`20P80000000000
0008000000030410@020P800oooo01L0oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo
000J0?ooo`D000001@3oool9000001X0oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo
000K0?ooo`D000001P3oool00`20P800000000000002000000030820P03oool0oooo01T0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo000K0?ooo`D000009`3oool01020P80000000000
0020P83o0?ooool0ooooM@3oool001/0oooo1@0000000`20P800oooo0?ooo`0T0?ooo`040820P000
000000000820P?l0ooooo`3ooome0?ooo`006`3oool00`20P800000000000002000000030820P03o
ool0oooo02@0oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo000K0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0903oool01020P800000000000020P83o0?ooool0oooo
M@3oool001`0oooo1@00000V0?ooo`040820P000000000000820P?l0ooooo`3ooome0?ooo`00703o
ool5000002H0oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo000L0?ooo`H000009@3o
ool01020P800000000000020P83o0?ooool0ooooM@3oool001d0oooo1@00000U0?ooo`040820P000
000000000820P?l0ooooo`3ooome0?ooo`007@3oool6000002@0oooo00@0P820000000000000P820
o`3ooooo0?ooogD0oooo000N0?ooo`D00000903oool01020P800000000000020P83o0?ooool0oooo
M@3oool001h0oooo1@00000T0?ooo`040820P000000000000820P?l0ooooo`3ooome0?ooo`007P3o
ool5000000030820P03oool0oooo0240oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo
000N0?ooo`030820P000000000000080000000<0P8200?ooo`3oool08@3oool01020P80000000000
0020P83o0?ooool0ooooM@3oool001h0oooo1@0000000`10@400oooo0?ooo`0Q0?ooo`040820P000
000000000820P?l0ooooo`3ooome0?ooo`006@3oool;000002<0oooo00@0P820000000000000P820
o`3ooooo0?ooogD0oooo000I0?ooo`80P8202@00000S0?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`007`3oool600000280oooo00@0P820000000000000P820o`3ooooo0?ooogD0oooo
000S0?ooo`8000008P3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P83o0?ooool0ooooM@3oool004L0oooo00@0
P820000000000000P820o`3ooooo0?ooogD0oooo00170?ooo`040820P000000000000820P?l0oooo
o`3ooome0?ooo`00A`3oool01020P800000000000020P80F0?ooo`030820P0000000oooo0?l0oooo
o`3ooomL0?ooo`00A`3oool01020P800000000000020P80F0?ooo`030820P000000000000?l0oooo
o`3ooomL0?ooo`00A`3oool01020P800000000000020P80F0?ooo`050820P0000000000000000020
P800o`3ooooo0?oooeX0oooo00170?ooo`040820P000000000000820P1H0oooo00<0P82000000000
00000`00003o0?ooool0ooooF@3oool004L0oooo00@0P820000000000000P8205P3oool01020P800
oooo0?ooo`20P802000000030410@03oool0oooo0?l0ooooo`3ooomF0?ooo`00A`3oool01020P800
000000000020P80K0?ooo`<00000o`3ooooo0?oooeL0oooo00170?ooo`040820P000000000000820
P1`0oooo0P0000000`20P800oooo0?ooo`3o0?ooool0ooooE03oool004L0oooo00@0P82000000000
0000P820703oool01030`<00000000000020P83o0?ooool0ooooE@3oool004L0oooo00@0P8200000
00000000P8207P3oool300000?l0ooooo`3ooomD0?ooo`00A`3oool01020P800000000000020P80N
0?ooo`040820P000000000000820P?l0ooooo`3ooomC0?ooo`00A`3oool01020P800000000000020
P80O0?ooo`040820P000000000000820P?l0ooooo`3ooomB0?ooo`00A`3oool01020P80000000000
0020P80Q0?ooo`80000000<0P8200?ooo`3oool0o`3ooooo0?ooodl0oooo00170?ooo`040820P000
000000000820P240oooo00<0`<3000000010@400o`3ooooo0?oooe40oooo00170?ooo`040820P000
000000000820P280oooo0`00003o0?ooool0ooooD03oool004L0oooo00@0P820000000000000P820
8P3oool400000?l0ooooo`3ooom?0?ooo`00A`3oool01020P800000000000020P80R0?ooo`@00000
00<0@4100?ooo`3oool0o`3ooooo0?oood`0oooo00170?ooo`040820P000000000000820P280oooo
1P00003o0?ooool0ooooC@3oool004L0oooo00@0P820000000000000P8208@3oool00`20P8000000
0000000500000?l0ooooo`3ooom<0?ooo`00A`3oool01020P800000000000020P80Q0?ooo`030820
P0000000000000D0000000<0P8200?ooo`3oool0o`3ooooo0?ooodT0oooo00170?ooo`040820P000
000000000820P240oooo00<0P8200000000000000`0000000`3oool000000000003o0?ooool0oooo
B`3oool004L0oooo00@0P820000000000000P8208@3oool00`20P80000000000000300000080oooo
0P0000000`30`<00oooo0?ooo`3o0?ooool0ooooA`3oool004L0oooo00@0P820000000000000P820
8@3oool00`20P80000000000000300000080oooo00<0P82000000020P800o`3ooooo0?ooodT0oooo
00170?ooo`040820P000000000000820P240oooo00<0P8200000000000000`0000030?ooo`800000
o`3ooooo0?ooodT0oooo00170?ooo`040820P000000000000820P240oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`020?ooo`80000000<0P8200?ooo`3oool0o`3ooooo0?ooodD0oooo
00170?ooo`040820P000000000000820P240oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`020?ooo`030820P000000000000?l0ooooo`3ooom70?ooo`00A`3oool01020P80000000000
0020P80Q0?ooo`030410@000000000000080000000<0P8200?ooo`3oool00`3oool00`20P8000000
0410@03o0?ooool0ooooAP3oool004L0oooo00@0P820000000000000P8208@3oool5000000030820
P03oool0oooo00@0oooo0P00003o0?ooool0ooooAP3oool004L0oooo00@0P820000000000000P820
8@3oool5000000030820P03oool0oooo00D0oooo0P00003o0?ooool0ooooA@3oool004D0oooo0P20
P8001010@400000000000010@4050820P1`0oooo1@0000000`20P800oooo0?ooo`050?ooo`030820
P0000000P8200?l0ooooo`3ooom40?ooo`00?`3ooolC000000030820P03oool0oooo01L0oooo1@00
00000`20P800oooo0?ooo`060?ooo`800000o`3ooooo0?oood@0oooo000m0?ooo`030410@0000000
000001@0000000<0P8200?ooo`3oool05@3oool5000000030<30`03oool0oooo00L0oooo0P00003o
0?ooool0oooo@`3oool003d0oooo00<0P8200000000000005000000H0?ooo`D000002P3oool00`20
P80000000000003o0?ooool0oooo@P3oool003d0oooo00<0P8200000000000005000000H0?ooo`D0
00002`3oool2000000030820P03oool0oooo0?l0ooooo`3ooolo0?ooo`00?@3oool00`30`<000000
0000000C000000030820P03oool0oooo01D0oooo00<0P8200000000000000`00000;0?ooo`030820
P0000000@4100?l0ooooo`3ooom10?ooo`00?P3ooolE000001P0oooo1P00000<0?ooo`800000o`3o
oooo0?oood40oooo000n0?oooaD00000603oool6000000d0oooo0P00003o0?ooool0oooo@03oool0
03l0oooo4`0000000`20P800oooo0?ooo`0F0?ooo`H000003@3oool00`10@40000000000003o0?oo
ool0oooo?`3oool003l0oooo4`0000000`20P800oooo0?ooo`0F0?ooo`H000003P3oool200000?l0
ooooo`3ooolo0?ooo`00@03ooolB000001T0oooo1P00000>0?ooo`80000000<0P8200?ooo`3oool0
o`3ooooo0?oooc`0oooo00100?oooa8000006@3oool5000000l0oooo0P0000000`20P800oooo0?oo
o`3o0?ooool0oooo?03oool00400oooo00<0P8200000000000003P00000I0?ooo`H000003P3oool0
1020P800000000000000003o0?ooool0oooo?P3oool00400oooo00<0P8200000000000003@000000
0`20P800oooo0?ooo`0G0?ooo`H000003@3oool00`20P80000000000000200000?l0ooooo`3oooln
0?ooo`00@@3oool?000001T0oooo00<0P8200000000000001000000<0?ooo`H00000o`3ooooo0?oo
och0oooo00110?ooo`h0000000<0@4100?ooo`3oool04P3oool50820P0H0000000<0P8200?ooo`3o
ool02P3oool600000?l0ooooo`3oooln0?ooo`00@P3oool=000000030820P03oool0oooo0180oooo
2`00000=0?ooo`H00000o`3ooooo0?oooch0oooo00120?ooo`d0000000<0P8200?ooo`3oool04`3o
ool:000000d0oooo1@0000000`20P800oooo0?ooo`3o0?ooool0oooo?03oool00480oooo00<0@410
0000000000002P00000J0?ooo`<0P82000<0@41000000020P8003P3oool01020P800000000000020
P83o0?ooool0oooo?`3oool00480oooo00<0P8200000000000002P00003o0?ooool0ooooL@3oool0
04<0oooo3000003o0?ooool0ooooL@3oool004<0oooo2`00003o0?ooool0ooooLP3oool004@0oooo
2P00003o0?ooool0ooooLP3oool004@0oooo2@0000000`20P800oooo0?ooo`3o0?ooool0ooooL03o
ool004D0oooo200000000`20P800oooo0?ooo`3o0?ooool0ooooL03oool004D0oooo2000003o0?oo
ool0ooooL`3oool004D0oooo00<0@410000000000000100000000`20P800oooo0?ooo`3o0?ooool0
ooooL@3oool004D0oooo00<0P8200000000000001000003o0?ooool0ooooM03oool004D0oooo00<0
`<300000000000000`0000000`20P800oooo0?ooo`3o0?ooool0ooooLP3oool004H0oooo1@00003o
0?ooool0ooooM@3oool004H0oooo1@00003o0?ooool0ooooM@3oool004L0oooo0`0000000`20P800
oooo0?ooo`3o0?ooool0ooooL`3oool004L0oooo0`0000000`20P800oooo0?ooo`3o0?ooool0oooo
L`3oool004L0oooo00<0P820000000000000o`3ooooo0?ooogH0oooo00170?ooo`030820P0000000
P8200?l0ooooo`3ooomf0?ooo`00B03oool00`000000oooo0?ooo`3o0?ooool0ooooM@3oool00?l0
ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo0
0?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3o
oooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00
oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?oo
ool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03o
ool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0oooo
o`3oooo00?ooo`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?oo
o`00o`3ooooo0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo
0?oool00oooo003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo
003o0?ooool0oooo`03oool00?l0ooooo`3oooo00?ooo`00o`3ooooo0?oool00oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{138.312, 170.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 4.4 Domain for  eigenmodes in rectangular geometry with \
Dirichlet boundary conditions.\
\>", "Caption",
  CellTags->"Fig. 4.4"],

Cell[TextData[{
  "\t  Applying the method of separation of variables, we assume that a \
solution for an eigenmode ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(x, y)\)]],
  " can be found in the form"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(x, 
        y) = \(X(x)\) \(Y(y)\)\)]]], "NE4",
  CellTags->"(4.3.18)"],

Cell[TextData[{
  "for some functions ",
  Cell[BoxData[
      \(TraditionalForm\`X\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ". If we substitute Eq. ",
  ButtonBox["(4.3.18)",
    ButtonData:>"(4.3.18)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(4.3.12)",
    ButtonData:>"(4.3.12)",
    ButtonStyle->"Hyperlink"],
  " and divide the result by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(X(
                  x)\)\) \[DifferentialD]\^2 X\/\[DifferentialD]x\^2 + \
\(1\/\(Y(y)\)\) \[DifferentialD]\^2 Y\/\[DifferentialD]y\^2 = \[Lambda]\_\
\[Alpha]\)]],
  "."
}], "NE4",
  CellTags->"(4.3.19)"],

Cell[TextData[{
  "Introducing a separation constant ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\^2\)\)]],
  ", this equation is separated into the two ODEs"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(1\/\(X(
              x)\)\) \[DifferentialD]\^2 X\/\[DifferentialD]x\^2 = \
\(-k\^2\)\)\(,\)\)\)]]], "NE4",
  CellTags->"(4.3.20)"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/\(Y(
              y)\)\) \[DifferentialD]\^2 Y\/\[DifferentialD]y\^2 = \
\[Lambda]\_\[Alpha] + \(\(k\^2\)\(.\)\)\)]]], "NE4",
  CellTags->"(4.3.21)"],

Cell[TextData[{
  "Boundary conditions for each ODE  follow from the Dirichlet condition for \
each eigenmode,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\( | \_S\)\(\(=\)\(0\)\)\)]],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X(0) = \(X(a) = \(Y(0) = \(Y(b)\  = \ 0\)\)\)\)]],
  " ."
}], "NE4",
  CellTags->"(4.3.22)"],

Cell[TextData[{
  "With these homogeneous boundary conditions, Eqs. ",
  ButtonBox["(4.3.20)",
    ButtonData:>"(4.3.20)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.21)",
    ButtonData:>"(4.3.21)",
    ButtonStyle->"Hyperlink"],
  " can be recognized to be separate eigenvalue problems. The solution to Eq. \
",
  ButtonBox["(4.3.20)",
    ButtonData:>"(4.3.20)",
    ButtonStyle->"Hyperlink"],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k = n\ \[Pi]/a\)]],
  ", "
}], "NE4",
  CellTags->"(4.3.23)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`X(x) = \ sin(n\ \[Pi]\ x/a)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3, \  ... , \)]]
}], "NE4",
  CellTags->"(4.3.24)"],

Cell[TextData[{
  "and the solution to Eq. ",
  ButtonBox["(4.3.21)",
    ButtonData:>"(4.3.21)",
    ButtonStyle->"Hyperlink"],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Y(y) = sin(m\ \[Pi]\ y/b)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2, 3, \  ... , \)]]
}], "NE4",
  CellTags->"(4.3.25)"],

Cell[TextData[{
  "with eigenvalues  given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha] + 
          k\^2 = \(-\((m\ \[Pi]/b)\)\^2\)\)]],
  ". Using Eq. ",
  ButtonBox["(4.3.23)",
    ButtonData:>"(4.3.23)",
    ButtonStyle->"Hyperlink"],
  ", this implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha] = \(-\((\(n\ \[Pi]\)\/a)\)\^2\) \
- \((\(m\ \[Pi]\)\/b)\)\^2\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2, 3,  ... , \ \ n = 1, 2, 3,  ... \)]],
  "."
}], "NE4",
  CellTags->"(4.3.26)"],

Cell[TextData[{
  "Thus, the Dirichlet eigenfunction ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(x, y)\)]],
  "  in rectangular geometry is a product of sine functions:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(x, 
          y) = \(sin(n\ \[Pi]\ x/a)\) \(sin(m\ \[Pi]\ y/b)\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(m = 1, 2, 3,  ... , \ \ n = 1, 2, 3,  ... \),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.27)"],

Cell[TextData[{
  "with an eigenvalue given by Eq. ",
  ButtonBox["(4.3.26)",
    ButtonData:>"(4.3.26)",
    ButtonStyle->"Hyperlink"],
  ". Different eigenfunctions and eigenvalues are selected by choosing \
different values for the positive integers ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". Therefore,  the counter \[Alpha], which we have used to enumerate the \
eigenmodes, is actually a list: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \ \((m, n)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe eigenmodes clearly form a complete orthogonal set with respect to \
the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%a\[DifferentialD]x \
\(\[Integral]\_0\%b\[DifferentialD]y\)\)]],
  ", as a consequence of  the known orthogonality and completeness properties \
of the sine functions in a Fourier sine series. This is expected from the \
general arguments made in Sec. ",
  ButtonBox["4.3.3",
    ButtonData:>"c:26",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 1: Solution of Poisson's Equation with Smooth \
Boundary Conditions",
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  "\tAs an example, consider the case where the charge density \[Rho] = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  ",",
  " a constant, and the walls of the enclosure are grounded,  except for the \
base at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 0) = \[Beta]\ \(x(a - x)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Beta]\)\(\ \)\)\)]],
  "is a constant."
}], "Text"],

Cell[TextData[{
  "\t In order to put Poisson's equation into standard form, Eqs. ",
  ButtonBox["(4.3.3)",
    ButtonData:>"(4.3.3)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.4)",
    ButtonData:>"(4.3.4)",
    ButtonStyle->"Hyperlink"],
  ", we simply take ",
  Cell[BoxData[
      \(TraditionalForm\`u = \[Beta]\ \(x(a - x)\) \((1 - y/b)\)\)]],
  ". This function satisfies the boundary conditions on all four sides of the \
rectangle."
}], "Text"],

Cell[TextData[{
  "\t  According to Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.4)",
    ButtonData:>"(4.3.4)",
    ButtonStyle->"Hyperlink"],
  ",  we require the inner product"
}], "Text"],

Cell[TextData[{
  "\t\t   ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(m\ n\), \[Rho]\_o/\[Epsilon]\_o + \
\[Del]\^2 
              u)\) = \[Integral]\_0\%a\[DifferentialD]x \(\[Integral]\_0\%b\
\[DifferentialD]y\ \(\(\[Psi]\_\(m\ n\)\^*\)(\[Rho]\_o/\[Epsilon]\_o + \[Del]\
\^2 u)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  " We can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to evaluate this inner product:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(u[x_, y_]\  = \ \[Beta]\ x \((a - x)\) \((1 - y/b)\);\)\), "\n", 
    \(\(\[Rho][m_, n_] = \ 
        Integrate[
          Sin[\(m\ \[Pi]\ y\)\/b] 
            Sin[\(n\ \[Pi]\ x\)\/a] \((\[Rho]\_o\ /\[Epsilon]\_o + 
                D[u[x, y], {x, 2}] + D[u[x, y], {y, 2}])\), {x, 0, a}, {y, 0, 
            b}];\)\), "\n", 
    \(\[Rho][m_, n_] = 
      Simplify[\[Rho][m, n], 
        m \[Element] Integers && n \[Element] Integers]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.20"],

Cell[BoxData[
    \(\(-\(\(2\ a\ b\ Sin[\(n\ \[Pi]\)\/2]\^2\ \((2\ \[Beta]\ \[Epsilon]\_o + \
\((\(-1\) + \((\(-1\))\)\^m)\)\ \[Rho]\_o)\)\)\/\(m\ n\ \[Pi]\^2\ \
\[Epsilon]\_o\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Also, the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Psi]\_\[Alpha])\)\ \
equals\ \ a\ b\ /4\)]],
  ".  The solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["\[Phi]",
            "TraditionalForm"], "(", \(x, y\), ")"}], TraditionalForm]]],
  ", Eqs. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.3)",
    ButtonData:>"(4.3.3)",
    ButtonStyle->"Hyperlink"],
  ", is plotted in Cell ",
  ButtonBox["4.21",
    ButtonData:>"Cell 4.21",
    ButtonStyle->"Hyperlink"],
  "  taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(b = \(\(1\)\(\ \)\(meter\)\(\ \)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\/\[Epsilon]\_o = \(3  \[Beta] = 
          1\ Volt/m\^2\)\)]],
  ". This corresponds to a charge density of ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\_o\), "=", " ", 
          RowBox[{"8.85", "\[Times]", \(10\^\(-12\)\), " ", 
            RowBox[{
              StyleBox["C",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "3"]}]}]}], TraditionalForm]]],
  ". We keep only the first nine terms in each sine series, since each series \
converges quickly."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = 1; b = 1;\), "\n", 
    \(\[Rho]\_o = \[Epsilon]\_o; \ \[Beta] = 1/3;\), "\n", 
    \(\(\[Lambda][m_, 
          n_] = \(-\((\(n\ \[Pi]\)\/a)\)\^2\) - \((\(m\ \
\[Pi]\)\/b)\)\^2;\)\), "\n", 
    \(\(\[Phi][x_, 
          y_] = \(-\(\[Sum]\+\(m = 1\)\%9\(\[Sum]\+\(n = 1\)\%9\( \[Rho][m, \
n]\ Sin[\(n\ \[Pi]\ x\)\/a]\ Sin[\(m\ \[Pi]\ y\)\/b]\)\/\(\[Lambda][m, n]\ \
1\/4\ a\ b\)\)\)\)\  + \ u[x, y];\)\), "\n", 
    \(\(Plot3D[\[Phi][x, y], {x, 0, a}, {y, 0, b}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel \[Rule] "\<\[Phi] in a charge-filled square \
enclosure\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -113 0 ]
[.5 .82364 113 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01536 .31996 -30 -2.7887 ]
[.01536 .31996 0 6.2113 ]
[.00629 .37681 -24 -2.83693 ]
[.00629 .37681 0 6.16307 ]
[-0.00311 .43575 -30 -2.88714 ]
[-0.00311 .43575 0 6.11286 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -174 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
93.000 13.000 moveto
(a) show
105.000 13.000 moveto
(charge) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
189.000 13.000 moveto
(square) show
231.000 13.000 moveto
(enclosure) show
285.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02763 .3153 m
.03376 .31297 L
s
[(0.025)] .01536 .31996 1 -0.38029 Mshowa
.0186 .37226 m
.02475 .36998 L
s
[(0.05)] .00629 .37681 1 -0.36957 Mshowa
.00924 .43132 m
.01542 .42911 L
s
[(0.075)] -0.00311 .43575 1 -0.35841 Mshowa
.125 Mabswid
.03462 .27117 m
.03829 .26975 L
s
.03289 .28209 m
.03656 .28067 L
s
.03115 .29308 m
.03482 .29167 L
s
.02939 .30415 m
.03307 .30274 L
s
.02585 .32653 m
.02953 .32513 L
s
.02405 .33784 m
.02774 .33645 L
s
.02225 .34923 m
.02594 .34785 L
s
.02043 .3607 m
.02412 .35933 L
s
.01676 .3839 m
.02045 .38254 L
s
.0149 .39562 m
.01859 .39427 L
s
.01303 .40744 m
.01673 .40609 L
s
.01114 .41934 m
.01484 .418 L
s
.00733 .4434 m
.01103 .44208 L
s
.0054 .45557 m
.00911 .45425 L
s
.00346 .46782 m
.00717 .46652 L
s
.0015 .48017 m
.00522 .47887 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.408 .647 .955 r
.38313 .58323 .40512 .60371 .44189 .59268 .41971 .58821 Metetra
.185 .7 .89 r
.41971 .58821 .44189 .59268 .47916 .5815 .45726 .58797 Metetra
.083 0 0 r
.45726 .58797 .47916 .5815 .51695 .57017 .49564 .58403 Metetra
.226 0 0 r
.49564 .58403 .51695 .57017 .55526 .55867 .53472 .57825 Metetra
.277 0 0 r
.53472 .57825 .55526 .55867 .59412 .54701 .57448 .57011 Metetra
.298 0 0 r
.57448 .57011 .59412 .54701 .63352 .53519 .61486 .56028 Metetra
.302 0 .016 r
.61486 .56028 .63352 .53519 .67349 .5232 .65584 .54905 Metetra
.285 0 .018 r
.65584 .54905 .67349 .5232 .71403 .51104 .69735 .53582 Metetra
.254 0 0 r
.69735 .53582 .71403 .51104 .75515 .4987 .73937 .52116 Metetra
.197 0 0 r
.73937 .52116 .75515 .4987 .79688 .48619 .78185 .50472 Metetra
.082 0 0 r
.78185 .50472 .79688 .48619 .83921 .47349 .82466 .48578 Metetra
.82466 .48578 .83921 .47349 .88217 .4606 .86777 .46481 Metetra
.497 .896 .76 r
.86777 .46481 .88217 .4606 .92578 .44752 .91089 .43984 Metetra
.792 .959 .92 r
.91089 .43984 .92578 .44752 .97003 .43424 .95362 .4092 Metetra
.078 .463 .887 r
.36056 .56222 .38313 .58323 .41971 .58821 .39692 .5784 Metetra
0 .525 .841 r
.39692 .5784 .41971 .58821 .45726 .58797 .43462 .58744 Metetra
.104 0 0 r
.43462 .58744 .45726 .58797 .49564 .58403 .47341 .5906 Metetra
.192 0 0 r
.47341 .5906 .49564 .58403 .53472 .57825 .51314 .5901 Metetra
.204 0 0 r
.51314 .5901 .53472 .57825 .57448 .57011 .55369 .58551 Metetra
.202 0 0 r
.55369 .58551 .57448 .57011 .61486 .56028 .59495 .5777 Metetra
.182 0 0 r
.59495 .5777 .61486 .56028 .65584 .54905 .63686 .56704 Metetra
.123 0 0 r
.63686 .56704 .65584 .54905 .69735 .53582 .67929 .55286 Metetra
.046 0 0 r
.67929 .55286 .69735 .53582 .73937 .52116 .72216 .53578 Metetra
.72216 .53578 .73937 .52116 .78185 .50472 .76535 .5153 Metetra
.76535 .5153 .78185 .50472 .82466 .48578 .80866 .49048 Metetra
.578 .934 .778 r
.80866 .49048 .82466 .48578 .86777 .46481 .85195 .46167 Metetra
.801 .99 .883 r
.85195 .46167 .86777 .46481 .91089 .43984 .8948 .42646 Metetra
.871 .906 .852 r
.8948 .42646 .91089 .43984 .95362 .4092 .93675 .38345 Metetra
0 .271 .748 r
.33741 .54067 .36056 .56222 .39692 .5784 .37355 .56453 Metetra
0 .376 .767 r
.37355 .56453 .39692 .5784 .43462 .58744 .41127 .58087 Metetra
0 .453 .727 r
.41127 .58087 .43462 .58744 .47341 .5906 .45037 .59016 Metetra
.135 0 0 r
.45037 .59016 .47341 .5906 .51314 .5901 .4906 .59429 Metetra
.09 0 0 r
.4906 .59429 .51314 .5901 .55369 .58551 .53182 .59298 Metetra
.043 0 0 r
.53182 .59298 .55369 .58551 .59495 .5777 .57387 .58702 Metetra
.57387 .58702 .59495 .5777 .63686 .56704 .61662 .57681 Metetra
.61662 .57681 .63686 .56704 .67929 .55286 .6599 .56174 Metetra
.6599 .56174 .67929 .55286 .72216 .53578 .70358 .5423 Metetra
.464 .878 .746 r
.70358 .5423 .72216 .53578 .76535 .5153 .74746 .518 Metetra
.665 .974 .844 r
.74746 .518 .76535 .5153 .80866 .49048 .79129 .48788 Metetra
.801 .989 .884 r
.79129 .48788 .80866 .49048 .85195 .46167 .83486 .45214 Metetra
.873 .939 .858 r
.83486 .45214 .85195 .46167 .8948 .42646 .8777 .4087 Metetra
.89 .867 .809 r
.8777 .4087 .8948 .42646 .93675 .38345 .91939 .35695 Metetra
0 .104 .594 r
.31365 .51855 .33741 .54067 .37355 .56453 .34951 .54874 Metetra
0 .237 .66 r
.34951 .54874 .37355 .56453 .41127 .58087 .38721 .57086 Metetra
0 .372 .708 r
.38721 .57086 .41127 .58087 .45037 .59016 .42651 .58513 Metetra
0 .459 .703 r
.42651 .58513 .45037 .59016 .4906 .59429 .46715 .59324 Metetra
0 .562 .715 r
.46715 .59324 .4906 .59429 .53182 .59298 .50895 .59473 Metetra
.09 .648 .726 r
.50895 .59473 .53182 .59298 .57387 .58702 .55171 .59038 Metetra
.21 .734 .752 r
.55171 .59038 .57387 .58702 .61662 .57681 .59524 .58054 Metetra
.37 .837 .804 r
.59524 .58054 .61662 .57681 .6599 .56174 .63934 .56457 Metetra
.523 .919 .854 r
.63934 .56457 .6599 .56174 .70358 .5423 .68381 .54299 Metetra
.672 .975 .891 r
.68381 .54299 .70358 .5423 .74746 .518 .7284 .51526 Metetra
.793 .985 .895 r
.7284 .51526 .74746 .518 .79129 .48788 .77282 .48046 Metetra
.858 .955 .872 r
.77282 .48046 .79129 .48788 .83486 .45214 .8168 .43892 Metetra
.893 .904 .827 r
.8168 .43892 .83486 .45214 .8777 .4087 .85984 .38877 Metetra
.903 .851 .781 r
.85984 .38877 .8777 .4087 .91939 .35695 .90152 .32967 Metetra
.519 .006 0 r
.28926 .49583 .31365 .51855 .34951 .54874 .32483 .53058 Metetra
0 .15 .597 r
.32483 .53058 .34951 .54874 .38721 .57086 .36245 .55715 Metetra
0 .323 .709 r
.36245 .55715 .38721 .57086 .42651 .58513 .40189 .57539 Metetra
0 .462 .776 r
.40189 .57539 .42651 .58513 .46715 .59324 .44286 .58668 Metetra
.071 .614 .847 r
.44286 .58668 .46715 .59324 .50895 .59473 .48516 .59048 Metetra
.232 .737 .894 r
.48516 .59048 .50895 .59473 .55171 .59038 .52854 .58742 Metetra
.387 .837 .928 r
.52854 .58742 .55171 .59038 .59524 .58054 .57278 .57782 Metetra
.548 .916 .949 r
.57278 .57782 .59524 .58054 .63934 .56457 .61765 .56102 Metetra
.672 .956 .948 r
.61765 .56102 .63934 .56457 .68381 .54299 .66288 .53751 Metetra
.77 .964 .928 r
.66288 .53751 .68381 .54299 .7284 .51526 .7082 .5068 Metetra
.839 .945 .89 r
.7082 .5068 .7284 .51526 .77282 .48046 .75326 .46806 Metetra
.876 .912 .85 r
.75326 .46806 .77282 .48046 .8168 .43892 .79775 .42172 Metetra
.898 .873 .804 r
.79775 .42172 .8168 .43892 .85984 .38877 .84118 .36621 Metetra
.908 .835 .763 r
.84118 .36621 .85984 .38877 .90152 .32967 .88312 .30158 Metetra
.59 .077 0 r
.2642 .4725 .28926 .49583 .32483 .53058 .29949 .51055 Metetra
.444 0 0 r
.29949 .51055 .32483 .53058 .36245 .55715 .337 .54043 Metetra
0 .283 .702 r
.337 .54043 .36245 .55715 .40189 .57539 .37652 .56171 Metetra
0 .453 .813 r
.37652 .56171 .40189 .57539 .44286 .58668 .41775 .57545 Metetra
.135 .628 .913 r
.41775 .57545 .44286 .58668 .48516 .59048 .46047 .58103 Metetra
.325 .76 .969 r
.46047 .58103 .48516 .59048 .52854 .58742 .50441 .57895 Metetra
.488 .852 .99 r
.50441 .57895 .52854 .58742 .57278 .57782 .54931 .56944 Metetra
.631 .908 .983 r
.54931 .56944 .57278 .57782 .61765 .56102 .5949 .55189 Metetra
.73 .928 .956 r
.5949 .55189 .61765 .56102 .66288 .53751 .64089 .5267 Metetra
.802 .924 .918 r
.64089 .5267 .66288 .53751 .7082 .5068 .68695 .49347 Metetra
.851 .905 .872 r
.68695 .49347 .7082 .5068 .75326 .46806 .7327 .45149 Metetra
.879 .88 .83 r
.7327 .45149 .75326 .46806 .79775 .42172 .77781 .40124 Metetra
.899 .851 .787 r
.77781 .40124 .79775 .42172 .84118 .36621 .82176 .3415 Metetra
.91 .825 .75 r
.82176 .3415 .84118 .36621 .88312 .30158 .86416 .27265 Metetra
.638 .127 0 r
.23846 .44853 .2642 .4725 .29949 .51055 .27344 .48921 Metetra
.487 0 0 r
.27344 .48921 .29949 .51055 .337 .54043 .31082 .52153 Metetra
0 .251 .689 r
.31082 .52153 .337 .54043 .37652 .56171 .35038 .545 Metetra
0 .44 .828 r
.35038 .545 .37652 .56171 .41775 .57545 .39183 .56054 Metetra
.173 .623 .938 r
.39183 .56054 .41775 .57545 .46047 .58103 .43492 .5674 Metetra
.376 .753 .99 r
.43492 .5674 .46047 .58103 .50441 .57895 .47937 .56598 Metetra
.536 .835 .999 r
.47937 .56598 .50441 .57895 .54931 .56944 .52489 .55645 Metetra
.665 .879 .978 r
.52489 .55645 .54931 .56944 .5949 .55189 .57117 .53818 Metetra
.75 .893 .943 r
.57117 .53818 .5949 .55189 .64089 .5267 .6179 .51158 Metetra
.81 .89 .901 r
.6179 .51158 .64089 .5267 .68695 .49347 .66471 .47628 Metetra
.853 .876 .856 r
.66471 .47628 .68695 .49347 .7327 .45149 .71121 .43166 Metetra
.879 .858 .817 r
.71121 .43166 .7327 .45149 .77781 .40124 .75702 .37835 Metetra
.899 .839 .777 r
.75702 .37835 .77781 .40124 .82176 .3415 .80164 .31526 Metetra
.913 .82 .742 r
.80164 .31526 .82176 .3415 .86416 .27265 .84462 .24283 Metetra
.663 .154 0 r
.212 .42389 .23846 .44853 .27344 .48921 .2467 .46609 Metetra
.499 0 0 r
.2467 .46609 .27344 .48921 .31082 .52153 .28394 .49997 Metetra
0 .242 .699 r
.28394 .49997 .31082 .52153 .35038 .545 .32352 .52488 Metetra
0 .44 .849 r
.32352 .52488 .35038 .545 .39183 .56054 .36514 .54155 Metetra
.22 .618 .953 r
.36514 .54155 .39183 .56054 .43492 .5674 .40855 .5492 Metetra
.42 .736 .991 r
.40855 .5492 .43492 .5674 .47937 .56598 .45346 .54814 Metetra
.569 .805 .988 r
.45346 .54814 .47937 .56598 .52489 .55645 .49954 .53845 Metetra
.682 .842 .96 r
.49954 .53845 .52489 .55645 .57117 .53818 .54649 .51953 Metetra
.756 .855 .923 r
.54649 .51953 .57117 .53818 .6179 .51158 .59393 .49175 Metetra
.81 .855 .883 r
.59393 .49175 .6179 .51158 .66471 .47628 .64151 .45481 Metetra
.849 .848 .841 r
.64151 .45481 .66471 .47628 .71121 .43166 .68879 .40818 Metetra
.875 .837 .805 r
.68879 .40818 .71121 .43166 .75702 .37835 .73537 .35251 Metetra
.896 .825 .768 r
.73537 .35251 .75702 .37835 .80164 .31526 .78075 .28694 Metetra
.912 .813 .736 r
.78075 .28694 .80164 .31526 .84462 .24283 .82447 .21208 Metetra
.675 .167 0 r
.18479 .39856 .212 .42389 .2467 .46609 .21923 .44152 Metetra
.502 0 0 r
.21923 .44152 .2467 .46609 .28394 .49997 .25634 .47618 Metetra
0 .241 .71 r
.25634 .47618 .28394 .49997 .32352 .52488 .29593 .50182 Metetra
0 .442 .863 r
.29593 .50182 .32352 .52488 .36514 .54155 .3377 .51903 Metetra
.255 .611 .956 r
.3377 .51903 .36514 .54155 .40855 .5492 .3814 .52702 Metetra
.447 .717 .982 r
.3814 .52702 .40855 .5492 .45346 .54814 .42671 .52601 Metetra
.585 .777 .971 r
.42671 .52601 .45346 .54814 .49954 .53845 .47332 .51604 Metetra
.687 .81 .941 r
.47332 .51604 .49954 .53845 .54649 .51953 .52089 .49651 Metetra
.755 .824 .906 r
.52089 .49651 .54649 .51953 .59393 .49175 .56904 .46779 Metetra
.805 .828 .868 r
.56904 .46779 .59393 .49175 .64151 .45481 .61738 .4296 Metetra
.844 .826 .831 r
.61738 .4296 .64151 .45481 .68879 .40818 .66546 .38152 Metetra
.871 .822 .798 r
.66546 .38152 .68879 .40818 .73537 .35251 .71288 .32419 Metetra
.893 .815 .764 r
.71288 .32419 .73537 .35251 .78075 .28694 .7591 .25691 Metetra
.911 .808 .733 r
.7591 .25691 .78075 .28694 .82447 .21208 .80369 .18035 Metetra
.678 .171 0 r
.1568 .3725 .18479 .39856 .21923 .44152 .19099 .41565 Metetra
.494 0 0 r
.19099 .41565 .21923 .44152 .25634 .47618 .22799 .45035 Metetra
0 .251 .727 r
.22799 .45035 .25634 .47618 .29593 .50182 .2676 .47602 Metetra
.037 .449 .875 r
.2676 .47602 .29593 .50182 .3377 .51903 .3095 .49321 Metetra
.287 .606 .953 r
.3095 .49321 .3377 .51903 .3814 .52702 .35346 .50111 Metetra
.468 .699 .969 r
.35346 .50111 .3814 .52702 .42671 .52601 .39916 .49986 Metetra
.594 .753 .953 r
.39916 .49986 .42671 .52601 .47332 .51604 .44626 .4895 Metetra
.688 .783 .924 r
.44626 .4895 .47332 .51604 .52089 .49651 .49442 .46941 Metetra
.751 .799 .891 r
.49442 .46941 .52089 .49651 .56904 .46779 .54325 .43996 Metetra
.799 .806 .857 r
.54325 .43996 .56904 .46779 .61738 .4296 .59235 .40091 Metetra
.837 .809 .823 r
.59235 .40091 .61738 .4296 .66546 .38152 .64126 .35188 Metetra
.865 .809 .793 r
.64126 .35188 .66546 .38152 .71288 .32419 .68955 .29356 Metetra
.89 .807 .761 r
.68955 .29356 .71288 .32419 .7591 .25691 .7367 .22528 Metetra
.909 .805 .732 r
.7367 .22528 .7591 .25691 .80369 .18035 .78223 .14761 Metetra
.666 .157 0 r
.128 .34568 .1568 .3725 .19099 .41565 .16203 .38792 Metetra
0 .046 .54 r
.16203 .38792 .19099 .41565 .22799 .45035 .19897 .42183 Metetra
0 .278 .759 r
.19897 .42183 .22799 .45035 .2676 .47602 .2386 .44686 Metetra
.094 .464 .889 r
.2386 .44686 .2676 .47602 .3095 .49321 .28063 .46345 Metetra
.326 .599 .945 r
.28063 .46345 .3095 .49321 .35346 .50111 .32483 .47083 Metetra
.489 .679 .95 r
.32483 .47083 .35346 .50111 .39916 .49986 .37086 .4691 Metetra
.602 .726 .932 r
.37086 .4691 .39916 .49986 .44626 .4895 .41841 .4582 Metetra
.685 .754 .904 r
.41841 .4582 .44626 .4895 .49442 .46941 .46712 .43761 Metetra
.744 .771 .875 r
.46712 .43761 .49442 .46941 .54325 .43996 .51659 .40762 Metetra
.79 .782 .845 r
.51659 .40762 .54325 .43996 .59235 .40091 .56642 .36805 Metetra
.827 .788 .815 r
.56642 .36805 .59235 .40091 .64126 .35188 .61616 .31862 Metetra
.856 .793 .788 r
.61616 .31862 .64126 .35188 .68955 .29356 .66535 .25995 Metetra
.883 .797 .76 r
.66535 .25995 .68955 .29356 .7367 .22528 .71349 .19149 Metetra
.905 .8 .733 r
.71349 .19149 .7367 .22528 .78223 .14761 .76008 .1138 Metetra
.642 .131 0 r
.09834 .31807 .128 .34568 .16203 .38792 .13231 .35863 Metetra
0 .084 .584 r
.13231 .35863 .16203 .38792 .19897 .42183 .16924 .39093 Metetra
0 .312 .791 r
.16924 .39093 .19897 .42183 .2386 .44686 .20894 .4146 Metetra
.149 .479 .898 r
.20894 .4146 .2386 .44686 .28063 .46345 .2511 .43007 Metetra
.359 .595 .936 r
.2511 .43007 .28063 .46345 .32483 .47083 .29551 .43656 Metetra
.504 .663 .933 r
.29551 .43656 .32483 .47083 .37086 .4691 .34186 .43409 Metetra
.606 .704 .914 r
.34186 .43409 .37086 .4691 .41841 .4582 .38981 .42258 Metetra
.682 .731 .888 r
.38981 .42258 .41841 .4582 .46712 .43761 .43903 .4015 Metetra
.737 .749 .862 r
.43903 .4015 .46712 .43761 .51659 .40762 .48911 .37114 Metetra
.781 .762 .836 r
.48911 .37114 .51659 .40762 .56642 .36805 .53965 .33137 Metetra
.817 .772 .81 r
.53965 .33137 .56642 .36805 .61616 .31862 .5902 .28199 Metetra
.847 .78 .786 r
.5902 .28199 .61616 .31862 .66535 .25995 .6403 .22364 Metetra
.875 .788 .762 r
.6403 .22364 .66535 .25995 .71349 .19149 .68947 .15582 Metetra
.9 .796 .737 r
.68947 .15582 .71349 .19149 .76008 .1138 .73719 .07886 Metetra
.592 .079 0 r
.0678 .28963 .09834 .31807 .13231 .35863 .10186 .3272 Metetra
0 .147 .652 r
.10186 .3272 .13231 .35863 .16924 .39093 .1389 .35691 Metetra
0 .355 .827 r
.1389 .35691 .16924 .39093 .20894 .4146 .17871 .37858 Metetra
.211 .495 .901 r
.17871 .37858 .20894 .4146 .2511 .43007 .22101 .39246 Metetra
.394 .588 .921 r
.22101 .39246 .2511 .43007 .29551 .43656 .26562 .39774 Metetra
.519 .644 .912 r
.26562 .39774 .29551 .43656 .34186 .43409 .31223 .39434 Metetra
.608 .681 .893 r
.31223 .39434 .34186 .43409 .38981 .42258 .36055 .3821 Metetra
.677 .707 .87 r
.36055 .3821 .38981 .42258 .43903 .4015 .41022 .36055 Metetra
.728 .725 .848 r
.41022 .36055 .43903 .4015 .48911 .37114 .46086 .32994 Metetra
.769 .74 .826 r
.46086 .32994 .48911 .37114 .53965 .33137 .51205 .29022 Metetra
.805 .752 .804 r
.51205 .29022 .53965 .33137 .5902 .28199 .56337 .24131 Metetra
.835 .764 .784 r
.56337 .24131 .5902 .28199 .6403 .22364 .61438 .18389 Metetra
.863 .776 .764 r
.61438 .18389 .6403 .22364 .68947 .15582 .66459 .11765 Metetra
.891 .79 .742 r
.66459 .11765 .68947 .15582 .73719 .07886 .71353 .04274 Metetra
.488 0 0 r
.03634 .26033 .0678 .28963 .10186 .3272 .07084 .29275 Metetra
0 .233 .736 r
.07084 .29275 .10186 .3272 .1389 .35691 .1081 .31892 Metetra
.072 .396 .853 r
.1081 .31892 .1389 .35691 .17871 .37858 .14802 .33821 Metetra
.275 .506 .897 r
.14802 .33821 .17871 .37858 .22101 .39246 .19047 .35006 Metetra
.424 .577 .901 r
.19047 .35006 .22101 .39246 .26562 .39774 .23524 .35396 Metetra
.53 .625 .891 r
.23524 .35396 .26562 .39774 .31223 .39434 .28208 .3495 Metetra
.609 .659 .873 r
.28208 .3495 .31223 .39434 .36055 .3821 .33071 .33638 Metetra
.67 .682 .853 r
.33071 .33638 .36055 .3821 .41022 .36055 .38077 .31442 Metetra
.718 .702 .834 r
.38077 .31442 .41022 .36055 .46086 .32994 .4319 .28361 Metetra
.757 .717 .815 r
.4319 .28361 .46086 .32994 .51205 .29022 .48369 .24404 Metetra
.79 .731 .797 r
.48369 .24404 .51205 .29022 .56337 .24131 .53573 .19597 Metetra
.82 .745 .781 r
.53573 .19597 .56337 .24131 .61438 .18389 .58757 .1398 Metetra
.847 .76 .766 r
.58757 .1398 .61438 .18389 .66459 .11765 .63882 .07606 Metetra
.874 .778 .752 r
.63882 .07606 .66459 .11765 .71353 .04274 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00n_ooool4o`000003oa0@4?oooooooooo06Oooooo003looooo`03o`00
0?oooooooooo06Wooooo003looooo`03o`000?oooooooooo06Wooooo003looooo`03o`000?oooooo
oooo06Wooooo003looooo`03o`000?oooooooooo06Wooooo003looooo`03o`000?oooooooooo06Wo
oooo003looooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Mooooo`00
n_ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool00?oooooo
1oooool01Ol@413ooooooooooooooooo410@05gooooo003oooooo`Oooooo00Go0000oooooooooooo
ooooo`00001Mooooo`00ooooool7ooooo`05o`000?ooooooooooooooool00000GOooool00?oooooo
1oooool01Ol@413ooooooooooooooooo410@05gooooo003oooooo`7ooooo0_l00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0GOooool00?gooooo0ol000000ooooooo0000ooooo`03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0GOooool00?_ooooo0_l00004ooooo`;o0000IOooool00?Sooooo0ol0
0006ooooo`03o`000?oooooo000006Cooooo003fooooo`;o00002?ooool4o`0006Cooooo003coooo
o`Co00002?ooool01?l0003oglO0o`000?oOal02o`0006?ooooo002mooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c00Nooooo`?o00000ooo
ool00ol0003oooooooooo`05ooooo`08o`000?oOal3oglO0o`000?oOal3o0000ooooool0001Roooo
o`00_Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B407?ooool2o`0000kooooo00Co0000omo7`?oOal3o00000_oOal02o`0006;ooooo002m
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001Wooooo
0ol0000?ooooo`05o`000?oOal3oglO0omo7`?l000000ooOal02o`00067ooooo002mooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b01Oooooo0_l0000Aoooo
o`03o`000?oOal3oglO000?oglO000?o0000omo7`?oOal000ol0001Pooooo`00_Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00Dooooo`?o00000_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oOal3oglO000?oglO000Co0000omo7`?oOal3oglO00_l0
001Pooooo`00_Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@400Booooo`;o00005Oooool00ol0003oglO0omo7`004omo7`003o`000?oOal3oglO000;oglO0
0_l0001Oooooo`00_Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
^[Zjo`00000?ooooo`?o00005_ooool00ol0003oglO0omo7`005omo7`003o`000?oOal3oglO000;o
glO000?o0000ooooool00000G_ooool00;gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT03Oooool2o`0001Sooooo00?o0000omo7`?oOal001_oOal000ol0
003oglO0omo7`003omo7`0;o0000G_ooool007_ooooo0_l00002ooooo`;o0000Foooool4o`0001Wo
oooo00?o0000omo7`?oOal001_oOal000ol0003oglO0omo7`004omo7`0;o0000GOooool007_ooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeIooooo`;o00001?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oOal3oglO000OoglO000?o0000omo7`?oOal001?oOal02o`0005gooooo001looooo`04
omgMgOl0003o410@olc<c5Oooooo0ol0000Mooooo`03o`000?oOal3oglO000SoglO000?o0000omo7
`?oOal000ooOal001?l0003oi<Zmo`000?l0001Looooo`00O?ooool01?o^k^ko8B4Qoa0@4?o^k^iD
ooooo`?o00007oooool00ol0003oglO0omo7`009omo7`003o`000?oOal3oglO000;oglO000Co0000
onC:_OoTb[goi<Zm0_l0001Kooooo`00O?ooool01?lQ8B7oMgMgogMgMolb<S9Booooo`?o00008Ooo
ool00ol0003oglO0omo7`009omo7`003o`000?oOal3oglO000;oglO000?o0000onC:_OoTb[d00_oT
b[d00ol0003oooooooooo`1Iooooo`00Noooool2o`0000;ooooo0_l0001>ooooo`?o00000_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oOal3oglO000[oglO000Go0000omo7`?oOal3oglO0o`00
0005onC:_@;o0000F_ooool00<gooooo0_l00006ooooo`03o`000?oooooooooo01cooooo00?o0000
omo7`?oOal002ooOal001Ol0003oglO0omo7`?oOal3o000000Koi<Zm0_l0001Iooooo`00b_ooool3
o`0002Oooooo00?o0000omo7`?oOal002ooOal001?l0003oglO0omo7`?l00008onC:_@03o`000?oo
oooooooo05Oooooo0038ooooo`;o0000:Oooool00ol0003oglO0omo7`00<omo7`003o`000?oOal3o
000000Woi<Zm0_l0001Hooooo`00TOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`07oooool3o`000003ooooool0003ooooo02Oooooo00?o
0000omo7`?oOal003OoOal000ol0003oglO0o`00000:onC:_@;o0000Eoooool0097ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01gooooo
0_l0000/ooooo`03o`000?oOal3oglO000ooglO000?o0000onC:_OoTb[d02_oTb[d00ol0003ooooo
ooooo`1Eooooo`00TOooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Jooooo`?o0000;_ooool00ol0003oglO0omo7`00>omo7`0;o00003OoTb[d00ol0003o
ooooooooo`1Dooooo`00TOooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@0Hooooo`;o0000<?ooool00ol0003of<;4o`00000?omo7`0;o00003OoTb[d2o`00
00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0003Sooooo002Aoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<01Gooooo1?l0
000`ooooo`05o`000?oH`/Cof<;4omS2a?l000003OoOal000ol0003oi<Zmo`00000<onC:_@03o`00
0?oVbkco000000Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A403Sooooo002Aooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`0Eooooo`;o00001?ooool00ol0003oooooooooo`0/ooooo`03o`000?oH`/Cof<;4
00;of<;400?o0000omo7`?oOal002ooOal000ol0003oi<Zmo`00000;onC:_@05o`000?oVbkcoi/^l
onK;_?l000001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0>Ooo
ool0097ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01;ooooo0ol0
000eooooo`03o`000?oH`/Cof<;400?of<;400?o0000omo7`?oOal002OoOal001?l0003oi<ZmonC:
_Ol0000;onC:_@04o`000?oVbkcoi/^lonK;_0;o00001_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0>?ooool0097ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40gooooo0ol0000gooooo`03o`000?oH`/Cof<;400Gof<;400?o0000
omo7`?oOal001ooOal001Ol0003oi<ZmonC:_OoTb[go000000[oi<Zm00?o0000onK;_?oVbk`00ooV
bk`00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`0gooooo`00/Oooool3o`0003Sooooo00?o0000omS2a?oH`/@01_oH`/@00ol0003oglO0omo7
`007omo7`005o`000?oTb[goi<ZmonC:_Ol000002OoTb[d00ol0003oi/^lonK;_005onK;_003o`00
0?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo03Ko
oooo002^ooooo`?o00000oooool00ol0003oooooooooo`0dooooo`03o`000?oH`/Cof<;400Sof<;4
00?o0000omo7`?oOal001OoOal000ol0003oi<ZmonC:_@02onC:_@03o`000?oTb[goi<Zm00Ooi<Zm
00?o0000onK;_?oVbk`01OoVbk`2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@4100>?ooool00:cooooo0_l0000mooooo`03o`000?oH`/Cof<;400So
f<;400?o0000omo7`?oOal001?oOal000ol0003oi<ZmonC:_@03onC:_@03o`000?oTb[goi<Zm00Ko
i<Zm00?o0000onK;_?oVbk`01ooVbk`00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<03Sooooo002Yooooo`?o0000?_ooool00ol0
003of<;4omS2a00:omS2a003o`000?oOal3oglO000?oglO000?o0000onC:_OoTb[d00ooTb[d00ol0
003oi<ZmonC:_@06onC:_@03o`000?oVbkcoi/^l00Ooi/^l0_l0001@ooooo`00Yoooool2o`00043o
oooo00?o0000omS2a?oH`/@03?oH`/@01Ol0003oglO0omo7`?oOal3o000000Koi<Zm00?o0000onC:
_OoTb[d01OoTb[d00ol0003oi/^lonK;_009onK;_0;o0000Coooool00:Cooooo0ol00002ooooo`03
o`000?oooooooooo03cooooo00?o0000omS2a?oH`/@03OoH`/@01Ol0003oglO0omo7`?oOal3o0000
00Koi<Zm00?o0000onC:_OoTb[d01?oTb[d00ol0003oi/^lonK;_00;onK;_003o`000?oooooooooo
04gooooo002Rooooo`;o00001_ooool00ol0003oooooooooo`0jooooo`03o`000?oH`/Cof<;400oo
f<;400?o0000omo7`?l000001ooTb[d00ol0003oi<ZmonC:_@04onC:_@03o`000?oVbkcoi/^l00_o
i/^l0_l0001>ooooo`00Woooool3o`0004Gooooo00?o0000omS2a?oH`/@04?oH`/@00ol0003oi<Zm
onC:_@06onC:_@03o`000?oTb[goi<Zm00?oi<Zm00?o0000onK;_?oVbk`02ooVbk`01?l0003oilbk
o`000?l0001=ooooo`00Ioooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool07oooool2o`0004Oooooo00?o0000omS2a?oH`/@04OoH`/@00ol0003o
i<ZmonC:_@06onC:_@03o`000?oTb[goi<Zm00;oi<Zm00?o0000onK;_?oVbk`02ooVbk`01Ol0003o
ilbkonO<^ooWc;_o000004gooooo001Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Oooooo00?o0000ooooooooool07Oooool3o`0000;ooooo00?o0000ooooooooool0@oooool00ol0
003of<;4omS2a00AomS2a003o`000?oLa/?o000000Soi<Zm00Go0000onC:_OoTb[goi<Zmo`00000=
onK;_004o`000?oWc;_oilbkonO<^`;o0000C?ooool006Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`Go00006oooool3o`0004[ooooo00?o0000omS2a?oH`/@04OoH`/@01?l0003og<K3omc6
`ol00008onC:_@04o`000?oTb[goi<Zmo`0000goi/^l00?o0000onO<^ooWc;/00ooWc;/2o`0004_o
oooo001Wooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Joooo
o`;o0000COooool00ol0003of<;4omS2a00@omS2a003o`000?oLa/?og<K300;og<K300?o0000onC:
_OoTb[d01OoTb[d00ol0003oi<Zmo`00000>onK;_003o`000?oWc;_oilbk00Coilbk00?o0000oooo
ooooool0BOooool006Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0001Oooooo0ol0001>ooooo`03o`000?oH`/Cof<;4017of<;400?o0000omc6`ooLa/<00ooLa/<0
0ol0003oi<ZmonC:_@04onC:_@03o`000?oTb[go000000goi/^l00?o0000onO<^ooWc;/01OoWc;/2
o`0004[ooooo001Wooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000E
ooooo`;o00000_ooool00ol0003oooooooooo`1;ooooo`03o`000?oH`/Cof<;4017of<;400?o0000
omc6`ooLa/<01?oLa/<00ol0003oi<ZmonC:_@04onC:_@;o00003OoVbk`00ol0003oilbkonO<^`07
onO<^`03o`000?oooooooooo04Sooooo001Wooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`00000Booooo`?o0000DOooool00ol0003of<;4omS2a00AomS2a003o`000?oLa/?o
g<K300Kog<K300?o0000onC:_OoTb[d00ooTb[d2o`0000goi/^l00?o0000onO<^ooWc;/01ooWc;/2
o`0004Wooooo001Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?
ooooo`;o0000E?ooool00ol0003of<;4omS2a00@omS2a003o`000?oLa/?og<K300Oog<K300?o0000
onC:_OoTb[d00ooTb[d00ol0003oi/^lonK;_00;onK;_003o`000?oWc;_oilbk00Woilbk0_l00018
ooooo`00R?ooool3o`0005Gooooo00?o0000om6naol000004OoH`/@00ol0003og<K3omc6``08omc6
``04o`000?oTb[goi<ZmonC:_@;o00003OoVbk`00ol0003oilbkonO<^`0:onO<^`03o`000?oooooo
oooo04Kooooo0026ooooo`;o00000_ooool00ol0003oooooooooo`1Booooo`05o`000?oA_/OodKk7
om6naol000003ooH`/@00ol0003og<K3omc6``0:omc6``03o`000?oTb[goi<Zm00;o00003?oVbk`0
0ol0003oilbkonO<^`0;onO<^`;o0000Aoooool008?ooooo0ol0001Hooooo`03o`000?oA_/OodKk7
00;odKk700?o0000omS2a?oH`/@03?oH`/@00ol0003og<K3omc6``0;omc6``05o`000?oTb[go0000
onK;_?l000002ooVbk`00ol0003oilbkonO<^`0;onO<^`04o`000?oXc[_o0000o`0004Kooooo0021
ooooo`;o0000F_ooool00ol0003odKk7om6na`04om6na`03o`000?oH`/Cof<;400[of<;400?o0000
omc6`ooLa/<03OoLa/<01?l0003oi/^lonK;_?l0000;onK;_003o`000?oWc;_oilbk00[oilbk00Go
0000onS>^ooXc[_oj<jko`000016ooooo`00O_ooool3o`0005_ooooo00?o0000om6naooA_/L01_oA
_/L00ol0003of<;4omS2a008omS2a003o`000?oLa/?og<K300kog<K300Co0000onK;_?oVbkco0000
2_oVbk`00ol0003oilbkonO<^`0;onO<^`04o`000?oXc[_oj<jkonS>^`;o0000AOooool007_ooooo
0ol00002ooooo`03o`000?oooooooooo05Sooooo00?o0000om6naooA_/L01ooA_/L00ol0003of<;4
omS2a008omS2a003o`000?oLa/?og<K300gog<K300Go0000omo9`ol0003oi/^lo`00000:onK;_003
o`000?oWc;_oilbk00[oilbk00?o0000onS>^ooXc[/00ooXc[/2o`0004Cooooo001iooooo`;o0000
1_ooool00ol0003oooooooooo`1Fooooo`03o`000?oA_/OodKk700WodKk700?o0000omS2a?oH`/@0
1_oH`/@00ol0003og<K3omc6``0=omc6``04o`000?oObL?oglW3omo9``;o00002OoVbk`00ol0003o
ilbkonO<^`0;onO<^`03o`000?oXc[_oj<jk00Coj<jk00?o0000ooooooooool0@_ooool007Kooooo
0ol0001Pooooo`03o`000?oA_/OodKk700[odKk700?o0000omS2a?oH`/@01OoH`/@00ol0003og<K3
omc6``0=omc6``03o`000?oObL?oglW300?oglW300?o0000onK;_?oVbk`01_oVbk`00ol0003oilbk
onO<^`0;onO<^`03o`000?oXc[_oj<jk00Koj<jk00?o0000ooooooooool0@Oooool003kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00027ooooo0_l0001Rooooo`03o`00
0?oA_/OodKk700codKk700?o0000omS2a?oH`/@00ooH`/@00ol0003og<K3omc6``0>omc6``03o`00
0?oObL?oglW300?oglW300?o0000onK;_?oVbk`01_oVbk`00ol0003oilbkonO<^`0:onO<^`03o`00
0?oXc[_oj<jk00Ooj<jk0_l00012ooooo`00?_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool3o`0000;ooooo00?o0000oooooooo
ool0G_ooool00ol0003odKk7om6na`0>om6na`03o`000?oH`/Cof<;400;of<;400?o0000omc6`ooL
a/<03OoLa/<00ol0003oglW3omo9``05omo9``03o`000?oVbkcoi/^l00Coi/^l00?o0000onO<^ooW
c;/02ooWc;/00ol0003oj<jkonS>^`08onS>^`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02?ooooo000nooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Mooooo`;o0000IOooool00ol0
003odKk7om6na`0?om6na`05o`000?oH`/Cof<;4omS2a?l000003ooLa/<00ol0003oglW3omo9``06
omo9``;o00001OoVbk`00ol0003oilbkonO<^`0:onO<^`03o`000?oXc[_oj<jk00[oj<jk00?o0000
ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo02Cooooo000nooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP0Iooooo`?o0000I_ooool00ol0003odKk7om6na`0Aom6na`03o`000?oH`/Co0000013og<K300?o
0000omo9`ooObL<01_oObL<2o`0000Coi/^l00?o0000onO<^ooWc;/02ooWc;/00ol0003oj<jkonS>
^`0:onS>^`;o00001_ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Uooooo`00?_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool05_ooool2o`0006Sooooo
00?o0000om6naooA_/L04ooA_/L00ol0003og<K3omc6``0>omc6``03o`000?oObL?oglW300OoglW3
00?o0000omo9`ol000000_oVbk`00ol0003oilbkonO<^`0;onO<^`03o`000?oXc[_oj<jk00[oj<jk
00?o0000onW>^ol000001_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00002oooool3o`000003oa0@4?oooooooooo01Gooooo000nooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`0Booooo`?o00000_ooool00ol0003oooooooooo`1Toooo
o`03o`000?oA_/OodKk701CodKk700?o0000omc6`ooLa/<03OoLa/<00ol0003oglW3omo9``08omo9
``06o`000?oObL?oglW3o`000?oVbkco00003?oWc;/00ol0003oj<jkonS>^`0;onS>^`04o`000?oY
c[_o0000o`0000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`00
00gooooo00?o410@okZj^_ooool05_ooool003kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41004_ooool2o`0006_ooooo00?o0000om6naooA_/L05?oA_/L0
0ol0003oeL?8o`00000=omc6``03o`000?oObL?oglW300WoglW300Go0000omo9`ooObL?oglW3o`00
000=onO<^`03o`000?oXc[_oj<jk00[oj<jk00Co0000onW>^ooYc[_ojLjk0_l00004ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000=ooooo`03oiRHV?lb<S;ooooo01Ko
oooo000nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00oooooo0ol0001[ooooo`;o00005_oA_/L01Ol0003oeL?8omG3b?oE`lSo000000cog<K300?o0000
omo9`ooObL<02OoObL<01Ol0003oglW3omo9`ooObL?o000000coilbk00?o0000onS>^ooXc[/02_oX
c[/00ol0003ojLjkonW>^`02onW>^`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000003Oooool00ooMgMgo0000okZj^P0Fooooo`00H?ooool3o`0006cooooo00?o
0000olZkc?l000005OoA_/L00ol0003oeL?8omG3b002omG3b003o`000?oLa/?og<K300Wog<K300?o
0000omo9`ooObL<02_oObL<01_l0003oglW3omo9`ol0003oh/c2o`0000_oilbk00?o0000onS>^ooX
c[/02_oXc[/00ol0003ojLjkonW>^`03onW>^`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool03?ooool00omEEEGoMgMgodA4A00Fooooo`00GOooool3o`0000;o
oooo00?o0000ooooooooool0JOooool01Ol0003ob[_<olZkc?o:^lco000001?odKk700?o0000omG3
b?oE`lP01?oE`lP00ol0003og<K3omc6``07omc6``03o`000?oObL?oglW300_oglW300?o0000omo9
`ol000000ooRc<800ol0003oilbkonO<^`07onO<^`03o`000?oXc[_oj<jk00[oj<jk00?o0000onW>
^ooYc[/01OoYc[/2o`0002;ooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Eooooo`00F_ooool3o`00
073ooooo00?o0000olZkc?o:^l`00_o:^l`00ol0003odKk7om6na`0@om6na`03o`000?oE`lSoeL?8
00KoeL?800?o0000omc6`ooLa/<01_oLa/<00ol0003oglW3omo9``0;omo9``03o`000?oObL?o0000
00?oh/c200?o0000onO<^ooWc;/01_oWc;/00ol0003oj<jkonS>^`0;onS>^`03o`000?oYc[_ojLjk
00GojLjk0_l0000Rooooo`05ofIVI_n7QhOooooooiRHV?mEEED05Oooool005Sooooo0_l0001boooo
o`03o`000?o:^lcob[_<00Cob[_<00?o0000om6naooA_/L03_oA_/L00ol0003oeL?8omG3b007omG3
b003o`000?oLa/?og<K300Gog<K300?o0000omo9`ooObL<03?oObL<2o`0000Goh/c200?o0000onO<
^ooWc;/01OoWc;/00ol0003oj<jkonS>^`0:onS>^`03o`000?oYc[_ojLjk00OojLjk0_l0000Poooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04oooool005Gooooo1?l0001booooo`03
o`000?o:^lcob[_<00Gob[_<00?o0000om6naooA_/L03OoA_/L00ol0003oeL?8omG3b009omG3b003
o`000?oLa/?og<K300?og<K300?o0000omo9`ooObL<03OoObL<00ol0003oh/c2on;<`P05on;<`P03
o`000?oWc;_oilbk00?oilbk00?o0000onS>^ooXc[/02ooXc[/00ol0003ojLjkonW>^`07onW>^`03
o`000?oooooo000001oooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0Boooo
o`00Doooool2o`0000Cooooo00?o0000ooooooooool0K_ooool00ol0003ob[_<olZkc007olZkc003
o`000?oA_/OodKk700_odKk700?o0000omG3b?oE`lP02ooE`lP01Ol0003og<K3omc6`ooLa/?o0000
013oglW300?o0000on;<`_oRc<801OoRc<800ol0003oilbkonO<^`03onO<^`03o`000?oXc[_oj<jk
00[oj<jk00?o0000onW>^ooYc[/02OoYc[/2o`0003[ooooo001@ooooo`?o0000M_ooool00ol0003o
b[_<olZkc008olZkc003o`000?oA_/OodKk700[odKk700?o0000omG3b?oE`lP03?oE`lP01Ol0003o
g<K3omc6`ooLa/?o000000ooglW30_l00008on;<`P05o`000?oWc;_oilbkonO<^ol000003OoXc[/0
0ol0003ojLjkonW>^`09onW>^`?o0000>Oooool002Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0P
ooooo`;o0000N?ooool00ol0003ob[_<olZkc00:olZkc003o`000?oA_/OodKk700SodKk700?o0000
omG3b?oE`lP03_oE`lP00ol0003og<K3o`00000?omo9``03o`000?oRc<;o000000Soh/c200Co0000
onO<^ooWc;_o00003OoXc[/00ol0003ojLjkonW>^`09onW>^`04o`000?oYd;co0000o`0003Wooooo
000Yooooo`05ogMgMonHV9SooooooiRHV?mgMgL07Oooool3o`000003ooooool0003ooooo07Kooooo
00?o0000olZkc?o:^l`03?o:^l`00ol0003odKk7om6na`06om6na`03o`000?oE`lSoeL?8013oeL?8
00?o0000omo9`ooObL<03_oObL<01?l0003oh/c2on;<`_l00008on;<`P03o`000?oWc;_o000000co
j<jk00?o0000onW>^ooYc[/02OoYc[/01?l0003ojM2lonW@_?oYd;`2o`0003Sooooo000Yooooo`05
oa0@4?ooooooooooooooool@41006oooool2o`0007_ooooo00?o0000olZkc?o:^l`03Oo:^l`00ol0
003odKk7om6na`05om6na`03o`000?oE`lSoeL?8017oeL?800?o0000omo9`ooObL<03OoObL<01Ol0
003oh/c2on;<`_oRc<;o000000Woh/c200?o0000onS>^ooXc[/02ooXc[/00ol0003ojLjkonW>^`09
onW>^`03o`000?oYd;cojM2l00;ojM2l0_l0000gooooo`00:Oooool01Ol0003ooooooooooooooooo
000001Sooooo0ol0001looooo`03o`000?o:^lcob[_<00oob[_<00?o0000om6naooA_/L00ooA_/L0
0ol0003oeL?8omG3b00AomG3b003o`000?oHalWo000000goglW300?o0000on;<`_oRc<800_oRc<80
0ol0003oh/c2on;<`P07on;<`P03o`000?oXc[_oj<jk00[oj<jk00?o0000onW>^ooYc[/02OoYc[/0
0ol0003ojM2lonW@_004onW@_003o`000?oooooooooo03Gooooo000Yooooo`05o`000?oooooooooo
ooooool000005_ooool2o`0007kooooo00?o0000olZkc?o:^l`04?o:^l`00ol0003odKk7om6na`02
om6na`03o`000?oE`lSoeL?8017oeL?800Go0000omS7bOoHalWof<O9o`00000;omo9``03o`000?oR
c<;oh/c200?oh/c200?o0000on;<`_oRc<801_oRc<800ol0003ohlk2o`00000;onS>^`03o`000?oY
c[_ojLjk00WojLjk00?o0000onW@_?oYd;`01?oYd;`2o`0003Kooooo000Yooooo`05oa0@4?oooooo
ooooooooool@41004oooool3o`0000;ooooo00?o0000ooooooooool0N_ooool00ol0003ob[_<olZk
c00BolZkc004o`000?oA_/OodKk7o`0001?oeL?800?o0000omS7bOoHalT00_oHalT00ol0003oglW3
omo9``09omo9``03o`000?oRc<;oh/c200?oh/c200?o0000on;<`_oRc<801OoRc<801Ol0003ohlk2
on?>`_oSc/;o000000Woj<jk00?o0000onW>^ooYc[/02OoYc[/00ol0003ojM2lonW@_006onW@_0;o
0000=Oooool002Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0@ooooo`?o0000POooool00ol0003o
b[_<olZkc00ColZkc003o`000?oA_/Oo000001?oeL?800?o0000omS7bOoHalT01?oHalT00ol0003o
glW3omo9``07omo9``03o`000?oRc<;oh/c200Coh/c200?o0000on;<`_oRc<801?oRc<800ol0003o
hlk2on?>`P03on?>`P03o`000?oXc[_oj<jk00Koj<jk00?o0000onW>^ooYc[/02?oYc[/00ol0003o
jM2lonW@_008onW@_003o`000?oooooooooo03?ooooo000Yooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03_ooool2o`0008?ooooo00?o0000olZkc?o:^l`05?o:^l`2o`0001?oeL?800?o0000omS7bOoH
alT01_oHalT00ol0003oglW3omo9``05omo9``03o`000?oRc<;oh/c200Goh/c200?o0000on;<`_oR
c<801?oRc<800ol0003ohlk2on?>`P04on?>`P03o`000?oXc[_oj<jk00Coj<jk00?o0000onW>^ooY
c[/02OoYc[/00ol0003ojM2lonW@_009onW@_003o`000?oooooooooo03;ooooo000iooooo`Go0000
POooool2o`0001Kob[_<00?o0000olk0cOl000004ooE`lP00ol0003of<O9omS7b@06omS7b@03o`00
0?oObL?oglW300GoglW300?o0000on;<`_oRc<801?oRc<82o`0000Goh/c200?o0000on?>`_oSc/80
1OoSc/800ol0003oj<jkonS>^`04onS>^`03o`000?oYc[_ojLjk00SojLjk00?o0000onW@_?oYd;`0
2_oYd;`2o`0003?ooooo000gooooo`;o0000QOooool00ol0003o`KO@o`00000EolZkc005o`000?o>
`<goc/3=olk0cOl000004OoE`lP00ol0003of<O9omS7b@08omS7b@03o`000?oObL?oglW300?oglW3
00?o0000on;<`_oRc<800_oRc<83o`000003on;<`_l0003oh/c200?oh/c200?o0000on?>`_oSc/80
1ooSc/800ol0003oj<jkonS>^`02onS>^`03o`000?oYc[_ojLjk00WojLjk00?o0000onW@_?oYd;`0
2OoYd;`00ol0003ojM6mo`00000cooooo`00=?ooool3o`0008Kooooo00Go0000ol6gd?o1]m3o`KO@
o`00000ColZkc003o`000?o>`<goc/3=00?oc/3=00?o0000omG3b?oE`lP03OoE`lP00ol0003of<O9
omS7b@0:omS7b@05o`000?oObL?oglW3omo9`ol000000_oRc<83o`0000Goh/c200Go0000on;<`_oR
c<;oh/c2o`00000:on?>`P04o`000?oXc[_oj<jko`0000_ojLjk00?o0000onW@_?oYd;`02OoYd;`0
1Ol0003ojM6monWA_OoYdKgo000003;ooooo000cooooo`;o0000Q_ooool2o`0000Go`KO@00?o0000
olZkc?o:^l`03oo:^l`00ol0003oc/3=olk0c@04olk0c@03o`000?oE`lSoeL?800coeL?800?o0000
omS7bOoHalT02ooHalT01?l0003oglW3omo9`ooObL<3o`0000Woh/c200?o0000on;<`_l000003?oS
c/800ol0003oj<jko`00000:onW>^`03o`000?oYd;cojM2l00[ojM2l00Co0000onWA_OoYdKgojM6m
0_l0000aooooo`00<oooool3o`0008Cooooo00?o0000ol6gd?o1]m001Oo1]m000ol0003ob[_<olZk
c00>olZkc003o`000?o>`<goc/3=00Koc/3=00?o0000omG3b?oE`lP02_oE`lP00ol0003of<O9omS7
b@0=omS7b@?o00003OoRc<800ol0003ohlk2on?>`P0<on?>`P03o`000?oYc[_ojLjk00WojLjk00?o
0000onW@_?oYd;`02OoYd;`00ol0003ojM6monWA_@03onWA_@;o0000<?ooool003;ooooo0ol00000
0ooooooo0000ooooo`21ooooo`03o`000?o1]m3o`KO@00Oo`KO@00?o0000olZkc?o:^l`03?o:^l`0
0ol0003oc/3=olk0c@08olk0c@03o`000?oE`lSoeL?800SoeL?800?o0000omS7bOoHalT02ooHalT3
o`000003omS7bOl0003oh/c200coh/c20_l0000>on?>`P03o`000?oYc[_ojLjk00SojLjk00?o0000
onW@_?oYd;`02_oYd;`00ol0003ojM6monWA_@03onWA_@;o00002?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`04oooool002Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`;o00000_ooool00ol0003oooooooooo`1mooooo`;o0000
2oo1]m000ol0003ob[_<olZkc00:olZkc003o`000?o>`<goc/3=00[oc/3=00?o0000omG3b?oE`lP0
1_oE`lP00ol0003of<O9omS7b@09omS7b@?o00001?oHalT00ol0003oh/c2on;<`P0;on;<`P03o`00
0?oSc/;o000000cohlk200?o0000onC@`ol000002OoYc[/00ol0003ojM2lonW@_009onW@_003o`00
0?oYdKgojM6m00GojM6m0_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@0Cooooo`009oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`1kooooo`03o`000?o1]m3o
`KO@00_o`KO@00?o0000olZkc?o:^l`02Oo:^l`00ol0003oc/3=olk0c@0;olk0c@03o`000?oE`lSo
eL?800KoeL?800?o0000omS7bOoHalT01ooHalT2o`0000Kof<O900?o0000om_;bOl000002ooRc<80
1Ol0003ohlk2on?>`_oSc/;o000000[ohlk200Go0000onC@`ooTd<?oi=33o`000007onW>^`03o`00
0?oYd;cojM2l00WojM2l00?o0000onWA_OoYdKd01ooYdKd00ol0003oooooooooo`05ooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001?ooooo000Wooooo`05
oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo00Co0000oooooooooooo0000Noooool0
0ol0003o`KO@ol6gd00=ol6gd003o`000?o:^lcob[_<00Oob[_<00?o0000olk0cOo>`<d03Oo>`<d0
0ol0003oeL?8omG3b004omG3b003o`000?oHalWof<O900Gof<O90ol00007omS7b@05o`000?oKblWo
fl_9om_;bOl000002OoRc<800ol0003ohlk2on?>`P02on?>`P03o`000?oSc/;ohlk200Oohlk200?o
0000onC@`ooTd<<00_oTd<<00ol0003ojLjkonW>^`04onW>^`03o`000?oYd;cojM2l00[ojM2l00?o
0000onWA_OoYdKd01ooYdKd2o`0000Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B404oooool002Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000N?ooool2o`00013o`KO@00?o0000olZk
c?o:^l`01_o:^l`00ol0003oc/3=olk0c@0?olk0c@03o`000?oE`lSoeL?800;oeL?800?o0000omS7
bOoHalT00ooHalT3o`0000Wof<O900?o0000om_;bOoKblT00_oKblT00ol0003oh/c2on;<`P07on;<
`P03o`000?oSc/;ohlk200?ohlk200?o0000on?>`_oSc/801_oSc/800ol0003oi=33onC@``03onC@
``03o`000?oYc[_ojLjk00?ojLjk00?o0000onW@_?oYd;`02OoYd;`00ol0003ojM6monWA_@09onWA
_@;o00001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c00Cooooo`009oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool0001fooooo`03o`000?o1]m3o`KO@017o`KO@00?o0000olZkc?o:^l`0
1?o:^l`00ol0003oc/3=olk0c@0@olk0c@05o`000?oE`lSoeL?8omG3b?l000000ooHalT3o`0000_o
f<O900?o0000om_;bOoKblT01?oKblT00ol0003oh/c2on;<`P05on;<`P03o`000?oSc/;ohlk200Go
hlk200?o0000on?>`_oSc/801?oSc/800ol0003oi=33onC@``05onC@``05o`000?oYc[_ojLjkonW>
^ol000003?oYd;`00ol0003ojM6monWA_@09onWA_@;o00001Oooool01Ol@413ooooooooooooooooo
410@00_ooooo00?oEEEEohN7Qoooool05Oooool002Oooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000M?ooool00ol0003o`KO@ol6g
d00Col6gd003o`000?o:^lcob[_<00;ob[_<00?o0000olk0cOo>`<d04_o>`<d01?l0003oeL?8o`00
0?oHalT3o`0000gof<O900?o0000om_;bOoKblT01_oKblT00ol0003oh/c2on;<`P03on;<`P03o`00
0?oSc/;ohlk200Oohlk200?o0000on?>`_oSc/800_oSc/800ol0003oi=33onC@``06onC@``05o`00
0?oYc[_ojLjkonW>^ol000002ooYd;`00ol0003ojM6monWA_@09onWA_@04o`000?oXdkoo0000o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01Gooooo000Woooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Oooooo00Co0000oooooooooooo0000LOoo
ool2o`0001Ko`KO@00Go0000olZkc?o:^lcob[_<o`00000Eolk0c@Co00003ooHalT00ol0003ofl_9
om_;b@08om_;b@05o`000?oRc<;oh/c2on;<`_l000002_oSc/800ol0003ohlk2on?>`P02on?>`P03
o`000?oTd<?oi=3300Ooi=3300?o0000onW>^ol000002ooYd;`00ol0003ojM6monWA_@09onWA_@04
o`000?oXdkooj=>oonSC_`;o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@4oooool002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo0000Koooool00ol0003o]k?Eo`00000Gol6gd003o`00
0?o:^lco000001Coc/3=1?l0000@omS7b@03o`000?oKblWofl_900Wofl_900Go0000on;<`_oRc<;o
h/c2o`00000;on?>`P04o`000?oSc/;ohlk2o`0000_oi=3300?o0000onW@_?oYd;`02_oYd;`00ol0
003ojM6monWA_@09onWA_@04o`000?oXdkooj=>oonSC_`;o0000:oooool0037ooooo00?o0000oooo
ooooool02?ooool2o`000003ooooool0003ooooo06_ooooo0_l00003okNce@03o`000?o1]m3o`KO@
01Co`KO@0_l0000Colk0c@?o00000ooAaLl00ol0003of<O9omS7b@0<omS7b@03o`000?oKblWofl_9
00_ofl_900?o0000on;<`_l000003OoSc/82o`0000coi=3300?o0000onW@_?oYd;`02OoYd;`00ol0
003ojM6monWA_@09onWA_@03o`000?oXdkooj=>o00?oj=>o0_l0000Zooooo`00<Oooool2o`0000Wo
oooo0ol000000ooooooo0000ooooo`1Xooooo`;o00001_ng/mD00ol0003o`KO@ol6gd00Bol6gd003
o`000?o4_M?o0000013oc/3=0ol000000oo>`<go0000om75c`04om75c`03o`000?oHalWof<O900_o
f<O900?o0000om_;bOoKblT03?oKblT00ol0003ohlk2on?>`P0<on?>`P03o`000?oTd<?oi=3300[o
i=3300?o0000onGCa?l000002_oYd;`00ol0003ojM6monWA_@08onWA_@03o`000?oXdkooj=>o00Go
j=>o0_l0000Yooooo`00<Oooool00ol0003oooooooooo`09ooooo`05o`000?l0>kco0000ooooool0
0000Ioooool00ol0003o]k?EokNce@06okNce@03o`000?o1]m3o`KO@017o`KO@00Go0000olBmdoo4
_M?oa;gCo`00000<olk0c@?o00000oo>`<d00ol0003odLG?om75c`05om75c`03o`000?oHalWof<O9
00Wof<O900?o0000om_;bOoKblT03OoKblT00ol0003ohlk2on?>`P0<on?>`P;o00002_oTd<<01Ol0
003oiM?4onGCa?oUdlCo000000SojM2l00?o0000onWA_OoYdKd02OoYdKd00ol0003oj=>oonSC_`05
onSC_`;o0000:Oooool0037ooooo00?o0000ooooooooool02_ooool00ol0003o03^lo`000002o`00
06Cooooo0_l0000:okNce@03o`000?o1]m3o`KO@00oo`KO@00?o0000olBmdoo4_M<00oo4_M<00ol0
003oc/3=olk0c@06olk0c@?o00001Oo>`<d00ol0003odLG?om75c`06om75c`03o`000?oHalWof<O9
00Sof<O900?o0000om_;bOoKblT03OoKblT00ol0003ogLo;o`00000<on?>`P04o`000?oTd<?oi=33
o`0000Woi=3300?o0000onGCa?oUdl@00_oUdl@00ol0003ojM2lonW@_004onW@_003o`000?oYdKgo
jM6m00WojM6m00?o0000onSC_ooXdkl01ooXdkl2o`0002Sooooo000aooooo`03o`000?oooooooooo
00_ooooo00?o0000o`0k_?l0>k`00_l0001Rooooo`03o`000?ng/mGo]k?E00[o]k?E00?o0000ol6g
d?o1]m003Oo1]m02o`0000Koa;gC00?o0000olk0cOo>`<d00oo>`<d3o`0000Ooc/3=00?o0000om75
cooAaLl02?oAaLl00ol0003of<O9omS7b@06omS7b@03o`000?oKblWofl_900gofl_900Go0000omg?
booMcl_ogLo;o`00000:on?>`P03o`000?oTd<?oi=3300;oi=3300?o0000onC@`ooTd<<01OoTd<<0
0ol0003oiM?4onGCa004onGCa003o`000?oYd;cojM2l00?ojM2l00?o0000onWA_OoYdKd02OoYdKd0
0ol0003oj=>oonSC_`08onSC_`03o`000?oooooooooo02Kooooo000`ooooo`;o00003_ooool00ol0
003o03^lo`0k_003o`0005kooooo0_l0000>okNce@03o`000?o1]m3o`KO@00_o`KO@00?o0000olBm
doo4_M<01oo4_M<00ol0003oc/3=o`000002o`0000Woc/3=00?o0000om75cooAaLl02_oAaLl00ol0
003of<O9omS7b@04omS7b@03o`000?oKblWofl_900gofl_900?o0000omg?booMcl/00ooMcl/00ol0
003ohlk2on?>`P07on?>`P03o`000?oTd<?oi=3300;oi=3300?o0000onC@`ooTd<<01?oTd<<00ol0
003oiM?4onGCa005onGCa003o`000?oYd;cojM2l00;ojM2l00?o0000onWA_OoYdKd02OoYdKd00ol0
003oj=>oonSC_`09onSC_`;o00009oooool0033ooooo00?o0000ooooooooool03_ooool01?l0003o
03^lo`0k_?l0>k`2o`0005_ooooo0_l0000AokNce@03o`000?o1]m3o`KO@00Wo`KO@00?o0000olBm
doo4_M<01oo4_M<3o`0000_oc/3=00?o0000om75cooAaLl02ooAaLl00ol0003of<O9omS7b@03omS7
b@03o`000?oKblWofl_900gofl_900?o0000omg?booMcl/01OoMcl/00ol0003ohlk2on?>`P05on?>
`P03o`000?oTd<?oi=3300Coi=3300?o0000onC@`ooTd<<00ooTd<<00ol0003oiM?4onGCa006onGC
a005o`000?oYd;cojM2lonW@_?l000002_oYdKd00ol0003oj=>oonSC_`09onSC_`04o`000?oXeL?o
0000o`0002Kooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000o`0k_?l0>kco03^l0_l0
001Iooooo`03o`000?ng/mGo]k?E017o]k?E00?o0000ol6gd?o1]m002?o1]m000ol0003oa;gColBm
d`06olBmd`;o00000oo4_M<00ol0003oc/3=olk0c@07olk0c@03o`000?oAaLoodLG?00godLG?00Go
0000omS7bOoHalWof<O9o`00000@om_;b@03o`000?oMcl_ogLo;00GogLo;00?o0000on?>`_oSc/80
1?oSc/800ol0003oi=33onC@``06onC@``05o`000?oTd<?oi=33onC@`ol000002_oUdl@00ol0003o
jM2lo`00000;onWA_@03o`000?oXdkooj=>o00Soj=>o00Go0000onSE`ooXeL?oj=G3o`00000Voooo
o`00<?ooool2o`00017ooooo00?o0000o`0k_?l0>k`00_l0>k`00ol0003oooooooooo`1Dooooo`;o
00005Ong/mD00ol0003o`KO@ol6gd006ol6gd003o`000?o4_M?oa;gC00Coa;gC0ol00005olBmd`03
o`000?o>`<goc/3=00Koc/3=00?o0000om75cooAaLl03ooAaLl00ol0003of<O9o`00000@om_;b@03
o`000?oMcl_ogLo;00OogLo;00?o0000on?>`_oSc/800_oSc/800ol0003oi=33onC@``08onC@``03
o`000?oTd<?o000000coiM?400?o0000onWA_OoYdKd02OoYdKd00ol0003oj=>oonSC_`09onSC_`04
o`000?oXeL?oj=G3onSE``;o00009Oooool0033ooooo00?o0000ooooooooool04Oooool00ol0003o
03^lo`0k_002o`0k_0;o0000D_ooool2o`000003oj^^f_l0003o]k?E01Co]k?E00?o0000ol6gd?o1
]m001?o1]m02o`0000Coa;gC0ol00009olBmd`03o`000?o>`<goc/3=00Coc/3=00?o0000om75cooA
aLl04OoAaLl00ol0003ofl_9om_;b@0>om_;b@03o`000?oMcl_ogLo;00WogLo;00Go0000on?>`_oS
c/;ohlk2o`00000:onC@``03o`000?oTd<?o000000coiM?400?o0000onWA_OoYdKd02?oYdKd00ol0
003oj=>oonSC_`09onSC_`03o`000?oXeL?oj=G300?oj=G30_l0000Tooooo`001Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5
o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo00Ko
0000o`0k_?l0>kco03^lo`000?lBIMX2o`0004gooooo0ol00004oj^^fP03o`000?ng/mGo]k?E01?o
]k?E00?o0000ol6gd?o1]m000_o1]m001?l0003oa;gColBmdoo4_M<3o`0000goa;gC00?o0000olk0
cOo>`<d00_o>`<d00ol0003odLG?om75c`0Aom75c`;o00003ooKblT00ol0003ogLo;omg?b`0;omg?
b`03o`000?oSc/;o000000coi=3300?o0000onGCa?oUdl@02_oUdl@00ol0003oi]K6o`000009onWA
_@03o`000?oXdkooj=>o00Soj=>o00?o0000onSE`ooXeL<01OoXeL<00ol0003oooooooooo`0Roooo
o`001Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Cooooo`05o`000?l0>kco03^lo`0k_?l000000_lBIMX2o`0004Wooooo
0_l00008oj^^fP03o`000?ng/mGo]k?E01?o]k?E00Go0000ol6gd?o1]m3o0000olBmd`03o`00013o
a;gC00Go0000olk0cOo>`<goc/3=o`00000Com75c`04o`000?oCbM3odlW@o`0000gofl_900?o0000
omg?booMcl/03OoMcl/00ol0003oi=33onC@``0:onC@``03o`000?oUdlCo000000[oiM?400Go0000
onKFa_oVe/Koi]K6o`000007onWA_@03o`000?oXdkooj=>o00Woj=>o00?o0000onSE`ooXeL<01OoX
eL<2o`0002?ooooo0005ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooo
oooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Gooooo0_l00002o`0k_004o`000?lBIM[o4VGJoa9UfP;o0000AOooool2o`0000[o
ZjkJ00?o0000okNceOng/mD04ong/mD00ol0003o`KO@o`000002o`0001Coa;gC00?o0000olk0cOl0
00004ooAaLl00ol0003odlW@om?9d002om?9d003o`000?oKblWofl_900[ofl_900?o0000omg?booM
cl/03OoMcl/00ol0003oi=33onC@``0:onC@``03o`000?oUdlCo000000[oiM?400Go0000onKFa_oV
e/Koi]K6o`000006onWA_@03o`000?oXdkooj=>o00Woj=>o00?o0000onSE`ooXeL<01ooXeL<2o`00
02;ooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000Gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01Kooooo0_l00002o`0k_003o`000?lBIM[o4VGJ00;o4VGJ00?o0000ooooooooool0?oooool3
o`0000goZjkJ00?o0000okNceOng/mD04Ong/mD3o`0001Ooa;gC0_l0000Com75c`03o`000?oCbM3o
dlW@00CodlW@00?o0000om_;bOoKblT02?oKblT00ol0003ogLo;omg?b`0=omg?b`03o`000?oNd/co
000000[oi=3300Go0000onGCa?oUdlCoiM?4o`000008onGCa003o`000?oVe/Koi]K600?oi]K600?o
0000onWA_OoYdKd00ooYdKd00ol0003oj=>oonSC_`08onSC_`03o`000?oXeL?oj=G300Woj=G300?o
0000ooooooooool08?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0Gooooo`;o00000_l0>k`00ol0003o4VGJoa9UfP02oa9UfP;o
0000?Oooool2o`00013oZjkJ00?o0000okNceOng/mD03ong/mD3o`000003okZifOl0003oa;gC01Go
a;gC00?o0000olO3e_l000004_oAaLl00ol0003odlW@om?9d005om?9d003o`000?oKblWofl_900Oo
fl_900?o0000omg?booMcl/03OoMcl/01Ol0003og];<omkBc?oNd/co000000Soi=3300?o0000onGC
a?oUdl@00ooUdl@00ol0003oiM?4onGCa004onGCa003o`000?oVe/Koi]K600Goi]K600Go0000onWA
_OoYdKgojM6mo`00000;onSC_`03o`000?oXeL?oj=G300Woj=G30_l0000Qooooo`001Oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool3o`0001Wooooo0ol000000ol0>kco0000oa9U
fP04oa9UfP;o0000>?ooool3o`0001?oZjkJ00?o0000okNceOng/mD02ong/mD5o`0000?o^[WI00?o
0000olBmdoo4_M<04_o4_M<01Ol0003oal?FolO3e_o7`mKo0000013odLG?00?o0000om?9d?oCbM00
1ooCbM000ol0003ofl_9om_;b@05om_;b@03o`000?oMcl_ogLo;00gogLo;00?o0000omkBc?oNd/`0
0ooNd/`00ol0003oi=33onC@``05onC@``03o`000?oUdlCoiM?400CoiM?400?o0000onGCa?oUdl@0
0_oUdl@00ol0003oi]K6onKFaP06onKFaP05o`000?oYdKgojM6monWA_Ol000002_oXdkl00ol0003o
j=G3onSE``09onSE``04o`000?oWfLOo0000o`00023ooooo0005ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool01?l0003o02FVo`00
0?l00007oa9UfP?o0000<Oooool4o`0000;oVjSO00?o0000oj^^f_n[[]X04_n[[]X00ol0003o]k?E
okNce@07okNce@?o000000?o]k?Eo`000?l000001_nj^MT00ol0003oa;gColBmd`0@olBmd`03o`00
0?o7`mKoal?F00?oal?F00?o0000om75cooAaLl03?oAaLl00ol0003odlW@om?9d009om?9d003o`00
0?oKblWofl_900Cofl_900?o0000omg?booMcl/03?oMcl/00ol0003og];<omkBc005omkBc003o`00
0?oTd<?oi=3300?oi=3300?o0000onGCa?oUdl@01OoUdl@00ol0003oiM?4onGCa002onGCa003o`00
0?oVe/Koi]K600Ooi]K600?o0000onWA_Ol000002ooXdkl00ol0003oj=G3onSE``08onSE``05o`00
0?oWfLOoimW7onOIaol000002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`00oooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
1?l00005ooooo`03o`000?oooooooooo01[ooooo00Co0000o`0UY_l0003o00001_lBIMX00ol0003o
AX7UodJ1i@05o`0002Sooooo1?l00007oi^Xg`03o`000?n[[][oZjkJ017oZjkJ00?o0000okNceOng
/mD01?ng/mD3o`0000?o]k?E00?o0000okZifOnj^MT01_nj^MT00ol0003oa;gColBmd`0>olBmd`;o
00001_o7`mH00ol0003odLG?om75c`0;om75c`03o`000?oCbM3odlW@00[odlW@00?o0000om_;bOoK
blT00ooKblT00ol0003ogLo;omg?b`0<omg?b`03o`000?oNd/cog];<00Kog];<00?o0000onC@`ooT
d<<00_oTd<<00ol0003oiM?4onGCa007onGCa004o`000?oUdlCoiM?4o`0000_oi]K600?o0000onSC
_ooXdkl02OoXdkl00ol0003oj=G3onSE``08onSE``03o`000?oWfLOoimW700;oimW70_l00007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@03ooooo`00;_ooool00ol0003oooooooooo`0Looooo`04o`000?l09JKo0000o`0000Ko4VGJ00?o
0000odJ1iOm6PND01?m6PND4o`00023ooooo1?l0000<oi^Xg`03o`000?n[[][oZjkJ017oZjkJ00?o
0000okNceOng/mD00ol00004okNce@;o00002_nj^MT00ol0003oa;gColBmd`0<olBmd`03o`000?o7
`mKoal?F00Ooal?F00?o0000om75cooAaLl02OoAaLl00ol0003odlW@om?9d00<om?9d005o`000?oK
blWofl_9om_;bOl000003ooMcl/00ol0003og];<omkBc007omkBc005o`000?oTd<?oi=33onC@`ol0
00002_oUdl@2o`0000coi]K60_l00009onSC_`03o`000?oXeL?oj=G300Woj=G300?o0000onOIaooW
fLL00ooWfLL2o`0000Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000000oooool002kooooo0_l0000Nooooo`04o`000?l09JKo02FVo`0000Ko4VGJ00?o0000
odJ1iOm6PND01om6PND6o`0001Cooooo1_l0000@oi^Xg`03o`000?n[[][oZjkJ017oZjkJ0ol00006
okNce@03o`000?nj^MWo^[WI00_o^[WI00?o0000olBmdoo4_M<02_o4_M<00ol0003oal?FolO3eP09
olO3eP03o`000?oAaLoodLG?00OodLG?00?o0000om?9d?oCbM003_oCbM000ol0003ofl_9o`00000?
omg?b`03o`000?oNd/cog];<00Wog];<00?o0000onC@`ol000003?oUdl@00ol0003oi]K6onKFaP09
onKFaP04o`000?oVfLWoi]W9o`0000Soj=>o00?o0000onSE`ooXeL<02?oXeL<00ol0003oimW7onOI
a`04onOIa`;o00001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P03ooooo`00;_ooool00ol0003oooooooooo`0Nooooo`04o`000?l09JKo02FVo`0000Ko
4VGJ00?o0000odJ1iOm6PND01om6PND00ol0003oK9?VofbCiP02ofbCiPOo00001_ooool7o`0000Co
QioT00?o0000oi^XgonKZ=l04?nKZ=l00ol0003oZjkJoj^^fP0=oj^^fP?o000000?oZjkJo`000?ng
/mD01?ng/mD2o`0000oo^[WI00?o0000olBmdoo4_M<02?o4_M<00ol0003oal?FolO3eP0:olO3eP03
o`000?oAaLoodLG?00KodLG?00?o0000om?9d?oCbM004?oCbM000ol0003ogLo;omg?b`0=omg?b`03
o`000?oNd/cog];<00_og];<00?o0000onGCa?oUdl@02_oUdl@2o`0000[oi]K600?o0000onKIbOoV
fLT00_oVfLT00ol0003oj=>oonSC_`04onSC_`03o`000?oXeL?oj=G300Soj=G300?o0000onOIaooW
fLL01_oWfLL2o`0000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`00oooool002kooooo00?o0000ooooooooool07oooool00ol0003o02FVo`0UYP02o`00
00Co4VGJ00?o0000odJ1iOm6PND02?m6PND00ol0003oK9?VofbCiP08ofbCiPKo00003?n7Wn@00ol0
003oVjSOoi^Xg`0@oi^Xg`03o`000?n[[][oZjkJ00[oZjkJ0_l00005oj^^fP03o`000?ng/mGo]k?E
00;o00004Onj^MT00ol0003oa;gColBmd`07olBmd`03o`000?o7`mKoal?F00coal?F00?o0000om75
cooAaLl01?oAaLl00ol0003odlW@om?9d00@om?9d0;o00003_oMcl/00ol0003og];<omkBc00<omkB
c003o`000?oUdlCoiM?400WoiM?400Co0000onKFa_oVe/Ko00002?oVe/H00ol0003oi]W9onKIb@04
onKIb@03o`000?oXdkooj=>o00;oj=>o00?o0000onSE`ooXeL<02?oXeL<00ol0003oimW7onOIa`08
onOIa`;o00001?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@4003ooooo`00;_ooool00ol0003oooooooooo`0Pooooo`?o000000?o05[Co`000?l000000olB
IMX00ol0003oAX7UodJ1i@08odJ1i@03o`000?m/TnKoK9?V00WoK9?V00?o0000ohNOi?n7Wn@03_n7
Wn@00ol0003oVjSOoi^Xg`0?oi^Xg`03o`000?n[[][oZjkJ00OoZjkJ0ol00007oj^^fP03o`000?ng
/mGo000001Co^[WI00?o0000olBmdoo4_M<01?o4_M<2o`00013oal?F00?o0000om75cooAaLl00_oA
aLl00ol0003odlW@om?9d00@om?9d004o`000?oFcm;oe/oBo`0000cogLo;00?o0000omkBc?oNd/`0
3?oNd/`00ol0003ogmK>o`00000:onGCa005o`000?oVe/Koi]K6onKFa_l000001ooVe/H00ol0003o
i]W9onKIb@05onKIb@05o`000?oXdkooj=>oonSC_ol000002_oXeL<00ol0003oimW7onOIa`08onOI
a`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0003ooooo`00;Oooool2o`0002?ooooo0ol00002o`1Jd`05o`000?lBIM[o4VGJoa9Uf_l000002_m6
PND00ol0003oK9?VofbCiP09ofbCiP03o`000?n7WnCoQioT00koQioT00?o0000oi^XgonKZ=l03onK
Z=l00ol0003oZjkJoj^^fP03oj^^fP?o00002_n[[]X2o`0001Ko^[WI00?o0000olBmdoo4_M<00_o4
_M<00ol0003oal?FolO3eP0@olO3eP05o`000?oAaLoodLG?om75col000004_oCbM000ol0003oe/oB
omK?dP02omK?dP03o`000?oMcl_ogLo;00SogLo;00?o0000omkBc?oNd/`03?oNd/`01Ol0003ogmK>
omoFc_oOe/ko000000SoiM?400?o0000onKFa_oVe/H00_oVe/H00ol0003oi]K6onKFaP04onKFaP03
o`000?oVfLWoi]W900Ooi]W900?o0000onSC_ol000002_oXeL<00ol0003oimW7onOIa`08onOIa`04
o`000?oSgLoo0000o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT00oooool002gooooo00?o0000ooooooooool08oooool3o`0000;o05[C0_l00002
oa9UfP03o`000?m6PNGoAX7U00OoAX7U00?o0000ofbCi_m/TnH02_m/TnH00ol0003oQioTohNOi00=
ohNOi003o`000?nKZ=ooVjSO00ooVjSO00?o0000oj^^f_n[[]X00ol0000:oj^^fP?o000000?o[KCN
o`000?nj^MT05Onj^MT01Ol0003oa;gColBmdoo4_M?o000001Coal?F00?o0000om75col000004_oC
bM000ol0003oe/oBomK?dP04omK?dP03o`000?oMcl_ogLo;00OogLo;00?o0000omkBc?oNd/`02ooN
d/`00ol0003ogmK>omoFcP03omoFcP03o`000?oUdlCoiM?400CoiM?400?o0000onKFa_oVe/H01?oV
e/H00ol0003oi]K6onKFaP02onKFaP03o`000?oVfLWoi]W900Woi]W900?o0000onSE`ooXeL<02?oX
eL<00ol0003oimW7onOIa`08onOIa`04o`000?oSgLoohmg?on?Mc`;o00006_ooool002gooooo00?o
0000ooooooooool09?ooool3o`0000?o05[C0ol0000:odJ1i@03o`000?m/TnKoK9?V00[oK9?V00?o
0000ohNOi?n7Wn@03On7Wn@00ol0003oVjSOoi^Xg`0>oi^Xg`?o00002_n[[]X3o`0000Go[KCN00?o
0000okZifOnj^MT05?nj^MT00ol0003oa;gCo`00000EolO3eP;o00004_oCbM000ol0003oe/oBomK?
dP06omK?dP03o`000?oMcl_ogLo;00GogLo;00?o0000omkBc?oNd/`02ooNd/`00ol0003ogmK>omoF
cP05omoFcP03o`000?oUdlCoiM?400;oiM?400?o0000onKFa_oVe/H01_oVe/H01?l0003oi]K6onKF
a_l0000<onKIb@03o`000?oXeL?oj=G300Soj=G300?o0000onOIaooWfLL01ooWfLL00ol0003ohmg?
on?Mc`02on?Mc`;o00006_ooool002gooooo0ol0000Uooooo`?o00001?l0F]<2o`0000[oAX7U00?o
0000ofbCi_m/TnH02Om/TnH00ol0003oQioTohNOi00>ohNOi003o`000?nKZ=ooVjSO00[oVjSO0ol0
0002oi^Xg`03o`000?n[[][oZjkJ00KoZjkJ0_l00009ojfdgP03o`000?nj^MWo^[WI01?o^[WI0_l0
000EolO3eP03o`000?o:b=So0000017odlW@00?o0000omK?d_oFcm802?oFcm800ol0003ogLo;omg?
b`03omg?b`03o`000?oNd/cog];<00_og];<00?o0000omoFc_oOe/h01ooOe/h01Ol0003oiM?4onGC
a?oUdlCo000000Woi]K600?o0000onKFa_l000002ooVfLT00ol0003oiMo=o`000008onSE``03o`00
0?oWfLOoimW700SoimW700?o0000on?McooSgLl00ooSgLl2o`0001Wooooo000]ooooo`03o`000?oo
oooooooo02Kooooo0ol00004o`1Jd`;o00002Om6PND00ol0003oK9?VofbCiP0:ofbCiP03o`000?n7
WnCoQioT00goQioT00?o0000oi^XgonKZ=l01onKZ=l3o`0000GoVjSO00?o0000oj^^f_n[[]X00on[
[]X3o`0000_o[KCN00?o0000okZifOnj^MT04_nj^MT00ol0003o_;oLo`00000DolO3eP05o`000?o:
b=Sob/SHol[8f?l000003ooCbM000ol0003oe/oBomK?dP0:omK?dP05o`000?oMcl_ogLo;omg?bol0
00003_oNd/`00ol0003ogmK>omoFcP08omoFcP03o`000?oUdlCo000000[oi]K60_l0000;onKIb@05
o`000?oUglgoiMo=onGOcOl000001_oXeL<00ol0003oimW7onOIa`08onOIa`03o`000?oSgLoohmg?
00Gohmg?0_l0000Hooooo`002_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool09oooool2o`0000Ko05[C0_l00008odJ1i@03o`000?m/TnKoK9?V00[oK9?V00?o
0000ohNOi?n7Wn@03On7Wn@00ol0003oVjSOoi^Xg`03oi^Xg`?o00002OnKZ=l00ol0003oZjkJo`00
0002o`0000oo[KCN00?o0000okZifOnj^MT03onj^MT2o`0000?o_;oL00?o0000olO3e_o7`mH04?o7
`mH00ol0003ob/SHol[8f003ol[8f003o`000?oCbM3odlW@00_odlW@00?o0000omK?d_oFcm803?oF
cm800ol0003ogLo;o`00000>omkBc003o`000?oOe/kogmK>00[ogmK>00?o0000onKFa_oVe/H02OoV
e/H2o`0000[oi]W900?o0000onGOcOoUgld00_oUgld00ol0003oj=G3onSE``03onSE``03o`000?oW
fLOoimW700SoimW700?o0000on?McooSgLl01_oSgLl2o`0001Sooooo000:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0:?ooool2o`0000Go05[C00?o0000ocIni_l00000
0_l00006odJ1i@03o`000?m/TnKoK9?V00[oK9?V00?o0000ohNOi?n7Wn@03On7Wn@00ol0003oVjSO
oi^Xg`02o`0000_oVjSO0ol0000CojfdgP03o`000?nj^MWo^[WI00co^[WI0_l00006okbog003o`00
0?o7`mKoal?F00koal?F00?o0000ol[8f?o:b=P01Oo:b=P00ol0003odlW@om?9d009om?9d003o`00
0?oFcm;oe/oB00koe/oB00?o0000omkBc?oNd/`03?oNd/`00ol0003ogmK>omoFcP0;omoFcP03o`00
0?oVe/Koi]K600Woi]K600?o0000onKIbOl000002?oVfLT00ol0003oiMo=onGOc@04onGOc@03o`00
0?oXeL?oj=G300;oj=G300?o0000onOIaooWfLL01ooWfLL00ol0003ohmg?on?Mc`08on?Mc`;o0000
5oooool000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`02ooooo`;o0000:oooool2o`0000Go05[C00Co0000ocIni_lf
O^Ko=WkV0ol00004odJ1i@03o`000?m/TnKoK9?V00[oK9?V00?o0000ohNOi?n7Wn@03?n7Wn@3o`00
00WoVjSO1?l00002oi^^i003o`000?n]]=ko[KCN01;o[KCN00?o0000okZifOnj^MT02_nj^MT00ol0
003o_;oLokbog007okbog003o`000?o7`mKoal?F00coal?F00?o0000ol[8f?o:b=P01oo:b=P00ol0
003odlW@om?9d007om?9d003o`000?oFcm;oe/oB00ooe/oB00?o0000omkBc?oNd/`02ooNd/`00ol0
003ogmK>omoFcP0;omoFcP03o`000?oQfm7o000000Woi]K600Co0000onKIbOoVfLWo00002?oVfLT0
0ol0003oiMo=onGOc@04onGOc@05o`000?oXeL?oj=G3onSE`ol000002OoWfLL00ol0003ohmg?on?M
c`0:on?Mc`;o00005_ooool000[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo02_ooooo
0_l00005o`1Jd`03o`000?lfO^Ko=WkV00?o=WkV0ol000000om6PNGo0000ofbCiP0;ofbCiP03o`00
0?n7WnCoQioT00WoQioT0ol000000on7WnCo0000oi^Xg`06oi^Xg`?o00001onK[^@00ol0003o[KCN
ojfdgP0AojfdgP03o`000?nj^MWo^[WI00So^[WI0_l0000:okbog003o`000?o7`mKoal?F00[oal?F
0_l0000;ol[8f003o`000?oCbM3odlW@00GodlW@00?o0000omK?d_oFcm803ooFcm800ol0003of=?D
o`00000;omkBc003o`000?oOe/kogmK>00_ogmK>00Go0000on7KdOoQfm7ohM_Ao`000007onKFaP03
o`000?oVfLWoi]W900;oi]W900?o0000onKIbOoVfLT01?oVfLT00ol0003oiMo=onGOc@06onGOc@03
o`000?oXeL?o000000[oimW700?o0000on?McooSgLl02_oSgLl2o`0001Kooooo000:ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02cooooo0ol00004o`1Jd`03o`000?lfO^Ko
=WkV00Go=WkV0ol0000<ofbCiP03o`000?n7WnCoQioT00GoQioT0ol00005ohNOi003o`000?nKZ=oo
VjSO00Co00002onK[^@00ol0003o[KCNojfdgP0AojfdgP03o`000?nj^MWo^[WI00Ko^[WI00?o0000
okbog?nl_m`02onl_m`00ol0003oal?FolO3eP08olO3eP03o`000?o:b=Sob/SH00cob/SH00?o0000
om?9d?oCbM000ooCbM000ol0003oe/oBomK?dP0?omK?dP05o`000?oHdmCof=?DomSCe?l000002OoN
d/`00ol0003ogmK>omoFcP0;omoFcP03o`000?oQfm7ohM_A00?ohM_A00?o0000onKFa_oVe/H00ooV
e/H00ol0003oi]W9onKIb@04onKIb@03o`000?oVfLWoi]W900;oi]W900?o0000onGOcOoUgld02?oU
gld00ol0003oimW7onOIa`08onOIa`03o`000?oSgLoohmg?00[ohmg?00Co0000omkWf_l0003o0000
5Oooool000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41001?ooool00ol0003oooooooooo`06ooooo`;o0000;_ooool3o`0000Co05[C00?o0000ocIni_lf
O^H01olfO^H8o`0000GoK9?V00Co0000ohNOi?n7WnCoQioT0ol00002ohNOi0Wo00003onK[^@00ol0
003o[KCNojfdgP0BojfdgP03o`000?nj^MWo^[WI00?o^[WI0_l0000?okbog003o`000?o7`mKoal?F
00Koal?F00?o0000ol[8f?o:b=P03_o:b=P01Ol0003odlW@om?9d?oCbM3o0000017oe/oB00?o0000
omSCe?oHdm@00ooHdm@00ol0003og];<omkBc006omkBc003o`000?oOe/kogmK>00[ogmK>00?o0000
on7KdOoQfm401?oQfm400ol0003oi]K6onKFaP03onKFaP03o`000?oVfLWoi]W900Goi]W900Co0000
onKIbOoVfLWo00002ooUgld2o`0000SoimW700?o0000on?McooSgLl02_oSgLl01?l0003og^OJomkW
f_oNimX2o`0001Cooooo000:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool2o`00033ooooo1?l00003o`1Jd`03
o`000?lfO^Ko=WkV00Ko=WkV00?o0000ofBFjomTU^/01OmTU^/>o`0000OoQ:CY00?o0000oi^^i?nK
[^@03onK[^@00ol0003o[KCNojfdgP0AojfdgP04o`000?nj^MWo^[WIokZif@;o00004_nl_m`00ol0
003oal?FolO3eP04olO3eP03o`000?o:b=Sob/SH013ob/SH00?o0000om?9d?l000004OoFcm800ol0
003of=?DomSCe005omSCe003o`000?oNd/cog];<00Cog];<00?o0000omoFc_oOe/h02_oOe/h00ol0
003ohM_Aon7Kd@06on7Kd@05o`000?oVe/Koi]K6onKFa_l000002?oVfLT01?l0003oi]W9onKIbOl0
000:onGOc@04o`000?oTim?oi>OCo`0000KoimW700?o0000on?McooSgLl02_oSgLl00ol0003og^OJ
omkWfP02omkWfP;o00005?ooool000[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Gooooo00?o0000ooooooooool0;oooool2o`000005
o`1?b_l0003o0000o`1Jdol000002OlfO^H00ol0003oI9K[ofBFj`07ofBFj`Co00003on4Y>T00ol0
003oVjkToi^^i00?oi^^i003o`000?n]]=ko[KCN017o[KCN00?o0000okZifOl000005?nl_m`00ol0
003oal?FolO3eP03olO3eP03o`000?o:b=Sob/SH017ob/SH0_l0000AomK?dP03o`000?oHdmCof=?D
00Kof=?D00?o0000omkBc?oNd/`00ooNd/`00ol0003ogmK>omoFcP0:omoFcP03o`000?oQfm7ohM_A
00SohM_A00?o0000onKFa_l000002_oVfLT2o`0000[oiMo=00?o0000onCWdooTim<00_oTim<00ol0
003oimW7onOIa`03onOIa`03o`000?oSgLoohmg?00Wohmg?00?o0000omkWf_oNimX01?oNimX2o`00
01?ooooo000/ooooo`03o`000?oooooooooo033ooooo0_l00002o`1?bP03o`000?l0F]?o000000Wo
=WkV00?o0000ofBFjomTU^/01?mTU^/2o`0000CoI9K[00?o0000ohBTjOn4Y>T03On4Y>T00ol0003o
VjkToi^^i00?oi^^i003o`000?n]]=ko[KCN013o[KCN0_l0000Fokbog005o`000?o7`mKoal?FolO3
e_l000004oo:b=P00ol0003oc<kKo`00000@omK?dP03o`000?oHdmCof=?D00Sof=?D00Go0000omkB
c?oNd/cog];<o`00000<omoFcP03o`000?oQfm7ohM_A00[ohM_A0_l0000:onKIb@;o00002OoUgld0
0ol0003oi>OConCWd`04onCWd`05o`000?oWfLOoimW7onOIaol000002ooSgLl00ol0003og^OJomkW
fP05omkWfP;o00004oooool002_ooooo0_l0000cooooo`;o00000_l0ClX3o`0000Wo=WkV00?o0000
ofBFjomTU^/00ol00007ofBFj`03o`000?n4Y>WoQ:CY00coQ:CY00?o0000oi^^i?nK[^@03onK[^@0
0ol0003o[KCNojfdgP0=ojfdgP?o000000?o[[_So`000?nl_m`05_nl_m`00ol0003oal?Fo`00000C
ol[8f005o`000?o<c]_oc<kKolc>fol000003_oFcm800ol0003of=?DomSCe00:omSCe003o`000?oN
d/co000000cogmK>00?o0000on7KdOoQfm402ooQfm400ol0003ohN7Do`000008onKIb@04o`000?oU
glgoiMo=o`0000OoiMo=00?o0000onCWdooTim<01_oTim<00ol0003oimW7o`00000;on?Mc`03o`00
0?oNim[og^OJ00Oog^OJ0_l0000Booooo`00:oooool00ol0003oooooooooo`0cooooo`;o00000ol0
ClX2o`0000So=WkV0ol0000:ofBFj`03o`000?n4Y>WoQ:CY00goQ:CY00?o0000oi^^i?nK[^@03onK
[^@00ol0003o[KCNojfdgP09ojfdgP?o00001On^^n<00ol0003o_;oLokbog00Dokbog0;o00004oo:
b=P00ol0003oc<kKolc>f`03olc>f`03o`000?oFcm;oe/oB00[oe/oB00?o0000omSCe?oHdm@03?oH
dm@00ol0003ogmK>omoFcP0;omoFcP03o`000?oQfm7ohM_A00[ohM_A00Go0000on7Qe?oQhMCohN7D
o`000006onKIb@05o`000?oUglgoiMo=onGOcOl000001_oUgld00ol0003oi>OConCWd`08onCWd`03
o`000?oSgLoohmg?00Wohmg?00?o0000omkWf_oNimX02?oNimX3o`00017ooooo000[ooooo`03o`00
0?oooooooooo03Cooooo0_l00004o`1?bP03o`000?lfO^Ko=WkV00;o=WkV0ol000000olfO^Ko0000
ofBFj`0;ofBFj`03o`000?n4Y>WoQ:CY00goQ:CY00?o0000oi^^i?nK[^@03onK[^@00ol0003o[KCN
ojfdgP06ojfdgP;o00002On^^n<00ol0003o_;oLokbog00Aokbog0;o000000?o_/GOo`000?o:b=P0
4?o:b=P2o`0000Ooc<kK00?o0000omK?d_oFcm802?oFcm800ol0003of=?DomSCe00<omSCe003o`00
0?oIfMOo000000_ogmK>00?o0000on7KdOoQfm402_oQfm400ol0003ohN7Don7Qe003on7Qe003o`00
0?oVfLWoi]W900?oi]W900?o0000onGOcOoUgld00_oUgld00ol0003oiMo=onGOc@02onGOc@03o`00
0?oTim?oi>OC00Woi>OC0_l00009on?Mc`03o`000?oNim[og^OJ00Sog^OJ00?o0000ol[ejol00000
0_l00008ooooo`Co000000?o410@ooooooooool00Oooool002_ooooo00?o0000ooooooooool0=Ooo
ool2o`0000Co04o:1?l00005ocIniP03o`000?mTU^_oI9K[00[oI9K[00?o0000ohBTjOn4Y>T03On4
Y>T00ol0003oVjkToi^^i00>oi^^i003o`000?n]]=ko[KCN00?o[KCN0ol0000<ojjkh`03o`000?nl
_mco_;oL00oo_;oL00?o0000okk5gonnaMl00_nnaMl00ol0003ob/SHol[8f00=ol[8f003o`000?o<
c]_oc<kK00Soc<kK00?o0000omK?d_oFcm801_oFcm800ol0003of=?DomSCe00<omSCe005o`000?oI
fMOofMWGomWIeol000002OoOe/h00ol0003ohM_Aon7Kd@0:on7Kd@03o`000?oQhMCohN7D00GohN7D
00Go0000onKIbOoVfLWoi]W9o`000006onGOc@04o`000?oUglgoiMo=o`0000_oi>OC00Co0000omo`
fooOl=_o00001ooSgLl00ol0003og^OJomkWfP08omkWfP04o`000?o:mN_ob_G[ol[ej`;o00002_oo
ool00ol0003oooooooooo`03ooooo`00:_ooool2o`0003Wooooo00?o0000o`1?b_l000000_l00000
1?lVN^Go0000o`000?l00005ocIniP03o`000?mTU^_oI9K[00[oI9K[00?o0000ohBTjOn4Y>T03?n4
Y>T00ol0003oVjkToi^^i00?oi^^i003o`000?n]]=ko000000;o00004?n^^n<00ol0003o_;oLokbo
g00<okbog0;o00001_nnaMl00ol0003ob/SHol[8f00;ol[8f003o`000?o<c]_oc<kK00Woc<kK00?o
0000omK?d_oFcm801OoFcm800ol0003of=?DomSCe00<omSCe003o`000?oIfMOofMWG00?ofMWG00?o
0000omoFc_oOe/h01OoOe/h00ol0003ohM_Aon7Kd@0:on7Kd@03o`000?oQhMCohN7D00OohN7D00?o
0000onKIbOl000001ooUgld01?l0003oiMo=onGOcOl0000:onCWd`03o`000?oOl=_ogo3K00;ogo3K
00?o0000on?McooSgLl00ooSgLl00ol0003og^OJomkWfP07omkWfP;o00001Oo:mN/2o`0000Wooooo
00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0=_ooool4o`0000;o04o:00Co
0000obIjiOlVN^Go9W[U0ol00002ocIniP03o`000?mTU^_oI9K[00[oI9K[00?o0000ohBTjOn4Y>T0
3On4Y>T00ol0003oVjkToi^^i00=oi^^i0?o00005?n^^n<00ol0003o_;oLokbog009okbog0;o0000
2OnnaMl00ol0003ob/SHol[8f009ol[8f003o`000?o<c]_oc<kK00_oc<kK00?o0000omK?d_oFcm80
0ooFcm800ol0003of=?DomSCe00<omSCe003o`000?oIfMOofMWG00GofMWG00?o0000omoFc_oOe/h0
0ooOe/h00ol0003ohM_Aon7Kd@0:on7Kd@03o`000?oQhMCohN7D00WohN7D0_l00008onGOc@;o0000
2_oTim<00ol0003ogo3Komo`f`04omo`f`05o`000?oSgLoohmg?on?Mcol000002OoNimX00ol0003o
b_G[ol[ej`05ol[ej`;o00002Oooool00ol0003oooooooooo`03ooooo`00:_ooool00ol0003ooooo
ooooo`0eooooo`;o00000oooool2o`0000;o04o:00?o0000obIjiOlVN^D00olVN^D2o`000003ocIn
i_l0003oI9K[00_oI9K[00?o0000ohBTjOn4Y>T03On4Y>T00ol0003oVjkToi^^i008oi^^i0Co0000
0_nK]>T00ol0003o[[_Sojjkh`0Bojjkh`03o`000?nl_mco_;oL00Oo_;oL0_l0000<okk5g`03o`00
0?o:b=Sob/SH00Oob/SH00?o0000olc>foo<c]/03Oo<c]/01Ol0003oe/oBomK?d_oFcm;o000000ko
f=?D00?o0000omWIeooIfML01ooIfML01Ol0003ogmK>omoFc_oOe/ko000000cohM_A00?o0000on7Q
e?oQhM@02_oQhM@00ol0003oh>WIo`000007onGOc@;o00002OoTim<00ol0003ogo3Komo`f`06omo`
f`03o`000?oSgLoo000000Wog^OJ00?o0000ol[ejoo:mN/01oo:mN/2o`0000Sooooo00?o0000oooo
ooooool00oooool002[ooooo0ol0000booooo`?o00001_ooool3o`000003o`1?b_l0003o9W[U00Go
9W[U0ol0000<ofBFj`03o`000?n4Y>WoQ:CY00coQ:CY00?o0000oi^^i?nK[^@01OnK[^@3o`0000Oo
VkCY00?o0000ojjkhon^^n<04_n^^n<00ol0003o_;oLokbog004okbog0;o00003_nnaMl00ol0003o
b/SHol[8f005ol[8f0;o00004Oo<c]/00ol0003oe/oBo`00000>omSCe003o`000?oIfMOofMWG00Wo
fMWG00?o0000omoFc_l000003?oQfm400ol0003ohN7Don7Qe00:on7Qe005o`000?oPjMWoh>WIon3Y
fOl000001OoUgld01?l0003oi>OConCWdol00007onCWd`03o`000?oOl=_ogo3K00Oogo3K0ol00008
omkWfP03o`000?o:mN_ob_G[00Sob_G[0ol00007ooooo`03o`000?oooooooooo00?ooooo000Zoooo
o`03o`000?oooooooooo02oooooo0ol0000:ooooo`05o`000?l0Al;o0000o`1?b_l000002?lVN^D5
o`0000OoI9K[00?o0000ohBTjOn4Y>T03On4Y>T00ol0003oVjkToi^^i004o`0000_oVkCY00?o0000
ojjkhon^^n<04_n^^n<00ol0003o_;oLokbog002okbog003o`000?nnaMoo_/GO00oo_/GO00?o0000
ol[8f?o:b=P00oo:b=P00ol0003oc<kKolc>f`0Aolc>f`;o00003_oHdm@00ol0003ofMWGomWIe`0;
omWIe`;o00002ooQfm400ol0003ohN7Don7Qe00:on7Qe003o`000?oPjMWoh>WI00?oh>WI00Go0000
onGOcOoUglgoiMo=o`000003onCWd`03o`000?oTim?oi>OC00Coi>OC00?o0000omo`fooOl=/01ooO
l=/01Ol0003ocOgRolgmh_o=oN;o000000Gog^OJ0_l0000<ol[ej`;o00001oooool00ol0003ooooo
ooooo`03ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?l0Al;o000000;o00002?lVN^D01?l0
003oFiS_oe^HkomKV>l7o`000003ofBFjol0003oQ:CY00OoQ:CY2Ol0000@oi^dj@03o`000?n^^n?o
[[_S01;o[[_S00Co0000okbog?l0003o00004onnaMl01Ol0003ob/SHol[8f?o:b=So000001?oc<kK
00?o0000olkCg_l000003OoHdm@00ol0003ofMWGomWIe`0;omWIe`04o`000?oJh=_of^3Ko`0000Wo
hM_A00?o0000on7Qe?oQhM@02_oQhM@00ol0003oh>WIon3Yf@05on3Yf@03o`000?oUglgo000000Go
i>OC00?o0000onCWdooTim<00_oTim<00ol0003ogo3Komo`f`07omo`f`03o`000?o=oN;ocOgR00?o
cOgR00Go0000omkWf_oNim[og^OJo`00000=ol[ej`?o00001Oooool00omEEEGoIVIVo`000005oooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Y
ooooo`?o00004_ooool00ol0003o04O2o`17`P02o`0000So9W[U00?o0000oe^HkomKV>l01omKV>l:
o`0000OoPJW^00?o0000oi^djOnK]>T03onK]>T00ol0003o[[_Sojjkh`0Bojjkh`;o00005_nnaMl0
0ol0003ob/SHo`00000Colc>f`05o`000?o>dmkoc]?NolkCg_l000002ooHdm@00ol0003ofMWGomWI
e`0;omWIe`03o`000?oJh=_of^3K00;of^3K00?o0000on7KdOoQfm401OoQfm400ol0003ohN7Don7Q
e00:on7Qe003o`000?oPjMWoh>WI00Ooh>WI0_l00006onCWd`04o`000?oTim?oi>OCo`0000Wogo3K
00?o0000olgmh_o=oN801Oo=oN800ol0003og^OJo`00000;ol[ej`?o00000_ooool00ol0003ooooo
ooooo`0;ooooo`000oooool00ol@413oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9_ooool3o`0001Kooooo00?o0000o`17`_l0Al800_l00008obIji@03o`000?mKV>ooFiS_00SoFiS_
00?o0000oh6Yk_n1ZNh03On1ZNh00ol0003oVkCYoi^dj@0?oi^dj@03o`000?n^^n?o[[_S00oo[[_S
0_l000000on_`NOo0000okk5g`0Eokk5g`;o00004_o<c]/2o`0000Goc]?N00?o0000omSCe?oHdm@0
1ooHdm@00ol0003ofMWGomWIe`0;omWIe`03o`000?oJh=_of^3K00Cof^3K00?o0000on7KdOoQfm40
0ooQfm400ol0003ohN7Don7Qe00:on7Qe003o`000?oPjMWoh>WI00Ooh>WI00Co0000om_dgooKm=oo
00001OoTim<00ol0003oi>OCo`000008omo`f`;o00002?o=oN83o`0000Oob_G[1?l00005ooooo`03
o`000?oooooooooo00_ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000006ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`0Tooooo`?o00006_ooool01Ol0003o04O2o`17`_l0Al;o000000So9W[U00?o0000oe^H
komKV>l02?mKV>l00ol0003oPJW^oh6YkP0=oh6YkP03o`000?nK]>WoVkCY00ooVkCY00?o0000ojjk
hon^^n<02on^^n<3o`0000Co[l7W00?o0000okk5gonnaMl04OnnaMl2o`000003ol3<i?l0003oc<kK
013oc<kK00?o0000olkCg_o>dmh01_o>dmh00ol0003of=?DomSCe005omSCe003o`000?oIfMOofMWG
00_ofMWG00?o0000om[PfooJh=/01_oJh=/01Ol0003ohM_Aon7KdOoQfm7o000000cohN7D00?o0000
on3YfOoPjMT01ooPjMT00ol0003ofoCOom_dg`02om_dg`03o`000?oTim?oi>OC00?oi>OC00?o0000
omo`fooOl=/01_oOl=/00ol0003ocOgRolgmhP06olgmhP;o00000omoiL82o`0000;ob_G[0ol0000:
ooooo`03o`000?oooooooooo00[ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo02;ooooo0_l0000Nooooo`04o`000?l0Al;o04O2o`17`P;o0000
1olVN^D00ol0003oFiS_oe^Hk`08oe^Hk`03o`000?n1ZNkoPJW^00goPJW^00?o0000oi^djOnK]>T0
3onK]>T00ol0003o[[_Sojjkh`08ojjkh`;o00002?n_`NL00ol0003o_/GOokk5g`0?okk5g`03o`00
0?o0c>Co`<cT00;o`<cT00?o0000olc>foo<c]/03Oo<c]/00ol0003oc]?NolkCgP08olkCgP03o`00
0?oHdmCof=?D00?of=?D00?o0000omWIeooIfML02ooIfML00ol0003of^3Kom[Pf`08om[Pf`03o`00
0?oQfm7o000000cohN7D00?o0000on3YfOoPjMT01ooPjMT00ol0003ofoCOom_dg`04om_dg`07o`00
0?oTim?oi>OConCWdol0003ogo3Ko`000006omo`f`03o`000?o=oN;ocOgR00KocOgR00?o0000ogoU
`_moiL800omoiL84o`0000gooooo00?o0000ooooooooool02_ooool000?ooooo00?o410@oooooooo
ool02Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?oZJVYogMgMoooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo0ol0000Qooooo`;o00000ol0Al83o`00
00Go9W[U00?o0000oe^HkomKV>l02?mKV>l00ol0003oPJW^oh6YkP0=oh6YkP03o`000?nK]>WoVkCY
00koVkCY00?o0000ojjkhon^^n<01_n^^n<2o`0000_o[l7W00?o0000okk5gonnaMl03?nnaMl2o`00
00Ko`<cT00?o0000olc>foo<c]/02_o<c]/2o`0000coc]?N00Go0000omSCe?oHdmCof=?Do`00000=
omWIe`03o`000?oJh=_of^3K00[of^3K0_l0000;on7Qe003o`000?oPjMWoh>WI00Ooh>WI00?o0000
om_dgooKm=l01_oKm=l00ol0003oi>OCo`000003omo`f`04o`000?oOl=_ogo3Komo`f`;o00001oo=
oN82o`0000?oOnG20ol0000Aooooo`03o`000?oooooooooo00[ooooo00001?nHV9SooooooiRHV?mg
MgL;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol@413ooooooooooooooooo<S8b00Co
oooo00?o0000ooooooooool01_ooool2o`0001gooooo0ol0000Vooooo`06o`000?l0Al;o04O2o`17
`_l0003o67KS0ol00003obIji@03o`000?mKV>ooFiS_00SoFiS_00?o0000oh6Yk_n1ZNh03On1ZNh0
0ol0003oVkCYoi^dj@0>oi^dj@03o`000?n^^n?o[[_S00;o[[_S0ol0000>ojo1i`03o`000?nnaMoo
_/GO00Wo_/GO0_l00009ol3<i003o`000?o<c]_oc<kK00Soc<kK00?o0000olkCg_o>dmh03Oo>dmh0
0ol0003of=?Do`00000=omWIe`03o`000?oJh=_of^3K00[of^3K00Co0000omWWgooIimoo00002OoQ
hM@00ol0003oh>WIon3Yf@07on3Yf@03o`000?oKm=oofoCO00OofoCO0ol00003omo`f`04o`000?oO
l=_ogo3Ko`0000OocOgR0_l00002ogoU`P?o00005?ooool00ol0003oooooooooo`0:ooooo`0000Co
<S8bo`000?lb<S;ok^k^2oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`Co
00001?ooool2o`0001_ooooo0ol0000Zooooo`;o00000_l0Al801?l0003o67KSoaQfholHM^<3o`00
0003obIjiOl0003oFiS_00WoFiS_00?o0000oh6Yk_n1ZNh03?n1ZNh00ol0003oVkCYoi^dj@0?oi^d
j@04o`000?n^^n?o0000o`0001;o[l7W00?o0000okk5gonnaMl01onnaMl00ol0003o`<cTol3<i00:
ol3<i003o`000?o<c]_oc<kK00Koc<kK00?o0000olkCg_o>dmh03_o>dmh3o`0000cofMWG00?o0000
om[PfooJh=/02_oJh=/00ol0003ofNOOomWWg`02omWWg`03o`000?oQhMCohN7D00GohN7D00?o0000
on3YfOoPjMT01ooPjMT00ol0003ofoCOom_dg`07om_dg`04o`000?o=oN;ocOgRolgmhP;o00000_oO
l=/2o`0000KocOgR0_l000001?moiL;o0000o`000?l0000Gooooo`03o`000?oooooooooo00[ooooo
000Yooooo`03o`000?oooooooooo01Kooooo0ol0000^ooooo`?o000000?o04O2o`000?lHM^<01?lH
M^<3o`0000[oFiS_00?o0000oh6Yk_n1ZNh03?n1ZNh00ol0003oVkCYoi^dj@0=oi^dj@?o00005On_
`NL00ol0003o_/GOokk5g`04okk5g`;o00003_o0c>@00ol0003oc<kKolc>f`03olc>f`;o00004?o>
dmh01Ol0003ocm[RoloJh_o?f^;o000000[ofMWG00?o0000om[PfooJh=/02_oJh=/00ol0003ofNOO
omWWg`04omWWg`03o`000?oQhMCohN7D00?ohN7D00?o0000on3YfOoPjMT01ooPjMT00ol0003ofoCO
om_dg`07om_dg`03o`000?o=oN;ocOgR00CocOgR00Co0000omo`fol0003o00001Oo=oN84o`0001[o
oooo00?o0000ooooooooool02_ooool002Wooooo00?o0000ooooooooool04oooool3o`0003;ooooo
00Go0000o`10^_l0003o04O2o`000007oaQfh`?o00002?mKV>l00ol0003oPJW^oh6YkP0<oh6YkP03
o`000?nK]>WoVkCY00OoVkCY1Ol00002oiZikP03o`000?n_`NOo[l7W01Co[l7W00Co0000okk5gonn
aMoo_/GO0_l0000Aol3<i005o`000?o<c]_oc<kKolc>fol000004Oo>dmh00ol0003ocm[RoloJhP03
oloJhP03o`000?oIfMOofMWG00KofMWG00?o0000om[PfooJh=/02_oJh=/00ol0003ofNOOomWWg`06
omWWg`05o`000?oQhMCohN7Don7Qe?l000002OoPjMT00ol0003ofoCOom_dg`07om_dg`03o`000?o=
oN;ocOgR00GocOgR1Ol00002olgmhP?o00007Oooool00ol0003oooooooooo`0:ooooo`00:?ooool2
o`0001;ooooo0ol0000fooooo`03o`000?l0@;[o000000;o00001_lHM^<00ol0003oDiWaoe>Il@05
o`0000CoFiS_00?o0000oh6Yk_n1ZNh03?n1ZNh01?l0003oVkCYoi^djOnK]>T5o`0000SoV[W^00?o
0000ojo1ion_`NL05?n_`NL00ol0003o_/GOo`00000Dol3<i003o`000?o<c]_o0000013oc]?N0_l0
0007oloJhP;o00001OoIfML00ol0003of^3Kom[Pf`0:om[Pf`03o`000?oIimoofNOO00SofNOO00?o
0000on7Qe?l000002OoPjMT00ol0003ofoCOom_dg`06om_dg`;o00001oo=oN800ol0003oTno7oi?_
a`02oi?_a`?o00008Oooool00ol0003oooooooooo`09ooooo`00:?ooool00ol0003oooooooooo`0?
ooooo`;o0000>_ooool00ol0003o042jo`10^P02o`0000Ko67KS00?o0000oe>IlOmCVO401?mCVO46
o`0000OoPJW^2_l0000>oiZikP03o`000?n_`NOo[l7W01?o[l7W0_l0000Eol3<i0?o00003oo>dmh0
0ol0003ocm[RoloJhP09oloJhP05o`000?oIfMOofMWGomWIeol000003?oJh=/00ol0003ofNOOomWW
g`09omWWg`?o00002?oPjMT00ol0003ofoCOom_dg`06om_dg`03o`000?o=oN;ocOgR00GocOgR0_l0
0003oi?_a`Co00008_ooool00ol0003oooooooooo`09ooooo`00:?ooool00ol0003oooooooooo`0<
ooooo`?o0000?Oooool01Ol0003o042jo`10^_l0@;[o000000Ko67KS00?o0000oe>IlOmCVO402?mC
VO48o`0000OoOJgc00?o0000oiZik_nJ^Nh03onJ^Nh00ol0003o[l7Wojo1i`0@ojo1i`;o000000?o
/<S/o`000?o0c>@04_o0c>@2o`0000?o`M;W00?o0000olkCg_o>dmh02_o>dmh2o`0000gocm[R00?o
0000omWIeol000003?oJh=/00ol0003ofNOOomWWg`09omWWg`05o`000?oFlN?oe_7SomKahol00000
1_oPjMT00ol0003ofoCOom_dg`06om_dg`03o`000?o=oN;ocOgR00GocOgR00Co0000oi?_aonCklOo
Tno70_l00004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Oooool002Sooooo
00?o0000ooooooooool02Oooool3o`00047ooooo0_l00002o`10^P;o00001OlHM^<00ol0003oDiWa
oe>Il@09oe>Il@03o`000?mm[O?oOJgc00_oOJgc00?o0000oiZik_nJ^Nh03onJ^Nh00ol0003o[l7W
ojo1i`0<ojo1i`?o00001?n`b>`00ol0003o`<cTol3<i00?ol3<i003o`000?o1d^Oo`M;W00Co`M;W
00?o0000olkCg_o>dmh02?o>dmh00ol0003ocm[RoloJhP0=oloJhP?o00002ooJh=/00ol0003ofNOO
omWWg`09omWWg`03o`000?oFlN?oe_7S00?oe_7S0_l00003on3Yf@03o`000?oKm=oofoCO00GofoCO
0_l00006olgmhP;o00000_nCklL2o`0000Kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`09ooooo`00:?ooool00ol0003oooooooooo`06ooooo`?o0000A_ooool01?l0003o042jo`10
^_l0@;X2o`0000Co67KS00?o0000oe>IlOmCVO402OmCVO400ol0003oOJgcogf]l`0;ogf]l`03o`00
0?nJ^NkoV[W^00ooV[W^00?o0000ojo1ion_`NL02On_`NL2o`0000So/<S/00?o0000ol3<i?o0c>@0
3?o0c>@2o`0000So`M;W00?o0000olkCg_o>dmh01_o>dmh00ol0003ocm[RoloJhP0=oloJhP05o`00
0?o?hnKocn?VoloSi_l000002OoJh=/00ol0003ofNOOomWWg`09omWWg`03o`000?oFlN?oe_7S00Ko
e_7S00?o0000on3YfOl000001ooKm=l00ol0003ocOgRolgmhP04olgmhP;o000000CoTno7o`000?l0
003o00002Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Wooooo`;o
00001Oooool3o`0004[ooooo0_l00002o`10^P?o00000olHM^<00ol0003oDiWaoe>Il@09oe>Il@03
o`000?mm[O?oOJgc00_oOJgc00?o0000oiZik_nJ^Nh03onJ^Nh00ol0003o[l7Wojo1i`06ojo1i`;o
00002on`b>`00ol0003o`<cTol3<i009ol3<i0;o00002oo1d^L00ol0003oc]?NolkCgP03olkCgP;o
00003oo?f^800ol0003ocn?VoloSiP03oloSiP03o`000?oJh=_of^3K00Gof^3K00?o0000omWWgooI
iml02?oIiml2o`0000Woe_7S1?l00005om_dg`03o`000?o=oN;ocOgR00CocOgR00Co0000oi?_aol0
003o00003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo000Wooooo`04
o`000?ooooooooooooooo`?o0000C_ooool3o`000003o`10^_l0003o2G;O00?o000000?o67KSo`00
0?mCVO402_mCVO400ol0003oOJgcogf]l`0;ogf]l`03o`000?nJ^NkoV[W^00ooV[W^00?o0000ojo1
ion_`NL00_n_`NL3o`0000ko/<S/00?o0000ol3<i?o0c>@01oo0c>@00ol0003o`M;Wol7Bi`0<ol7B
i`05o`000?o>dmkoc]?NolkCg_l000004?o?f^800ol0003ocn?VoloSiP05oloSiP03o`000?oJh=_o
f^3K00?of^3K00?o0000omWWgooIiml02?oIiml00ol0003oe_7SomKah`08omKah`03o`000?o;o>Go
bocU00;obocU0ol000000ooKm=oo0000olgmhP04olgmhPCo00004?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00Wooooo000Wooooo`Co0000D_ooool01Ol0003o03feo`000?l0@;[o
000000?o2G;O0ol0000;oe>Il@03o`000?mm[O?oOJgc00_oOJgc00?o0000oiZik_nJ^Nh03onJ^Nh0
1?l0003o[l7Wo`000?l0000Bok38k003o`000?o0c>Co`<cT00Co`<cT0_l0000@ol7Bi`03o`000?o>
dmko000000oocm[R0_l00009oloSiP05o`000?oJh=_of^3Kom[Pfol000002_oIiml00ol0003oe_7S
omKah`08omKah`03o`000?o;o>GobocU00GobocU1Ol00002olgmhP?o00004_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Sooooo000Wooooo`;o0000EOooool00ol0003o03feo`00
0002o`0000Co2G;O0_l0000;oe>Il@03o`000?mm[O?oOJgc00_oOJgc00?o0000oiZik_nJ^Nh03OnJ
^Nh4o`0001Co/<S/00Co0000ol3<i?o0c>Co`<cT0_l0000Bol7Bi`?o00003_o?f^800ol0003ocn?V
oloSiP0:oloSiP03o`000?oJh=_o000000[ofNOO00?o0000omKahooFlN<02?oFlN<00ol0003obocU
ol_li@05ol_li@03o`000?nZnMSoZ_WH00?oZ_WH0ol0000Eooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02?ooool002Wooooo00?o0000ooooooooool0Doooool00ol0003o03feo`0m
]@02o`0000Go2G;O1Ol00007oe>Il@03o`000?mm[O?oOJgc00_oOJgc00?o0000oiZik_nJ^Nh01onJ
^Nh5o`0000CoV<3c00?o0000ok38k?n`b>`04_n`b>`00ol0003o`<cTo`00000Bol7Bi`;o00000oo1
f^`00ol0003ocm[RoloJhP0:oloJhP03o`000?o?hnKocn?V00_ocn?V0ol00008omWWg`;o00002OoF
lN<2o`0000KobocU0_l00004oj[if0?o00006?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo000Zooooo`03o`000?oooooooooo05?ooooo00Go0000o`0m]Ol0?KGo03feo`00
0006o`Ubg`03o`000?m9Vo?oBI_c00Oo000000?oDiWao`000?mm[O<03?mm[O<01?l0003oV[W^oiZi
k_nJ^Nh5o`0000[oV<3c00?o0000ok38k?n`b>`04On`b>`3o`00017o`M;W00?o0000ol7Jk?o1f^`0
1?o1f^`00ol0003ocm[RoloJhP08oloJhP03o`000?o?hnKocn?V00_ocn?V00Go0000olg/joo=k>_o
cNc[o`000006omWWg`03o`000?oFlN?oe_7S00Soe_7S00?o0000ol_liOo;o>D01Oo;o>D00ol0003o
Z_WHoj[if003oj[if003o`000?oooooooooo01Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`00:oooool00ol0003oooooooooo`1Cooooo`;o00000_l0?KD2o`0000Go2G;O
00?o0000odVKlom9Vo<01_m9Vo<Co`00013oV<3c00?o0000ok38k?n`b>`03On`b>`3o`0000?o[lo`
00?o0000ol7Bioo1d^L03?o1d^L2o`0000So`M[/00?o0000oloJh_o?f^801Oo?f^82o`0000cocn?V
0_l00005olg/j`;o00000ooIiml00ol0003oe_7SomKah`08omKah`03o`000?o;o>GobocU00GobocU
00?o0000oj[if?nZnMP00_nZnMP2o`0001gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`08ooooo`00;?ooool2o`0005Gooooo00?o0000o`0m]Ol0?KD00ol00004o`Ubg`03o`000?m9
Vo?oBI_c00WoBI_c00?o0000ogNbn?mg/_P02omg/_P00ol0003oV<3coiS0l`0?oiS0l`03o`000?n`
b>co/<S/00[o/<S/0_l00007ojo?l003o`000?o1d^Oo`M;W00Wo`M;W0_l0000;ol7Jk003o`000?o?
f^;ocm[R00?ocm[R00?o0000oloSi_o?hnH02oo?hnH00ol0003ocNc[olg/j`07olg/j`03o`000?oI
imoo000000Woe_7S0_l00006ol_li@;o00000onZnMP2o`00023ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`08ooooo`00;_ooool00ol0003oooooooooo`1Cooooo`;o000000?o03fe
o`000?l0LM`00_l00003o`Ubg`03o`000?m9Vo?oBI_c00WoBI_c00?o0000ogNbn?mg/_P02omg/_P0
0ol0003oV<3coiS0l`0?oiS0l`03o`000?n`b>co/<S/00Ko/<S/0ol0000:ojo?l003o`000?o1d^Oo
`M;W00Oo`M;W00?o0000ol7Jk?o1f^`03?o1f^`01Ol0003ocm[RoloJh_o?f^;o000000cocn?V0_l0
000:olg/j`?o00002?oFlN<00ol0003obocUol_li@05ol_li@04o`000?nZnMSoZ_WHoj[if0;o0000
8oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo000_ooooo`03o`000?oo
oooooooo05?ooooo0_l000001?l0?KGo0000o`1ag?l0LM`3o`000003o`Ubgol0003oBI_c00[oBI_c
00?o0000ogNbn?mg/_P02omg/_P00ol0003oV<3coiS0l`0?oiS0l`03o`000?n`b>co/<S/00?o/<S/
0_l0000>ojo?l003o`000?o1d^Oo`M;W00Co`M;W0_l0000@ol7Jk003o`000?o?f^;o000000cocn?V
00?o0000olg/joo=k>/02Oo=k>/01?l0003oaOK]olGfkOo5m^d3o`0000Coe_7S00?o0000ol_liOo;
o>D01?o;o>D2o`0000?oZ_WH00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Oooooo000`ooooo`03o`000?oooooooooo05?ooooo1?l00004o`1ag0?o0000
2om9Vo<00ol0003oMk;hogNbn00;ogNbn003o`000?nH`??oV<3c00ooV<3c00?o0000ok38k?l00000
0_l0000Aojo?l004o`000?o1d^Oo`M;Wol7Bi`;o00004_o1f^`3o`0000[ocn?V0_l0000:olg/j`;o
00001oo5m^d2o`000003omKahol0003obocU00GobocU00Co0000oj[if?nZnMSoZ_WH0_l0000Woooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool0037ooooo0_l0001Dooooo`04
o`000?l0?K;o0000o`0000Go077L0_l0000;odVKl`03o`000?mg/_SoMk;h00_oMk;h00?o0000oiS0
lonH`?<03OnH`?<4o`0001Co[lo`00?o0000ol7Biol000004_o1f^`2o`0000?o_nCa0_l00007oloS
iP03o`000?o=k>_ocNc[00WocNc[00?o0000olGfkOo5m^d02?o5m^d5o`0000?obocU00?o0000oj[i
f?l000000_l0000Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool003?o
oooo00?o0000ooooooooool0D_ooool01?l0003o03fbo`000?l00006o`1ag0Go00001om9Vo<00ol0
003oMk;hogNbn00;ogNbn003o`000?nH`??oV<3c00OoV<3c1Ol00004oiG6n003o`000?n_co3o[lo`
017o[lo`0ol0000@ol7Jk0;o00001onoi?400ol0003ocn?VoloSiP02oloSiP;o00002oo=k>/00ol0
003oaOK]olGfk@07olGfk@;o00001On/nN@6o`0002gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`07ooooo`00=?ooool00ol0003oooooooooo`1Booooo`;o000000?o03fbo`000?l0
LM`01_l0LM`00ol0003o@Icdod6Lm007o`000003odVKlol0003oMk;h00coMk;h00Co0000oiS0lonH
`??oV<3c1Ol0000:oiG6n003o`000?n_co3o[lo`00go[lo`0ol00003ojkGm@03o`000?o1f^co`M[/
00_o`M[/0_l0000:okoTl@;o000000?ocn?Vo`000?o=k>/02_o=k>/2o`0000WoaOK]00?o0000ojci
i?n/nN@01?n/nN@2o`000003ogKP__l0003o000002oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`07ooooo`00=Oooool00ol0003oooooooooo`1Cooooo`Co00001_l0LM`00ol0003o
@Icdod6Lm006od6Lm1?o00004?nEa_P00ol0003o[lo`ojo?l00:ojo?l0;o00001on^eoD00ol0003o
`M[/ol7Jk009ol7Jk003o`000?noi?7o_nCa00_o_nCa0ol0000:olg/j`03o`000?o5m^goaOK]00Oo
aOK]0_l00005ojcii0Go0000<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oo
oooo000fooooo`03o`000?oooooooooo05?ooooo1_l00004o`1ag0;o00002_m1W?@00ol0003oL[Ok
og:gn`0;og:gn`03o`000?nEa_SoULKh00ooULKh00?o0000ojo?l?n_co001_n_co03o`0000[o[]Oe
0_l00007ol7Jk0;o00003?noi?42o`0000?o^^gd0_l00006olg/j`;o00002?o5m^d2o`0000Go[?WT
1?l0000fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool003Oooooo0_l0
001Eooooo`Oo00000ol0LM`00ol0003o@Icdod6Lm008od6Lm003o`000?mb]o_oL[Ok00_oL[Ok00?o
0000oiG6n?nEa_P03onEa_P00ol0003o[lo`ojo?l003ojo?l0;o00003on^eoD00ol0003o`M[/ol7J
k002ol7Jk0;o00003?noi?42o`0000Oo^^gd00?o0000olg/joo=k>/00_o=k>/00ol0003oaOK]olGf
k@06olGfk@;o00001On/nN@4o`0003Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`06ooooo`00>Oooool00ol0003oooooooooo`1Cooooo`Co00000_l0L=T3o`000003o`1ag?l0003o
@Icd00Wo@Icd00?o0000og:gnomb]o/02omb]o/2o`00013oULKh00?o0000ojo?l?l000000_l0000B
ojkGm@04o`000?o1f^co0000o`0000co_nCa0_l0000:ok[]m0;o000000?ocNc[o`000?o5m^d01oo5
m^d00ol0003o[?WTojcii003ojcii0Co0000>oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Kooooo000jooooo`03o`000?oooooooooo05Cooooo1?l00003o`1`f@?o00002_m1W?@0
0ol0003oL[Okog:gn`0<og:gn`03o`000?nEa_SoULKh00coULKh1?l0000DojkGm@?o00003?noi?40
0ol0003o^^gdok[]m00;ok[]m0Ko00000oo5m^d2o`0000Co[?WT1?l0000nooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool003_ooooo00?o0000ooooooooool0E?ooool4o`00
00Go073I1?l00007od6Lm003o`000?mb]o_oL[Ok00coL[Ok00?o0000oiG6n?nEa_P01_nEa_P5o`00
00CoTLkl00?o0000ojkGmOn^eoD03_n^eoD3o`0000?oZ^7j0_l00008okoTl@;o00003?njkO@2o`00
00Ko[?Cb2_l00012ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool003co
oooo0_l0001Eooooo`Go00001Ol0L=T00ol0003o>9kco`000006o`000003od6Lm?l0003oL[Ok00go
L[Ok00?o0000oiG6n?nEa_P01Ol0000:oi7>o003o`000?n^eoGo[]Oe00_o[]Oe0_l00008oj[QnP03
o`000?noi?7o_nCa00?o_nCa0_l0000<ok[]m0;o00001on/m?82o`0000?oQN_J1?l00014ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool003kooooo00?o0000ooooooooool0
Doooool7o`0000?o073I00?o0000ocRNlolhW_<01OlhW_<Co`00013oTLkl0_l00008ojkGm@?o0000
2onZhOX2o`000003okoTlOl0003o000000co^^gd0_l00007ojcdlP;o00000on5jmX4o`0004Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`00?oooool00ol0003ooooooooo
o`1Cooooo`03o`000?l0AKoo000000Ko000000?o073Io`000?l000002OlhW_<00ol0003oJkcmof^l
o@0<of^lo@03o`000?nAc_coTLkl00ooTLkl00?o0000ojkGmOn^eoD00on^eoD2o`0000ooZ^7j0ol0
000;ok[]m0;o00001on/m?82o`0000?oQN_J0ol0001;ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01_ooool0043ooooo00?o0000ooooooooool0Doooool00ol0003o04Foo`15_`04
o`000005o`1`dol0003o0000o`1`fOl000002OlhW_<2o`0000goJkcm00?o0000oi7>o?nAc_`03onA
c_`00ol0003o[]Oeo`000002o`0000koZ^7j0ol00003oj7Xn`?o00001_njkO@2o`0000Oo[?Cb0_l0
0002ohG[fPCo0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo0011
ooooo`;o0000E?ooool00ol0003o04Foo`15_`04o`0000;o073C0ol0000:ocRNl`03o`000?m[_?go
Jkcm00_oJkcm0_l0000>oi7>o0Co00003_nZhOX2o`0000WoXNSk0ol000000onjkOCo0000o`000007
ojcdlP;o00000_n5jmX4o`00053ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05
ooooo`00@oooool00ol0003oooooooooo`1Booooo`04o`000?l0AKoo04Foo`15_`Co00000ol0L=<5
o`0000Ko>9kc0_l0000=of^lo@03o`000?nAc_coTLkl00KoTLkl1Ol00004ohWEo`;o00002_nZhOX2
o`0000goXNSk1_l00003ojcdlPOo0000E?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo0014ooooo`03o`000?oooooooooo05;ooooo0_l00002o`15_`Ko00000_l0L=<00ol0
003o;9o`obbOl007o`000003ocRNlol0003oJkcm00coJkcm00?o0000oi7>o?nAc_`01Ol0000;ohWE
o`;o00001OnZhOX3o`0000coXNSk0ol00006ohcZlPOo0000F?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Gooooo0015ooooo`03o`000?oooooooooo05?ooooo0ol000000ol0AKoo
0000o`000007o`0000Oo;9o`4_l0000BohWEo`;o000000?oZ^7jo`000?l000003OnQj?/2o`0000Oo
S>[b1_l0001Kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool004Kooooo
0_l0001Dooooo`03o`000?lCM^?o000000Ko000000?o07?@o`000?l000000_l00009obbOl003o`00
0?mP`?goH<3m00_oH<3m0_l0000@ohWEo`Co00002onQj?/3o`0000KoS>[b1_l0001Oooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool004Sooooo00?o0000ooooooooool0D_oo
ool00ol0003o4gKSoa=fh`06o`0000;o07?@0ol00009obbOl0;o00003OmP`?d2o`0000WoRMGo1Ol0
0004ogcJo@?o00001_nQj?/2o`0000KoS>[b1_l0001Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool004Wooooo00?o0000ooooooooool0D_ooool01?l0003o4gKSoa=fholC
M^<7o`0000;o07?@1Ol00006obbOl0;o00003OmP`?d2o`0000;oRMGo1Ol0000<ogcJo@;o000000Co
XNSko`000?l0003o00001On<j_86o`0006Oooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`00B_ooool00ol0003oooooooooo`1Booooo`03o`000?lCM^?o4gKS00?o4gKS4_l0
00000ol/Wo3o0000of30o@06of30o@Wo00004Omlf_d>o`0006[ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`04ooooo`00Boooool00ol0003oooooooooo`1Booooo`Co00000olCM^<<
o`0000Co8Z3Y2Ol00009oe?2n0?o00002Omlf_d5o`0000GoHmK]1?l0001`ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01?ooool004cooooo0_l0001Cooooo`03o`000?mXYOCoJ:Gd
01Co00000olRX>T3o`0000koDl;h0_l00002ogcJo@Go00001_mSe^d4o`0007Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`00C_ooool00ol0003oooooooooo`1Aooooo`03
o`000?mXYOCoJ:Gd00GoJ:Gd5ol00007oe?2n0_o00001OmSe^d3o`0007Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`00Coooool00ol0003oooooooooo`1Aooooo`03o`00
0?mXYOCoJ:Gd00_oJ:Gd1?l00003oooooa3o00001olk_>@9o`0007gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`00D?ooool00ol0003oooooooooo`1Aooooo`03o`000?mX
YOCoJ:Gd00SoJ:Gd0ol0000>ooooo`oo0000Qoooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo001Aooooo`;o0000D_ooool00ol0003oJ:GdofRUm004ofRUm0?o0000Z?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo001Cooooo`03o`000?oooooooooo
053ooooo00?o0000ofRUm?mXYO@00ol0002[ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool005Cooooo00?o0000ooooooooool0D?ooool2o`000:oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`00EOooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo0:oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`00E_oo
ool2o`0004oooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo001Hooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0/?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo001Iooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo001Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo001Kooooo`;o0000B_ooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool005gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool005kooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2d
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool005oooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`2eooooo`05o`000?ooooooooooooooool000001?ooool0
063ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2eooooo`05o`000?oooooooooo
ooooool000001?ooool0067ooooo0_l00014ooooo`03o`000?oooooooooo0;Kooooo00Co0000oooo
oooooooo00001?ooool006?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2goooo
o`03o`000?oooooo000000Cooooo001Tooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0]oooool01?l0003oooooooooool00003ooooo`00IOooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo0;Sooooo00?o0000ooooool000000oooool006Kooooo0_l0000oooooo`03o`00
0?oooooooooo0;Wooooo0_l00003ooooo`00J?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;Wooooo0ol00003ooooo`00JOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo0;Gooooo1?l00006ooooo`00J_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
0;7ooooo1?l0000:ooooo`00Joooool2o`0003Wooooo00?o0000ooooooooool0[_ooool3o`0000ko
oooo001]ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Z_ooool4o`00017ooooo
001^ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y_ooool4o`0001Gooooo001_
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`0001Wooooo001`oooo
o`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00007Oooool007;ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`2Kooooo`?o00008Oooool007?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`2Gooooo`Co00009?ooool007Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`2Cooooo`Co0000:?ooool007Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`2?ooooo`Co0000;?ooool007Kooooo0_l0000^ooooo`03o`000?oooooooooo
08_ooooo1?l0000`ooooo`00N?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Oo
oooo1?l0000dooooo`00NOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Cooooo
0ol0000hooooo`00N_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo083ooooo1?l0
000kooooo`00Noooool2o`0002Wooooo00?o0000ooooooooool0O?ooool4o`0003oooooo001moooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4o`0004?ooooo001nooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`0004Oooooo001oooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3o`0004_ooooo0020ooooo`;o00009?oo
ool00ol0003oooooooooo`1]ooooo`Co0000C_ooool008;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Yooooo`Co0000D_ooool008?ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1Uooooo`Co0000E_ooool008Cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1Qooooo`Co0000F_ooool008Gooooo0_l0000Oooooo`03o`000?oooooooooo05gooooo
1?l0001Nooooo`00Qoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo0ol0
001Rooooo`00R?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Kooooo1?l0001U
ooooo`00ROooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo1?l0001Yoooo
o`00R_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo1?l0001]ooooo`00
Roooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00077ooooo002=ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`0007Gooooo002>ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0@oooool3o`0007Wooooo002?ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0?oooool4o`0007cooooo002@ooooo`;o00005?ooool00ol0003o
ooooooooo`0kooooo`Co0000P?ooool009;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0hooooo`Co0000Q?ooool009?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0dooooo`Co0000R?ooool009Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0a
ooooo`?o0000S?ooool009Gooooo0_l0000>ooooo`03o`000?oooooooooo02gooooo1?l0002?oooo
o`00Uoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo1?l0002Cooooo`00
V?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Gooooo`00VOoo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Kooooo`00V_ooool2
o`0000Wooooo00?o0000ooooooooool07Oooool4o`0009oooooo002Looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06_ooool3o`000:?ooooo002Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool4o`000:Kooooo002Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04_ooool4o`000:[ooooo002Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`000:kooooo002Pooooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`Co0000/_ooool00:;ooooo00Co0000oooooooooooo00002Oooool3o`000;Kooooo002Soooo
o`03o`000?oooooo000000Gooooo1?l0002iooooo`00Y?ooool2o`000003ooooool0003o000000;o
0000_Oooool00:Gooooo0_l00031ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00TOooool01OlQ8B7o0000o`000?m4A4CogMgM04kooooo0ol000000ol@413o
ooooooooo`1nooooo`00?_ooool00ol0003oooooooooo`1Cooooo`03ogMgMolb<S;ooooo04oooooo
00?o0000ooooooooool0Ooooool003kooooo00?o410@omgMgOooool0E?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo07oooooo000looooo`05olc<c?l@413o0000o`000?n7QhL02ooo
ool5o`0000;ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`05ooooo`06oiRH
V?l0003o0000ogMgMol@413o00002_ooool01OmVIVKo0000o`000?m4A4Coc<c<00;ooooo00Co410@
o`000?l0003ooooo0_l000000ol@413ooooooiRHV002o`000005ogMgMol@413o0000ooooool@4100
1Ol00003ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000_ooool01_o^k^koEEEEo`000?l0003o
A4A4okZj^POooooo00?o410@o`000?l000000_l000001?l@413oooooooooooooool5o`0000;ooooo
1Ol00003ooooo`Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Ook^k^oeEE
EOl0003o0000oiRHV?l0003o410@00Gooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06
onk^k_mEEEGo0000o`000?mgMgOo00000oooool02?nHV9So0000o`000?mgMgOo0000oa0@4?oooooo
V9RH0_l000001OmgMgOo410@o`000?oooooo410@00Go00000oooool01_o^k^koEEEEo`000?l0003o
A4A4okZj^POooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0003o0000oooo
o`;o000000Co410@ooooooooooooIVIV0_l000001?m4A4Coc<c<ooooooooool5o`0000?ooooo00Ko
k^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0oooool0
1OnHV9So0000o`000?mgMgOo000000;o410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
^[Zj5?ooool003cooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhL<ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?o<c<cok^k^ohN7Qol000002_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?o<c<cok^k^ohN7Qol000001?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOo
ooooonk^k_mEEEGo00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoEEEEogMgMoooooook^k^
oeEEEOl00006ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^
k^koEEEEo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`05o`000?o<c<cok^k^ohN7
Qol000001?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1ooo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000ooooooooooooooooo`000002oooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@1?ooool00ol0003oooooooooo`03ooooo`06oeEEEOmg
MgOooooooooooomgMgOoEEEE0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000
ojVYZOooooooQhN7o`000003ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooook^k^
ogMgMol@410Dooooo`00??ooool01_l0003oooooofIVI_n7QhOogMgMoa0@40cooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00Go410@ohN7Qoooooook^k^o`00
000:ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`05oa0@
4?n7QhOoooooonk^k_l000001?ooool00ol0003oooooooooo`04ooooo`06o`000?oooooooooooooo
ooo^k^ko00000_ooool00ol0003oooooooooo`02ooooo`Ko00001?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooonk^k_l00007ooooo`05okZj
^_n7QhOoIVIVofIVI_l@41000_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooookZj^_n7QhL2ofIVIP05oa0@4?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
5oooool003cooooo00Ko410@omgMgOmgMgOoMgMgooooool0000<ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03okZj^_l@413o000000;o00002_ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00onj^[[o410@o`000002
o`0000Cooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo
1_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`06o`000?ooooooooooooooooo^
k^ko00001_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo00Ko0000oooooooooooooooo
onk^k_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00onj^[[o410@o`000002o`00
00Cooooo00?o0000ooooooooool01?ooool6o`0000Oooooo1_l00003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooolb<S;o8B4Q00;oMgMg00?oQhN7onk^k_ooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool6o`0001Cooooo
000looooo`06ojVYZOm4A4CoV9RHodA4A?nHV9So410@3?ooool00ol0003oooooooooo`03ooooo`05
o`000?n7QhOoooooojVYZOl000002oooool00oo<c<co0000ooooo`09ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?oc<c<o`000?ooool0
0oooool00ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<PWooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00006ooooo`06o`000?nj^[[o
ooooonk^k_mgMgOo00000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01?ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<POooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83oooo
o`05o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000Cooooo
00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko0000okZj
^_ooooook^k^ogMgMol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o<S8b
omgMg@04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b5?ooool003gooooo00GoV9RHo`000?l0
003o410@olc<c00:ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onH
V9Soooooooooo`07ooooo`04oc8b<_l0003o0000oiRHV0[ooooo00Kok^k^ofIVI_l0003o0000odA4
A?l00003ooooo`05o`000?mgMgOo0000o`000?nHV9P00oooool01?lb<S;o0000o`000?nHV9P3oooo
o`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02_o^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413o
ooooonk^k_mEEED2o`000003odA4A?o^k^kooooo00Kooooo00?o410@o`000?l000000ol00003oooo
o`03oa0@4?l0003o000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koEEEEo`000?l@413oc<c<o`0000Ko
oooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`0:onk^k_mEEEGo0000o`000?mgMgOo0000
oa0@4?oooooo410@o`0000;ooooo0_l00003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo0_l00000
1?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1oooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^
k^koIVIV00;o000000?oA4A4o`000?ooool00oooool00ol0003oooooooooo`03ooooo`06onk^k_mE
EEGo0000o`000?mEEEGok^k^0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Co410@
o`000?oooooooooo0_l00002ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kQCooooo000nooooo`03okZj^_lb<S;ooooo03Sooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo03gooooo000oooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0[ooooo`03oa0@
4?nj^[[ooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0mooooo`00C_oo
ool00ol@413oooooooooo`0Wooooo`03oa0@4?l0003ooooo02cooooo00Co^[Zjoa0@4?l0003o410@
1Oooool00ol@413oooooooooo`02ooooo`03oa0@4?l0003o000000Gooooo00?o410@o`000?l00000
4Oooool2o`0005?ooooo00?o410@o`000?l00000?oooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.117954, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell["\<\
The potential matches the boundary conditions, and has a maximum in \
the interior of the domain due to the uniform charge density. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Example 2: Solution of Laplace's Equation with Rapidly-Varying \
Boundary Conditions\
\>", "Subsubsection",
  CellTags->"i:67"],

Cell[TextData[{
  "\tIn this example, we choose a case with no charge density, so that we are \
looking for the solution of Laplace's equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ".  For boundary conditions, we take  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " on three sides, but on the right side of the box at ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  ", we take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a, 
          y) = \[Phi]\_o\ \(h(y - b/3)\) \(h(\ 2  b/3 - y)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(y)\)]],
  " is a Heaviside step function. In other words, the center third of the \
right side of the box wall is at potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_o\)]],
  ", but the rest of the box is grounded. (See Fig. ",
  ButtonBox["4.5",
    ButtonData:>"Fig. 4.5",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;N0003Gb000`400?l00000o`00003oo`3ooooo
0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo
003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0
ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool0
0?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3o
oooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00
o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?oo
on00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o
0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0oooo
h03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0
ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP
0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3o
oooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooXP3oool4000000`0oooo00@0P8200000
000000000000o`3ooolZ0?ooo`00o`3ooonP0?ooo`030820P0000000000000D0000000<0P8200?oo
o`3oool01`3oool5000000030820P03oool0oooo0?l0oooo9P3oool00?l0ooooWP3oool00`20P800
000000000009000000030<30`03oool0oooo00D0oooo1P0000000`20P800oooo0?ooo`3o0?ooobD0
oooo003o0?oooih0oooo3P0000060?ooo`P00000o`3ooolV0?ooo`00o`3ooonM0?ooo`030820P000
0000000000D0000000@0@4100820P020P800P820100000000`30`<00oooo0?ooo`020?ooo`D00000
0P3oool00`000000@4100?ooo`3o0?ooob@0oooo000^0?ooo`030820P0000000000000<00000o`3o
oomY0?ooo`P000001P3oool3000000@0oooo1@0000030?ooo`800000o`3ooolT0?ooo`00;03oool0
0`20P80000000000000700000?l0ooooI`3oool7000000P0oooo0`0000030?ooo`D000000`3oool0
0`20P80000000?ooo`3o0?ooob<0oooo000Z0?ooo`80P8200`0000040820P0@0000000<0P8200?oo
o`3oool0o`3ooomS0?ooo`H000002P3oool00`30`<0000000410@0020?ooo`030410@00000000000
0080000000H0P8200?ooo`3oool0`<3000000030`<3o0?ooob<0oooo000Y0?ooo`030820P0000000
0000008000001P3oool00`20P80000000000000200000?l0ooooI03oool6000000`0oooo0P000000
0`3oool0P82000000003000000030820P03oool0oooo0?l0oooo9P3oool002P0oooo00D0P8200000
0000000000000410@0080?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3ooomP
0?ooo`D0000000<0@4100?ooo`3oool02P3oool01030`<00000000000020P80500000?l0oooo:03o
ool002P0oooo100000000`20P800oooo0?ooo`070?ooo`030820P0000000000000800000o`3ooomR
0?ooo`H000003P3oool700000?l0oooo:03oool002L0oooo00<0P8200000000000000P00000;0?oo
o`@0000000<0P8200?ooo`3oool0o`3ooomO0?ooo`H000003P3oool700000?l0oooo:03oool002L0
oooo100000000`20P800oooo0?ooo`090?ooo`030820P0000000000000800000o`3ooomQ0?ooo`03
0820P0000000000000<000003`3oool00`10@40000000000000400000?l0oooo9`3oool002H0oooo
1@00000=0?ooo`D00000o`3ooomP0?ooo`030820P0000000000000<000003`3oool00`20P8000000
0000000400000?l0oooo9`3oool002H0oooo1@00000=0?ooo`D00000o`3ooomP0?ooo`030820P000
0000000000<00000403oool600000?l0oooo9`3oool002D0oooo1@00000?0?ooo`D00000o`3ooomP
0?ooo`H000003`3oool00`20P80000000000000400000?l0oooo9P3oool002@0oooo00<0P8200000
000000000`00000?0?ooo`D0000000<0P8200?ooo`3oool0o`3ooomM0?ooo`H00000403oool60000
0?l0oooo9P3oool002@0oooo00<0@4100000000000000P0000000`10@400oooo0?ooo`0=0?ooo`03
0410@000000000000080000000<0@4100?ooo`3oool0o`3ooomN0?ooo`D0000000<0P8200?ooo`3o
ool03P3oool5000000030820P03oool0oooo0?l0oooo8`3oool002@0oooo1@0000000`20P800oooo
0?ooo`0=0?ooo`030820P0000000000000<00000o`3ooomQ0?ooo`D00000403oool00`20P8000000
00000002000000030820P03oool0oooo0?l0oooo8`3oool002@0oooo1@0000000`20P800oooo0?oo
o`0=0?ooo`030820P0000000000000<00000o`3ooomQ0?ooo`D0000000<0P8200?ooo`3oool03@3o
ool00`20P800000000000002000000030820P03oool0oooo0?l0oooo8`3oool002<0oooo00<0P820
0000000000000`0000000`20P800oooo0?ooo`0=0?ooo`030820P0000000000000<0000000<0P820
0?ooo`3oool0o`3ooomN0?ooo`030820P000000000000080000000<0@4100?ooo`3oool03@3oool0
0`30`<0000000000000300000?l0oooo9@3oool002<0oooo1P0000000`20P800oooo0?ooo`0=0?oo
o`030820P0000000000000@00000o`3ooomQ0?ooo`D00000403oool500000?l0oooo9@3oool002<0
oooo1P00000@0?ooo`030<30`0000000000000@00000o`3ooomR0?ooo`D000003`3oool600000?l0
oooo903oool002<0oooo1P00000A0?ooo`H00000o`3ooomR0?ooo`030820P0000000000000<00000
3P3oool600000?l0oooo903oool00280oooo1`00000A0?ooo`H00000o`3ooomS0?ooo`D000003P3o
ool600000?l0oooo903oool00280oooo1`00000A0?ooo`L00000o`3ooomS0?ooo`@0000000<0@410
0?ooo`3oool02`3oool6000000030820P03oool0oooo0?l0oooo8@3oool00280oooo1`00000A0?oo
o`L00000o`3ooomT0?ooo`D00000303oool6000000030820P03oool0oooo0?l0oooo8@3oool00280
oooo1`00000A0?ooo`L00000o`3ooomT0?ooo`030820P0000000000000800000303oool700000?l0
oooo8`3oool00280oooo1`00000A0?ooo`L00000o`3ooomU0?ooo`80P8200P0000000`10@400oooo
0?ooo`090?ooo`0300000020P800000000@00000o`3ooolS0?ooo`008P3oool700000140oooo1`00
003o0?ooofL0oooo00@0P82000000000000000002P3oool00`000000P8200000000400000?l0oooo
8`3oool00280oooo1`00000A0?ooo`L00000o`3ooomX0?ooo`050820P010@400000000000010@400
1`3oool01010@40000000?ooo`20P80500000?l0oooo8P3oool00280oooo1`00000A0?ooo`L00000
o`3ooomZ0?ooo`@0000000<0P8200?ooo`3oool00P3oool2000000<0oooo1@00003o0?ooob80oooo
000R0?ooo`L000004@3oool700000?l0ooooK03oool8000000030820P03oool0oooo0080oooo00<0
P8200000000000000P00003o0?ooob40oooo000R0?ooo`L000004@3oool700000?l0ooooKP3oool5
0820P0T0oooo0P20P83o0?ooob40oooo000R0?ooo`L000004@3oool700000?l0ooooo`3ooonO0?oo
o`008P3oool00`20P80000000000000400000140oooo1`00003o0?ooool0ooooW`3oool002<0oooo
1P0000000`20P800oooo0?ooo`0>0?ooo`H00000o`3ooooo0?oooj00oooo000S0?ooo`H0000000<0
P8200?ooo`3oool03P3oool600000?l0ooooo`3ooonP0?ooo`008`3oool6000000030820P03oool0
oooo00h0oooo1P00003o0?ooool0ooooX03oool002<0oooo1P0000000`20P800oooo0?ooo`0=0?oo
o`030820P0000000000000@00000o`3ooooo0?oooj00oooo000T0?ooo`D0000000<0P8200?ooo`3o
ool03@3oool00`20P80000000000000300000?l0ooooo`3ooonQ0?ooo`00903oool5000000030820
P03oool0oooo00d0oooo00<0P8200000000000000`00003o0?ooool0ooooX@3oool002@0oooo00<0
P8200000000000000`00000?0?ooo`030820P0000000000000<00000o`3ooooo0?oooj40oooo000T
0?ooo`030820P0000000000000<000003`3oool00`10@400000000000002000000030820P03oool0
oooo0?l0ooooo`3ooonO0?ooo`009@3oool5000000l0oooo1@00003o0?ooool0ooooXP3oool002D0
oooo1@00000?0?ooo`D00000o`3ooooo0?oooj80oooo000V0?ooo`D000003@3oool00`20P8000000
00000002000000030820P03oool0oooo0?l0ooooo`3ooonP0?ooo`009`3oool4000000d0oooo1000
003o0?ooool0ooooY03oool002L0oooo00<0@4100000000000000P00000;0?ooo`@0000000<0@410
0?ooo`3oool0o`3ooooo0?oooj80oooo000X0?ooo`@0000000<0P8200?ooo`3oool01`3oool00`20
P80000000000000200000?l0ooooo`3ooonU0?ooo`00:@3oool4000000T0oooo00<0P82000000000
00000P00003o0?ooool0ooooY@3oool002T0oooo00<0`<300000000000000P0000000`30`<00oooo
0?ooo`040?ooo`050820P0000000000000000010@400o`3ooooo0?ooojH0oooo000[0?ooo`D00000
103oool400000?l0ooooo`3ooonX0?ooo`00;03oool;00000?l0ooooo`3ooonY0?ooo`00;@3oool2
0820P0D0000000<0@4100820P03oool0o`3ooooo0?ooojT0oooo003o0?ooool0ooooh03oool00?l0
ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooom_
0?ooo`050820P000000000000820P030`<00K03oool00?l0ooooo`3ooom_0?ooo`L00000JP3oool0
04<0oooo00<0`<300820P020P800o`20P81Z0820P;d0oooo00<0`<300000000000001`0000020820
P6H0oooo00130?ooo`030820P000000000000?l00000JP00002m0?ooo`030820P0000000000000X0
000000<0P8200?ooo`3oool0HP3oool004<0oooo00<0P820000000000000o`00001Z00000;d0oooo
00<0P820000000000000300000000`20P800oooo0?ooo`1P0?ooo`00@`3oool00`20P80000000000
003o000006X00000_@3oool00`20P80000000000000?000000040410@020P800P8200<30`5`0oooo
00130?ooo`030820P000000000000?l00000JP00002m0?oooaL00000F`3oool004<0oooo00<0P820
000000000000o`00001Z00000;d0oooo6@00001I0?ooo`00@`3oool00`20P80000000000003o0000
06X00000_@3ooolJ000000030410@020P800`<3005D0oooo00130?ooo`030820P000000000000?l0
0000JP00002m0?oooal00000D`3oool004<0oooo00<0P820000000000000o`00003o000004T00000
00<0P8200<30`03oool0CP3oool004<0oooo00<0P820000000000000o`00003o000004/00000C`3o
ool004<0oooo00<0P820000000000000o`00003o000004T00000D@3oool004<0oooo00<0P8200000
00000000o`00001Z00000;`0oooo00<0P8200000000000006P0000000`10@400P8200820P01C0?oo
o`00@`3oool00`20P80000000000003o000006X00000_@3ooolK000005L0oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000_@3ooolG00000080P820F@3oool004<0oooo00<0
P8200000000000002P00003o0?oooe@0oooo3000002m0?oooaD00000G@3oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000002m0?ooo`030820P0000000000000l0000000<0P820
0?ooo`3oool0G@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000002m0?oo
o`030820P0000000000000/000000P20P81R0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000;d0oooo00<0P8200000000000002@00001V0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000;h0oooo2@0000000`20P800oooo0?ooo`1U0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000;h0oooo1@0000020820P0030<30`03o
ool0oooo06L0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000_P3oool3
000006h0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o
0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000<l0oooo00@0P820000000000000P8203P3oool01020P80000000000
0020P81:0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000<l0oooo1@00
000=0?ooo`D00000B@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003?
0?ooo`D0000000<0@4100?ooo`3oool02@3oool6000000030410@03oool0oooo04H0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``00000c`3oool7000000T0oooo00<0P8200000
000000001P0000170?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000<l0
oooo200000080?ooo`030820P0000000000000L00000AP3oool004<0oooo00<0P820000000000000
2P00003o0?oooe@0oooo3000003?0?ooo`<0000000<0`<300?ooo`30`<000P0000000`20P800oooo
0?ooo`050?ooo`030410@000000000000080000000<0P8200?ooo`30`<000P0000000`20P800oooo
0?ooo`130?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000<l0oooo0P00
00050?ooo`8000001`3oool5000000040820P03oool0oooo0?ooo`800000A@3oool004<0oooo00<0
P8200000000000002P00003o0?oooe@0oooo3000003F0?ooo`030820P0000000000000H0oooo1@00
00050?ooo`030410@0000000oooo04<0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000e`3oool00`20P80000000820P0040?ooo`H000001P3oool00`000000P8200?ooo`12
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000=P0oooo0P0000040?oo
o`H000001P3oool00`000000oooo0?ooo`120?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000=P0oooo00<0P82000000020P8000`3oool5000004`0oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000f@3oool01020P80000000?ooo`3oool6000004`0
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000f@3oool01030`<000000
0000003oool5000004d0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000
fP3oool2000000030820P0000000000000<00000C@3oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003K0?ooo`L00000C@3oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003L0?ooo`D0000000<0P8200?ooo`3oool0B`3oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003L0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0B`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003L0?ooo`D0
000000<0P8200?ooo`3oool0B`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003L0?ooo`D00000CP3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003K0?ooo`H00000CP3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003K
0?ooo`D0000000<0P8200?ooo`3oool0C03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003K0?ooo`H0000000<0P8200?ooo`3oool0B`3oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003J0?ooo`L0000000<0P8200?ooo`3oool0B`3oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003J0?ooo`D000000P20P8000`000000P820
0?ooo`1;0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000=T0oooo00<0
P8200000000000000`0000001020P800oooo00000000001<0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000=T0oooo00<0P8200000000000000`0000000`30`<00oooo0<30
`002000000030<30`03oool0oooo04P0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000f@3oool6000000<0oooo0`00001:0?ooo`00@`3oool00`20P80000000000000:0000
0?l0ooooE03oool<00000=T0oooo1P0000040?ooo`<00000103oool300000480oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000e`3oool00`30`<00000000000004000000H0
oooo00<0@41000000010@4000P20P805000000030<30`03oool0oooo03h0oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000eP3oool8000000H0oooo00<0P820000000000000
1`0000000`20P800oooo0?ooo`0n0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000=80oooo2`0000080?ooo`T0000000<0P8200?ooo`3oool0?P3oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003B0?ooo`030820P0000000000000L0000000<0@410
0?ooo`3oool01`3oool00`20P800000000000005000000030820P03oool0oooo03h0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``00000e`3oool5000000`0oooo1P0000110?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000=T0oooo00<0`<300820P020
P8003@3oool01030`<00P8200820P020P8120?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3o
ool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooooo
0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`03
0820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000
o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo0013
0?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P00000000000
00X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00
oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o
0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o
0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o
0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o
0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo
<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000080oooo00<0P8200?ooo`3oool0o`3oool[0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<00000080oooo00<0P820000000000000o`3oool[0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000080oooo00D0`<3000000000000000000820P03o
0?ooobT0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000000`3oool50000
0?l0oooo:03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo300000040?ooo`H0
0000o`3ooolV0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000@0oooo
00<0P820000000000000100000000`20P800`<300?ooo`3o0?ooob80oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``000001@3oool900000?l0oooo8P3oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000050?ooo`030820P0000000000000L0000000<0P820
0?ooo`3oool0o`3ooolN0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
00D0oooo00<0`<30000000000000200000020820P?l0oooo7P3oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000060?ooo`d00000o`3ooolM0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<000000L0oooo3@0000000`10@400P8200?ooo`3o0?oooaT0oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000001`3oool00`20P80000000000
000=000000030820P03oool0oooo0?l0oooo5P3oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000070?ooo`030820P0000000000000l00000o`3ooolG0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<000000P0oooo4P0000000`20P800oooo0?ooo`3o0?oo
oa<0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000002@3ooolC00000003
0820P03oool0oooo0?l0oooo4@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000090?ooo`030820P000000000000180000000<0P8200<30`03oool0o`3oool?0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<000000X0oooo5`00003o0?ooo`l0oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000002P3oool00`20P80000000000000E
00000?l0oooo3P3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000:0?oo
o`030<30`0000000000001L0000000<0`<300?ooo`3oool0o`3oool90?ooo`00@`3oool00`20P800
00000000000:00000?l0ooooE03oool<000000/0oooo6`00003o0?ooo`X0oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000303ooolK00000?l0oooo2@3oool004<0oooo00<0
P8200000000000002P00003o0?oooe@0oooo3000000<0?ooo`030410@0000000000001X0000000<0
P8200?ooo`3oool0?`3oool00`20P80000000000000700000080P82000<0`<300?ooo`3oool0]@3o
ool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000<0?ooo`030820P0000000
000001`0000000<0P8200?ooo`3oool0?03oool00`20P80000000000000<000000030820P03oool0
oooo0;<0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000003@3ooolP0000
00030820P03oool0oooo03T0oooo00@0P82000000000000000001`20P8000`10@400000000000005
000000030820P03oool0oooo0;00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``000003P3ooolQ000003T0oooo100000000`20P800oooo0?ooo`070?ooo`T00000/03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000>0?oooa800000303oool5000003H0
oooo00<0P8200000000000000P00000=0?ooo`H0000000<0P8200?ooo`3oool0[@3oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000000?0?ooo`h0000000<0P8200?ooo`3oool0
A`3oool01020P800000000000010@40?0?ooo`80P8201@0000000`20P800oooo0?ooo`2[0?ooo`00
@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000l0oooo00<0P820000000000000
3@0000180?ooo`<0000000<0P8200?ooo`3oool0403oool700000:/0oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``000003`3oool00`30`<0000000000000800000080oooo00@0
@410000000000000@410A`3oool3000000030<30`03oool0oooo0180oooo00<0P820000000000000
0P0000000`10@400P8200?ooo`2X0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<00000140oooo2@0000030?ooo`@00000AP3oool3000001L0oooo00<0P8200000000000000`00
002X0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000140oooo2@000004
0?ooo`<0000000<0P8200?ooo`3oool0@P3oool4000001T0oooo1@00002W0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<00000180oooo200000050?ooo`<0000000<0P8200?oo
o`3oool0@@3oool3000001/0oooo00<0`<300000000000000P0000000`10@400P8200?ooo`2S0?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000180oooo00<0P82000000000
0000100000000`20P800oooo0?ooo`030?ooo`030820P0000000000000800000@P3oool3000001d0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2Q0?ooo`00@`3oool00`20P8000000
0000000:00000?l0ooooE03oool<00000180oooo00<0P820000000000000100000000`20P800oooo
0?ooo`040?ooo`@0000000<0P8200?ooo`3oool0?`3oool3000001h0oooo1P00002R0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<000001<0oooo1P0000000`20P800oooo0?oo
o`050?ooo`050410@0000000000000000020P800@03oool300000200oooo00<0@410000000000000
0P0000000`10@400oooo0?ooo`2N0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<000001@0oooo1@0000000`20P800oooo0?ooo`060?ooo`@0000000<0P8200?ooo`3oool0?03o
ool01020P800000000000000000Q0?ooo`L00000WP3oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo3000000D0?ooo`030410@000000000000080000000<0P8200?ooo`3oool01`3o
ool01020P800000000000010@40n0?ooo`030820P0000000000002<0oooo00<0`<30000000000000
0`0000000`10@400P8200?ooo`2K0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<000001D0oooo100000000`20P800oooo0?ooo`080?ooo`040820P00000000000000003d0oooo
00<0P8200000000000009P3oool5000000030820P03oool0oooo09T0oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``000005@3oool4000000030820P03oool0oooo00P0oooo00<0
P8200000000000000P00000l0?ooo`030820P0000000000002H0oooo00<0P8200000000000000`00
002K0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000001H0oooo0`000000
0`20P800oooo0?ooo`090?ooo`050820P0000000000000000010@400>`3oool00`20P80000000000
000W0?ooo`80P820100000000`20P800`<300?ooo`2G0?ooo`00@`3oool00`20P80000000000000:
00000?l0ooooE03oool<000001L0oooo0`00000<0?ooo`030820P0000000000000800000>P3oool0
0`20P80000000000000Y0?ooo`030820P0000000000000<00000V03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000000G0?ooo`030410@0000000000000d0oooo00D0P8200000
0000000000000410@00i0?ooo`030820P0000000000002/0oooo00<0@4100000000000000P000000
0`30`<00oooo0?ooo`2D0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
01L0oooo00<0P8200000000000003`3oool4000003P0oooo00<0P820000000000000;03oool60000
09D0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000603oool2000000l0
oooo00<0P8200000000000000P00000g0?ooo`80000000<0P8200?ooo`3oool0;03oool5000006T0
oooo1P00000U0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000001T0oooo
00<000000?ooo`3oool03P3oool01@20P8000000000000000000@41003H0oooo0P0000000`20P800
oooo0?ooo`0/0?ooo`030<30`020P80000000080000000<0@4100820P03oool0H`3oool01@20P800
0000000000000000@41000<0P8200`0000000`20P800`<300?ooo`0P0?ooo`00@`3oool00`20P800
00000000000:00000?l0ooooE03oool<000001T0oooo00<0P8200?ooo`3oool03`3oool00`20P800
000000000002000003D0oooo0P0000000`20P800oooo0?ooo`0^0?ooo`030820P0000000000000<0
0000HP3oool01020P80000000000000000070?ooo`@00000803oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo3000000I0?ooo`030820P0000000oooo0100oooo1@00000d0?ooo`80
000000<0P8200?ooo`3oool0;`3oool5000000030820P03oool0oooo05l0oooo0`0000000`20P800
oooo0?ooo`060?ooo`@000007`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000000J0?ooo`030000003oool0oooo0100oooo00D0P82000000000000000000410@00c0?ooo`80
000000<0P8200?ooo`3oool0<@3oool00`10@400000000000002000000030<30`03oool0oooo05/0
oooo00<0`<300000000000000P00000:0?ooo`050410@0000000000000000020P8007@3oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000^0?ooo`030820P000000000000080
0000<P3oool2000000030820P03oool0oooo0380oooo1@00001M0?ooo`030820P000000000000080
00002P3oool00`20P800000000000002000000030820P03oool0oooo01X0oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000;`3oool01@20P8000000000000000000@4100340
oooo0P0000000`20P800oooo0?ooo`0R0?ooo`D0P82000<0`<300?ooo`3oool02P3oool00`10@400
000000000002000000030<30`03oool0oooo03d0oooo1@20P80F0?ooo`040410@000000000000000
00`0oooo00<0P8200000000000000P00000L0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000340oooo1000000`0?ooo`80000000<0P8200?ooo`3oool08P3oool500000003
0820P03oool0oooo00/0oooo1@00000o0?ooo`D000005P3oool4000000d0oooo1@00000K0?ooo`00
@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000340oooo00<0P820000000000000
0P00000^0?ooo`<0000000<0P8200?ooo`3oool08P3oool5000000030820P03oool0oooo00`0oooo
1@00000n0?ooo`D000005P3oool4000000h0oooo1@00000J0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000380oooo00H0P82000000000000000000410@020P80/0?ooo`<0
00009@3oool00`20P800000000000002000000030410@03oool0oooo00d0oooo00D0P82000000000
000000000410@00m0?ooo`030820P000000000000080000000<0P8200?ooo`3oool04`3oool40000
00h0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0G0?ooo`00@`3oool00`20P800
00000000000:00000?l0ooooE03oool<000003<0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0Y0?ooo`<000009P3oool500000140oooo1@00000l0?ooo`D000005@3oool5000000h0
oooo100000000`20P800oooo0?ooo`0G0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<000003@0oooo00<0P8200000000000000P0000020820P2T0oooo0`00000V0?ooo`D00000
4P3oool01@20P8000000000000000000@41003/0oooo1@00000E0?ooo`D000003P3oool5000001T0
oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000=P3oool00`20P8000000
00000002000000030820P03oool0oooo02H0oooo0`00000V0?ooo`D000004`3oool00`20P8000000
00000002000003X0oooo1@00000E0?ooo`030820P00000000000008000003`3oool5000001P0oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000=`3oool5000002L0oooo1000
000W0?ooo`D000004`3oool5000003T0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0B0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0303oool5000001P0oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000>03oool00`10@400000000000003
000000030<30`03oool0oooo0280oooo0`00000X0?ooo`D000005@3oool01@10@400000000000010
@400P82003L0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0B0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool0303oool00`20P800000000000002000001P0oooo0013
0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000>@3oool6000002@0oooo0`00000X
0?ooo`D000005P3oool4000000030820P03oool0oooo03@0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`0C0?ooo`D000003P3oool00`20P800000000000003000001L0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``00000>`3oool5000000030820P03oool0oooo
0200oooo0`00000X0?ooo`D000005`3oool5000003D0oooo00<0P8200000000000000P0000000`20
P800oooo0?ooo`0C0?ooo`D000003P3oool00`20P800000000000003000001L0oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000>`3oool00`30`<0000000000000300000080
P8207`3oool01020P800000000000010@40X0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool05@3oool01@20P8000000000000000000P82003D0oooo1@00000F0?ooo`@0000000<0P820
0?ooo`3oool02`3oool00`30`<00000000000003000001L0oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000?P3oool5000000030820P03oool0oooo01`0oooo00@0P8200000
00000000P820:03oool00`20P800000000000002000000030820P03oool0oooo01L0oooo00<00000
0?ooo`3oool0=@3oool5000001H0oooo00<0P8200000000000000P00000>0?ooo`D000005`3oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000n0?ooo`030<30`020P8000000
00@0000000<0`<300?ooo`3oool06P3oool3000000030<30`03oool0oooo02H0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`1?0?ooo`D000005P3oool00`30`<000000000000020000
00030410@03oool0oooo00/0oooo1@00000G0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<00000400oooo00<0P8200000000000001000000K0?ooo`<00000:P3oool500000580
oooo1@00000G0?ooo`@000003@3oool5000001L0oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000@P3oool6000001T0oooo1000000Z0?ooo`D00000DP3oool5000001P0oooo
1000000<0?ooo`@00000603oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00130?ooo`030820P0000000000000<000000P20P80F0?ooo`<0000000<0P8200?ooo`3oool08`3o
ool30820P0T0000000<0@4100820P020P800B03oool30820P0T000000`20P80C0?ooo`030<30`000
00000000008000002P3oool00`20P800000000000002000001P0oooo00130?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``00000A@3oool8000001<0oooo0`00000V0?ooo`030820P0000000
000000l00000A@3ooolA000000030820P03oool0oooo0140oooo0`0000000`20P800oooo0?ooo`07
0?ooo`040820P00000000000000001T0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000AP3oool20820P0H000000P20P80?0?ooo`040410@000000000000410@2@0oooo00<0
P8200000000000000`0000000`20P800`<300?ooo`05000000030?ooo`30`<00P82000@000000P20
P8100?ooo`030820P0000000000000<0000000<0P8200?ooo`20P800100000001020P800oooo0820
P010@404000000030820P03oool0oooo00l0oooo00<0`<300820P00000000P0000000`20P800oooo
0?ooo`040?ooo`050820P0000000000000000030`<006@3oool004<0oooo00<0P820000000000000
2P00003o0?oooe@0oooo300000190?ooo`T00000303oool4000000030820P03oool0oooo0240oooo
00<0P8200000000000000`0000040?ooo`D00000103oool5000000030820P03oool0oooo03`0oooo
1P0000030?ooo`030820P000000000000080000000<0P8200?ooo`3oool00P3oool5000001<0oooo
100000040?ooo`040820P00000000000000001/0oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000B`3oool00`20P800000000000006000000P0oooo1P00000T0?ooo`D00000
00<0P8200?ooo`3oool00P3oool5000000D0oooo1@00000m0?ooo`030820P0000000000000<00000
103oool00`20P800000000000002000000030820P03oool0oooo00<0oooo1@00000D0?ooo`T00000
703oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000001=0?ooo`030820P000
0000000000H000001020P806000000030820P03oool0oooo0280oooo00<0P8200000000000000`00
00000`30`<00oooo0?ooo`030?ooo`@0000000<0P8200?ooo`3oool00`3oool00`10@40000000000
0002000000030<30`03oool0oooo03T0oooo00<0@4100000000000000P0000000`10@400oooo0?oo
o`030?ooo`@0000000<0@4100?ooo`3oool00`3oool00`30`<00000000000002000000030410@03o
ool0oooo01<0oooo1@20P80N0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<
00000500oooo00<0P820000000000000300000000`20P800oooo0?ooo`0R0?ooo`030820P0000000
000000@000001P3oool5000000H0oooo1@00000j0?ooo`H0000000<0P8200?ooo`3oool00`3oool5
000000L0oooo1@00000g0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<0000
0580oooo00<0P820000000000000200000000`20P800oooo0?ooo`0T0?ooo`030820P00000000000
00@000001P3oool5000000H0oooo1P00000i0?ooo`H0000000<0P8200?ooo`3oool00`3oool50000
00L0oooo1@0000000`20P800oooo0?ooo`0d0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<000005D0oooo1P20P80Y0?ooo`030410@0000000000000<000001`3oool00`10@400
000000000002000000L0oooo00<0P8200000000000000`00000g0?ooo`030820P0000000000000@0
00001P3oool00`20P800000000000002000000L0oooo00<0`<300000000000000`00000f0?ooo`00
@`3oool00`20P80000000000000:00000?l0ooooE03oool<000008@0oooo1P0000070?ooo`030820
P0000000000000800000203oool5000000030820P03oool0oooo03@0oooo1`0000070?ooo`@00000
203oool6000003D0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000Q03o
ool6000000L0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`050?ooo`030820P000
0000000000<00000=P3oool7000000L0oooo1@0000080?ooo`H00000=03oool004<0oooo00<0P820
0000000000002P00003o0?oooe@0oooo300000240?ooo`H00000203oool4000000030820P03oool0
oooo00H0oooo1P00000e0?ooo`L00000203oool4000000T0oooo1@0000000`20P800oooo0?ooo`0a
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000008@0oooo1P0000080?oo
o`@0000000<0P8200?ooo`3oool01P3oool6000003D0oooo1`0000080?ooo`@000002@3oool50000
00030820P03oool0oooo0340oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``0
0000Q03oool6000000P0oooo100000000`20P800oooo0?ooo`060?ooo`030820P0000000000000<0
000000<0`<300?ooo`3oool0<P3oool7000000P0oooo100000090?ooo`030410@000000000000080
000000<0@4100?ooo`3oool0<@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo
300000240?ooo`H000002@3oool4000000T0oooo1@0000000`20P800oooo0?ooo`0b0?ooo`L00000
203oool00`20P800000000000002000000P0oooo00<0P8200000000000000`00000c0?ooo`00@`3o
ool00`20P80000000000000:00000?l0ooooE03oool<000008@0oooo00<0@4100000000000000`00
00000`20P800oooo0?ooo`060?ooo`@000002@3oool5000000030820P03oool0oooo0380oooo00<0
P820000000000000100000000`30`<00oooo0?ooo`050?ooo`030820P0000000000000800000203o
ool00`20P800000000000003000003<0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000Q03oool00`20P800000000000004000000P0oooo100000090?ooo`030820P0000000
000000<000001@3oool00`20P80000000000000S000000X0oooo1P0000000`20P800oooo0?ooo`05
0?ooo`030820P00000000000008000002@3oool600000380oooo00130?ooo`030820P00000000000
00X00000o`3ooomD0?ooo``00000Q03oool00`20P800000000000004000000P0oooo100000090?oo
o`030820P0000000000000<000001@3oool00`20P80000000000000S000000X0oooo1P0000000`20
P800oooo0?ooo`050?ooo`030820P00000000000008000002@3oool600000380oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000Q03oool00`30`<00000000000004000000P0
oooo00<0P8200000000000000P0000080?ooo`030820P0000000000000<000001@3oool00`30`<00
P8200820P00S0820P0X0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`060?ooo`@0
000000<0P8200?ooo`3oool01P3oool600000380oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000Q@3oool6000000030820P03oool0oooo00D0oooo00<0P820000000000000
0P0000080?ooo`030820P0000000000000<00000=P3oool6000000P0oooo100000000`20P800oooo
0?ooo`060?ooo`H00000<P3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00250?ooo`H0000000<0P8200?ooo`3oool01@3oool00`20P800000000000002000000P0oooo00<0
P8200000000000000`00000f0?ooo`H00000203oool4000000030820P03oool0oooo00H0oooo1P00
000b0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000008H0oooo1@000000
0`10@400oooo0?ooo`060?ooo`@00000203oool00`20P800000000000003000003H0oooo00<0P820
0000000000000`0000000`20P800oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool01P3oool6
00000380oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000QP3oool00`20
P800000000000003000000P0oooo100000000`20P800oooo0?ooo`050?ooo`030820P00000000000
00<00000=`3oool6000000P0oooo100000080?ooo`H00000<P3oool004<0oooo00<0P82000000000
00002P00003o0?oooe@0oooo300000260?ooo`030<30`0000000000000@000001`3oool400000003
0820P03oool0oooo00D0oooo00<0P8200000000000000`00000g0?ooo`030820P0000000000000@0
00001`3oool4000000P0oooo1P00000b0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<000008L0oooo1`0000070?ooo`<0000000<0P8200?ooo`3oool01@3oool00`20P8000000
00000002000000030820P03oool0oooo03H0oooo1P0000000`20P800oooo0?ooo`040?ooo`040820
P00000000000000000P0oooo1@00000c0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<000008P0oooo1P0000000`20P800oooo0?ooo`040?ooo`<0000000<0P8200?ooo`3oool0
1@3oool5000000030820P03oool0oooo03L0oooo1P0000060?ooo`040820P00000000000000000L0
oooo00<0P8200000000000000`00000c0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<000008T0oooo00<0@4100000000000000P0000000`10@400oooo0?ooo`040?ooo`<00000
00<0@4100?ooo`3oool0103oool00`20P800000000000003000000030<30`03oool0oooo03L0oooo
00<0`<300000000000000`0000000`20P800oooo0?ooo`030?ooo`050820P0000000000000000020
P8001P3oool00`10@400000000000002000000030410@03oool0oooo0340oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000RP3oool6000000H0oooo0`0000060?ooo`H00000
1P3oool00`20P80000000000000S00000100oooo1@0000000`20P800oooo0?ooo`030?ooo`@00000
1P3oool5000000030820P03oool0oooo0340oooo00130?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``00000R`3oool00`10@400000000000003000000030<30`03oool0oooo0080oooo0`00
00050?ooo`030410@000000000000080000000<0@4100?ooo`3oool01@3oool00`20P80000000000
000S00000100oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`020?ooo`@00000103o
ool00`20P800000000000003000000030820P03oool0oooo0380oooo00130?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``00000S03oool7000000<0oooo0`0000040?ooo`H00000@03oool6
000000030820P03oool0oooo00@000000`3oool00`20P800000000000003000003H0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``00000SP3oool600000080oooo0`0000020?oo
o`030820P0000000000000@00000@P3oool00`20P800000000000004000000030?ooo`0000000000
008000000P3oool6000000030820P03oool0oooo03@0oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000S`3oool20820P0l0000000<0P8200?ooo`3oool0@`3oool00`20P800
00000000000=000000030410@020P800oooo03H0oooo00130?ooo`030820P0000000000000X00000
o`3ooomD0?ooo``00000T`3oool00`20P800000000000007000004d0oooo2@0000000`20P800oooo
0?ooo`0i0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000009H0oooo00@0
P8200000000000000000D`3oool4000003h0oooo00130?ooo`030820P0000000000000X00000o`3o
oomD0?ooo``00000U`3oool3000000030820P03oool0oooo0540oooo0`0000000`30`<00oooo0?oo
o`0k0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000009L0oooo1000001C
0?ooo`<0000000<0P8200?ooo`3oool0>`3oool004<0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000002G0?ooo`@00000D`3oool3000000030820P03oool0oooo03/0oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``00000V03oool3000005<0oooo00@0P82000000000
0000P820?@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000002H0?ooo`<0
0000D`3oool01020P800000000000020P80m0?ooo`00@`3oool00`20P80000000000000:00000?l0
ooooE03oool<000009P0oooo0`0000000`20P800oooo0?ooo`1@0?ooo`040820P000000000000000
03d0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000V03oool01020P800
000000000020P81C0?ooo`<00000?@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0
oooo3000002H0?ooo`040820P000000000000820P5<0oooo0`00000m0?ooo`00@`3oool00`20P800
00000000000:00000?l0ooooE03oool<000009P0oooo00@0P820000000000000P820D`3oool30000
03d0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000V@3oool3000005@0
oooo0`00000l0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000009T0oooo
0`00001D0?ooo`<00000?03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
002I0?ooo`<00000E03oool3000003`0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``00000V@3oool3000005@0oooo0`00000l0?ooo`00@`3oool00`20P80000000000000:0000
0?l0ooooE03oool<000009X0oooo0`20P81D0?ooo`80P82000<0`<300?ooo`3oool0>@3oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3o
oooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?oo
o`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X0
0000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo
00130?ooo`030820P0000000000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000
000000X00000o`3ooooo0?oooi00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``0P820o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820
P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000
000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?oo
o``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0
oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo
00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0oooo00<0P8200000
000000002P00003o0?oooe@0oooo3000003o0?oooc00oooo00130?ooo`030820P0000000000000X0
0000o`3ooomD0?ooo``00000o`3oool`0?ooo`00@`3oool00`20P80000000000000:00000?l0oooo
E03oool<00000?l0oooo<03oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
003o0?oooc00oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000o`3oool`
0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<00000?l0oooo<03oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000020?ooo`030820P03oool0oooo0?l0
oooo:`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo300000020?ooo`030820
P000000000000?l0oooo:`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
00020?ooo`040820P0000000000000000?l0oooo:P3oool004<0oooo00<0P8200000000000002P00
003o0?oooe@0oooo300000030?ooo`@0000000<0P8200?ooo`3oool0o`3ooolV0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000@0oooo1P00003o0?ooobH0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``00000103oool700000?l0oooo9@3oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo300000050?ooo`L0000000<0@4100820P03o
ool0o`3ooolQ0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000D0oooo
00<0P8200000000000001`0000000`20P800oooo0?ooo`3o0?oooah0oooo00130?ooo`030820P000
0000000000X00000o`3ooomD0?ooo``000001@3oool00`30`<0000000000000800000080P820o`3o
oolN0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000H0oooo3@00003o
0?oooad0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000001`3oool=0000
00030820P03oool0oooo0?l0oooo6@3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0
oooo300000070?ooo`030410@0000000000000`0000000<0P8200<30`03oool0o`3ooolG0?ooo`00
@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000L0oooo00<0P820000000000000
3`00003o0?oooaL0oooo00130?ooo`030820P0000000000000X00000o`3ooomD0?ooo``00000203o
oolB000000030820P03oool0oooo0?l0oooo4`3oool004<0oooo00<0P8200000000000002P00003o
0?oooe@0oooo300000090?oooa<0000000<0P8200?ooo`3oool0o`3ooolA0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<000000T0oooo5@00003o0?oooa80oooo00130?ooo`03
0820P0000000000000X00000o`3ooomD0?ooo``000002P3ooolE000000030410@020P800oooo0?l0
oooo3P3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000:0?ooo`030820
P0000000000001D00000o`3oool>0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03o
ool<000000X0oooo00<0P8200000000000005`00003o0?ooo``0oooo00130?ooo`030820P0000000
000000X00000o`3ooomD0?ooo``000002`3ooolI000000030410@020P800oooo0?l0oooo2@3oool0
04<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000<0?oooa/00000o`3oool90?oo
o`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000`0oooo00<0@41000000000
00006P0000000`20P800oooo0?ooo`0o0?ooo`030820P0000000000000L000000P20P8000`30`<00
oooo0?ooo`2e0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooE03oool<000000`0oooo
00<0P820000000000000700000000`20P800oooo0?ooo`0l0?ooo`030820P0000000000000`00000
00<0P8200?ooo`3oool0/`3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
000=0?ooob000000?@3ooolB00000;<0oooo00130?ooo`030820P0000000000000X00000o`3ooomD
0?ooo``000003@3oool00`20P80000000000000N000000030820P03oool0oooo03L0oooo00D0P820
00000000000000000410@0070?ooo`030<30`020P800000000H000000P20P82`0?ooo`00@`3oool0
0`20P80000000000000:00000?l0ooooE03oool<000000h0oooo4P00000<0?ooo`D00000=P3oool0
0`20P800000000000002000000d0oooo1P0000000`20P800oooo0?ooo`2]0?ooo`00@`3oool00`20
P80000000000000:00000?l0ooooE03oool<000000l0oooo3`0000000`20P800oooo0?ooo`160?oo
o`040820P000000000000410@0l0oooo0P20P805000000030820P03oool0oooo0:/0oooo00130?oo
o`030820P0000000000000X00000o`3ooomD0?ooo``000003`3oool00`20P80000000000000=0000
00030820P03oool0oooo04D0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`L00000Z`3oool004<0
oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000?0?ooo`030820P0000000000000P0
00000P3oool4000004L0oooo0`00000E0?ooo`D0000000<0P8200?ooo`3oool0Z03oool004<0oooo
00<0P8200000000000002P00003o0?oooe@0oooo3000000@0?ooo`030820P0000000000000L00000
0P3oool00`30`<00000000000002000004H0oooo0`00000F0?ooo`030820P010@400000000<00000
00<0P8200?ooo`3oool0YP3oool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000
000A0?ooo`T00000103oool3000000030820P03oool0oooo0480oooo1000000I0?ooo`D00000Y`3o
ool004<0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000B0?ooo`P000001@3oool3
000004@0oooo0`00000K0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0X`3oool0
01/0oooo1P20P80R0?ooo`030820P0000000000000X00000o`3ooomD0?ooo``000004P3oool00`10
@400000000000004000000030410@03oool0oooo00<0oooo00D0@41000000000000000000820P012
0?ooo`<00000703oool00`20P800@41000000003000000030<30`03oool0oooo0:40oooo000I0?oo
o`X00000803oool00`20P80000000000000:00000?l0ooooE03oool<00000180oooo00<0P8200000
00000000100000000`20P800oooo0?ooo`040?ooo`@0000000<0P8200?ooo`3oool0?`3oool30000
01h0oooo1P00002R0?ooo`005P3oool01P20P800@410000000000000@4100820P0@0oooo0P20P803
000000030820P03oool0oooo01/0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000C
0?ooo`H0000000<0P8200?ooo`3oool01@3oool01@10@4000000000000000000P8200400oooo0`00
000P0?ooo`030410@000000000000080000000<0@4100?ooo`3oool0WP3oool001@0oooo00<0P820
0000000000000P00000;0?ooo`<0000000<0P8200?ooo`3oool06@3oool00`20P80000000000000:
00000?l0ooooE03oool<000001@0oooo1@0000000`20P800oooo0?ooo`060?ooo`@0000000<0P820
0?ooo`3oool0?03oool00`20P80000000000000R0?ooo`L00000WP3oool001@0oooo1000000<0?oo
o`040820P00000000000000001/0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000D
0?ooo`D0000000<0P8200?ooo`3oool01`3oool3000000030820P03oool0oooo03`0oooo00<0P820
0000000000008`3oool00`20P800000000000003000000030820P03oool0oooo09/0oooo000C0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool02P3oool01@20P8000000000000000000
@41001T0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000D0?ooo`030<30`0000000
00000080000000<0P8200?ooo`3oool0203oool01010@400000000000020P80m0?ooo`030820P000
0000000002@0oooo0P20P805000000030<30`03oool0oooo09T0oooo000D0?ooo`D000003P3oool4
000001P0oooo00<0P8200000000000002P00003o0?oooe@0oooo3000000E0?ooo`@0000000<0P820
0?ooo`3oool0203oool00`20P800000000000002000003`0oooo00<0P8200000000000009P3oool0
0`20P800000000000004000009X0oooo000D0?ooo`030410@000000000000080000000<0P8200?oo
o`3oool02`3oool00`30`<00000000000002000001L0oooo00<0P8200000000000002P00003o0?oo
oe@0oooo3000000F0?ooo`<0000000<0P8200?ooo`3oool02@3oool01@20P8000000000000000000
@41003/0oooo00<0P8200000000000009`3oool20820P0D0000000<0`<300?ooo`3oool0UP3oool0
01@0oooo00<0P8200000000000000`00000>0?ooo`@0000000<0P8200?ooo`3oool0503oool00`20
P80000000000000:00000?l0ooooE03oool<000001L0oooo0`00000<0?ooo`030820P00000000000
00800000>P3oool00`20P80000000000000Y0?ooo`030820P0000000000000@00000U`3oool001@0
oooo00<0P8200000000000000`00000?0?ooo`@000005P3oool00`20P80000000000000:00000?l0
ooooE03oool<000001L0oooo0`00000=0?ooo`@0000000<0P8200?ooo`3oool0=`3oool00`20P800
00000000000[0?ooo`D0000000<0P8200?ooo`3oool0U03oool001@0oooo00<0`<30000000000000
0`0000000`30`<00oooo0?ooo`0<0?ooo`030410@00000000000008000005@3oool00`20P8000000
0000000:00000?l0ooooE03oool<000001L0oooo00<0P8200000000000003P3oool01@20P8000000
000000000000P82003P0oooo00<0P820000000000000:`3oool00`30`<0000000000000400000003
0820P03oool0oooo0980oooo000E0?ooo`D0000000<0P8200?ooo`3oool0303oool00`20P8000000
00000002000000030820P03oool0oooo0180oooo00<0P8200000000000002P00003o0?oooe@0oooo
3000000H0?ooo`8000003`3oool00`20P800000000000002000003L0oooo0P0000000`20P800oooo
0?ooo`0/0?ooo`D0000000<0P8200?ooo`3oool0T@3oool001D0oooo1@0000000`20P800oooo0?oo
o`0=0?ooo`D00000503oool00`20P80000000000000:00000?l0ooooE03oool<000001T0oooo00<0
00000?ooo`3oool03P3oool4000000030820P03oool0oooo03@0oooo0P0000000`20P800oooo0?oo
o`0/0?ooo`030820P0000000000000<00000T`3oool001H0oooo1@00000?0?ooo`D0000000<0P820
0?ooo`3oool04@3oool00`20P80000000000000:00000?l0ooooE03oool<000001T0oooo00<0@410
0?ooo`3oool03`3oool01@10@4000000000000000000P82003D0oooo0P0000000`20P800oooo0?oo
o`0^0?ooo`030410@0000000000000<0000000<0`<300?ooo`3oool0SP3oool001H0oooo1@00000@
0?ooo`D000004`3oool00`20P80000000000003o000006X000006@3oool00`20P80000000?ooo`0@
0?ooo`D00000=03oool2000000030820P03oool0oooo02l0oooo1P00002@0?ooo`005P3oool00`20
P800000000000002000000030820P03oool0oooo00d0oooo1@0000000`20P800oooo0?ooo`0@0?oo
o`030820P000000000000?l00000JP00000J0?ooo`030000003oool0oooo0100oooo00D0P8200000
0000000000000410@00c0?ooo`80000000<0P8200?ooo`3oool0<@3oool00`10@400000000000002
000000030<30`03oool0oooo08`0oooo000G0?ooo`D00000403oool500000180oooo00<0P8200000
00000000o`00001Z000002h0oooo00<0P8200000000000000P00000b0?ooo`80000000<0P8200?oo
o`3oool0<P3oool6000008d0oooo000G0?ooo`D00000403oool5000000030820P03oool0oooo00l0
oooo00<0P820000000000000o`00001Z000002l0oooo100000000`20P800oooo0?ooo`0_0?ooo`80
000000<0P8200?ooo`3oool0=03oool5000008`0oooo000G0?ooo`030820P0000000000000800000
00<0P8200?ooo`3oool03@3oool5000000030820P03oool0oooo00l0oooo00<0P820000000000000
o`00001Z00000300oooo00D0P82000000000000000000820P00`0?ooo`80000000<0P8200?ooo`3o
ool08P3oool5000000030820P03oool0oooo00X0oooo00<0`<300000000000000P0000000`10@400
oooo0?ooo`290?ooo`005`3oool00`20P800000000000002000000030820P03oool0oooo00d0oooo
1@0000000`20P800oooo0?ooo`0?0?ooo`030820P000000000000?l00000JP00000a0?ooo`030820
P0000000000000800000;P3oool3000000030820P03oool0oooo0280oooo1@0000000`20P800oooo
0?ooo`0<0?ooo`D00000RP3oool001L0oooo00<0P8200000000000000`00000?0?ooo`H000004@3o
ool00`20P80000000000003o000006X00000<P3oool4000000030820P03oool0oooo02/0oooo0`00
000U0?ooo`D0000000<0P8200?ooo`3oool03@3oool4000000030820P03oool0oooo08L0oooo000H
0?ooo`D000003`3oool600000140oooo00<0P820000000000000o`00001Z000003<0oooo00<0@410
0000000000000P0000000`30`<00oooo0?ooo`0Y0?ooo`<000009P3oool500000100oooo00@0P820
00000000000000000P20P8270?ooo`00603oool6000000h0oooo00<0P8200000000000000`00000A
0?ooo`030820P000000000000?l00000JP00000d0?ooo`D00000:`3oool3000002H0oooo1@00000B
0?ooo`@0000000<0P8200?ooo`3oool0Q03oool001T0oooo1@0000000`20P800oooo0?ooo`0;0?oo
o`H000004@3oool00`20P80000000000003o000006X00000=@3oool00`20P800@410000000030000
00030<30`03oool0oooo02H0oooo0`00000V0?ooo`D000004`3oool01@10@4000000000000000000
P82008D0oooo000I0?ooo`H000003@3oool600000140oooo00<0P820000000000000o`00001Z0000
03L0oooo1@00000W0?ooo`@000009`3oool5000001<0oooo1@0000240?ooo`006@3oool600000003
0820P03oool0oooo00X0oooo1P00000A0?ooo`030820P000000000000?l00000JP00000h0?ooo`H0
00009@3oool3000002P0oooo1@00000E0?ooo`<0000000<0P8200?ooo`3oool0P@3oool001X0oooo
1P0000000`20P800oooo0?ooo`080?ooo`030820P0000000000000@000004@3oool00`30`<00P820
0820P0020820P0040410@000000000000410@?l0P820I020P80h0?ooo`030<30`0000000000000<0
000000<0@4100?ooo`3oool08P3oool3000002P0oooo1@00000E0?ooo`030<30`000000000000080
000000<0`<300?ooo`3oool0O`3oool001X0oooo1@0000000`20P80000000820P0080?ooo`L00000
00<0P8200?ooo`3oool0503oool01020P800000000000020P83o0?oooil0oooo1@0000000`20P800
oooo0?ooo`0P0?ooo`<00000:03oool5000001L0oooo1@0000200?ooo`006P3oool00`20P8000000
0000000200000080P8200P0000000`20P800`<300?ooo`030?ooo`030410@0000000000000D00000
00<0P8200?ooo`3oool0503oool01020P800000000000020P83o0?oooil0oooo00<0`<3000000000
00000`0000020820P1l0oooo00@0P820000000000000@410:03oool00`20P8000000000000020000
00030820P03oool0oooo01D0oooo00D0P82000000000000000000820P01o0?ooo`006P3oool00`20
P800000000000002000000030820P03oool0P82000l000005`3oool01020P800000000000020P83o
0?oooj80oooo1@0000000`20P800oooo0?ooo`0L0?ooo`040820P000000000000820P2P0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`0G0?ooo`030000003oool0oooo07l0oooo000J
0?ooo`030820P0000000000000<000000P3oool>000001P0oooo00@0P820000000000000P820o`3o
oonS0?ooo`H000007@3oool3000000030820P03oool0oooo02H0oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`2I0?ooo`006`3oool5000000<0oooo00<0P82000000000000020000000
0`10@400P8200?ooo`0G0?ooo`040820P000000000000820P?l0ooooY03oool00`20P80000000000
0002000000030410@020P800oooo01X0oooo0`00000Y0?ooo`030<30`000000000000080000000<0
@4100?ooo`3oool0V@3oool001/0oooo1@0000050?ooo`T000006P3oool01020P800000000000020
P83o0?ooojL0oooo1@00000I0?ooo`@00000:P3oool500000500oooo00<0P8200000000000000P00
00000`20P800oooo0?ooo`130?ooo`00703oool5000000H0oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`0I0?ooo`040820P000000000000820P?l0ooooZ03oool5000001P0oooo1000
000X0?ooo`T0000000<0P8200?ooo`3oool0B@3oool9000000030820P03oool0oooo0440oooo000L
0?ooo`D000009`3oool01020P800000000000020P83o0?ooojT0oooo00<0P8200000000000000`00
00020820P1<0oooo00@0P820000000000000P8209@3oool00`30`<0000000000000=00000080P820
A@3oool00`20P800@41000000002000000@0P820100000000`20P800oooo0?ooo`0o0?ooo`00703o
ool5000000030820P03oool0oooo02@0oooo00@0P820000000000000P820o`3ooonZ0?ooo`P00000
4@3oool01020P800000000000000000U0?ooo`H0000000<0P8200?ooo`000000100000000`3oool0
P82000000004000004<0oooo00<0P8200000000000000P0000060?ooo`@0000000<0P8200?ooo`3o
ool0?P3oool001`0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0T0?ooo`040820
P000000000000820P?l0oooo[03oool00`20P80000000000000500000080P820303oool01@20P800
0000000000000000P82002<0oooo00<0`<300000000000000`0000001020P800oooo0?ooo`3oool5
000000<0oooo00<0P8200000000000000`0000000`30`<00oooo0?ooo`0m0?ooo`050820P0000000
000000000020P800203oool00`10@400000000000002000000030820P03oool0oooo03`0oooo000L
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0903oool01020P800000000000020
P83o0?ooojl0oooo00<0P8200000000000001P0000080?ooo`H00000903oool5000000030820P03o
ool0oooo0080oooo1@0000050?ooo`D00000?`3oool4000000X0oooo1@00000n0?ooo`007@3oool5
000002H0oooo00@0P820000000000000P820o`3ooona0?ooo`T00000103oool7000002D0oooo1@00
00000`20P800oooo0?ooo`030?ooo`@000001P3oool5000003d0oooo100000000`20P800oooo0?oo
o`090?ooo`@0000000<0P8200?ooo`3oool0>`3oool001d0oooo1@00000V0?ooo`040820P0000000
00000820P?l0oooo/P3oool20820P0030410@0000000000000`0000000<0P8200?ooo`3oool08P3o
ool00`30`<00000000000004000000H0oooo1@0000050?ooo`030<30`000000000000080000000<0
@4100?ooo`3oool0>@3oool00`20P800000000000002000000030<30`03oool0oooo00T0oooo00<0
P8200000000000000P00000m0?ooo`007@3oool6000002D0oooo00@0P820000000000000P820o`3o
oonf0?ooo`030820P0000000000000P0000000<0P8200?ooo`3oool0903oool00`20P80000000000
0004000000H0oooo1@0000060?ooo`H00000>P3oool5000000d0oooo1@00000l0?ooo`007P3oool5
000002D0oooo00@0P820000000000000P820o`3oooni0?ooo`H0P820:@3oool00`10@40000000000
0003000000L0oooo00<0@4100000000000000P0000070?ooo`030820P0000000000000<00000>03o
ool00`20P800000000000002000000030820P03oool0oooo00/0oooo00<0@4100000000000000P00
00000`30`<00oooo0?ooo`0i0?ooo`007P3oool6000002@0oooo00@0P820000000000000P820o`3o
oooX0?ooo`H000001`3oool00`20P800000000000002000000P0oooo1@0000000`20P800oooo0?oo
o`0e0?ooo`D000003P3oool00`20P800000000000002000000030820P03oool0oooo03T0oooo000O
0?ooo`D00000903oool01020P800000000000020P83o0?ooonP0oooo1P0000070?ooo`030820P000
000000000080000000<0P8200?ooo`3oool01@3oool00`20P800000000000003000003H0oooo1P00
000>0?ooo`030820P0000000000000<00000>`3oool001l0oooo1@00000T0?ooo`040820P0000000
00000820P?l0ooooj03oool6000000L0oooo00<0`<300000000000000P0000000`20P800oooo0?oo
o`050?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0<P3oool00`30`<0000000000
0003000000030410@03oool0oooo00`0oooo00<0`<300000000000000`0000000`20P800oooo0?oo
o`0h0?ooo`007`3oool5000000030820P03oool0oooo0240oooo00@0P820000000000000P820o`3o
oooX0?ooo`H00000203oool4000000030820P03oool0oooo00H0oooo1P00000d0?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool03@3oool6000003X0oooo000O0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool08@3oool01020P800000000000020P83o0?ooonP0oooo1P00
00080?ooo`@0000000<0P8200?ooo`3oool01P3oool6000003@0oooo00<0P8200000000000000`00
00000`20P800oooo0?ooo`0=0?ooo`H00000>P3oool001l0oooo1@0000000`10@400oooo0?ooo`0Q
0?ooo`040820P000000000000820P?l0ooooj03oool6000000P0oooo00D0P8200000000000000000
0410@0090?ooo`D0000000<0P8200?ooo`3oool0<@3oool00`10@400000000000003000000030820
P03oool0oooo00d0oooo1P0000000`20P800oooo0?ooo`0g0?ooo`006P3oool;000002<0oooo00@0
P820000000000000P820o`3ooooX0?ooo`H000002@3oool4000000T0oooo1@0000000`20P800oooo
0?ooo`0a0?ooo`H0000000<0P8200?ooo`3oool03@3oool7000003T0oooo000J0?ooo`80P8202@00
000S0?ooo`040820P000000000000820P?l0ooooj03oool00`20P800000000000004000000P0oooo
100000090?ooo`030410@000000000000080000000<0@4100?ooo`3oool00`3oool00`30`<00P820
0820P00S0820P0P0oooo1P00000@0?ooo`030820P0000000000000@00000>@3oool00200oooo1P00
000R0?ooo`040820P000000000000820P?l0ooooj03oool00`20P800000000000004000000P0oooo
100000090?ooo`030820P0000000000000<000001@3oool00`20P80000000000000S000000P0oooo
1P00000A0?ooo`H00000>@3oool002@0oooo0P00000R0?ooo`040820P000000000000820P?l0oooo
j03oool00`20P800000000000004000000P0oooo00<0P8200000000000000P0000080?ooo`030820
P0000000000000<000001@3oool00`20P80000000000000S000000L0oooo1`00000A0?ooo`H00000
>@3oool004P0oooo00@0P820000000000000P820o`3ooooY0?ooo`H0000000<0`<300?ooo`3oool0
1@3oool00`20P800000000000002000000P0oooo00<0P8200000000000000`00000b0?ooo`L00000
4@3oool6000000030820P03oool0oooo03H0oooo00180?ooo`040820P000000000000820P?l0oooo
j@3oool6000000030820P03oool0oooo00D0oooo00<0P8200000000000000P0000080?ooo`030820
P0000000000000<00000<P3oool700000140oooo1P0000000`20P800oooo0?ooo`0f0?ooo`00B03o
ool01020P800000000000020P83o0?ooonX0oooo1@0000000`10@400oooo0?ooo`060?ooo`@00000
203oool00`20P80000000000000300000380oooo1`00000A0?ooo`H0000000<0P8200?ooo`3oool0
=P3oool004P0oooo00@0P820000000000000P820o`3ooooZ0?ooo`030820P0000000000000<00000
203oool4000000030820P03oool0oooo00D0oooo00<0P8200000000000000`00000b0?ooo`L00000
4@3oool6000000030820P03oool0oooo03H0oooo00180?ooo`040820P000000000000820P?l0oooo
jP3oool00`20P800000000000004000000L0oooo100000000`20P800oooo0?ooo`050?ooo`030820
P0000000000000<00000<P3oool700000140oooo1P0000000`20P800oooo0?ooo`0f0?ooo`00B03o
ool01020P800000000000020P83o0?ooon/0oooo1P0000000`20P800oooo0?ooo`040?ooo`050820
P0000000000000000020P8001`3oool00`20P800000000000002000000030410@03oool0oooo0300
oooo1`00000A0?ooo`H0000000<0P8200?ooo`3oool0=P3oool004P0oooo00@0P820000000000000
P820o`3oooo/0?ooo`H0000000<0P8200?ooo`3oool0103oool3000000030820P03oool0oooo00D0
oooo1@0000000`20P800oooo0?ooo`0`0?ooo`L000004@3oool6000000030820P03oool0oooo03H0
oooo00180?ooo`040820P000000000000820P?l0ooook@3oool5000000030820P03oool0oooo00@0
oooo0`0000000`20P800oooo0?ooo`050?ooo`D0000000<0P8200?ooo`3oool0<03oool700000140
oooo1P0000000`20P800oooo0?ooo`0f0?ooo`00B03oool01020P800000000000020P83o0?ooond0
oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`030?ooo`040820P000000000000000
00H0oooo1P0000060?ooo`030<30`020P800P82002<0P8201`3oool700000140oooo1P0000000`20
P800oooo0?ooo`0f0?ooo`00B03oool01020P800000000000020P83o0?ooonl0oooo1P0000050?oo
o`<000001@3oool00`20P800000000000003000000L0oooo00<0P8200000000000008`0000070?oo
o`L000004@3oool6000000030820P03oool0oooo03H0oooo00180?ooo`040820P000000000000820
P?l0ooook`3oool00`30`<00000000000003000000030410@020P800oooo0080oooo0`0000040?oo
o`030820P0000000000000<0000000<0`<300?ooo`3oool01@3oool00`30`<00P8200820P00S0820
P0L0oooo00<0P8200000000000001000000A0?ooo`H0000000<0P8200?ooo`3oool0=P3oool004P0
oooo00@0P820000000000000P820o`3oooob0?ooo`H000000P3oool300000080oooo00<0P8200000
000000001000000g0?ooo`H0000000<0P8200?ooo`3oool03P3oool6000003T0oooo00180?ooo`04
0820P000000000000820P?l0ooool`3ooolB000003P0oooo1P0000000`20P800oooo0?ooo`0>0?oo
o`H00000>@3oool004P0oooo00@0P820000000000000P820o`3ooooe0?ooo`80P82000<0@4100000
000000001`0000030820P3T0oooo1P0000000`20P800oooo0?ooo`0>0?ooo`H00000>@3oool004P0
oooo00@0P820000000000000P820o`3ooooj0?ooo`040820P00000000000000003l0oooo1P000000
0`20P800oooo0?ooo`0=0?ooo`L00000>@3oool004P0oooo00@0P820000000000000P820o`3ooook
0?ooo`<0000000<0P8200?ooo`3oool0?03oool00`20P800000000000003000000030820P03oool0
oooo00d0oooo1P00000j0?ooo`00B03oool01020P800000000000020P83o0?oooo/0oooo1000000n
0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool03@3oool6000003X0oooo00180?oo
o`040820P000000000000820P?l0oooon`3oool4000003l0oooo1P00000?0?ooo`H00000>P3oool0
04P0oooo00@0P820000000000000P820o`3ooook0?ooo`040820P00000000000000003l0oooo1P00
000>0?ooo`030<30`0000000000000<00000>`3oool004P0oooo00@0P820000000000000P820o`3o
oool0?ooo`<00000@03oool5000000h0oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`0i0?ooo`00B03oool01020P800000000000020P83o0?oooo`0oooo0`0000000`20P800oooo0?oo
o`0m0?ooo`D000003P3oool00`20P800000000000002000000030820P03oool0oooo03T0oooo0018
0?ooo`040820P000000000000820P?l0ooooo03oool01010@400000000000020P8100?ooo`D00000
3@3oool00`10@400000000000002000000030<30`03oool0oooo03T0oooo00180?ooo`040820P000
000000000820P?l0ooooo03oool01020P800000000000020P8100?ooo`030820P000000000000080
00003@3oool4000003d0oooo00180?ooo`040820P000000000000820P?l0ooooo03oool01020P800
000000000020P8100?ooo`030<30`000000000000080000000<0P8200?ooo`3oool02@3oool40000
00030410@03oool0oooo03/0oooo00180?ooo`040820P000000000000820P?l0ooooo@3oool30000
0480oooo1000000:0?ooo`D00000?P3oool004P0oooo00@0P820000000000000P820o`3oooom0?oo
o`<00000@`3oool4000000T0oooo1@00000n0?ooo`00B03oool01020P800000000000020P83o0?oo
ood0oooo0`0000130?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0103oool01@10
@4000000000000000000P82003l0oooo00180?ooo`040820P000000000000820P?l0ooooo@3oool3
000004D0oooo1@0000030?ooo`030820P0000000000000800000@@3oool004P0oooo00@0P8200000
00000000P820o`3oooon0?ooo`<0P820A03oool00`30`<00P82000000007000000030410@020P800
oooo0440oooo00180?ooo`040820P000000000000820P?l0ooooo`3ooom:0?ooo`D00000A@3oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P83o0?ooool0ooooU03oool0
04P0oooo00@0P820000000000000P820o`3ooooo0?oooi@0oooo00180?ooo`040820P00000000000
0820P?l0ooooo`3ooonD0?ooo`00B03oool01020P800000000000020P80F0?ooo`030820P0000000
oooo0?l0ooooo`3ooomk0?ooo`00B03oool01020P800000000000020P80F0?ooo`030820P0000000
00000?l0ooooo`3ooomk0?ooo`00B03oool01020P800000000000020P80F0?ooo`050820P0000000
000000000020P800o`3ooooo0?ooogT0oooo00180?ooo`040820P000000000000820P1H0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`3o0?ooool0ooooMP3oool004P0oooo00@0P820
000000000000P8205P3oool01020P800oooo0?ooo`20P802000000030820P03oool0oooo0?l0oooo
o`3ooome0?ooo`00B03oool01020P800000000000020P80K0?ooo`<00000o`3ooooo0?ooogH0oooo
00180?ooo`040820P000000000000820P1/0oooo00@0P820000000000000P820o`3ooooo0?ooogD0
oooo00180?ooo`040820P000000000000820P1`0oooo00@0P820000000000000P820o`3ooooo0?oo
og@0oooo00180?ooo`040820P000000000000820P1h0oooo0`00003o0?ooool0ooooL`3oool004P0
oooo00@0P820000000000000P8207P3oool01020P800000000000020P83o0?ooool0ooooLP3oool0
04P0oooo00@0P820000000000000P8207`3oool01020P800000000000020P83o0?ooool0ooooL@3o
ool004P0oooo00@0P820000000000000P8208@3oool2000000030820P03oool0oooo0?l0ooooo`3o
oom^0?ooo`00B03oool01020P800000000000020P80Q0?ooo`030<30`0000000@4100?l0ooooo`3o
oom`0?ooo`00B03oool01020P800000000000020P80R0?ooo`<00000o`3ooooo0?ooofl0oooo0018
0?ooo`040820P000000000000820P280oooo1000003o0?ooool0ooooKP3oool004P0oooo00@0P820
000000000000P8208P3oool4000000030410@03oool0oooo0?l0ooooo`3ooom[0?ooo`00B03oool0
1020P800000000000020P80R0?ooo`H00000o`3ooooo0?ooof`0oooo00180?ooo`040820P0000000
00000820P240oooo00<0P820000000000000100000000`20P800oooo0?ooo`3o0?ooool0ooooJ@3o
ool004P0oooo00@0P820000000000000P8208@3oool00`20P80000000000000500000?l0ooooo`3o
oom[0?ooo`00B03oool01020P800000000000020P80Q0?ooo`030820P0000000000000<0000000<0
oooo000000000000o`3ooooo0?ooofX0oooo00180?ooo`040820P000000000000820P240oooo00<0
P8200000000000000`0000001@3oool0P820000000000000`<300?l0ooooo`3ooomX0?ooo`00B03o
ool01020P800000000000020P80Q0?ooo`030820P0000000000000<000000P3oool2000000030820
P03oool0oooo0?l0ooooo`3ooomV0?ooo`00B03oool01020P800000000000020P80Q0?ooo`030820
P0000000000000<000000`3oool200000?l0ooooo`3ooomX0?ooo`00B03oool01020P80000000000
0020P80Q0?ooo`030820P000000000000080000000<0P8200?ooo`3oool00P3oool2000000030820
P03oool0oooo0?l0ooooo`3ooomT0?ooo`00B03oool01020P800000000000020P80Q0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool00P3oool00`20P80000000000003o0?ooool0oooo
IP3oool004P0oooo00@0P820000000000000P8208@3oool00`10@400000000000002000000030820
P03oool0oooo00<0oooo00<0P82000000010@400o`3ooooo0?ooofD0oooo00180?ooo`040820P000
000000000820P240oooo1@0000000`20P800oooo0?ooo`040?ooo`800000o`3ooooo0?ooofD0oooo
00180?ooo`040820P000000000000820P240oooo1@0000000`20P800oooo0?ooo`050?ooo`800000
o`3ooooo0?ooof@0oooo00160?ooo`80P82000@0@410000000000000@4101@20P80L0?ooo`D00000
00<0P8200?ooo`3oool01@3oool00`20P80000000820P03o0?ooool0ooooH`3oool00400oooo4`00
00000`20P800oooo0?ooo`0G0?ooo`D0000000<0P8200?ooo`3oool01P3oool200000?l0ooooo`3o
oomS0?ooo`00?P3oool00`10@40000000000000D000000030820P03oool0oooo01D0oooo1@000000
0`30`<00oooo0?ooo`070?ooo`800000o`3ooooo0?ooof80oooo000n0?ooo`030820P00000000000
01@00000603oool5000000X0oooo00<0P820000000000000o`3ooooo0?ooof40oooo000n0?ooo`03
0820P0000000000001@00000603oool5000000/0oooo0P0000000`20P800oooo0?ooo`3o0?ooool0
ooooGP3oool003h0oooo00<0`<300000000000004`0000000`20P800oooo0?ooo`0E0?ooo`030820
P0000000000000<000002`3oool00`20P80000000410@03o0?ooool0ooooH03oool003l0oooo5@00
000H0?ooo`H00000303oool200000?l0ooooo`3ooomP0?ooo`00?`3ooolE000001P0oooo1P00000=
0?ooo`800000o`3ooooo0?oooel0oooo00100?oooa<0000000<0P8200?ooo`3oool05P3oool60000
00d0oooo00<0@41000000020P800o`3ooooo0?oooeh0oooo00100?oooa<0000000<0P8200?ooo`3o
ool05P3oool6000000h0oooo00<000000820P03oool0o`3ooooo0?oooed0oooo00110?oooa800000
6@3oool6000000h0oooo0P00003o0?ooool0ooooGP3oool00440oooo4P00000I0?ooo`D000003`3o
ool200000?l0ooooo`3ooomN0?ooo`00@@3oool00`20P80000000000000>000001T0oooo1P00000>
0?ooo`040820P0000000000000000?l0ooooo`3ooomM0?ooo`00@@3oool00`20P80000000000000=
000000030820P03oool0oooo01L0oooo1P00000=0?ooo`030820P0000000000000800000o`3ooooo
0?oooed0oooo00120?ooo`l000006@3oool00`20P800000000000004000000`0oooo1P00003o0?oo
ool0ooooG@3oool00480oooo3P0000000`10@400oooo0?ooo`0B0?ooo`D0P8201P0000000`20P800
oooo0?ooo`0:0?ooo`H00000o`3ooooo0?oooed0oooo00130?ooo`d0000000<0P8200?ooo`3oool0
4P3oool;000000d0oooo1P00003o0?ooool0ooooG@3oool004<0oooo3@0000000`20P800oooo0?oo
o`0C0?ooo`X000003@3oool500000?l0ooooo`3ooomN0?ooo`00@`3oool00`10@40000000000000:
000001X0oooo0`20P8000`10@40000000820P00>0?ooo`040820P000000000000<30`?l0ooooo`3o
oomN0?ooo`00@`3oool00`20P80000000000000:00000?l0ooooo`3ooon@0?ooo`00A03oool<0000
0?l0ooooo`3ooon@0?ooo`00A03oool;00000?l0ooooo`3ooonA0?ooo`00A@3oool:00000?l0oooo
o`3ooonA0?ooo`00A@3oool900000?l0ooooo`3ooonB0?ooo`00AP3oool800000?l0ooooo`3ooonB
0?ooo`00AP3oool7000000030820P03oool0oooo0?l0ooooo`3ooon@0?ooo`00AP3oool00`10@400
000000000004000000030<30`03oool0oooo0?l0ooooo`3ooon@0?ooo`00AP3oool00`20P8000000
0000000400000?l0ooooo`3ooonC0?ooo`00AP3oool00`30`<00000000000003000000030820P03o
ool0oooo0?l0ooooo`3ooonA0?ooo`00A`3oool500000?l0ooooo`3ooonD0?ooo`00A`3oool50000
0?l0ooooo`3ooonD0?ooo`00B03oool3000000030820P03oool0oooo0?l0ooooo`3ooonB0?ooo`00
B03oool3000000030820P03oool0oooo0?l0ooooo`3ooonB0?ooo`00B03oool00`20P80000000000
003o0?ooool0ooooU@3oool004P0oooo00<0P82000000020P800o`3ooooo0?oooiD0oooo00190?oo
o`030000003oool0oooo0?l0ooooo`3ooonD0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0oooo
h03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0
ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP
0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3o
oooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00
oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?oo
ool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03o
ool00?l0ooooo`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0oooo
o`3ooooP0?ooo`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?oo
o`00o`3ooooo0?ooon00oooo003o0?ooool0ooooh03oool00?l0ooooo`3ooooP0?ooo`00o`3ooooo
0?ooon00oooo003o0?ooool0ooooh03oool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{151.625, 178.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.5", "Caption",
  CellTags->"Fig. 4.5"],

Cell[TextData[{
  "\tThis is a case where it is best to solve the Laplace equation directly \
using the methods outlined in Sec. ",
  ButtonBox["3.2.2",
    ButtonData:>{"Chapter3.nb", "c:27"},
    ButtonStyle->"Hyperlink"],
  " .  To see why this is so, let us  instead  put the problem into standard \
form by choosing some function ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " that matches the boundary conditions. There are many choices we could \
make [see Exercise (6) at the end of this section]; one simple choice (which \
does not work very well) is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`u(x, 
          y)\  = \ \(\[Phi]\_o\) \(h(y - b/3)\)\ \(h(\ 2  b/3 - y)\) x/a\)]],
  "."
}], "NE4",
  CellTags->"(4.3.28)"],

Cell[TextData[{
  "Then, according to Eqs. ",
  ButtonBox["(4.3.2)",
    ButtonData:>"(4.3.2)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  ", the solution to the problem is given by the following eigenmode \
expansion:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](x, y)\), " ", "=", 
          RowBox[{\(u(x, y)\), " ", "-", 
            RowBox[{\(\[Sum]\_\(m, n = 1\)\%\[Infinity]\), 
              
              RowBox[{\(\((\[Psi]\_\(m\ n\), \[Del]\^2 
                        u)\)\/\(\[Lambda]\_\(m\ n\)\ \((\[Psi]\_\(m\ n\), \
\[Psi]\_\(m\ n\))\)\)\), 
                RowBox[{\(\[Psi]\_\(m\ n\)\), "(", 
                  StyleBox[\(x, y\),
                    FontWeight->"Plain"], ")"}]}]}]}]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.29)"],

Cell[TextData[{
  "where the eigenfunctions and eigenvalues are given by Eqs. ",
  ButtonBox["(4.3.27)",
    ButtonData:>"(4.3.27)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.26)",
    ButtonData:>"(4.3.26)",
    ButtonStyle->"Hyperlink"],
  ".  The inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(m\ n\), \[Del]\^2 u)\)\)]],
  " can be evaluated directly, but because ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is discontinuous it is best to do so by first applying two  integrations \
by parts in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " integral:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(m\ n\), \[Del]\^2 
            u)\) = \(\[Integral]\_0\%a\[DifferentialD]x \(\[Integral]\_0\%b\
\[DifferentialD]y\ \(\[Psi]\_\(m\ n\)\) \[PartialD]\^2 u\/\[PartialD]y\^2\) = \
\[Integral]\_0\%a\[DifferentialD]x \(\[Integral]\_0\%b\[DifferentialD]y\ \ u \
\[PartialD]\^2 \[Psi]\_\(m\ n\)\/\[PartialD]y\^2\)\)\)]],
  ". "
}], "NE4",
  CellTags->"(4.3.30)"],

Cell[TextData[{
  "In the first step, we used the fact that Eqs. ",
  ButtonBox["(4.3.28)",
    ButtonData:>"(4.3.28)",
    ButtonStyle->"Hyperlink"],
  " implies ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 u\/\[PartialD]x\^2 = 0\)]],
  ",",
  " and in the second step we integrated by parts twice, and dropped the \
boundary terms because  ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " and its derivatives vanish at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = b\)]],
  ".  The integrals in Eq. ",
  ButtonBox["(4.3.30)",
    ButtonData:>"(4.3.30)",
    ButtonStyle->"Hyperlink"],
  " can then easily be performed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\ \(u[x_, y_]\  = \ \[Phi]\_o\ UnitStep[y - b/3] UnitStep[2  b/3 - y] 
          x/a;\)\n\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][m_, n_, x_, y_]\  = \ 
        Sin[n\ Pi\ x/a]\ Sin[m\ Pi\ y/b];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\[Rho][m_, n_]\  = \ 
      FullSimplify[
        Integrate[
          u[x, y]\ D[\[Psi][m, n, x, y], {y, 2}], {x, 0, a}, {y, 0, b}], 
        b > 0 && m > 0 && n > 0 && \ m \[Element] Integers && 
          n \[Element] Integers]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.22"],

Cell[BoxData[
    \(\(\((\(-1\))\)\^n\ a\ m\ \((Cos[\(m\ \[Pi]\)\/3] - Cos[\(2\ m\ \
\[Pi]\)\/3])\)\ \[Phi]\_o\)\/\(b\ n\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["4.23",
    ButtonData:>"Cell 4.23",
    ButtonStyle->"Hyperlink"],
  ", we plot the solution for a 1-meter-square box and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_o\), "=", 
          RowBox[{"1", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", keeping ",
  Cell[BoxData[
      \(TraditionalForm\`M = 30\)]],
  " terms in the sums."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = \(b = \(\[Phi]\_o = 1\)\);\)\), "\n", 
    \(\(M = 30;\)\), "\n", 
    \(\(\[Lambda][m_, 
          n_] = \(-\((\(n\ \[Pi]\)\/a)\)\^2\) - \((\(m\ \
\[Pi]\)\/b)\)\^2;\)\), "\n", 
    \(\(\[Phi][x_, 
          y_] = \(-\(\[Sum]\+\(m = 1\)\%M\(\[Sum]\+\(n = 1\)\%M\( \[Rho][m, \
n] \[Psi][m, n, x, y]\)\/\(\[Lambda][m, n]\ 1\/4\ a\ b\)\)\)\)\  + \ 
          u[x, y];\)\), "\n", 
    \(\(Plot3D[\[Phi][x, y], {x, 0, a}, {y, 0, b}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel \[Rule] "\<\[Phi] in a square enclosure\>", 
        PlotRange \[Rule] All, \ PlotPoints \[Rule] 30];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.23"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -71 0 ]
[.5 .82364 71 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02411 .26511 -6 -2.74232 ]
[.02411 .26511 0 6.25768 ]
[.01568 .31795 -24 -2.78699 ]
[.01568 .31795 0 6.21301 ]
[.00696 .37264 -18 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00208 .42927 -24 -2.88161 ]
[-0.00208 .42927 0 6.11839 ]
[-0.01144 .48795 -6 -2.93176 ]
[-0.01144 .48795 0 6.06824 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
93.000 13.000 moveto
(a) show
105.000 13.000 moveto
(square) show
147.000 13.000 moveto
(enclosure) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26033 m
.04245 .25795 L
s
[(0)] .02411 .26511 1 -0.3906 Mshowa
.02795 .31328 m
.03408 .31095 L
s
[(0.25)] .01568 .31795 1 -0.38067 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0.5)] .00696 .37264 1 -0.37036 Mshowa
.01027 .42483 m
.01644 .42261 L
s
[(0.75)] -0.00208 .42927 1 -0.35964 Mshowa
.00095 .48363 m
.00715 .48147 L
s
[(1)] -0.01144 .48795 1 -0.3485 Mshowa
.125 Mabswid
.03468 .27078 m
.03835 .26935 L
s
.03301 .2813 m
.03669 .27988 L
s
.03134 .29189 m
.03501 .29047 L
s
.02965 .30255 m
.03332 .30114 L
s
.02623 .32409 m
.02991 .3227 L
s
.02451 .33497 m
.02819 .33359 L
s
.02277 .34593 m
.02646 .34455 L
s
.02102 .35697 m
.02471 .35559 L
s
.01749 .37927 m
.02118 .37791 L
s
.0157 .39054 m
.0194 .38919 L
s
.0139 .40189 m
.0176 .40054 L
s
.01209 .41332 m
.01579 .41198 L
s
.00843 .43642 m
.01214 .4351 L
s
.00658 .4481 m
.01029 .44678 L
s
.00472 .45986 m
.00843 .45855 L
s
.00284 .4717 m
.00656 .4704 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.661 .741 .909 r
.39457 .59389 .40512 .60371 .42281 .59841 .41233 .58865 Metetra
.661 .743 .911 r
.41233 .58865 .42281 .59841 .44061 .59307 .4302 .58338 Metetra
.66 .746 .913 r
.4302 .58338 .44061 .59307 .45853 .58769 .4482 .57807 Metetra
.66 .748 .915 r
.4482 .57807 .45853 .58769 .47657 .58228 .46631 .57274 Metetra
.66 .751 .918 r
.46631 .57274 .47657 .58228 .49473 .57683 .48455 .56737 Metetra
.66 .754 .92 r
.48455 .56737 .49473 .57683 .51301 .57135 .50292 .56197 Metetra
.659 .757 .922 r
.50292 .56197 .51301 .57135 .53142 .56582 .52141 .55655 Metetra
.659 .76 .925 r
.52141 .55655 .53142 .56582 .54995 .56027 .54002 .55109 Metetra
.658 .764 .928 r
.54002 .55109 .54995 .56027 .5686 .55467 .55877 .54561 Metetra
.657 .767 .931 r
.55877 .54561 .5686 .55467 .58738 .54904 .57764 .5401 Metetra
.656 .771 .934 r
.57764 .5401 .58738 .54904 .60629 .54336 .59665 .53456 Metetra
.655 .776 .937 r
.59665 .53456 .60629 .54336 .62532 .53765 .61579 .529 Metetra
.654 .78 .941 r
.61579 .529 .62532 .53765 .64449 .5319 .63506 .52341 Metetra
.653 .785 .944 r
.63506 .52341 .64449 .5319 .66379 .52611 .65447 .5178 Metetra
.652 .79 .948 r
.65447 .5178 .66379 .52611 .68322 .52028 .67402 .51215 Metetra
.65 .795 .952 r
.67402 .51215 .68322 .52028 .70279 .51441 .69371 .50647 Metetra
.648 .801 .956 r
.69371 .50647 .70279 .51441 .72249 .5085 .71354 .50075 Metetra
.647 .807 .96 r
.71354 .50075 .72249 .5085 .74233 .50255 .73351 .49498 Metetra
.646 .812 .963 r
.73351 .49498 .74233 .50255 .7623 .49656 .75363 .48914 Metetra
.645 .818 .966 r
.75363 .48914 .7623 .49656 .78242 .49052 .77388 .48323 Metetra
.644 .822 .968 r
.77388 .48323 .78242 .49052 .80268 .48445 .79428 .47721 Metetra
.645 .826 .97 r
.79428 .47721 .80268 .48445 .82308 .47833 .81481 .47107 Metetra
.648 .828 .969 r
.81481 .47107 .82308 .47833 .84363 .47216 .83549 .46476 Metetra
.652 .828 .967 r
.83549 .46476 .84363 .47216 .86432 .46595 .85629 .45827 Metetra
.659 .825 .963 r
.85629 .45827 .86432 .46595 .88516 .4597 .87722 .45154 Metetra
.665 .818 .957 r
.87722 .45154 .88516 .4597 .90615 .45341 .89828 .44461 Metetra
.673 .807 .947 r
.89828 .44461 .90615 .45341 .92729 .44706 .91946 .4374 Metetra
.677 .791 .935 r
.91946 .4374 .92729 .44706 .94858 .44068 .94077 .43006 Metetra
.686 .776 .919 r
.94077 .43006 .94858 .44068 .97003 .43424 .96217 .42224 Metetra
.659 .74 .91 r
.38389 .58395 .39457 .59389 .41233 .58865 .40172 .57873 Metetra
.659 .742 .911 r
.40172 .57873 .41233 .58865 .4302 .58338 .41966 .57349 Metetra
.659 .744 .913 r
.41966 .57349 .4302 .58338 .4482 .57807 .43773 .56821 Metetra
.658 .745 .914 r
.43773 .56821 .4482 .57807 .46631 .57274 .45593 .56291 Metetra
.658 .747 .916 r
.45593 .56291 .46631 .57274 .48455 .56737 .47424 .55758 Metetra
.657 .749 .918 r
.47424 .55758 .48455 .56737 .50292 .56197 .49269 .55223 Metetra
.657 .752 .92 r
.49269 .55223 .50292 .56197 .52141 .55655 .51126 .54685 Metetra
.656 .754 .922 r
.51126 .54685 .52141 .55655 .54002 .55109 .52997 .54146 Metetra
.656 .756 .924 r
.52997 .54146 .54002 .55109 .55877 .54561 .5488 .53604 Metetra
.655 .759 .926 r
.5488 .53604 .55877 .54561 .57764 .5401 .56777 .53063 Metetra
.654 .762 .929 r
.56777 .53063 .57764 .5401 .59665 .53456 .58687 .52518 Metetra
.653 .765 .932 r
.58687 .52518 .59665 .53456 .61579 .529 .60611 .51973 Metetra
.652 .769 .935 r
.60611 .51973 .61579 .529 .63506 .52341 .62549 .51426 Metetra
.65 .772 .938 r
.62549 .51426 .63506 .52341 .65447 .5178 .64501 .50879 Metetra
.649 .776 .941 r
.64501 .50879 .65447 .5178 .67402 .51215 .66467 .50328 Metetra
.648 .781 .944 r
.66467 .50328 .67402 .51215 .69371 .50647 .68447 .49776 Metetra
.647 .785 .948 r
.68447 .49776 .69371 .50647 .71354 .50075 .70443 .49219 Metetra
.646 .79 .951 r
.70443 .49219 .71354 .50075 .73351 .49498 .72452 .48657 Metetra
.645 .795 .954 r
.72452 .48657 .73351 .49498 .75363 .48914 .74477 .48087 Metetra
.646 .8 .957 r
.74477 .48087 .75363 .48914 .77388 .48323 .76516 .47506 Metetra
.647 .805 .959 r
.76516 .47506 .77388 .48323 .79428 .47721 .78569 .46909 Metetra
.651 .809 .959 r
.78569 .46909 .79428 .47721 .81481 .47107 .80635 .4629 Metetra
.656 .811 .958 r
.80635 .4629 .81481 .47107 .83549 .46476 .82714 .45646 Metetra
.664 .813 .955 r
.82714 .45646 .83549 .46476 .85629 .45827 .84806 .44963 Metetra
.672 .81 .949 r
.84806 .44963 .85629 .45827 .87722 .45154 .86908 .44244 Metetra
.683 .805 .94 r
.86908 .44244 .87722 .45154 .89828 .44461 .89019 .43474 Metetra
.69 .793 .928 r
.89019 .43474 .89828 .44461 .91946 .4374 .91141 .42668 Metetra
.698 .78 .914 r
.91141 .42668 .91946 .4374 .94077 .43006 .9327 .41815 Metetra
.689 .755 .902 r
.9327 .41815 .94077 .43006 .96217 .42224 .9542 .41007 Metetra
.655 .739 .911 r
.37308 .57388 .38389 .58395 .40172 .57873 .39097 .56877 Metetra
.655 .742 .914 r
.39097 .56877 .40172 .57873 .41966 .57349 .40899 .56363 Metetra
.654 .746 .917 r
.40899 .56363 .41966 .57349 .43773 .56821 .42713 .55847 Metetra
.654 .749 .92 r
.42713 .55847 .43773 .56821 .45593 .56291 .4454 .55327 Metetra
.653 .752 .923 r
.4454 .55327 .45593 .56291 .47424 .55758 .4638 .54807 Metetra
.653 .756 .926 r
.4638 .54807 .47424 .55758 .49269 .55223 .48232 .54283 Metetra
.651 .759 .929 r
.48232 .54283 .49269 .55223 .51126 .54685 .50098 .5376 Metetra
.65 .764 .932 r
.50098 .5376 .51126 .54685 .52997 .54146 .51977 .53233 Metetra
.649 .767 .936 r
.51977 .53233 .52997 .54146 .5488 .53604 .5387 .52709 Metetra
.647 .772 .939 r
.5387 .52709 .5488 .53604 .56777 .53063 .55777 .52182 Metetra
.645 .776 .943 r
.55777 .52182 .56777 .53063 .58687 .52518 .57697 .51657 Metetra
.643 .782 .947 r
.57697 .51657 .58687 .52518 .60611 .51973 .59632 .5113 Metetra
.64 .786 .952 r
.59632 .5113 .60611 .51973 .62549 .51426 .61581 .50605 Metetra
.638 .792 .956 r
.61581 .50605 .62549 .51426 .64501 .50879 .63544 .50078 Metetra
.635 .798 .961 r
.63544 .50078 .64501 .50879 .66467 .50328 .65523 .49553 Metetra
.632 .804 .965 r
.65523 .49553 .66467 .50328 .68447 .49776 .67516 .49025 Metetra
.628 .81 .97 r
.67516 .49025 .68447 .49776 .70443 .49219 .69525 .48495 Metetra
.625 .818 .974 r
.69525 .48495 .70443 .49219 .72452 .48657 .71549 .47959 Metetra
.623 .825 .978 r
.71549 .47959 .72452 .48657 .74477 .48087 .73588 .47414 Metetra
.621 .832 .981 r
.73588 .47414 .74477 .48087 .76516 .47506 .75642 .46857 Metetra
.622 .84 .983 r
.75642 .46857 .76516 .47506 .78569 .46909 .77711 .46278 Metetra
.625 .847 .984 r
.77711 .46278 .78569 .46909 .80635 .4629 .79793 .45673 Metetra
.633 .855 .984 r
.79793 .45673 .80635 .4629 .82714 .45646 .81887 .45025 Metetra
.645 .86 .981 r
.81887 .45025 .82714 .45646 .84806 .44963 .83993 .44331 Metetra
.663 .865 .976 r
.83993 .44331 .84806 .44963 .86908 .44244 .86106 .43568 Metetra
.681 .863 .968 r
.86106 .43568 .86908 .44244 .89019 .43474 .88228 .42743 Metetra
.702 .858 .957 r
.88228 .42743 .89019 .43474 .91141 .42668 .90353 .41832 Metetra
.714 .839 .942 r
.90353 .41832 .91141 .42668 .9327 .41815 .92486 .40877 Metetra
.739 .826 .918 r
.92486 .40877 .9327 .41815 .9542 .41007 .94612 .39774 Metetra
.654 .739 .912 r
.36214 .56369 .37308 .57388 .39097 .56877 .3801 .55855 Metetra
.654 .74 .913 r
.3801 .55855 .39097 .56877 .40899 .56363 .39819 .55339 Metetra
.654 .741 .913 r
.39819 .55339 .40899 .56363 .42713 .55847 .41641 .5482 Metetra
.653 .741 .914 r
.41641 .5482 .42713 .55847 .4454 .55327 .43475 .54299 Metetra
.653 .742 .915 r
.43475 .54299 .4454 .55327 .4638 .54807 .45323 .53775 Metetra
.652 .743 .916 r
.45323 .53775 .4638 .54807 .48232 .54283 .47183 .53253 Metetra
.652 .744 .917 r
.47183 .53253 .48232 .54283 .50098 .5376 .49057 .52727 Metetra
.65 .745 .918 r
.49057 .52727 .50098 .5376 .51977 .53233 .50945 .52204 Metetra
.65 .746 .92 r
.50945 .52204 .51977 .53233 .5387 .52709 .52846 .51679 Metetra
.648 .747 .922 r
.52846 .51679 .5387 .52709 .55777 .52182 .54762 .51157 Metetra
.647 .75 .924 r
.54762 .51157 .55777 .52182 .57697 .51657 .56691 .50634 Metetra
.645 .751 .926 r
.56691 .50634 .57697 .51657 .59632 .5113 .58635 .50116 Metetra
.644 .754 .929 r
.58635 .50116 .59632 .5113 .61581 .50605 .60594 .49597 Metetra
.642 .755 .931 r
.60594 .49597 .61581 .50605 .63544 .50078 .62568 .49082 Metetra
.641 .759 .934 r
.62568 .49082 .63544 .50078 .65523 .49553 .64557 .48566 Metetra
.638 .762 .937 r
.64557 .48566 .65523 .49553 .67516 .49025 .66562 .48053 Metetra
.637 .766 .941 r
.66562 .48053 .67516 .49025 .69525 .48495 .68582 .47536 Metetra
.636 .77 .944 r
.68582 .47536 .69525 .48495 .71549 .47959 .70619 .47017 Metetra
.636 .775 .947 r
.70619 .47017 .71549 .47959 .73588 .47414 .7267 .46489 Metetra
.637 .781 .95 r
.7267 .46489 .73588 .47414 .75642 .46857 .74738 .45947 Metetra
.64 .787 .953 r
.74738 .45947 .75642 .46857 .77711 .46278 .7682 .45384 Metetra
.646 .794 .954 r
.7682 .45384 .77711 .46278 .79793 .45673 .78916 .44784 Metetra
.655 .8 .953 r
.78916 .44784 .79793 .45673 .81887 .45025 .81024 .44139 Metetra
.669 .808 .949 r
.81024 .44139 .81887 .45025 .83993 .44331 .83141 .43421 Metetra
.686 .81 .942 r
.83141 .43421 .83993 .44331 .86106 .43568 .85266 .42624 Metetra
.708 .812 .93 r
.85266 .42624 .86106 .43568 .88228 .42743 .87392 .4171 Metetra
.723 .8 .912 r
.87392 .4171 .88228 .42743 .90353 .41832 .8952 .40701 Metetra
.739 .788 .892 r
.8952 .40701 .90353 .41832 .92486 .40877 .91646 .39567 Metetra
.719 .752 .878 r
.91646 .39567 .92486 .40877 .94612 .39774 .93793 .38524 Metetra
.65 .738 .914 r
.35106 .55337 .36214 .56369 .3801 .55855 .36908 .54839 Metetra
.649 .742 .917 r
.36908 .54839 .3801 .55855 .39819 .55339 .38724 .54336 Metetra
.648 .746 .92 r
.38724 .54336 .39819 .55339 .41641 .5482 .40553 .53833 Metetra
.648 .75 .924 r
.40553 .53833 .41641 .5482 .43475 .54299 .42395 .53326 Metetra
.646 .754 .928 r
.42395 .53326 .43475 .54299 .45323 .53775 .4425 .52821 Metetra
.645 .759 .931 r
.4425 .52821 .45323 .53775 .47183 .53253 .46119 .52312 Metetra
.643 .762 .935 r
.46119 .52312 .47183 .53253 .49057 .52727 .48001 .51807 Metetra
.642 .768 .94 r
.48001 .51807 .49057 .52727 .50945 .52204 .49898 .513 Metetra
.638 .771 .944 r
.49898 .513 .50945 .52204 .52846 .51679 .51809 .50798 Metetra
.636 .778 .948 r
.51809 .50798 .52846 .51679 .54762 .51157 .53734 .50294 Metetra
.632 .782 .953 r
.53734 .50294 .54762 .51157 .56691 .50634 .55674 .49797 Metetra
.629 .788 .958 r
.55674 .49797 .56691 .50634 .58635 .50116 .57629 .493 Metetra
.624 .793 .963 r
.57629 .493 .58635 .50116 .60594 .49597 .59599 .48811 Metetra
.619 .8 .969 r
.59599 .48811 .60594 .49597 .62568 .49082 .61585 .48322 Metetra
.613 .805 .974 r
.61585 .48322 .62568 .49082 .64557 .48566 .63587 .4784 Metetra
.607 .813 .979 r
.63587 .4784 .64557 .48566 .66562 .48053 .65606 .47358 Metetra
.599 .82 .984 r
.65606 .47358 .66562 .48053 .68582 .47536 .67641 .46881 Metetra
.592 .828 .989 r
.67641 .46881 .68582 .47536 .70619 .47017 .69692 .464 Metetra
.584 .836 .993 r
.69692 .464 .70619 .47017 .7267 .46489 .71761 .45915 Metetra
.577 .845 .995 r
.71761 .45915 .7267 .46489 .74738 .45947 .73845 .45418 Metetra
.572 .856 .996 r
.73845 .45418 .74738 .45947 .7682 .45384 .75946 .44897 Metetra
.57 .866 .996 r
.75946 .44897 .7682 .45384 .78916 .44784 .78061 .44343 Metetra
.577 .881 .992 r
.78061 .44343 .78916 .44784 .81024 .44139 .80189 .43729 Metetra
.591 .895 .988 r
.80189 .43729 .81024 .44139 .83141 .43421 .82326 .43041 Metetra
.623 .914 .98 r
.82326 .43041 .83141 .43421 .85266 .42624 .84467 .42227 Metetra
.665 .927 .973 r
.84467 .42227 .85266 .42624 .87392 .4171 .86609 .41281 Metetra
.721 .938 .957 r
.86609 .41281 .87392 .4171 .8952 .40701 .88741 .40136 Metetra
.762 .919 .942 r
.88741 .40136 .8952 .40701 .91646 .39567 .90868 .38857 Metetra
.815 .898 .9 r
.90868 .38857 .91646 .39567 .93793 .38524 .92963 .37257 Metetra
.65 .738 .913 r
.33984 .54293 .35106 .55337 .36908 .54839 .35794 .53783 Metetra
.65 .737 .913 r
.35794 .53783 .36908 .54839 .38724 .54336 .37617 .53272 Metetra
.65 .737 .913 r
.37617 .53272 .38724 .54336 .40553 .53833 .39453 .52756 Metetra
.649 .736 .912 r
.39453 .52756 .40553 .53833 .42395 .53326 .41303 .52242 Metetra
.649 .736 .912 r
.41303 .52242 .42395 .53326 .4425 .52821 .43166 .51724 Metetra
.648 .734 .912 r
.43166 .51724 .4425 .52821 .46119 .52312 .45043 .51211 Metetra
.648 .735 .913 r
.45043 .51211 .46119 .52312 .48001 .51807 .46933 .50693 Metetra
.645 .733 .913 r
.46933 .50693 .48001 .51807 .49898 .513 .48838 .50183 Metetra
.645 .734 .914 r
.48838 .50183 .49898 .513 .51809 .50798 .50757 .49671 Metetra
.642 .732 .914 r
.50757 .49671 .51809 .50798 .53734 .50294 .52691 .49167 Metetra
.642 .734 .915 r
.52691 .49167 .53734 .50294 .55674 .49797 .54639 .48663 Metetra
.638 .732 .916 r
.54639 .48663 .55674 .49797 .57629 .493 .56603 .48169 Metetra
.637 .734 .918 r
.56603 .48169 .57629 .493 .59599 .48811 .58583 .47676 Metetra
.634 .734 .92 r
.58583 .47676 .59599 .48811 .61585 .48322 .60578 .47195 Metetra
.632 .736 .923 r
.60578 .47195 .61585 .48322 .63587 .4784 .6259 .46716 Metetra
.629 .737 .925 r
.6259 .46716 .63587 .4784 .65606 .47358 .64619 .46247 Metetra
.627 .74 .929 r
.64619 .46247 .65606 .47358 .67641 .46881 .66664 .4578 Metetra
.624 .742 .932 r
.66664 .4578 .67641 .46881 .69692 .464 .68728 .45319 Metetra
.622 .747 .936 r
.68728 .45319 .69692 .464 .71761 .45915 .70808 .44856 Metetra
.622 .753 .94 r
.70808 .44856 .71761 .45915 .73845 .45418 .72906 .44385 Metetra
.623 .761 .945 r
.72906 .44385 .73845 .45418 .75946 .44897 .75021 .43899 Metetra
.628 .772 .949 r
.75021 .43899 .75946 .44897 .78061 .44343 .77152 .43376 Metetra
.636 .783 .952 r
.77152 .43376 .78061 .44343 .80189 .43729 .79296 .42805 Metetra
.655 .801 .953 r
.79296 .42805 .80189 .43729 .82326 .43041 .8145 .42134 Metetra
.679 .815 .948 r
.8145 .42134 .82326 .43041 .84467 .42227 .83608 .41342 Metetra
.722 .835 .935 r
.83608 .41342 .84467 .42227 .86609 .41281 .85758 .40327 Metetra
.759 .833 .909 r
.85758 .40327 .86609 .41281 .88741 .40136 .87895 .39079 Metetra
.799 .824 .871 r
.87895 .39079 .88741 .40136 .90868 .38857 .90001 .37488 Metetra
.773 .767 .847 r
.90001 .37488 .90868 .38857 .92963 .37257 .92121 .35972 Metetra
.644 .736 .916 r
.32848 .53235 .33984 .54293 .35794 .53783 .34663 .52747 Metetra
.644 .742 .92 r
.34663 .52747 .35794 .53783 .37617 .53272 .36493 .52256 Metetra
.642 .746 .925 r
.36493 .52256 .37617 .53272 .39453 .52756 .38336 .51765 Metetra
.642 .752 .929 r
.38336 .51765 .39453 .52756 .41303 .52242 .40193 .51269 Metetra
.639 .757 .934 r
.40193 .51269 .41303 .52242 .43166 .51724 .42063 .50779 Metetra
.638 .764 .939 r
.42063 .50779 .43166 .51724 .45043 .51211 .43948 .50283 Metetra
.633 .768 .944 r
.43948 .50283 .45043 .51211 .46933 .50693 .45847 .49797 Metetra
.632 .775 .949 r
.45847 .49797 .46933 .50693 .48838 .50183 .47761 .49305 Metetra
.626 .779 .954 r
.47761 .49305 .48838 .50183 .50757 .49671 .4969 .48827 Metetra
.623 .787 .96 r
.4969 .48827 .50757 .49671 .52691 .49167 .51633 .48344 Metetra
.616 .791 .966 r
.51633 .48344 .52691 .49167 .54639 .48663 .53593 .47877 Metetra
.611 .8 .972 r
.53593 .47877 .54639 .48663 .56603 .48169 .55568 .47409 Metetra
.601 .803 .977 r
.55568 .47409 .56603 .48169 .58583 .47676 .57559 .46958 Metetra
.593 .812 .984 r
.57559 .46958 .58583 .47676 .60578 .47195 .59568 .46508 Metetra
.58 .817 .989 r
.59568 .46508 .60578 .47195 .6259 .46716 .61593 .46077 Metetra
.568 .825 .994 r
.61593 .46077 .6259 .46716 .64619 .46247 .63636 .45648 Metetra
.551 .829 .997 r
.63636 .45648 .64619 .46247 .66664 .4578 .65698 .45237 Metetra
.532 .836 .999 r
.65698 .45237 .66664 .4578 .68728 .45319 .67778 .4483 Metetra
.509 .84 .998 r
.67778 .4483 .68728 .45319 .70808 .44856 .69877 .44433 Metetra
.482 .843 .992 r
.69877 .44433 .70808 .44856 .72906 .44385 .71995 .44036 Metetra
.452 .844 .98 r
.71995 .44036 .72906 .44385 .75021 .43899 .74132 .4363 Metetra
.417 .841 .959 r
.74132 .4363 .75021 .43899 .77152 .43376 .76288 .43209 Metetra
.386 .837 .924 r
.76288 .43209 .77152 .43376 .79296 .42805 .78459 .42733 Metetra
.358 .829 .882 r
.78459 .42733 .79296 .42805 .8145 .42134 .80644 .42191 Metetra
.357 .83 .821 r
.80644 .42191 .8145 .42134 .83608 .41342 .82831 .4148 Metetra
.401 .852 .787 r
.82831 .4148 .83608 .41342 .85758 .40327 .85015 .40561 Metetra
.527 .908 .75 r
.85015 .40561 .85758 .40327 .87895 .39079 .87165 .39199 Metetra
.728 .986 .794 r
.87165 .39199 .87895 .39079 .90001 .37488 .89269 .37371 Metetra
.911 .98 .768 r
.89269 .37371 .90001 .37488 .92121 .35972 .91267 .34669 Metetra
.648 .737 .914 r
.31697 .52163 .32848 .53235 .34663 .52747 .33521 .51651 Metetra
.648 .734 .912 r
.33521 .51651 .34663 .52747 .36493 .52256 .35359 .51138 Metetra
.648 .732 .91 r
.35359 .51138 .36493 .52256 .38336 .51765 .3721 .5062 Metetra
.646 .727 .908 r
.3721 .5062 .38336 .51765 .40193 .51269 .39075 .50106 Metetra
.647 .726 .906 r
.39075 .50106 .40193 .51269 .42063 .50779 .40954 .49585 Metetra
.644 .721 .904 r
.40954 .49585 .42063 .50779 .43948 .50283 .42846 .49075 Metetra
.645 .72 .903 r
.42846 .49075 .43948 .50283 .45847 .49797 .44753 .48557 Metetra
.642 .715 .901 r
.44753 .48557 .45847 .49797 .47761 .49305 .46675 .48054 Metetra
.642 .714 .9 r
.46675 .48054 .47761 .49305 .4969 .48827 .48611 .47545 Metetra
.638 .709 .898 r
.48611 .47545 .4969 .48827 .51633 .48344 .50563 .47054 Metetra
.638 .709 .898 r
.50563 .47054 .51633 .48344 .53593 .47877 .5253 .46559 Metetra
.633 .704 .897 r
.5253 .46559 .53593 .47877 .55568 .47409 .54513 .46086 Metetra
.633 .705 .898 r
.54513 .46086 .55568 .47409 .57559 .46958 .56512 .45612 Metetra
.627 .7 .898 r
.56512 .45612 .57559 .46958 .59568 .46508 .58528 .45162 Metetra
.626 .701 .899 r
.58528 .45162 .59568 .46508 .61593 .46077 .60562 .44715 Metetra
.62 .697 .9 r
.60562 .44715 .61593 .46077 .63636 .45648 .62614 .44294 Metetra
.617 .699 .902 r
.62614 .44294 .63636 .45648 .65698 .45237 .64684 .4388 Metetra
.612 .698 .905 r
.64684 .4388 .65698 .45237 .67778 .4483 .66774 .43489 Metetra
.608 .7 .909 r
.66774 .43489 .67778 .4483 .69877 .44433 .68884 .4311 Metetra
.604 .703 .914 r
.68884 .4311 .69877 .44433 .71995 .44036 .71014 .42746 Metetra
.599 .708 .92 r
.71014 .42746 .71995 .44036 .74132 .4363 .73165 .42393 Metetra
.598 .719 .929 r
.73165 .42393 .74132 .4363 .76288 .43209 .75335 .4203 Metetra
.595 .73 .938 r
.75335 .4203 .76288 .43209 .78459 .42733 .77527 .41663 Metetra
.604 .757 .952 r
.77527 .41663 .78459 .42733 .80644 .42191 .79733 .4122 Metetra
.615 .785 .963 r
.79733 .4122 .80644 .42191 .82831 .4148 .81953 .40699 Metetra
.667 .848 .969 r
.81953 .40699 .82831 .4148 .85015 .40561 .84165 .39897 Metetra
.746 .899 .947 r
.84165 .39897 .85015 .40561 .87165 .39199 .8635 .38689 Metetra
.89 .938 .84 r
.8635 .38689 .87165 .39199 .89269 .37371 .88423 .36389 Metetra
.914 .85 .767 r
.88423 .36389 .89269 .37371 .91267 .34669 .90401 .33348 Metetra
.638 .735 .918 r
.30532 .51078 .31697 .52163 .33521 .51651 .3236 .50603 Metetra
.64 .743 .924 r
.3236 .50603 .33521 .51651 .35359 .51138 .34204 .50114 Metetra
.633 .747 .931 r
.34204 .50114 .35359 .51138 .3721 .5062 .36061 .49646 Metetra
.638 .761 .937 r
.36061 .49646 .3721 .5062 .39075 .50106 .37933 .49144 Metetra
.625 .761 .944 r
.37933 .49144 .39075 .50106 .40954 .49585 .39818 .48688 Metetra
.634 .778 .95 r
.39818 .48688 .40954 .49585 .42846 .49075 .4172 .48179 Metetra
.614 .774 .957 r
.4172 .48179 .42846 .49075 .44753 .48557 .43634 .47738 Metetra
.626 .796 .963 r
.43634 .47738 .44753 .48557 .46675 .48054 .45566 .47229 Metetra
.6 .788 .971 r
.45566 .47229 .46675 .48054 .48611 .47545 .47511 .46806 Metetra
.612 .813 .977 r
.47511 .46806 .48611 .47545 .50563 .47054 .49474 .46308 Metetra
.58 .802 .984 r
.49474 .46308 .50563 .47054 .5253 .46559 .51452 .45905 Metetra
.59 .828 .989 r
.51452 .45905 .5253 .46559 .54513 .46086 .53447 .45428 Metetra
.552 .815 .995 r
.53447 .45428 .54513 .46086 .56512 .45612 .55459 .45049 Metetra
.554 .839 .998 r
.55459 .45049 .56512 .45612 .58528 .45162 .57489 .44606 Metetra
.511 .825 1 r
.57489 .44606 .58528 .45162 .60562 .44715 .59538 .44256 Metetra
.499 .842 .997 r
.59538 .44256 .60562 .44715 .62614 .44294 .61605 .4386 Metetra
.449 .825 .991 r
.61605 .4386 .62614 .44294 .64684 .4388 .63693 .43543 Metetra
.411 .825 .973 r
.63693 .43543 .64684 .4388 .66774 .43489 .65801 .43211 Metetra
.351 .802 .948 r
.65801 .43211 .66774 .43489 .68884 .4311 .67932 .42928 Metetra
.273 .767 .899 r
.67932 .42928 .68884 .4311 .71014 .42746 .70086 .42677 Metetra
.199 .726 .832 r
.70086 .42677 .71014 .42746 .73165 .42393 .72261 .42423 Metetra
.075 .637 .733 r
.72261 .42423 .73165 .42393 .75335 .4203 .74466 .42262 Metetra
.006 0 0 r
.74466 .42262 .75335 .4203 .77527 .41663 .76688 .42013 Metetra
.155 0 0 r
.76688 .42013 .77527 .41663 .79733 .4122 .78947 .4193 Metetra
.199 0 0 r
.78947 .4193 .79733 .4122 .81953 .40699 .81209 .41589 Metetra
.328 0 0 r
.81209 .41589 .81953 .40699 .84165 .39897 .83516 .41473 Metetra
.267 0 .048 r
.83516 .41473 .84165 .39897 .8635 .38689 .85769 .4058 Metetra
.249 0 .106 r
.85769 .4058 .8635 .38689 .88423 .36389 .87999 .39335 Metetra
.87999 .39335 .88423 .36389 .90401 .33348 .89523 .32008 Metetra
.612 .727 .927 r
.29351 .49979 .30532 .51078 .3236 .50603 .3118 .49604 Metetra
.604 .746 .944 r
.3118 .49604 .3236 .50603 .34204 .50114 .33025 .49236 Metetra
.6 .771 .962 r
.33025 .49236 .34204 .50114 .36061 .49646 .34885 .48851 Metetra
.582 .785 .976 r
.34885 .48851 .36061 .49646 .37933 .49144 .3676 .4849 Metetra
.57 .814 .991 r
.3676 .4849 .37933 .49144 .39818 .48688 .38652 .481 Metetra
.538 .819 .998 r
.38652 .481 .39818 .48688 .4172 .48179 .40559 .47752 Metetra
.51 .845 .997 r
.40559 .47752 .4172 .48179 .43634 .47738 .42484 .47363 Metetra
.458 .834 .989 r
.42484 .47363 .43634 .47738 .45566 .47229 .44424 .47032 Metetra
.401 .835 .951 r
.44424 .47032 .45566 .47229 .47511 .46806 .46382 .46653 Metetra
.326 .799 .918 r
.46382 .46653 .47511 .46806 .49474 .46308 .48357 .46344 Metetra
.236 .754 .82 r
.48357 .46344 .49474 .46308 .51452 .45905 .50351 .45986 Metetra
.147 .691 .758 r
.50351 .45986 .51452 .45905 .53447 .45428 .52362 .45704 Metetra
.52362 .45704 .53447 .45428 .55459 .45049 .54393 .45379 Metetra
.042 0 0 r
.54393 .45379 .55459 .45049 .57489 .44606 .56444 .45133 Metetra
.129 0 0 r
.56444 .45133 .57489 .44606 .59538 .44256 .58515 .44856 Metetra
.2 0 0 r
.58515 .44856 .59538 .44256 .61605 .4386 .60608 .44654 Metetra
.264 0 0 r
.60608 .44654 .61605 .4386 .63693 .43543 .62722 .44445 Metetra
.316 0 0 r
.62722 .44445 .63693 .43543 .65801 .43211 .64861 .443 Metetra
.362 0 0 r
.64861 .443 .65801 .43211 .67932 .42928 .67025 .44182 Metetra
.399 0 .023 r
.67025 .44182 .67932 .42928 .70086 .42677 .69215 .4411 Metetra
.435 0 .082 r
.69215 .4411 .70086 .42677 .72261 .42423 .71434 .44114 Metetra
.458 .031 .14 r
.71434 .44114 .72261 .42423 .74466 .42262 .73682 .44133 Metetra
.491 .076 .181 r
.73682 .44133 .74466 .42262 .76688 .42013 .75967 .44299 Metetra
.501 .113 .236 r
.75967 .44299 .76688 .42013 .78947 .4193 .78279 .44431 Metetra
.535 .155 .267 r
.78279 .44431 .78947 .4193 .81209 .41589 .80644 .4483 Metetra
.534 .185 .321 r
.80644 .4483 .81209 .41589 .83516 .41473 .83034 .45127 Metetra
.579 .236 .351 r
.83034 .45127 .83516 .41473 .85769 .4058 .85517 .46014 Metetra
.584 .274 .411 r
.85517 .46014 .85769 .4058 .87999 .39335 .88064 .4709 Metetra
.699 .39 .45 r
.88064 .4709 .87999 .39335 .89523 .32008 .91185 .52741 Metetra
.647 .737 .915 r
.28155 .48866 .29351 .49979 .3118 .49604 .30002 .48337 Metetra
.647 .712 .895 r
.30002 .48337 .3118 .49604 .33025 .49236 .31862 .47809 Metetra
.647 .688 .875 r
.31862 .47809 .33025 .49236 .34885 .48851 .33736 .47273 Metetra
.643 .667 .859 r
.33736 .47273 .34885 .48851 .3676 .4849 .35624 .46746 Metetra
.642 .648 .841 r
.35624 .46746 .3676 .4849 .38652 .481 .37526 .46208 Metetra
.637 .631 .827 r
.37526 .46208 .38652 .481 .40559 .47752 .39443 .45689 Metetra
.635 .614 .812 r
.39443 .45689 .40559 .47752 .42484 .47363 .41375 .45156 Metetra
.629 .6 .801 r
.41375 .45156 .42484 .47363 .44424 .47032 .43321 .44649 Metetra
.628 .586 .788 r
.43321 .44649 .44424 .47032 .46382 .46653 .45284 .44129 Metetra
.622 .574 .779 r
.45284 .44129 .46382 .46653 .48357 .46344 .47261 .43642 Metetra
.62 .562 .768 r
.47261 .43642 .48357 .46344 .50351 .45986 .49255 .43144 Metetra
.614 .551 .76 r
.49255 .43144 .50351 .45986 .52362 .45704 .51266 .42685 Metetra
.612 .541 .751 r
.51266 .42685 .52362 .45704 .54393 .45379 .53293 .42221 Metetra
.606 .532 .745 r
.53293 .42221 .54393 .45379 .56444 .45133 .55339 .41801 Metetra
.604 .523 .737 r
.55339 .41801 .56444 .45133 .58515 .44856 .57403 .41386 Metetra
.598 .515 .732 r
.57403 .41386 .58515 .44856 .60608 .44654 .59488 .4102 Metetra
.595 .507 .725 r
.59488 .4102 .60608 .44654 .62722 .44445 .61592 .40676 Metetra
.589 .499 .721 r
.61592 .40676 .62722 .44445 .64861 .443 .63719 .40384 Metetra
.584 .492 .716 r
.63719 .40384 .64861 .443 .67025 .44182 .65869 .40139 Metetra
.579 .485 .712 r
.65869 .40139 .67025 .44182 .69215 .4411 .68045 .39953 Metetra
.572 .478 .71 r
.68045 .39953 .69215 .4411 .71434 .44114 .70249 .3985 Metetra
.566 .472 .707 r
.70249 .3985 .71434 .44114 .73682 .44133 .72483 .39818 Metetra
.555 .464 .707 r
.72483 .39818 .73682 .44133 .75967 .44299 .74753 .3993 Metetra
.546 .458 .707 r
.74753 .3993 .75967 .44299 .78279 .44431 .77061 .40145 Metetra
.524 .447 .712 r
.77061 .40145 .78279 .44431 .80644 .4483 .79422 .40628 Metetra
.502 .438 .717 r
.79422 .40628 .80644 .4483 .83034 .45127 .8184 .41344 Metetra
.416 .4 .734 r
.8184 .41344 .83034 .45127 .85517 .46014 .84369 .42779 Metetra
.211 .297 .734 r
.84369 .42779 .85517 .46014 .88064 .4709 .87072 .45372 Metetra
.676 .274 0 r
.87072 .45372 .88064 .4709 .91185 .52741 .90237 .51434 Metetra
.636 .734 .919 r
.26944 .47738 .28155 .48866 .30002 .48337 .28794 .47249 Metetra
.635 .743 .926 r
.28794 .47249 .30002 .48337 .31862 .47809 .30659 .46757 Metetra
.633 .75 .933 r
.30659 .46757 .31862 .47809 .33736 .47273 .32539 .46266 Metetra
.631 .76 .94 r
.32539 .46266 .33736 .47273 .35624 .46746 .34433 .45772 Metetra
.627 .767 .947 r
.34433 .45772 .35624 .46746 .37526 .46208 .36342 .45283 Metetra
.623 .777 .955 r
.36342 .45283 .37526 .46208 .39443 .45689 .38267 .44794 Metetra
.617 .783 .961 r
.38267 .44794 .39443 .45689 .41375 .45156 .40206 .44315 Metetra
.611 .794 .969 r
.40206 .44315 .41375 .45156 .43321 .44649 .42162 .43836 Metetra
.601 .799 .975 r
.42162 .43836 .43321 .44649 .45284 .44129 .44133 .43374 Metetra
.591 .81 .983 r
.44133 .43374 .45284 .44129 .47261 .43642 .46122 .42916 Metetra
.578 .813 .988 r
.46122 .42916 .47261 .43642 .49255 .43144 .48126 .42479 Metetra
.562 .823 .994 r
.48126 .42479 .49255 .43144 .51266 .42685 .50149 .42052 Metetra
.542 .824 .998 r
.50149 .42052 .51266 .42685 .53293 .42221 .5219 .41653 Metetra
.517 .829 1 r
.5219 .41653 .53293 .42221 .55339 .41801 .54249 .41271 Metetra
.487 .826 .999 r
.54249 .41271 .55339 .41801 .57403 .41386 .56328 .40925 Metetra
.447 .822 .992 r
.56328 .40925 .57403 .41386 .59488 .4102 .58428 .40609 Metetra
.4 .808 .979 r
.58428 .40609 .59488 .4102 .61592 .40676 .6055 .4034 Metetra
.335 .786 .953 r
.6055 .4034 .61592 .40676 .63719 .40384 .62695 .40118 Metetra
.258 .749 .915 r
.62695 .40118 .63719 .40384 .65869 .40139 .64865 .39959 Metetra
.159 .692 .852 r
.64865 .39959 .65869 .40139 .68045 .39953 .67063 .39877 Metetra
.04 .609 .758 r
.67063 .39877 .68045 .39953 .70249 .3985 .69292 .39886 Metetra
.094 0 0 r
.69292 .39886 .70249 .3985 .72483 .39818 .71555 .40019 Metetra
.24 0 0 r
.71555 .40019 .72483 .39818 .74753 .3993 .73857 .40294 Metetra
.374 0 0 r
.73857 .40294 .74753 .3993 .77061 .40145 .76208 .40785 Metetra
.492 0 0 r
.76208 .40785 .77061 .40145 .79422 .40628 .78615 .41531 Metetra
.587 .078 .008 r
.78615 .41531 .79422 .40628 .8184 .41344 .811 .42703 Metetra
.656 .192 .14 r
.811 .42703 .8184 .41344 .84369 .42779 .83685 .44431 Metetra
.717 .278 .206 r
.83685 .44431 .84369 .42779 .87072 .45372 .86421 .47068 Metetra
.736 .298 .21 r
.86421 .47068 .87072 .45372 .90237 .51434 .89274 .50108 Metetra
.64 .735 .918 r
.25717 .46595 .26944 .47738 .28794 .47249 .27576 .46082 Metetra
.64 .732 .915 r
.27576 .46082 .28794 .47249 .30659 .46757 .29449 .45566 Metetra
.64 .729 .913 r
.29449 .45566 .30659 .46757 .32539 .46266 .31337 .45048 Metetra
.638 .726 .911 r
.31337 .45048 .32539 .46266 .34433 .45772 .3324 .44532 Metetra
.638 .723 .91 r
.3324 .44532 .34433 .45772 .36342 .45283 .35158 .44015 Metetra
.636 .719 .908 r
.35158 .44015 .36342 .45283 .38267 .44794 .3709 .43505 Metetra
.635 .717 .907 r
.3709 .43505 .38267 .44794 .40206 .44315 .39038 .42997 Metetra
.632 .712 .905 r
.39038 .42997 .40206 .44315 .42162 .43836 .41002 .42499 Metetra
.63 .71 .904 r
.41002 .42499 .42162 .43836 .44133 .43374 .42982 .42007 Metetra
.626 .705 .903 r
.42982 .42007 .44133 .43374 .46122 .42916 .44978 .41531 Metetra
.623 .703 .902 r
.44978 .41531 .46122 .42916 .48126 .42479 .46991 .41066 Metetra
.618 .698 .901 r
.46991 .41066 .48126 .42479 .50149 .42052 .49021 .40623 Metetra
.614 .695 .902 r
.49021 .40623 .50149 .42052 .5219 .41653 .5107 .40197 Metetra
.607 .69 .901 r
.5107 .40197 .5219 .41653 .54249 .41271 .53137 .39801 Metetra
.601 .686 .902 r
.53137 .39801 .54249 .41271 .56328 .40925 .55224 .39434 Metetra
.592 .68 .903 r
.55224 .39434 .56328 .40925 .58428 .40609 .57331 .39107 Metetra
.582 .676 .905 r
.57331 .39107 .58428 .40609 .6055 .4034 .59461 .38824 Metetra
.569 .67 .906 r
.59461 .38824 .6055 .4034 .62695 .40118 .61614 .38598 Metetra
.553 .663 .91 r
.61614 .38598 .62695 .40118 .64865 .39959 .63793 .38441 Metetra
.532 .655 .914 r
.63793 .38441 .64865 .39959 .67063 .39877 .65999 .38369 Metetra
.504 .644 .919 r
.65999 .38369 .67063 .39877 .69292 .39886 .68238 .38405 Metetra
.466 .631 .925 r
.68238 .38405 .69292 .39886 .71555 .40019 .70512 .38575 Metetra
.409 .608 .93 r
.70512 .38575 .71555 .40019 .73857 .40294 .72828 .38926 Metetra
.325 .575 .931 r
.72828 .38926 .73857 .40294 .76208 .40785 .75194 .39498 Metetra
.194 .51 .912 r
.75194 .39498 .76208 .40785 .78615 .41531 .77622 .40383 Metetra
.002 .404 .853 r
.77622 .40383 .78615 .41531 .811 .42703 .80125 .41648 Metetra
0 .247 .732 r
.80125 .41648 .811 .42703 .83685 .44431 .82727 .43435 Metetra
0 .106 .605 r
.82727 .43435 .83685 .44431 .86421 .47068 .85441 .4576 Metetra
0 .041 .579 r
.85441 .4576 .86421 .47068 .89274 .50108 .88296 .4876 Metetra
.638 .735 .918 r
.24474 .45438 .25717 .46595 .27576 .46082 .26339 .44926 Metetra
.637 .736 .92 r
.26339 .44926 .27576 .46082 .29449 .45566 .2822 .44411 Metetra
.636 .738 .922 r
.2822 .44411 .29449 .45566 .31337 .45048 .30115 .43896 Metetra
.635 .739 .923 r
.30115 .43896 .31337 .45048 .3324 .44532 .32025 .43381 Metetra
.634 .74 .925 r
.32025 .43381 .3324 .44532 .35158 .44015 .3395 .42868 Metetra
.632 .742 .927 r
.3395 .42868 .35158 .44015 .3709 .43505 .35891 .42357 Metetra
.629 .743 .929 r
.35891 .42357 .3709 .43505 .39038 .42997 .37847 .41854 Metetra
.626 .744 .932 r
.37847 .41854 .39038 .42997 .41002 .42499 .39819 .41356 Metetra
.623 .744 .934 r
.39819 .41356 .41002 .42499 .42982 .42007 .41807 .4087 Metetra
.618 .746 .937 r
.41807 .4087 .42982 .42007 .44978 .41531 .43813 .40394 Metetra
.613 .745 .94 r
.43813 .40394 .44978 .41531 .46991 .41066 .45835 .39935 Metetra
.607 .746 .943 r
.45835 .39935 .46991 .41066 .49021 .40623 .47875 .39493 Metetra
.6 .745 .946 r
.47875 .39493 .49021 .40623 .5107 .40197 .49933 .39075 Metetra
.591 .745 .95 r
.49933 .39075 .5107 .40197 .53137 .39801 .5201 .38682 Metetra
.58 .743 .954 r
.5201 .38682 .53137 .39801 .55224 .39434 .54107 .38324 Metetra
.567 .741 .958 r
.54107 .38324 .55224 .39434 .57331 .39107 .56225 .38004 Metetra
.551 .738 .963 r
.56225 .38004 .57331 .39107 .59461 .38824 .58366 .37733 Metetra
.531 .733 .967 r
.58366 .37733 .59461 .38824 .61614 .38598 .60531 .37521 Metetra
.504 .725 .972 r
.60531 .37521 .61614 .38598 .63793 .38441 .62721 .37381 Metetra
.47 .714 .976 r
.62721 .37381 .63793 .38441 .65999 .38369 .64941 .37334 Metetra
.423 .697 .978 r
.64941 .37334 .65999 .38369 .68238 .38405 .67193 .374 Metetra
.358 .67 .975 r
.67193 .374 .68238 .38405 .70512 .38575 .69481 .37614 Metetra
.267 .626 .961 r
.69481 .37614 .70512 .38575 .72828 .38926 .71813 .38015 Metetra
.141 .556 .926 r
.71813 .38015 .72828 .38926 .75194 .39498 .74197 .38659 Metetra
0 .45 .853 r
.74197 .38659 .75194 .39498 .77622 .40383 .76643 .3961 Metetra
0 .311 .741 r
.76643 .3961 .77622 .40383 .80125 .41648 .79165 .40948 Metetra
0 .167 .608 r
.79165 .40948 .80125 .41648 .82727 .43435 .81778 .42719 Metetra
.469 0 0 r
.81778 .42719 .82727 .43435 .85441 .4576 .84494 .44934 Metetra
.467 0 0 r
.84494 .44934 .85441 .4576 .88296 .4876 .87303 .47391 Metetra
.638 .735 .918 r
.23214 .44265 .24474 .45438 .26339 .44926 .25087 .43745 Metetra
.637 .735 .919 r
.25087 .43745 .26339 .44926 .2822 .44411 .26975 .43222 Metetra
.637 .734 .919 r
.26975 .43222 .2822 .44411 .30115 .43896 .28877 .42698 Metetra
.636 .734 .919 r
.28877 .42698 .30115 .43896 .32025 .43381 .30795 .42175 Metetra
.634 .734 .92 r
.30795 .42175 .32025 .43381 .3395 .42868 .32729 .41653 Metetra
.633 .733 .92 r
.32729 .41653 .3395 .42868 .35891 .42357 .34678 .41134 Metetra
.63 .732 .921 r
.34678 .41134 .35891 .42357 .37847 .41854 .36642 .40622 Metetra
.628 .732 .922 r
.36642 .40622 .37847 .41854 .39819 .41356 .38623 .40116 Metetra
.625 .731 .923 r
.38623 .40116 .39819 .41356 .41807 .4087 .4062 .39621 Metetra
.621 .729 .924 r
.4062 .39621 .41807 .4087 .43813 .40394 .42633 .39136 Metetra
.617 .728 .925 r
.42633 .39136 .43813 .40394 .45835 .39935 .44664 .38668 Metetra
.612 .726 .927 r
.44664 .38668 .45835 .39935 .47875 .39493 .46713 .38218 Metetra
.605 .724 .928 r
.46713 .38218 .47875 .39493 .49933 .39075 .4878 .3779 Metetra
.598 .721 .93 r
.4878 .3779 .49933 .39075 .5201 .38682 .50867 .37389 Metetra
.589 .717 .932 r
.50867 .37389 .5201 .38682 .54107 .38324 .52973 .37022 Metetra
.579 .713 .934 r
.52973 .37022 .54107 .38324 .56225 .38004 .55101 .36693 Metetra
.566 .708 .937 r
.55101 .36693 .56225 .38004 .58366 .37733 .57251 .36413 Metetra
.55 .701 .939 r
.57251 .36413 .58366 .37733 .60531 .37521 .59425 .36192 Metetra
.53 .692 .942 r
.59425 .36192 .60531 .37521 .62721 .37381 .61625 .36044 Metetra
.505 .68 .944 r
.61625 .36044 .62721 .37381 .64941 .37334 .63854 .35988 Metetra
.472 .664 .946 r
.63854 .35988 .64941 .37334 .67193 .374 .66116 .36046 Metetra
.428 .641 .946 r
.66116 .36046 .67193 .374 .69481 .37614 .68414 .36252 Metetra
.369 .608 .942 r
.68414 .36252 .69481 .37614 .71813 .38015 .70755 .36645 Metetra
.288 .56 .929 r
.70755 .36645 .71813 .38015 .74197 .38659 .73147 .37283 Metetra
.183 .494 .904 r
.73147 .37283 .74197 .38659 .76643 .3961 .75602 .38228 Metetra
.051 .403 .857 r
.75602 .38228 .76643 .3961 .79165 .40948 .78133 .39562 Metetra
0 .3 .792 r
.78133 .39562 .79165 .40948 .81778 .42719 .80754 .4133 Metetra
0 .203 .72 r
.80754 .4133 .81778 .42719 .84494 .44934 .83477 .43543 Metetra
0 .162 .687 r
.83477 .43543 .84494 .44934 .87303 .47391 .86293 .46001 Metetra
.64 .735 .918 r
.21937 .43076 .23214 .44265 .25087 .43745 .23818 .42538 Metetra
.64 .733 .916 r
.23818 .42538 .25087 .43745 .26975 .43222 .25714 .41997 Metetra
.639 .732 .915 r
.25714 .41997 .26975 .43222 .28877 .42698 .27626 .41454 Metetra
.638 .729 .914 r
.27626 .41454 .28877 .42698 .30795 .42175 .29552 .40913 Metetra
.637 .728 .914 r
.29552 .40913 .30795 .42175 .32729 .41653 .31494 .40371 Metetra
.635 .725 .913 r
.31494 .40371 .32729 .41653 .34678 .41134 .33451 .39835 Metetra
.634 .723 .912 r
.33451 .39835 .34678 .41134 .36642 .40622 .35425 .39301 Metetra
.631 .72 .911 r
.35425 .39301 .36642 .40622 .38623 .40116 .37414 .38777 Metetra
.629 .718 .911 r
.37414 .38777 .38623 .40116 .4062 .39621 .39419 .38259 Metetra
.625 .715 .911 r
.39419 .38259 .4062 .39621 .42633 .39136 .41441 .37757 Metetra
.622 .712 .91 r
.41441 .37757 .42633 .39136 .44664 .38668 .43481 .37265 Metetra
.617 .708 .91 r
.43481 .37265 .44664 .38668 .46713 .38218 .45538 .36795 Metetra
.612 .704 .91 r
.45538 .36795 .46713 .38218 .4878 .3779 .47614 .36343 Metetra
.605 .699 .91 r
.47614 .36343 .4878 .3779 .50867 .37389 .49709 .3592 Metetra
.599 .695 .91 r
.49709 .3592 .50867 .37389 .52973 .37022 .51824 .35526 Metetra
.59 .688 .91 r
.51824 .35526 .52973 .37022 .55101 .36693 .53959 .35172 Metetra
.58 .682 .91 r
.53959 .35172 .55101 .36693 .57251 .36413 .56117 .34862 Metetra
.567 .673 .91 r
.56117 .34862 .57251 .36413 .59425 .36192 .58299 .3461 Metetra
.552 .663 .91 r
.58299 .3461 .59425 .36192 .61625 .36044 .60507 .34426 Metetra
.533 .65 .909 r
.60507 .34426 .61625 .36044 .63854 .35988 .62742 .34328 Metetra
.509 .633 .908 r
.62742 .34328 .63854 .35988 .66116 .36046 .6501 .3434 Metetra
.48 .613 .905 r
.6501 .3434 .66116 .36046 .68414 .36252 .67312 .34486 Metetra
.44 .584 .9 r
.67312 .34486 .68414 .36252 .70755 .36645 .69657 .34814 Metetra
.391 .548 .891 r
.69657 .34814 .70755 .36645 .73147 .37283 .7205 .35365 Metetra
.322 .497 .876 r
.7205 .35365 .73147 .37283 .75602 .38228 .74504 .36232 Metetra
.237 .435 .853 r
.74504 .36232 .75602 .38228 .78133 .39562 .77033 .37482 Metetra
.119 .348 .813 r
.77033 .37482 .78133 .39562 .80754 .4133 .79657 .3926 Metetra
0 .257 .764 r
.79657 .3926 .80754 .4133 .83477 .43543 .82393 .41582 Metetra
0 .133 .68 r
.82393 .41582 .83477 .43543 .86293 .46001 .85268 .44588 Metetra
.636 .734 .919 r
.20643 .41871 .21937 .43076 .23818 .42538 .2253 .41342 Metetra
.636 .737 .921 r
.2253 .41342 .23818 .42538 .25714 .41997 .24433 .40808 Metetra
.634 .739 .924 r
.24433 .40808 .25714 .41997 .27626 .41454 .26351 .40276 Metetra
.634 .743 .927 r
.26351 .40276 .27626 .41454 .29552 .40913 .28284 .3974 Metetra
.631 .744 .929 r
.28284 .3974 .29552 .40913 .31494 .40371 .30233 .3921 Metetra
.63 .748 .932 r
.30233 .3921 .31494 .40371 .33451 .39835 .32199 .38677 Metetra
.626 .749 .935 r
.32199 .38677 .33451 .39835 .35425 .39301 .3418 .38156 Metetra
.625 .752 .938 r
.3418 .38156 .35425 .39301 .37414 .38777 .36177 .37634 Metetra
.619 .752 .941 r
.36177 .37634 .37414 .38777 .39419 .38259 .38192 .37128 Metetra
.617 .755 .944 r
.38192 .37128 .39419 .38259 .41441 .37757 .40223 .36626 Metetra
.61 .755 .947 r
.40223 .36626 .41441 .37757 .43481 .37265 .42272 .36146 Metetra
.605 .757 .951 r
.42272 .36146 .43481 .37265 .45538 .36795 .4434 .35674 Metetra
.597 .755 .954 r
.4434 .35674 .45538 .36795 .47614 .36343 .46425 .35231 Metetra
.59 .756 .958 r
.46425 .35231 .47614 .36343 .49709 .3592 .48531 .34804 Metetra
.578 .753 .96 r
.48531 .34804 .49709 .3592 .51824 .35526 .50656 .34414 Metetra
.568 .751 .964 r
.50656 .34414 .51824 .35526 .53959 .35172 .52803 .34053 Metetra
.553 .745 .966 r
.52803 .34053 .53959 .35172 .56117 .34862 .54972 .33739 Metetra
.538 .74 .969 r
.54972 .33739 .56117 .34862 .58299 .3461 .57165 .33473 Metetra
.518 .73 .97 r
.57165 .33473 .58299 .3461 .60507 .34426 .59384 .33271 Metetra
.495 .717 .97 r
.59384 .33271 .60507 .34426 .62742 .34328 .61631 .33145 Metetra
.468 .7 .969 r
.61631 .33145 .62742 .34328 .6501 .3434 .63908 .33112 Metetra
.433 .675 .964 r
.63908 .33112 .6501 .3434 .67312 .34486 .66219 .33204 Metetra
.393 .644 .957 r
.66219 .33204 .67312 .34486 .69657 .34814 .6857 .3344 Metetra
.338 .597 .942 r
.6857 .3344 .69657 .34814 .7205 .35365 .70967 .33894 Metetra
.274 .542 .921 r
.70967 .33894 .7205 .35365 .74504 .36232 .7342 .34607 Metetra
.173 .452 .879 r
.7342 .34607 .74504 .36232 .77033 .37482 .75948 .35754 Metetra
.032 .339 .819 r
.75948 .35754 .77033 .37482 .79657 .3926 .78572 .37466 Metetra
0 .161 .699 r
.78572 .37466 .79657 .3926 .82393 .41582 .81341 .40103 Metetra
0 .048 .591 r
.81341 .40103 .82393 .41582 .85268 .44588 .84226 .43152 Metetra
.647 .737 .915 r
.19331 .4065 .20643 .41871 .2253 .41342 .21231 .40063 Metetra
.646 .729 .909 r
.21231 .40063 .2253 .41342 .24433 .40808 .23145 .39477 Metetra
.647 .722 .903 r
.23145 .39477 .24433 .40808 .26351 .40276 .25075 .38882 Metetra
.644 .713 .897 r
.25075 .38882 .26351 .40276 .28284 .3974 .27019 .38296 Metetra
.645 .707 .892 r
.27019 .38296 .28284 .3974 .30233 .3921 .28979 .37698 Metetra
.64 .697 .886 r
.28979 .37698 .30233 .3921 .32199 .38677 .30953 .37118 Metetra
.642 .692 .881 r
.30953 .37118 .32199 .38677 .3418 .38156 .32945 .36524 Metetra
.636 .681 .876 r
.32945 .36524 .3418 .38156 .36177 .37634 .34951 .35955 Metetra
.637 .677 .871 r
.34951 .35955 .36177 .37634 .38192 .37128 .36975 .35373 Metetra
.63 .665 .866 r
.36975 .35373 .38192 .37128 .40223 .36626 .39014 .34824 Metetra
.631 .661 .861 r
.39014 .34824 .40223 .36626 .42272 .36146 .41072 .34263 Metetra
.623 .65 .856 r
.41072 .34263 .42272 .36146 .4434 .35674 .43146 .33741 Metetra
.623 .645 .851 r
.43146 .33741 .4434 .35674 .46425 .35231 .45238 .33213 Metetra
.614 .633 .846 r
.45238 .33213 .46425 .35231 .48531 .34804 .47349 .3273 Metetra
.613 .627 .842 r
.47349 .3273 .48531 .34804 .50656 .34414 .4948 .32251 Metetra
.604 .616 .836 r
.4948 .32251 .50656 .34414 .52803 .34053 .51631 .31821 Metetra
.6 .608 .831 r
.51631 .31821 .52803 .34053 .54972 .33739 .53804 .31413 Metetra
.591 .596 .825 r
.53804 .31413 .54972 .33739 .57165 .33473 .55999 .31057 Metetra
.584 .585 .82 r
.55999 .31057 .57165 .33473 .59384 .33271 .58218 .30749 Metetra
.575 .572 .813 r
.58218 .30749 .59384 .33271 .61631 .33145 .60464 .305 Metetra
.563 .557 .806 r
.60464 .305 .61631 .33145 .63908 .33112 .62738 .30334 Metetra
.553 .543 .798 r
.62738 .30334 .63908 .33112 .66219 .33204 .65042 .30242 Metetra
.535 .521 .787 r
.65042 .30242 .66219 .33204 .6857 .3344 .67382 .30294 Metetra
.523 .504 .777 r
.67382 .30294 .6857 .3344 .70967 .33894 .6976 .30451 Metetra
.494 .471 .761 r
.6976 .30451 .70967 .33894 .7342 .34607 .72189 .30882 Metetra
.472 .445 .747 r
.72189 .30882 .7342 .34607 .75948 .35754 .74675 .3155 Metetra
.402 .382 .722 r
.74675 .3155 .75948 .35754 .78572 .37466 .77261 .32954 Metetra
.281 .294 .696 r
.77261 .32954 .78572 .37466 .81341 .40103 .80007 .35543 Metetra
0 0 .556 r
.80007 .35543 .81341 .40103 .84226 .43152 .83167 .41692 Metetra
.612 .727 .927 r
.18002 .39412 .19331 .4065 .21231 .40063 .19894 .38967 Metetra
.604 .752 .948 r
.19894 .38967 .21231 .40063 .23145 .39477 .21802 .38528 Metetra
.599 .78 .967 r
.21802 .38528 .23145 .39477 .25075 .38882 .23728 .3807 Metetra
.576 .802 .985 r
.23728 .3807 .25075 .38882 .27019 .38296 .25669 .37638 Metetra
.564 .831 .995 r
.25669 .37638 .27019 .38296 .28979 .37698 .27631 .37174 Metetra
.516 .84 .999 r
.27631 .37174 .28979 .37698 .30953 .37118 .29606 .36753 Metetra
.489 .857 .987 r
.29606 .36753 .30953 .37118 .32945 .36524 .31603 .36289 Metetra
.404 .835 .953 r
.31603 .36289 .32945 .36524 .34951 .35955 .33615 .35883 Metetra
.355 .823 .902 r
.33615 .35883 .34951 .35955 .36975 .35373 .35648 .35429 Metetra
.238 .755 .818 r
.35648 .35429 .36975 .35373 .39014 .34824 .37697 .35044 Metetra
.177 .71 .73 r
.37697 .35044 .39014 .34824 .41072 .34263 .39768 .34608 Metetra
.39768 .34608 .41072 .34263 .43146 .33741 .41857 .3425 Metetra
.001 0 0 r
.41857 .3425 .43146 .33741 .45238 .33213 .43968 .33847 Metetra
.1 0 0 r
.43968 .33847 .45238 .33213 .47349 .3273 .46098 .33523 Metetra
.144 0 0 r
.46098 .33523 .47349 .3273 .4948 .32251 .48252 .33168 Metetra
.215 0 0 r
.48252 .33168 .4948 .32251 .51631 .31821 .50427 .32888 Metetra
.249 0 0 r
.50427 .32888 .51631 .31821 .53804 .31413 .52627 .326 Metetra
.295 0 0 r
.52627 .326 .53804 .31413 .55999 .31057 .54851 .32377 Metetra
.324 0 0 r
.54851 .32377 .55999 .31057 .58218 .30749 .57102 .32181 Metetra
.352 0 0 r
.57102 .32181 .58218 .30749 .60464 .305 .59381 .32031 Metetra
.381 0 .01 r
.59381 .32031 .60464 .305 .62738 .30334 .6169 .31958 Metetra
.392 0 .032 r
.6169 .31958 .62738 .30334 .65042 .30242 .64029 .31899 Metetra
.424 0 .052 r
.64029 .31899 .65042 .30242 .67382 .30294 .66405 .31992 Metetra
.419 0 .054 r
.66405 .31992 .67382 .30294 .6976 .30451 .68812 .32048 Metetra
.459 0 .053 r
.68812 .32048 .6976 .30451 .72189 .30882 .7127 .32378 Metetra
.432 0 .017 r
.7127 .32378 .72189 .30882 .74675 .3155 .73758 .32602 Metetra
.508 0 0 r
.73758 .32602 .74675 .3155 .77261 .32954 .76331 .33433 Metetra
.485 0 0 r
.76331 .33433 .77261 .32954 .80007 .35543 .78967 .34459 Metetra
.779 .327 0 r
.78967 .34459 .80007 .35543 .83167 .41692 .8209 .40209 Metetra
.638 .735 .918 r
.16654 .38157 .18002 .39412 .19894 .38967 .18565 .37592 Metetra
.641 .718 .903 r
.18565 .37592 .19894 .38967 .21802 .38528 .20492 .37012 Metetra
.635 .696 .889 r
.20492 .37012 .21802 .38528 .23728 .3807 .22433 .36454 Metetra
.64 .685 .876 r
.22433 .36454 .23728 .3807 .25669 .37638 .24394 .35858 Metetra
.63 .661 .862 r
.24394 .35858 .25669 .37638 .27631 .37174 .26366 .3531 Metetra
.637 .655 .851 r
.26366 .3531 .27631 .37174 .29606 .36753 .28359 .34706 Metetra
.623 .631 .837 r
.28359 .34706 .29606 .36753 .31603 .36289 .30364 .3417 Metetra
.632 .628 .829 r
.30364 .3417 .31603 .36289 .33615 .35883 .32391 .33565 Metetra
.616 .603 .815 r
.32391 .33565 .33615 .35883 .35648 .35429 .34429 .33046 Metetra
.625 .603 .808 r
.34429 .33046 .35648 .35429 .37697 .35044 .3649 .32449 Metetra
.608 .579 .795 r
.3649 .32449 .37697 .35044 .39768 .34608 .38565 .31949 Metetra
.617 .58 .789 r
.38565 .31949 .39768 .34608 .41857 .3425 .40661 .31372 Metetra
.601 .557 .777 r
.40661 .31372 .41857 .3425 .43968 .33847 .42773 .30896 Metetra
.608 .557 .772 r
.42773 .30896 .43968 .33847 .46098 .33523 .44907 .30351 Metetra
.594 .537 .761 r
.44907 .30351 .46098 .33523 .48252 .33168 .47059 .29901 Metetra
.598 .536 .755 r
.47059 .29901 .48252 .33168 .50427 .32888 .49234 .29404 Metetra
.587 .519 .745 r
.49234 .29404 .50427 .32888 .52627 .326 .51429 .28986 Metetra
.587 .514 .739 r
.51429 .28986 .52627 .326 .54851 .32377 .53647 .28552 Metetra
.581 .502 .731 r
.53647 .28552 .54851 .32377 .57102 .32181 .55888 .28167 Metetra
.576 .492 .723 r
.55888 .28167 .57102 .32181 .59381 .32031 .58154 .27814 Metetra
.575 .485 .716 r
.58154 .27814 .59381 .32031 .6169 .31958 .60446 .27457 Metetra
.565 .47 .706 r
.60446 .27457 .6169 .31958 .64029 .31899 .62766 .27194 Metetra
.571 .469 .699 r
.62766 .27194 .64029 .31899 .66405 .31992 .6511 .26839 Metetra
.556 .448 .686 r
.6511 .26839 .66405 .31992 .68812 .32048 .67488 .26655 Metetra
.574 .455 .679 r
.67488 .26655 .68812 .32048 .7127 .32378 .69882 .26202 Metetra
.556 .428 .662 r
.69882 .26202 .7127 .32378 .73758 .32602 .72317 .25981 Metetra
.597 .449 .651 r
.72317 .25981 .73758 .32602 .76331 .33433 .74724 .24955 Metetra
.599 .429 .623 r
.74724 .24955 .76331 .33433 .78967 .34459 .7712 .23564 Metetra
.737 .506 .579 r
.7712 .23564 .78967 .34459 .8209 .40209 .78971 .15902 Metetra
.648 .737 .914 r
.15287 .36884 .16654 .38157 .18565 .37592 .17211 .36265 Metetra
.647 .73 .909 r
.17211 .36265 .18565 .37592 .20492 .37012 .1915 .35643 Metetra
.648 .725 .905 r
.1915 .35643 .20492 .37012 .22433 .36454 .21104 .35014 Metetra
.646 .715 .898 r
.21104 .35014 .22433 .36454 .24394 .35858 .23074 .3439 Metetra
.646 .712 .896 r
.23074 .3439 .24394 .35858 .26366 .3531 .2506 .33757 Metetra
.643 .7 .888 r
.2506 .33757 .26366 .3531 .28359 .34706 .27061 .33133 Metetra
.643 .699 .887 r
.27061 .33133 .28359 .34706 .30364 .3417 .29079 .32501 Metetra
.639 .686 .878 r
.29079 .32501 .30364 .3417 .32391 .33565 .31113 .31884 Metetra
.639 .686 .878 r
.31113 .31884 .32391 .33565 .34429 .33046 .33164 .31258 Metetra
.634 .671 .868 r
.33164 .31258 .34429 .33046 .3649 .32449 .35231 .3065 Metetra
.634 .672 .868 r
.35231 .3065 .3649 .32449 .38565 .31949 .37317 .30037 Metetra
.629 .657 .858 r
.37317 .30037 .38565 .31949 .40661 .31372 .3942 .29445 Metetra
.628 .656 .858 r
.3942 .29445 .40661 .31372 .42773 .30896 .41541 .2885 Metetra
.622 .642 .849 r
.41541 .2885 .42773 .30896 .44907 .30351 .43681 .2828 Metetra
.621 .64 .848 r
.43681 .2828 .44907 .30351 .47059 .29901 .45841 .27712 Metetra
.615 .626 .838 r
.45841 .27712 .47059 .29901 .49234 .29404 .4802 .27168 Metetra
.613 .622 .836 r
.4802 .27168 .49234 .29404 .51429 .28986 .5022 .26631 Metetra
.608 .609 .827 r
.5022 .26631 .51429 .28986 .53647 .28552 .52442 .26117 Metetra
.605 .601 .821 r
.52442 .26117 .53647 .28552 .55888 .28167 .54686 .25614 Metetra
.602 .591 .813 r
.54686 .25614 .55888 .28167 .58154 .27814 .56953 .25123 Metetra
.598 .579 .803 r
.56953 .25123 .58154 .27814 .60446 .27457 .59244 .24644 Metetra
.598 .571 .795 r
.59244 .24644 .60446 .27457 .62766 .27194 .61558 .24153 Metetra
.596 .556 .779 r
.61558 .24153 .62766 .27194 .6511 .26839 .63897 .23655 Metetra
.603 .552 .77 r
.63897 .23655 .6511 .26839 .67488 .26655 .66257 .23078 Metetra
.606 .533 .747 r
.66257 .23078 .67488 .26655 .69882 .26202 .68636 .22417 Metetra
.628 .538 .733 r
.68636 .22417 .69882 .26202 .72317 .25981 .71021 .21464 Metetra
.645 .522 .699 r
.71021 .21464 .72317 .25981 .74724 .24955 .73395 .20087 Metetra
.701 .546 .674 r
.73395 .20087 .74724 .24955 .7712 .23564 .75695 .17577 Metetra
.707 .527 .643 r
.75695 .17577 .7712 .23564 .78971 .15902 .77922 .14301 Metetra
.644 .736 .916 r
.13902 .35594 .15287 .36884 .17211 .36265 .15831 .34983 Metetra
.644 .739 .918 r
.15831 .34983 .17211 .36265 .1915 .35643 .17776 .34367 Metetra
.643 .741 .92 r
.17776 .34367 .1915 .35643 .21104 .35014 .19737 .3375 Metetra
.643 .745 .923 r
.19737 .3375 .21104 .35014 .23074 .3439 .21714 .33127 Metetra
.641 .746 .925 r
.21714 .33127 .23074 .3439 .2506 .33757 .23707 .32508 Metetra
.641 .75 .928 r
.23707 .32508 .2506 .33757 .27061 .33133 .25717 .31882 Metetra
.638 .751 .93 r
.25717 .31882 .27061 .33133 .29079 .32501 .27742 .31264 Metetra
.638 .755 .933 r
.27742 .31264 .29079 .32501 .31113 .31884 .29786 .3064 Metetra
.634 .754 .935 r
.29786 .3064 .31113 .31884 .33164 .31258 .31845 .30028 Metetra
.634 .758 .937 r
.31845 .30028 .33164 .31258 .35231 .3065 .33923 .2941 Metetra
.629 .757 .939 r
.33923 .2941 .35231 .3065 .37317 .30037 .36018 .28808 Metetra
.628 .76 .942 r
.36018 .28808 .37317 .30037 .3942 .29445 .38132 .28202 Metetra
.623 .758 .943 r
.38132 .28202 .3942 .29445 .41541 .2885 .40263 .27613 Metetra
.621 .76 .945 r
.40263 .27613 .41541 .2885 .43681 .2828 .42415 .27023 Metetra
.616 .756 .945 r
.42415 .27023 .43681 .2828 .45841 .27712 .44586 .26451 Metetra
.614 .757 .947 r
.44586 .26451 .45841 .27712 .4802 .27168 .46777 .25882 Metetra
.61 .753 .946 r
.46777 .25882 .4802 .27168 .5022 .26631 .48989 .25328 Metetra
.608 .751 .946 r
.48989 .25328 .5022 .26631 .52442 .26117 .51223 .24777 Metetra
.606 .746 .943 r
.51223 .24777 .52442 .26117 .54686 .25614 .53478 .24234 Metetra
.605 .741 .94 r
.53478 .24234 .54686 .25614 .56953 .25123 .55757 .23691 Metetra
.608 .735 .935 r
.55757 .23691 .56953 .25123 .59244 .24644 .58058 .23136 Metetra
.612 .726 .926 r
.58058 .23136 .59244 .24644 .61558 .24153 .60382 .22563 Metetra
.624 .72 .915 r
.60382 .22563 .61558 .24153 .63897 .23655 .62728 .21931 Metetra
.636 .707 .898 r
.62728 .21931 .63897 .23655 .66257 .23078 .65094 .21229 Metetra
.662 .703 .878 r
.65094 .21229 .66257 .23078 .68636 .22417 .67474 .20348 Metetra
.686 .689 .847 r
.67474 .20348 .68636 .22417 .71021 .21464 .69862 .19248 Metetra
.731 .694 .815 r
.69862 .19248 .71021 .21464 .73395 .20087 .72235 .17685 Metetra
.765 .693 .783 r
.72235 .17685 .73395 .20087 .75695 .17577 .74583 .15634 Metetra
.852 .764 .764 r
.74583 .15634 .75695 .17577 .77922 .14301 .76857 .12675 Metetra
.65 .738 .913 r
.12497 .34286 .13902 .35594 .15831 .34983 .14438 .33635 Metetra
.65 .733 .91 r
.14438 .33635 .15831 .34983 .17776 .34367 .16394 .3298 Metetra
.65 .729 .907 r
.16394 .3298 .17776 .34367 .19737 .3375 .18366 .3232 Metetra
.649 .723 .903 r
.18366 .3232 .19737 .3375 .21714 .33127 .20354 .3166 Metetra
.649 .719 .9 r
.20354 .3166 .21714 .33127 .23707 .32508 .22358 .30994 Metetra
.647 .713 .896 r
.22358 .30994 .23707 .32508 .25717 .31882 .24377 .30331 Metetra
.646 .709 .893 r
.24377 .30331 .25717 .31882 .27742 .31264 .26414 .29663 Metetra
.644 .703 .889 r
.26414 .29663 .27742 .31264 .29786 .3064 .28467 .29001 Metetra
.643 .699 .886 r
.28467 .29001 .29786 .3064 .31845 .30028 .30537 .28335 Metetra
.64 .692 .882 r
.30537 .28335 .31845 .30028 .33923 .2941 .32624 .27677 Metetra
.64 .688 .879 r
.32624 .27677 .33923 .2941 .36018 .28808 .34729 .27015 Metetra
.636 .68 .875 r
.34729 .27015 .36018 .28808 .38132 .28202 .36852 .26365 Metetra
.635 .676 .872 r
.36852 .26365 .38132 .28202 .40263 .27613 .38993 .25712 Metetra
.632 .668 .867 r
.38993 .25712 .40263 .27613 .42415 .27023 .41153 .25071 Metetra
.63 .663 .863 r
.41153 .25071 .42415 .27023 .44586 .26451 .43332 .24429 Metetra
.627 .655 .858 r
.43332 .24429 .44586 .26451 .46777 .25882 .45531 .23798 Metetra
.626 .649 .853 r
.45531 .23798 .46777 .25882 .48989 .25328 .4775 .23165 Metetra
.623 .64 .847 r
.4775 .23165 .48989 .25328 .51223 .24777 .49991 .22538 Metetra
.622 .633 .841 r
.49991 .22538 .51223 .24777 .53478 .24234 .52252 .21906 Metetra
.622 .626 .834 r
.52252 .21906 .53478 .24234 .55757 .23691 .54535 .21264 Metetra
.622 .618 .826 r
.54535 .21264 .55757 .23691 .58058 .23136 .5684 .20605 Metetra
.625 .612 .817 r
.5684 .20605 .58058 .23136 .60382 .22563 .59166 .19904 Metetra
.629 .604 .806 r
.59166 .19904 .60382 .22563 .62728 .21931 .61512 .19152 Metetra
.638 .601 .795 r
.61512 .19152 .62728 .21931 .65094 .21229 .63876 .18291 Metetra
.648 .596 .782 r
.63876 .18291 .65094 .21229 .67474 .20348 .66254 .17303 Metetra
.668 .6 .77 r
.66254 .17303 .67474 .20348 .69862 .19248 .68639 .16077 Metetra
.685 .602 .757 r
.68639 .16077 .69862 .19248 .72235 .17685 .71023 .14607 Metetra
.717 .625 .753 r
.71023 .14607 .72235 .17685 .74583 .15634 .73393 .12777 Metetra
.72 .641 .769 r
.73393 .12777 .74583 .15634 .76857 .12675 .75774 .11023 Metetra
.65 .738 .914 r
.11072 .32959 .12497 .34286 .14438 .33635 .1302 .32302 Metetra
.65 .738 .914 r
.1302 .32302 .14438 .33635 .16394 .3298 .14984 .3164 Metetra
.649 .739 .915 r
.14984 .3164 .16394 .3298 .18366 .3232 .16964 .30975 Metetra
.649 .739 .915 r
.16964 .30975 .18366 .3232 .20354 .3166 .1896 .30304 Metetra
.648 .739 .916 r
.1896 .30304 .20354 .3166 .22358 .30994 .20973 .29634 Metetra
.648 .74 .917 r
.20973 .29634 .22358 .30994 .24377 .30331 .23002 .28958 Metetra
.646 .739 .917 r
.23002 .28958 .24377 .30331 .26414 .29663 .25047 .28284 Metetra
.646 .74 .918 r
.25047 .28284 .26414 .29663 .28467 .29001 .2711 .27606 Metetra
.644 .738 .918 r
.2711 .27606 .28467 .29001 .30537 .28335 .29189 .26932 Metetra
.644 .739 .918 r
.29189 .26932 .30537 .28335 .32624 .27677 .31287 .26255 Metetra
.641 .737 .918 r
.31287 .26255 .32624 .27677 .34729 .27015 .33401 .25583 Metetra
.641 .737 .918 r
.33401 .25583 .34729 .27015 .36852 .26365 .35535 .24908 Metetra
.638 .734 .918 r
.35535 .24908 .36852 .26365 .38993 .25712 .37686 .24241 Metetra
.637 .733 .918 r
.37686 .24241 .38993 .25712 .41153 .25071 .39857 .23571 Metetra
.635 .73 .916 r
.39857 .23571 .41153 .25071 .43332 .24429 .42047 .22908 Metetra
.634 .728 .915 r
.42047 .22908 .43332 .24429 .45531 .23798 .44257 .22242 Metetra
.633 .724 .913 r
.44257 .22242 .45531 .23798 .4775 .23165 .46487 .21578 Metetra
.632 .721 .911 r
.46487 .21578 .4775 .23165 .49991 .22538 .48738 .2091 Metetra
.633 .717 .908 r
.48738 .2091 .49991 .22538 .52252 .21906 .5101 .20234 Metetra
.634 .713 .904 r
.5101 .20234 .52252 .21906 .54535 .21264 .53303 .19543 Metetra
.638 .709 .898 r
.53303 .19543 .54535 .21264 .5684 .20605 .55618 .18826 Metetra
.643 .705 .892 r
.55618 .18826 .5684 .20605 .59166 .19904 .57954 .18071 Metetra
.652 .703 .884 r
.57954 .18071 .59166 .19904 .61512 .19152 .6031 .1725 Metetra
.662 .701 .875 r
.6031 .1725 .61512 .19152 .63876 .18291 .62684 .1635 Metetra
.68 .705 .866 r
.62684 .1635 .63876 .18291 .66254 .17303 .65073 .15314 Metetra
.696 .708 .856 r
.65073 .15314 .66254 .17303 .68639 .16077 .67472 .14137 Metetra
.724 .726 .852 r
.67472 .14137 .68639 .16077 .71023 .14607 .69876 .12747 Metetra
.743 .745 .853 r
.69876 .12747 .71023 .14607 .73393 .12777 .72283 .11215 Metetra
.794 .802 .858 r
.72283 .11215 .73393 .12777 .75774 .11023 .74675 .09346 Metetra
.654 .739 .912 r
.09627 .31614 .11072 .32959 .1302 .32302 .11586 .30923 Metetra
.654 .735 .909 r
.11586 .30923 .1302 .32302 .14984 .3164 .13561 .30228 Metetra
.654 .732 .907 r
.13561 .30228 .14984 .3164 .16964 .30975 .15552 .29528 Metetra
.653 .728 .904 r
.15552 .29528 .16964 .30975 .1896 .30304 .17559 .28825 Metetra
.653 .725 .902 r
.17559 .28825 .1896 .30304 .20973 .29634 .19582 .28116 Metetra
.651 .72 .899 r
.19582 .28116 .20973 .29634 .23002 .28958 .21621 .27407 Metetra
.651 .717 .896 r
.21621 .27407 .23002 .28958 .25047 .28284 .23678 .26693 Metetra
.649 .712 .894 r
.23678 .26693 .25047 .28284 .2711 .27606 .25751 .2598 Metetra
.649 .709 .891 r
.25751 .2598 .2711 .27606 .29189 .26932 .27841 .25262 Metetra
.647 .704 .888 r
.27841 .25262 .29189 .26932 .31287 .26255 .29948 .24547 Metetra
.646 .7 .885 r
.29948 .24547 .31287 .26255 .33401 .25583 .32074 .23828 Metetra
.644 .694 .882 r
.32074 .23828 .33401 .25583 .35535 .24908 .34217 .23112 Metetra
.643 .69 .879 r
.34217 .23112 .35535 .24908 .37686 .24241 .36378 .22392 Metetra
.641 .684 .875 r
.36378 .22392 .37686 .24241 .39857 .23571 .38558 .21676 Metetra
.64 .68 .872 r
.38558 .21676 .39857 .23571 .42047 .22908 .40758 .20955 Metetra
.638 .674 .867 r
.40758 .20955 .42047 .22908 .44257 .22242 .42977 .20236 Metetra
.638 .669 .863 r
.42977 .20236 .44257 .22242 .46487 .21578 .45215 .19511 Metetra
.637 .663 .858 r
.45215 .19511 .46487 .21578 .48738 .2091 .47475 .18781 Metetra
.637 .657 .853 r
.47475 .18781 .48738 .2091 .5101 .20234 .49754 .18039 Metetra
.637 .652 .848 r
.49754 .18039 .5101 .20234 .53303 .19543 .52055 .17279 Metetra
.639 .647 .842 r
.52055 .17279 .53303 .19543 .55618 .18826 .54376 .16495 Metetra
.642 .643 .836 r
.54376 .16495 .55618 .18826 .57954 .18071 .56718 .15669 Metetra
.647 .64 .829 r
.56718 .15669 .57954 .18071 .6031 .1725 .5908 .14794 Metetra
.655 .64 .823 r
.5908 .14794 .6031 .1725 .62684 .1635 .6146 .13838 Metetra
.663 .64 .817 r
.6146 .13838 .62684 .1635 .65073 .15314 .63856 .12796 Metetra
.677 .648 .814 r
.63856 .12796 .65073 .15314 .67472 .14137 .66264 .11627 Metetra
.688 .655 .812 r
.66264 .11627 .67472 .14137 .69876 .12747 .68684 .10356 Metetra
.707 .675 .817 r
.68684 .10356 .69876 .12747 .72283 .11215 .71111 .08951 Metetra
.701 .687 .833 r
.71111 .08951 .72283 .11215 .74675 .09346 .73558 .07641 Metetra
.655 .739 .911 r
.08161 .30249 .09627 .31614 .11586 .30923 .10129 .29544 Metetra
.655 .739 .911 r
.10129 .29544 .11586 .30923 .13561 .30228 .12113 .28833 Metetra
.655 .738 .911 r
.12113 .28833 .13561 .30228 .15552 .29528 .14112 .28118 Metetra
.655 .737 .91 r
.14112 .28118 .15552 .29528 .17559 .28825 .16129 .27397 Metetra
.654 .736 .91 r
.16129 .27397 .17559 .28825 .19582 .28116 .18161 .26674 Metetra
.654 .735 .909 r
.18161 .26674 .19582 .28116 .21621 .27407 .20211 .25945 Metetra
.653 .734 .909 r
.20211 .25945 .21621 .27407 .23678 .26693 .22276 .25215 Metetra
.653 .733 .908 r
.22276 .25215 .23678 .26693 .25751 .2598 .2436 .24479 Metetra
.652 .731 .907 r
.2436 .24479 .25751 .2598 .27841 .25262 .2646 .23743 Metetra
.651 .73 .907 r
.2646 .23743 .27841 .25262 .29948 .24547 .28578 .23002 Metetra
.65 .727 .905 r
.28578 .23002 .29948 .24547 .32074 .23828 .30713 .22261 Metetra
.65 .726 .904 r
.30713 .22261 .32074 .23828 .34217 .23112 .32867 .21516 Metetra
.648 .723 .903 r
.32867 .21516 .34217 .23112 .36378 .22392 .35039 .2077 Metetra
.648 .721 .902 r
.35039 .2077 .36378 .22392 .38558 .21676 .3723 .20021 Metetra
.647 .717 .9 r
.3723 .20021 .38558 .21676 .40758 .20955 .3944 .1927 Metetra
.646 .715 .898 r
.3944 .1927 .40758 .20955 .42977 .20236 .4167 .18514 Metetra
.645 .711 .895 r
.4167 .18514 .42977 .20236 .45215 .19511 .43919 .17754 Metetra
.646 .708 .893 r
.43919 .17754 .45215 .19511 .47475 .18781 .46189 .16984 Metetra
.646 .705 .89 r
.46189 .16984 .47475 .18781 .49754 .18039 .48479 .16203 Metetra
.647 .702 .886 r
.48479 .16203 .49754 .18039 .52055 .17279 .5079 .15405 Metetra
.65 .7 .883 r
.5079 .15405 .52055 .17279 .54376 .16495 .53122 .14583 Metetra
.653 .698 .879 r
.53122 .14583 .54376 .16495 .56718 .15669 .55475 .13729 Metetra
.659 .699 .876 r
.55475 .13729 .56718 .15669 .5908 .14794 .57847 .12827 Metetra
.666 .7 .872 r
.57847 .12827 .5908 .14794 .6146 .13838 .60238 .11873 Metetra
.676 .706 .871 r
.60238 .11873 .6146 .13838 .63856 .12796 .62647 .10843 Metetra
.685 .713 .87 r
.62647 .10843 .63856 .12796 .66264 .11627 .65072 .09744 Metetra
.699 .73 .874 r
.65072 .09744 .66264 .11627 .68684 .10356 .67511 .08552 Metetra
.708 .745 .881 r
.67511 .08552 .68684 .10356 .71111 .08951 .69964 .07309 Metetra
.734 .78 .889 r
.69964 .07309 .71111 .08951 .73558 .07641 .72423 .05908 Metetra
.659 .74 .91 r
.06673 .28864 .08161 .30249 .10129 .29544 .08652 .2813 Metetra
.659 .737 .908 r
.08652 .2813 .10129 .29544 .12113 .28833 .10647 .2739 Metetra
.658 .734 .906 r
.10647 .2739 .12113 .28833 .14112 .28118 .12658 .26644 Metetra
.658 .731 .904 r
.12658 .26644 .14112 .28118 .16129 .27397 .14685 .25894 Metetra
.658 .729 .902 r
.14685 .25894 .16129 .27397 .18161 .26674 .16728 .25138 Metetra
.657 .725 .9 r
.16728 .25138 .18161 .26674 .20211 .25945 .18788 .24379 Metetra
.656 .723 .898 r
.18788 .24379 .20211 .25945 .22276 .25215 .20865 .23613 Metetra
.656 .719 .895 r
.20865 .23613 .22276 .25215 .2436 .24479 .22959 .22845 Metetra
.655 .716 .893 r
.22959 .22845 .2436 .24479 .2646 .23743 .2507 .22071 Metetra
.654 .712 .89 r
.2507 .22071 .2646 .23743 .28578 .23002 .27199 .21294 Metetra
.653 .709 .888 r
.27199 .21294 .28578 .23002 .30713 .22261 .29345 .20512 Metetra
.652 .704 .885 r
.29345 .20512 .30713 .22261 .32867 .21516 .31509 .19728 Metetra
.652 .701 .882 r
.31509 .19728 .32867 .21516 .35039 .2077 .33692 .18938 Metetra
.65 .696 .879 r
.33692 .18938 .35039 .2077 .3723 .20021 .35894 .18146 Metetra
.65 .692 .876 r
.35894 .18146 .3723 .20021 .3944 .1927 .38114 .17347 Metetra
.649 .688 .873 r
.38114 .17347 .3944 .1927 .4167 .18514 .40354 .16545 Metetra
.648 .683 .869 r
.40354 .16545 .4167 .18514 .43919 .17754 .42613 .15734 Metetra
.648 .679 .866 r
.42613 .15734 .43919 .17754 .46189 .16984 .44892 .14916 Metetra
.648 .675 .862 r
.44892 .14916 .46189 .16984 .48479 .16203 .47191 .14086 Metetra
.648 .671 .858 r
.47191 .14086 .48479 .16203 .5079 .15405 .49511 .1324 Metetra
.649 .668 .854 r
.49511 .1324 .5079 .15405 .53122 .14583 .51851 .12376 Metetra
.651 .666 .851 r
.51851 .12376 .53122 .14583 .55475 .13729 .54212 .11485 Metetra
.654 .665 .848 r
.54212 .11485 .55475 .13729 .57847 .12827 .56593 .10563 Metetra
.658 .666 .846 r
.56593 .10563 .57847 .12827 .60238 .11873 .58994 .09599 Metetra
.663 .669 .845 r
.58994 .09599 .60238 .11873 .62647 .10843 .61413 .08591 Metetra
.671 .676 .846 r
.61413 .08591 .62647 .10843 .65072 .09744 .6385 .07527 Metetra
.676 .684 .85 r
.6385 .07527 .65072 .09744 .67511 .08552 .66305 .06421 Metetra
.685 .699 .857 r
.66305 .06421 .67511 .08552 .69964 .07309 .68777 .05261 Metetra
.681 .709 .869 r
.68777 .05261 .69964 .07309 .72423 .05908 .71269 .04148 Metetra
.661 .741 .909 r
.05165 .27459 .06673 .28864 .08652 .2813 .07153 .26704 Metetra
.661 .739 .908 r
.07153 .26704 .08652 .2813 .10647 .2739 .09158 .25942 Metetra
.66 .738 .907 r
.09158 .25942 .10647 .2739 .12658 .26644 .11179 .25176 Metetra
.66 .736 .906 r
.11179 .25176 .12658 .26644 .14685 .25894 .13216 .24403 Metetra
.66 .734 .905 r
.13216 .24403 .14685 .25894 .16728 .25138 .15269 .23624 Metetra
.66 .733 .903 r
.15269 .23624 .16728 .25138 .18788 .24379 .1734 .2284 Metetra
.659 .731 .902 r
.1734 .2284 .18788 .24379 .20865 .23613 .19427 .2205 Metetra
.659 .729 .901 r
.19427 .2205 .20865 .23613 .22959 .22845 .21532 .21255 Metetra
.659 .726 .899 r
.21532 .21255 .22959 .22845 .2507 .22071 .23654 .20454 Metetra
.658 .724 .898 r
.23654 .20454 .2507 .22071 .27199 .21294 .25793 .19648 Metetra
.658 .722 .896 r
.25793 .19648 .27199 .21294 .29345 .20512 .2795 .18836 Metetra
.657 .719 .894 r
.2795 .18836 .29345 .20512 .31509 .19728 .30126 .18019 Metetra
.657 .716 .892 r
.30126 .18019 .31509 .19728 .33692 .18938 .3232 .17196 Metetra
.656 .713 .89 r
.3232 .17196 .33692 .18938 .35894 .18146 .34532 .16368 Metetra
.656 .71 .888 r
.34532 .16368 .35894 .18146 .38114 .17347 .36763 .15533 Metetra
.655 .707 .885 r
.36763 .15533 .38114 .17347 .40354 .16545 .39014 .14692 Metetra
.655 .704 .883 r
.39014 .14692 .40354 .16545 .42613 .15734 .41284 .13843 Metetra
.654 .7 .88 r
.41284 .13843 .42613 .15734 .44892 .14916 .43573 .12986 Metetra
.654 .697 .878 r
.43573 .12986 .44892 .14916 .47191 .14086 .45883 .1212 Metetra
.654 .695 .875 r
.45883 .1212 .47191 .14086 .49511 .1324 .48213 .11242 Metetra
.655 .693 .873 r
.48213 .11242 .49511 .1324 .51851 .12376 .50564 .10349 Metetra
.656 .691 .871 r
.50564 .10349 .51851 .12376 .54212 .11485 .52935 .0944 Metetra
.658 .692 .87 r
.52935 .0944 .54212 .11485 .56593 .10563 .55326 .0851 Metetra
.66 .694 .87 r
.55326 .0851 .56593 .10563 .58994 .09599 .57739 .07557 Metetra
.664 .698 .872 r
.57739 .07557 .58994 .09599 .61413 .08591 .60171 .06575 Metetra
.668 .705 .875 r
.60171 .06575 .61413 .08591 .6385 .07527 .62623 .05568 Metetra
.673 .716 .881 r
.62623 .05568 .6385 .07527 .66305 .06421 .65095 .04528 Metetra
.676 .728 .889 r
.65095 .04528 .66305 .06421 .68777 .05261 .67587 .0347 Metetra
.685 .748 .899 r
.67587 .0347 .68777 .05261 .71269 .04148 .70097 .02358 Metetra
.664 .741 .908 r
.03634 .26033 .05165 .27459 .07153 .26704 .05633 .25252 Metetra
.663 .739 .906 r
.05633 .25252 .07153 .26704 .09158 .25942 .07648 .24465 Metetra
.663 .737 .905 r
.07648 .24465 .09158 .25942 .11179 .25176 .0968 .23672 Metetra
.663 .735 .903 r
.0968 .23672 .11179 .25176 .13216 .24403 .11728 .22872 Metetra
.663 .732 .901 r
.11728 .22872 .13216 .24403 .15269 .23624 .13792 .22065 Metetra
.662 .73 .9 r
.13792 .22065 .15269 .23624 .1734 .2284 .15874 .21252 Metetra
.662 .728 .898 r
.15874 .21252 .1734 .2284 .19427 .2205 .17972 .20433 Metetra
.662 .725 .896 r
.17972 .20433 .19427 .2205 .21532 .21255 .20088 .19607 Metetra
.662 .723 .894 r
.20088 .19607 .21532 .21255 .23654 .20454 .22221 .18773 Metetra
.661 .72 .892 r
.22221 .18773 .23654 .20454 .25793 .19648 .24371 .17933 Metetra
.661 .717 .89 r
.24371 .17933 .25793 .19648 .2795 .18836 .2654 .17086 Metetra
.66 .714 .887 r
.2654 .17086 .2795 .18836 .30126 .18019 .28727 .16232 Metetra
.66 .71 .885 r
.28727 .16232 .30126 .18019 .3232 .17196 .30932 .15371 Metetra
.659 .707 .882 r
.30932 .15371 .3232 .17196 .34532 .16368 .33155 .14502 Metetra
.659 .703 .88 r
.33155 .14502 .34532 .16368 .36763 .15533 .35397 .13627 Metetra
.658 .7 .877 r
.35397 .13627 .36763 .15533 .39014 .14692 .37659 .12743 Metetra
.658 .696 .874 r
.37659 .12743 .39014 .14692 .41284 .13843 .39939 .11852 Metetra
.657 .692 .871 r
.39939 .11852 .41284 .13843 .43573 .12986 .4224 .10954 Metetra
.657 .689 .869 r
.4224 .10954 .43573 .12986 .45883 .1212 .44559 .10048 Metetra
.656 .686 .866 r
.44559 .10048 .45883 .1212 .48213 .11242 .46899 .09134 Metetra
.655 .683 .864 r
.46899 .09134 .48213 .11242 .50564 .10349 .4926 .08212 Metetra
.655 .681 .863 r
.4926 .08212 .50564 .10349 .52935 .0944 .51641 .07282 Metetra
.655 .681 .862 r
.51641 .07282 .52935 .0944 .55326 .0851 .54042 .06344 Metetra
.655 .682 .863 r
.54042 .06344 .55326 .0851 .57739 .07557 .56465 .05398 Metetra
.656 .684 .865 r
.56465 .05398 .57739 .07557 .60171 .06575 .58909 .04443 Metetra
.657 .69 .869 r
.58909 .04443 .60171 .06575 .62623 .05568 .61375 .0348 Metetra
.658 .697 .875 r
.61375 .0348 .62623 .05568 .65095 .04528 .63862 .02508 Metetra
.66 .709 .884 r
.63862 .02508 .65095 .04528 .67587 .0347 .66372 .01528 Metetra
.661 .721 .893 r
.66372 .01528 .67587 .0347 .70097 .02358 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m_ooool4o`000003oa0@4?oooooooooo06_ooooo003hooooo`03o`00
0?oooooooooo06gooooo003hooooo`03o`000?oooooooooo06gooooo003hooooo`03o`000?oooooo
oooo06gooooo003hooooo`03o`000?oooooooooo06gooooo003hooooo`03o`000?oooooooooo06go
oooo003hooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Qooooo`00
m_ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0HOooool00?oooooo
0oooool01Ol@413ooooooooooooooooo410@067ooooo003oooooo`?ooooo00Go0000oooooooooooo
ooooo`00001Qooooo`00ooooool3ooooo`05o`000?ooooooooooooooool00000HOooool00?oooooo
0oooool01Ol@413ooooooooooooooooo410@067ooooo003looooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg067ooooo003iooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^067ooooo003gooooo`;o00000oooool3o`0006Wooooo003dooooo`?o00000_oo
ool3o`000004ojVhi?l0003oooooo`0006Sooooo003booooo`;o00000_ooool3o`0000CoZKST0ol0
001Xooooo`00koooool4o`000003ooooool0003o000000OoZKST00Co0000ojVhi?l0003o0000Iooo
ool00;Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`00
0?lQ8B7oc<c<01kooooo0ol00002ooooo`?o000000?oZ;GRo`000?nY^>@01_nY^>@01Ol0003oZKST
o`000?oooooo000006Kooooo002iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0Looooo`;o00000_ooool3o`0000GoZ;GR00?o0000ojVh
i?nY^>@01?nY^>@00ol0003oZKSTojVhi002o`0006Kooooo002iooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001Wooooo0ol00002ooooo`;o00002OnX]N80
0ol0003oZKSTojVhi003ojVhi003o`000?nY^>CoZKST00?o0000IOooool00;Wooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805oooool2o`0000;ooooo0ol0
00000onX/]oo0000ojRehP08ojRehP03o`000?nY^>CoZKST00?oZKST0ol000001?n__nKo0000o`00
0?l0001Tooooo`00^Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c00Dooooo`?o000000Coooooo`000?l0003o00001OnX/]l00ol0003oZ;GRojRehP07ojRe
hP03o`000?nY^>Co000000;o000000?o[koVo`000?n__nH00_n__nH2o`0006Cooooo002iooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@01;ooooo0_l00002
ooooo`;o00002?nX/]l00ol0003oZ;GRojRehP07ojRehP;o00001?n__nH00ol0003o[koVojnoiP02
ojnoiP;o0000Hoooool00;Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000003oooool3o`000006ooooool0003o0000o`000?nX/=ko00002OnX/]l00ol0003o
Z;GRojRehP04ojRehP;o000000?o[K[So`000?n__nH00on__nH00ol0003o[koVojnoiP03ojnoiP;o
0000H_ooool00;Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT03Oooool2o`0000;ooooo0_l00005ojR`gP03o`000?nX/]ooZ;;O00OoZ;;O00Co0000ojRe
h_nX]N;oZ;GR0_l00004ojfjh`05o`000?n__nKo[koVojnoi_l000001On__nH2o`0006;ooooo001g
ooooo`;o00000_ooool2o`0005_ooooo1?l000000ooooooo0000o`000007ojR`gP03o`000?nX/]oo
Z;;O00OoZ;;O00Co0000ojReh_l0003o00001on]^^<01?l0003o[koVojnoi_l00003ojnoiP;o0000
00?o[[GNo`000?l00000HOooool007Oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMeIooooo`;o
00000_ooool3o`000003ojN_gOl0003oZ;3N00OoZ;3N00?o0000ojRbgonX/]l01_nX/]l2o`0000Wo
[K[S00Go0000ojnoi_n__nKo0000ojnoiP02o`0000Co[[GN00?o0000ooooooooool0Goooool007So
oooo00CogMgMo`000?l@413oc<c<Eoooool3o`000004ooooool0003o0000o`0000GoYjoM00?o0000
ojR`g_nX/=h01_nX/=h00ol0003oZ;;OojRbg`02ojRbg`?o000000?o[;OQo`000?n]^^<02On]^^<0
1?l0003o[koVo`000?l00007ojjegP03o`000?oooooooooo05kooooo001hooooo`04onk^k_lQ8B7o
410@onk^kUCooooo0ol00002ooooo`;o00002?nW[md00ol0003oZ;3NojR`gP06ojR`gP03o`000?nX
/]oo000000;o00001On/]n400ol0003o[K[Sojfjh`07ojfjh`?o00002?n^]Mh2o`0005oooooo001h
ooooo`04ob4Q8OmgMgOoMgMgoc8b<U;ooooo0ol000001_oooooo0000o`000?l0003oYjkLo`0000Wo
YjoM00?o0000ojR`g_nX/=h01OnX/=h2o`0000Wo[;OQ00?o0000ojfjhon]^^<01?n]^^<2o`000003
ojnbfol0003o000000Wo[[GN00?o0000ooooooooool0GOooool007Oooooo0_l00002ooooo`;o0000
C_ooool3o`000004ooooool0003o0000o`0000GoYjkL00?o0000ojN_gOnW[md01onW[md01?l0003o
Z;3NojR`g_nX/=h3o`000003oj^dgol0003o[;OQ00So[;OQ00?o0000ojfjhon]^^<00_n]^^<2o`00
00Co[k;K00?o0000ojjeg_n^]Mh01on^]Mh2o`0005kooooo0039ooooo`;o00000_ooool2o`0000;o
YjkL00?o0000ojN^g?nW[]`00onW[]`00ol0003oYjoMojN_g@07ojN_g@04o`000?nX/=ko0000o`00
00GoZkCO00?o0000ojbghOn/]n401on/]n401?l0003o[K[So`000?l00006ojnbf`;o00001_n^]Mh2
o`000003ok_7hol0003o000005gooooo0036ooooo`?o000000Koooooo`000?l0003o0000ojN^g?l0
0009ojN^g003o`000?nW[mgoYjoM00KoYjoM0_l00008oj^dg`03o`000?n/]n7o[;OQ00Ko[;OQ0_l0
0008ojnbf`;o00001?n^]Mh2o`0000Co^lOS00?o0000ooooooooool0Foooool00<Cooooo0_l00002
ooooo`;o00001OnW[]`00ol0003oYjkLojN^g007ojN^g003o`000?nW[mgoYjoM00;oYjoM0ol00000
0onY/]oo0000oj^dg`07oj^dg`03o`000?n/]n7o[;OQ00?o[;OQ0ol000000on][mWo0000ojnbf`07
ojnbf`04o`000?n_/]_o0000ojjegP;o00001_nkan<2o`0005cooooo002=ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c00Oooooo`?o0000
00Coooooo`000?l0003o00001onW[]`00ol0003oYjkLojN^g007ojN^g003o`000?nW[mgo000000;o
00001OnY/]l00ol0003oZkCOoj^dg`06oj^dg`03o`000?n/]n7o000000;o00001On][mT00ol0003o
[k;Kojnbf`05ojnbf`04o`000?n_/]_o0000o`0000Wo^lOS0_l0001Kooooo`00SOooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool2
o`0000;ooooo0ol000000onW[]co0000ojN^g007ojN^g003o`000?nW[]coYjkL00KoYjkL0_l00008
ojVbg`03o`000?n[]=ooZkCO00KoZkCO0_l00009ojf_f@03o`000?n_/]_o[k;K00Co[k;K0_l00000
0one_^7o0000ok_7h`08ok_7h`;o0000Foooool008gooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000006_ooool3o`000004ooooool0003o0000o`0000GoYjkL
00?o0000ojN^g?nW[]`01_nW[]`00ol0003oYjkLojN^g002ojN^g0?o000000?oZ;7No`000?nY/]l0
2?nY/]l00ol0003oZkCOoj^dg`03oj^dg`;o000000?oZjgHo`000?n][mT02?n][mT00ol0003o[k;K
ojnbf`02ojnbf`;o000000Go]KkQo`000?ne_^7o]KkQo`000008ok_7h`?o0000F_ooool008gooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B406?ooool2o`00
00;ooooo0_l00008ojN^g003o`000?nW[]coYjkL00KoYjkL00?o0000ojN^g?l000000_l00005ojRa
gP03o`000?nY/]ooZK;O00OoZK;O00Go0000oj^dgon[]=ooZkCOo`000004oj^]f003o`000?n][mWo
[JoI00Oo[JoI00Co0000ojnbfol0003o00000one_^401?l0003o]KkQokFnhOl00006ok_7h`;o0000
00Co/joEo`000?oooooo00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000??ooool008gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`05Oooool7o`000003ojN^gOl0003oYjkL00SoYjkL00?o0000ojN^g?nW[]`01OnW[]`2
o`0000SoZ;7N00?o0000ojVbgonY/]l01onY/]l01?l0003oZkCOo`000?l00005oj^]f003o`000?n]
[mWo[JoI00Oo[JoI0_l00005okFnh@05o`000?ne_^7o]KkQokFnhOl000000onkan<2o`0000Co/joE
0_l00008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00looooo`00SOooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool05Oooool2o`0000;ooooo0ol00004ojN^g@03o`000?nW[]coYjkL00OoYjkL00Co0000ojN^
g?nW[]coYjkL0ol000000onX/Mko0000ojRagP08ojRagP03o`000?nY/]ooZK;O00KoZK;O0_l00008
oj^]f003o`000?n][mWo[JoI00Co[JoI0_l000000onb^]oo0000okFnh@04okFnh@06o`000?ne_^7o
]KkQokFnhOl0003o^lOS0_l00007ok>_e@;o00001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h0?Oooool008gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH01;ooooo0ol00002ooooo`;o00001onW[]d00ol0003oYjkLojN^g007ojN^g004
o`000?nW[]co0000o`0000GoZ;7N00?o0000ojRag_nX/Mh01onX/Mh00ol0003oZK;OojVbg`02ojVb
g`?o000000?oZJ_Ho`000?n[[MP02?n[[MP01?l0003o[JoIojf_fOn][mT2o`0000Co/[[O00?o0000
okFnhOne_^400_ne_^401?l0003o]KkQokFnhOne_^42o`0000[o/joE0_l00006ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0looooo`00SOooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@3Oooool3o`0000;ooooo0ol000000onW[mgo
0000ojN^g@07ojN^g@03o`000?nW[]coYjkL00KoYjkL0_l00007ojRagP03o`000?nX/MkoZ;7N00Oo
Z;7N00?o0000ojVbgol000000_l00005ojV[f003o`000?n[[MSoZjgH00KoZjgH00Co0000ojf_fOl0
003o00001onb^]l01_l0003o]KkQokFnhOne_^7o0000okFnh@;o000000?o]:cAo`000?nc[mD02Onc
[mD2o`0000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo03_ooooo
002]ooooo`?o000000Coooooo`000?l0003o00001OnW[md00ol0003oYjkMojN^g@06ojN^g@03o`00
0?nW[]coYjkL00;oYjkL0ol000000onW/=ko0000ojRagP07ojRagP03o`000?nX/MkoZ;7N00KoZ;7N
0_l00008ojV[f003o`000?n[[MSoZjgH00KoZjgH0_l00009ok:jg`04o`000?ne_^7o]KkQokFnh@;o
00001?nd[=400ol0003o/joEok>_e@06ok>_e@04o`000?o;cM_o0000o`0000Gooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo03[ooooo002Zooooo`?o00000_ooool2o`00
00SoYjoM00?o0000ojN^gOnW[]d01_nW[]d00ol0003oYjkLo`000002o`0000GoYk3N00?o0000ojRa
g_nX/Mh01_nX/Mh00ol0003oZ;7NojRagP02ojRagP?o000000?oZ:[Ho`000?nYZmP02?nYZmP00ol0
003oZjgHoj^]f003oj^]f0;o000000?o[kKNo`000?nb^]l02Onb^]l01?l0003o]KkQo`000?l00005
okB/d@03o`000?nc[mGo/joE00Go/joE00Co0000ol_=foo;cM_oblgK0_l00004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@03cooooo002Xooooo`;o0000
0_ooool3o`000003ojR`g_l0003oYjoM00SoYjoM00?o0000ojN^gOnW[]d01OnW[]d2o`0000SoYk3N
00?o0000ojRag_nX/Mh01_nX/Mh00ol0003oZ;7No`000002o`0000GoZ:[H00?o0000ojV[f?nYZmP0
1onYZmP01Ol0003oZjgHoj^]f?n[[MSo000000Co[kKN00?o0000ok:jgonb^]l01onb^]l2o`000003
okB/dOl0003o]:cA00Go]:cA00?o0000ok>_eOnc[mD00_nc[mD2o`0000GoblgK00?o0000oooooooo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00l
ooooo`00YOooool3o`0000;ooooo0_l00005ojR`gP03o`000?nW[mgoYjoM00OoYjoM00Co0000ojN^
gOnW[]goYjkM0ol000000onW/Moo0000ojN`gP08ojN`gP03o`000?nX/MkoZ;7N00GoZ;7N0_l00008
ojRZf003o`000?nYZmSoZJ_H00OoZJ_H00Co0000oj^]f?l0003o00001_n_]]h00ol0003o/[[Ook:j
g`04ok:jg`;o000000Co/:O?o`000?nd[=7o00001ond[=401?l0003o/joEok>_eOl00007ol_=f`;o
0000E?ooool00:?ooooo0_l00003ooooo`;o00001onX/=h00ol0003oYjoMojN_g@07ojN_g@04o`00
0?nW[]go0000o`0000GoYk7O00?o0000ojN`g_nW/=h01onW/=h01?l0003oZ;7NojRag_nX/Mh3o`00
0003ojNZfOl0003oZ:[H00SoZ:[H00?o0000ojV[f?nYZmP01_nYZmP2o`0000So[kKN00?o0000ok:j
gonb^]l00_nb^]l2o`0000Co/:O?0_l00007okB/d@03o`000?nc[mGo000000SoblgK0ol0001Coooo
o`00X?ooool3o`0000;ooooo0ol000000onX/Mko0000ojR`gP07ojR`gP03o`000?nW[mgoYjoM00Ko
YjoM0_l00007ojNag`03o`000?nW/=koYk3N00OoYk3N00Co0000ojRag_l0003o00001OnWZ]T00ol0
003oZ:[HojRZf007ojRZf003o`000?nYZmSoZJ_H00;oZJ_H0ol000000on]]=ko0000ojnfgP08ojnf
gP04o`000?nb^]oo0000o`0000Ko/:O?0_l00007okB/d@;o00002?o;cM/01?l0003o^:C4o`000?l0
001Cooooo`00W_ooool2o`0000?ooooo0_l000000onX/Mko0000ojRagP02ojRagP03o`000?nX/=ko
Z;3N00KoZ;3N00?o0000ojN_gOnW[md00_nW[md3o`000003ojNagol0003oYk7O00OoYk7O00?o0000
ojN`g_nW/=h01_nW/=h2o`0000OoYj[I00?o0000ojRZf?nXZ]P01onXZ]P00ol0003oZJ_Ho`000002
o`0000Go[KCN00?o0000ojnfg_n_]]h01_n_]]h2o`0000So/:O?0_l00006okB/d@03o`000?nn_][o
000000OoblgK00Co0000okRTa?nhY<Co^:C40_l0001Booooo`00Voooool3o`0000?ooooo0_l00008
ojRagP03o`000?nX/=koZ;3N00GoZ;3N00?o0000ojN_gOl000000_l00005ojNag`03o`000?nW/Moo
Yk7O00KoYk7O00?o0000ojN`g_nW/=h00_nW/=h3o`000003ojJZfOl0003oYj[I00OoYj[I00?o0000
ojRZf?nXZ]P01_nXZ]P2o`0000So[KCN00?o0000ojnfg_n_]]h01?n_]]h2o`000003ojfUd?l0003o
/:O?00So/:O?00?o0000okB/dOnd[=400_nd[=42o`0000?o_[kJ00?o0000ol_=foo;cM/00oo;cM/0
0ol0003o^:C4okRTa003okRTa0;o0000DOooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo01oooooo0_l00003ooooo`?o000000?oZ;;O
o`000?nX/Mh01onX/Mh00ol0003oZ;3NojR`gP04ojR`gP?o00002OnW/Ml00ol0003oYk7OojNag`05
ojNag`03o`000?nW/=ko000000;o00001OnVZ]T00ol0003oYj[IojNZf@06ojNZf@03o`000?nXZ]So
Z:[H00;oZ:[H0ol000000onZ/moo0000ojfdgP08ojfdgP04o`000?n_]]ko[kKNojnfgP;o00001?n]
YM000ol0003o/:O?ok2Wc`06ok2Wc`03o`000?nd[=7o]:cA00;o00001_nn_]X01Ol0003oblgKol_=
foo;cM_o000000Oo^:C400?o0000ooooooooool0Coooool006?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Mooooo`?o00000_ooool3o`0000GoZ;;O
00?o0000ojRag_nX/Mh01_nX/Mh00ol0003oZ;3NojR`gP03o`0000;oYk;P00?o0000ojNagonW/Ml0
1onW/Ml00ol0003oYk7OojNag`04ojNag`?o00002?nVZ]T00ol0003oYj[IojNZf@06ojNZf@03o`00
0?nXZ]So000000;o00001OnZ/ml00ol0003o[KCNojfdgP06ojfdgP04o`000?n_]]ko0000o`0000Ko
[JG@00?o0000ok2Wcon`Yll01_n`Yll3o`0000Wo_[kJ00?o0000ol_=fol000002OnhY<@00ol0003o
ooooooooo`1>ooooo`00Hoooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Kooooo`?o
00000oooool2o`0000WoZ;;O00?o0000ojRag_nX/Mh01OnX/Mh3o`0000KoYk;P00?o0000ojNagonW
/Ml01onW/Ml00ol0003oYk7OojNag`03o`0000;oYZ_J00?o0000ojJZfOnVZ]T01onVZ]T00ol0003o
Yj[IojNZf@05ojNZf@;o00002OnZ/ml00ol0003o[KCNojfdgP05ojfdgP;o00002On]YM000ol0003o
/:O?ok2Wc`05ok2Wc`;o00002_nn_]X2o`0000[o^:C40_l0001?ooooo`00Hoooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00006_ooool2o`0000?ooooo0ol000000onX
/n3o0000ojRbg`08ojRbg`03o`000?nX/MkoZ;7N00;oZ;7N0ol000000onW/n7o0000ojNbh007ojNb
h003o`000?nW/MooYk7O00KoYk7O0ol00006ojJ[fP03o`000?nVZ]WoYZ[I00OoYZ[I00Co0000ojNZ
fOnWZ]WoYj[I0ol000000onX/^3o0000ojZcg`08ojZcg`03o`000?n]]=ko[KCN00;o[KCN0ol00000
0onYXm7o0000ojfUd008ojfUd003o`000?n`Yloo/:O?00?o/:O?0_l000000oni^M[o0000okjnfP08
okjnfP03o`000?ngWl3o000000Wo^:C400?o0000om[3`ol00000Coooool006?ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Oooooo0ol00003ooooo`;o00001OnX
/n000ol0003oZ;;OojRbg`07ojRbg`04o`000?nX/Mko0000o`0000GoYk?Q00?o0000ojNbh?nW/^00
1_nW/^000ol0003oYk7OojNag`02ojNag`?o000000?oYJ_Ko`000?nVZmX01_nVZmX00ol0003oYZ[I
ojJZf@07ojJZf@04o`000?nWZ]Wo0000o`0000GoZ;;P00?o0000ojZcgonZ/ml01onZ/ml01?l0003o
[KCNo`000?l00005ojVSd@03o`000?n]YM3o[JG@00Oo[JG@00Go0000ok2Wcon`Yloo/:O?o`000003
okVifP;o00001onn_]X01Ol0003o]io0okNO`?ngWl3o000000Oo^:C400?o0000om[3`ooJ`l<00_l0
001>ooooo`00Hoooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000005Ooo
ool2o`0000;ooooo1?l00008ojRch003o`000?nX/]ooZ;;O00KoZ;;O0_l00007ojNch@03o`000?nW
/^3oYk;P00OoYk;P00Co0000ojNagol0003o00001OnUZm/00ol0003oYZ_JojJ[fP05ojJ[fP03o`00
0?nVZ]WoYZ[I00KoYZ[I0_l00008ojRbh003o`000?nZ/mooZ[?O00KoZ[?O0_l00007ojVSd@03o`00
0?n]YM3o[JG@00Oo[JG@00Co0000ok2Wcol0003o00001?ni^MX00ol0003o^KWJo`000004okjnfP;o
00001?ngWl000ol0003o^:C4okRTa004okRTa003o`000?oJ`l?of/?300;of/?300?o0000oooooooo
ool0C?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000001;o
oooo0ol00002ooooo`?o00000_nX/n400ol0003oZ;?PojRch007ojRch003o`000?nX/]ooZ;;O00;o
Z;;O0ol000000onW]>;o0000ojNch@07ojNch@03o`000?nW/^3oYk;P00KoYk;P0_l00007ojF[f`03
o`000?nVZm[oYZ_J00KoYZ_J00?o0000ojJZfOnVZ]T00_nVZ]T3o`000003ojNbhOl0003oZ;;P00Oo
Z;;P00?o0000ojZcgonZ/ml00onZ/ml3o`000003ojNSd_l0003oZJ?A00OoZJ?A00?o0000ojfUd?n]
YM001_n]YM02o`0000Ko^KWJ00?o0000okVif_l000000onn_]X00ol0003o]io0okNO`004okNO`003
o`000?nhY<Co^:C400?o^:C400?o0000om[3`ooJ`l<00ooJ`l<2o`0004gooooo001Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0?ooooo`;o00000_ooool3o`0000Ko
Z;?Q00?o0000ojRch?nX/n001onX/n001?l0003oZ;;Oo`000?l00005ojNdhP03o`000?nW/n7oYk?Q
00KoYk?Q00?o0000ojNbh?nW/^000_nW/^03o`000003ojF/g?l0003oYJ_K00OoYJ_K00?o0000ojJ[
f_nVZmX01OnVZmX00ol0003oYZ[Io`000002o`0000GoYk;Q00?o0000ojRbh?nX/^001_nX/^000ol0
003oZ[?Oo`000002o`0000GoYj?B00?o0000ojVSdOnYXm401OnYXm400ol0003o[JG@ojfUd004ojfU
d0;o000000?o/[GKo`000?ni^MX01Oni^MX01_l0003o^KWJokVif_l0003o_[kJo`0000So]io000?o
0000okRTa?nhY<@00_nhY<@00ol0003of/?3om[3``04om[3``;o0000C?ooool008Cooooo0ol00000
1_oooooo0000o`000?l0003oZ;CQo`0000SoZ;?Q00?o0000ojRch?nX/n001_nX/n02o`0000SoYkCR
00?o0000ojNchOnW/n401OnW/n400ol0003oYk;Po`000002o`0000GoYJcL00?o0000ojF[fonUZm/0
1_nUZm/00ol0003oYZ_JojJ[fP03ojJ[fP?o00002OnW/^400ol0003oZ;;PojRbh005ojRbh0;o0000
2?nWXm800ol0003oZJ?AojVSd@06ojVSd@04o`000?n]YM3o[JG@ojfUd0;o00001?nb]M/00ol0003o
^KWJokVifP03okVifP03o`000?ni^M[o^KWJ00;o00002OngWl001Ol0003o^:C4okRTa?nhY<Co0000
00Oof/?30_l0001<ooooo`00P_ooool2o`0000;ooooo0_l00005ojRdh@03o`000?nX/n7oZ;?Q00Go
Z;?Q00?o0000ojRch?nX/n000onX/n03o`000003ojNdh_l0003oYkCR00OoYkCR00?o0000ojNchOnW
/n401?nW/n43o`0000SoYJcL00?o0000ojF[fonUZm/01_nUZm/00ol0003oYZ_JojJ[fP03o`0000;o
Y[?R00?o0000ojNbhOnW/^401onW/^400ol0003oZ;;PojRbh002ojRbh0?o000000?oYJ?Do`000?nW
Xm802?nWXm800ol0003oZJ?AojVSd@05ojVSd@04o`000?n]YM3o0000o`0000Oo/[GK00?o0000okVi
f_ni^MX00_ni^MX3o`000003ojnJ`Ol0003o]io000So]io000Co0000okRTa?nhY<Co00001ooJ`l<0
1?l0003o]8JTo`000?l0001;ooooo`00Ooooool3o`0000;ooooo0_l00008ojRdh@03o`000?nX/n7o
Z;?Q00GoZ;?Q00?o0000ojRch?l000000_l00005ojNdhP03o`000?nW]>;oYkCR00KoYkCR00?o0000
ojNchOnW/n400ol00002ojF]g@03o`000?nU[=coYJcL00OoYJcL00?o0000ojF[fonUZm/01OnUZm/3
o`0000KoY[?R00?o0000ojNbhOnW/^401onW/^401?l0003oZ;;Po`000?l00005ojFSe003o`000?nW
Xm;oYj?B00KoYj?B00?o0000ojVSdOnYXm401OnYXm42o`0000Wo/[GK00?o0000okVif_ni^MX00_ni
^MX00ol0003o[i[1ojnJ`@02ojnJ`@03o`000?ngWl3o]io000Oo]io00_l00007om[3``04o`000?nd
QZCo]8JTokB6Y0;o0000B_ooool007gooooo0_l00002ooooo`?o000000?oZ;GRo`000?nX]>401onX
]>400ol0003oZ;?QojRch@04ojRch@?o00002OnW]>800ol0003oYkCRojNdhP05ojNdhP?o00001_nU
[Md00ol0003oYJcLojF/g007ojF/g004o`000?nUZm_oYJ_KojF[f`?o000000?oYK?Ro`000?nV/n80
1onV/n800ol0003oYk;QojNbh@06ojNbh@;o00001onUXm@00ol0003oYj?BojNSdP07ojNSdP04o`00
0?nYXm7oZJ?AojVSd@?o000000?o[[CMo`000?nb]M/02Onb]M/00ol0003o^KWJo`000002o`0000Co
[i[100?o0000okNO`?ngWl001_ngWl02o`0000Sof/?300Co0000okB6Y?ndQZCo]8JT0_l0001:oooo
o`00N_ooool3o`0000;ooooo0_l00005ojRehP03o`000?nX]>7oZ;CQ00KoZ;CQ00?o0000ojRchOnX
/n400ol00003ojNeh`03o`000?nW]>;oYkCR00KoYkCR00?o0000ojNdh_nW]>800_nW]>83o`000003
ojF^g_l0003oYJgM00OoYJgM00?o0000ojF/g?nU[=`01_nU[=`01?l0003oYJ_Ko`000?l00005ojFc
hP03o`000?nV/n;oY[?R00GoY[?R00?o0000ojNbhOnW/^400onW/^43o`000003ojBTe_l0003oYJ?D
00OoYJ?D00?o0000ojNSd_nWXm801_nWXm801?l0003oZJ?Ao`000?l00005ojjdg@03o`000?nb]M_o
/[GK00Oo/[GK0_l00002ojnJ`@03o`000?n_V/7o[i[100?o[i[100?o0000okNO`?ngWl001?ngWl00
0ol0003o`k78o`000007om[3``03o`000?ndQZCo]8JT00?o]8JT0_l00019ooooo`00Moooool3o`00
00;ooooo0ol00008ojRehP03o`000?nX]>7oZ;CQ00GoZ;CQ0ol00007ojNeh`03o`000?nW]>;oYkCR
00KoYkCR00Co0000ojNdh_l0003o00001OnU[]h00ol0003oYJgMojF]g@05ojF]g@03o`000?nU[=co
YJcL00GoYJcL0ol00008ojFchP03o`000?nV/n;oY[?R00GoY[?R00?o0000ojNbhOl000000_l00005
ojBTeP03o`000?nUXmCoYJ?D00GoYJ?D00?o0000ojNSd_nWXm801_nWXm82o`0000So[[CM00?o0000
ok:efonb]M/01?nb]M/2o`000005oj^IaOl0003o[i[1ojnJ`Ol000001On_V/400ol0003o]io0okNO
`003okNO`005o`000?o3/LSo`k78ol>ab?l000001OoJ`l<00ol0003o]8JTokB6Y004okB6Y003o`00
0?oooooo000004Sooooo001eooooo`;o00000_ooool3o`000003ojRfhol0003o000000SoZ;GR00?o
0000ojRdhOnX]>400_nX]>43o`000003ojNfhol0003oYkGS00SoYkGS00?o0000ojNdh_nW]>801?nW
]>83o`0000OoYJkN00?o0000ojF]gOnU[Md01_nU[Md00ol0003oYJcLojF/g004o`0000;oYKCS00?o
0000ojFch_nU/n801_nU/n800ol0003oY[?RojJchP04ojJchP?o00002?nTY=H00ol0003oYJ?DojFS
e006ojFSe003o`000?nWXm;oYj?B00;oYj?B0ol000000onY/moo0000ojjdg@07ojjdg@03o`000?nb
]M_o/[GK00;o/[GK0_l00003oj^Ia@04o`000?n_V/7o[i[1o`0000Go[i[100?o0000okNO`?ngWl00
0_ngWl000ol0003o`k78ol>ab003ol>ab005o`000?oJ`l?of/?3om[3`ol000001ondQZ@00ol0003o
ooooo`000018ooooo`00L_ooool3o`000004ooooool0003o0000o`0000KoZ;KS00?o0000ojReh_nX
]N801_nX]N801?l0003oZ;CQo`000?l00005ojNfh`03o`000?nW]N?oYkGS00OoYkGS00?o0000ojNd
h_nW]>800ol00002ojJ`g`03o`000?nU[]koYJkN00KoYJkN00?o0000ojF]gOnU[Md01OnU[Md3o`00
00OoYKCS00?o0000ojFch_nU/n801_nU/n800ol0003oY[?RojJchP03o`0000;oXjGG00?o0000ojBT
e_nTY=H01onTY=H00ol0003oYJ?DojFSe005ojFSe003o`000?nWXm;o000000;o00001OnY/ml00ol0
003o[[CMojjdg@06ojjdg@04o`000?nb]M_o0000o`0000KoZiW500?o0000ojnJ`Ol000001_n_V/40
1?l0003o]io0okNO`?l00006ol>ab005o`000?oJ`l?of/?3om[3`ol000001_ndQZ@2o`0000;ooooo
00?o0000ooooooooool0AOooool003[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`00027ooooo0_l000001_oooooo0000o`000?l0003oZKOSo`0000SoZ;KS00?o0000ojRe
h_nX]N801?nX]N83o`0000SoYkKS00?o0000ojNehonW]N<01_nW]N<3o`0000KoY[3O00?o0000ojF^
g_nU[]h01_nU[]h01?l0003oYJgMojF]gOnU[Md3o`000003ojFei?l0003oYKCS00SoYKCS00?o0000
ojFch_nU/n801OnU/n83o`0000KoXjGG00?o0000ojBTe_nTY=H01_nTY=H00ol0003oYJ?DojFSe005
ojFSe0;o00002?nY/ml00ol0003o[[CMojjdg@06ojjdg@;o00002?n[VLD00ol0003o[i[1o`000006
ojnJ`@03o`000?ngWl3o000000So`k7800?o0000om[3`ol000001ondQZ@2o`0000;ooooo0_l00016
ooooo`00>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@07_ooool3o`000003ooooool0003o000000GoZKOS00?o0000ojRfhonX]^<01_nX
]^<00ol0003oZ;GRojRehP03o`0000?oZ;OT00?o0000ojNfhonW]^<01_nW]^<00ol0003oYkGSojNe
h`02ojNeh`?o000000?oY[7Po`000?nV/=l01onV/=l00ol0003oYJkNojF^gP05ojF^gP04o`000?nU
[Mgo0000o`0000GoYKGT00?o0000ojFdhonU]><01_nU]><00ol0003oYK?RojFchP02ojFchP?o0000
00?oXjKIo`000?nSYML01_nSYML00ol0003oY:CFojBTeP07ojBTeP04o`000?nUXmCoYJ?DojFSe0?o
000000?oY[?Ro`000?nY/ml02?nY/ml00ol0003o[[CMojjdg@02ojjdg@?o000000?oYIS8o`000?n[
VLD01on[VLD01?l0003o[i[1ojnJ`Ol00005ojnJ`@;o00002_o3/LP00ol0003o]8JTokB6Y006okB6
Y003o`000?nlPICo000000;ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool09oooool003[ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01gooooo0_l00002ooooo`;o00002?nY]n<0
0ol0003oZ;KSojRfh`05ojRfh`?o00001onX]n@00ol0003oYkKSojNfh`06ojNfh`04o`000?nW]N?o
0000o`0000GoY[7P00?o0000ojJ`gonV/=l01OnV/=l00ol0003oYJkNojF^gP04ojF^gP?o00002?nU
]N@00ol0003oYKCSojFdh`06ojFdh`04o`000?nU/n;o0000o`0000GoXjKI00?o0000oj>UeonSYML0
1OnSYML00ol0003oY:CFojBTeP06ojBTeP04o`000?nUXmCo0000o`0000GoY[?R00?o0000ojVcgonY
/ml01_nY/ml00ol0003o[[CMo`000002o`0000GoYIS800?o0000oj^IaOn[VLD01_n[VLD00ol0003o
[i[1o`000004ojnJ`@03o`000?nk/M3o000000[o`k7800?o0000okB6Y?ndQZ@01_ndQZ@00ol0003o
_86Do`000003ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`0Xooooo`00>_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h06Oooool3o`000006ooooool0003o0000o`000?nY^>Co00002?nY
]n<00ol0003oZ;KSojRfh`02ojRfh`?o000000?oZ;STo`000?nX]n@02?nX]n@00ol0003oYkKSojNf
h`04ojNfh`?o00002?nV/N000ol0003oY[3OojJ`g`05ojJ`g`03o`000?nU[]koYJkN00?o00000_nU
]^D00ol0003oYKGTojFei006ojFei003o`000?nU]>?oYKCS00GoYKCS0ol00007oj>Vf@03o`000?nS
YMOoXjGG00KoXjGG00?o0000ojBTe_nTY=H01?nTY=H3o`0000SoY[?R00?o0000ojVcgonY/ml01OnY
/ml2o`0000SoYIS800?o0000oj^IaOn[VLD01_n[VLD00ol0003o[i[1o`000002ojnJ`@;o00000onk
/M000ol0003o`k78ol>ab006ol>ab0;o00001ondQZ@01?l0003o_86Dokb1U?l00004ooooo`03o`00
0?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:Oooool003[ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo0_l00002ooooo`;o
00001OnY^>@00ol0003oZKOSojVgh`06ojVgh`04o`000?nX]^?o0000o`0000GoZ;ST00?o0000ojRg
i?nX]n@01onX]n@00ol0003oYkKSojNfh`03o`0000;oY[;Q00?o0000ojJah?nV/N001_nV/N000ol0
003oY[3OojJ`g`04ojJ`g`Co00001_nU]^D00ol0003oYKGTojFei006ojFei003o`000?nU]>?oYKCS
00Co00000_nSZ=X00ol0003oXjKIoj>Vf@06oj>Vf@03o`000?nSYMOoXjGG00GoXjGG00?o0000ojBT
e_nTY=H01?l00002ojBdi003o`000?nV/n;oY[?R00KoY[?R00?o0000ojVcgonY/ml00_nY/ml3o`00
0003oj>Ibol0003oYIS800OoYIS800?o0000oj^IaOn[VLD01_n[VLD00ol0003o[i[1o`000002o`00
00Go^k7@00?o0000ol>ab?o3/LP01Oo3/LP01?l0003o/h^/ok>;[?l00006okB6Y004o`000?nlPICo
_86Do`0000Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00002oooool3o`000003oa0@4?oooooooooo01Wooooo000jooooo`05oa0@
4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Booooo`?o00000_ooool2o`0000So
ZKST00?o0000ojVghonY]n<01OnY]n<2o`0000SoZ;ST00?o0000ojRgi?nX]n@01_nX]n@3o`0000Ko
Y[;Q00?o0000ojJah?nV/N001_nV/N000ol0003oY[3OojJ`g`03o`0000;oYKOU00?o0000ojFfiOnU
]^D01_nU]^D00ol0003oYKGTojFei004ojFei0Co00001onSZ=X00ol0003oXjKIoj>Vf@06oj>Vf@03
o`000?nSYMOoXjGG00?oXjGG1?l00007ojBdi003o`000?nV/n;oY[?R00KoY[?R00Co0000ojVcgol0
003o00001OnSVL/00ol0003oYIS8ojFHb006ojFHb003o`000?n[VLGoZiW500KoZiW50_l00008ok^a
d003o`000?o3/LSo`k7800?o`k7800Go0000ok>;[?ncRjco/h^/o`000006okB6Y004o`000?nlPICo
_86Do`0000Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00003Oooool00ol@413o^[Zjooooo`0Jooooo`00>_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`;o00000_ooool3o`00
00;oZKWT00?o0000ojVhi?nY^>@01_nY^>@00ol0003oZKOSojVgh`02ojVgh`;o00000_nX^>D00ol0
003oZ;STojRhi006ojRhi003o`000?nX]nCoZ;OT00;oZ;OT0ol000000onV/n7o0000ojJbh@07ojJb
h@03o`000?nV/N3oY[7P00GoY[7P0ol00006ojFgi@03o`000?nU]^GoYKKU00KoYKKU00?o0000ojFe
i?nU]N@00ol00002oj>Yf`03o`000?nSZ=[oXjSJ00OoXjSJ00?o0000oj>VfOnSY]T01OnSY]T00ol0
003oXjGGoj>Ue`03o`0000;oXkGU00?o0000ojBdi?nT]>@01onT]>@00ol0003oY[?RojJchP04ojJc
hP?o00001onSVL/00ol0003oYIS8ojFHb006ojFHb003o`000?n[VLGoZiW500GoZiW50ol00008ok^a
d003o`000?o3/LSo`k7800;o`k7800?o0000ok>;[?ncRj`00_ncRj`00ol0003o]8JTokB6Y004okB6
Y004o`000?nlPICo_86Do`0000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000003Oooool00onHV9So<S8booooo`0Jooooo`00>_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`?o0000
00Coooooo`000?l0003o00001_nY^N@00ol0003oZKSTojVhi006ojVhi004o`000?nY]n?o0000o`00
00GoZ;SU00?o0000ojRhi?nX^>@01_nX^>@01?l0003oZ;OTo`000?l00005ojJch@03o`000?nV/^7o
Y[;Q00GoY[;Q00?o0000ojJah?nV/N000_nV/N03o`000003ojFgi_l0003oYKOU00OoYKOU00?o0000
ojFfiOnU]^D01?nU]^D4o`0000KoXjWK00?o0000oj>Xf_nSZ=X01_nSZ=X00ol0003oXjKIoj>Vf@04
oj>Vf@Co00001_nS]ND00ol0003oY;CTojBdi006ojBdi003o`000?nV/n;oY[?R00Co00000_nQV/h0
0ol0003oXiW;oj>Ib`05oj>Ib`03o`000?nUV<SoYIS800OoYIS800?o0000oj^IaOn[VLD00_n[VLD2
o`000003ojn`f?l0003o000000Wo^k7@00Co0000ol>ab?o3/LSo00001OncRj`00ol0003o]8JTokB6
Y003okB6Y005o`000?nlPICo_86Dokb1U?l000001_ooool2o`0000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000000gooooo00?ogMgMo`000?nj^[X06_ooool005cooooo
1_l000000onY^NGo0000ojVii007ojVii003o`000?nY^>CoZKST00CoZKST0ol00008ojRhi@03o`00
0?nX^>CoZ;ST00CoZ;ST0ol00008ojJch@03o`000?nV/^7oY[;Q00GoY[;Q00Co0000ojJah?l0003o
00001OnU]nH00ol0003oYKOUojFgi@06ojFgi@03o`000?nU]^GoYKKU00?o00000_nSZm`00ol0003o
XjWKoj>Yf`05oj>Yf`03o`000?nSZ=[oXjSJ00OoXjSJ00?o0000oj>VfOnSY]T00ol00002oj:fi`03
o`000?nS]NGoXkGU00KoXkGU00?o0000ojBdi?nT]>@01OnT]>@3o`0000OoXI[>00?o0000oj>IbonS
VL/01OnSVL/00ol0003oYIS8ojFHb006ojFHb005o`000?n[VLGoZiW5oj^IaOl000001?n_/=P00ol0
003o^k7@ok^ad007ok^ad003o`000?o3/LSo000000Ko/h^/00?o0000okB6Y?ndQZ@00ondQZ@01Ol0
003o_86Dokb1U?nlPICo000000Gooooo00?o0000ooooool000000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool03?ooool00omEEEGoMgMgodA4A00Jooooo`00FOooool3
o`000004ooooool0003o0000o`0000CoZKWU00?o0000ojVii?nY^N@01_nY^N@00ol0003oZKSTojVh
i003o`0000;oZ;WU00?o0000ojRhiOnX^>D01onX^>D00ol0003oZ;STojRhi003o`0000;oY[CR00?o
0000ojJchOnV/n401_nV/n400ol0003oY[;QojJbh@04ojJbh@?o00002?nU]nH00ol0003oYKOUojFg
i@05ojFgi@?o00001_nSZm`00ol0003oXjWKoj>Yf`05oj>Yf`03o`000?nSZ=[oXjSJ00KoXjSJ0ol0
0006oj:fi`03o`000?nS]NGoXkGU00GoXkGU00?o0000ojBdi?nT]>@00_nT]>@3o`000003oinLdOl0
003oXI[>00OoXI[>00?o0000oj>IbonSVL/01OnSVL/00ol0003oYIS8ojFHb006ojFHb004o`000?n[
VLGo0000o`0000Go[k3H00?o0000ok^ad?nk/M001onk/M02o`0000So/h^/00?o0000okB6Y?ndQZ@0
0_ndQZ@00ol0003o_86Dokb1U002okb1U003o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8?ooool01OoMgMgo410@oooooolQ8B7ogMgM01Wooooo001Fooooo`?o00000_ooool2o`0000SoZKWU
00?o0000ojVii?nY^N@01OnY^N@3o`0000KoZ;WU00?o0000ojRhiOnX^>D01_nX^>D3o`0000KoY[CR
00?o0000ojJchOnV/n401_nV/n400ol0003oY[;QojJbh@03o`0000;oYKSV00?o0000ojFgi_nU]nH0
1_nU]nH00ol0003oYKOUojFgi@02ojFgi@?o000000?oXjcMo`000?nSZm`01_nSZm`00ol0003oXjWK
oj>Yf`06oj>Yf`03o`000?nSZ=[oXjSJ00;oXjSJ0ol000000onR]nSo0000oj:fi`07oj:fi`03o`00
0?nS]NGoXkGU00GoXkGU00Co0000ojBdi?l0003o00001OnOW=400ol0003oXI[>oj6JcP06oj6JcP03
o`000?nSVL_oXiW;00GoXiW;00?o0000ojFHb?nUV<P01OnUV<P2o`0000Oo[k3H0_l00006ok^ad0;o
000000?oYHFbo`000?ncRj`01oncRj`00ol0003o]8JTokB6Y002okB6Y003o`000?nlPICo_86D00;o
_86D00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`05ofIVI_n7QhOooooooiRH
V?mEEED06Oooool005Cooooo0_l00002ooooo`?o000000?oZK[Uo`000?nY^ND01onY^ND00ol0003o
ZKWTojVii002ojVii0?o000000?oZ;WVo`000?nX^ND01onX^ND00ol0003oZ;SUojRhi@02ojRhi@?o
000000?oYkGSo`000?nV]>801onV]>800ol0003oY[?QojJch@05ojJch@?o00001_nU^>H00ol0003o
YKOVojFgiP06ojFgiP04o`000?nU]nGo0000o`0000GoXjcM00?o0000oj>[g?nSZm`01OnSZm`00ol0
003oXjWKoj>Yf`05oj>Yf`03o`000?nSZ=[o000000;o00001OnR]nP00ol0003oX[KWoj:fi`05oj:f
i`03o`000?nS]NGoXkGU00CoXkGU0ol00007oinLd@03o`000?nQV/koXI[>00KoXI[>00?o0000oj>I
bonSVL/01OnSVL/00ol0003oYIS8ojFHb002ojFHb0?o000000?oZK?Po`000?n_/=P01_n_/=P00ol0
003o[k3Ho`000003ok^ad0;o00000onUQK800ol0003o/h^/ok>;[006ok>;[005o`000?ndQZCo]8JT
okB6Y?l000001OnlPI@00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?ok^k^
o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Gooooo`00DOooool7o`0000GoZK[U00?o0000ojVi
iOnY^ND01_nY^ND01?l0003oZKWTo`000?l00005ojRiiP03o`000?nX^NGoZ;WU00KoZ;WU00Co0000
ojRhiOl0003o00001OnW]N<00ol0003oY[CRojJdhP05ojJdhP03o`000?nV/n7oY[?Q00;oY[?Q0ol0
00000onU^NOo0000ojFhiP07ojFhiP03o`000?nU]nKoYKOV00CoYKOV0ol00007oj>/g@03o`000?nS
ZmcoXj_L00KoXj_L00?o0000oj>YfonSZM/00onSZM/3o`0000WoX[OX00?o0000oj:fionR]^L01OnR
]^L00ol0003oXkGUoj>ei@03o`0000;oWikC00?o0000oinLdOnOW=401_nOW=400ol0003oXI[>oj6J
cP05oj6JcP03o`000?nSVL_oXiW;00GoXiW;00?o0000ojFHb?l000000_l00005ojVch003o`000?n_
/=So[k3H00Co[k3H00Co0000ojn`f?l0003o^k7@0_l00006ojF5/P03o`000?ncRjco/h^/00Go/h^/
00Go0000okB6Y?ndQZCo]8JTo`000005okb1U003o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07Oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo01Kooooo001?ooooo`;o
00000oooool3o`0000OoZK[U00?o0000ojViiOnY^ND01?nY^ND3o`0000SoZ;WV00?o0000ojRiiOnX
^ND01?nX^ND3o`0000SoYkGS00?o0000ojJdh_nV]>801OnV]>801?l0003oY[?Qo`000?l00005ojFi
i`03o`000?nU^>KoYKSV00KoYKSV00?o0000ojFgi_nU]nH00ol00002oj>^g`03o`000?nS[=goXjcM
00KoXjcM00?o0000oj>[g?nSZm`01OnSZm`00ol0003oXjWKoj>Yf`03o`0000;oXKSY00?o0000oj:g
j?nR]nP01onR]nP00ol0003oX[KWoj:fi`04oj:fi`Co00001_nOW]<00ol0003oWicAoinLd@05oinL
d@03o`000?nQV/koXI[>00KoXI[>00?o0000oj>IbonSVL/00onSVL/3o`0000WoZK?P00?o0000ojn`
f?n_/=P00on_/=P01?l0003o[k3Ho`000?l00008ojF5/P03o`000?ncRjco/h^/00Go/h^/00Go0000
okB6Y?ndQZCo]8JTo`000005okb1U003o`000?oooooooooo00Oooooo00?o0000ooooooooool0??oo
ool004cooooo0ol00002ooooo`?o00000_nY^^H00ol0003oZK[UojVji@06ojVji@03o`000?nY^NGo
ZKWU00?o00000onX^^H00ol0003oZ;WVojRiiP06ojRiiP03o`000?nX^NGoZ;WU00?o00000_nW]^<0
0ol0003oYkGSojNeh`06ojNeh`03o`000?nV]>;oY[CR00CoY[CR0ol00008ojFii`03o`000?nU^>Ko
YKSV00CoYKSV1?l00006oj>^g`03o`000?nS[=goXjcM00KoXjcM00?o0000oj>[g?nSZm`00onSZm`4
o`0000KoXKSY00?o0000oj:gj?nR]nP01onR]nP00ol0003oX[KWoj:fi`03o`0000;oWj3E00?o0000
oinNdonOW]<01OnOW]<00ol0003oWicAoinLd@05oinLd@03o`000?nQV/koXI[>00KoXI[>00?o0000
oj>IbonSVL/00ol00002oj:di@03o`000?nY/n3oZK?P00OoZK?P00?o0000ojn`f?n_/=P00_n_/=P3
o`000003oj29^ol0003oYHFb00OoYHFb00?o0000ok>;[?ncRj`01_ncRj`01?l0003o]8JTokB6Y?l0
0005okb1U003o`000?oooooooooo00Oooooo0_l0000mooooo`009Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^023ooooo0_l00002ooooo`?o00001_nY^^H00ol0003oZK[UojVji@05ojVji@?o00001onX
^^H00ol0003oZ;WVojRiiP05ojRiiP?o00001_nW]^<00ol0003oYkGSojNeh`06ojNeh`03o`000?nV
]>;oY[CR00?o00000_nV^NL00ol0003oYKWWojFii`07ojFii`03o`000?nU^>KoYKSV00?o00000_nT
[ml00ol0003oXjkOoj>^g`06oj>^g`03o`000?nS[=goXjcM00GoXjcM00?o0000oj>[g?nSZm`00ol0
0002oj:ij@03o`000?nQ^>WoXKSY00KoXKSY00?o0000oj:gj?nR]nP01OnR]nP4o`0000KoWj3E00?o
0000oinNdonOW]<01OnOW]<00ol0003oWicAoinLd@05oinLd@03o`000?nQV/koXI[>00CoXI[>1?l0
0006oj:di@03o`000?nY/n3oZK?P00OoZK?P00Ko0000ojn`f?l0003o0000oj29^ol00002oj29^`03
o`000?nUQK;oYHFb00KoYHFb00?o0000ok>;[?ncRj`01_ncRj`00ol0003o]8JTo`000006okb1U003
o`000?oooooooooo00Sooooo00?o0000ooooooooool0>oooool002Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Mooooo`?o000000Koooooo`000?l0003o0000ojVki_l00008ojVjiP03o`000?nY^^Go
ZK[U00;oZK[U0_l00002ojRkiP03o`000?nX^^KoZ;[V00KoZ;[V00?o0000ojRii_nX^NH00_nX^NH2
o`000003ojNgi?l0003oYkKS00OoYkKS00?o0000ojNehonW]N<01?nW]N<4o`0000KoY[WW00?o0000
ojFiionU^NL01_nU^NL3o`0000KoY:oO00?o0000oj>^gonS[]l01OnS[]l00ol0003oXjcMoj>/g@04
oj>/g@Co00001_nR^NT00ol0003oXKSYoj6hj@06oj6hj@03o`000?nR]nSoX[OX00Co00000_nOX]L0
0ol0003oWj3EoinPe@05oinPe@03o`000?nOW]?oWikC00GoWikC00?o0000oinLdOnOW=401OnOW=40
0ol0003oXI[>oj6JcP04o`0000;oWkSZ00?o0000oj:diOnR]>D01_nR]>D00ol0003oZK?PojVch005
ojVch0?o00001?nPRK/01?l0003oX8Vkoj29^ol00008ojF5/P03o`000?ncRjco/h^/00Go/h^/00?o
0000okB6Y?l000001onlPI@00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03[ooooo000U
ooooo`05oa0@4?ooooooooooooooool@41006oooool2o`0000;ooooo0_l00005ojVkiP03o`000?nY
^^KoZK[V00KoZK[V00Co0000ojVjiOl0003o00001OnX^nH00ol0003oZ;[VojRjiP06ojRjiP04o`00
0?nX^NKo0000o`0000CoYkOT00?o0000ojNfhonW]^<01_nW]^<00ol0003oYkGSojNeh`03o`0000?o
Y[[W00?o0000ojJiionV^NL01OnV^NL00ol0003oYKWWojFii`02ojFii`?o000000?oY;3Qo`000?nT
[ml01onT[ml00ol0003oXjkOoj>^g`05oj>^g`03o`000?nS[=goXjcM00?o00000_nR^^X00ol0003o
X[WYoj:ij@06oj:ij@03o`000?nQ^>WoXKSY00CoXKSY1?l00007oinRe`03o`000?nOX=GoWj3E00Go
Wj3E00?o0000oinNdonOW]<01OnOW]<00ol0003oWicAoinLd@03oinLd@Co00001onO^>X00ol0003o
X[CUoj:di@06oj:di@03o`000?nY/n3oZK?P00Co00000_nKR;l00ol0003oX8Vkoj29^`02oj29^`04
o`000?nPRK_oX8Vko`0000SoYHFb00?o0000ok>;[?ncRj`01OncRj`00ol0003o]8JTo`000007okb1
U003o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool002Gooooo00Go0000oooooooo
ooooooooo`00000Hooooo`?o00000_ooool2o`0000SoZK_V00?o0000ojVji_nY^^H01?nY^^H3o`00
00SoZ;_V00?o0000ojRji_nX^^H01?nX^^H3o`0000OoYkOT00?o0000ojNfhonW]^<01OnW]^<3o`00
00OoY[[W00?o0000ojJiionV^NL01OnV^NL01?l0003oYKWWo`000?l00005ojB`h@03o`000?nT[moo
Y:oO00GoY:oO00?o0000oj>^gonS[]l01?nS[]l4o`0000KoX[[Z00?o0000oj:ijOnR^NT01_nR^NT0
0ol0003oXKSYoj6hj@03o`0000;oWj?H00?o0000oinReonOX]L01_nOX]L00ol0003oWj3EoinPe@06
oinPe@03o`000?nOW]?oWikC00CoWikC00?o0000oinLdOnOW=400ol00002oibik@03o`000?nO^>[o
WkSZ00OoWkSZ00?o0000oj:diOnR]>D01?nR]>D4o`0000KoVhRo00?o0000oj29^onPRK/00_nPRK/0
1?l0003oX8Vkoj29^ol00008ojF5/P03o`000?ncRjco/h^/00Go/h^/00?o0000okB6Y?l000001onl
PI@00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Wooooo000Uooooo`05o`000?oooooo
ooooooooool000005_ooool2o`0000;ooooo0ol00002ojVli`03o`000?nY^nKoZK_V00KoZK_V00?o
0000ojVji_nY^^H00ol00002ojRki`03o`000?nX^nKoZ;_V00OoZ;_V00?o0000ojRji_nX^^H00ol0
0002ojNhi@03o`000?nW]nCoYkOT00KoYkOT00?o0000ojNfhonW]^<00_nW]^<2o`0000;oY[[X00?o
0000ojJjionV^^L01_nV^^L00ol0003oY[WWojJii`04ojJii`;o00002?nT/>400ol0003oY:oOojB_
g`05ojB_g`03o`000?nS[]ooXjkO00?o00000_nR^^X00ol0003oX[[Zoj:jjP06oj:jjP03o`000?nR
^NWoX[WY00CoX[WY1?l00006oinSf003o`000?nOX]OoWj;G00KoWj;G00?o0000oinPeOnOX=D01OnO
X=D00ol0003oWikCoinNd`02oinNd`Go00001_nL^Nd00ol0003oWkSZoinhjP06oinhjP03o`000?nR
]>GoX[CU00Co00000_nJSLD00ol0003oVhRooi^8_`06oi^8_`05o`000?nPRK_oX8Vkoj29^ol00000
0_nPRK/00ol0003oYHFbojF5/P07ojF5/P03o`000?ncRjco/h^/00Go/h^/00?o0000okb1U?nlPI@0
1_nlPI@00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Sooooo000Uooooo`05oa0@4?oo
ooooooooooooool@41004oooool3o`000004ooooool0003o0000o`0000KoZKcW00?o0000ojVki_nY
^nH01OnY^nH3o`0000KoZ;_W00?o0000ojRki_nX^nH01_nX^nH3o`0000KoYkSU00?o0000ojNgi?nW
]n@01_nW]n@01?l0003oYkKSo`000?l00005ojJjj003o`000?nV^^OoY[[W00KoY[[W00?o0000ojJi
ionV^NL00ol00002ojBah@03o`000?nT/>7oY;3Q00GoY;3Q00?o0000ojB_gonT[ml01?nT[ml4o`00
00KoX[[Z00?o0000oj:jj_nR^^X01_nR^^X00ol0003oX[WYoj:ij@03o`0000;oX:KJ00?o0000oinS
f?nOXmP01OnOXmP00ol0003oWj;GoinRe`06oinRe`03o`000?nOX=GoWj3E00CoWj3E1_l00004oi^l
k`03o`000?nL^NgoW;W]00GoW;W]00?o0000oinhj_nO^>X01?nO^>X4o`0000OoVXg500?o0000oi^8
_onKR;l01OnKR;l01Ol0003oX8Vkoj29^onPRK_o000000?oX8Vk00?o0000ojF5/_nUQK801_nUQK80
0ol0003o/h^/ok>;[004ok>;[0;o00002?nlPI@00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Oooooo000Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL04?ooool3o`000006ooooool0003o
0000o`000?nY_>Oo00002?nY_>L00ol0003oZK_VojVkiP02ojVkiP;o00000_nX^nL00ol0003oZ;_W
ojRki`05ojRki`03o`000?nX^nKoZ;_V00;oZ;_V0ol00002ojNii@03o`000?nW^>GoYkSU00GoYkSU
00?o0000ojNgi?nW]n@01?nW]n@3o`0000SoY[[X00?o0000ojJjionV^^L01?nV^^L4o`0000KoY;7Q
00?o0000ojB`hOnT/>401OnT/>400ol0003oY:oOojB_g`03o`0000;oXk_[00?o0000oj:jj_nR^^X0
1_nR^^X00ol0003oX[[Zoj:jjP04oj:jjPCo00001_nPY]X00ol0003oWj?HoinSf005oinSf003o`00
0?nOX]OoWj;G00GoWj;G00?o0000oinPeOnOX=D01?l00002oiZml003o`000?nK_>ooVkc_00KoVkc_
00?o0000oibikOnL^Nd01OnL^Nd00ol0003oWkSZoinhjP03o`0000;oV8k700?o0000oiZ=aOnJSLD0
1_nJSLD00ol0003oVhRooi^8_`05oi^8_`05o`000?nPRK_oX8Vkoj29^ol000000onPRK/00ol0003o
YHFbojF5/P06ojF5/P03o`000?ncRjco/h^/00;o/h^/0_l000000onIKIoo0000okb1U007okb1U003
o`000?oooooooooo00[ooooo0ol0000hooooo`009Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00ko
oooo0_l00002ooooo`;o00001OnY_>L00ol0003oZKcWojVli`06ojVli`04o`000?nY^nKo0000o`00
00GoZ;_W00?o0000ojRkionX^nL01OnX^nL01?l0003oZ;_Vo`000?l00006ojNii@03o`000?nW^>Go
YkSU00GoYkSU00?o0000ojNgi?nW]n@00ol00003ojJkj003o`000?nV^^SoY[[X00KoY[[X00?o0000
ojJjionV^^L00ol00002ojFchP03o`000?nT/N7oY;7Q00KoY;7Q00?o0000ojB`hOnT/>401?nT/>43
o`0000KoXk_[00?o0000oj:jj_nR^^X01_nR^^X00ol0003oX[[Zoj:jjP03o`0000;oX:OK00?o0000
oj2Vf_nPY]X01OnPY]X00ol0003oWj?HoinSf006oinSf003o`000?nOX]OoWj;G00?oWj;G1?l00007
oiZml003o`000?nK_>ooVkc_00KoVkc_00?o0000oibikOnL^Nd00_nL^Nd5o`0000KoV8k700?o0000
oiZ=aOnJSLD01OnJSLD00ol0003oVhRooi^8_`05oi^8_`05o`000?nPRK_oX8Vkoj29^ol000000onP
RK/00ol0003oYHFbojF5/P06ojF5/P05o`000?ncRjco/h^/ok>;[?l000000onIKIl00ol0003o_86D
okb1U006okb1U003o`000?oooooooooo00cooooo00?o0000ooooooooool0=_ooool003Gooooo1ol0
0008ojVli`03o`000?nY_>OoZKcW00CoZKcW0ol00008ojRki`03o`000?nX^nOoZ;_W00CoZ;_W0_l0
0009ojNii@03o`000?nW^>GoYkSU00CoYkSU0ol00007ojJkj003o`000?nV^^SoY[[X00CoY[[X1?l0
0006ojFchP03o`000?nT/N7oY;7Q00KoY;7Q00?o0000ojB`hOnT/>400ol00002oj>kj`03o`000?nS
^n_oXk_[00GoXk_[00?o0000oj:jj_nR^^X01?nR^^X4o`0000KoX:OK00?o0000oj2Vf_nPY]X01OnP
Y]X00ol0003oWj?HoinSf005oinSf003o`000?nOX]OoWj;G00?o00000_nK__400ol0003oV[g`oiZm
l007oiZml003o`000?nK_>ooVkc_00CoVkc_1_l00003oiVBb`03o`000?nHS/OoV8k700GoV8k700?o
0000oiZ=aOnJSLD01_nJSLD00ol0003oVhRooi^8_`05oi^8_`04o`000?nPRK_o0000o`0000CoX8Vk
00?o0000ojF5/_nUQK801_nUQK83o`0000CoVFfO00?o0000okb1U?nlPI@01_nlPI@00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03Gooooo000cooooo`;o00000_ooool3o`0000;oZKgW00?o
0000ojVlionY_>L01_nY_>L00ol0003oZKcWojVli`03o`0000?oZ;cW00?o0000ojRkionX^nL01_nX
^nL00ol0003oZ;_WojRki`03o`0000;oZ;WV00?o0000ojNiiOnW^ND01onW^ND00ol0003oYkSUojNh
i@03o`0000;oYk_X00?o0000ojJkj?nV^nP01_nV^nP00ol0003oY[[XojJjj003o`0000;oYKCS00?o
0000ojFch_nU/n801_nU/n800ol0003oY;7QojBah@04ojBah@Co00001_nS^n/00ol0003oXk_[oj>k
j`05oj>kj`03o`000?nR^^[oX[[Z00?o00000_nQZM`00ol0003oX:OKoj2Wf`06oj2Wf`03o`000?nP
Y][oX:KJ00GoX:KJ00?o0000oinSf?nOXmP00onOXmP4o`0000KoVkka00?o0000oiZml?nJ_O001_nJ
_O000ol0003oVkc_oi^lk`04o`0000;oVIC=00?o0000oiVBbonIT//01OnIT//00ol0003oV8k7oiR>
a`04oiR>a`03o`000?nJSLGoVXg500KoVXg500?o0000oi^8_onKR;l01?nKR;l3o`000003oj29^ol0
003oX8Vk00?oX8Vk00?o0000ojF5/_nUQK801OnUQK82o`0000OoVFfO00?o0000okb1U?nlPI@01_nl
PI@00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo000`ooooo`?o000000Cooooo
o`000?l0003o00001_nY_NL00ol0003oZKcWojVli`05ojVli`?o00001onX_>L00ol0003oZ;_WojRk
i`04ojRki`Co00001_nX^NH00ol0003oYkWUojNii@06ojNii@?o00001_nW^nP00ol0003oY[_XojJk
j005ojJkj0?o00001_nU]><00ol0003oYK?RojFchP06ojFchP03o`000?nT/N7oY;7Q00?o00000_nT
_>/00ol0003oXk_[oj>kj`06oj>kj`03o`000?nS^n_oXk_[00CoXk_[0ol00006oj6Yg003o`000?nP
Ym_oX:OK00GoX:OK00?o0000oj2Vf_nPY]X01OnPY]X00ol0003oWj?HoinSf003o`0000?oVl3b00?o
0000oi^nlOnK__401OnK__400ol0003oV[g`oiZml004oiZml0Co00001onIU<d00ol0003oVI;;oiVB
b`04oiVBb`03o`000?nHS/OoV8k700GoV8k700?o0000oiZ=aOnJSLD01OnJSLD01?l0003oVhRooi^8
_onKR;l3o`000003oi^8_ol0003oX8Vk00;oX8Vk00Go0000oj29^onPRK_oX8Vko`000005ojF5/P;o
000000?oV7:Vo`000?nIKIl01_nIKIl00ol0003o_86Dokb1U006okb1U003o`000?oooooooooo00go
oooo00?o0000ooooooooool0=?ooool002oooooo1Ol00002ojVmj003o`000?nY_NOoZKgW00GoZKgW
00?o0000ojVlionY_>L00_nY_>L2o`0000;oZ;cX00?o0000ojRlionX_>L01_nX_>L00ol0003oZ;_W
ojRki`03o`0000;oZ;[V00?o0000ojRii_nX^NH01_nX^NH00ol0003oYkWUojNii@02ojNii@?o0000
00?oYk_Xo`000?nW^nP01onW^nP00ol0003oY[_XojJkj002ojJkj0;o000000?oY[GTo`000?nU]><0
1onU]><00ol0003oYK?RojFchP05ojFchP?o00001_nT_>/00ol0003oXk_[oj>kj`06oj>kj`03o`00
0?nS^n_oXk_[00?o000000?oXJ_Mo`000?nQZM`01onQZM`00ol0003oX:OKoj2Wf`05oj2Wf`03o`00
0?nPY][oX:KJ00;oX:KJ1Ol00007oi_0lP03o`000?nK__7oVkka00GoVkka00?o0000oiZml?nJ_O00
0ol00002oiZGd003o`000?nIU<goVIC=00KoVIC=00?o0000oiVBbonIT//01?nIT//00ol0003oV8k7
oiR>a`05oiR>a`03o`000?nJSLGoVXg500KoVXg50ol00004oi^8_`03o`000?nPRK_oX8Vk00;oX8Vk
00Co0000oj29^onPRK_o00000onUQK82o`0000?oV7:V00?o0000oiU]WonIKIl01OnIKIl00ol0003o
_86Dokb1U006okb1U003o`000?oooooooooo00kooooo00?o0000ooooooooool0<oooool002oooooo
0_l00006ojVmj003o`000?nY_NOoZKgW00GoZKgW00Co0000ojVliol0003o00001OnX_>P00ol0003o
Z;cWojRli`05ojRli`?o00001_nX^^H00ol0003oZ;WVojRiiP06ojRiiP04o`000?nW^NGo0000o`00
00GoYk_X00?o0000ojNkj?nW^nP01_nW^nP01?l0003oY[_Xo`000?l00004ojJei003o`000?nU]>?o
YKCS00GoYKCS00?o0000ojFch_nU/n800_nU/n83o`000003ojBljol0003oY;c[00OoY;c[00?o0000
oj>kjonS^n/01?nS^n/4o`0000GoXJ_M00?o0000oj6Yg?nQZM`01OnQZM`00ol0003oX:OKoj2Wf`04
oj2Wf`Ko00001?nL`?800ol0003oVl3boi_0lP06oi_0lP03o`000?nK__7oVkka00;oVkka1Ol00006
oiZGd003o`000?nIU<goVIC=00KoVIC=00?o0000oiVBbonIT//01?nIT//00ol0003oV8k7oiR>a`05
oiR>a`03o`000?nJSLGoVXg500;oVXg51?l00007oi^8_`03o`000?nPRK_oX8Vk00;oX8Vk00?o0000
oj29^onPRK/00ol00005oiQbYP03o`000?nIKIooVFfO00GoVFfO00?o0000okb1U?nlPI@01_nlPI@0
0ol0003oooooooooo`0>ooooo`;o0000=?ooool002kooooo0ol00007ojVmj003o`000?nY_NOoZKgW
00CoZKgW0ol00007ojRlj003o`000?nX_>OoZ;cW00;oZ;cW0_l00002ojRki`03o`000?nX^^KoZ;[V
00GoZ;[V00?o0000ojRii_nX^NH01?nX^NH3o`0000SoYk_X00?o0000ojNkj?nW^nP01?nW^nP3o`00
00OoY[GT00?o0000ojFdhonU]><01OnU]><01?l0003oYK?Ro`000?l00005ojBlj`03o`000?nT_>_o
Y;c[00KoY;c[00?o0000oj>kjonS^n/00ol00002oj:]g`03o`000?nQZmgoXJ_M00GoXJ_M00?o0000
oj6Yg?nQZM`01OnQZM`00ol0003oX:OKoj2Wf`03o`0000?oWL7b00?o0000oic0l_nL`?801OnL`?80
0ol0003oVl3boi_0lP04oi_0lPKo00000onJVM800ol0003oVYO@oiZGd005oiZGd003o`000?nIU<go
VIC=00KoVIC=00?o0000oiVBbonIT//01?nIT//00ol0003oV8k7oiR>a`05oiR>a`03o`000?nJSLGo
000000;o00000onJSLD00ol0003oVhRooi^8_`03oi^8_`_o00002?nHLZH00ol0003oVFfOoiU]W`04
oiU]W`03o`000?nlPICo_86D00Ko_86D00?o0000ooooooooool03_ooool2o`0000Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Oooooo
000Tooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`0000SoZKgX00?o0000ojVmionY_NL0
0ol00003ojVmj003o`000?nX_>SoZ;cX00GoZ;cX00Co0000ojRliol0003o00001OnX^nL00ol0003o
Z;[VojRjiP05ojRjiP03o`000?nX^NKoZ;WV00?o00000onW_>P00ol0003oYk_XojNkj006ojNkj003
o`000?nW^nSoYk_X00?o00000_nV]^@00ol0003oY[GTojJei005ojJei003o`000?nU]>?oYKCS00Co
YKCS0ol00008ojBlj`03o`000?nT_>_oY;c[00CoY;c[1?l00006oj:]g`03o`000?nQZmgoXJ_M00Co
XJ_M00?o0000oj6Yg?nQZM`01?nQZM`4o`0000OoWL7b00?o0000oic0l_nL`?801OnL`?800ol0003o
Vl3boi_0lP03o`0000;oVi_C00?o0000oiZId_nJVM801OnJVM800ol0003oVYO@oiZGd005oiZGd003
o`000?nIU<goVIC=00GoVIC=00?o0000oiVBbonIT//01OnIT//00ol0003oV8k7oiR>a`03oiR>a`?o
00001onJSLD00ol0003oVhRoo`000002o`0000;oTWB]00?o0000ohi]ZOn>KJT00on>KJT00ol0003o
SVfYo`000008oiQbYP03o`000?nIKIooVFfO00CoVFfO00?o0000okb1U?nlPI@01_nlPI@00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Oooooo000Tooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool01?l0003oooooooooool00006ojVmj0Co00001onY_NP00ol0003oZ;cXojRl
j004ojRlj0?o00001onX^nL00ol0003oZ;[VojRjiP04ojRjiP?o00001onW_>P00ol0003oYk_XojNk
j004ojNkj0Co00001_nV]^@00ol0003oY[GTojJei005ojJei003o`000?nU]>?oYKCS00?o00000onT
_N/00ol0003oY;c[ojBlj`06ojBlj`03o`000?nT_>_oY;c[00?o00000_nR[]l00ol0003oXZgOoj:]
g`06oj:]g`03o`000?nQZmgoXJ_M00CoXJ_M00?o0000oj6Yg?nQZM`00ol00003oig1l@03o`000?nM
`O;oWL7b00KoWL7b00?o0000oic0l_nL`?800_nL`?85o`0000KoVi_C00?o0000oiZId_nJVM801?nJ
VM800ol0003oVYO@oiZGd005oiZGd003o`000?nIU<goVIC=00KoVIC=00?o0000oiVBbonIT//01?nI
T//01?l0003oV8k7oiR>aonHS/L>o`0000GoTWB]00?o0000ohi]ZOn>KJT01?n>KJT2o`0000SoV7:V
00?o0000oiU]WonIKIl01OnIKIl00ol0003o_86Dokb1U005okb1U003o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Gooooo`009?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00002oooo
o`03o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj007ojVmj003o`000?nX_>SoZ;cX
00?o00000onX^nL00ol0003oZ;_WojRki`05ojRki`03o`000?nX^^KoZ;[V00?o00000onW_>P00ol0
003oYkcXojNlj005ojNlj003o`000?nW^nSoYk_X00?o00000_nV]nD00ol0003oY[KTojJfi006ojJf
i003o`000?nV]NCoY[GT00CoY[GT0ol00007ojBmj`03o`000?nT_>_oY;c[00CoY;c[1?l00006oj:^
g`03o`000?nR[MooXZgO00GoXZgO00?o0000oj6[gOnQZmd01?nQZmd3o`0000OoWL7a00?o0000oig1
l_nM`O801?nM`O86o`0000?oW9oF00?o0000oi^KdonKVm<01OnKVm<00ol0003oVYWBoiZIdP05oiZI
dP03o`000?nJUm3oVYO@00CoVYO@00?o0000oiVDcOnIU<d01_nIU<d00ol0003oVI;;oiVBb`04oiVB
b`Ko00000_nBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nBM:goTWB]00GoTWB]00?o0000ohi]
ZOn>KJT00on>KJT00ol0003oSVfYo`000007oiQbYP03o`000?nIKIooVFfO00GoVFfO00?o0000okb1
U?nlPI@01OnlPI@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B405oooool002Cooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo0_l00006ojVmj003o`000?nY
_NSoZKgX00KoZKgX0ol00007ojRki`03o`000?nX^nOoZ;_W00CoZ;_W0ol00007ojNlj003o`000?nW
_>SoYkcX00CoYkcX0ol00006ojJgi@03o`000?nV]^CoY[KT00KoY[KT00?o0000ojJei?nV]N@00ol0
0003ojBlj`03o`000?nT_N_oY;g[00GoY;g[00?o0000ojBljonT_>/00ol00002oj>`h@03o`000?nR
[]ooXZkO00KoXZkO00?o0000oj:]gonR[Ml01OnR[Ml00ol0003oXJ_Moj6[g@03o`0000;oW/;a00?o
0000oig1lOnM`O401_nM`O400ol0003oWL7boig1lP03o`0000;oWJ3F00?o0000oibOe_nLWmH01OnL
WmH00ol0003oVi_Coi^Kd`05oi^Kd`03o`000?nJVM;oVYWB00CoVYWB00?o0000oiZGd?nJUm001OnJ
Um000ol0003oVIC=oiVDc@04oiVDc@_o00001OnBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nB
M:goTWB]00GoTWB]00?o0000ohi]ZOn>KJT01?n>KJT2o`0000OoV7:V00?o0000oiU]WonIKIl01OnI
KIl00ol0003o_86Dokb1U006okb1U003o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Gooooo`00
9?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003o
ZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol000000onX_>So0000ojRki`08ojRki`03
o`000?nX^nOoZ;_W00?o00000_nW_>P00ol0003oYkcXojNlj006ojNlj003o`000?nW_>SoYkcX00?o
00000_nV^>H00ol0003oY[OUojJgi@05ojJgi@03o`000?nV]^CoY[KT00CoY[KT1?l00007ojBlj`03
o`000?nT_N_oY;g[00CoY;g[0ol00006oj>`h@03o`000?nR[]ooXZkO00GoXZkO00?o0000oj:]gonR
[Ml01?nR[Ml4o`0000KoW/;a00?o0000oig1lOnM`O401?nM`O44o`0000KoWJ3F00?o0000oibOe_nL
WmH01?nLWmH00ol0003oVi_Coi^Kd`05oi^Kd`03o`000?nJVM;oVYWB00GoVYWB00?o0000oiZGd?nJ
Um001?nJUm000ol0003oVIC=oiVDc@04o`0000;oTgbg1?l00003oi1h]003o`000?nBN;;oTWRb00Go
TWRb00?o0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d[@04oi9d[@03o`000?n>KJWoSVfY00Go
SVfY00?o0000oiQbY_nHLZH01_nHLZH00ol0003oVFfOoiU]W`04oiU]W`03o`000?nlPICo_86D00Ko
_86D00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00omEEEGoQhN7ooooo`0Iooooo`009?ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool01?ooool00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000
o`0000GoZ;cX00?o0000ojRkionX^nL01_nX^nL3o`0000KoYkcX00?o0000ojNlj?nW_>P01OnW_>P3
o`0000KoY[SV00?o0000ojJgiOnV]nD01OnV]nD00ol0003oY[KTojJfi003o`0000?oYKg[00?o0000
ojBljonT_>/01_nT_>/00ol0003oY;g[ojBmj`03o`000003oj>ahOl0003oXk3Q00OoXk3Q00?o0000
oj:^gonR[]l01OnR[]l00ol0003oXZgOoj:]g`03o`0000?oWl;a00?o0000oik2lOnN`_401OnN`_40
0ol0003oWL7aoig1l@03o`0000;oWZ?I00?o0000oifPe_nMX=H01OnMX=H00ol0003oW9oFoibOeP05
oibOeP03o`000?nKVm?oVi_C00GoVi_C00?o0000oiZId_nJVM801?nJVM800ol0003oVYO@oiZGd002
oiZGd0Go00001?nCO;L3o`0000KoT7Rd00?o0000oi9h/_nBN;801OnBN;800ol0003oSW:_ohib[`05
ohib[`03o`000?nBM:goTWB]00CoTWB]00?o0000ohi]ZOn>KJT01On>KJT2o`0000OoV7:V00?o0000
oiU]WonIKIl01?nIKIl00ol0003o_86Dokb1U006okb1U003o`000?oooooooooo013ooooo0ol00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Iooooo`009?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo0_l00007ooooo`03o`000?nY_NSoZKgX00CoZKgX0ol0
0007ojRlj003o`000?nX^nOoZ;_W00;oZ;_W0ol000000onW_>Wo0000ojNlj007ojNlj003o`000?nW
_>SoYkcX00;oYkcX0_l000000onW^NKo0000ojJhiP07ojJhiP03o`000?nV]nGoY[OU00CoY[OU0ol0
0007ojFmj`03o`000?nT_>_oY;c[00CoY;c[1?l00005oj>ah@03o`000?nS/>7oXk3Q00GoXk3Q00?o
0000oj:^gonR[]l01?nR[]l4o`0000OoWl;a00?o0000oik2lOnN`_401?nN`_43o`0000KoWZ?I00?o
0000oifPe_nMX=H01OnMX=H00ol0003oW9oFoibOeP05oibOeP03o`000?nKVm?oVi_C00CoVi_C00?o
0000oiZId_nJVM800_nJVM87o`0000?oTgfi00?o0000oi=l]onCO;L00ol00003oi=l]`03o`000?n@
N;CoT7Rd00CoT7Rd00?o0000oi9h/_nBN;801?nBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nB
M:goTWB]00GoTWB]00?o0000ohi]ZOn>KJT01On>KJT00ol0003oV7:VoiQbYP05oiQbYP03o`000?nI
KIooVFfO00CoVFfO00?o0000okb1U?nlPI@01_nlPI@00ol0003oooooooooo`0Cooooo`09o`000?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@5oooool0
02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ojVmj?nY_NP00ol00003ojRmj003o`000?nX_>SoZ;cX00GoZ;cX00Co0000ojRkiol0003o00001OnW
_>T00ol0003oYkcXojNlj006ojNlj004o`000?nW_>So0000o`0000CoYkWV00?o0000ojJhi_nV^>H0
1_nV^>H00ol0003oY[OUojJgi@03o`0000?oYKgZ00?o0000ojFmjonU_N/01OnU_N/00ol0003oY;c[
ojBlj`03o`0000;oY;;R00?o0000oj>ahOnS/N401OnS/N400ol0003oXk3Qoj>`h@05oj>`h@03o`00
0?nR[]ooXZkO00?o00000onP`_400ol0003oWl;aoio2l@06oio2l@03o`000?nN`_7oW/;a00?o0000
00?oWjCIo`000?nNXmT01_nNXmT00ol0003oWJ3FoifPeP05oifPeP03o`000?nLWmKoW9oF00GoW9oF
00?o0000oi^KdonKVm<00_nKVm<7o`0000?oU82k00?o0000oi=m^OnCOKT01?nCOKT3o`0000KoTgbg
00?o0000oi1h]?n@N;@01?n@N;@00ol0003oTWRboi9h/P04oi9h/P03o`000?n>LZooSW:_00GoSW:_
00?o0000oi9d[OnBM:d01OnBM:d00ol0003oSVfYohi]Z@05ohi]Z@;o00001_nHLZH00ol0003oVFfO
oiU]W`05oiU]W`03o`000?nlPICo_86D00Go_86D00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0]ooooo`00;Oooool2o`0000Wooooo0_l00007ojRmj003o`000?nX_>SoZ;cX00CoZ;cX0ol0
0007ojNlj@03o`000?nW_>SoYkcX00CoYkcX0ol00007ojNiiP03o`000?nV^>KoY[SV00CoY[SV1?l0
0007ojFmjP03o`000?nU_N_oYKg[00CoYKg[0ol00006ojBbhP03o`000?nS/N7oXk7Q00CoXk7Q00?o
0000oj>`hOnS/>401?nS/>44o`0000OoX<;a00?o0000oio2lOnO`_401?nO`_44o`0000GoWjCI00?o
0000oijSfOnNXmT01OnNXmT00ol0003oWJ3FoifPeP05oifPeP03o`000?nLWmKoW9oF00?oW9oF1_l0
0003oiJ3_@03o`000?nDP;_oU82k00GoU82k00Co0000oi=m^OnCOKWoTgfi0_l000000onCOKWo0000
oi=l]`06oi=l]`03o`000?n@N;CoT7Rd00CoT7Rd00?o0000oi9h/_nBN;801OnBN;800ol0003oSW:_
ohib[`05ohib[`03o`000?nBM:goTWB]00CoTWB]00?o0000ohi]ZOn>KJT01On>KJT00ol0003oV7:V
o`000005oiQbYP03o`000?nIKIooVFfO00GoVFfO00?o0000okb1U?nlPI@01OnlPI@00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02cooooo000]ooooo`03o`000?oooooooooo00[ooooo00?o
0000ojRmj?nX_NP01OnX_NP00ol0003oZ;cXojRlj003o`0000?oYkgY00?o0000ojNljOnW_>T01OnW
_>T00ol0003oYkcXojNlj003o`0000?oYk[W00?o0000ojNii_nW^NH01OnW^NH00ol0003oY[SVojJh
iP03o`0000?oYKgZ00?o0000ojFmj_nU_NX01_nU_NX00ol0003oYKg[ojFmj`03o`000003ojBchol0
003oY;;R00OoY;;R00?o0000oj>ahOnS/N401?nS/N400ol0003oXk3Qoj>`h@03o`0000?oXL7`00?o
0000oj32lOnP`_401_nP`_400ol0003oWl;aoio2l@03o`0000;oX:OK00?o0000oinTfOnOY=T01?nO
Y=T00ol0003oWZ?IoijSf@06oijSf@03o`000?nMX=KoWJ3F00CoWJ3F00?o0000oibOe_nLWmH00ol0
0002oiJ4_P03o`000?nFPkgoUX>m00GoUX>m00?o0000oiB0^onDP;/01?nDP;/4o`0000?oTgfi00?o
0000oi=l]onCO;L01OnCO;L00ol0003oT7Rdoi1h]005oi1h]003o`000?nBN;;oTWRb00CoTWRb00?o
0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d[@04oi9d[@03o`000?n>KJWoSVfY00GoSVfY00?o
0000oiQbY_l000001_nHLZH00ol0003oVFfOoiU]W`04oiU]W`03o`000?nlPICo_86D00Go_86D00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`00;Oooool00ol0003oooooooooo`0;
ooooo`03o`000?nX_NSoZ;gX00CoZ;gX0ol00007ojNmj@03o`000?nW_>WoYkcY00CoYkcY0ol00007
ojNji`03o`000?nW^NKoYkWV00CoYkWV0ol00007ojFmjP03o`000?nU_N[oYKgZ00CoYKgZ1?l00005
ojBch`03o`000?nT/^;oY;;R00GoY;;R00?o0000oj>ahOnS/N401?nS/N43o`0000OoXL7`00?o0000
oj32lOnP`_401?nP`_44o`0000KoX:OK00?o0000oinTfOnOY=T01?nOY=T00ol0003oWZ?IoijSf@05
oijSf@03o`000?nMX=KoWJ3F00;oWJ3F1Ol00006oiJ4_P03o`000?nFPkgoUX>m00CoUX>m00?o0000
oiB0^onDP;/00_nDP;/3o`0000KoTgfi00?o0000oi=l]onCO;L01OnCO;L00ol0003oT7Rdoi1h]005
oi1h]003o`000?nBN;;oTWRb00CoTWRb00?o0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d[@05
oi9d[@03o`000?n>KJWoSVfY00GoSVfY00?o0000oiQbY_l000001OnHLZH00ol0003oVFfOoiU]W`04
oiU]W`03o`000?nlPICo_86D00Ko_86D00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[
ooooo`00;Oooool00ol0003oooooooooo`0<ooooo`03o`000?nX_NSoZ;gX00?o00000onW_NT00ol0
003oYkgYojNmj@05ojNmj@03o`000?nW_>WoYkcY00?o00000_nW^nP00ol0003oYk[WojNji`06ojNj
i`03o`000?nW^NKoYkWV00?o00000_nU_NX00ol0003oYKgZojFmjP06ojFmjP03o`000?nU_N[oYKgZ
00?o00000_nU]N@00ol0003oY;?SojBch`05ojBch`03o`000?nT/^;oY;;R00GoY;;R00?o0000oj>a
hOnS/N400ol00003oj;2k`;o00001_nQ`O000ol0003oX<;aoj32l@03o`0000;oXJSK00?o0000oj2W
fonPYm/01_nPYm/00ol0003oWjCIoinTf@04oinTf@03o`000?nNXmWoWZ?I00?oWZ?I1_l00003oiV9
`@03o`000?nFQ;koUXBn00GoUXBn00?o0000oiJ3_OnFPkd01?nFPkd00ol0003oU82ko`000002o`00
00?oU82k00?o0000oi=m^OnCOKT01?nCOKT00ol0003oTgbgoi=l]`05oi=l]`03o`000?n@N;CoT7Rd
00CoT7Rd00?o0000oi9h/_nBN;801?nBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nBM:goTWB]
00GoTWB]00?o0000ohi]ZOn>KJT01On>KJT01?l0003oV7:VoiQbY_l00004oiQbYP03o`000?nIKIoo
VFfO00CoVFfO00?o0000okb1U?nlPI@01_nlPI@00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo02[ooooo000/ooooo`;o00003oooool2o`0000OoYkgY00?o0000ojNmjOnW_NT01?nW_NT3o`00
00KoYk_X00?o0000ojNjionW^^L01OnW^^L3o`0000KoYKgZ00?o0000ojFmj_nU_NX01OnU_NX3o`00
00KoYKGT00?o0000ojBchonT/n<01OnT/n<00ol0003oY;;RojBbhP02ojBbhPGo00002?nR`^l01?l0
003oXL7`oj71l?nQ`O05o`0000KoXJSK00?o0000oj2WfonPYm/01OnPYm/00ol0003oWjCIoinTf@04
oinTf@03o`000?nNXmWoWZ?I00?o00000_nHRL800ol0003oVHW1oiV9`@05oiV9`@03o`000?nFQ;ko
UXBn00CoUXBn00?o0000oiJ3_OnFPkd00onFPkd3o`0000KoU82k00?o0000oi=m^OnCOKT01?nCOKT0
0ol0003oTgbgoi=l]`05oi=l]`03o`000?n@N;CoT7Rd00CoT7Rd00?o0000oi9h/_nBN;801?nBN;80
0ol0003oSW:_ohib[`05ohib[`03o`000?nBM:goTWB]00GoTWB]00?o0000ohi]ZOn>KJT01On>KJT0
1Ol0003oV7:VoiQbY_nHLZKo000000?oV7:V00?o0000oiU]WonIKIl01OnIKIl00ol0003o_86Dokb1
U005okb1U003o`000?oooooooooo01Cooooo0_l0000/ooooo`00;Oooool00ol0003oooooooooo`0=
ooooo`03o`000?nW_NWoYkgY00OoYkgY00?o0000ojNmjOnW_NT00ol000000onW_>So0000ojNkj007
ojNkj003o`000?nW^^OoYk[W00;oYk[W0_l000000onV_N[o0000ojFmjP07ojFmjP03o`000?nU_N[o
YKgZ00;oYKgZ0_l000000onU]^Go0000ojFei007ojFei003o`000?nT/n?oY;?S00CoY;?S1Ol00005
oj;1k`03o`000?nR`^ooX/;_00CoX/;_1Ol00003oj:/gP03o`000?nQZ=_oXJSK00KoXJSK00?o0000
oj2WfonPYm/01OnPYm/01?l0003oWjCIoinTfOnOY=T5o`0000KoV8W200?o0000oiV9`OnIRL401?nI
RL400ol0003oUXBnoiJ4_P05oiJ4_P03o`000?nFPkgo000000;o00000_nFPkd00ol0003oU82koiB0
^`04oiB0^`03o`000?nCOKWoTgfi00CoTgfi00?o0000oi=l]onCO;L01OnCO;L00ol0003oT7Rdoi1h
]005oi1h]003o`000?nBN;;oTWRb00CoTWRb00?o0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d
[@04oi9d[@03o`000?n>KJWoSVfY00GoSVfY00Go0000oiQbY_nHLZKoV7:Vo`000003oiQbYP03o`00
0?nIKIooVFfO00GoVFfO00?o0000okb1U?nlPI@01OnlPI@00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02Wooooo000/ooooo`03o`000?oooooooooo00oooooo00?o0000ojNmjOnW_NT01_nW
_NT3o`0000GoYkcX00?o0000ojNkj?nW^nP01_nW^nP01?l0003oYk[Wo`000?l00004ojJmjP03o`00
0?nU_N[oYKgZ00KoYKgZ00Co0000ojFmj_l0003o00001?nU]^D00ol0003oYKGTojFei006ojFei003
o`000?nT/n?oY;?S00?o00000onS`Nh00ol0003oX/7_oj;1k`05oj;1k`03o`000?nR`^ooX/;_00?o
00000_nRZmh00ol0003oXZcNoj:/gP04oj:/gP03o`000?nQZ=_oXJSK00GoXJSK00?o0000oj2WfonP
Ym/01?nPYm/5o`0000?oVhk500?o0000oiR9`_nHRL801OnHRL800ol0003oVHW1oiV9`@04oiV9`@03
o`000?nFQ;koUXBn00CoUXBn0ol00005oiJ3_@03o`000?nDP;_oU82k00GoU82k00?o0000oi=m^OnC
OKT01?nCOKT00ol0003oTgbgoi=l]`04oi=l]`03o`000?n@N;CoT7Rd00GoT7Rd00?o0000oi9h/_nB
N;801?nBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nBM:goTWB]00GoTWB]00?o0000ohi]ZOn>
KJT01?n>KJT00ol0003oV7:VoiQbYP02oiQbYP04o`000?nHLZKoV7:Vo`0000OoVFfO00?o0000okb1
U?nlPI@01OnlPI@00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Sooooo000/ooooo`?o
00004?ooool00ol0003oYkgYojNmj@02ojNmj@?o000000?oYkgYo`000?nW_>P01_nW_>P00ol0003o
Yk_XojNkj004ojNkj0?o00001onV_NX00ol0003oYKgZojFmjP04ojFmjP?o00001onU]^D00ol0003o
YKGTojFei004ojFei0Co00001onS`Nh00ol0003oX/7_oj;1k`04oj;1k`?o00001_nRZmh00ol0003o
XZcNoj:/gP04oj:/gP03o`000?nQZ=_oXJSK00GoXJSK00?o0000oj2WfonPYm/00ol00002oiV>aP03
o`000?nKS/GoVhk500CoVhk500?o0000oiR9`_nHRL801?nHRL800ol0003oVHW1oiV9`@05oiV9`@04
o`000?nFQ;koUXBnoiJ4_P;o000000?oUXBno`000?nFPkd01_nFPkd00ol0003oU82koiB0^`04oiB0
^`03o`000?nCOKWoTgfi00CoTgfi00?o0000oi=l]onCO;L01?nCO;L00ol0003oT7Rdoi1h]005oi1h
]003o`000?nBN;;oTWRb00CoTWRb00?o0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d[@05oi9d
[@03o`000?n>KJWoSVfY00GoSVfY00?o0000oiQbY_nHLZH00_nHLZH01?l0003oV7:VoiQbY_l00006
oiU]W`03o`000?nlPICo_86D00Go_86D00?o0000ooooooooool05oooool00ol0003oooooooooo`0X
ooooo`00;?ooool00ol0003oooooooooo`0Aooooo`04o`000?nW_NWo0000o`0000GoYkgY00?o0000
ojNlj?nW_>P01OnW_>P00ol0003oYk_XojNkj003o`0000?oY[gZ00?o0000ojJmj_nV_NX01OnV_NX0
0ol0003oYKgZojFmjP03o`0000?oY[SV00?o0000ojFfiOnU]^D01OnU]^D00ol0003oYKGTojFei003
o`0000?oXl3^00?o0000oj?1k_nS`Nh01_nS`Nh00ol0003oX/7_oj;1k`03o`000003oj>_h?l0003o
XZ_N00OoXZ_N00?o0000oj:/g_nR[=h00onR[=h00ol0003oXJSKoj6Xf`04oj6Xf`Co00001OnIS/H0
0ol0003oVhk5oi^>a@04oi^>a@03o`000?nHRL;oV8W200GoV8W200?o0000oiV9`OnIRL401?nIRL44
o`0000CoUXBn00?o0000oiJ3_OnFPkd01?nFPkd00ol0003oU82koiB0^`04oiB0^`03o`000?nCOKWo
Tgfi00CoTgfi00?o0000oi=l]onCO;L01OnCO;L00ol0003oT7Rdoi1h]005oi1h]003o`000?nBN;;o
TWRb00?oTWRb00?o0000ohib[on>LZl01On>LZl00ol0003oTWB]oi9d[@05oi9d[@03o`000?n>KJWo
SVfY00GoSVfY00?o0000oiQbY_nHLZH00onHLZH00ol0003oV7:Vo`000006oiU]W`03o`000?nlPICo
_86D00Go_86D00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Wooooo`002Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool2o`0000OoYkgY00?o0000ojNlj?nW_>P01?nW
_>P3o`0000OoY[gZ00?o0000ojJmj_nV_NX01?nV_NX3o`0000OoY[SV00?o0000ojFfiOnU]^D01?nU
]^D3o`0000OoXl3^00?o0000oj?1k_nS`Nh01?nS`Nh4o`0000GoXjoP00?o0000oj:[g_nRZmh01OnR
Zmh00ol0003oXZcNoj:/gP04oj:/gP03o`000?nQZ=_oXJSK00?o00000_nMU<T00ol0003oVHk6oiV>
aP05oiV>aP03o`000?nKS/GoVhk500?oVhk500?o0000oiR9`_nHRL801OnHRL800ol0003oVHW1oiV9
`@02oiV9`@?o00001onFQ;h00ol0003oUX>moiJ3_@04oiJ3_@03o`000?nDP;_oU82k00GoU82k00?o
0000oi=m^OnCOKT01?nCOKT00ol0003oTgbgoi=l]`04oi=l]`04o`000?n@N;CoT7Rdoi1h]0Wo0000
0_nBN;800ol0003oSW:_ohib[`05ohib[`03o`000?nBM:goTWB]00CoTWB]00?o0000ohi]ZOn>KJT0
1On>KJT00ol0003oV7:VoiQbYP03oiQbYP03o`000?nHLZKo000000KoVFfO00?o0000okb1U?nlPI@0
1OnlPI@00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo0009ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oYkgYojNmj@05ojNmj@03
o`000?nW_>SoYkcX00?o00000onV_>T00ol0003oY[gZojJmjP05ojJmjP03o`000?nV_N[oY[gZ00?o
00000onV^NL00ol0003oY[SVojJhiP05ojJhiP03o`000?nU]^GoYKKU00?o00000onT_nd00ol0003o
Xl3^oj?0kP05oj?0kP03o`000?nS`NkoXl7^00?o00000_nS[n000ol0003oXjoPoj>_h005oj>_h003
o`000?nRZmkoXZ_N00GoXZ_N00Co0000oj:/g_nR[=koXZcN1Ol00006oifDb@03o`000?nIS/KoVHk6
00CoVHk600?o0000oi^>aOnKS/D01?nKS/D00ol0003oV8W2oiR9`P05oiR9`PCo00000onIRL400ol0
003oUXBnoiJ4_P04oiJ4_P03o`000?nFPkgoUX>m00GoUX>m00Co0000oiB0^onDP;_oU82k5Ol00002
oi2>cP03o`000?n=RlcoSH_<00CoSH_<3ol00003oi9d[@03o`000?n>KJWoSVfY00CoSVfY00?o0000
oiQbY_nHLZH01?nHLZH2o`0000OoVFfO00?o0000okb1U?nlPI@01OnlPI@00ol0003oooooooooo`0G
ooooo`;o0000:?ooool000Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00_ooool2o`0001Oooooo00?o0000ojNmjOnW_NT01?nW_NT3
o`0000OoY[cY00?o0000ojJmj_nV_NX01?nV_NX3o`0000OoY[WW00?o0000ojJhi_nV^>H01?nV^>H3
o`0000OoY;o]00?o0000oj?0k_nS`>h01?nS`>h3o`0000KoXjoP00?o0000oj>_h?nS[n001?nS[n00
0ol0003oXZ_Noj:[gP04oj:[gPGo00000onKU</00ol0003oWIC9oifDb@05oifDb@03o`000?nIS/Ko
VHk600CoVHk600?o0000oi^>aOnKS/D01?nKS/D00ol0003oV8W2oiR9`P03oiR9`P?o00001_nIRL40
0ol0003oUXBnoiJ4_P05oiJ4_P04o`000?nFPkgoUX>moiJ3_@Oo000000?oUiSCo`000?nEUM401OnE
UM400ol0003oTi;@oi>Bd005oi>Bd003o`000?n@S/koT8k>00GoT8k>00?o0000ohf;c?n=Rl`01?n=
Rl`00ol0003oR8G9ohR5b@04ohR5b@03o`000?n5PLKoQH7600CoQH762?l00003ohi]Z@03o`000?nH
LZKoV7:V00CoV7:V00?o0000oiU]WonIKIl01OnIKIl00ol0003o_86Dokb1U005okb1U003o`000?oo
oooooooo01Sooooo0_l0000Wooooo`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
V9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Oooooo00?o
0000ojNmjOnW_NT00ol00003ojJlj@03o`000?nV_>WoY[cY00GoY[cY00?o0000ojJmj_nV_NX00ol0
0002ojJjj003o`000?nV^NOoY[WW00KoY[WW00?o0000ojJhi_nV^>H00ol00002ojBnk003o`000?nT
_ngoY;o]00KoY;o]00?o0000oj?0k_nS`>h00ol000000onT/^?o0000oj>_h007oj>_h003o`000?nS
[n3oXjoP00CoXjoP00?o0000oj:[g_nRZmh00ol00002oinJcP03o`000?nKU<_oViC;00CoViC;00?o
0000oifDbOnMU<T01OnMU<T00ol0003oVHk6oiV>aP04oiV>aP03o`000?nKS/GoVhk500CoVhk500?o
0000oiR9`_l000000_l00002oiR9`P03o`000?nIRL7oVHW100CoVHW100?o0000oiJ4__nFQ;h00_nF
Q;h7o`000003oiVKe?l0003oUiSC00KoUiSC00?o0000oiFEdOnEUM401?nEUM400ol0003oTi;@oi>B
d004oi>Bd003o`000?n@S/koT8k>00GoT8k>00?o0000ohf;c?n=Rl`01?n=Rl`00ol0003oR8G9ohR5
b@04ohR5b@03o`000?n5PLKoQH7600CoQH7600?o0000ogih`_mnN<801OmnN<86o`0000CoV7:V0_l0
0006oiU]W`03o`000?nlPICo_86D00Go_86D00?o0000ooooooooool06?ooool3o`0002Kooooo0009
ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Hooooo`;o00001onV_>T00ol0003oY[cY
ojJlj@04ojJlj@?o00001_nV^^P00ol0003oY[WWojJii`04ojJii`Co00001_nT_^`00ol0003oY;o]
ojBok@04ojBok@Co00001OnT/^<00ol0003oXjoPoj>_h005oj>_h003o`000?nS[n3oXjoP00CoXjoP
0ol00006oinJcP03o`000?nKU<_oViC;00?oViC;00?o0000oifDbOnMU<T01OnMU<T00ol0003oVHk6
oiV>aP04oiV>aP03o`000?nKS/GoVhk500?oVhk50ol00004oiR9`Pgo00000_nJWMH00ol0003oVI_D
oiVKe004oiVKe003o`000?nGV=?oUiSC00CoUiSC00?o0000oiFEdOnEUM401?nEUM400ol0003oTi;@
oi>Bd002oi>Bd13o000000?oSH_<o`000?n8QLT01_n8QLT00ol0003oQH76ohF1aP04ohF1aP03o`00
0?mnN<;oOWS200CoOWS200?o0000ogQa_omhLKl00omhLKl4o`000003oiQbY_l0003oVFfO00GoVFfO
00?o0000okb1U?nlPI@01OnlPI@00ol0003oooooooooo`0Gooooo`Co00009_ooool000Wooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool2o`0001[ooooo00?o0000ojJljOnV_>T01_nV_>T00ol0003oY[cYojJlj@03o`0000;oY[_X
00?o0000ojJjj?nV^^P01OnV^^P00ol0003oY[WWojJii`03o`0000?oY;k/00?o0000ojBnk?nT_^`0
1OnT_^`00ol0003oY;o]ojBok@03o`0000;oY;?S00?o0000ojBbhonT/^<01OnT/^<00ol0003oXjoP
oj>_h005oj>_h003o`000?nS[n3oXjoP00?o000000?oWI[@o`000?nOV/h01_nOV/h00ol0003oViC;
oi^Db`04oi^Db`03o`000?nMU<WoWIC900CoWIC900?o0000oiV>a_nIS/H01?nIS/H01?l0003oVhk5
oi^>aOnKS/D2o`000004oi^>aOl0003oV8W2oiR9`PCo00001onLX=L00ol0003oVYgFoiZMeP04oiZM
eP03o`000?nIVmCoVI_D00CoVI_D00?o0000oiNHdonGV=<00_nGV=<>o`0000CoO[Oh00?o0000ogNc
n?mg/oP01?mg/oP00ol0003oKZcfofj/mP02ofj/mPco00001?n5PLH00ol0003oOWS2ogih`P05ogih
`P03o`000?mhLKooN76o00CoN76o00?o0000ofIQ^?l000000_l00005oiU]W`03o`000?nlPICo_86D
00Go_86D00?o0000ooooooooool05oooool5o`0002Gooooo0009ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?nV_>WoY[cY00CoY[cY1?l00006ojJkj003o`000?nV^^So
Y[[X00CoY[[X0ol00007ojBnk003o`000?nT_^coY;k/00CoY;k/0ol00006ojBch`03o`000?nT/^?o
Y;;S00CoY;;S00?o0000oj>_h?nS[n001?nS[n04o`0000GoWI[@00?o0000oinJc_nOV/h01?nOV/h0
0ol0003oViC;oi^Db`04oi^Db`03o`000?nMU<WoWIC900GoWIC900?o0000oiV>a_nIS/H01?nIS/H3
o`000003oi^>aOl0003o000000?o00000onMX]P00ol0003oW:3GoibPe`05oibPe`03o`000?nJWMKo
VYgF00CoVYgF00?o0000oiVKe?nIVm@00_nIVm@7o`0000CoRKgh00?o0000ohBjn?n4^_P01On4^_P0
0ol0003oO[Ohogjgn004ogjgn003o`000?mg/oSoMk?h00CoMk?h00?o0000ofj/m_m^[?H00om^[?H0
0ol0003oI:CdofBTm004ofBTm003o`000?mFV?7oEYSa00Go00001omnN<800ol0003oN76oogQa_`04
ogQa_`03o`000?mVHKSoIV6h00;oIV6h0_l00003oiU]W`03o`000?nlPICo_86D00Go_86D00?o0000
ooooooooool05oooool6o`0002Cooooo0009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo01_ooooo00?o
0000ojJljOnV_>T00ol00003ojJlj@03o`000?nV^nSoY[_X00GoY[_X00?o0000ojJjj?nV^^P00ol0
0003ojBmj`03o`000?nT_^coY;k/00GoY;k/00?o0000ojBnk?nT_^`00ol000000onU]^Go0000ojBc
h`07ojBch`03o`000?nT/^?oY;;S00CoY;;S00?o0000oj>_h?nS[n000ol00002oj6Pe003o`000?nM
V]3oWI[@00CoWI[@00?o0000oinJc_nOV/h01OnOV/h00ol0003oViC;oi^Db`04oi^Db`03o`000?nM
U<WoWIC900CoWIC900Co0000oiV>a_nIS/KoVHk61ol000000onOYMWo0000oifRf006oifRf003o`00
0?nLX=OoW:3G00GoW:3G00Co0000oiZMe_nJWMKoVYgF1ol00004ohfnm`03o`000?n9_OSoRKgh00Go
RKgh00?o0000ohBjn?n4^_P01On4^_P00ol0003oO[Ohogjgn004ogjgn003o`000?mg/oSoMk?h00Co
Mk?h00?o0000ofj/m_m^[?H00om^[?H00ol0003oI:CdofBTm004ofBTm003o`000?mFV?7oEYSa00?o
EYSa1?l00004ogih`P03o`000?mhLKooN76o00CoN76o00?o0000ofIQ^?mVHKP00_mVHKP01?l0003o
IV6ho`000?l00002oiU]W`03o`000?nlPICo_86D00Co_86D00?o0000ooooooooool05oooool4o`00
0003onWIa?l0003ooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo<c<co8B4Qo`000?lQ8B7oc<c<00Oooooo000[ooooo`03o`000?oooooooooo01cooooo0_l00007
ojJlj@03o`000?nV^nSoY[_X00CoY[_X0ol00007ojBmj`03o`000?nT_^coY;k/00CoY;k/0ol00005
ojFfi@03o`000?nT/n?oY;?S00KoY;?S00Co0000ojBbhonT/^?oY;;S1Ol00006oj6Pe003o`000?nM
V]3oWI[@00CoWI[@00?o0000oinJc_nOV/h01?nOV/h00ol0003oViC;oi^Db`04oi^Db`03o`000?nM
U<WoWIC900;oWIC91_l00002oinVf`03o`000?nOYMWoWjGI00CoWjGI00?o0000oifRf?nMX]P01OnM
X]P00ol0003oW:3GoibPe`03oibPe`Go00001?nA`?H00ol0003oSKkgohfnm`05ohfnm`03o`000?n9
_OSoRKgh00GoRKgh00?o0000ohBjn?n4^_P00_n4^_PFo`000003ofj/m_l0003oI:Cd00GoI:Cd00?o
0000oeJHlOmFV?400omFV?400ol0003oAX[[odJ:j`04o`000003ogih`_l0003oN76o00CoN76o00?o
0000ofIQ^?mVHKP00omVHKP2o`000004odM;/_l0003o0000o`0000Ko_86D00?o0000ooooooooool0
5oooool3o`0000;ojMW40_l00007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`00:_ooool2o`00023ooooo00?o0000ojJljOnV
_>T01OnV_>T00ol0003oY[_XojJkj003o`0000?oY;g[00?o0000ojBmjonT_N/01OnT_N/00ol0003o
Y;k/ojBnk003o`000003ojFgiOl0003oYKKU00KoYKKU00?o0000ojBchonT/n<01?nT/n<5o`0000?o
Wj7F00?o0000oj6Pe?nQX=@01OnQX=@00ol0003oWI[@oifJd004oifJd003o`000?nOV/koWi[>00Co
Wi[>00?o0000oi^DbonKU</00_nKU</:o`0000GoWjKK00?o0000oinUfOnOYMT01?nOYMT00ol0003o
WJ;HoifRf005oifRf003o`000?nLX=OoW:3G00?o00000_nC`?D00ol0003oTL3foi70mP05oi70mP03
o`000?n=__OoSKkg00GoSKkg00?o0000ohVmn?n9_OP00_n9_OP7o`0000?oSJWX00?o0000ohRVj?n8
Y^P01?n8Y^P00ol0003oPZ;Xoh:Rj004oh:Rj003o`000?mjW>OoNYcW00;oNYcW1ol00002ofBTm003
o`000?mFV?7oEYSa00?oEYSa00?o0000odJ:jom6R^/00om6R^/3o`0000GoN76o00?o0000ofIQ^?mV
HKP00omVHKP01Ol0003oAd^bodM;/_m7Bk;o000000Oo_86D00?o0000ooooooooool05Oooool01?l0
003o/V=cok9SLol00003onWIa0;o00001_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000007ooooo`00:_ooool00ol0003oooooooooo`0Pooooo`03o`000?nV
_>WoY[cY00CoY[cY0ol00007ojBmj`03o`000?nT_N_oY;g[00CoY;g[0ol00005ojFgi@03o`000?nU
]^GoYKKU00GoYKKU00?o0000ojBchonT/n<00ol00002oj>Wf@03o`000?nOXMKoWj7F00CoWj7F00?o
0000oj6Pe?nQX=@01OnQX=@00ol0003oWI[@oifJd004oifJd003o`000?nOV/koWi[>00?oWi[>2?l0
00001_nQZMco0000o`000?l0003oXJWLo`0000OoWjKK00?o0000oinUfOnOYMT01?nOYMT00ol0003o
WJ;HoifRf002oifRf0Go00001_nC`?D00ol0003oTL3foi70mP05oi70mP03o`000?n=__OoSKkg00;o
SKkg1ol00003oi6/j003o`000?n=ZNSoSJWX00GoSJWX00?o0000ohRVj?n8Y^P01?n8Y^P00ol0003o
PZ;Xoh:Rj004oh:Rj003o`000?mjW>OoNYcW00?oNYcW00?o0000og2Ei_m`UNH00_m`UNH8o`000003
oeJHlOl0003oAX[[00CoAX[[00Co0000obachOl0003o00000omhLKl00ol0003oIV6hofIQ^004ofIQ
^004o`000?m7Bk;oAd^bo`0000Oo_86D00?o0000ooooooooool05Oooool01?l0003o/V=cok9SLol0
0003onWIa0;o00001_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P07ooooo`00:_ooool00ol0003oooooooooo`0Qooooo`03o`000?nV_>WoY[cY00?o0000
0_nT_>X00ol0003oY;g[ojBmj`06ojBmj`03o`000?nT_N_oY;g[00?o000000?oYKWWo`000?nU]nD0
1_nU]nD00ol0003oYKKUojFfi@04ojFfi@?o00001_nSYmT00ol0003oWj7FoinQeP04oinQeP03o`00
0?nQX=CoXJ3D00CoXJ3D00?o0000oifJd?nMV]001?nMV]000ol0003oWi[>oinJcP06o`0000?oXJ[M
0ol00005oj6Yg003o`000?nOY]_oWjKK00CoWjKK00?o0000oinUfOnOYMT00_nOYMT7o`0000GoUl7e
00?o0000oi?0mOnC`?D01?nC`?D00ol0003oTL3foi70mP02oi70mPOo00000onD[^P00ol0003oTJcX
oi6/j005oi6/j003o`000?n=ZNSoSJWX00CoSJWX00?o0000ohRVj?n8Y^P01On8Y^P00ol0003oPZ;X
oh:Rj004oh:Rj003o`000?mjW>OoNYcW00?oNYcW00?o0000og2Ei_m`UNH01?m`UNH00ol0003oI8cT
ofB<i002ofB<i0Co00001?m6R^/00ol0003o;7?Qobach@02o`000003ogQa_ol0003oIV6h00GoIV6h
00Go0000odM;/_m7Bk;oAd^bo`000006okb1U003o`000?oooooooooo01Gooooo00Co0000ok9SLonb
Hg?o00000_oYfL@01?l0003ojO[4o`000?l00005ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Oooooo000Zooooo`;o00008oooool2o`0000KoY;cZ00?o
0000ojBmjonT_N/01?nT_N/4o`0000GoYKWW00?o0000ojFgiOnU]nD01OnU]nD00ol0003oYKKUojFf
i@03o`000003oj6Yg?l0003oXjOI00KoXjOI00?o0000oinQe_nOXMH01?nOXMH00ol0003oXJ3Doj6P
e004oj6Pe003o`000?nMV]3oWI[@00;oWI[@1_l000000onS[Mko0000oj6Zg@03oj6Zg@;o000000?o
XJ[Mo`000?nQZM`01OnQZM`00ol0003oWjKKoinVf`04oinVf`Go00001?nH`O@00ol0003oUl7eoiO1
m@06oiO1m@04o`000?nC`?GoTl3eoi?0m@Oo00000onG/>P00ol0003oU:kXoiB^j005oiB^j003o`00
0?nA[>SoTJcX00GoTJcX00?o0000ohfYj?n=ZNP01?n=ZNP00ol0003oR:KXohRVj004ohRVj003o`00
0?n2X^SoPZ;X00CoPZ;X00?o0000ogZLiomjW>L01?mjW>L00ol0003oL9GVog2EiP04og2EiP03o`00
0?mTS>CoI8cT00?oI8cT00?o0000oe9oh?l000000_l00002odJ:j`04o`000?l/Ln7o;7?Qobach@?o
00001OmVHKP2o`0000;oAd^b00?o0000okb1U?nlPI@01?nlPI@00ol0003oooooooooo`0Eooooo`06
o`000?nbHg?o/V=co`000?oYfLCo00000ooYn/@2o`0000Cooooo00Go410@oooooooooooooooooa0@
400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001oooool002[ooooo00?o0000ooooooooool08ooo
ool00ol0003oY;cZojBljP05ojBljP03o`000?nT_N_oY;g[00?o00000_nU^^P00ol0003oYKWWojFi
i`05ojFii`03o`000?nU]nGoYKOU00CoYKOU0ol00005oj6Yg003o`000?nSYmWoXjOI00GoXjOI00?o
0000oinQe_nOXMH01?nOXMH01?l0003oXJ3Doj6Pe?nQX=@:o`0000GoXjgN1?l00004oj6Zg@03o`00
0?nQZMcoXJWL00CoXJWL00?o0000oinVfonOY]/00ol00002oi[1l`03o`000?nH`OCoV<7d00GoV<7d
00?o0000oiO1mOnG`OD01?nG`OD5o`0000?oVK7X00?o0000oiN`j?nG/>P01OnG/>P00ol0003oU:kX
oiB^j005oiB^j003o`000?nA[>SoTJcX00CoTJcX00?o0000ohfYj?n=ZNP01?n=ZNP00ol0003oR:KX
ohRVj002ohRVj0So00000_n2X^P00ol0003oNYcWogZLi`04ogZLi`03o`000?m`UNKoL9GV00?oL9GV
00?o0000ofB<i?mTS>@01?mTS>@01?l0003oDWoPoe9oh?mBOn03o`0000Go;7?Q0_l00004ofIQ^003
o`000?m7Bk;o000000;oAd^b00?o0000okb1U?nlPI@00onlPI@00ol0003oooooooooo`0Dooooo`07
o`000?nbHg?o/V=cok9SLol0003ojMW4o`000003onWja0;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000007ooooo`00:_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?nT_>[oY;cZ00CoY;cZ0ol00006ojFjj003o`000?nU^NOoYKWW00GoYKWW00?o
0000ojFgiOnU]nD00ol000000onS[n3o0000oj6Yg006oj6Yg003o`000?nSYmWoXjOI00GoXjOI00?o
0000oinQe_nOXMH00onOXMH4o`0000?oImGc0ol00002oj:^h003o`000?nS[MkoXjgN00;oXjgN1?l0
0006oj6Zg@03o`000?nQZMcoXJWL00;oXJWL1Ol00006oi[1l`03o`000?nH`OCoV<7d00GoV<7d00?o
0000oiO1mOnG`OD00ol00002oiZbj003o`000?nI/NSoVK7X00CoVK7X00?o0000oiN`j?nG/>P01OnG
/>P00ol0003oU:kXoiB^j004oiB^j003o`000?nA[>SoTJcX00;oTJcX3_l00003oh6^l@03o`000?mh
ZO;oN:Wb00;oN:Wb3Ol00003og2EiP03o`000?mTS>CoI8cT00?oI8cT00?o0000oe9oh?mBOn001?mB
On02o`0000?o;7?Q00?o0000o`QFdOl000001?mVHKP2o`0000?oAd^b00?o0000okb1U?nlPI@00_nl
PI@00ol0003oooooooooo`0Dooooo`04o`000?nbHg?o/V=cok9SL`;o00000ooYn/@01?l0003oaLCH
o`000?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Oooooo000Yooooo`?o00009_ooool00ol0003oY;cZojBljP03o`0000;oYKcY00?o0000ojFj
j?nU^^P01OnU^^P00ol0003oYKWWojFii`04ojFii`?o00001OnS[n000ol0003oXJWLoj6Yg004oj6Y
g003o`000?nSYmWoXjOI00GoXjOI00?o0000oinQe_nOXMH00ol00004oggKo0?o00001_nR[^04o`00
00?oXjgN00?o0000oj6ZgOnQZ]d01?nQZ]d5o`0000GoW<7b00?o0000oi[1lonJ`O<01?nJ`O<00ol0
003oV<7doiS1m002oiS1m0Go00001_nJ/^P00ol0003oVK7XoiVaj004oiVaj003o`000?nG/>SoUk3X
00GoUk3X00Co0000oiB^j?nD[^SoU:kX1ol00004ohbcl003o`000?n7/O7oQk7a00CoQk7a00?o0000
oh6^lOn1[_401?n1[_400ol0003oN:WbogRYlP04ogRYlP03o`000?m]Y?;oKJCb00CoKJCb00?o0000
oejKlOmNVo401?l00006ofB<i003o`000?mBOn3oDWoP00?oDWoP00Co0000oca_f_l0003o00000_l/
Ln401?l0003o25KAo`000?l00002ofIQ^003o`000?m7Bk;o000000;oAd^b00?o0000okb1U?nlPI@0
0_nlPI@00ol0003oooooooooo`0Cooooo`;o00000onbHg<00ol0003ojO[4onWja002o`0000?oaLCH
0_l0000Nooooo`00:Oooool00ol0003oooooooooo`0Wooooo`;o00001_nU_>T00ol0003oYK[XojFj
j005ojFjj003o`000?nU^NOoYKWW00?o000000?oX[;So`000?nS[n001_nS[n000ol0003oXJWLoj6Y
g004oj6Yg003o`000?nSYmWoXjOI00;oXjOI1_l00003oggKo0?o000000?oY;7Qo`000?nR[^001?nR
[^04o`0000KoXjgN00?o0000oj6ZgOnQZ]d00ol00002oig1l@03o`000?nL`O;oW<7b00KoW<7b00Co
0000oi[1lonJ`O?oV/7c1ol00004oibdj003o`000?nJ/^SoV[;X00GoV[;X00?o0000oiVaj?nI/NP0
1?nI/NP00ol0003oUk3XoiN`j002oiN`j0Ko00001?n@]Nl00ol0003oS;?`ohbcl005ohbcl003o`00
0?n7/O7oQk7a00CoQk7a00?o0000oh6^lOn1[_401?n1[_400ol0003oN:WbogRYlP04ogRYlP03o`00
0?m]Y?;oKJCb00CoKJCb00?o0000oejKlOmNVo400_mNVo44o`0000CoI8cT00?o0000oe9oh?mBOn00
0omBOn000ol0003o?6oJoca_fP02o`000004obachOl0003o25KAo`QFd@?o00000_m7Bk801?l0003o
Ad^bodM;/_l00004okb1U003o`000?oooooooooo01;ooooo0_l00003ok9SL`03o`000?oYn/Co0000
00KoaLCH00?o0000ooooooooool07?ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0:Oooool0
0ol0003oYKcYojFlj@04ojFlj@03o`000?nU^^SoYK[X00CoYK[X0ol00005oj:bh`03o`000?nS[n3o
XjoP00CoXjoP00?o0000oj6Yg?nQZM`01?nQZM`5o`0000KoQ=Oo0ol00005ojBah@03o`000?nR[^3o
000000;o00000onR[^000ol0003oXjgNoj>]gP04oj>]gP?o00001_nM`O400ol0003oW<7boic1lP04
oic1lPGo00001?nM]NP00ol0003oW;CXoibdj005oibdj003o`000?nJ/^SoV[;X00CoV[;X00?o0000
oiVaj?nI/NP00_nI/NP7o`0000?oU;K_00?o0000oi2ekon@]Nl01On@]Nl00ol0003oS;?`ohbcl005
ohbcl003o`000?n7/O7oQk7a00CoQk7a00?o0000oh6^lOn1[_401?n1[_400ol0003oN:WbogRYlP04
ogRYlP03o`000?m]Y?;oKJCb00CoKJCb00?o0000oejKlOmNVo400omNVo400ol0003oBHo]o`000004
o`0000GoDWoP00?o0000oca_f_llKmX00_llKmX2o`0000Co25KA0_l00002odM;/P03o`000?m7Bk;o
000000Co_86D00?o0000ooooooooool04Oooool3o`0000?o/V=c0_l00007olG4f0;o00007Oooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02[ooooo00?o0000ojFljOnU_>T01?nU_>T00ol0003oYK[XojFjj003
o`0000;oY;OW00?o0000oj:bhonR/^<01?nR/^<00ol0003oXjoPoj>_h004oj>_h003o`000?nQZMco
XJWL00?o00000on@e?h3o`0000;oQ=Oo0ol000000onS/^;o0000ojBah@04ojBah@?o00001onR[^00
0ol0003oXjgNoj>]gP03o`0000;oW/3`00?o0000oig1lOnM`O401OnM`O400ol0003oW<7boic1lP03
o`0000;oWkKX00?o0000oifej?nM]NP01OnM]NP00ol0003oW;CXoibdj005oibdj004o`000?nJ/^So
V[;XoiZbj0Oo00000onF]nh00ol0003oU;K_oiBfk`05oiBfk`03o`000?n@]NooT;G_00GoT;G_00?o
0000ohbcl?n</o000_n</o0Mo`000003offTl_l0003oGY_a00GoGY_a00?o0000odV?kOm9Snd00_m9
Snd3o`0000CoDWoP00?o0000oca_f_llKmX00ollKmX2o`0000?o25KA0_l000001Om7Bk;o0000odM;
/_m7Bk;o000000?o_86D00?o0000ooooooooool04?ooool00ol0003o?`0Ko`000004ok9SL`03o`00
0?o5a=SoaLCH00GoaLCH00Co0000om3Ui_l0003o00007?ooool000kooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0_l0000/ooooo`04o`000?nU_>WoYKcYojFl
j@Go00001_nT]nL00ol0003oX[;Soj:bh`04oj:bh`04o`000?nS[n3oXjoPoj>_h0Go00002?n@e?h3
o`0000GoXk;R00?o0000ojBahOl000000_l00003ojBah@03o`000?nR[^3oXZkP00;oXZkP1Ol00006
oik0l003o`000?nM`O7oWL7a00CoWL7a0ol00006oinfj003o`000?nM]NSoWKGX00GoWKGX00?o0000
oibdj?nL]>P00_nL]>P6o`0000CoVKS^00?o0000oiJgk_nF]nh01?nF]nh00ol0003oU;K_oiBfk`05
oiBfk`03o`000?n@]NooT;G_00;oT;G_1ol00003ohNkm`03o`000?n1^OSoPKWh00GoPKWh00?o0000
ogRfnOmh]_T01?mh]_T00ol0003oK;;jofbbnP04ofbbnP04o`000?mKZoWoFj_ioe^[n@Oo00000_mN
Vo400ol0003oBHo]odV?k@02odV?k@03o`000?l^O^Oo000000;o00000_mBOn000ol0003o?6oJoca_
fP02oca_fP03o`000?lNFM3o000000;o25KA00Oo0000o`0Y/_l0003oAd^bo`000?m7Bk;o000000?o
_86D00?o0000ooooooooool03oooool01?l0003o?`0Kocl06ol00004ok9SL`03o`000?o5a=SoaLCH
00CoaLCH00Go0000om3Ui_o@iNKod>GVo`00000Looooo`003_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0002kooooo0ol00004oj>lj`03o`000?nT]nOo
Y;OW00GoY;OW00Co0000oj:bhonR/^?oX[;S1_l00005oi?=o0?o00000_n@e?h3o`000003ojFdi?l0
003oXk;R00GoXk;R0_l00006ojBah@Go00001OnO`?000ol0003oW/3`oik0l004oik0l003o`000?nM
`O7oWL7a00?o00000_nO]nT00ol0003oWkKXoinfj005oinfj003o`000?nM]NSoWKGX00CoWKGX1Ol0
0003oiZik@03o`000?nI^>koVKS^00GoVKS^00?o0000oiJgk_nF]nh01?nF]nh00ol0003oU;K_oiBf
k`02oiBfk`Oo00001?n=_?H00ol0003oQk_gohNkm`04ohNkm`03o`000?n1^OSoPKWh00GoPKWh00?o
0000ogRfnOmh]_T01?mh]_T00ol0003oK;;jofbbnP04ofbbnP03o`000?mKZoWoFj_i00?oFj_i00Co
0000odBPm_m4X?KoA:3f1_l00002odV?k@04o`000?l^O^Oo;WkWobini`?o00001OllKmX00ol0003o
7UW@o`000002o`QFd@07o`000?l0:K;o0000odM;/_l0003oAd^bo`000002okb1U003o`000?oooooo
oooo00kooooo00?o0000ocl06olo01/00_l00004ok9SL`;o00001?o5a=P00ol0003od>GVom3UiP02
om3UiP;o00006oooool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0]ooooo`03o`000?nS_>_oXkc[00CoXkc[00?o
0000ojBgionT]nL01?nT]nL4o`0000GoVLOg00?o0000oi?=o?nCcO`01?nCcO`4o`0000GoYKCT00?o
0000oj>bh_nS/^800ol00002oj>bhP03o`000?nT/N7oY;7Q00?o00000_nP_nl00ol0003oWl3`oio0
l006oio0l004o`000?nN`?3oW/3`oik0l0Go00001_nO]nT00ol0003oWkKXoinfj005oinfj003o`00
0?nM]NSoWKGX00?o000000?oW;W]o`000?nJ^Nd01_nJ^Nd00ol0003oVKS^oiVhkP05oiVhkP04o`00
0?nF]nkoU[O^oiJgkPOo00001OnA_OD00ol0003oSKcfohflmP04ohflmP03o`000?n7^oOoQk_g00Co
Qk_g00?o0000oh6in?n1^OP00_n1^OPFo`000003oe^[nOl0003oA:3f00GoA:3f00?o0000obB>kOl0
00000ol00005obini`;o00000ollKmX00ol0003o7UW@oaiId003o`0000;o02Vb0_l000001Om7Bk;o
0000okb1U?nlPICo000000oooooo00Co0000ocl06olo01_o?`0K0_l00004ok9SL`03o`000?o<d]ko
000000;oaLCH00?o0000om3Ui_o@iNH00oo@iNH3o`0001[ooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02oooooo00?o0000
oj>ljonS_>/01?nS_>/00ol0003oY;OWojBgi`03o`0000?oV/3b00?o0000oiW7monIaoL01?nIaoL0
0ol0003oTlgloi?=o003o`0000?oY;KU00?o0000ojFdi?nU]>@00onU]>@3o`0000GoXk;R0ol00006
oj2ok`03o`000?nO`?3oWl3`00CoWl3`1Ol00004oj6gj@03o`000?nO]nWoWkOY00GoWkOY00?o0000
oinfj?nO]^P00_nO]^P5o`0000GoW;W]00?o0000oiZikOnJ^Nd01OnJ^Nd00ol0003oVKS^oiVhkP02
oiVhkPKo00001OnD__@00ol0003oTKgeoi6mm@05oi6mm@04o`000?n=_?KoSKcfohflmPko00000on=
ZNP00ol0003oR:OYohRWj@04ohRWj@03o`000?n1Y>_oPJC[00CoPJC[00?o0000ogNQk?mgXN`00_mg
XN`7o`0000;oA:3f00Co0000obB>kOlTS^go98k]0ol00003obini`04o`000?l=Im_o0000o`0000;o
?6oJ00Co0000oaiId?lNFM3o7UW@0_l00002o`0Y/P;o000000CoAd^bo`000?nlPICo00003Oooool2
o`0000Co?`0K0_l00005ok9SL`;o000000?oaLCHo`000?o@iNH00oo@iNH2o`000003okS0h?l0003o
000001[ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`;o0000<Oooool01?l0003oXkc[oj>ljonS_>/5o`0000OoV/3b00Co0000oiW7monIaoOoVLOg
1Ol00007ojBfi@03o`000?nU]>Co000000;o00000_nU]>@00ol0003oXk;Roj>bhP03o`0000;oXKo^
00?o0000oj2okonP_nl01OnP_nl00ol0003oWl3`oio0l003o`0000;oXKSY00?o0000oj6gjOnQ]nT0
1OnQ]nT00ol0003oWkOYoingj@04oingj@Go00000onM^^`00ol0003oW;W]oibik@05oibik@03o`00
0?nJ^NgoV[W]00CoV[W]1Ol00003oiNnl`03o`000?nD__CoU;kd00KoU;kd00?o0000oi6mmOnA_OD0
0_nA_OD6o`0000?oU:gW00?o0000oi6[ionAZnL01?nAZnL00ol0003oSJWXohfYj005ohfYj003o`00
0?n8YnWoR:OY00CoR:OY00?o0000oh6Tjon1Y>/01?n1Y>/00ol0003oMj7/ogNQk004ogNQk004o`00
0?mXVnkoJ9_^ofRKkPKo00000_lTS^d4o`000004obiniol0003o3FOKo`eWf`;o000000?o?6oJo`00
0?lNFM000_lNFM001?l0003o02Vbo`0Y/_l0:K85o`0000_ooooo0_l000000om400co0000ocl06`03
ocl06`03o`000?nbHg?o/V=c00Co/V=c0ol00004om3UiP03o`000?nh`>3o^<3P00;o^<3P0_l0000I
ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooo
oooo037ooooo0ol00005oibjk@03o`000?nJ`?;oV/3b00CoV/3b1?l00004ojFhi`03o`000?nT]^Go
Y;KU00CoY;KU0ol00003ojFdi0Go00001_nQ_nh00ol0003oX;o_oj2ok`04oj2ok`?o00001_nQ^>T0
0ol0003oXKOYoj6gj@05oj6gj@03o`000?nO]nWoWkOY00?o00000_nN^^`00ol0003oWK[/oifjk004
oifjk003o`000?nL^NgoW;W]00GoW;W]00?o0000oiZikOnJ^Nd00ol00002oiVnlP03o`000?nG__?o
Ukkc00CoUkkc00?o0000oiBnm?nD__@01?nD__@6o`0000?oUjkW00?o0000oiB]ionD[NL01?nD[NL0
0ol0003oTJ_Woi6[i`04oi6[i`03o`000?n=ZNSoSJWX00GoSJWX00?o0000ohRWjOn8YnT01?n8YnT0
0ol0003oPJC[oh6Tj`04oh6Tj`03o`000?mgXNcoMj7/00CoMj7/00?o0000ofRKk_mXVnh00omXVnh0
0ol0003oDi?^oe>CkP04o`0000;o07?J0ol00003o`eWf`;o00001?lNFM02o`0000;o02Vb0ol00000
0onlPICo0000ooooo`08ooooo`04o`000?m400coA00<o`0000Co?`0K0_l00006ok9SL`05o`000?o3
jo7o`n_ao`000?o@iNH00_l00006okS0h0;o00006?ooool002Sooooo00?o0000ooooooooool0<_oo
ool00ol0003oW;[]oibjk@05oibjk@03o`000?nJ`?;oV/3b00?o000000?oYK[Xo`000?nU^>L01_nU
^>L00ol0003oY;KUojBfi@03o`000003ojBfiOl0003o000000?o00001OnQ_^d00ol0003oXKo^oj6o
kP04oj6okP03o`000?nP_nooX;o_00?o00000_nR^NT00ol0003oXKSYoj6hj@05oj6hj@03o`000?nQ
]nWoXKOY00?oXKOY1?l00006oijjk003o`000?nM^^coWK[/00CoWK[/00?o0000oibikOnL^Nd00_nL
^Nd5o`0000KoVKkb00?o0000oiNnlonG__<01?nG__<00ol0003oU;kdoiBnm003o`0000;oVJoV00?o
0000oiN^ionG[^L01OnG[^L00ol0003oU:gWoiB]i`04oiB]i`03o`000?nAZnOoTJ_W00CoTJ_W00?o
0000ohfYj?n=ZNP01On=ZNP00ol0003oR:OYohRWj@04ohRWj@03o`000?n1Y>_oPJC[00CoPJC[00?o
0000ogNQk?mgXN`01?mgXN`00ol0003oJ9_^ofRKkP03ofRKkP03o`000?mCTnkoDi?^00;oDi?^1?l0
0002o`1cfP;o00000ol=Im/2o`0000;o7UW@00?o0000o`11`ol000000_l0:K84o`0000Oooooo0_l0
0003od@03003o`000?lo01_o?`0K00;o000000?oUDIYo`000?nbHg<01OnbHg<00ol0003o`n_aol?[
l@02o`0000So^<3P0_l0000Hooooo`00:?ooool00ol0003oooooooooo`0cooooo`03o`000?nL^^go
W;[]00CoW;[]0ol00005ojFjj003o`000?nU^>OoYKSW00CoYKSW0ol000001?nT]^Go0000o`000?l0
0003oj:nk@03o`000?nQ_^goXKk]00GoXKk]00Co0000oj6ok_nQ_nkoXKo^1Ol00006oj:ij@03o`00
0?nQ^>WoXKSY00CoXKSY00?o0000oj6gjOnQ]nT00ol00002oinkk003o`000?nN^^coW[[/00KoW[[/
00Co0000oifjk?nM^^coWK[/1ol00004oi^nl@03o`000?nI__;oVKkb00GoVKkb00Co0000oiNnlonG
__?oUkkc1Ol00006oiV_iP03o`000?nG[^OoUjkW00GoUjkW00?o0000oiB]ionD[NL01?nD[NL00ol0
003oTJ_Woi6[i`04oi6[i`03o`000?n=ZNSoSJWX00;oSJWX7Ol000000omXVnko0000oe>CkP04oe>C
kP03o`000?laP^Wo000000Go000000Co3FOKo`000?l0C<[o00000_lNFM000ol0003o0473o`000002
o`0Y/PCo00000oooool3o`0000GoA00<00?o0000ocl06ol000000onEAVT00ol0003o/V=cok9SL`04
ok9SL`?o000000?o_LWTo`000?nh`>001Onh`>02o`000003okgCjol0003o000001Oooooo000Woooo
o`;o0000=_ooool00ol0003oW;[]oibjk@03o`0000;oYKcZ00?o0000ojFjj?nU^^P01?nU^^P01?l0
003oYKSWojFhionU^>L2o`000004ojFhiol0003o0000o`0000OoX[k]00?o0000oj6nkOnQ_^d01?nQ
_^d4o`0000CoX[WY00?o0000oj:ijOnR^NT01OnR^NT01?l0003oXKSYoj6hjOnQ^>T5o`0000KoWk_/
00?o0000oijjk?nN^^`01?nN^^`5o`0000CoW;k`00?o0000oi^nlOnK__401OnK__400ol0003oVKkb
oiVnlP02oiVnlPKo00001?nK/>H00ol0003oVJoVoiV_iP05oiV_iP03o`000?nG[^OoUjkW00CoUjkW
00?o0000oiB]ionD[NL00_nD[NLHo`0000?oU7bf00?o0000oi9j]OnBN[D01?nBN[D00ol0003oT7Rd
oi1h]004oi1h]003o`000?n>M[Co000000Co00000omCTnh00ol0003o<H;Yoc62j@02oc62j@Go0000
00Ko04c:o`000?l0003o7UW@o`000?l0@L<9o`0000;oD`0000?o0000od@03?m400`00_m400`3o`00
00CoUDIY00?o0000ok9SLonbHg<01?nbHg<00ol0003o_LWTokg9i002okg9i003o`000?nh`>3o^<3P
00;o^<3P00?o0000okgCjonmdn/00_nmdn/00ol0003oooooooooo`0Eooooo`009oooool00ol0003o
ooooooooo`0fooooo`;o00001_nU_>X00ol0003oYK[XojFjj004ojFjj0Ko00000_nR_N`00ol0003o
X[k]oj:nk@06oj:nk@03o`000?nQ_^goXKk]00?o00000_nS^^T00ol0003oX[WYoj:ij@04oj:ij@03
o`000?nR^NWoX[WY00CoX[WY1?l00005oj2kk003o`000?nO^ncoWk_/00CoWk_/00?o0000oijjk?nN
^^`00ol00002oijnk`03o`000?nL__3oW;k`00GoW;k`00?o0000oi^nlOnK__401?nK__45o`0000?o
WK7V00?o0000oi^`i_nK/>H01OnK/>H00ol0003oVJoVoiV_iP04oiV_iP03o`000?nG[^OoUjkW00;o
UjkW1ol00003ofK>nPOo00000onFOkP00ol0003oUGfgoiEm]`04oiEm]`03o`000?nDO;KoU7bf00Co
U7bf00?o0000oi9j]OnBN[D01?nBN[D00ol0003oT7Rdoi1h]004oi1h]003o`000?n>M[CoSWJd00Co
SWJd1Ol00004oc62j@03o`000?l0Im[o000000;o00000_l0C<X2o`0000?o04730ol000000oo7D`3o
0000oe<00002oe<00003o`000?m400coA00<00;oA00<0_l00006oiE6J@03o`000?nbHg?o/V=c00Co
/V=c00?o0000okg9i?nmbN@00onmbN@01?l0003o^<3Po`000?l00005okgCj`;o00005_ooool002Oo
oooo00?o0000ooooooooool0=oooool00ol0003oYKcZojFljP05ojFljP03o`000?nU^^SoYK[X00Ko
00001_nR_N`00ol0003oX[k]oj:nk@04oj:nk@Co00001_nS^^T00ol0003oX[WYoj:ij@04oj:ij@03
o`000?nR^NWoX[WY00?o00000_nQ^n/00ol0003oX;_/oj2kk005oj2kk004o`000?nO^ncoWk_/oink
k0Go00001_nN_^l00ol0003oW;k`oibnl005oibnl003o`000?nK__7oVkka00?o000000?oW[;Vo`00
0?nM/NH01_nM/NH00ol0003oVk3Voi^`iP05oi^`iP04o`000?nI[nKoVJoVoiV_iPOo00001Ombd_d5
o`0000?oV86i00?o0000oiIo^?nFOkP01?nFOkP00ol0003oUGfgoiEm]`04oiEm]`03o`000?nDO;Ko
U7bf00GoU7bf00?o0000oi9j]OnBN[D01?nBN[D00ol0003oT7Rdoi1h]004oi1h]003o`000?n>M[Co
SWJd00CoSWJd00?o0000oh]e]?n;MK@01?l00002oc62j@03o`000?l0Im[o06OJ00?o00000_l0C<X0
1?l0003o0473o`11`ol0@L<4o`0000?oD`0000?o0000od@03?l000000_l000000onD?5Wo0000oiE6
J@05oiE6J@03o`000?nbHg?o/V=c00Co/V=c00?o0000okg9i?nmbN@00onmbN@2o`0000Oo_M?[0ol0
000Eooooo`009oooool2o`0003Wooooo00?o0000ojFlj_nU_>X01?nU_>X4o`0000GoX[c[00?o0000
oj:mk?nR_N`01?nR_N`00ol0003oX[k]oj:nk@03o`0000?oXk[Y00?o0000oj>jjOnS^^T01OnS^^T0
1?l0003oX[WYoj:ijOnR^NT5o`0000KoXK_[00?o0000oj2kk?nP^n`01?nP^n`4o`0000CoWkk_00?o
0000oijnkonN_^l01OnN_^l00ol0003oW;k`oibnl002oibnl0Go00001OnN/^H00ol0003oWK7Voifa
iP05oifaiP03o`000?nK/>KoVk3V00;oVk3V1_l00005ogcCo`;o00000_mbd_d3o`0000;oVH>k00?o
0000oiR1^OnHPKT01?nHPKT00ol0003oUWnhoiIo^004oiIo^003o`000?nEOKOoUGfg00CoUGfg00?o
0000oiAl]_nDO;H01?nDO;H00ol0003oTWZeoi9j]@04oi9j]@03o`000?n@N;CoT7Rd00CoT7Rd00?o
0000ohif]?n>M[@01?n>M[@00ol0003oRgFdoh]e]004oh]e]0Co00000ol0ImX2o`0000;o04c:0_l0
0002o`11``Co00000_mC0002o`0000CoU3aI00?o0000oiE6JOnEAVT01?nEAVT00ol0003o/V=cok9S
L`04ok9SL`03o`000?nmbNCo_LWT00?o00000_nfe_400ol0003o_M?[okgCj`02okgCj`;o000000Co
/<7Vo`000?l0003o00002?ooool4o`000003oa0@4?oooooooooo00Gooooo000Wooooo`03o`000?oo
oooooooo03Wooooo00?o0000ojFlj_nU_>X00ol00002oj:kj`03o`000?nR_>_oX[c[00GoX[c[00Co
0000oj:mk?nR_NcoX[g/1Ol00007oj>jj@03o`000?nS^^WoXk[Y00CoXk[Y1?l00004oj:kj`03o`00
0?nQ^n_oXK_[00GoXK_[00?o0000oj2kk?nP^n`00ol00002oj2nkP03o`000?nO_^ooWkk_00CoWkk_
00?o0000oijnkonN_^l01?nN_^l5o`0000?oWk?V00?o0000oijbi_nN/^H01OnN/^H00ol0003oWK7V
oifaiP04oifaiPGo00001On4e?l00ol0003oO=?oogcCo`02ogcCo`Go00001OnIPk/00ol0003oV86i
oiR1^@04oiR1^@03o`000?nFOkSoUWnh00CoUWnh00?o0000oiEm]onEOKL01?nEOKL00ol0003oU7bf
oiAl]P04oiAl]P03o`000?nBN[GoTWZe00CoTWZe00?o0000oi1h]?n@N;@01?n@N;@00ol0003oSWJd
ohif]004ohif]003o`000?n;MKCoRgFd00CoRgFd00?o0000ohIb]_n6L[H00ol00003o`1WfP05o`00
0?l0C<[o0000o`0c^?l000000_l0@L<5o`0000KoU3aI00?o0000oiE6JOnEAVT01?nEAVT00ol0003o
/V=cok9SL`04ok9SL`?o00001_nfe_401?l0003o_M?[o`000?l00004ok31iP;o00002_ooool00ol0
003oooooooooo`07ooooo`009oooool00ol0003oooooooooo`0iooooo`?o00001_nR^n/00ol0003o
X[c[oj:lj`04oj:lj`Co00001?nS^nX00ol0003oXk[Yoj>jj@06oj>jj@03o`000?nS^^WoXk[Y00?o
00000_nR^n/00ol0003oX[_[oj:kj`04oj:kj`03o`000?nQ^n_oXK_[00CoXK_[0ol00006oj2nkP03
o`000?nO_^ooWkk_00CoWkk_00?o0000oijnkonN_^l00ol00002oj2di`03o`000?nO/nKoWk?V00Co
Wk?V00?o0000oijbi_nN/^H01OnN/^H00ol0003oWK7VoifaiP03o`0000?oR];o0_l00003ohCDo`Oo
00000onJQK`00ol0003oVH>koiV3^`05oiV3^`03o`000?nHPKWoV86i00?oV86i00?o0000oiIo^?nF
OkP01?nFOkP00ol0003oUGfgoiEm]`04oiEm]`03o`000?nDO;KoU7bf00CoU7bf00?o0000oi9j]OnB
N[D01?nBN[D00ol0003oT7Rdoi1h]005oi1h]003o`000?n>M[CoSWJd00CoSWJd00?o0000oh]e]?n;
MK@00on;MK@00ol0003oQW:fohIb]P03ohIb]P;o000000?o06OJo`000?l000000_l000000ol0<kSo
0000o`11``05o`0000KoU3aI00?o0000oiE6JOnEAVT01?nEAVT00ol0003o/V=cok9SL`04ok9SL`03
o`000?nfe_7o]]Ka00Ko]]Ka0_l00007ok31iP;o00002Oooool00ol0003oooooooooo`07ooooo`00
9oooool2o`0003Oooooo0ol00002ooooo`03o`000?nR^n_oX[_[00GoX[_[00?o0000oj:ljonR_>/0
0ol00002oj>kjP03o`000?nS^n[oXk_Z00CoXk_Z00?o0000oj>jjOnS^^T01?nS^^T4o`0000KoX[_[
00?o0000oj:kjonR^n/01?nR^n/00ol0003oXK_[oj6kj`03o`0000;oXKk]00?o0000oj2nk_nP_^h0
1OnP_^h01?l0003oWkk_oinnkonO_^l5o`0000KoX;CW00?o0000oinci_nO/nH01?nO/nH00ol0003o
W[;VoijbiP02oijbiPGo00001_n:d_l5o`0000?oVhRn00?o0000oiZ5_?nJQK`01?nJQK`00ol0003o
VH>koiV3^`05oiV3^`03o`000?nHPKWoV86i00CoV86i00?o0000oiIo^?nFOkP01?nFOkP00ol0003o
UGfgoiEm]`03oiEm]`03o`000?nDO;KoU7bf00GoU7bf00?o0000oi9j]OnBN[D01?nBN[D00ol0003o
T7Rdoi1h]004oi1h]003o`000?n>M[CoSWJd00CoSWJd00?o0000oh]e]?n;MK@01?n;MK@00ol0003o
QW:fohIb]P04ohIb]P?o000000Co03nko`000?l0003o03>h1_l00006oi@lF@03o`000?nEAVWoUDIY
00CoUDIY00?o0000ok9SLonbHg<01?nbHg<2o`0000Co]]Ka0ol000000onbanWo0000ok31iP06ok31
iP;o00002Oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0eooooo`;o
00001_ooool00ol0003oX[_[oj:kj`04oj:kj`?o00001_nS^nX00ol0003oXk_Zoj>kjP04oj>kjP03
o`000?nS^^WoXk[Y00?o00000_nR^n/00ol0003oX[_[oj:kj`06oj:kj`04o`000?nR^n_oX[_[oj:k
j`Go00001_nQ_^d00ol0003oX;k^oj2nkP04oj2nkPCo00001?nQ]NL00ol0003oX;CWoj2di`05oj2d
i`04o`000?nO/nKoWk?VoinciPOo00001On?d_h00ol0003oR];ooh[Bo`03o`0000;oW8[000?o0000
oi^8__nKR;h01?nKR;h00ol0003oVXFloiZ5_004oiZ5_003o`000?nIPk_oVH>k00CoVH>k00?o0000
oiR1^OnHPKT01?nHPKT00ol0003oUWnhoiIo^004oiIo^003o`000?nEOKOoUGfg00CoUGfg00?o0000
oiAl]_nDO;H01?nDO;H00ol0003oTWZeoi9j]@04oi9j]@03o`000?n@N;CoT7Rd00CoT7Rd00?o0000
ohif]?n>M[@01?n>M[@00ol0003oRgFdoh]e]004oh]e]003o`000?n6L[KoQW:f00GoQW:f0ol00000
0ol0?k_o0000o`0c^002o`0c^0Go00001OnD?5T00ol0003oUDIYoiE6J@04oiE6J@03o`000?nbHg?o
/V=c00Co/V=c00Co0000ok?Km?l0003o]]Ka0_l00005ok;7j@04o`000?n``NKo/<7Vok31iP?o0000
00?o[lK[o`000?l000002?ooool00ol0003oooooooooo`07ooooo`000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo03;ooooo0ol00009ooooo`03o`000?nR^n_oX[_[00?o
00000_nS_>/00ol0003oXk_Zoj>kjP05oj>kjP04o`000?nS^n[oXk_Zoj>kjPGo00001_nR^n/00ol0
003oX[_[oj:kj`04oj:kj`Go00001?nQ_Nd00ol0003oXKk]oj6nk@05oj6nk@03o`000?nP_^koX;k^
00?o00000_nQ]^L00ol0003oXKGWoj6ei`04oj6ei`03o`000?nP]>OoX;CW00CoX;CW1?l00005oi?@
o0;o00000on?d_h5o`0000GoW8[000?o0000oi^8__nKR;h01?nKR;h00ol0003oVXFloiZ5_004oiZ5
_003o`000?nIPk_oVH>k00CoVH>k00?o0000oiR1^OnHPKT01?nHPKT00ol0003oUWnhoiIo^004oiIo
^003o`000?nEOKOoUGfg00CoUGfg00?o0000oiAl]_nDO;H01?nDO;H00ol0003oTWZeoi9j]@04oi9j
]@03o`000?n@N;CoT7Rd00GoT7Rd00?o0000ohif]?n>M[@00on>M[@00ol0003oRgFdoh]e]004oh]e
]003o`000?n6L[KoQW:f00GoQW:f00?o0000oh1`]on0L;L01?l00002o`0c^0Ko00000onD?5T00ol0
003oUDIYoiE6J@04oiE6J@03o`000?nbHg?o/V=c00Go/V=c0ol00007ok;7j@04o`000?n``NKo0000
o`0000Go[lK[0_l00007ooooo`03o`000?oooooooooo00Oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo02oooooo0ol0000=ooooo`;o00001_nS_>/00ol0003oXk_Zoj>kjP04
oj>kjPCo00001?nS^n/00ol0003oX[_[oj:kj`05oj:kj`03o`000?nR^n_oX[_[00?o00000_nR_N`0
0ol0003oXKg]oj6mk@05oj6mk@03o`000?nQ_^goXKk]00;oXKk]1Ol00006oj6fi`03o`000?nQ]NOo
XKGW00CoXKGW00?o0000oj2dionP]>L00ol00003oiO?n`03o`000?nCd?coTm3l00CoTm3l1?l00003
oif=`P03o`000?nLR/3oW8[000GoW8[000?o0000oi^8__nKR;h00onKR;h00ol0003oVXFloiZ5_004
oiZ5_003o`000?nIPk_oVH>k00GoVH>k00?o0000oiR1^OnHPKT01?nHPKT00ol0003oUWnhoiIo^004
oiIo^003o`000?nEOKOoUGfg00?oUGfg00?o0000oiAl]_nDO;H01?nDO;H00ol0003oTWZeoi9j]@04
oi9j]@03o`000?n@N;CoT7Rd00GoT7Rd00?o0000ohif]?n>M[@01?n>M[@00ol0003oRgFdoh]e]004
oh]e]003o`000?n6L[KoQW:f00CoQW:f00?o0000oh1`]on0L;L00_n0L;L00ol0003o03nko`000002
o`0c^0;o000000Co00bGo`000?ngAcCo00000_nD?5T00ol0003oUDIYoiE6J@04oiE6J@03o`000?nb
Hg?o/V=c00Go/V=c00?o0000ok3;kOl000001_nbanT3o`0000Oo[lK[0_l00007ooooo`03o`000?oo
oooooooo00Oooooo0003ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEoooo
o`08ooooo`03o`000?oooooooooo00?ooooo0_l0000]ooooo`?o00004Oooool00ol0003oXkc[oj>l
j`05oj>lj`03o`000?nS^n[oXk_Z00?o00000_nS_>/00ol0003oXk_[oj>kj`04oj>kj`03o`000?nR
^n_oX[_[00CoX[_[0ol00006oj:mk003o`000?nQ_NgoXKg]00CoXKg]1Ol00003oj:gj003o`000?nQ
]^OoXKKW00KoXKKW00Co0000oj6eionQ]NOoXKGW1Ol00007oiO?n`03o`000?nCd?coTm3l00?o0000
00?oWXo4o`000?nMSL801OnMSL800ol0003oW8[0oib:`004oib:`003o`000?nKR;koVhRn00CoVhRn
00?o0000oiZ5_?nJQK`01?nJQK`00ol0003oVH>koiV3^`04oiV3^`03o`000?nHPKWoV86i00CoV86i
00?o0000oiIo^?nFOkP01?nFOkP00ol0003oUGfgoiEm]`03oiEm]`03o`000?nDO;KoU7bf00CoU7bf
00?o0000oi9j]OnBN[D01?nBN[D00ol0003oT7Rdoi1h]005oi1h]003o`000?n>M[CoSWJd00CoSWJd
00?o0000oh]e]?n;MK@01?n;MK@00ol0003oQW:fohIb]P05ohIb]P03o`000?n0L;OoP72g00;oP72g
0ol00002o`0c^0?o00000_ngAc@2o`0000OoUDIY00?o0000ok9SLonbHg<01OnbHg<01?l0003o/<_]
ok3;kOl00002ok;7j@?o00000on]b^l00ol0003o[lK[ojo6j`04ojo6j`;o00001Oooool00omEEEGo
IVIVo`000009ooooo`000oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Wooooo0ol0000Eooooo`03
o`000?nS_>_oXkc[00CoXkc[0ol00006oj>lj`03o`000?nS^n_oXk_[00CoXk_[00?o0000oj:kjonR
^n/00ol00002oj:mk003o`000?nR_NcoX[g/00GoX[g/00?o0000oj6mkOnQ_Nd00ol00002oj:hj003
o`000?nR]nSoX[OX00CoX[OX00?o0000oj6fionQ]^L01?nQ]^L5o`0000GoVLci00?o0000oiO?nonG
co/00_nGco/5o`0000GoWXo400?o0000oif=`_nMSL800onMSL800ol0003oW8[0oib:`004oib:`003
o`000?nKR;koVhRn00CoVhRn00?o0000oiZ5_?nJQK`01?nJQK`00ol0003oVH>koiV3^`04oiV3^`03
o`000?nHPKWoV86i00CoV86i00?o0000oiIo^?nFOkP01?nFOkP00ol0003oUGfgoiEm]`04oiEm]`03
o`000?nDO;KoU7bf00CoU7bf00?o0000oi9j]OnBN[D01?nBN[D00ol0003oT7Rdoi1h]005oi1h]003
o`000?n>M[CoSWJd00?oSWJd00?o0000oh]e]?n;MK@01?n;MK@00ol0003oQW:fohIb]P05ohIb]P03
o`000?n0L;OoP72g00CoP72g1?l000000ol0:Joo0000o`000002okM7=003o`000?nEAVWoUDIY00Go
UDIY00?o0000ok9SLonbHg<01OnbHg<00ol0003o/<_]ok3;k@03o`0000Oo[L[_00?o0000ojo6jon_
a^/00ol000000ooooooo0000ooooo`0@ooooo`000oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool09_ooool3o`0001Wooooo00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[
00GoXkc[00Co0000oj>kjonS^n_oXk_[1Ol00006oj:mk003o`000?nR_NcoX[g/00CoX[g/0ol00006
oj:hj003o`000?nR]nSoX[OX00CoX[OX00?o0000oj6fionQ]^L00ol00003oic;n003o`000?nIc?Wo
VLci00CoVLci1Ol00003oinBa`03o`000?nNSlCoWXo400CoWXo400?o0000oif=`_nMSL801?nMSL80
0ol0003oW8[0oib:`004oib:`003o`000?nKR;koVhRn00CoVhRn00?o0000oiZ5_?nJQK`00onJQK`0
0ol0003oVH>koiV3^`04oiV3^`03o`000?nHPKWoV86i00GoV86i00?o0000oiIo^?nFOkP01?nFOkP0
0ol0003oUGfgoiEm]`0No`0000;oSWJd00?o0000oh]e]?n;MK@01?n;MK@00ol0003oQW:fohIb]P04
ohIb]P03o`000?n0L;OoP72g00CoP72g00?o0000ofYV^ol000001Ol00002okM7=003o`000?nEAVWo
UDIY00CoUDIY00?o0000ok9SLonbHg<01OnbHg<3o`0000;o[<kb00?o0000ojg:kon]b^l01?n]b^l4
o`0000Cooooo00?o0000ooooooooool03oooool000?ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0T
ooooo`?o00007Oooool2o`0000KoXkc[00?o0000oj>ljonS_>/01?nS_>/4o`0000GoX[c/00?o0000
oj:mk?nR_N`01?nR_N`00ol0003oX[g/oj:mk003o`0000;oXkWX00?o0000oj:hj?nR^>P01OnR^>P0
1?l0003oX[OXoj:gj?nR]nP5o`0000OoW<_h00?o0000oiW<nOnIc?T00ol000000onPU/Wo0000oinB
a`06oinBa`03o`000?nNSlCoWXo400CoWXo400?o0000oif=`_nMSL800onMSL800ol0003oW8[0oib:
`004oib:`003o`000?nKR;koVhRn00CoVhRn00?o0000oiZ5_?nJQK`00onJQK`00ol0003oVH>koiV3
^`05oiV3^`04o`000?nHPKWoV86ioiR1^@go00001OnL/^L01?l0003oVk?Xoi^cj?nK/nP7o`0000Co
NmOm1_l00004oio2l@ko00000on6L[H00ol0003oP72goh1`]`03oh1`]`03o`000?mZI[_oJVJk00Go
00000ongAc@00ol0003oUDIYoiE6J@03oiE6J@03o`000?nbHg?o/V=c00Go/V=c00?o0000ojc>l_n/
c_800on/c_800ol0003o[L[_ojg:k`03o`0000Wooooo00?o0000ooooooooool03_ooool000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0
003oooooooooo`06ooooo`;o00008oooool2o`0002;ooooo00?o0000oj>ljonS_>/01?nS_>/00ol0
003oXkc[oj>lj`03o`0000;oXkc[00?o0000oj:lk?nR_>`01OnR_>`01?l0003oX[g/oj:mk?nR_N`5
o`0000KoXkWX00?o0000oj:hj?nR^>P01?nR^>P4o`0000GoWLSf0_l00003oic;n0Go00001OnPU/T0
0ol0003oWi;7oinBa`04oinBa`03o`000?nNSlCoWXo400CoWXo400?o0000oif=`_nMSL800onMSL80
0ol0003oW8[0oib:`004oib:`003o`000?nKR;koVhRn00CoVhRn00?o0000oiZ5_?nJQK`01?nJQK`0
1?l0003oVH>koiV3^onIPk/7o`0000?oW[;V00?o0000oifbi_nM/^H01OnM/^H00ol0003oW;;Woibb
i`03oibbi`Go00001On2eol00ol0003oNmOmog_Go@03o`0000?oWl3`00?o0000oio2lOnO`_401OnO
`_400ol0003oX<Gboj35lP03o`0000;oTMgn1?l000000onWc??o0000o`000006o`0000;oP72g00?o
0000ofYV^omZI[/00_l000000ol0:Joo0000o`000003okM7=003o`000?nEAVWoUDIY00;oUDIY00?o
0000ok9SLonbHg<01OnbHg<00ol0003o[<kbojc>lP02ojc>lPCo00003?ooool00ol0003ooooooooo
o`0>ooooo`000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001Ooo
ool00ol0003oooooooooo`0Oooooo`?o00009Oooool01?l0003oXkc[oj>ljonS_>/5o`0000KoXkc[
00?o0000oj:lk?nR_>`01?nR_>`4o`0000GoXkWY00?o0000oj>ij?nS^NP01?nS^NP00ol0003oX[SX
oj:hj003o`0000?oWlKd00?o0000oig8m_nMb?H01?nMb?H4o`0000?oXIW=00?o0000oj2FbOnPU/T0
1?nPU/T00ol0003oWi;7oinBa`04oinBa`03o`000?nNSlCoWXo400CoWXo400?o0000oif=`_nMSL80
1?nMSL800ol0003oW8[0oib:`004oib:`004o`000?nKR;koVhRnoi^8_Pko00000_nP/nH00ol0003o
W[;VoijbiP05oijbiP03o`000?nM/^KoWK;V00CoWK;V00?o0000oibbionL/^L00ol00004ohSFo`04
o`000?n2eoooP]Oooh;Go`Go00001onO`?000ol0003oWl;aoio2l@02oio2l@Go00000_nAgOh3o`00
00?oYL_d00?o0000ojO<lonWc?<01?nWc?<7o`0000;oJVJk1Ol00003okM7=005o`000?nEAVWoUDIY
oiE6JOl000001onbHg<00ol0003o[<kbo`000002o`00013ooooo00?o0000ooooooooool03_ooool0
02Gooooo00?o0000ooooooooool07?ooool3o`0002Wooooo0ol00005oj>lj`03o`000?nS_>_oXkc[
00CoXkc[00?o0000oj:lk?nR_>`00ol00002oj>jj@03o`000?nS^NWoXkWY00GoXkWY00Co0000oj>i
j?nS^NSoXkWX1Ol00007oio6m003o`000?nMb?KoWLSf00?o000000?oXYg?o`000?nQVLd01OnQVLd0
0ol0003oX9K9oj2Fb@04oj2Fb@03o`000?nOT/OoWi;700CoWi;700?o0000oij?a?nNSl@01?nNSl@0
0ol0003oWHg2oif=`P03oif=`P04o`000?nLR/3oW8[0oib:`0Oo00000_n=d?h01?l0003oSMKoohgF
oon=e_l5o`0000KoX;?V00?o0000oijbi_nN/^H01OnN/^H01?l0003oWK;Voifbi_nM/^H6o`0000Co
R=Ko1_l00004oinok`03o`000?nO`?3oWl3`00CoWl3`1_l00004oi;KoP?o00001onUbo@00ol0003o
YlccojO<l`03o`0000?oX][k00?o0000ojGLnonUg?/01Ol000001?l06i[o0000o`0Y[ol00003okM7
=004o`000?nEAVWoUDIYo`0000Oo/V=c0_l0000Cooooo`03o`000?oooooooooo00kooooo000Uoooo
o`03o`000?oooooooooo01Wooooo0ol0000]ooooo`03o`000?nS_>_oXkc[00GoXkc[00Co0000oj>l
jonS_>_oXkc[1Ol00006oj>jj@03o`000?nS^NWoXkWY00CoXkWY1?l00005oj34lP03o`000?nOa_Co
WlKd00CoWlKd0ol00005oj:Mc`03o`000?nQVLgoXIW=00?oXIW=00?o0000oj2FbOnPU/T01?nPU/T0
0ol0003oWi;7oinBa`04oinBa`03o`000?nNSlCoWXo400CoWXo400Co0000oif=`_nMSL;oWHg21_l0
0002oiOCo@;o00000on=d?h6o`0000CoX;?U00?o0000oj2ci_nP/nH01OnP/nH00ol0003oW[;Voijb
iP02oijbiPKo00001On=e?l5o`0000CoWkg^00?o0000oinokonO_nl01?nO_nl00ol0003oWl3`oio0
l003o`0000CoTmSn00?o0000oi;Ko_nBfoh00ol00002oj?9l`03o`000?nUboCoYL_d00CoYL_d1?l0
0006oj;Jn`?o00001?nYd?@2o`000004o`0KV_l0003o02V_o`0000;o]dLd00Co0000oiE6JOnEAVWo
00001onbHg<00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo000Tooooo`?o0000
5oooool3o`00037ooooo00?o0000oj>ljonS_>/01?nS_>/4o`0000CoXk_Z00?o0000oj>jjOnS^^T0
1OnS^^T00ol0003oXkWYoj>ij@03o`0000;oXL;`00?o0000oj34l_nPa?801OnPa?800ol0003oWlKd
oio6m003o`000003oj>Qdol0003oXYg?00GoXYg?00?o0000oj6IcOnQVLd01?nQVLd00ol0003oX9K9
oj2Fb@04oj2Fb@03o`000?nOT/OoWi;700?oWi;700?o0000oij?a?nNSl@00_nNSl@8o`0000KoUm?m
1Ol00003oj:di@03o`000?nP/nGoX;?U00GoX;?U00?o0000oj2ci_nP/nH01?nP/nH5o`0000GoTM?n
00?o0000ohgDoon=e?l00ol000000onP_Ngo0000oinmkP07oinmkP04o`000?nO_nooWko_oinok`Go
00001_nCf?h4o`0000KoXlWc00?o0000ojG;m?nUbo@00ol00004oioHn`03o`000?nRf__oX][k00?o
00000_nWcoD00ol0003oZM3dojW@m004ojW@m0?o000000Oo02V_o`000?l0003o_4`eo`000?nEAVWo
000000Oo/V=c00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`009Oooool00ol0
003oooooooooo`0Cooooo`?o0000=Oooool00ol0003oXkc[oj>lj`03o`0000;oXkc[00?o0000oj>k
j_nS^nX01?nS^nX00ol0003oXk[Yoj>jj@04oj>jj@?o00001_nQ`_000ol0003oX<Cboj34lP04oj34
lP?o00001OnSXM<00ol0003oXYg?oj:Mc`04oj:Mc`03o`000?nQVLgoXIW=00CoXIW=00?o0000oj2F
bOnPU/T00onPU/T01?l0003oWi;7oinBaonOT/L:o`0000GoU<gk00?o0000oiOCoOnGdod00ol00002
oj:di@03o`000?nR]>GoX[CU00CoX[CU00?o0000oj2ciOnP/nD01OnP/nD00ol0003oX;?Voj2ciP03
o`0000?oU=7m00?o0000oi7Co_nAdoh00_nAdoh5o`0000GoX;g]00?o0000oinmk_nO_Nh01?nO_Nh5
o`0000GoUMKn00?o0000oi?Ho_nCf?h00ol00003oj?7l`03o`000?nSbO?oXlWc00CoXlWc0ol00006
oioHn`Co00001_nWcoD00ol0003oZM3dojW@m003o`000003ojKCmol0003o000000?o000000Co_4`e
o`000?nEAVWo00001onbHg<00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo000T
ooooo`03o`000?oooooooooo017ooooo0ol0000iooooo`;o00001_nS_>/00ol0003oXk_Zoj>kjP04
oj>kjP03o`000?nS^^WoXk[Y00?o00000onR_nh00ol0003oXL;`oj72l004oj72l003o`000?nPa?;o
X<Cb00?o000000?oY:GGo`000?nSXM<01OnSXM<00ol0003oXYg?oj:Mc`05oj:Mc`03o`000?nQVLgo
XIW=00?oXIW=00Co0000oj2FbOnPU/WoX9K91_l00003oe?<j`?o00000_nLd?X00ol0003oU<gkoiC=
n`04oiC=n`?o00001_nR]>D00ol0003oX[CUoj:di@04oj:di@03o`000?nP/nGoX;?U00;oX;?U1Ol0
0006oiCAo@Go00001?nQ_>`00ol0003oX;g]oj2mk@04oj2mk@03o`000?nO_NkoWkg^00?o00001?nG
dod01?l0003oUMKnoiGFo_nEe_h5o`0000OoXlOc00?o0000oj?9lonSbO<00ol00003oioGn`03o`00
0?nOf?_oWmSk00?o00000_nVcoD00ol0003oYloeojO?m@04ojO?m@Co00001OnVdoL4o`0000;o_4`e
0_l00007ok9SL`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool002Cooooo0_l0
000@ooooo`;o0000?Oooool00ol0003oXkc[oj>lj`05oj>lj`04o`000?nS^n[oXk_Zoj>kjPGo0000
1onR_nh01?l0003oXL;`oj72l?nQ`_05o`0000GoY:GG00?o0000oj>QdonSXM<01?nSXM<00ol0003o
XYg?oj:Mc`04oj:Mc`04o`000?nQVLgoXIW=oj6Ic@Ko00001?mVeO<5o`0000KoW=3j00?o0000oiC=
nonDcO/00ol00002oj>ei@03o`000?nR]>GoX[CU00GoX[CU00?o0000oj:diOnR]>D00onR]>D5o`00
00GoUlok00?o0000oiCAoOnDdOd00ol00002oj6lk003o`000?nQ_>coXKc/00GoXKc/00Co0000oj2m
kOnP_NgoX;g]1Ol00006oiOCo@Go00001?nRa_800ol0003oXlOcoj?7l`04oj?7l`Co00001_nOeo/3
o`0000KoY/oe00?o0000ojO?mOnWcoD00ol00003ojGCn003o`000?nVdoOoY]?g00?o000000?ooooo
o`000?l000000_l000000onlC3Go0000o`000008ok9SL`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03Oooool002Cooooo00?o0000ooooooooool03?ooool3o`00043ooooo00?o0000oj>l
jonS_>/01?nS_>/4o`0000GoX[k]00?o0000oj:ok_nR_nh01?nR_nh4o`0000?oY:[K00?o0000ojBU
eonTYML01?nTYML00ol0003oXj7Coj>Qd`04oj>Qd`03o`000?nRWLooXYg?00?oXYg?1Ol00005ogGE
o@Go00001OnIbOP01?l0003oW=3joic@n_nLd?X5o`0000KoXkGU00?o0000oj:diOnR]>D01?nR]>D0
0ol0003oX[CUoj:di@03o`0000?oVLgj0_l00003oiO?n`Go00001_nQ_>`00ol0003oXKc/oj6lk004
oj6lk0Co00001OnIdO/00ol0003oUm?moiOCo@03o`0000?oX/Ga00?o0000oj;6l_nRa_801?nRa_80
0ol0003oXlOcoj?7l`03o`0000CoW]Ck00?o0000oioGnonOeo/00ol00002ojG>m@03o`000?nVcoGo
Y/oe00CoY/oe0ol00006ojGCn0?o00001Oooool3o`0000;o_4`e00?o0000ok9SLonbHg<01_nbHg<0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo000Tooooo`03o`000?oooooooooo
00Wooooo0ol00014ooooo`03o`000?nS_>_oXkc[00?o00000_nR^n/00ol0003oX[k]oj:nk@05oj:n
k@03o`000?nR_nkoX[o^00?o000000?oYK3Oo`000?nTZ]/01OnTZ]/00ol0003oY:GGojBUe`04ojBU
e`03o`000?nSXM?oXj7C00?oXj7C00?o0000oj:MconRWLl00ol00004oh;Ho`03o`000?meeOgoMMGm
00?o00000onPboH00ol0003oVLWhoiW9n004oiW9n0Co00001?nS]ND00ol0003oXkGUoj>ei@05oj>e
i@04o`000?nR]>GoX[CUoj:di@Go00001_nIcOX5o`0000?oX[_[00?o0000oj6lk?nQ_>`01_nQ_>`0
0ol0003oXKc/oj6lk003o`0000;oVm3j00?o0000oiWAnonIdO/01?nIdO/3o`0000OoX/Ga00Co0000
oj;6l_nRa_;oX/Kb1Ol00006oikDn`Co00001_nUc_D00ol0003oY/oeojK?m@03o`0000?oYM?h00?o
0000ojGCn?nUdoP00ol00009ooooo`?o000000?o_4`eo`000?nbHg<01onbHg<00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00gooooo000Tooooo`03o`000?oooooooooo00Kooooo0ol00018
ooooo`;o00001_nR^n/00ol0003oX[k]oj:nk@04oj:nk@?o00001OnU/=l00ol0003oY:[KojBZf`04
ojBZf`03o`000?nTYMOoY:GG00?oY:GG00Co0000oj>QdonSXM?oXj7C1_l00004oh;Ho`Go00001onP
boH00ol0003oVLWhoiW9n003o`000003ojBfi_l0003oXkGU00KoXkGU00?o0000oj>eiOnS]ND01?nS
]ND4o`0000GoW<ch00?o0000oiW=n_nIcOX00ol00002oj>kj`03o`000?nR^n_oX[_[00CoX[_[00?o
0000oj6lk?nQ_>`01?nQ_>`4o`0000KoVm3j00?o0000oiWAnonIdO/00ol00002oj?4l003o`000?nR
aO7oX/Ga00CoX/Ga1Ol00005oioCnP03o`000?nNe?_oW]Ck00?o00000_nUc?@00ol0003oYLkeojG>
m@04ojG>m@Co00001OnUdoP4o`0000gooooo0_l00002oka<=@03o`000?nbHg?o/V=c00Go/V=c00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`009?ooool2o`0000Cooooo0ol0001=
ooooo`03o`000?nR^n_oX[_[00CoX[_[00?o0000oj:nkOnR_^d00ol00002ojFfi@03o`000?nU/=oo
YK3O00CoYK3O00?o0000ojBZfonTZ]/00onTZ]/01?l0003oY:GGojBUeonTYML6o`0000KoRM7o1?l0
0005oig6m0;o00000onPboH5o`0000GoY;KV00?o0000oj>eiOnS]ND01OnS]ND00ol0003oXkGUoj>e
i@03o`0000;oWL[g00?o0000oic<n?nLc?P01?nLc?P3o`0000KoXk_[00?o0000oj:kjonR^n/01?nR
^n/00ol0003oXKc/oj6lk003o`0000CoW<ki00Co0000oi_@n_nKd?[oVm3j1Ol00006oj?4l003o`00
0?nRaO7oX/Ga00?o00000onOdOT00ol0003oWm?joioCnP04oioCnP?o00001_nUc?@00ol0003oYLke
ojG>m@03o`0000?oY=;g00?o0000ojGCn?nUdoP00ol0000Booooo`;o000000?o_4`eo`000?nbHg<0
1_nbHg<00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo000Sooooo`04o`000?oo
ooooooooooooo`?o0000DOooool01?l0003oX[_[oj:kjonR^n/5o`0000KoYKKU00?o0000ojF`gonU
/=l00onU/=l01?l0003oY:[KojBZfonTZ]/6o`0000GoTM3m0_l00002ohWAo`?o00000onRao<00ol0
003oWLKdoig6m004oig6m0Co00000onT]nH00ol0003oY;KVojBfiP05ojBfiP03o`000?nS]NGoXkGU
00;oXkGU1Ol00006oig:m`03o`000?nLc?SoW<ch00?o00000_nS^nX00ol0003oXk_[oj>kj`05oj>k
j`04o`000?nR^n_oX[_[oj:kj`Go00001_nLc_T5o`0000CoXl?_00?o0000oj?4l?nSa?001?nSa?03
o`0000OoWm7i00?o0000oioCn_nOdoX00ol00003ojG;m004o`000?nUc?CoYLcdojG<m0Go00001_nT
d_L3o`0001Kooooo0_l000000onlC3Go0000ok9SL`05ok9SL`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03Oooool001Wooooo1?l000000ol@413oooooooooo`03ooooo`Co0000EOooool3
o`0000CoYKcZ00?o0000ojFfiOnU]^D01OnU]^D01?l0003oYK3OojF`gonU/=l5o`0000GoU<Si0_l0
0003oi7@o@Go00001onRao<00ol0003oWLKdoig6m003o`000003ojFhiol0003oY;OV00GoY;OV00?o
0000ojBfi_nT]^H01?nT]^H5o`0000GoWlWe00Co0000oig:monMb_OoWL[g1Ol00006oj>kjP03o`00
0?nS^n_oXk_[00CoXk_[1?l00005oik<n003o`000?nLc_WoW<ki00?o00000onT`^l00ol0003oXl?_
oj?3k`04oj?3k`03o`000?nSa?3oXlC`00?o00000onPcoP00ol0003oWm7ioioAn@02oioAn@Go0000
1OnUbo@5o`0000GoYM7g00?o0000ojCBmonTd_L00ol0000Iooooo`?o000000?o_4`eo`000?nbHg<0
1?nbHg<00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oo
oooooooo00Gooooo0_l0001Hooooo`03o`000?nU_>[oYKcZ00CoYKcZ00?o0000ojFfiOnU]^D01?nU
]^D4o`0000CoVLGf00?o0000oiC8nOnDb?T01?nDb?T4o`0000GoWl;a00?o0000oj;7lonRao<01?nR
ao<3o`0000GoYKSW00?o0000ojBgi_nT]nH01?nT]nH00ol0003oY;KVojBfiP03o`0000?oX<Od00?o
0000oio9mOnObOD01?nObOD4o`0000CoY;_Z00?o0000oj>kj_nS^nX01OnS^nX00ol0003oXk_[oj>k
j`03o`0000;oWl_f00?o0000oik<n?nNc?P01?nNc?P3o`0000OoY<;_00Co0000oj?3konS`nooXl?_
1Ol00006oj3?n0Go00001?nUb_<00ol0003oYL_dojG;m003o`0000?oYLof00?o0000ojGAmonUdOL0
1?nUdOL3o`0001gooooo0_l000000onlC3Go0000ok9SL`04ok9SL`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Fooooo`03o`000?nU_>[oYKcZ00CoYKcZ00?o0000ojFfiOnU]^D00ol00002oiZnl@03o`000?nI
aOKoVLGf00CoVLGf00?o0000oiC8nOnDb?T00ol00003oj?2k`03o`000?nO`_7oWl;a00CoWl;a00?o
0000oj;7lonRao<00ol000000onT^>Oo0000ojFhi`06ojFhi`04o`000?nT]nKoY;OVojBgiPGo0000
1onPao@00ol0003oWlWeoio9m@03o`000003ojBkjOl0003oY;_Z00KoY;_Z00?o0000oj>kj_nS^nX0
0_nS^nX5o`0000KoWl_f00?o0000oik<n?nNc?P00ol00002ojC1kP03o`000?nT`^ooY<;_00CoY<;_
1Ol00005oj7=m`03o`000?nPcoSoX<oh00?o00000_nUb?800ol0003oYL[cojG:l`04ojG:l`?o0000
1onUcoH00ol0003oYM7gojGAm`03o`00027ooooo0_l000000onlC3Go0000ok9SL`03ok9SL`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03?ooool001_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Fooooo`04o`000?nU_>[oYKcZojFljPGo00001_nJ__401?l0003oVLGf
oiW5m_nIaOH5o`0000OoXl;_00Co0000oio2lOnO`_7oWl;a1Ol00005ojBhi`03o`000?nU^>OoYKSW
00CoYKSW1?l00005oj76lP;o00000onPao@5o`0000GoY;_Y00?o0000ojBkj_nT^nX01?nT^nX5o`00
00GoXLWe00Co0000oio;m_nOboKoWl_f1Ol00006ojC1kP03o`000?nT`^ooY<;_00?o00000onRc?H0
0ol0003oXLggoj7=m`04oj7=m`?o00001_nUb?800ol0003oYL[cojG:l`03o`0000;oYLke00?o0000
ojG?m_nUcoH01?nUcoH4o`0002Cooooo00Co0000ooooool0003o00001?nbHg<00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00cooooo000Kooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0E_ooool3o`0000CoW;[]00?o0000oiZnlOnJ__401?nJ__44o`0000GoX[o^00?o0000
oj?2konS`^l01?nS`^l4o`0000CoYKWW00?o0000ojBhionT^>L01?nT^>L00ol0003oYKSWojFhi`03
o`0000?oX/Ca00?o0000oj76l_nQa_801?nQa_84o`0000CoYK_Y00?o0000ojBkjOnT^nT01?nT^nT0
0ol0003oY;_ZojBkjP03o`0000?oXLSc00?o0000oj79mOnQbOD01?nQbOD4o`0000CoY<7]00?o0000
ojC1k_nT`Nh01?nT`Nh3o`0000OoX/cf00?o0000oj7=monQcOL00ol00002ojG7l@03o`000?nUb?;o
YLSb00CoYLSb0ol00006ojG>m@03o`000?nUcoKoYLof00?o0000:Oooool01?l0003oooooo`000?l0
0003ok9SL`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool001_ooooo00?o0000
ooooooooool02_ooool2o`0005Sooooo00?o0000oibjkOnL^^d00onL^^d00ol0003oV[kaoiZnl@03
o`0000?oXkk/00?o0000oj:ok_nR_nh01?nR_nh00ol0003oXl;_oj?2k`03o`000003ojFjj?l0003o
YKWW00KoYKWW00Co0000ojBhionT^>OoY;SW1Ol00007oj;4l@03o`000?nQa_;oXLKb00?o000000?o
YK_Yo`000?nU^nT01_nU^nT01?l0003oY;_YojBkjOnT^nT5o`0000OoXLSc00?o0000oj79mOnQbOD0
0ol00002ojG0k@03o`000?nT`NgoY<7]00CoY<7]00?o0000ojC1k_nT`Nh00ol00002oj?:m003o`00
0?nRc?KoX/cf00CoX/cf1?l00006ojG7l@03o`000?nUb?;oYLSb00?o00000_nUcO@00ol0003oYLke
ojG>m@04ojG>m@?o0000;Oooool3o`0000?o/V=c00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`006oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo00Co
0000oibjkOnL^^goW;[]1?l00007oj>nk004o`000?nR_nkoX[o^oj:okPGo00001OnU^^P00ol0003o
YKWWojFii`04ojFii`Co00001OnS`o000ol0003oX/Caoj;4l@04oj;4l@?o00001OnU^nT00ol0003o
YK_YojFkj@04ojFkj@Co00001OnRao800ol0003oXLScoj78l`04oj78l`?o00001_nU`>d01?l0003o
Y<7]ojC1kOnT`Nd5o`0000KoXl[d00?o0000oj;<m_nRc?H00ol00003ojK6l003o`000?nUao7oYLOa
00CoYLOa0ol00006ojG=m003o`000?nUc_GoYLke00?o0000<Oooool3o`0000;o/V=c00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`006Oooool00omEEEGoIVIVo`00000?ooooo`03
o`000?oooooooooo05Kooooo0ol00004oj>lj`03o`000?nS_^coXkk/00CoXkk/1?l00004ojFkj003
o`000?nU^^SoYK[X00CoYK[X00?o0000ojFiionU^NL00ol00003oj?1k`03o`000?nS`o3oXl?`00Co
Xl?`00?o0000oj;4lOnRa?400ol000000onU_>Wo0000ojFkj@06ojFkj@03o`000?nU^nWoYK_Y00?o
00000_nSaO400ol0003oX/Oboj;7lP05oj;7lP03o`000?nQb??oXLSc00?o00000_nU_n`00ol0003o
YL3]ojG0k@04ojG0k@Co00001OnSbO<01?l0003oXl[doj?:m?nSb_@5o`0000OoY/K`00?o0000ojG7
lOnUao400ol00003ojK;l`04o`000?nUcOCoYLgdojG=m0Go0000=?ooool00ol0003oooooo`000003
ok9SL`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool002cooooo00?o0000oooo
ooooool0EOooool00ol0003oXkc[oj>lj`05oj>lj`03o`000?nS_^coXkk/00?o00000_nU^nT00ol0
003oYK_XojFkj004ojFkj004o`000?nU^^SoYK[XojFjj0Go00001onS`Nl01?l0003oXl?`oj?3l?nS
`o05o`0000GoYKcY00?o0000ojFkjOnU^nT01?nU^nT3o`0000KoXlGa00?o0000oj;7l_nRao800_nR
ao85o`0000KoYKo/00?o0000ojG0kOnU`>d00ol00002ojC8lP03o`000?nSbO?oXlWc00CoXlWc1?l0
0004ojK5l003o`000?nVa_3oY/K`00CoY/K`1?l00006ojK;l`Co0000>_ooool00ol0003oooooo`00
0002ok9SL`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool002gooooo0_l0001F
ooooo`03o`000?nS_>_oXkc[00CoXkc[0ol00006ojFkj@03o`000?nU^nSoYK_X00?oYK_X1?l00005
ojC0k@03o`000?nS`NooXl7_00CoXl7_1?l00004ojFkj@03o`000?nU_>WoYKcY00CoYKcY00?o0000
ojFkjOnU^nT00ol00002ojC4l003o`000?nSaO7oXlGa00CoXlGa1Ol00004ojFok003o`000?nU_nco
YKo/00CoYKo/0ol00006ojC8lP03o`000?nSbO?oXlWc00?o00000_nVa>l00ol0003oY/G`ojK5l004
ojK5l003o`000?nVa_3oY/K`00?o00001?nVb_800ol0003oY/_cojK;l`03o`0003oooooo0ol00000
0onbHg?o0000ooooo`0Dooooo`03o`000?oooooooooo00_ooooo000_ooooo`03o`000?oooooooooo
05Cooooo00?o0000oj>ljonS_>/00ol00002ojFlj@03o`000?nU^nWoYK_Y00GoYK_Y00?o0000ojFk
j?l000000_l00002ojBnk003o`000?nT`>goY<3]00GoY<3]00?o0000oj?1konS`Nl00ol000000onV
_>Wo0000ojFkj@06ojFkj@04o`000?nU_>WoYKcYojFlj@Go00001_nTa?000ol0003oXlGaoj?5l@03
o`0000?oY[k[00?o0000ojFok?nU_n`01?nU_n`00ol0003oYKo/ojFok003o`0000;oYLKa00?o0000
ojC8l_nTb?801?nTb?83o`0000KoY/C_00Co0000ojK5l?nVaO3oY/G`1Ol00006ojK:lPCo0000@ooo
ool2o`000003ok9SLol0003ooooo01Cooooo00?o0000ooooooooool02oooool0033ooooo00?o0000
ooooooooool0E?ooool2o`0000KoYKcY00?o0000ojFkjOnU^nT01?nU^nT2o`0000KoY;k/00?o0000
ojC0kOnT`>d01?nT`>d3o`0000GoY[cY00?o0000ojFkjOnU^nT01?nU^nT4o`0000CoY<?_00?o0000
ojC4l?nTa?001?nTa?03o`0000OoY[k[00Co0000ojFok?nU_ncoYKo/1Ol00006ojG6l@03o`000?nT
b?;oY<Sb00?o00000_nW`nh00ol0003oY/C_ojK4k`04ojK4k`Co00001OnWb?400ol0003oY/[bojK:
lP03o`0004Oooooo00Co0000ooooool0003o00005Oooool00ol0003oooooooooo`0;ooooo`00<Ooo
ool00ol0003oooooooooo`1Eooooo`03o`000?nU_>WoYKcY00CoYKcY00?o0000ojFkjOnU^nT00ol0
0002ojBmj`03o`000?nT_^coY;k/00CoY;k/00?o0000ojC0kOnT`>d00ol00002ojJlj@03o`000?nV
_>WoY[cY00CoY[cY00?o0000ojFkjOnU^nT00ol00002ojG2kP03o`000?nT`nooY<?_00CoY<?_00?o
0000ojC4l?nTa?000ol00003ojJnj`03o`000?nV_^_oY[k[00CoY[k[1?l00004ojG5l003o`000?nU
a_7oYLKa00CoYLKa0ol00006ojO3kP03o`000?nVa>ooY/C_00?o00000_nWao000ol0003oYlSaojO8
l@04ojO8l@?o0000Boooool3o`0001Gooooo00?o0000ooooooooool02oooool003;ooooo00?o0000
ooooooooool0EOooool01?l0003oYKcYojFljOnU_>T5o`0000KoY;g[00Co0000ojBnk?nT_^coY;k/
1Ol00006ojJlj@04o`000?nV_>WoY[cYojJlj@Go00001_nU`^h01?l0003oY<?_ojC3konT`nl5o`00
00OoY[k[00?o0000ojJnjonV_^/00ol00002ojK4k`03o`000?nUaO3oYLG`00CoYLG`00?o0000ojG6
lOnUa_400ol00002ojO3k@03o`000?nW`nkoYl?^00CoYl?^0ol00006ojO7l003o`000?nWb?7oYlSa
00?o0000Coooool2o`0001Gooooo00?o0000ooooooooool02oooool003?ooooo0_l0001Fooooo`?o
00001?nT_>X00ol0003oY;g[ojBmj`04ojBmj`Co00001?nV_>T00ol0003oY[cYojJlj@04ojJlj@Co
00001OnU`Nd00ol0003oYL;^ojG2kP03ojG2kPCo00001OnV_^X00ol0003oY[k[ojJnj`04ojJnj`?o
00001_nVa>l01?l0003oYLG`ojG5l?nUaO05o`0000KoYl?]00?o0000ojO3k_nW`nh00ol00002ojO6
k`03o`000?nWao3oYlO`00CoYlO`0ol0001Booooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool003Gooooo00?o0000ooooooooool0EOooool00ol0003oY;cZojBljP03ojBljP03
o`000?nT_N_oY;g[00?o00000_nV_>T00ol0003oY[cYojJlj@04ojJlj@03o`000?nV_>WoY[cY00?o
00000onU_n`00ol0003oYL7]ojG1k@04ojG1k@03o`000?nU`^ko000000;o00000onV_^X00ol0003o
Y[kZojJnjP04ojJnjP03o`000?nV_^_oY[k[00?o00000_nV`nh00ol0003oY/C_ojK4k`04ojK4k`Co
00001?nW`^d00ol0003oYl?]ojO3k@04ojO3k@?o00001_nWa^l00ol0003oYlO`ojO7l003o`0005Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`00=_ooool00ol0003ooooo
ooooo`1Eooooo`04o`000?nT_>[oY;cZojBljPCo00001_nV_>T00ol0003oY[cYojJlj@03ojJlj@?o
00001onU_n`01?l0003oYL7]ojG1kOnU`Nd4o`0000OoY[kZ00Co0000ojJnj_nV_^[oY[kZ1Ol00006
ojK3kP03o`000?nVa>ooY/C_00?o00000_nW`N`00ol0003oYl;]ojO2k@04ojO2k@03o`000?nW`ngo
Yl?]00?o00000_nWaNl00ol0003oYlK_ojO6k`04ojO6k`?o0000F_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo000gooooo`03o`000?oooooooooo05Gooooo0ol00004ojJl
j@03o`000?nV_>WoY[cY00CoY[cY00?o0000ojJljOl000000_l00003ojFnj`03o`000?nU_ncoYKo/
00CoYKo/1?l00004ojNmjP03o`000?nV_^[oY[kZ00CoY[kZ1?l00004ojK2k@03o`000?nV`nkoY/?^
00CoY/?^0ol00006ojO1k004o`000?nW`^goYl;]ojO2k@Go00001_nWaNl00ol0003oYlK_ojO6k`03
o`0005kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00>?ooool2o`00
05Gooooo00?o0000ojJljOnV_>T01OnV_>T01?l0003oY[cYojJljOnV_>T4o`0000OoYKk[00?o0000
ojFok?nU_n`00ol000000onW_NWo0000ojNmjP06ojNmjP03o`000?nV_^[oY[kZ00?o00000_nW`Nd0
0ol0003oY/;]ojK2k@04ojK2k@03o`000?nV`nkoY/?^00?o00000_nW`N`00ol0003oYl7/ojO1k004
ojO1k0Co00001OnXa>h01?l0003oYlG_ojO5konWaNl5o`00067ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0:ooooo`00>_ooool00ol0003oooooooooo`1Cooooo`03o`000?nV_>Wo
Y[cY00CoY[cY1?l00004ojJmjP03o`000?nU_^_oYKk[00CoYKk[0ol00005ojNmj@03o`000?nW_N[o
YkgZ00CoYkgZ0ol00006ojO1k@04o`000?nV`^goY/;]ojK2k@Go00001_nW`N`00ol0003oYl7/ojO1
k003o`0000;oZ<?]00?o0000ojS4k_nXa>h01?nXa>h4o`0006Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0:ooooo`00>oooool00ol0003oooooooooo`1Cooooo`03o`000?nV_>Wo
Y[cY00?o00000_nV_>T00ol0003oY[gZojJmjP04ojJmjP03o`000?nU_^_oYKk[00?o00000_nW_NT0
0ol0003oYkgYojNmj@04ojNmj@03o`000?nW_N[oYkgZ00?o00000_nW`>`00ol0003oYl7]ojO1k@04
ojO1k@Co00001?nX`>/00ol0003oYl7/ojO1k004ojO1k0?o00001_nX`nd00ol0003oZ<C^ojS4kP03
o`0006cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`00??ooool00ol0
003oooooooooo`1Cooooo`;o00001_nV_>T01?l0003oY[gZojJmj_nV_NX5o`0000KoYkgY00Co0000
ojNmjOnW_NWoYkgY1Ol00006ojO0k003o`000?nW`NgoYl7]00?o000000?oZ;o[o`000?nX`>/01_nX
`>/00ol0003oYl7/ojO1k003o`0000;oZ<;/00?o0000ojS3kOnX`nd01?nX`nd3o`00073ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00?Oooool2o`0005Gooooo00?o0000
ojJljOnV_>T00onV_>T4o`0000GoYkgY00?o0000ojNmjOnW_NT00onW_NT4o`0000CoYko[00?o0000
ojO0k?nW`>`01?nW`>`3o`0000GoZ;o[00?o0000ojS0jonX`>/01?nX`>/3o`0000KoZ<;/00?o0000
ojS3kOnX`nd00ol0001cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool0
03oooooo00?o0000ooooooooool0Doooool00ol0003oY[cYo`000002o`0000;oYkgY00?o0000ojNm
jOnW_NT01OnW_NT00ol0003oYkgYo`000002o`0000?oYkkZ00?o0000ojNojonW_n/00onW_n/00ol0
003oYl3/ojO0k003o`0000?oZ;oZ00?o0000ojRojonX_n/00onX_n/00ol0003oZ<3[ojS0j`03o`00
00;oZ<7/00?o0000ojS2k?nX`^`01?nX`^`3o`0007Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`09ooooo`00@?ooool00ol0003oooooooooo`1Cooooo`03o`000?nW_NWoYkgY00Co
YkgY00?o0000ojNmjOnW_NT01?nW_NT2o`0000OoYkkZ00Co0000ojNojonW_n_oYko[1?l00007ojRo
jP04o`000?nX_n_oZ;o[ojRoj`Co00001_nX`N`00ol0003oZ<;/ojS2k003o`0007_ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`09ooooo`00@Oooool00ol0003oooooooooo`1Coooo
o`03o`000?nW_NWoYkgY00CoYkgY00?o0000ojNmjOnW_NT00ol00002ojNmj@03o`000?nW_^[oYkkZ
00CoYkkZ1?l00004ojRnj@03o`000?nX_n[oZ;oZ00CoZ;oZ1?l00004ojS1j`;o00000onX`N`4o`00
07kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`00@_ooool2o`0005Co
oooo00Co0000ojNmjOnW_NWoYkgY1Ol00006ojNmj@03o`000?nW_^[oYkkZ00?o000000?oZ;kYo`00
0?nX_^T01_nX_^T00ol0003oZ;oZojRojP03o`0000;oZ<3[00?o0000ojS1jonX`N/01?nX`N/4o`00
08?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`00A?ooool00ol0003o
ooooooooo`1Booooo`?o00001?nW_NT00ol0003oYkgYojNmj@04ojNmj@?o00001OnX_^T00ol0003o
Z;kYojRnj@04ojRnj@?o00001_nX`>/00ol0003oZ<7[ojS1j`03o`0008Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`09ooooo`00AOooool00ol0003oooooooooo`1Cooooo`03o`00
0?nW_NWoYkgY00?oYkgY00?o0000ojNmjOnW_NT00ol00002ojRmj@03o`000?nX_^WoZ;kY00CoZ;kY
00?o0000ojRnjOnX_^T00ol00002ojRojP03o`000?nX`>_oZ<3[00CoZ<3[0ol0002<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool004Kooooo00?o0000ooooooooool0Dooo
ool01?l0003oYkgYojNmjOnW_NT4o`0000KoZ;gY00Co0000ojRnjOnX_^WoZ;kY1Ol00006ojRojP03
o`000?nX`>_oZ<3[00?o0000Soooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo0017ooooo`03o`000?oooooooooo05?ooooo0ol00004ojRmj003o`000?nX_NWoZ;gY00?oZ;gY
1?l00004ojRnj@03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0002Cooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool004Sooooo0_l0001Cooooo`03o`000?nX_NSoZ;gX00GoZ;gX00?o
0000ojRmjOl000000_l00003ojVnj@03o`000?nX_^WoZ;kY00?oZ;kY00?o0000ojRoj_nX_nX00ol0
002Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool004[ooooo00?o0000
ooooooooool0DOooool00ol0003oZ;gXojRmj004ojRmj0;o00001onY_^T01?l0003oZ;kYojRnjOnX
_^T4o`0009[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`00Boooool0
0ol0003oooooooooo`1Aooooo`03o`000?nX_NSoZ;gX00?o00000_nY_NP00ol0003oZKkYojVnj@04
ojVnj@Co0000Woooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo001<oooo
o`03o`000?oooooooooo057ooooo0_l00006ojVmj003o`000?nY_^WoZKkY00?o0000Y?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo001=ooooo`;o0000D_ooool00ol0003o
ZKgXojVmj004ojVmj0?o0000Z?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo001?ooooo`03o`000?oooooooooo053ooooo00?o0000ojVmj?nY_NP00ol0002[ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool0053ooooo00?o0000ooooooooool0D?oo
ool2o`000:oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`00DOooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`00D_ooool2o`0004oooooo00?o0000ooooooooool0/?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo001Dooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo001Eooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0/Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo001G
ooooo`;o0000B_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool005Wooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2coooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool005[ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool005_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2eooooo`05o`00
0?ooooooooooooooool000002?ooool005cooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`2eooooo`05o`000?ooooooooooooooool000002?ooool005gooooo0_l00014ooooo`03o`00
0?oooooooooo0;Kooooo00Co0000oooooooooooo00002?ooool005oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Sooooo001Pooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0]oooool01?l0003oooooooooool00007ooooo`00HOoo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooool000001ooo
ool006;ooooo0_l0000oooooo`03o`000?oooooooooo0;Wooooo0_l00007ooooo`00I?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0;Wooooo0ol00007ooooo`00IOooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo0;Gooooo1?l0000:ooooo`00I_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo0;7ooooo1?l0000>ooooo`00Ioooool2o`0003Wooooo00?o
0000ooooooooool0[_ooool3o`0001;ooooo001Yooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0Z_ooool4o`0001Gooooo001Zooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0Y_ooool4o`0001Wooooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0X_ooool4o`0001gooooo001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co0000
8Oooool006kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Kooooo`?o00009Ooo
ool006oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Gooooo`Co0000:?ooool0
073ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co0000;?ooool0077o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2?ooooo`Co0000<?ooool007;ooooo
0_l0000^ooooo`03o`000?oooooooooo08_ooooo1?l0000dooooo`00M?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo08Oooooo1?l0000hooooo`00MOooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo08Cooooo0ol0000looooo`00M_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo083ooooo1?l0000oooooo`00Moooool2o`0002Wooooo00?o0000oooooooo
ool0O?ooool4o`0004?ooooo001iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
N?ooool4o`0004Oooooo001jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?oo
ool4o`0004_ooooo001kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0LOooool3
o`0004oooooo001looooo`;o00009?ooool00ol0003oooooooooo`1]ooooo`Co0000D_ooool007ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Yooooo`Co0000E_ooool007oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Uooooo`Co0000F_ooool0083ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`Co0000G_ooool0087ooooo0_l0000O
ooooo`03o`000?oooooooooo05gooooo1?l0001Rooooo`00Poooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo05[ooooo0ol0001Vooooo`00Q?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo05Kooooo1?l0001Yooooo`00QOooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo05;ooooo1?l0001]ooooo`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04kooooo1?l0001aooooo`00Qoooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4
o`0007Gooooo0029ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00
07Wooooo002:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@oooool3o`0007go
oooo002;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool4o`00083ooooo
002<ooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`Co0000Q?ooool008kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000R?ooool008oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0dooooo`Co0000S?ooool0093ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0aooooo`?o0000T?ooool0097ooooo0_l0000>ooooo`03o`00
0?oooooooooo02gooooo1?l0002Cooooo`00Toooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo02Wooooo1?l0002Gooooo`00U?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Gooooo1?l0002Kooooo`00UOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
027ooooo1?l0002Oooooo`00U_ooool2o`0000Wooooo00?o0000ooooooooool07Oooool4o`000:?o
oooo002Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool3o`000:Oooooo
002Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:[ooooo002J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:kooooo002Koooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;;ooooo002Looooo`;o
00000oooool00ol0003oooooooooo`0:ooooo`Co0000]_ooool009kooooo00Co0000oooooooooooo
00002Oooool3o`000;[ooooo002Oooooo`03o`000?oooooo000000Gooooo1?l0002mooooo`00X?oo
ool2o`000003ooooool0003o000000;o0000`Oooool00:7ooooo0_l00035ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00[?ooool3o`000003oa0@4?oooooo
oooo0;Kooooo001^ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0]oooool006ko
oooo00?o410@omgMgOooool0?Oooool00ol0003oooooooooo`2gooooo`00K?ooool01Oo<c<co410@
o`000?l0003oQhN700_ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool01_ooool01_nHV9So0000o`000?mgMgOo410@o`0000Wooooo00Ko410@oc8b<_l0003o0000
oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?mgMgOo00000oooool02?nHV9So0000o`000?mg
MgOo0000oa0@4?ooooooV9RH0_l000001OmgMgOo410@o`000?oooooo410@00Go00000oooool01_o^
k^koEEEEo`000?l0003oA4A4okZj^PKooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04
oa0@4?l0003o0000ooooo`;o000000Co410@ooooooooooooIVIV0_l000001?m4A4Coc<c<oooooooo
ool5o`0000?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`06oa0@4?lb<S;o0000o`00
0?l@413oZJVY0oooool01OnHV9So0000o`000?mgMgOo000000;o410@1Ol00003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Co^[ZjCOooool006cooooo00Ko8B4QohN7Qolb<S;oZJVYodA4A?n7QhL<oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?o<c<co
k^k^ohN7Qol000002_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00003ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01Ol0003oc<c<onk^
k_n7QhOo000000Cooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`05o`000?ooooooooooooooool00000
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Cooooo00?o0000ooooooooool00oooool01_mE
EEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`05
o`000?nYZJWoooooohN7Qol000000oooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@COooool006cooooo00Ko0000oooooomVIVKoQhN7omgMgOl@410<ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000009ooooo`05oa0@4?n7QhOoooooonk^
k_l000002oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00Ko0000ooooooooooooooooonk^
k_l00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@413oQhN7ooooooo^k^ko0000
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oooooooooooooooonj^[[oQhN7
0_mVIVH01Ol@413ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo053ooooo001/ooooo`06oa0@4?oMgMgoMgMgogMgMooooooo00003?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002Oooool00onj^[[o410@o`00
0002o`0000[ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`06o`000?oooooooooooooo
ooo^k^ko00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o^[Zjoa0@4?l000000_l0
0004ooooo`03o`000?oooooooooo00Cooooo1_l00006ooooo`Ko00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000oooooooooooo<S8bob4Q8@02ogMgM`03ohN7Qoo^k^kooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo1_l0001=oooo
o`00K?ooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40cooooo00?o0000ooooooooool00oooool0
1Ol0003oQhN7oooooonYZJWo000000cooooo00?oc<c<o`000?ooool02Oooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?oooooo
ooooooooool000001Oooool00oo<c<co0000ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S86ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool0
1Ol0003oQhN7oooooonYZJWo000000;ooooo00KoIVIVogMgMoooooooooooohN7Qol00004ooooo`03
o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED2ooooo`06o`000?nj^[[o
ooooonk^k_mgMgOo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oc8b<_oM
gMd01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<Tgooooo001]ooooo`05oiRHV?l0003o0000
oa0@4?o<c<`02_ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RH
ooooooooool02?ooool01?lb<S;o0000o`000?nHV9P:ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o
00000_ooool02_o^k^koEEEEo`000?l0003oMgMgo`000?l@413ooooooa0@4?l00002ooooo`;o0000
0oooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^
k^koEEEEo`000?l0003oA4A4onk^kPKooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`03
oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^ofIVIP02o`000003odA4A?l0003ooooo
00?ooooo00?o0000ooooooooool00oooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Ko
ZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool2o`00
0004ojVYZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^i=ooooo`00K_oo
ool00onj^[[o<S8booooo`1nooooo`03o`000?oooooooooo07Kooooo001_ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`1fooooo`00O_ooool00ol@
413oooooooooo`1/ooooo`03oa0@4?l0003o000007Sooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.106199, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "There is a rather large Gibbs phenomenon caused by the discontinuities in \
our choice for ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  ", Eq. ",
  ButtonBox["(4.3.28)",
    ButtonData:>"(4.3.28)",
    ButtonStyle->"Hyperlink"],
  ". This Gibbs phenomenon extends all the way into the interior of the box, \
as can be seen in Cell ",
  ButtonBox["4.24",
    ButtonData:>"Cell 4.24",
    ButtonStyle->"Hyperlink"],
  " by looking at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " along the line ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1/2\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[\[Phi][1/2, y], {y, 0, b}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.24"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.206776 1.51573 [
[.21429 .19428 -9 -9 ]
[.21429 .19428 9 0 ]
[.40476 .19428 -9 -9 ]
[.40476 .19428 9 0 ]
[.59524 .19428 -9 -9 ]
[.59524 .19428 9 0 ]
[.78571 .19428 -9 -9 ]
[.78571 .19428 9 0 ]
[.97619 .19428 -3 -9 ]
[.97619 .19428 3 0 ]
[.01131 .0552 -24 -4.5 ]
[.01131 .0552 0 4.5 ]
[.01131 .35835 -18 -4.5 ]
[.01131 .35835 0 4.5 ]
[.01131 .50992 -18 -4.5 ]
[.01131 .50992 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .20678 m
.21429 .21303 L
s
[(0.2)] .21429 .19428 0 1 Mshowa
.40476 .20678 m
.40476 .21303 L
s
[(0.4)] .40476 .19428 0 1 Mshowa
.59524 .20678 m
.59524 .21303 L
s
[(0.6)] .59524 .19428 0 1 Mshowa
.78571 .20678 m
.78571 .21303 L
s
[(0.8)] .78571 .19428 0 1 Mshowa
.97619 .20678 m
.97619 .21303 L
s
[(1)] .97619 .19428 0 1 Mshowa
.125 Mabswid
.07143 .20678 m
.07143 .21053 L
s
.11905 .20678 m
.11905 .21053 L
s
.16667 .20678 m
.16667 .21053 L
s
.2619 .20678 m
.2619 .21053 L
s
.30952 .20678 m
.30952 .21053 L
s
.35714 .20678 m
.35714 .21053 L
s
.45238 .20678 m
.45238 .21053 L
s
.5 .20678 m
.5 .21053 L
s
.54762 .20678 m
.54762 .21053 L
s
.64286 .20678 m
.64286 .21053 L
s
.69048 .20678 m
.69048 .21053 L
s
.7381 .20678 m
.7381 .21053 L
s
.83333 .20678 m
.83333 .21053 L
s
.88095 .20678 m
.88095 .21053 L
s
.92857 .20678 m
.92857 .21053 L
s
.25 Mabswid
0 .20678 m
1 .20678 L
s
.02381 .0552 m
.03006 .0552 L
s
[(-0.1)] .01131 .0552 1 0 Mshowa
.02381 .35835 m
.03006 .35835 L
s
[(0.1)] .01131 .35835 1 0 Mshowa
.02381 .50992 m
.03006 .50992 L
s
[(0.2)] .01131 .50992 1 0 Mshowa
.125 Mabswid
.02381 .08552 m
.02756 .08552 L
s
.02381 .11583 m
.02756 .11583 L
s
.02381 .14615 m
.02756 .14615 L
s
.02381 .17646 m
.02756 .17646 L
s
.02381 .23709 m
.02756 .23709 L
s
.02381 .2674 m
.02756 .2674 L
s
.02381 .29772 m
.02756 .29772 L
s
.02381 .32803 m
.02756 .32803 L
s
.02381 .38866 m
.02756 .38866 L
s
.02381 .41898 m
.02756 .41898 L
s
.02381 .44929 m
.02756 .44929 L
s
.02381 .47961 m
.02756 .47961 L
s
.02381 .02489 m
.02756 .02489 L
s
.02381 .54024 m
.02756 .54024 L
s
.02381 .57055 m
.02756 .57055 L
s
.02381 .60087 m
.02756 .60087 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20678 m
.06244 .22995 L
.10458 .25421 L
.11448 .26242 L
.11733 .26436 L
.12002 .26594 L
.12247 .26712 L
.12507 .26813 L
.12733 .2688 L
.12982 .26936 L
.13209 .26972 L
.13422 .26997 L
.13665 .27022 L
.13931 .2705 L
.14053 .27066 L
.14182 .27087 L
.14415 .27135 L
.14539 .27169 L
.14674 .27212 L
.14917 .27312 L
.15154 .2744 L
.15373 .27584 L
.15799 .27943 L
.16249 .28418 L
.172 .29565 L
.17689 .3009 L
.17965 .30328 L
.18221 .305 L
.18342 .30565 L
.18477 .30621 L
.18544 .30644 L
.18617 .30665 L
.18748 .30691 L
.18875 .30703 L
.18939 .30705 L
.19009 .30703 L
.19133 .30691 L
.19248 .30672 L
.1937 .30642 L
.19485 .30607 L
.19701 .30528 L
.20185 .30323 L
.20407 .30238 L
.20529 .30201 L
.20642 .30173 L
.20739 .30155 L
.20843 .30144 L
.20959 .30143 L
.21064 .30152 L
.21186 .30176 L
Mistroke
.21298 .30212 L
.21422 .30267 L
.21554 .30346 L
.21797 .30545 L
.22018 .30786 L
.22507 .31504 L
.23023 .32457 L
.23469 .33323 L
.23946 .34142 L
.24216 .34498 L
.24343 .34631 L
.24461 .34731 L
.24579 .34808 L
.24707 .34864 L
.2482 .34889 L
.2494 .34889 L
.25069 .34859 L
.25142 .3483 L
.25208 .34794 L
.2533 .34708 L
.25459 .34591 L
.25732 .34258 L
.2603 .33792 L
.2656 .32843 L
.2682 .32403 L
.2706 .32061 L
.27173 .31932 L
.27278 .31832 L
.27388 .31754 L
.27509 .31701 L
.27631 .31686 L
.27743 .31709 L
.27872 .31781 L
.27995 .31896 L
.28115 .32055 L
.28247 .32285 L
.28516 .32925 L
.28765 .33716 L
.28998 .34613 L
.2952 .36996 L
.30091 .39705 L
.30337 .40698 L
.30472 .41159 L
.30599 .41522 L
.30718 .41788 L
.30847 .41988 L
.30965 .42081 L
.31073 .42084 L
.31196 .41983 L
.31312 .4178 L
Mistroke
.31439 .41431 L
.31575 .409 L
.31717 .40162 L
.31853 .39284 L
.32107 .37149 L
.32329 .34757 L
.32566 .31669 L
.32992 .2479 L
.33461 .15508 L
.33717 .09869 L
.33957 .04367 L
.3408 .01472 L
Mfstroke
.3408 .01472 m
.34136 .61803 L
s
.34745 .61803 m
.34986 .56352 L
.3552 .45826 L
.35801 .41225 L
.36099 .37194 L
.36355 .34491 L
.36491 .33344 L
.36638 .32331 L
.36772 .31606 L
.36895 .31105 L
.37012 .30769 L
.37136 .3056 L
.37253 .30493 L
.37379 .30554 L
.37497 .30729 L
.37604 .30981 L
.37731 .31379 L
.37868 .31922 L
.38117 .33153 L
.38613 .36199 L
.39145 .3961 L
.39403 .41067 L
.39647 .42236 L
.39867 .43069 L
.3999 .43436 L
.40106 .43714 L
.4017 .43837 L
.40238 .43948 L
.40358 .44083 L
.40426 .44128 L
.40498 .4415 L
.40626 .44127 L
.40745 .44036 L
.40856 .43895 L
.40978 .4368 L
.41109 .43387 L
.41405 .42513 L
.41686 .41493 L
.42211 .39391 L
.42452 .38475 L
.42711 .37606 L
.42956 .36944 L
.43072 .36695 L
.4318 .36504 L
.43299 .36341 L
.4343 .36223 L
.43546 .36171 L
.43669 .36172 L
.43738 .36198 L
.43814 .36245 L
Mistroke
.43885 .3631 L
.43951 .36385 L
.44076 .36567 L
.44207 .36815 L
.44426 .3734 L
.44662 .38033 L
.45086 .395 L
.45554 .4118 L
.46051 .42676 L
.46302 .43212 L
.46445 .43435 L
.4651 .43515 L
.46579 .43585 L
.46702 .43671 L
.46814 .43706 L
.46935 .43696 L
.47004 .43669 L
.47068 .4363 L
.47137 .43574 L
.47212 .43495 L
.47348 .43309 L
.47602 .42824 L
.479 .42071 L
.48174 .41254 L
.48679 .39653 L
.49151 .38337 L
.49389 .37837 L
.49522 .37618 L
.49644 .37463 L
.49708 .37398 L
.49777 .37343 L
.49852 .37299 L
.49922 .37274 L
.49993 .37264 L
.5006 .3727 L
.50186 .37319 L
.50302 .37408 L
.50427 .37548 L
.50545 .37722 L
.50652 .37913 L
.51164 .3918 L
.51659 .40725 L
.5192 .41543 L
.52197 .42334 L
.52431 .42898 L
.52556 .43146 L
.5269 .43366 L
.52813 .43523 L
.52925 .43625 L
.53033 .43686 L
Mistroke
.53146 .43708 L
.53254 .4369 L
.53369 .43628 L
.53477 .43529 L
.53576 .43407 L
.53817 .4298 L
.54045 .42427 L
.55019 .39121 L
.55276 .38235 L
.55552 .374 L
.55685 .37057 L
.55812 .36776 L
.55927 .36563 L
.56049 .36384 L
.56153 .36273 L
.56268 .36195 L
.56372 .36166 L
.5647 .36176 L
.56585 .36233 L
.56691 .3633 L
.56807 .36483 L
.56929 .36696 L
.57168 .37256 L
.5739 .37927 L
.57895 .39815 L
.58399 .41815 L
.58664 .4274 L
.58809 .43172 L
.58945 .43516 L
.59074 .43779 L
.59191 .43962 L
.59321 .44095 L
.59393 .44136 L
.59461 .44151 L
.5958 .44125 L
.59689 .44038 L
.5981 .43873 L
.59938 .43617 L
.60063 .43286 L
.60179 .42914 L
.6044 .41849 L
.60912 .39264 L
.61796 .33647 L
.62037 .32358 L
.62266 .31391 L
.62392 .30991 L
.62458 .30824 L
.62529 .30681 L
.62654 .30525 L
.62769 .30496 L
Mistroke
.62877 .30574 L
.62992 .30779 L
.63102 .31092 L
.63202 .31484 L
.63313 .32041 L
.63434 .32798 L
.63679 .34808 L
.6395 .37794 L
.64196 .41179 L
.64749 .5087 L
.65223 .60981 L
Mfstroke
.65223 .60981 m
.65259 .61803 L
s
.65887 .61803 m
.65979 .0286 L
.66099 .05665 L
.6623 .08679 L
.66744 .19744 L
.67227 .28521 L
.67664 .34675 L
.67934 .37532 L
.68187 .3956 L
.68326 .40409 L
.68454 .41028 L
.68595 .41537 L
.68666 .41729 L
.68743 .4189 L
.68874 .42054 L
.68994 .42092 L
.6906 .42069 L
.69131 .42012 L
.69261 .41826 L
.69383 .41566 L
.69512 .41208 L
.69744 .40391 L
.70684 .3602 L
.70932 .34906 L
.71202 .33833 L
.71461 .3299 L
.71696 .32402 L
.71819 .32163 L
.71935 .31983 L
.72058 .31841 L
.72127 .31781 L
.72191 .31739 L
.72297 .31697 L
.72414 .31687 L
.72537 .31717 L
.72651 .31779 L
.72764 .31869 L
.72871 .3198 L
.73073 .3224 L
.73525 .32995 L
.74022 .33879 L
.74266 .34254 L
.74489 .34535 L
.74601 .34648 L
.74723 .34749 L
.74847 .34824 L
.74976 .34873 L
.75047 .34887 L
.75111 .34892 L
.75185 .34888 L
Mistroke
.75255 .34875 L
.75379 .3483 L
.75449 .34792 L
.75514 .3475 L
.75734 .34554 L
.7594 .34304 L
.76408 .3355 L
.77356 .31744 L
.77853 .30952 L
.78134 .30614 L
.78268 .30485 L
.78395 .30382 L
.78516 .30302 L
.78646 .30235 L
.78764 .3019 L
.78873 .30162 L
.78991 .30146 L
.79121 .30143 L
.79186 .30146 L
.79256 .30155 L
.79382 .30178 L
.79506 .30211 L
.79621 .30248 L
.7988 .3035 L
.80352 .30549 L
.80573 .30626 L
.80681 .30656 L
.80781 .30677 L
.80885 .30694 L
.80997 .30703 L
.81113 .30704 L
.81235 .30693 L
.81359 .30671 L
.81429 .30652 L
.81493 .30632 L
.81736 .30524 L
.81957 .30385 L
.82191 .30199 L
.83212 .29067 L
.83705 .28472 L
.84172 .27972 L
.84592 .27611 L
.84832 .27448 L
.85049 .27329 L
.85287 .27226 L
.85408 .27185 L
.8554 .27147 L
.85774 .27095 L
.85994 .2706 L
.86488 .27007 L
Mistroke
.86757 .26976 L
.87009 .26937 L
.87229 .2689 L
.87464 .26823 L
.87726 .26724 L
.87964 .26612 L
.88841 .26021 L
.92833 .234 L
.96674 .21233 L
.97619 .20678 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4
ooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?oo
ooooA?ooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`3Jooooo`008_oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo0=[ooooo000Rooooo`03o`000?oooooo
oooo06Kooooo00?o0000ooooooooool0f_ooool002;ooooo0_l0001Wooooo`03o`000?oooooooooo
0=[ooooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool0L?ooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo073ooooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0L?ooool002;ooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo073ooooo000Rooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0Ioooool2o`00077ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool0Ioooool2o`00077ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo06Oooooo0_l0001aooooo`001Ol00002ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`?o0000I_ooool00ol0003ooooo
ooooo`1Wooooo`;o0000LOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`;o0000
LOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`;o0000LOooool000Oooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
I_ooool00ol0003oooooooooo`1Wooooo`;o0000LOooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`1Wooooo`;o0000LOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEE
EOmVIVKo000000Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`;o0000
LOooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Wooooo`;o0000LOoo
ool002;ooooo00?o0000ooooooooool0IOooool2o`0006Wooooo0_l0001aooooo`008_ooool00ol0
003oooooooooo`1Uooooo`;o0000JOooool2o`00077ooooo000Rooooo`03o`000?oooooooooo06Go
oooo0_l0001Yooooo`;o0000LOooool002;ooooo0_l0001Vooooo`;o0000JOooool2o`00077ooooo
000Rooooo`03o`000?oooooooooo06Gooooo0_l0001Yooooo`;o0000LOooool002;ooooo00?o0000
ooooooooool0IOooool2o`0006Wooooo0_l0001aooooo`008_ooool00ol0003oooooooooo`1Uoooo
o`;o0000JOooool2o`00077ooooo000Rooooo`03o`000?oooooooooo06Gooooo0_l0001Yooooo`;o
0000LOooool002;ooooo00?o0000ooooooooool0IOooool2o`0006Wooooo0_l0001aooooo`008_oo
ool00ol0003oooooooooo`1Uooooo`;o0000JOooool2o`00077ooooo000Rooooo`03o`000?oooooo
oooo06Gooooo0_l0001Yooooo`;o0000LOooool002;ooooo00?o0000ooooooooool0IOooool2o`00
06Wooooo0_l0001aooooo`008_ooool00ol0003oooooooooo`1Uooooo`;o0000JOooool2o`00077o
oooo000Rooooo`03o`000?oooooooooo06Gooooo0_l0001Yooooo`;o0000LOooool002;ooooo0_l0
001Vooooo`;o0000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0003oooooooooo`1U
ooooo`;o0000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0003oooooooooo`1Uoooo
o`;o0000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0003oooooooooo`1Uooooo`;o
0000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooo000006Wooooo00?o0000ooooool00000L?ooool002;ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooo`00001Yooooo`03o`000?oooooo0000073ooooo000Rooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooool00000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooo000006Wooooo00?o0000ooooool00000L?ooool002;o
oooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00001Yooooo`03o`000?oooooo0000073o
oooo000Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool00000JOooool00ol0003ooooo
o`00001`ooooo`008_ooool2o`0006Gooooo00?o0000ooooool00000JOooool00ol0003oooooo`00
001`ooooo`008_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000006Wooooo00?o0000
ooooool00000L?ooool002;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00001Yoooo
o`03o`000?oooooo0000073ooooo000Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool0
0000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooo000006Wooooo00?o0000ooooool00000L?ooool002;ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooo`00001Yooooo`03o`000?oooooo0000073ooooo000Rooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooool00000JOooool00ol0003oooooo`00001`ooooo`008_ooool00ol0
003oooooooooo`0aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000N
ooooo`03o`000?oooooo000000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_oo
ool2o`000003oa0@4?oooooooooo02Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00_ooooo00?o0000ooooool000007?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=?ooool4
o`000003oa0@4?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo037ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo00?o
0000ooooool000002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGo
MgMgoooooonHV9So8B4Q00_ooooo00?o0000ooooool000007?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40=_ooool00ol0003ooooooooo
o`06ooooo`008_ooool00ol0003oooooooooo`0aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP0Oooooo`03o`000?oooooo000000Wooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go0000:oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04o`000?ooooooooooo`0001_ooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`06ooooo`008_oo
ool2o`0003;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01kooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo0000;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@0;ooooo`04o`000?ooooooooooo`0001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S80=_ooool00ol0003oooooooooo`06ooooo`008_ooool00ol0003o
ooooooooo`0aooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Moooo
o`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0002cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`02oooool01?l0003oooooooooool0000Kooooo`05o`000?ooooooooooooooool000002oooool0
1Oo<c<co0000o`000?l0003oc<c<03Kooooo00?o0000ooooooooool01_ooool002;ooooo00?o0000
ooooooooool0<Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooo`000009ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000/ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0=ooooo`04
o`000?ooooooooooo`0001_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[o
oooookZj^_l@4100=_ooool00ol0003oooooooooo`06ooooo`008_ooool00ol0003oooooooooo`0a
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01kooooo
00?o0000ooooool000002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
0000;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P03Oooool01?l0
003oooooooooool0000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonj^[[o000003Kooooo00?o0000ooooooooool01_ooool002;ooooo00?o0000ooooooooool0<Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Nooooo`03
o`000?oooooo000000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
02_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40_ooooo00Co
0000oooooooooooo00006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@0dooooo`03oeEEEOmVIVKo000000Sooooo000Rooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooool00000JOooool01?l0003oooooooooool0001_ooooo`008_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooo000006Wooooo00Co0000oooooooooooo0000Koooool002;o
oooo00?o0000ooooooooool0I?ooool00ol0003oooooo`00001Yooooo`04o`000?ooooooooooo`00
06oooooo000Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool00000JOooool01?l0003o
ooooooooool0001_ooooo`008_ooool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`00
06Wooooo00Co0000oooooooooooo0000Koooool001[oooooool0001?o`0000008_ooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool01oooool002;ooooo00?o0000oooo
ooooool00_l0000jooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00005?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo00009_oo
ool00ol0003oooooooooo`0hooooo`;o00000oooool00ol0003oooooooooo`06ooooo`008_ooool0
0ol0003oooooooooo`02ooooo`;o0000Goooool01?l0003oooooooooool0001Yooooo`04o`000?oo
ooooooooo`0005oooooo0_l0000>ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05cooooo00Co0000oooooooooooo0000JOooool01?l0003oooooooooool0001Nooooo`03
o`000?oooooooooo00kooooo000Rooooo`03o`000?oooooooooo00Gooooo0_l0001Looooo`04o`00
0?ooooooooooo`0006Wooooo00Co0000oooooooooooo0000G?ooool2o`00017ooooo000Rooooo`03
o`000?oooooooooo00Oooooo0_l0001Jooooo`04o`000?ooooooooooo`0006Wooooo00Co0000oooo
oooooooo0000F_ooool2o`0001?ooooo000Rooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Eoooool01?l0003oooooooooool0001Yooooo`04o`000?ooooooooooo`0005Wooooo00?o
0000ooooooooool04oooool002;ooooo00?o0000ooooooooool02_ooool2o`0005Oooooo00Co0000
oooooooooooo0000JOooool01?l0003oooooooooool0001Gooooo`;o00005_ooool002;ooooo00?o
0000ooooooooool03?ooool2o`0005Gooooo00Co0000oooooooooooo0000JOooool01?l0003ooooo
ooooool0001Eooooo`;o00006?ooool002;ooooo0_l0000?ooooo`03o`000?oooooooooo05;ooooo
00Co0000oooooooooooo0000JOooool01?l0003oooooooooool0001Dooooo`03o`000?oooooooooo
01Sooooo000Rooooo`03o`000?oooooooooo00oooooo0_l0001Booooo`04o`000?ooooooooooo`00
06Wooooo00Co0000oooooooooooo0000D_ooool2o`0001_ooooo000Rooooo`03o`000?oooooooooo
017ooooo0_l0001@ooooo`04o`000?ooooooooooo`0006Wooooo00Go0000ooooooooooooooooo`00
001@ooooo`03o`000?oooooooooo01_ooooo000Rooooo`03o`000?oooooooooo01?ooooo0_l0001>
ooooo`04o`000?ooooooooooo`0006Wooooo00Go0000ooooooooooooooooo`00001>ooooo`;o0000
7_ooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1;ooooo`04o`000?oo
ooooooooo`0006Wooooo00Go0000ooooooooooooooooo`00001<ooooo`;o00008?ooool002;ooooo
00?o0000ooooooooool05_ooool2o`0004_ooooo00Co0000oooooooooooo0000JOooool01Ol0003o
oooooooooooooooo000004_ooooo00?o0000ooooooooool08?ooool002;ooooo00?o0000oooooooo
ool06?ooool2o`0004Wooooo00Co0000oooooooooooo0000JOooool01Ol0003ooooooooooooooooo
000004Wooooo0_l0000Sooooo`008_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04Kooooo00Co0000oooooooooooo0000JOooool01Ol0003ooooooooooooooooo000004Sooooo00?o
0000ooooooooool08oooool002;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`15
ooooo`04o`000?ooooooooooo`0006Wooooo00Go0000ooooooooooooooooo`000016ooooo`;o0000
9_ooool002;ooooo00?o0000ooooooooool07?ooool2o`0004Gooooo00Co0000oooooooooooo0000
JOooool01Ol0003ooooooooooooooooo000004Gooooo00?o0000ooooooooool09_ooool002;ooooo
0_l0000Nooooo`?o0000@_ooool01Ol0003ooooooooooooooooo000006Wooooo00Go0000oooooooo
ooooooooo`000012ooooo`?o0000:Oooool002;ooooo00?o0000ooooooooool08?ooool6o`0003co
oooo00Go0000ooooooooooooooooo`00001Yooooo`05o`000?ooooooooooooooool00000??ooool6
o`0002cooooo000Rooooo`03o`000?oooooooooo02Kooooo0_l0000jooooo`05o`000?oooooooooo
ooooool00000JOooool01Ol0003ooooooooooooooooo000003[ooooo0ol0000aooooo`008_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`00
001Yooooo`05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0booooo`008_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo00Go0000oooooooooooooooo
o`00001Yooooo`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`0cooooo`00
8_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo00Go0000oooooooooooo
ooooo`00001Yooooo`05o`000?ooooooooooooooool00000=oooool00ol0003oooooooooo`0doooo
o`008_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Cooooo00Go0000oooooooo
ooooooooo`00001Yooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`0e
ooooo`008_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03?ooooo00Go0000oooo
ooooooooooooo`00001Yooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003ooooooooo
o`0eooooo`008_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo03;ooooo00Go0000
ooooooooooooooooo`00001Yooooo`05o`000?ooooooooooooooool00000=?ooool2o`0003Sooooo
000Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooooo
oooooooo000006Wooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo03So
oooo000Rooooo`;o0000<?ooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool0
0000JOooool01Ol0003ooooooooooooooooo000003;ooooo00?o0000ooooooooool0>Oooool002;o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`?o00009Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00000Voooo
o`?o00002?ooool00ol0003oooooooooo`0jooooo`008_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00?ooooo0ol00002ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo0_l00002ooooo`?o
00001Oooool00ol0003oooooooooo`0kooooo`008_ooool00ol0003oooooooooo`0booooo`Go0000
1_ooool2o`0002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`?o0000
D_ooool2o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Cooooo1_l0000mooooo`008_ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooo0000057ooooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`18ooooo`008_ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo0000057ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0B?ooool002;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0=ooooo`;o00003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000DOooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool2o`00013ooooo
00?o0000ooooooooool0BOooool002;ooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0<ooooo`Co00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`00001@ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`Co00003_ooool00ol0003oooooooooo`1:ooooo`00
8_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_l0000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000004oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool0B_ooool002;ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00001?ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04_ooooo000R
ooooo`;o0000@_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04_ooooo000Roooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1<oooo
o`008_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0C?ooool002;ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo04gooooo000Rooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1>ooooo`008_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Coooool002;ooooo00?o0000ooooooooool0AOooool2o`00
00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool00000DOooool002;ooooo00?o0000ooooooooool0A_ooool4o`0000_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool4o`0005;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo05Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Goooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Goooool000Oo
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo0ol0001Foooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo063ooooo0007ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02Oooooo0_l0000?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0H?ooool000Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo0_l000000ooooooo0000ooooo`0Vooooo`Co00003_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo063ooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o00009Oooool2o`00
00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
063ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<oooo
o`05o`000?ooooooooooooooool000009Oooool01Ol0003ooooooooooooooooo000000gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`1Gooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00kooooo0ol0000Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo067ooooo000Rooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo067ooooo000Rooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool002;ooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Qooooo`008_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06;ooooo000Rooooo`;o0000FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`008_ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06;ooooo000Rooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0H_ooool002;ooooo00?o0000ooooooooool0FOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Rooooo`008_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo000Roooo
o`03o`000?oooooooooo05[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0Hoooool002;ooooo00?o0000ooooooooool0F_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1S
ooooo`008_ooool00ol0003oooooooooo`1Jooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool0001Vooooo`008_ooool00ol0003oooooooooo`1Jooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool0001Vooooo`008_ooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000I_ooool002;ooooo0_l0
001Looooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000Ioooool002;ooooo00?o0000
ooooooooool0Foooool3o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo0_l0001Wooooo`008_ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1`oooo
o`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1`ooooo`008_oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo0000
4Oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo073ooooo000Rooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`04o`00
0?ooooooooooo`00017ooooo1?l0000Aooooo`Co00004Oooool01?l0003oooooooooool0000=oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool002;ooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo0_l000000ooooooo
0000ooooo`0jooooo`;o000000?oooooo`000?ooool03Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo073ooooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0=ooooo`;o0000?Oooool2o`0000oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo073ooooo000Rooooo`;o0000Ioooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`008_ooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo000Rooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0L?ooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo000R
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0L?ooool002;ooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo073ooooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
L?ooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`008_ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo073ooooo000Rooooo`;o0000Ioooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1`ooooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo073o
oooo000Rooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00001Qooooo`05
o`000?ooooooooooooooool00000L_ooool002;ooooo00?o0000ooooooooool0I_ooool01Ol0003o
oooooooooooooooo0000067ooooo00Go0000ooooooooooooooooo`00001booooo`008_ooool00ol0
003oooooooooo`1Vooooo`05o`000?ooooooooooooooool00000HOooool01Ol0003ooooooooooooo
oooo000007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo00Go0000ooooooooooooooooo`00
001Qooooo`05o`000?ooooooooooooooool00000L_ooool002;ooooo00?o0000ooooooooool0I_oo
ool01Ol0003ooooooooooooooooo0000067ooooo00Go0000ooooooooooooooooo`00001booooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003o
ooooooooo`1Vooooo`05o`000?ooooooooooooooool00000HOooool01Ol0003ooooooooooooooooo
000007;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo06Kooooo00Go0000oooooooooooooooo
o`00001Qooooo`05o`000?ooooooooooooooool00000L_ooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0I_ooool01Ol0003o
oooooooooooooooo0000067ooooo00Go0000ooooooooooooooooo`00001booooo`001oooool01Ol0
003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0006Kooooo00Go0000
ooooooooooooooooo`00001Qooooo`05o`000?ooooooooooooooool00000L_ooool000Oooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
I_ooool01Ol0003ooooooooooooooooo0000067ooooo00Go0000ooooooooooooooooo`00001boooo
o`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Vooooo`05o`000?ooooooooooooooool00000HOooool01Ol0003ooooooooooooo
oooo000007;ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo0000067o
oooo00Go0000ooooooooooooooooo`00001booooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Kooooo00Go0000
ooooooooooooooooo`00001Qooooo`05o`000?ooooooooooooooool00000L_ooool002;ooooo00?o
0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo0000067ooooo00Go0000oooooooooooo
ooooo`00001booooo`008_ooool00ol0003oooooooooo`1Vooooo`05o`000?ooooooooooooooool0
0000HOooool01Ol0003ooooooooooooooooo000007;ooooo000Rooooo`03o`000?oooooooooo06Ko
oooo00Go0000ooooooooooooooooo`00001Qooooo`05o`000?ooooooooooooooool00000L_ooool0
02;ooooo00?o0000ooooooooool0I_ooool01Ol0003ooooooooooooooooo000006;ooooo00Co0000
oooooooooooo0000L_ooool002;ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool0
001Sooooo`04o`000?ooooooooooo`0007;ooooo000Rooooo`;o0000Ioooool01?l0003ooooooooo
ool0001Sooooo`04o`000?ooooooooooo`0007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo
00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool0001booooo`008_ooool00ol0003o
ooooooooo`1Vooooo`04o`000?ooooooooooo`0006?ooooo00Co0000oooooooooooo0000L_ooool0
02;ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool0001Sooooo`04o`000?oooooo
ooooo`0007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000Hooo
ool01?l0003oooooooooool0001booooo`008_ooool00ol0003oooooooooo`1Vooooo`04o`000?oo
ooooooooo`0006?ooooo00Co0000oooooooooooo0000L_ooool002;ooooo00?o0000ooooooooool0
I_ooool01?l0003oooooooooool0001Sooooo`04o`000?ooooooooooo`0007;ooooo000Rooooo`03
o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool0001b
ooooo`008_ooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0006?ooooo00Co0000
oooooooooooo0000L_ooool002;ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool0
001Sooooo`04o`000?ooooooooooo`0007;ooooo000Rooooo`;o0000Ioooool01?l0003ooooooooo
ool0001Sooooo`04o`000?ooooooooooo`0007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo
00Co0000oooooooooooo0000Hoooool01?l0003oooooooooool0001booooo`008_ooool00ol0003o
ooooooooo`1Vooooo`04o`000?ooooooooooo`0006?ooooo00Co0000oooooooooooo0000L_ooool0
02;ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool0001Sooooo`04o`000?oooooo
ooooo`0007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo0000Hooo
ool01?l0003oooooooooool0001booooo`008_ooool00ol0003oooooooooo`1Vooooo`04o`000?oo
ooooooooo`0006Cooooo00?o0000ooooool00000L_ooool002;ooooo00?o0000ooooooooool0I_oo
ool01?l0003oooooooooool0001Tooooo`03o`000?oooooo000007;ooooo000Rooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooool00000IOooool00ol0003oooooo`00001booooo`008_ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooo000006Gooooo00?o0000ooooool00000L_ooool0
02;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00001Uooooo`03o`000?oooooo0000
07;ooooo000Rooooo`;o0000Ioooool00ol0003oooooo`00001Uooooo`03o`000?oooooo000007;o
oooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000IOooool00ol0003ooooo
o`00001booooo`008_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000006Gooooo00?o
0000ooooool00000L_ooool002;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00001U
ooooo`03o`000?oooooo000007;ooooo000Rooooo`03o`000?oooooooooo06Kooooo00?o0000oooo
ool00000IOooool00ol0003oooooo`00001booooo`008_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooo000006Gooooo00?o0000ooooool00000L_ooool002;ooooo00?o0000ooooooooool0
I_ooool00ol0003oooooo`00001Uooooo`03o`000?oooooo000007;ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.107792, -0.152003, \
0.00394428, 0.00247832}}]
}, Open  ]],

Cell[TextData[{
  "This is not a very good solution.  One can see that the solution is \
\"trying\" to be smooth, but the discontinuities in ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  "are creating problems. [A better choice for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " can be found in Exercise (6) at the end of the section.]"
}], "Text"],

Cell[TextData[{
  "\tLet's now compare this solution with the direct solution of Laplace's \
equation for this problem, as given by Eq. ",
  ButtonBox["(3.2.10)",
    ButtonData:>{"Chapter3.nb", "(3.2.10)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi](x, 
        y) = \[Sum]\+n\( A\_n\) \(sinh(
            n\ \[Pi]\ x/b)\)\ sin\ \(\((n\ \[Pi]\ y/b)\)\(.\)\)\)]]], "NE4",
  CellTags->"(4.3.31)"],

Cell[TextData[{
  "We can already observe one striking difference between Eqs. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ". The eigenmode expansion, Eq. ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ", involves two sums, one over linearly-independent eigenmodes in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and the other over independent modes in ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". However,  the direct solution of Laplace's equation, Eq. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  ", involves only one sum.  This is because in the direct solution,  the ",
  Cell[BoxData[
      \(TraditionalForm\`sin(n\ \[Pi]\ y/b\ )\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`sinh\ \((n\ \[Pi]\ x/b)\)\)]],
  " functions  are ",
  "not independent",
  "; they are connected by the fact that the product of this pair of \
functions directly satisfies Laplace's equation.  "
}], "Text"],

Cell[TextData[{
  "\tAlthough Eqs. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  " are formally identical, the fact that one fewer sum is required in Eq. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  " is often a great practical advantage."
}], "Text"],

Cell["\<\
\tFurthermore, for rapidly varying  boundary conditions, we have \
seen that the eigenmode expansion does not converge well. We will now see \
that the direct solution works nicely. \
\>", "Text"],

Cell[TextData[{
  "\tThe Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " in Eq. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  " are given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[{
      \(TraditionalForm\`A\_n\ sinh\ \((n\ \[Pi]\ a/
                b)\) = \(2\/b\) \(\[Integral]\_0\%b \[Phi]\_o\ \(h(
                y - b/3)\) \(h(\ 2  b/3 - y)\) \(sin(
                n\ \[Pi]\ y/b)\) \[DifferentialD]y\)\), 
    "\[IndentingNewLine]", 
      \(TraditionalForm\`\t\t\ \ \ \ \(\(=\)\(\(2\/b\) \(\[Phi]\_o\) \(\
\[Integral]\_\(b/3\)\%\(2  b/3\)\(sin(
                n\ \[Pi]\ y/b)\) \[DifferentialD]y\)\)\)\)}]],
  "."
}], "NE4",
  CellTags->"(4.3.32)"],

Cell[TextData[{
  "\tIn Cell ",
  ButtonBox["4.25",
    ButtonData:>"Cell 4.25",
    ButtonStyle->"Hyperlink"],
  ", we evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and calculate the direct solution for the potential, again taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 30\)]],
  " (this involves a sum of 30 terms, as opposed to the 900 terms in the sums \
for the previous eigenmode method)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a = \(b = \(\[Phi]\_o = 1\)\);\)\), "\n", 
    \(\(\(M = 30;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(A[
          n_]\  = \ \ Simplify[
            2/b\ \ \(\[Phi]\_o\) 
              Integrate[Sin[n\ Pi\ y/b], {y, b/3, 2  b/3}], 
            n \[Element] Integers]/Sinh[n\ Pi\ a/b];\)\), "\n", 
    \(\(\[Phi][x_, 
          y_] = \[Sum]\+\(n = 1\)\%M A[n]\ Sinh[n\ Pi\ x/b]\ Sin[
              n\ Pi\ y/b];\)\), "\n", 
    \(\(Plot3D[\[Phi][x, y], {x, 0, a}, {y, 0, b}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\>"}, 
        PlotLabel \[Rule] "\<\[Phi] in a square enclosure\>", 
        PlotRange \[Rule] All, \ PlotPoints \[Rule] 30];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.25"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1978e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -71 0 ]
[.5 .82364 71 12 ]
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.14598 .19958 -17.886 -9 ]
[.14598 .19958 .11404 0 ]
[.27013 .15073 -17.1354 -9 ]
[.27013 .15073 .86461 0 ]
[.40046 .09948 -16.3848 -9 ]
[.40046 .09948 1.61518 0 ]
[.53743 .04564 -15.6342 -9 ]
[.53743 .04564 2.36575 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.29165 .07573 -9.31117 -12 ]
[.29165 .07573 .68883 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 18 2.83813 ]
[.82812 .18993 0 -6.07246 ]
[.82812 .18993 18 2.92754 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.93478 .35327 0 -5.9197 ]
[.93478 .35327 18 3.0803 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.91861 .21225 0 -8.04169 ]
[.91861 .21225 10 3.95831 ]
[.02328 .27034 -6 -2.74673 ]
[.02328 .27034 0 6.25327 ]
[.01538 .31986 -24 -2.78861 ]
[.01538 .31986 0 6.21139 ]
[.00722 .37099 -18 -2.83199 ]
[.00722 .37099 0 6.16801 ]
[-0.00121 .42382 -24 -2.87696 ]
[-0.00121 .42382 0 6.12304 ]
[-0.00992 .47843 -6 -2.92361 ]
[-0.00992 .47843 0 6.07639 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -132 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
93.000 13.000 moveto
(a) show
105.000 13.000 moveto
(square) show
147.000 13.000 moveto
(enclosure) show
201.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.75514 .10158 m
.74899 .10385 L
s
[(0.2)] .76745 .09703 -1 .3693 Mshowa
.81573 .19425 m
.80953 .19642 L
s
[(0.4)] .82812 .18993 -1 .34944 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.6)] .88369 .27502 -1 .3316 Mshowa
.92227 .35722 m
.91601 .35919 L
s
[(0.8)] .93478 .35327 -1 .31549 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.7708 .12553 m
.7671 .12688 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.83006 .21617 m
.82633 .21745 L
s
.84407 .23761 m
.84035 .23888 L
s
.8578 .2586 m
.85407 .25986 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.9099 .3383 m
.90615 .3395 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
gsave
.91861 .21225 -61 -12.0417 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03551 .26557 m
.04162 .26319 L
s
[(0)] .02328 .27034 1 -0.38962 Mshowa
.02764 .31519 m
.03378 .31286 L
s
[(0.25)] .01538 .31986 1 -0.38031 Mshowa
.01952 .36643 m
.02568 .36415 L
s
[(0.5)] .00722 .37099 1 -0.37067 Mshowa
.01113 .41937 m
.01731 .41714 L
s
[(0.75)] -0.00121 .42382 1 -0.36067 Mshowa
.00246 .4741 m
.00865 .47193 L
s
[(1)] -0.00992 .47843 1 -0.35031 Mshowa
.125 Mabswid
.03395 .27537 m
.03762 .27395 L
s
.03239 .28523 m
.03606 .28381 L
s
.03082 .29515 m
.03449 .29374 L
s
.02924 .30514 m
.03291 .30374 L
s
.02604 .32531 m
.02972 .32391 L
s
.02443 .33549 m
.02811 .3341 L
s
.0228 .34574 m
.02649 .34435 L
s
.02117 .35605 m
.02486 .35467 L
s
.01787 .37688 m
.02156 .37552 L
s
.0162 .3874 m
.0199 .38604 L
s
.01452 .39798 m
.01822 .39663 L
s
.01283 .40864 m
.01653 .4073 L
s
.00942 .43017 m
.01313 .42884 L
s
.0077 .44104 m
.01141 .43972 L
s
.00597 .45198 m
.00968 .45067 L
s
.00422 .463 m
.00793 .46169 L
s
.03705 .25584 m
.04071 .2544 L
s
.00069 .48526 m
.00441 .48397 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.661 .741 .91 r
.39439 .59871 .40495 .60851 .42267 .60322 .41217 .59346 Metetra
.661 .743 .911 r
.41217 .59346 .42267 .60322 .44049 .59788 .43007 .58818 Metetra
.66 .746 .913 r
.43007 .58818 .44049 .59788 .45844 .59252 .44809 .58286 Metetra
.66 .748 .915 r
.44809 .58286 .45844 .59252 .4765 .58711 .46623 .57752 Metetra
.66 .75 .917 r
.46623 .57752 .4765 .58711 .49469 .58167 .4845 .57214 Metetra
.66 .753 .919 r
.4845 .57214 .49469 .58167 .513 .5762 .50289 .56673 Metetra
.659 .756 .921 r
.50289 .56673 .513 .5762 .53143 .57068 .5214 .56129 Metetra
.659 .758 .923 r
.5214 .56129 .53143 .57068 .54998 .56513 .54004 .55582 Metetra
.658 .761 .926 r
.54004 .55582 .54998 .56513 .56866 .55955 .55881 .55033 Metetra
.658 .765 .929 r
.55881 .55033 .56866 .55955 .58747 .55392 .57772 .54481 Metetra
.657 .768 .931 r
.57772 .54481 .58747 .55392 .60641 .54826 .59675 .53926 Metetra
.656 .772 .934 r
.59675 .53926 .60641 .54826 .62547 .54255 .61592 .53368 Metetra
.655 .776 .937 r
.61592 .53368 .62547 .54255 .64467 .53681 .63522 .52808 Metetra
.654 .78 .941 r
.63522 .52808 .64467 .53681 .66399 .53103 .65466 .52245 Metetra
.653 .785 .944 r
.65466 .52245 .66399 .53103 .68345 .52521 .67423 .51678 Metetra
.652 .789 .948 r
.67423 .51678 .68345 .52521 .70305 .51935 .69395 .51108 Metetra
.651 .794 .951 r
.69395 .51108 .70305 .51935 .72278 .51345 .7138 .50534 Metetra
.649 .799 .955 r
.7138 .50534 .72278 .51345 .74265 .5075 .7338 .49956 Metetra
.648 .804 .958 r
.7338 .49956 .74265 .5075 .76266 .50152 .75394 .49371 Metetra
.648 .809 .961 r
.75394 .49371 .76266 .50152 .78281 .49549 .77422 .48778 Metetra
.648 .813 .963 r
.77422 .48778 .78281 .49549 .8031 .48942 .79465 .48175 Metetra
.649 .817 .964 r
.79465 .48175 .8031 .48942 .82353 .48331 .81521 .4756 Metetra
.652 .818 .964 r
.81521 .4756 .82353 .48331 .84411 .47716 .83592 .4693 Metetra
.655 .818 .962 r
.83592 .4693 .84411 .47716 .86484 .47096 .85675 .46281 Metetra
.661 .815 .957 r
.85675 .46281 .86484 .47096 .88571 .46471 .87772 .45612 Metetra
.667 .808 .951 r
.87772 .45612 .88571 .46471 .90673 .45842 .89881 .4492 Metetra
.673 .797 .942 r
.89881 .4492 .90673 .45842 .92791 .45209 .92003 .44206 Metetra
.677 .783 .93 r
.92003 .44206 .92791 .45209 .94924 .44571 .94137 .43473 Metetra
.684 .768 .915 r
.94137 .43473 .94924 .44571 .97072 .43928 .96281 .42702 Metetra
.658 .741 .911 r
.38369 .58878 .39439 .59871 .41217 .59346 .40154 .58358 Metetra
.658 .743 .912 r
.40154 .58358 .41217 .59346 .43007 .58818 .41951 .57835 Metetra
.658 .745 .914 r
.41951 .57835 .43007 .58818 .44809 .58286 .43761 .57308 Metetra
.658 .747 .916 r
.43761 .57308 .44809 .58286 .46623 .57752 .45583 .56779 Metetra
.657 .75 .918 r
.45583 .56779 .46623 .57752 .4845 .57214 .47417 .56247 Metetra
.657 .752 .92 r
.47417 .56247 .4845 .57214 .50289 .56673 .49264 .55713 Metetra
.656 .755 .922 r
.49264 .55713 .50289 .56673 .5214 .56129 .51124 .55177 Metetra
.656 .757 .925 r
.51124 .55177 .5214 .56129 .54004 .55582 .52997 .54638 Metetra
.655 .76 .927 r
.52997 .54638 .54004 .55582 .55881 .55033 .54883 .54098 Metetra
.654 .763 .93 r
.54883 .54098 .55881 .55033 .57772 .54481 .56783 .53556 Metetra
.653 .767 .933 r
.56783 .53556 .57772 .54481 .59675 .53926 .58696 .53012 Metetra
.652 .77 .936 r
.58696 .53012 .59675 .53926 .61592 .53368 .60623 .52467 Metetra
.65 .774 .939 r
.60623 .52467 .61592 .53368 .63522 .52808 .62564 .51921 Metetra
.649 .778 .942 r
.62564 .51921 .63522 .52808 .65466 .52245 .64518 .51373 Metetra
.648 .783 .946 r
.64518 .51373 .65466 .52245 .67423 .51678 .66488 .50823 Metetra
.646 .787 .95 r
.66488 .50823 .67423 .51678 .69395 .51108 .68471 .5027 Metetra
.645 .792 .953 r
.68471 .5027 .69395 .51108 .7138 .50534 .70469 .49713 Metetra
.643 .798 .957 r
.70469 .49713 .7138 .50534 .7338 .49956 .72482 .49151 Metetra
.643 .803 .96 r
.72482 .49151 .7338 .49956 .75394 .49371 .7451 .48581 Metetra
.643 .808 .963 r
.7451 .48581 .75394 .49371 .77422 .48778 .76552 .48 Metetra
.644 .813 .965 r
.76552 .48 .77422 .48778 .79465 .48175 .78608 .47404 Metetra
.647 .818 .965 r
.78608 .47404 .79465 .48175 .81521 .4756 .80678 .46788 Metetra
.652 .821 .965 r
.80678 .46788 .81521 .4756 .83592 .4693 .82761 .46146 Metetra
.659 .823 .962 r
.82761 .46146 .83592 .4693 .85675 .46281 .84856 .45471 Metetra
.668 .821 .957 r
.84856 .45471 .85675 .46281 .87772 .45612 .86962 .44757 Metetra
.678 .816 .949 r
.86962 .44757 .87772 .45612 .89881 .4492 .89078 .44001 Metetra
.688 .807 .939 r
.89078 .44001 .89881 .4492 .92003 .44206 .91204 .43203 Metetra
.694 .793 .926 r
.91204 .43203 .92003 .44206 .94137 .43473 .9334 .42372 Metetra
.688 .772 .915 r
.9334 .42372 .94137 .43473 .96281 .42702 .95495 .41572 Metetra
.656 .74 .912 r
.37287 .57873 .38369 .58878 .40154 .58358 .39078 .57357 Metetra
.656 .742 .913 r
.39078 .57357 .40154 .58358 .41951 .57835 .40883 .56839 Metetra
.655 .744 .915 r
.40883 .56839 .41951 .57835 .43761 .57308 .427 .56318 Metetra
.655 .746 .917 r
.427 .56318 .43761 .57308 .45583 .56779 .44529 .55794 Metetra
.655 .749 .919 r
.44529 .55794 .45583 .56779 .47417 .56247 .46371 .55267 Metetra
.654 .751 .921 r
.46371 .55267 .47417 .56247 .49264 .55713 .48227 .5474 Metetra
.653 .753 .923 r
.48227 .5474 .49264 .55713 .51124 .55177 .50095 .5421 Metetra
.652 .756 .926 r
.50095 .5421 .51124 .55177 .52997 .54638 .51977 .5368 Metetra
.651 .759 .928 r
.51977 .5368 .52997 .54638 .54883 .54098 .53872 .53148 Metetra
.65 .762 .931 r
.53872 .53148 .54883 .54098 .56783 .53556 .55781 .52616 Metetra
.649 .765 .934 r
.55781 .52616 .56783 .53556 .58696 .53012 .57704 .52084 Metetra
.647 .768 .937 r
.57704 .52084 .58696 .53012 .60623 .52467 .59641 .51552 Metetra
.646 .772 .94 r
.59641 .51552 .60623 .52467 .62564 .51921 .61592 .51019 Metetra
.644 .776 .944 r
.61592 .51019 .62564 .51921 .64518 .51373 .63558 .50487 Metetra
.642 .78 .947 r
.63558 .50487 .64518 .51373 .66488 .50823 .65539 .49953 Metetra
.64 .785 .951 r
.65539 .49953 .66488 .50823 .68471 .5027 .67534 .49418 Metetra
.638 .79 .955 r
.67534 .49418 .68471 .5027 .70469 .49713 .69545 .4888 Metetra
.637 .796 .959 r
.69545 .4888 .70469 .49713 .72482 .49151 .71571 .48337 Metetra
.636 .802 .962 r
.71571 .48337 .72482 .49151 .7451 .48581 .73612 .47785 Metetra
.636 .808 .965 r
.73612 .47785 .7451 .48581 .76552 .48 .75668 .47221 Metetra
.638 .814 .967 r
.75668 .47221 .76552 .48 .78608 .47404 .77738 .46637 Metetra
.642 .82 .968 r
.77738 .46637 .78608 .47404 .80678 .46788 .79823 .46026 Metetra
.649 .826 .968 r
.79823 .46026 .80678 .46788 .82761 .46146 .81919 .45378 Metetra
.66 .83 .965 r
.81919 .45378 .82761 .46146 .84856 .45471 .84027 .44683 Metetra
.674 .831 .959 r
.84027 .44683 .84856 .45471 .86962 .44757 .86144 .43928 Metetra
.689 .829 .95 r
.86144 .43928 .86962 .44757 .89078 .44001 .88268 .43106 Metetra
.703 .82 .938 r
.88268 .43106 .89078 .44001 .91204 .43203 .90398 .42216 Metetra
.714 .806 .922 r
.90398 .42216 .91204 .43203 .9334 .42372 .92534 .41265 Metetra
.731 .789 .899 r
.92534 .41265 .9334 .42372 .95495 .41572 .94667 .40194 Metetra
.654 .739 .913 r
.3619 .56855 .37287 .57873 .39078 .57357 .37989 .56344 Metetra
.653 .741 .914 r
.37989 .56344 .39078 .57357 .40883 .56839 .39801 .5583 Metetra
.653 .743 .916 r
.39801 .5583 .40883 .56839 .427 .56318 .41625 .55313 Metetra
.653 .746 .918 r
.41625 .55313 .427 .56318 .44529 .55794 .43462 .54794 Metetra
.652 .748 .92 r
.43462 .54794 .44529 .55794 .46371 .55267 .45312 .54273 Metetra
.651 .75 .922 r
.45312 .54273 .46371 .55267 .48227 .5474 .47175 .53751 Metetra
.65 .752 .924 r
.47175 .53751 .48227 .5474 .50095 .5421 .49052 .53228 Metetra
.649 .755 .926 r
.49052 .53228 .50095 .5421 .51977 .5368 .50943 .52705 Metetra
.648 .757 .929 r
.50943 .52705 .51977 .5368 .53872 .53148 .52847 .52182 Metetra
.646 .76 .932 r
.52847 .52182 .53872 .53148 .55781 .52616 .54765 .5166 Metetra
.645 .763 .935 r
.54765 .5166 .55781 .52616 .57704 .52084 .56698 .51139 Metetra
.643 .766 .938 r
.56698 .51139 .57704 .52084 .59641 .51552 .58645 .50619 Metetra
.641 .77 .941 r
.58645 .50619 .59641 .51552 .61592 .51019 .60606 .50101 Metetra
.638 .774 .945 r
.60606 .50101 .61592 .51019 .63558 .50487 .62583 .49584 Metetra
.636 .778 .949 r
.62583 .49584 .63558 .50487 .65539 .49953 .64576 .49069 Metetra
.634 .783 .953 r
.64576 .49069 .65539 .49953 .67534 .49418 .66583 .48553 Metetra
.631 .788 .957 r
.66583 .48553 .67534 .49418 .69545 .4888 .68607 .48036 Metetra
.629 .793 .961 r
.68607 .48036 .69545 .4888 .71571 .48337 .70646 .47515 Metetra
.628 .8 .965 r
.70646 .47515 .71571 .48337 .73612 .47785 .72701 .46986 Metetra
.628 .807 .969 r
.72701 .46986 .73612 .47785 .75668 .47221 .74772 .46444 Metetra
.629 .814 .971 r
.74772 .46444 .75668 .47221 .77738 .46637 .76857 .4588 Metetra
.634 .823 .973 r
.76857 .4588 .77738 .46637 .79823 .46026 .78956 .45284 Metetra
.643 .831 .973 r
.78956 .45284 .79823 .46026 .81919 .45378 .81068 .44642 Metetra
.657 .839 .97 r
.81068 .44642 .81919 .45378 .84027 .44683 .8319 .43936 Metetra
.676 .845 .964 r
.8319 .43936 .84027 .44683 .86144 .43928 .85319 .43149 Metetra
.698 .846 .954 r
.85319 .43149 .86144 .43928 .88268 .43106 .87451 .42262 Metetra
.72 .84 .939 r
.87451 .42262 .88268 .43106 .90398 .42216 .89586 .41269 Metetra
.735 .824 .92 r
.89586 .41269 .90398 .42216 .92534 .41265 .91721 .40185 Metetra
.723 .795 .909 r
.91721 .40185 .92534 .41265 .94667 .40194 .93875 .3916 Metetra
.651 .739 .914 r
.35081 .55825 .3619 .56855 .37989 .56344 .36886 .55317 Metetra
.651 .741 .915 r
.36886 .55317 .37989 .56344 .39801 .5583 .38705 .54807 Metetra
.651 .743 .917 r
.38705 .54807 .39801 .5583 .41625 .55313 .40536 .54294 Metetra
.65 .745 .919 r
.40536 .54294 .41625 .55313 .43462 .54794 .42381 .53779 Metetra
.649 .747 .921 r
.42381 .53779 .43462 .54794 .45312 .54273 .44239 .53263 Metetra
.648 .749 .923 r
.44239 .53263 .45312 .54273 .47175 .53751 .4611 .52746 Metetra
.647 .751 .925 r
.4611 .52746 .47175 .53751 .49052 .53228 .47996 .52229 Metetra
.646 .753 .927 r
.47996 .52229 .49052 .53228 .50943 .52705 .49895 .51713 Metetra
.644 .755 .93 r
.49895 .51713 .50943 .52705 .52847 .52182 .51808 .51198 Metetra
.643 .758 .932 r
.51808 .51198 .52847 .52182 .54765 .5166 .53735 .50686 Metetra
.641 .761 .935 r
.53735 .50686 .54765 .5166 .56698 .51139 .55677 .50175 Metetra
.638 .764 .939 r
.55677 .50175 .56698 .51139 .58645 .50619 .57634 .49668 Metetra
.636 .767 .942 r
.57634 .49668 .58645 .50619 .60606 .50101 .59607 .49164 Metetra
.633 .771 .946 r
.59607 .49164 .60606 .50101 .62583 .49584 .61595 .48664 Metetra
.63 .775 .95 r
.61595 .48664 .62583 .49584 .64576 .49069 .63598 .48167 Metetra
.627 .779 .954 r
.63598 .48167 .64576 .49069 .66583 .48553 .65618 .47672 Metetra
.623 .784 .959 r
.65618 .47672 .66583 .48553 .68607 .48036 .67654 .47179 Metetra
.62 .79 .963 r
.67654 .47179 .68607 .48036 .70646 .47515 .69707 .46684 Metetra
.618 .797 .968 r
.69707 .46684 .70646 .47515 .72701 .46986 .71776 .46183 Metetra
.616 .805 .972 r
.71776 .46183 .72701 .46986 .74772 .46444 .73862 .45671 Metetra
.617 .814 .976 r
.73862 .45671 .74772 .46444 .76857 .4588 .75963 .45138 Metetra
.621 .825 .979 r
.75963 .45138 .76857 .4588 .78956 .45284 .78079 .44571 Metetra
.63 .837 .98 r
.78079 .44571 .78956 .45284 .81068 .44642 .80208 .43952 Metetra
.646 .85 .978 r
.80208 .43952 .81068 .44642 .8319 .43936 .82346 .43256 Metetra
.671 .862 .972 r
.82346 .43256 .8319 .43936 .85319 .43149 .8449 .42452 Metetra
.703 .87 .96 r
.8449 .42452 .85319 .43149 .87451 .42262 .86633 .41509 Metetra
.737 .869 .942 r
.86633 .41509 .87451 .42262 .89586 .41269 .88771 .40402 Metetra
.765 .852 .916 r
.88771 .40402 .89586 .41269 .91721 .40185 .90901 .39133 Metetra
.793 .824 .876 r
.90901 .39133 .91721 .40185 .93875 .3916 .93006 .376 Metetra
.649 .738 .914 r
.33957 .54782 .35081 .55825 .36886 .55317 .35769 .54277 Metetra
.649 .74 .916 r
.35769 .54277 .36886 .55317 .38705 .54807 .37595 .53769 Metetra
.649 .742 .918 r
.37595 .53769 .38705 .54807 .40536 .54294 .39434 .5326 Metetra
.648 .744 .919 r
.39434 .5326 .40536 .54294 .42381 .53779 .41286 .52748 Metetra
.647 .745 .921 r
.41286 .52748 .42381 .53779 .44239 .53263 .43152 .52236 Metetra
.646 .747 .923 r
.43152 .52236 .44239 .53263 .4611 .52746 .45031 .51724 Metetra
.645 .749 .925 r
.45031 .51724 .4611 .52746 .47996 .52229 .46925 .51213 Metetra
.643 .751 .928 r
.46925 .51213 .47996 .52229 .49895 .51713 .48832 .50703 Metetra
.641 .753 .93 r
.48832 .50703 .49895 .51713 .51808 .51198 .50754 .50196 Metetra
.639 .756 .933 r
.50754 .50196 .51808 .51198 .53735 .50686 .52691 .49692 Metetra
.637 .758 .936 r
.52691 .49692 .53735 .50686 .55677 .50175 .54643 .49192 Metetra
.634 .761 .939 r
.54643 .49192 .55677 .50175 .57634 .49668 .5661 .48696 Metetra
.631 .764 .943 r
.5661 .48696 .57634 .49668 .59607 .49164 .58592 .48207 Metetra
.627 .767 .947 r
.58592 .48207 .59607 .49164 .61595 .48664 .60591 .47723 Metetra
.624 .771 .951 r
.60591 .47723 .61595 .48664 .63598 .48167 .62606 .47245 Metetra
.619 .775 .955 r
.62606 .47245 .63598 .48167 .65618 .47672 .64638 .46773 Metetra
.615 .78 .96 r
.64638 .46773 .65618 .47672 .67654 .47179 .66687 .46306 Metetra
.61 .786 .965 r
.66687 .46306 .67654 .47179 .69707 .46684 .68754 .45841 Metetra
.606 .793 .971 r
.68754 .45841 .69707 .46684 .71776 .46183 .70837 .45375 Metetra
.602 .802 .976 r
.70837 .45375 .71776 .46183 .73862 .45671 .72939 .44903 Metetra
.6 .812 .981 r
.72939 .44903 .73862 .45671 .75963 .45138 .75057 .44413 Metetra
.601 .824 .985 r
.75057 .44413 .75963 .45138 .78079 .44571 .77191 .43894 Metetra
.608 .84 .988 r
.77191 .43894 .78079 .44571 .80208 .43952 .79339 .43321 Metetra
.623 .858 .987 r
.79339 .43321 .80208 .43952 .82346 .43256 .81497 .42665 Metetra
.652 .88 .982 r
.81497 .42665 .82346 .43256 .8449 .42452 .8366 .41881 Metetra
.696 .9 .97 r
.8366 .41881 .8449 .42452 .86633 .41509 .85818 .40908 Metetra
.752 .909 .946 r
.85818 .40908 .86633 .41509 .88771 .40402 .87962 .39684 Metetra
.799 .894 .911 r
.87962 .39684 .88771 .40402 .90901 .39133 .90083 .38189 Metetra
.79 .847 .894 r
.90083 .38189 .90901 .39133 .93006 .376 .92213 .36712 Metetra
.647 .738 .915 r
.32819 .53726 .33957 .54782 .35769 .54277 .34638 .53223 Metetra
.647 .739 .917 r
.34638 .53223 .35769 .54277 .37595 .53769 .36471 .52717 Metetra
.646 .741 .918 r
.36471 .52717 .37595 .53769 .39434 .5326 .38317 .5221 Metetra
.646 .743 .92 r
.38317 .5221 .39434 .5326 .41286 .52748 .40177 .51701 Metetra
.645 .744 .922 r
.40177 .51701 .41286 .52748 .43152 .52236 .4205 .51192 Metetra
.644 .746 .923 r
.4205 .51192 .43152 .52236 .45031 .51724 .43938 .50684 Metetra
.642 .748 .925 r
.43938 .50684 .45031 .51724 .46925 .51213 .4584 .50177 Metetra
.64 .749 .928 r
.4584 .50177 .46925 .51213 .48832 .50703 .47756 .49673 Metetra
.638 .751 .93 r
.47756 .49673 .48832 .50703 .50754 .50196 .49687 .49172 Metetra
.636 .753 .933 r
.49687 .49172 .50754 .50196 .52691 .49692 .51633 .48676 Metetra
.633 .755 .936 r
.51633 .48676 .52691 .49692 .54643 .49192 .53594 .48185 Metetra
.63 .758 .939 r
.53594 .48185 .54643 .49192 .5661 .48696 .55571 .47701 Metetra
.626 .76 .943 r
.55571 .47701 .5661 .48696 .58592 .48207 .57564 .47225 Metetra
.622 .763 .947 r
.57564 .47225 .58592 .48207 .60591 .47723 .59573 .46758 Metetra
.617 .767 .951 r
.59573 .46758 .60591 .47723 .62606 .47245 .61599 .463 Metetra
.612 .771 .956 r
.61599 .463 .62606 .47245 .64638 .46773 .63643 .45852 Metetra
.606 .775 .961 r
.63643 .45852 .64638 .46773 .66687 .46306 .65705 .45413 Metetra
.6 .781 .967 r
.65705 .45413 .66687 .46306 .68754 .45841 .67785 .44982 Metetra
.593 .788 .973 r
.67785 .44982 .68754 .45841 .70837 .45375 .69884 .44557 Metetra
.586 .796 .979 r
.69884 .44557 .70837 .45375 .72939 .44903 .72001 .44133 Metetra
.579 .806 .986 r
.72001 .44133 .72939 .44903 .75057 .44413 .74137 .43702 Metetra
.574 .82 .991 r
.74137 .43702 .75057 .44413 .77191 .43894 .76291 .43251 Metetra
.572 .837 .995 r
.76291 .43251 .77191 .43894 .79339 .43321 .78461 .42757 Metetra
.579 .86 .996 r
.78461 .42757 .79339 .43321 .81497 .42665 .80643 .42187 Metetra
.601 .889 .99 r
.80643 .42187 .81497 .42665 .8366 .41881 .82832 .41481 Metetra
.652 .925 .974 r
.82832 .41481 .8366 .41881 .85818 .40908 .85013 .40547 Metetra
.739 .957 .942 r
.85013 .40547 .85818 .40908 .87962 .39684 .8717 .39246 Metetra
.838 .956 .89 r
.8717 .39246 .87962 .39684 .90083 .38189 .89276 .37435 Metetra
.902 .891 .809 r
.89276 .37435 .90083 .38189 .92213 .36712 .91293 .3488 Metetra
.645 .737 .916 r
.31666 .52656 .32819 .53726 .34638 .53223 .33493 .52154 Metetra
.645 .739 .917 r
.33493 .52154 .34638 .53223 .36471 .52717 .35332 .5165 Metetra
.645 .74 .919 r
.35332 .5165 .36471 .52717 .38317 .5221 .37186 .51144 Metetra
.644 .742 .92 r
.37186 .51144 .38317 .5221 .40177 .51701 .39053 .50637 Metetra
.643 .743 .922 r
.39053 .50637 .40177 .51701 .4205 .51192 .40935 .5013 Metetra
.641 .744 .924 r
.40935 .5013 .4205 .51192 .43938 .50684 .4283 .49624 Metetra
.64 .746 .926 r
.4283 .49624 .43938 .50684 .4584 .50177 .4474 .49121 Metetra
.638 .747 .928 r
.4474 .49121 .4584 .50177 .47756 .49673 .46665 .48621 Metetra
.635 .749 .93 r
.46665 .48621 .47756 .49673 .49687 .49172 .48604 .48125 Metetra
.633 .751 .933 r
.48604 .48125 .49687 .49172 .51633 .48676 .50559 .47636 Metetra
.63 .752 .936 r
.50559 .47636 .51633 .48676 .53594 .48185 .5253 .47154 Metetra
.626 .754 .939 r
.5253 .47154 .53594 .48185 .55571 .47701 .54516 .46681 Metetra
.622 .757 .943 r
.54516 .46681 .55571 .47701 .57564 .47225 .5652 .46217 Metetra
.617 .759 .947 r
.5652 .46217 .57564 .47225 .59573 .46758 .5854 .45766 Metetra
.611 .762 .951 r
.5854 .45766 .59573 .46758 .61599 .463 .60577 .45327 Metetra
.605 .765 .956 r
.60577 .45327 .61599 .463 .63643 .45852 .62633 .44903 Metetra
.597 .769 .962 r
.62633 .44903 .63643 .45852 .65705 .45413 .64707 .44493 Metetra
.589 .774 .968 r
.64707 .44493 .65705 .45413 .67785 .44982 .66801 .44099 Metetra
.578 .78 .975 r
.66801 .44099 .67785 .44982 .69884 .44557 .68914 .4372 Metetra
.567 .787 .982 r
.68914 .4372 .69884 .44557 .72001 .44133 .71048 .43353 Metetra
.553 .796 .989 r
.71048 .43353 .72001 .44133 .74137 .43702 .73203 .42994 Metetra
.538 .808 .996 r
.73203 .42994 .74137 .43702 .76291 .43251 .75378 .42633 Metetra
.521 .823 1 r
.75378 .42633 .76291 .43251 .78461 .42757 .77573 .42253 Metetra
.504 .843 .997 r
.77573 .42253 .78461 .42757 .80643 .42187 .79784 .41824 Metetra
.493 .867 .981 r
.79784 .41824 .80643 .42187 .82832 .41481 .82007 .4129 Metetra
.508 .9 .941 r
.82007 .4129 .82832 .41481 .85013 .40547 .84228 .40538 Metetra
.595 .95 .874 r
.84228 .40538 .85013 .40547 .8717 .39246 .86419 .39335 Metetra
.798 .997 .788 r
.86419 .39335 .8717 .39246 .89276 .37435 .88517 .37221 Metetra
.932 .964 .76 r
.88517 .37221 .89276 .37435 .91293 .3488 .90514 .34288 Metetra
.644 .737 .917 r
.30499 .51572 .31666 .52656 .33493 .52154 .32332 .51071 Metetra
.643 .738 .918 r
.32332 .51071 .33493 .52154 .35332 .5165 .34179 .50567 Metetra
.643 .739 .919 r
.34179 .50567 .35332 .5165 .37186 .51144 .3604 .50061 Metetra
.642 .74 .92 r
.3604 .50061 .37186 .51144 .39053 .50637 .37915 .49554 Metetra
.641 .742 .922 r
.37915 .49554 .39053 .50637 .40935 .5013 .39804 .49048 Metetra
.639 .743 .924 r
.39804 .49048 .40935 .5013 .4283 .49624 .41708 .48544 Metetra
.638 .744 .925 r
.41708 .48544 .4283 .49624 .4474 .49121 .43626 .48043 Metetra
.636 .745 .928 r
.43626 .48043 .4474 .49121 .46665 .48621 .45559 .47546 Metetra
.633 .746 .93 r
.45559 .47546 .46665 .48621 .48604 .48125 .47507 .47055 Metetra
.63 .748 .932 r
.47507 .47055 .48604 .48125 .50559 .47636 .49471 .46571 Metetra
.627 .749 .935 r
.49471 .46571 .50559 .47636 .5253 .47154 .51451 .46096 Metetra
.623 .751 .938 r
.51451 .46096 .5253 .47154 .54516 .46681 .53447 .45631 Metetra
.618 .752 .942 r
.53447 .45631 .54516 .46681 .5652 .46217 .5546 .45179 Metetra
.612 .754 .946 r
.5546 .45179 .5652 .46217 .5854 .45766 .57491 .44742 Metetra
.606 .756 .95 r
.57491 .44742 .5854 .45766 .60577 .45327 .59539 .44322 Metetra
.598 .759 .956 r
.59539 .44322 .60577 .45327 .62633 .44903 .61606 .4392 Metetra
.589 .762 .961 r
.61606 .4392 .62633 .44903 .64707 .44493 .63693 .4354 Metetra
.578 .765 .968 r
.63693 .4354 .64707 .44493 .66801 .44099 .658 .43184 Metetra
.564 .77 .975 r
.658 .43184 .66801 .44099 .68914 .4372 .67928 .42853 Metetra
.547 .775 .983 r
.67928 .42853 .68914 .4372 .71048 .43353 .70079 .42548 Metetra
.526 .782 .991 r
.70079 .42548 .71048 .43353 .73203 .42994 .72252 .4227 Metetra
.497 .789 .997 r
.72252 .4227 .73203 .42994 .75378 .42633 .74449 .42016 Metetra
.458 .796 .999 r
.74449 .42016 .75378 .42633 .77573 .42253 .76671 .41781 Metetra
.4 .799 .985 r
.76671 .41781 .77573 .42253 .79784 .41824 .78916 .41549 Metetra
.313 .783 .932 r
.78916 .41549 .79784 .41824 .82007 .4129 .81183 .41292 Metetra
.19 .722 .792 r
.81183 .41292 .82007 .4129 .84228 .40538 .83465 .40938 Metetra
.83465 .40938 .84228 .40538 .86419 .39335 .8574 .403 Metetra
.8574 .403 .86419 .39335 .88517 .37221 .87926 .38669 Metetra
.854 .805 .316 r
.87926 .38669 .88517 .37221 .90514 .34288 .89523 .32008 Metetra
.642 .736 .917 r
.29317 .50475 .30499 .51572 .32332 .51071 .31157 .49972 Metetra
.642 .738 .918 r
.31157 .49972 .32332 .51071 .34179 .50567 .33011 .49467 Metetra
.641 .739 .919 r
.33011 .49467 .34179 .50567 .3604 .50061 .34879 .4896 Metetra
.641 .739 .92 r
.34879 .4896 .3604 .50061 .37915 .49554 .36762 .48453 Metetra
.639 .74 .922 r
.36762 .48453 .37915 .49554 .39804 .49048 .38659 .47947 Metetra
.638 .741 .923 r
.38659 .47947 .39804 .49048 .41708 .48544 .4057 .47443 Metetra
.636 .742 .925 r
.4057 .47443 .41708 .48544 .43626 .48043 .42497 .46942 Metetra
.634 .743 .927 r
.42497 .46942 .43626 .48043 .45559 .47546 .44438 .46447 Metetra
.631 .744 .929 r
.44438 .46447 .45559 .47546 .47507 .47055 .46395 .45958 Metetra
.628 .745 .932 r
.46395 .45958 .47507 .47055 .49471 .46571 .48368 .45477 Metetra
.624 .746 .934 r
.48368 .45477 .49471 .46571 .51451 .46096 .50357 .45008 Metetra
.62 .747 .937 r
.50357 .45008 .51451 .46096 .53447 .45631 .52363 .4455 Metetra
.614 .748 .941 r
.52363 .4455 .53447 .45631 .5546 .45179 .54386 .44108 Metetra
.608 .749 .945 r
.54386 .44108 .5546 .45179 .57491 .44742 .56426 .43683 Metetra
.601 .75 .949 r
.56426 .43683 .57491 .44742 .59539 .44322 .58486 .43279 Metetra
.592 .752 .954 r
.58486 .43279 .59539 .44322 .61606 .4392 .60564 .42898 Metetra
.581 .754 .96 r
.60564 .42898 .61606 .4392 .63693 .4354 .62663 .42546 Metetra
.568 .756 .966 r
.62663 .42546 .63693 .4354 .658 .43184 .64783 .42225 Metetra
.551 .758 .974 r
.64783 .42225 .658 .43184 .67928 .42853 .66925 .41942 Metetra
.529 .761 .982 r
.66925 .41942 .67928 .42853 .70079 .42548 .69091 .417 Metetra
.5 .763 .99 r
.69091 .417 .70079 .42548 .72252 .4227 .71283 .41506 Metetra
.458 .764 .996 r
.71283 .41506 .72252 .4227 .74449 .42016 .73502 .41367 Metetra
.394 .758 .993 r
.73502 .41367 .74449 .42016 .76671 .41781 .7575 .41291 Metetra
.291 .733 .964 r
.7575 .41291 .76671 .41781 .78916 .41549 .78031 .41287 Metetra
.116 .652 .858 r
.78031 .41287 .78916 .41549 .81183 .41292 .80347 .41372 Metetra
.148 0 0 r
.80347 .41372 .81183 .41292 .83465 .40938 .82703 .41578 Metetra
.417 0 0 r
.82703 .41578 .83465 .40938 .8574 .403 .85114 .42005 Metetra
.595 .158 .182 r
.85114 .42005 .8574 .403 .87926 .38669 .87631 .43082 Metetra
.734 .387 .392 r
.87631 .43082 .87926 .38669 .89523 .32008 .90618 .47834 Metetra
.641 .736 .918 r
.28119 .49363 .29317 .50475 .31157 .49972 .29966 .48858 Metetra
.641 .737 .918 r
.29966 .48858 .31157 .49972 .33011 .49467 .31828 .48351 Metetra
.64 .738 .919 r
.31828 .48351 .33011 .49467 .34879 .4896 .33703 .47842 Metetra
.639 .738 .92 r
.33703 .47842 .34879 .4896 .36762 .48453 .35594 .47332 Metetra
.638 .739 .922 r
.35594 .47332 .36762 .48453 .38659 .47947 .37498 .46824 Metetra
.636 .74 .923 r
.37498 .46824 .38659 .47947 .4057 .47443 .39418 .46319 Metetra
.635 .74 .925 r
.39418 .46319 .4057 .47443 .42497 .46942 .41353 .45817 Metetra
.632 .741 .926 r
.41353 .45817 .42497 .46942 .44438 .46447 .43303 .45322 Metetra
.629 .741 .928 r
.43303 .45322 .44438 .46447 .46395 .45958 .45268 .44833 Metetra
.626 .742 .931 r
.45268 .44833 .46395 .45958 .48368 .45477 .4725 .44355 Metetra
.622 .742 .933 r
.4725 .44355 .48368 .45477 .50357 .45008 .49248 .43888 Metetra
.617 .743 .936 r
.49248 .43888 .50357 .45008 .52363 .4455 .51263 .43435 Metetra
.612 .743 .939 r
.51263 .43435 .52363 .4455 .54386 .44108 .53295 .42999 Metetra
.605 .744 .943 r
.53295 .42999 .54386 .44108 .56426 .43683 .55346 .42584 Metetra
.597 .744 .947 r
.55346 .42584 .56426 .43683 .58486 .43279 .57416 .42192 Metetra
.587 .745 .952 r
.57416 .42192 .58486 .43279 .60564 .42898 .59505 .4183 Metetra
.575 .745 .957 r
.59505 .4183 .60564 .42898 .62663 .42546 .61615 .41501 Metetra
.56 .745 .963 r
.61615 .41501 .62663 .42546 .64783 .42225 .63748 .41212 Metetra
.541 .745 .971 r
.63748 .41212 .64783 .42225 .66925 .41942 .65904 .40971 Metetra
.515 .745 .978 r
.65904 .40971 .66925 .41942 .69091 .417 .68085 .40787 Metetra
.48 .742 .986 r
.68085 .40787 .69091 .417 .71283 .41506 .70294 .40672 Metetra
.428 .736 .991 r
.70294 .40672 .71283 .41506 .73502 .41367 .72534 .40642 Metetra
.347 .718 .986 r
.72534 .40642 .73502 .41367 .7575 .41291 .74808 .40718 Metetra
.215 .67 .948 r
.74808 .40718 .7575 .41291 .78031 .41287 .77121 .40933 Metetra
0 .548 .82 r
.77121 .40933 .78031 .41287 .80347 .41372 .79481 .4134 Metetra
.307 0 0 r
.79481 .4134 .80347 .41372 .82703 .41578 .81904 .42048 Metetra
.57 .016 0 r
.81904 .42048 .82703 .41578 .85114 .42005 .84422 .43313 Metetra
.72 .262 .163 r
.84422 .43313 .85114 .42005 .87631 .43082 .8712 .45834 Metetra
.8 .413 .322 r
.8712 .45834 .87631 .43082 .90618 .47834 .90237 .51434 Metetra
.64 .736 .918 r
.26906 .48237 .28119 .49363 .29966 .48858 .2876 .47728 Metetra
.64 .737 .919 r
.2876 .47728 .29966 .48858 .31828 .48351 .30629 .47217 Metetra
.639 .737 .919 r
.30629 .47217 .31828 .48351 .33703 .47842 .32512 .46704 Metetra
.638 .738 .92 r
.32512 .46704 .33703 .47842 .35594 .47332 .3441 .46192 Metetra
.637 .738 .921 r
.3441 .46192 .35594 .47332 .37498 .46824 .36323 .4568 Metetra
.635 .738 .923 r
.36323 .4568 .37498 .46824 .39418 .46319 .3825 .45172 Metetra
.633 .739 .924 r
.3825 .45172 .39418 .46319 .41353 .45817 .40193 .44668 Metetra
.631 .739 .925 r
.40193 .44668 .41353 .45817 .43303 .45322 .42151 .4417 Metetra
.628 .739 .927 r
.42151 .4417 .43303 .45322 .45268 .44833 .44126 .4368 Metetra
.625 .739 .929 r
.44126 .4368 .45268 .44833 .4725 .44355 .46116 .432 Metetra
.62 .739 .931 r
.46116 .432 .4725 .44355 .49248 .43888 .48123 .42734 Metetra
.616 .739 .934 r
.48123 .42734 .49248 .43888 .51263 .43435 .50147 .42283 Metetra
.61 .739 .937 r
.50147 .42283 .51263 .43435 .53295 .42999 .52189 .4185 Metetra
.603 .738 .94 r
.52189 .4185 .53295 .42999 .55346 .42584 .5425 .41441 Metetra
.594 .738 .944 r
.5425 .41441 .55346 .42584 .57416 .42192 .5633 .41058 Metetra
.584 .737 .948 r
.5633 .41058 .57416 .42192 .59505 .4183 .5843 .40708 Metetra
.571 .736 .953 r
.5843 .40708 .59505 .4183 .61615 .41501 .60551 .40397 Metetra
.555 .734 .959 r
.60551 .40397 .61615 .41501 .63748 .41212 .62695 .40132 Metetra
.534 .732 .965 r
.62695 .40132 .63748 .41212 .65904 .40971 .64864 .39925 Metetra
.507 .728 .973 r
.64864 .39925 .65904 .40971 .68085 .40787 .67059 .39789 Metetra
.468 .721 .979 r
.67059 .39789 .68085 .40787 .70294 .40672 .69284 .39739 Metetra
.412 .708 .984 r
.69284 .39739 .70294 .40672 .72534 .40642 .71542 .39799 Metetra
.327 .682 .979 r
.71542 .39799 .72534 .40642 .74808 .40718 .73838 .4 Metetra
.191 .626 .946 r
.73838 .4 .74808 .40718 .77121 .40933 .76178 .40388 Metetra
0 .506 .842 r
.76178 .40388 .77121 .40933 .79481 .4134 .78574 .41031 Metetra
.299 0 0 r
.78574 .41031 .79481 .4134 .81904 .42048 .81042 .42043 Metetra
.549 0 0 r
.81042 .42043 .81904 .42048 .84422 .43313 .83607 .4361 Metetra
.693 .157 0 r
.83607 .4361 .84422 .43313 .8712 .45834 .86307 .45956 Metetra
.713 .178 0 r
.86307 .45956 .8712 .45834 .90237 .51434 .89121 .4873 Metetra
.64 .736 .918 r
.25676 .47096 .26906 .48237 .2876 .47728 .27538 .46582 Metetra
.639 .736 .919 r
.27538 .46582 .2876 .47728 .30629 .47217 .29414 .46065 Metetra
.639 .736 .919 r
.29414 .46065 .30629 .47217 .32512 .46704 .31305 .45548 Metetra
.638 .737 .92 r
.31305 .45548 .32512 .46704 .3441 .46192 .33211 .4503 Metetra
.637 .737 .921 r
.33211 .4503 .3441 .46192 .36323 .4568 .35131 .44514 Metetra
.635 .737 .922 r
.35131 .44514 .36323 .4568 .3825 .45172 .37067 .44 Metetra
.633 .737 .923 r
.37067 .44 .3825 .45172 .40193 .44668 .39018 .43492 Metetra
.63 .737 .924 r
.39018 .43492 .40193 .44668 .42151 .4417 .40985 .4299 Metetra
.627 .736 .926 r
.40985 .4299 .42151 .4417 .44126 .4368 .42968 .42496 Metetra
.624 .736 .927 r
.42968 .42496 .44126 .4368 .46116 .432 .44967 .42013 Metetra
.62 .736 .929 r
.44967 .42013 .46116 .432 .48123 .42734 .46983 .41544 Metetra
.615 .735 .932 r
.46983 .41544 .48123 .42734 .50147 .42283 .49016 .41091 Metetra
.609 .734 .934 r
.49016 .41091 .50147 .42283 .52189 .4185 .51068 .40659 Metetra
.602 .733 .937 r
.51068 .40659 .52189 .4185 .5425 .41441 .53138 .4025 Metetra
.593 .731 .94 r
.53138 .4025 .5425 .41441 .5633 .41058 .55227 .39871 Metetra
.583 .73 .944 r
.55227 .39871 .5633 .41058 .5843 .40708 .57337 .39527 Metetra
.57 .727 .948 r
.57337 .39527 .5843 .40708 .60551 .40397 .59469 .39226 Metetra
.553 .724 .953 r
.59469 .39226 .60551 .40397 .62695 .40132 .61625 .38977 Metetra
.532 .719 .959 r
.61625 .38977 .62695 .40132 .64864 .39925 .63805 .38792 Metetra
.504 .712 .965 r
.63805 .38792 .64864 .39925 .67059 .39789 .66013 .38686 Metetra
.466 .702 .97 r
.66013 .38686 .67059 .39789 .69284 .39739 .68251 .38681 Metetra
.412 .684 .974 r
.68251 .38681 .69284 .39739 .71542 .39799 .70525 .38803 Metetra
.333 .655 .971 r
.70525 .38803 .71542 .39799 .73838 .4 .72839 .39089 Metetra
.214 .601 .949 r
.72839 .39089 .73838 .4 .76178 .40388 .752 .39589 Metetra
.04 .505 .885 r
.752 .39589 .76178 .40388 .78574 .41031 .77621 .4037 Metetra
0 .351 .753 r
.77621 .4037 .78574 .41031 .81042 .42043 .80114 .41518 Metetra
.398 0 0 r
.80114 .41518 .81042 .42043 .83607 .4361 .82699 .43133 Metetra
.531 0 0 r
.82699 .43133 .83607 .4361 .86307 .45956 .85392 .45276 Metetra
.565 .036 0 r
.85392 .45276 .86307 .45956 .89121 .4873 .88215 .48015 Metetra
.639 .736 .918 r
.24431 .45939 .25676 .47096 .27538 .46582 .263 .45419 Metetra
.639 .736 .919 r
.263 .45419 .27538 .46582 .29414 .46065 .28184 .44896 Metetra
.639 .736 .919 r
.28184 .44896 .29414 .46065 .31305 .45548 .30082 .44372 Metetra
.638 .736 .92 r
.30082 .44372 .31305 .45548 .33211 .4503 .31995 .43847 Metetra
.636 .736 .92 r
.31995 .43847 .33211 .4503 .35131 .44514 .33924 .43324 Metetra
.635 .736 .921 r
.33924 .43324 .35131 .44514 .37067 .44 .35868 .42804 Metetra
.633 .735 .922 r
.35868 .42804 .37067 .44 .39018 .43492 .37827 .42289 Metetra
.63 .735 .923 r
.37827 .42289 .39018 .43492 .40985 .4299 .39802 .4178 Metetra
.627 .734 .924 r
.39802 .4178 .40985 .4299 .42968 .42496 .41794 .41281 Metetra
.624 .733 .926 r
.41794 .41281 .42968 .42496 .44967 .42013 .43802 .40792 Metetra
.619 .732 .927 r
.43802 .40792 .44967 .42013 .46983 .41544 .45827 .40317 Metetra
.615 .731 .929 r
.45827 .40317 .46983 .41544 .49016 .41091 .47869 .39859 Metetra
.609 .73 .931 r
.47869 .39859 .49016 .41091 .51068 .40659 .4993 .39422 Metetra
.602 .728 .933 r
.4993 .39422 .51068 .40659 .53138 .4025 .52009 .3901 Metetra
.593 .726 .936 r
.52009 .3901 .53138 .4025 .55227 .39871 .54109 .38628 Metetra
.583 .723 .939 r
.54109 .38628 .55227 .39871 .57337 .39527 .56229 .38283 Metetra
.57 .719 .942 r
.56229 .38283 .57337 .39527 .59469 .39226 .5837 .37982 Metetra
.555 .714 .946 r
.5837 .37982 .59469 .39226 .61625 .38977 .60536 .37737 Metetra
.535 .707 .95 r
.60536 .37737 .61625 .38977 .63805 .38792 .62727 .37559 Metetra
.508 .698 .955 r
.62727 .37559 .63805 .38792 .66013 .38686 .64946 .37466 Metetra
.473 .685 .959 r
.64946 .37466 .66013 .38686 .68251 .38681 .67196 .37481 Metetra
.425 .665 .961 r
.67196 .37481 .68251 .38681 .70525 .38803 .69482 .37631 Metetra
.358 .635 .959 r
.69482 .37631 .70525 .38803 .72839 .39089 .7181 .37956 Metetra
.263 .588 .947 r
.7181 .37956 .72839 .39089 .752 .39589 .74186 .38507 Metetra
.132 .513 .912 r
.74186 .38507 .752 .39589 .77621 .4037 .76623 .39345 Metetra
0 .407 .845 r
.76623 .39345 .77621 .4037 .80114 .41518 .79131 .40538 Metetra
0 .283 .75 r
.79131 .40538 .80114 .41518 .82699 .43133 .81726 .42139 Metetra
0 .186 .673 r
.81726 .42139 .82699 .43133 .85392 .45276 .84416 .4414 Metetra
0 .171 .676 r
.84416 .4414 .85392 .45276 .88215 .48015 .87195 .46372 Metetra
.639 .736 .918 r
.23169 .44768 .24431 .45939 .263 .45419 .25045 .44239 Metetra
.639 .736 .918 r
.25045 .44239 .263 .45419 .28184 .44896 .26936 .43708 Metetra
.639 .735 .919 r
.26936 .43708 .28184 .44896 .30082 .44372 .28843 .43175 Metetra
.638 .735 .919 r
.28843 .43175 .30082 .44372 .31995 .43847 .30764 .42642 Metetra
.636 .735 .919 r
.30764 .42642 .31995 .43847 .33924 .43324 .32701 .42111 Metetra
.635 .734 .92 r
.32701 .42111 .33924 .43324 .35868 .42804 .34653 .41582 Metetra
.633 .734 .921 r
.34653 .41582 .35868 .42804 .37827 .42289 .36621 .41059 Metetra
.63 .733 .921 r
.36621 .41059 .37827 .42289 .39802 .4178 .38604 .40541 Metetra
.627 .732 .922 r
.38604 .40541 .39802 .4178 .41794 .41281 .40604 .40033 Metetra
.624 .731 .923 r
.40604 .40033 .41794 .41281 .43802 .40792 .42621 .39535 Metetra
.62 .729 .925 r
.42621 .39535 .43802 .40792 .45827 .40317 .44655 .39052 Metetra
.615 .728 .926 r
.44655 .39052 .45827 .40317 .47869 .39859 .46707 .38585 Metetra
.61 .726 .928 r
.46707 .38585 .47869 .39859 .4993 .39422 .48776 .38139 Metetra
.603 .723 .929 r
.48776 .38139 .4993 .39422 .52009 .3901 .50865 .37718 Metetra
.595 .72 .931 r
.50865 .37718 .52009 .3901 .54109 .38628 .52974 .37327 Metetra
.585 .716 .934 r
.52974 .37327 .54109 .38628 .56229 .38283 .55103 .36973 Metetra
.573 .711 .936 r
.55103 .36973 .56229 .38283 .5837 .37982 .57255 .36663 Metetra
.559 .705 .938 r
.57255 .36663 .5837 .37982 .60536 .37737 .5943 .36409 Metetra
.541 .697 .941 r
.5943 .36409 .60536 .37737 .62727 .37559 .6163 .36223 Metetra
.517 .686 .944 r
.6163 .36223 .62727 .37559 .64946 .37466 .63859 .36121 Metetra
.487 .671 .946 r
.63859 .36121 .64946 .37466 .67196 .37481 .66119 .36127 Metetra
.447 .651 .946 r
.66119 .36127 .67196 .37481 .69482 .37631 .68415 .36269 Metetra
.393 .622 .944 r
.68415 .36269 .69482 .37631 .7181 .37956 .70751 .36587 Metetra
.321 .58 .935 r
.70751 .36587 .7181 .37956 .74186 .38507 .73137 .3713 Metetra
.224 .52 .915 r
.73137 .3713 .74186 .38507 .76623 .39345 .75583 .37962 Metetra
.104 .439 .877 r
.75583 .37962 .76623 .39345 .79131 .40538 .781 .3915 Metetra
0 .344 .821 r
.781 .3915 .79131 .40538 .81726 .42139 .80703 .40748 Metetra
0 .254 .759 r
.80703 .40748 .81726 .42139 .84416 .4414 .83401 .42746 Metetra
0 .213 .727 r
.83401 .42746 .84416 .4414 .87195 .46372 .86188 .44978 Metetra
.64 .736 .918 r
.2189 .43581 .23169 .44768 .25045 .44239 .23774 .43042 Metetra
.639 .735 .918 r
.23774 .43042 .25045 .44239 .26936 .43708 .25673 .42501 Metetra
.639 .735 .918 r
.25673 .42501 .26936 .43708 .28843 .43175 .27587 .41959 Metetra
.638 .735 .918 r
.27587 .41959 .28843 .43175 .30764 .42642 .29517 .41416 Metetra
.637 .734 .919 r
.29517 .41416 .30764 .42642 .32701 .42111 .31461 .40874 Metetra
.635 .733 .919 r
.31461 .40874 .32701 .42111 .34653 .41582 .33422 .40335 Metetra
.633 .732 .919 r
.33422 .40335 .34653 .41582 .36621 .41059 .35398 .398 Metetra
.631 .731 .92 r
.35398 .398 .36621 .41059 .38604 .40541 .3739 .39272 Metetra
.628 .73 .92 r
.3739 .39272 .38604 .40541 .40604 .40033 .39399 .38752 Metetra
.625 .728 .921 r
.39399 .38752 .40604 .40033 .42621 .39535 .41425 .38243 Metetra
.621 .727 .922 r
.41425 .38243 .42621 .39535 .44655 .39052 .43468 .37747 Metetra
.617 .725 .923 r
.43468 .37747 .44655 .39052 .46707 .38585 .45528 .37268 Metetra
.611 .722 .924 r
.45528 .37268 .46707 .38585 .48776 .38139 .47607 .36809 Metetra
.605 .719 .925 r
.47607 .36809 .48776 .38139 .50865 .37718 .49705 .36373 Metetra
.598 .715 .926 r
.49705 .36373 .50865 .37718 .52974 .37327 .51823 .35967 Metetra
.589 .711 .928 r
.51823 .35967 .52974 .37327 .55103 .36973 .53961 .35596 Metetra
.578 .705 .929 r
.53961 .35596 .55103 .36973 .57255 .36663 .56122 .35268 Metetra
.565 .698 .93 r
.56122 .35268 .57255 .36663 .5943 .36409 .58306 .34992 Metetra
.549 .689 .931 r
.58306 .34992 .5943 .36409 .6163 .36223 .60516 .34781 Metetra
.53 .677 .932 r
.60516 .34781 .6163 .36223 .63859 .36121 .62753 .34649 Metetra
.505 .662 .931 r
.62753 .34649 .63859 .36121 .66119 .36127 .65021 .34619 Metetra
.474 .641 .93 r
.65021 .34619 .66119 .36127 .68415 .36269 .67323 .34716 Metetra
.433 .614 .925 r
.67323 .34716 .68415 .36269 .70751 .36587 .69666 .34979 Metetra
.38 .576 .917 r
.69666 .34979 .70751 .36587 .73137 .3713 .72056 .35457 Metetra
.309 .525 .901 r
.72056 .35457 .73137 .3713 .75583 .37962 .74503 .36218 Metetra
.216 .457 .875 r
.74503 .36218 .75583 .37962 .781 .3915 .77023 .37351 Metetra
.095 .37 .834 r
.77023 .37351 .781 .3915 .80703 .40748 .79631 .38955 Metetra
0 .267 .774 r
.79631 .38955 .80703 .40748 .83401 .42746 .82348 .41094 Metetra
0 .139 .679 r
.82348 .41094 .83401 .42746 .86188 .44978 .85192 .43834 Metetra
.64 .736 .918 r
.20593 .42377 .2189 .43581 .23774 .43042 .22485 .41828 Metetra
.64 .735 .918 r
.22485 .41828 .23774 .43042 .25673 .42501 .24392 .41275 Metetra
.64 .735 .918 r
.24392 .41275 .25673 .42501 .27587 .41959 .26315 .40721 Metetra
.639 .734 .917 r
.26315 .40721 .27587 .41959 .29517 .41416 .28252 .40166 Metetra
.638 .733 .918 r
.28252 .40166 .29517 .41416 .31461 .40874 .30205 .39613 Metetra
.636 .732 .918 r
.30205 .39613 .31461 .40874 .33422 .40335 .32174 .39061 Metetra
.634 .731 .918 r
.32174 .39061 .33422 .40335 .35398 .398 .34159 .38514 Metetra
.632 .73 .918 r
.34159 .38514 .35398 .398 .3739 .39272 .3616 .37973 Metetra
.629 .728 .918 r
.3616 .37973 .3739 .39272 .39399 .38752 .38178 .37439 Metetra
.626 .726 .919 r
.38178 .37439 .39399 .38752 .41425 .38243 .40212 .36915 Metetra
.623 .724 .919 r
.40212 .36915 .41425 .38243 .43468 .37747 .42264 .36404 Metetra
.619 .722 .92 r
.42264 .36404 .43468 .37747 .45528 .37268 .44334 .35908 Metetra
.614 .719 .92 r
.44334 .35908 .45528 .37268 .47607 .36809 .46422 .35431 Metetra
.608 .715 .921 r
.46422 .35431 .47607 .36809 .49705 .36373 .48529 .34976 Metetra
.601 .711 .921 r
.48529 .34976 .49705 .36373 .51823 .35967 .50656 .34549 Metetra
.593 .706 .922 r
.50656 .34549 .51823 .35967 .53961 .35596 .52803 .34153 Metetra
.584 .7 .922 r
.52803 .34153 .53961 .35596 .56122 .35268 .54973 .33797 Metetra
.573 .692 .922 r
.54973 .33797 .56122 .35268 .58306 .34992 .57166 .33488 Metetra
.56 .683 .921 r
.57166 .33488 .58306 .34992 .60516 .34781 .59383 .33236 Metetra
.545 .671 .92 r
.59383 .33236 .60516 .34781 .62753 .34649 .61628 .33056 Metetra
.526 .655 .917 r
.61628 .33056 .62753 .34649 .65021 .34619 .63902 .32963 Metetra
.503 .636 .913 r
.63902 .32963 .65021 .34619 .67323 .34716 .66209 .32981 Metetra
.474 .61 .906 r
.66209 .32981 .67323 .34716 .69666 .34979 .68554 .33141 Metetra
.437 .577 .896 r
.68554 .33141 .69666 .34979 .72056 .35457 .70943 .33491 Metetra
.388 .533 .88 r
.70943 .33491 .72056 .35457 .74503 .36218 .73386 .341 Metetra
.318 .473 .857 r
.73386 .341 .74503 .36218 .77023 .37351 .75898 .35083 Metetra
.209 .388 .822 r
.75898 .35083 .77023 .37351 .79631 .38955 .78504 .3663 Metetra
.036 .267 .764 r
.78504 .3663 .79631 .38955 .82348 .41094 .81239 .38971 Metetra
0 .186 .719 r
.81239 .38971 .82348 .41094 .85192 .43834 .84089 .41749 Metetra
.641 .736 .918 r
.19279 .41157 .20593 .42377 .22485 .41828 .21179 .40595 Metetra
.641 .735 .917 r
.21179 .40595 .22485 .41828 .24392 .41275 .23094 .4003 Metetra
.64 .735 .917 r
.23094 .4003 .24392 .41275 .26315 .40721 .25025 .39463 Metetra
.64 .734 .917 r
.25025 .39463 .26315 .40721 .28252 .40166 .26971 .38895 Metetra
.639 .733 .916 r
.26971 .38895 .28252 .40166 .30205 .39613 .28933 .38327 Metetra
.637 .731 .916 r
.28933 .38327 .30205 .39613 .32174 .39061 .3091 .37761 Metetra
.635 .73 .916 r
.3091 .37761 .32174 .39061 .34159 .38514 .32904 .37199 Metetra
.633 .728 .916 r
.32904 .37199 .34159 .38514 .3616 .37973 .34913 .36643 Metetra
.631 .727 .916 r
.34913 .36643 .3616 .37973 .38178 .37439 .3694 .36093 Metetra
.628 .725 .916 r
.3694 .36093 .38178 .37439 .40212 .36915 .38983 .35552 Metetra
.625 .722 .917 r
.38983 .35552 .40212 .36915 .42264 .36404 .41044 .35022 Metetra
.621 .719 .917 r
.41044 .35022 .42264 .36404 .44334 .35908 .43123 .34507 Metetra
.617 .716 .917 r
.43123 .34507 .44334 .35908 .46422 .35431 .4522 .34008 Metetra
.612 .712 .917 r
.4522 .34008 .46422 .35431 .48529 .34976 .47336 .33529 Metetra
.606 .708 .916 r
.47336 .33529 .48529 .34976 .50656 .34549 .49472 .33074 Metetra
.599 .702 .916 r
.49472 .33074 .50656 .34549 .52803 .34153 .51629 .32648 Metetra
.591 .696 .915 r
.51629 .32648 .52803 .34153 .54973 .33797 .53807 .32255 Metetra
.583 .688 .914 r
.53807 .32255 .54973 .33797 .57166 .33488 .56009 .31903 Metetra
.572 .678 .912 r
.56009 .31903 .57166 .33488 .59383 .33236 .58234 .31598 Metetra
.561 .667 .909 r
.58234 .31598 .59383 .33236 .61628 .33056 .60485 .31352 Metetra
.547 .652 .904 r
.60485 .31352 .61628 .33056 .63902 .32963 .62765 .31175 Metetra
.531 .634 .897 r
.62765 .31175 .63902 .32963 .66209 .32981 .65076 .31083 Metetra
.513 .611 .888 r
.65076 .31083 .66209 .32981 .68554 .33141 .6742 .31099 Metetra
.491 .583 .874 r
.6742 .31099 .68554 .33141 .70943 .33491 .69805 .31256 Metetra
.462 .546 .857 r
.69805 .31256 .70943 .33491 .73386 .341 .72235 .3161 Metetra
.42 .497 .833 r
.72235 .3161 .73386 .341 .75898 .35083 .74726 .32271 Metetra
.342 .423 .8 r
.74726 .32271 .75898 .35083 .78504 .3663 .77304 .335 Metetra
.146 .274 .739 r
.77304 .335 .78504 .3663 .81239 .38971 .80048 .36015 Metetra
0 0 .479 r
.80048 .36015 .81239 .38971 .84089 .41749 .83167 .41692 Metetra
.642 .736 .917 r
.17947 .39921 .19279 .41157 .21179 .40595 .19855 .39345 Metetra
.642 .735 .917 r
.19855 .39345 .21179 .40595 .23094 .4003 .21779 .38765 Metetra
.642 .734 .916 r
.21779 .38765 .23094 .4003 .25025 .39463 .23718 .38183 Metetra
.641 .733 .916 r
.23718 .38183 .25025 .39463 .26971 .38895 .25672 .376 Metetra
.64 .732 .915 r
.25672 .376 .26971 .38895 .28933 .38327 .27643 .37017 Metetra
.639 .731 .915 r
.27643 .37017 .28933 .38327 .3091 .37761 .29629 .36435 Metetra
.637 .729 .915 r
.29629 .36435 .3091 .37761 .32904 .37199 .31631 .35857 Metetra
.635 .727 .914 r
.31631 .35857 .32904 .37199 .34913 .36643 .3365 .35282 Metetra
.633 .725 .914 r
.3365 .35282 .34913 .36643 .3694 .36093 .35686 .34714 Metetra
.63 .723 .914 r
.35686 .34714 .3694 .36093 .38983 .35552 .37738 .34153 Metetra
.627 .72 .914 r
.37738 .34153 .38983 .35552 .41044 .35022 .39808 .33603 Metetra
.624 .717 .913 r
.39808 .33603 .41044 .35022 .43123 .34507 .41896 .33064 Metetra
.62 .714 .913 r
.41896 .33064 .43123 .34507 .4522 .34008 .44003 .3254 Metetra
.616 .71 .912 r
.44003 .3254 .4522 .34008 .47336 .33529 .46128 .32033 Metetra
.611 .705 .912 r
.46128 .32033 .47336 .33529 .49472 .33074 .48273 .31547 Metetra
.605 .7 .91 r
.48273 .31547 .49472 .33074 .51629 .32648 .50439 .31084 Metetra
.599 .693 .909 r
.50439 .31084 .51629 .32648 .53807 .32255 .52626 .30648 Metetra
.592 .685 .906 r
.52626 .30648 .53807 .32255 .56009 .31903 .54835 .30245 Metetra
.585 .676 .903 r
.54835 .30245 .56009 .31903 .58234 .31598 .57069 .29878 Metetra
.577 .665 .899 r
.57069 .29878 .58234 .31598 .60485 .31352 .59327 .29553 Metetra
.568 .652 .892 r
.59327 .29553 .60485 .31352 .62765 .31175 .61611 .29277 Metetra
.559 .636 .884 r
.61611 .29277 .62765 .31175 .65076 .31083 .63924 .29056 Metetra
.549 .617 .872 r
.63924 .29056 .65076 .31083 .6742 .31099 .66268 .28898 Metetra
.54 .593 .856 r
.66268 .28898 .6742 .31099 .69805 .31256 .68644 .28814 Metetra
.53 .565 .836 r
.68644 .28814 .69805 .31256 .72235 .3161 .71057 .2882 Metetra
.518 .53 .808 r
.71057 .2882 .72235 .3161 .74726 .32271 .73512 .2895 Metetra
.498 .484 .773 r
.73512 .2895 .74726 .32271 .77304 .335 .76019 .29305 Metetra
.441 .409 .727 r
.76019 .29305 .77304 .335 .80048 .36015 .78622 .30329 Metetra
.123 .156 .623 r
.78622 .30329 .80048 .36015 .83167 .41692 .81625 .35141 Metetra
.644 .737 .917 r
.16597 .38668 .17947 .39921 .19855 .39345 .18513 .38076 Metetra
.644 .736 .916 r
.18513 .38076 .19855 .39345 .21779 .38765 .20445 .3748 Metetra
.643 .734 .915 r
.20445 .3748 .21779 .38765 .23718 .38183 .22393 .36882 Metetra
.642 .733 .915 r
.22393 .36882 .23718 .38183 .25672 .376 .24356 .36282 Metetra
.642 .732 .914 r
.24356 .36282 .25672 .376 .27643 .37017 .26335 .35682 Metetra
.64 .73 .914 r
.26335 .35682 .27643 .37017 .29629 .36435 .28331 .35083 Metetra
.639 .728 .913 r
.28331 .35083 .29629 .36435 .31631 .35857 .30342 .34486 Metetra
.637 .726 .913 r
.30342 .34486 .31631 .35857 .3365 .35282 .3237 .33892 Metetra
.635 .724 .912 r
.3237 .33892 .3365 .35282 .35686 .34714 .34415 .33303 Metetra
.633 .722 .912 r
.34415 .33303 .35686 .34714 .37738 .34153 .36477 .32721 Metetra
.63 .719 .911 r
.36477 .32721 .37738 .34153 .39808 .33603 .38556 .32147 Metetra
.627 .716 .91 r
.38556 .32147 .39808 .33603 .41896 .33064 .40653 .31582 Metetra
.624 .712 .909 r
.40653 .31582 .41896 .33064 .44003 .3254 .42769 .3103 Metetra
.62 .708 .908 r
.42769 .3103 .44003 .3254 .46128 .32033 .44904 .30492 Metetra
.616 .704 .907 r
.44904 .30492 .46128 .32033 .48273 .31547 .47058 .2997 Metetra
.612 .698 .905 r
.47058 .2997 .48273 .31547 .50439 .31084 .49233 .29466 Metetra
.607 .692 .903 r
.49233 .29466 .50439 .31084 .52626 .30648 .51429 .28984 Metetra
.602 .684 .9 r
.51429 .28984 .52626 .30648 .54835 .30245 .53647 .28524 Metetra
.597 .676 .896 r
.53647 .28524 .54835 .30245 .57069 .29878 .55887 .28089 Metetra
.592 .666 .89 r
.55887 .28089 .57069 .29878 .59327 .29553 .58152 .27681 Metetra
.587 .654 .883 r
.58152 .27681 .59327 .29553 .61611 .29277 .60442 .27299 Metetra
.583 .64 .873 r
.60442 .27299 .61611 .29277 .63924 .29056 .62757 .26941 Metetra
.58 .625 .861 r
.62757 .26941 .63924 .29056 .66268 .28898 .651 .266 Metetra
.58 .607 .844 r
.651 .266 .66268 .28898 .68644 .28814 .67469 .26262 Metetra
.584 .586 .821 r
.67469 .26262 .68644 .28814 .71057 .2882 .69865 .25895 Metetra
.594 .565 .791 r
.69865 .25895 .71057 .2882 .73512 .2895 .72281 .25428 Metetra
.617 .544 .75 r
.72281 .25428 .73512 .2895 .76019 .29305 .74703 .24666 Metetra
.668 .533 .691 r
.74703 .24666 .76019 .29305 .78622 .30329 .77064 .22876 Metetra
.78 .556 .596 r
.77064 .22876 .78622 .30329 .81625 .35141 .78971 .15902 Metetra
.645 .737 .916 r
.15228 .37397 .16597 .38668 .18513 .38076 .17153 .36788 Metetra
.645 .736 .915 r
.17153 .36788 .18513 .38076 .20445 .3748 .19094 .36175 Metetra
.645 .735 .914 r
.19094 .36175 .20445 .3748 .22393 .36882 .2105 .3556 Metetra
.644 .733 .914 r
.2105 .3556 .22393 .36882 .24356 .36282 .23022 .34942 Metetra
.643 .732 .913 r
.23022 .34942 .24356 .36282 .26335 .35682 .2501 .34323 Metetra
.642 .73 .912 r
.2501 .34323 .26335 .35682 .28331 .35083 .27015 .33705 Metetra
.641 .728 .911 r
.27015 .33705 .28331 .35083 .30342 .34486 .29035 .33087 Metetra
.64 .726 .911 r
.29035 .33087 .30342 .34486 .3237 .33892 .31073 .32472 Metetra
.638 .724 .91 r
.31073 .32472 .3237 .33892 .34415 .33303 .33127 .31861 Metetra
.636 .721 .909 r
.33127 .31861 .34415 .33303 .36477 .32721 .35198 .31255 Metetra
.633 .718 .908 r
.35198 .31255 .36477 .32721 .38556 .32147 .37287 .30655 Metetra
.631 .715 .907 r
.37287 .30655 .38556 .32147 .40653 .31582 .39394 .30063 Metetra
.628 .711 .906 r
.39394 .30063 .40653 .31582 .42769 .3103 .41519 .2948 Metetra
.625 .707 .905 r
.41519 .2948 .42769 .3103 .44904 .30492 .43663 .28908 Metetra
.622 .702 .903 r
.43663 .28908 .44904 .30492 .47058 .2997 .45827 .28348 Metetra
.618 .697 .901 r
.45827 .28348 .47058 .2997 .49233 .29466 .48011 .27801 Metetra
.615 .691 .898 r
.48011 .27801 .49233 .29466 .51429 .28984 .50216 .27269 Metetra
.611 .684 .894 r
.50216 .27269 .51429 .28984 .53647 .28524 .52442 .26751 Metetra
.608 .676 .89 r
.52442 .26751 .53647 .28524 .55887 .28089 .54691 .26247 Metetra
.605 .668 .884 r
.54691 .26247 .55887 .28089 .58152 .27681 .56962 .25754 Metetra
.603 .658 .876 r
.56962 .25754 .58152 .27681 .60442 .27299 .59257 .25268 Metetra
.603 .647 .866 r
.59257 .25268 .60442 .27299 .62757 .26941 .61577 .24779 Metetra
.605 .634 .853 r
.61577 .24779 .62757 .26941 .651 .266 .6392 .24269 Metetra
.611 .621 .837 r
.6392 .24269 .651 .266 .67469 .26262 .66285 .23706 Metetra
.623 .608 .815 r
.66285 .23706 .67469 .26262 .69865 .25895 .68669 .23031 Metetra
.642 .596 .787 r
.68669 .23031 .69865 .25895 .72281 .25428 .71061 .22129 Metetra
.674 .587 .75 r
.71061 .22129 .72281 .25428 .74703 .24666 .73442 .20757 Metetra
.719 .585 .705 r
.73442 .20757 .74703 .24666 .77064 .22876 .75761 .18439 Metetra
.745 .582 .674 r
.75761 .18439 .77064 .22876 .78971 .15902 .78005 .15274 Metetra
.647 .738 .915 r
.1384 .36108 .15228 .37397 .17153 .36788 .15774 .35481 Metetra
.647 .736 .914 r
.15774 .35481 .17153 .36788 .19094 .36175 .17723 .3485 Metetra
.647 .735 .913 r
.17723 .3485 .19094 .36175 .2105 .3556 .19689 .34216 Metetra
.646 .733 .912 r
.19689 .34216 .2105 .3556 .23022 .34942 .2167 .33579 Metetra
.645 .731 .912 r
.2167 .33579 .23022 .34942 .2501 .34323 .23667 .3294 Metetra
.644 .73 .911 r
.23667 .3294 .2501 .34323 .27015 .33705 .25681 .32301 Metetra
.643 .728 .91 r
.25681 .32301 .27015 .33705 .29035 .33087 .27711 .31662 Metetra
.642 .725 .909 r
.27711 .31662 .29035 .33087 .31073 .32472 .29758 .31024 Metetra
.64 .723 .908 r
.29758 .31024 .31073 .32472 .33127 .31861 .31821 .30389 Metetra
.639 .72 .907 r
.31821 .30389 .33127 .31861 .35198 .31255 .33902 .29757 Metetra
.637 .717 .906 r
.33902 .29757 .35198 .31255 .37287 .30655 .36001 .29129 Metetra
.635 .714 .905 r
.36001 .29129 .37287 .30655 .39394 .30063 .38117 .28508 Metetra
.632 .711 .903 r
.38117 .28508 .39394 .30063 .41519 .2948 .40252 .27892 Metetra
.63 .707 .901 r
.40252 .27892 .41519 .2948 .43663 .28908 .42406 .27285 Metetra
.627 .702 .899 r
.42406 .27285 .43663 .28908 .45827 .28348 .4458 .26685 Metetra
.624 .697 .897 r
.4458 .26685 .45827 .28348 .48011 .27801 .46773 .26094 Metetra
.622 .691 .894 r
.46773 .26094 .48011 .27801 .50216 .27269 .48987 .25511 Metetra
.62 .685 .89 r
.48987 .25511 .50216 .27269 .52442 .26751 .51222 .24935 Metetra
.618 .678 .885 r
.51222 .24935 .52442 .26751 .54691 .26247 .53479 .24364 Metetra
.617 .671 .879 r
.53479 .24364 .54691 .26247 .56962 .25754 .55758 .23792 Metetra
.617 .663 .872 r
.55758 .23792 .56962 .25754 .59257 .25268 .58059 .23211 Metetra
.619 .654 .862 r
.58059 .23211 .59257 .25268 .61577 .24779 .60383 .22607 Metetra
.624 .645 .85 r
.60383 .22607 .61577 .24779 .6392 .24269 .62729 .21957 Metetra
.633 .637 .836 r
.62729 .21957 .6392 .24269 .66285 .23706 .65094 .21224 Metetra
.647 .629 .818 r
.65094 .21224 .66285 .23706 .68669 .23031 .67474 .20349 Metetra
.668 .624 .796 r
.67474 .20349 .68669 .23031 .71061 .22129 .69861 .19233 Metetra
.698 .625 .771 r
.69861 .19233 .71061 .22129 .73442 .20757 .72239 .17734 Metetra
.734 .635 .749 r
.72239 .17734 .73442 .20757 .75761 .18439 .74588 .15701 Metetra
.798 .682 .737 r
.74588 .15701 .75761 .18439 .78005 .15274 .76875 .12894 Metetra
.649 .738 .914 r
.12432 .34801 .1384 .36108 .15774 .35481 .14375 .34155 Metetra
.649 .737 .913 r
.14375 .34155 .15774 .35481 .17723 .3485 .16334 .33504 Metetra
.649 .735 .912 r
.16334 .33504 .17723 .3485 .19689 .34216 .18308 .3285 Metetra
.648 .733 .911 r
.18308 .3285 .19689 .34216 .2167 .33579 .20299 .32192 Metetra
.648 .732 .91 r
.20299 .32192 .2167 .33579 .23667 .3294 .22306 .31533 Metetra
.647 .73 .909 r
.22306 .31533 .23667 .3294 .25681 .32301 .24329 .30871 Metetra
.646 .728 .908 r
.24329 .30871 .25681 .32301 .27711 .31662 .26369 .30209 Metetra
.645 .725 .907 r
.26369 .30209 .27711 .31662 .29758 .31024 .28425 .29548 Metetra
.643 .723 .906 r
.28425 .29548 .29758 .31024 .31821 .30389 .30498 .28887 Metetra
.642 .72 .905 r
.30498 .28887 .31821 .30389 .33902 .29757 .32589 .28228 Metetra
.64 .717 .903 r
.32589 .28228 .33902 .29757 .36001 .29129 .34698 .27572 Metetra
.638 .714 .902 r
.34698 .27572 .36001 .29129 .38117 .28508 .36824 .26919 Metetra
.636 .71 .9 r
.36824 .26919 .38117 .28508 .40252 .27892 .38969 .2627 Metetra
.634 .706 .898 r
.38969 .2627 .40252 .27892 .42406 .27285 .41133 .25625 Metetra
.632 .702 .896 r
.41133 .25625 .42406 .27285 .4458 .26685 .43316 .24986 Metetra
.63 .697 .893 r
.43316 .24986 .4458 .26685 .46773 .26094 .45519 .2435 Metetra
.629 .692 .89 r
.45519 .2435 .46773 .26094 .48987 .25511 .47742 .23718 Metetra
.627 .687 .886 r
.47742 .23718 .48987 .25511 .51222 .24935 .49986 .23086 Metetra
.627 .681 .881 r
.49986 .23086 .51222 .24935 .53479 .24364 .52251 .22452 Metetra
.627 .674 .876 r
.52251 .22452 .53479 .24364 .55758 .23792 .54539 .21808 Metetra
.628 .668 .869 r
.54539 .21808 .55758 .23792 .58059 .23211 .56847 .21145 Metetra
.632 .661 .861 r
.56847 .21145 .58059 .23211 .60383 .22607 .59178 .20448 Metetra
.638 .656 .851 r
.59178 .20448 .60383 .22607 .62729 .21957 .61528 .19693 Metetra
.648 .651 .839 r
.61528 .19693 .62729 .21957 .65094 .21224 .63897 .18849 Metetra
.662 .648 .826 r
.63897 .18849 .65094 .21224 .67474 .20349 .6628 .17868 Metetra
.681 .649 .811 r
.6628 .17868 .67474 .20349 .69861 .19233 .68672 .16687 Metetra
.705 .656 .798 r
.68672 .16687 .69861 .19233 .72239 .17734 .71062 .15241 Metetra
.734 .674 .792 r
.71062 .15241 .72239 .17734 .74588 .15701 .73445 .1351 Metetra
.747 .708 .815 r
.73445 .1351 .74588 .15701 .76875 .12894 .75836 .11797 Metetra
.651 .739 .914 r
.11004 .33476 .12432 .34801 .14375 .34155 .12956 .32809 Metetra
.651 .737 .912 r
.12956 .32809 .14375 .34155 .16334 .33504 .14925 .32138 Metetra
.651 .735 .911 r
.14925 .32138 .16334 .33504 .18308 .3285 .16909 .31462 Metetra
.651 .734 .91 r
.16909 .31462 .18308 .3285 .20299 .32192 .18909 .30783 Metetra
.65 .732 .909 r
.18909 .30783 .20299 .32192 .22306 .31533 .20925 .30101 Metetra
.649 .73 .908 r
.20925 .30101 .22306 .31533 .24329 .30871 .22958 .29417 Metetra
.648 .728 .907 r
.22958 .29417 .24329 .30871 .26369 .30209 .25008 .28731 Metetra
.647 .725 .905 r
.25008 .28731 .26369 .30209 .28425 .29548 .27074 .28044 Metetra
.646 .723 .904 r
.27074 .28044 .28425 .29548 .30498 .28887 .29157 .27356 Metetra
.645 .72 .903 r
.29157 .27356 .30498 .28887 .32589 .28228 .31258 .26669 Metetra
.644 .717 .901 r
.31258 .26669 .32589 .28228 .34698 .27572 .33377 .25983 Metetra
.642 .714 .9 r
.33377 .25983 .34698 .27572 .36824 .26919 .35513 .25298 Metetra
.641 .71 .898 r
.35513 .25298 .36824 .26919 .38969 .2627 .37668 .24615 Metetra
.639 .707 .896 r
.37668 .24615 .38969 .2627 .41133 .25625 .39842 .23933 Metetra
.637 .703 .893 r
.39842 .23933 .41133 .25625 .43316 .24986 .42035 .23253 Metetra
.636 .698 .89 r
.42035 .23253 .43316 .24986 .45519 .2435 .44248 .22574 Metetra
.635 .693 .887 r
.44248 .22574 .45519 .2435 .47742 .23718 .46481 .21893 Metetra
.634 .688 .883 r
.46481 .21893 .47742 .23718 .49986 .23086 .48734 .21209 Metetra
.634 .683 .879 r
.48734 .21209 .49986 .23086 .52251 .22452 .51009 .20518 Metetra
.635 .678 .874 r
.51009 .20518 .52251 .22452 .54539 .21808 .53304 .19811 Metetra
.637 .673 .868 r
.53304 .19811 .54539 .21808 .56847 .21145 .55621 .19081 Metetra
.641 .669 .861 r
.55621 .19081 .56847 .21145 .59178 .20448 .57959 .18312 Metetra
.647 .665 .853 r
.57959 .18312 .59178 .20448 .61528 .19693 .60316 .17486 Metetra
.656 .663 .845 r
.60316 .17486 .61528 .19693 .63897 .18849 .62692 .16576 Metetra
.669 .663 .836 r
.62692 .16576 .63897 .18849 .6628 .17868 .65083 .15551 Metetra
.685 .668 .827 r
.65083 .15551 .6628 .17868 .68672 .16687 .67484 .14377 Metetra
.704 .679 .822 r
.67484 .14377 .68672 .16687 .71062 .15241 .69892 .13028 Metetra
.727 .699 .824 r
.69892 .13028 .71062 .15241 .73445 .1351 .72302 .11506 Metetra
.765 .737 .828 r
.72302 .11506 .73445 .1351 .75836 .11797 .74703 .09706 Metetra
.654 .739 .913 r
.09556 .32132 .11004 .33476 .12956 .32809 .11518 .31444 Metetra
.654 .738 .911 r
.11518 .31444 .12956 .32809 .14925 .32138 .13496 .30751 Metetra
.653 .736 .91 r
.13496 .30751 .14925 .32138 .16909 .31462 .1549 .30053 Metetra
.653 .734 .909 r
.1549 .30053 .16909 .31462 .18909 .30783 .175 .29352 Metetra
.652 .732 .908 r
.175 .29352 .18909 .30783 .20925 .30101 .19526 .28646 Metetra
.652 .73 .906 r
.19526 .28646 .20925 .30101 .22958 .29417 .21569 .27938 Metetra
.651 .728 .905 r
.21569 .27938 .22958 .29417 .25008 .28731 .23628 .27227 Metetra
.65 .725 .904 r
.23628 .27227 .25008 .28731 .27074 .28044 .25704 .26513 Metetra
.649 .723 .902 r
.25704 .26513 .27074 .28044 .29157 .27356 .27798 .25798 Metetra
.648 .72 .901 r
.27798 .25798 .29157 .27356 .31258 .26669 .29909 .25082 Metetra
.647 .717 .899 r
.29909 .25082 .31258 .26669 .33377 .25983 .32038 .24365 Metetra
.646 .714 .897 r
.32038 .24365 .33377 .25983 .35513 .25298 .34185 .23647 Metetra
.645 .711 .895 r
.34185 .23647 .35513 .25298 .37668 .24615 .3635 .22929 Metetra
.643 .707 .893 r
.3635 .22929 .37668 .24615 .39842 .23933 .38534 .2221 Metetra
.642 .703 .891 r
.38534 .2221 .39842 .23933 .42035 .23253 .40737 .2149 Metetra
.641 .699 .888 r
.40737 .2149 .42035 .23253 .44248 .22574 .4296 .20768 Metetra
.64 .695 .885 r
.4296 .20768 .44248 .22574 .46481 .21893 .45203 .20042 Metetra
.64 .691 .881 r
.45203 .20042 .46481 .21893 .48734 .21209 .47466 .19309 Metetra
.64 .686 .877 r
.47466 .19309 .48734 .21209 .51009 .20518 .4975 .18566 Metetra
.641 .682 .873 r
.4975 .18566 .51009 .20518 .53304 .19811 .52054 .17806 Metetra
.643 .678 .868 r
.52054 .17806 .53304 .19811 .55621 .19081 .5438 .17022 Metetra
.647 .675 .862 r
.5438 .17022 .55621 .19081 .57959 .18312 .56726 .162 Metetra
.653 .673 .857 r
.56726 .162 .57959 .18312 .60316 .17486 .59092 .15327 Metetra
.661 .673 .851 r
.59092 .15327 .60316 .17486 .62692 .16576 .61476 .14384 Metetra
.671 .676 .846 r
.61476 .14384 .62692 .16576 .65083 .15551 .63877 .13352 Metetra
.684 .682 .842 r
.63877 .13352 .65083 .15551 .67484 .14377 .66292 .12212 Metetra
.698 .694 .842 r
.66292 .12212 .67484 .14377 .69892 .13028 .68717 .10958 Metetra
.713 .712 .847 r
.68717 .10958 .69892 .13028 .72302 .11506 .71153 .09605 Metetra
.712 .733 .868 r
.71153 .09605 .72302 .11506 .74703 .09706 .73607 .08313 Metetra
.656 .74 .912 r
.08087 .30768 .09556 .32132 .11518 .31444 .10059 .30058 Metetra
.656 .738 .91 r
.10059 .30058 .11518 .31444 .13496 .30751 .12046 .29343 Metetra
.656 .736 .909 r
.12046 .29343 .13496 .30751 .1549 .30053 .1405 .28622 Metetra
.655 .734 .908 r
.1405 .28622 .1549 .30053 .175 .29352 .1607 .27897 Metetra
.655 .732 .906 r
.1607 .27897 .175 .29352 .19526 .28646 .18106 .27168 Metetra
.654 .73 .905 r
.18106 .27168 .19526 .28646 .21569 .27938 .20159 .26434 Metetra
.654 .728 .904 r
.20159 .26434 .21569 .27938 .23628 .27227 .22229 .25697 Metetra
.653 .726 .902 r
.22229 .25697 .23628 .27227 .25704 .26513 .24316 .24957 Metetra
.652 .723 .901 r
.24316 .24957 .25704 .26513 .27798 .25798 .2642 .24213 Metetra
.651 .721 .899 r
.2642 .24213 .27798 .25798 .29909 .25082 .28541 .23467 Metetra
.651 .718 .897 r
.28541 .23467 .29909 .25082 .32038 .24365 .3068 .22718 Metetra
.65 .715 .895 r
.3068 .22718 .32038 .24365 .34185 .23647 .32838 .21967 Metetra
.649 .711 .893 r
.32838 .21967 .34185 .23647 .3635 .22929 .35014 .21213 Metetra
.648 .708 .891 r
.35014 .21213 .3635 .22929 .38534 .2221 .37208 .20457 Metetra
.647 .704 .889 r
.37208 .20457 .38534 .2221 .40737 .2149 .39422 .19698 Metetra
.646 .7 .886 r
.39422 .19698 .40737 .2149 .4296 .20768 .41655 .18934 Metetra
.645 .697 .883 r
.41655 .18934 .4296 .20768 .45203 .20042 .43908 .18165 Metetra
.645 .693 .88 r
.43908 .18165 .45203 .20042 .47466 .19309 .46181 .17388 Metetra
.645 .689 .876 r
.46181 .17388 .47466 .19309 .4975 .18566 .48474 .16599 Metetra
.646 .685 .872 r
.48474 .16599 .4975 .18566 .52054 .17806 .50788 .15794 Metetra
.648 .682 .868 r
.50788 .15794 .52054 .17806 .5438 .17022 .53123 .14966 Metetra
.651 .68 .864 r
.53123 .14966 .5438 .17022 .56726 .162 .55478 .14106 Metetra
.656 .679 .86 r
.55478 .14106 .56726 .162 .59092 .15327 .57854 .13204 Metetra
.662 .68 .857 r
.57854 .13204 .59092 .15327 .61476 .14384 .60248 .12248 Metetra
.67 .684 .854 r
.60248 .12248 .61476 .14384 .63877 .13352 .6266 .11226 Metetra
.679 .691 .854 r
.6266 .11226 .63877 .13352 .66292 .12212 .65089 .10131 Metetra
.69 .702 .856 r
.65089 .10131 .66292 .12212 .68717 .10958 .67532 .0896 Metetra
.701 .718 .863 r
.67532 .0896 .68717 .10958 .71153 .09605 .69989 .07722 Metetra
.721 .743 .869 r
.69989 .07722 .71153 .09605 .73607 .08313 .72454 .06354 Metetra
.658 .741 .911 r
.06597 .29385 .08087 .30768 .10059 .30058 .08579 .28652 Metetra
.658 .739 .909 r
.08579 .28652 .10059 .30058 .12046 .29343 .10576 .27914 Metetra
.658 .737 .908 r
.10576 .27914 .12046 .29343 .1405 .28622 .1259 .2717 Metetra
.658 .735 .907 r
.1259 .2717 .1405 .28622 .1607 .27897 .1462 .2642 Metetra
.657 .733 .905 r
.1462 .2642 .1607 .27897 .18106 .27168 .16667 .25666 Metetra
.657 .731 .904 r
.16667 .25666 .18106 .27168 .20159 .26434 .1873 .24907 Metetra
.657 .729 .902 r
.1873 .24907 .20159 .26434 .22229 .25697 .2081 .24143 Metetra
.656 .726 .901 r
.2081 .24143 .22229 .25697 .24316 .24957 .22908 .23375 Metetra
.655 .724 .899 r
.22908 .23375 .24316 .24957 .2642 .24213 .25022 .22602 Metetra
.655 .721 .898 r
.25022 .22602 .2642 .24213 .28541 .23467 .27154 .21825 Metetra
.654 .718 .896 r
.27154 .21825 .28541 .23467 .3068 .22718 .29304 .21044 Metetra
.653 .715 .894 r
.29304 .21044 .3068 .22718 .32838 .21967 .31472 .20259 Metetra
.653 .712 .892 r
.31472 .20259 .32838 .21967 .35014 .21213 .33659 .1947 Metetra
.652 .709 .889 r
.33659 .1947 .35014 .21213 .37208 .20457 .35864 .18677 Metetra
.651 .705 .887 r
.35864 .18677 .37208 .20457 .39422 .19698 .38088 .17879 Metetra
.65 .702 .884 r
.38088 .17879 .39422 .19698 .41655 .18934 .40332 .17075 Metetra
.65 .698 .881 r
.40332 .17075 .41655 .18934 .43908 .18165 .42595 .16264 Metetra
.65 .695 .878 r
.42595 .16264 .43908 .18165 .46181 .17388 .44878 .15445 Metetra
.65 .691 .875 r
.44878 .15445 .46181 .17388 .48474 .16599 .47182 .14615 Metetra
.65 .688 .872 r
.47182 .14615 .48474 .16599 .50788 .15794 .49506 .13771 Metetra
.652 .685 .869 r
.49506 .13771 .50788 .15794 .53123 .14966 .5185 .12907 Metetra
.654 .684 .866 r
.5185 .12907 .53123 .14966 .55478 .14106 .54215 .12019 Metetra
.657 .684 .864 r
.54215 .12019 .55478 .14106 .57854 .13204 .566 .111 Metetra
.661 .685 .862 r
.566 .111 .57854 .13204 .60248 .12248 .59006 .10142 Metetra
.667 .689 .862 r
.59006 .10142 .60248 .12248 .6266 .11226 .6143 .0914 Metetra
.673 .696 .863 r
.6143 .0914 .6266 .11226 .65089 .10131 .63873 .0809 Metetra
.68 .706 .867 r
.63873 .0809 .65089 .10131 .67532 .0896 .66333 .06992 Metetra
.687 .72 .874 r
.66333 .06992 .67532 .0896 .69989 .07722 .6881 .05856 Metetra
.684 .734 .888 r
.6881 .05856 .69989 .07722 .72454 .06354 .71309 .0475 Metetra
.661 .741 .91 r
.05085 .27982 .06597 .29385 .08579 .28652 .07077 .27225 Metetra
.661 .739 .908 r
.07077 .27225 .08579 .28652 .10576 .27914 .09085 .26463 Metetra
.66 .737 .907 r
.09085 .26463 .10576 .27914 .1259 .2717 .11109 .25695 Metetra
.66 .735 .905 r
.11109 .25695 .1259 .2717 .1462 .2642 .13149 .24921 Metetra
.66 .733 .904 r
.13149 .24921 .1462 .2642 .16667 .25666 .15207 .24141 Metetra
.66 .731 .903 r
.15207 .24141 .16667 .25666 .1873 .24907 .1728 .23356 Metetra
.659 .729 .901 r
.1728 .23356 .1873 .24907 .2081 .24143 .19371 .22564 Metetra
.659 .727 .899 r
.19371 .22564 .2081 .24143 .22908 .23375 .21479 .21768 Metetra
.658 .724 .898 r
.21479 .21768 .22908 .23375 .25022 .22602 .23605 .20965 Metetra
.658 .722 .896 r
.23605 .20965 .25022 .22602 .27154 .21825 .25748 .20158 Metetra
.658 .719 .894 r
.25748 .20158 .27154 .21825 .29304 .21044 .27909 .19344 Metetra
.657 .716 .892 r
.27909 .19344 .29304 .21044 .31472 .20259 .30088 .18525 Metetra
.656 .713 .89 r
.30088 .18525 .31472 .20259 .33659 .1947 .32286 .177 Metetra
.656 .71 .888 r
.32286 .177 .33659 .1947 .35864 .18677 .34502 .1687 Metetra
.655 .707 .885 r
.34502 .1687 .35864 .18677 .38088 .17879 .36737 .16033 Metetra
.655 .703 .882 r
.36737 .16033 .38088 .17879 .40332 .17075 .38991 .1519 Metetra
.654 .7 .88 r
.38991 .1519 .40332 .17075 .42595 .16264 .41265 .14339 Metetra
.654 .696 .877 r
.41265 .14339 .42595 .16264 .44878 .15445 .43559 .1348 Metetra
.654 .693 .874 r
.43559 .1348 .44878 .15445 .47182 .14615 .45872 .12612 Metetra
.654 .69 .872 r
.45872 .12612 .47182 .14615 .49506 .13771 .48206 .11732 Metetra
.654 .688 .869 r
.48206 .11732 .49506 .13771 .5185 .12907 .50561 .10838 Metetra
.655 .687 .867 r
.50561 .10838 .5185 .12907 .54215 .12019 .52936 .09928 Metetra
.657 .686 .866 r
.52936 .09928 .54215 .12019 .566 .111 .55331 .08998 Metetra
.659 .688 .866 r
.55331 .08998 .566 .111 .59006 .10142 .57747 .08046 Metetra
.662 .691 .867 r
.57747 .08046 .59006 .10142 .6143 .0914 .60184 .07067 Metetra
.666 .698 .87 r
.60184 .07067 .6143 .0914 .63873 .0809 .62641 .06061 Metetra
.67 .707 .875 r
.62641 .06061 .63873 .0809 .66333 .06992 .65117 .05029 Metetra
.674 .719 .882 r
.65117 .05029 .66333 .06992 .6881 .05856 .67614 .03972 Metetra
.682 .734 .89 r
.67614 .03972 .6881 .05856 .71309 .0475 .70129 .02871 Metetra
.663 .742 .908 r
.03551 .26557 .05085 .27982 .07077 .27225 .05553 .25777 Metetra
.663 .74 .907 r
.05553 .25777 .07077 .27225 .09085 .26463 .07571 .24991 Metetra
.663 .738 .906 r
.07571 .24991 .09085 .26463 .11109 .25695 .09606 .24198 Metetra
.663 .736 .904 r
.09606 .24198 .11109 .25695 .13149 .24921 .11657 .23399 Metetra
.662 .734 .903 r
.11657 .23399 .13149 .24921 .15207 .24141 .13725 .22593 Metetra
.662 .732 .901 r
.13725 .22593 .15207 .24141 .1728 .23356 .1581 .21781 Metetra
.662 .73 .9 r
.1581 .21781 .1728 .23356 .19371 .22564 .17912 .20962 Metetra
.662 .728 .898 r
.17912 .20962 .19371 .22564 .21479 .21768 .20031 .20137 Metetra
.662 .725 .896 r
.20031 .20137 .21479 .21768 .23605 .20965 .22167 .19304 Metetra
.661 .723 .895 r
.22167 .19304 .23605 .20965 .25748 .20158 .24322 .18465 Metetra
.661 .72 .893 r
.24322 .18465 .25748 .20158 .27909 .19344 .26494 .17618 Metetra
.661 .717 .891 r
.26494 .17618 .27909 .19344 .30088 .18525 .28684 .16765 Metetra
.66 .714 .888 r
.28684 .16765 .30088 .18525 .32286 .177 .30893 .15904 Metetra
.66 .711 .886 r
.30893 .15904 .32286 .177 .34502 .1687 .3312 .15037 Metetra
.659 .708 .884 r
.3312 .15037 .34502 .1687 .36737 .16033 .35367 .14162 Metetra
.659 .705 .881 r
.35367 .14162 .36737 .16033 .38991 .1519 .37632 .13279 Metetra
.658 .701 .878 r
.37632 .13279 .38991 .1519 .41265 .14339 .39917 .12389 Metetra
.658 .698 .876 r
.39917 .12389 .41265 .14339 .43559 .1348 .42221 .11491 Metetra
.657 .695 .873 r
.42221 .11491 .43559 .1348 .45872 .12612 .44545 .10585 Metetra
.657 .692 .871 r
.44545 .10585 .45872 .12612 .48206 .11732 .46889 .09672 Metetra
.656 .689 .869 r
.46889 .09672 .48206 .11732 .50561 .10838 .49254 .08751 Metetra
.656 .688 .868 r
.49254 .08751 .50561 .10838 .52936 .09928 .51639 .07822 Metetra
.656 .687 .868 r
.51639 .07822 .52936 .09928 .55331 .08998 .54045 .06884 Metetra
.656 .688 .868 r
.54045 .06884 .55331 .08998 .57747 .08046 .56472 .05938 Metetra
.657 .691 .871 r
.56472 .05938 .57747 .08046 .60184 .07067 .58921 .04984 Metetra
.657 .696 .875 r
.58921 .04984 .60184 .07067 .62641 .06061 .61392 .04022 Metetra
.659 .704 .881 r
.61392 .04022 .62641 .06061 .65117 .05029 .63884 .03051 Metetra
.66 .715 .888 r
.63884 .03051 .65117 .05029 .67614 .03972 .66399 .02071 Metetra
.662 .728 .898 r
.66399 .02071 .67614 .03972 .70129 .02871 .68936 .01082 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.1552 .20892 m
.15981 .21359 L
s
[(0.2)] .14598 .19958 .98733 1 Mshowa
.27893 .16047 m
.28333 .16533 L
s
[(0.4)] .27013 .15073 .90393 1 Mshowa
.40878 .10962 m
.41294 .11469 L
s
[(0.6)] .40046 .09948 .82054 1 Mshowa
.54521 .0562 m
.54911 .06148 L
s
[(0.8)] .53743 .04564 .73714 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.18558 .19702 m
.18832 .19985 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.3108 .14799 m
.31341 .15094 L
s
.34306 .13535 m
.34564 .13834 L
s
.37572 .12257 m
.37826 .12558 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.51046 .06981 m
.51284 .07294 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
gsave
.29165 .07573 -70.3112 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00m_ooool4o`000003oa0@4?oooooooooo06_ooooo003hooooo`03o`00
0?oooooooooo06gooooo003hooooo`03o`000?oooooooooo06gooooo003hooooo`03o`000?oooooo
oooo06gooooo003hooooo`03o`000?oooooooooo06gooooo003hooooo`03o`000?oooooooooo06go
oooo003hooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1Qooooo`00
m_ooool00omEEEGoIVIVo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0HOooool00?oooooo
0oooool01Ol@413ooooooooooooooooo410@067ooooo003oooooo`?ooooo00Go0000oooooooooooo
ooooo`00001Qooooo`00ooooool3ooooo`05o`000?ooooooooooooooool00000HOooool00?oooooo
0oooool01Ol@413ooooooooooooooooo410@067ooooo003looooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg067ooooo003iooooo`?o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^067ooooo003gooooo`;o00001?ooool2o`0006Wooooo003dooooo`?o00001_oo
ool00ol0003oooooo`00001Xooooo`00l_ooool2o`0000Sooooo0_l000000ooooooo0000ooooo`1W
ooooo`00koooool4o`0000Kooooo0ol000001OnY^^Go0000oooooooooooo000006Oooooo002ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<
c00Nooooo`?o00000oooool01?l0003oooooooooooooool3o`0000CoZK[U0_l00002ooooo`03o`00
0?oooooooooo06Cooooo002iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@0Looooo`;o00002?ooool2o`0000OoZK[U00Go0000ojVjiOl0
003oooooo`00001Vooooo`00^Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`?o00001oooool3o`000003ojRghol0003oZK[U00KoZK[U00Ko0000
ojVjiOnY^^Go0000ooooool0001Uooooo`00^Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P0Gooooo`;o00001oooool3o`0000GoZ;OS00?o0000ojVjiOnY
^^D01OnY^^D00ol0003oZK[Uo`000003o`0006Cooooo002iooooo`05o`000?ooooooooooooooool0
00002oooool01Oo<c<co0000o`000?l0003oc<c<01Cooooo0ol00002ooooo`03o`000?oooooooooo
00;ooooo0_l00009ojRgh`03o`000?nY^^GoZK[U00CoZK[U0_l000001?n^^n?o0000ooooool0001T
ooooo`00^Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
400Booooo`;o00001oooool3o`000003ojRdhOl0003oZ;OS00SoZ;OS00?o0000ojVjiOnY^^D00_nY
^^D3o`0000?o[[_S00?o0000ooooool00000Hoooool00;Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000003oooool3o`0000Kooooo0ol00005ojRdh@03o`00
0?nX]n?oZ;OS00OoZ;OS00Co0000ojVjiOl0003o00000_n^^n<00ol0003o[[_Sojjkh`02ojjkh`03
o`000?oooooo000006;ooooo002iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo
410@o`000?l@413oZJVY00gooooo0_l00007ooooo`;o00002OnX]>400ol0003oZ;OSojRgh`06ojRg
h`;o00001?n^^n<00ol0003o[[_Sojjkh`02ojjkh`03o`000?oooooo000006;ooooo001gooooo`;o
00000_ooool2o`0005_ooooo1?l00005ooooo`?o000000?oZ;;Oo`000?nX]>402?nX]>400ol0003o
Z;OSojRgh`03ojRgh`?o000000?o[;SQo`000?n^^n<00on^^n<00ol0003o[[_Sojjkh`03ojjkh`03
o`000?oooooo0000067ooooo001gooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgMFOooool2o`00
00Cooooo00?o0000ooooooooool00_l00005ojRbg`03o`000?nX]>7oZ;CQ00OoZ;CQ00?o0000ojRg
hol000000_l00005ojbhh@05o`000?n^^n?o[[_Sojjkhol000001On^^n<3o`00067ooooo001hoooo
o`04omgMgOl0003o410@olc<c5Oooooo0ol00007ooooo`;o00001onX/]l00ol0003oZ;CQojRdh@07
ojRdh@;o00002On/^>401?l0003o[[_Sojjkhol00003ojjkh`;o000000Co[k_So`000?oooooo0000
H?ooool007Sooooo00Cok^k^ob4Q8Ol@413ok^k^E?ooool3o`0000Oooooo0ol000000onX/=ko0000
ojRbg`07ojRbg`03o`000?nX]>7oZ;CQ00CoZ;CQ0_l000000on[]=oo0000ojbhh@08ojbhh@05o`00
0?n^^n?o[[_So`000?n^^n<00_l00004ojnkh`?o0000Goooool007Sooooo00Co8B4QogMgMomgMgOo
<S8bD_ooool3o`0000Kooooo0ol00005ojR`gP03o`000?nX/]ooZ;;O00KoZ;;O00Co0000ojRdhOnX
]>7oZ;CQ0_l00004oj^dg`03o`000?n/^>7o[;SQ00Oo[;SQ00Co0000ojjkhol0003o00001on_^n<2
o`0005oooooo001gooooo`;o00000_ooool2o`0004kooooo0ol00002ooooo`03o`000?oooooooooo
00;ooooo0_l00008ojR`gP03o`000?nX/]ooZ;;O00KoZ;;O00Co0000ojRdhOl0003o00001on[]=l0
0ol0003o[;SQojbhh@06ojbhh@?o00002?n_^n<00ol0003oooooo`00001Nooooo`00bOooool2o`00
00Kooooo1?l000000onW/=ko0000ojR`gP08ojR`gP03o`000?nX/]ooZ;;O00GoZ;;O0_l00009oj^d
g`03o`000?n/^>7o[;SQ00?o[;SQ0ol000000on_^=oo0000o`000008ojnkh`;o000000?oooooo`00
0?ooool0G?ooool00<Kooooo0ol00006ooooo`?o00001OnW/=h00ol0003oZ;3NojR`gP07ojR`gP04
o`000?nX/]ooZ;;OojRbg`?o000000?oZ[;No`000?n[]=l02On[]=l00ol0003o[;SQo`000002o`00
00Go[kSO00?o0000ojnkhon_^n<01On_^n<01Ol0003o^;kNo`000?oooooo000005gooooo0034oooo
o`;o00001oooool2o`0000SoYk3N00?o0000ojR`g_nX/=h01onX/=h01?l0003oZ;;Oo`000?l00005
ojZbgP03o`000?n[]=ooZkCO00OoZkCO0_l00008ojnhg`;o00001?n_^n<2o`0000?o^;kN00?o0000
ooooool00000G?ooool008gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<01oooooo0ol000000ooooooo0000ooooo`03ooooo`?o000000?o
YjoNo`000?nW/=h02?nW/=h00ol0003oZ;3NojR`gP06ojR`gP;o00002?nZ/]h00ol0003oZkCOoj^d
g`04oj^dg`;o000000?o[[CMo`000?n_^=l01on_^=l2o`0000?o[k_S00?o0000okRng_nh_]h00onh
_]h01?l0003oooooooooool0001Kooooo`00SOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B407Oooool2o`0000Kooooo0ol00005ojN_gP03
o`000?nW/=koYk3N00OoYk3N00?o0000ojR`g_nX/=h00_nX/=h3o`000003ojV`gOl0003oZ[;N00Oo
Z[;N00?o0000oj^dgon[]=l00_n[]=l2o`0000Co[[CM00?o0000ojnhgon_^=l01_n_^=l2o`000003
ojnkhol0003o^;kN00Ko^;kN00?o0000ooooool00000Foooool008gooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05o`000?ooooooooooooooool000006_ooool3o`0000Kooooo0_l00008ojN_
gP03o`000?nW/=koYk3N00OoYk3N00?o0000ojR`g_l000000_l00005ojV`g@03o`000?nZ/]koZ[;N
00KoZ[;N00Co0000oj^dgol0003o00001_n^]=d00ol0003o[kSOojnhg`06ojnhg`?o00002Onh_]h3
o`0005[ooooo002=ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonH
V9So8B4Q01Sooooo0_l00006ooooo`?o000000?oYk3No`000?nW[mh02?nW[mh00ol0003oYk3NojN`
gP06ojN`gP;o00002OnY/=d00ol0003oZ[;NojZbgP05ojZbgP;o00002On^]=d00ol0003o[kSOojnh
g`04ojnhg`;o000000?o/kOLo`000?nh_]h02?nh_]h01?l0003oooooooooool00008ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000looooo`00SOooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c00Eooooo`Co00001Oooool2o`00
00GoYk3N00?o0000ojN_g_nW[mh01onW[mh00ol0003oYk3NojN`gP02ojN`gP?o000000?oZ;3Mo`00
0?nY/=d02?nY/=d00ol0003oZ[;NojZbgP02ojZbgP?o000000?o[;;Lo`000?n^]=d02On^]=d01?l0
003o[kSOojnhgon_^=l2o`000005ok>gg?l0003o/kOLok>gg?l000002?nh_]h2o`000003ooooool0
003ooooo00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A403cooooo002=ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`0Eooooo`;o00000oooool01?l0003oooooooooooooool2o`0000SoYk3N00?o0000ojN_
g_nW[mh01_nW[mh00ol0003oYk3No`000002o`0000GoZ;3M00?o0000ojV`gOnY/=d01onY/=d01?l0
003oZ[;No`000?l00005ojbbg003o`000?n^]=go[[CM00Oo[[CM00Co0000ojnhgol0003o00000onc
]m`01?l0003o/kOLok>gg?l00006okRngP;o00000_nf^mh00ol0003oooooo`000007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0mooooo`00SOooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P04_ooool3o`0000Kooooo0ol000000onW/=ko
0000ojN`gP08ojN`gP03o`000?nW[mkoYjoN00GoYjoN0_l00009ojR`g@03o`000?nY/=goZK3M00Ko
ZK3M0_l00008ojbbg003o`000?n^]=go[[CM00Ko[[CM0_l00005ok>gg005o`000?nc]mco/kOLok>g
g?l000000onh_]h2o`0000Go][_N00?o0000ooooool000001_ooool01Ol0003ooooooooooooooooo
000000gooooo00?oV9RHob4Q8Oo^k^h0??ooool008gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`04olc<c?m4A4Co0000oa0@40gooooo0ol00006ooooo`?o00001OnW/=h00ol0003oYk3NojN`
gP06ojN`gP03o`000?nW[mkoYjoN00;oYjoN0ol000000onX[mgo0000ojR`g@08ojR`g@03o`000?nY
/=goZK3M00?oZK3M0ol000000onZ/=co0000ojbbg007ojbbg003o`000?n^]=go[[CM00?o[[CM0ol0
00000on`/m_o0000ok>gg004ok>gg006o`000?nc]mco/kOLok>gg?l0003o^;kN0_l00008okJkgP;o
00001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0>oooool00:go
oooo0ol00006ooooo`;o00002?nW/=h00ol0003oYk3NojN`gP07ojN`gP04o`000?nW[mko0000o`00
00GoZ:oM00?o0000ojR`gOnX/=d01onX/=d00ol0003oZK3Mo`000002o`0000GoZ[3L00?o0000ojbb
g?n//]`01_n//]`00ol0003o[[CMo`000002o`0000Go/;?K00?o0000ok>gg?nc]m`00_nc]m`01?l0
003o/kOLok>gg?nc]m`2o`0000[o][_N0ol00005ooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0jooooo`00Z_ooool3o`0000?ooooo00?o0000ooooooooool00ol00000
0onX/Mko0000ojN`gP08ojN`gP03o`000?nW/=koYk3N00KoYk3N0_l00008ojR_g@03o`000?nX/=go
Z;3M00KoZ;3M0_l00008ojZ`g003o`000?n//]co[;;L00Ko[;;L0_l00009ok2cf`06o`000?nc]mco
/kOLok>gg?l0003o/kOL0_l000000onf]]So0000okJkgP08okJkgP05o`000?o3_=?o0000ooooool0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400l
ooooo`00Z?ooool2o`0000Oooooo0_l00005ojRagP03o`000?nW/=koYk3N00OoYk3N00?o0000ojN`
g_nW/=h00_nW/=h3o`000003ojN_gOl0003oZ:oM00OoZ:oM00?o0000ojR`gOnX/=d00onX/=d3o`00
0003ojV_g?l0003oZ[3L00SoZ[3L00?o0000ojbbg?n//]`00on//]`2o`000003ojf`f_l0003o/;?K
00So/;?K00Co0000ok>gg?nc]mco/kOL0_l00004okJff003o`000?nf^mko][_N00Go][_N00Co0000
ol>ldoo3_=?o`kcC0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<03cooooo002Uooooo`?o00001oooool2o`0000SoZ;7N00?o0000ojN`g_nW/=h0
1_nW/=h00ol0003oYk3No`000002o`0000GoYjoM00?o0000ojR_gOnX[md01_nX[md00ol0003oZ;3M
o`000002o`0000GoZJoL00?o0000ojZ`g?nZ/=`01_nZ/=`01?l0003o[;;Lojbbg?n//]`2o`0000Co
[K3J00?o0000ok2cfon`/m/01on`/m/01?l0003o/kOLo`000?l00006okJff003o`000?nf^mko][_N
00;o][_N0_l00004ol>ld`03o`000?oooooo000005Cooooo002Sooooo`;o00001oooool3o`000003
ojRagol0003oZ;7N00SoZ;7N00?o0000ojN`g_nW/=h01?nW/=h3o`0000WoYjoM00?o0000ojR_gOnX
[md01OnX[md2o`0000SoZJoL00?o0000ojZ`g?nZ/=`01_nZ/=`01?l0003o[;;Lo`000?l00006ojf`
fP03o`000?n`/m_o/;?K00Oo/;?K0_l000000onf]]So0000okJff005okJff005o`000?nf^mko][_N
okJkg_l000001oo3_=<00ol0003oooooo`00001Cooooo`00X?ooool3o`0000;ooooo00?o0000oooo
ooooool00_ooool2o`0000GoZ;7O00?o0000ojRag_nX/Mh01onX/Mh00ol0003oYk3NojN`gP03o`00
00;oYk3N00?o0000ojN_gOnW[md01onW[md00ol0003oZ:oMojR_g@02ojR_g@?o000000?oZ:oMo`00
0?nY[m`02?nY[m`00ol0003oZ[3LojZ`g005ojZ`g0;o00002On]/=X00ol0003o/;?Kok2cf`04ok2c
f`;o000000Co/[7Go`000?nf]]So00001onf]]P00ol0003o][_No`000008ol>ld`03o`000?oooooo
000005?ooooo002Nooooo`;o00001_ooool01?l0003oooooo`000?l00008ojRag`03o`000?nX/Mko
Z;7N00KoZ;7N0ol00006ojN`gP03o`000?nW[mgoYjoM00OoYjoM00Co0000ojR_gOl0003o00001OnX
[md00ol0003oZJoLojV_g007ojV_g004o`000?nZ/=coZ[3LojZ`g0?o000000?oZjoJo`000?n]/=X0
2On]/=X01?l0003o/;?Kok2cfon`/m/2o`0000Co/[7G0_l00007okJff0;o00002Oo3_=<01?l0003o
ooooooooool0001Booooo`00Voooool3o`0000Oooooo0ol000000onX/^3o0000ojRag`07ojRag`03
o`000?nX/MkoZ;7N00?oZ;7N0ol000000onW/=oo0000ojN`gP07ojN`gP03o`000?nW[mgoYjoM00Ko
YjoM0_l00007ojR_g@03o`000?nY[mcoZJoL00OoZJoL00Co0000ojZ`g?l0003o00001On[[mX00ol0
003o[K3Jojf`fP07ojf`fP04o`000?n`/m_o0000o`0000Ko/[7G0_l00006okJff003o`000?nj/];o
000000Wo`kcC0ol000000ooooooo0000ooooo`1@ooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool07oooool2o`0000Oooooo0ol00005
ojRbh003o`000?nX/MooZ;7O00KoZ;7O00?o0000ojRag_l000000_l00005ojN`g`03o`000?nW/=ko
Yk3N00GoYk3N00?o0000ojN_gOnW[md00onW[md3o`000003ojN_gOl0003oZ:oM00OoZ:oM00?o0000
ojV_g?nY[m`01_nY[m`2o`0000OoZjoJ00?o0000ojf`f_n]/=X01on]/=X2o`0000Wo/[7G00?o0000
okJff?nf]]P00_nf]]P2o`0000?o^[;B00?o0000ol>ldoo3_=<01Oo3_=<01?l0003o_kG@okned?no
]M02o`00057ooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool07Oooool3o`0000;ooooo00Co0000oooooooooooooooo0ol00009ojRbh003o`00
0?nX/MooZ;7O00GoZ;7O0_l00008ojN`g`03o`000?nW/=koYk3N00KoYk3N00?o0000ojN_gOl00000
0_l00005ojN_g@03o`000?nX[mgoZ:oM00KoZ:oM00?o0000ojV_g?nY[m`00_nY[m`3o`000003ojV^
fol0003oZjoJ00OoZjoJ00?o0000ojf`f_n]/=X01?n]/=X2o`000003ojn^eol0003o/[7G00So/[7G
0_l000000onf]]So0000o`000006okZbdP03o`000?o3_=?o`kcC00;o`kcC0_l00005okned0;o0000
D?ooool006?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00006oooool3o`0000Kooooo
0ol00002ojRch003o`000?nX/^3oZ;;P00OoZ;;P00?o0000ojRagonX/Ml00_nX/Ml3o`000003ojNa
gol0003oYk3O00SoYk3O00?o0000ojN`g_nW/=h01OnW/=h2o`0000SoYjoM00?o0000ojR_gOnX[md0
1_nX[md00ol0003oZJoLo`000002o`0000GoZJkK00?o0000oj^_f_n[[mX01_n[[mX01?l0003o[K3J
ojf`f_n]/=X2o`0000Co[jkG00?o0000ok:aeonb/ML01_nb/ML3o`0000So^[;B00Go0000ol>ldoo3
_=?o`kcCo`000008okned0;o0000Coooool006?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0001[ooooo0_l00006ooooo`?o00001_nX/n000ol0003oZ;;PojRbh007
ojRbh004o`000?nX/Moo0000o`0000GoYk7O00?o0000ojN`gonW/=l01onW/=l01?l0003oYk3NojN`
g_nW/=h3o`000003ojJ_g_l0003oYjoM00SoYjoM00?o0000ojR_gOnX[md01OnX[md2o`0000SoZJkK
00?o0000oj^_f_n[[mX01_n[[mX01?l0003o[K3Jo`000?l00006ojn^e`03o`000?nb/MOo/[7G00Ko
/[7G0_l0000:okZbdP03o`000?o3_=?o000000Wo_kG@0_l0001?ooooo`00Hoooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00005oooool3o`0000Gooooo0ol000000onX
]>7o0000ojRch007ojRch003o`000?nX/^3oZ;;P00KoZ;;P0_l00007ojNag`03o`000?nW/=ooYk3O
00OoYk3O00Co0000ojN`g_l0003o00001OnV[mh00ol0003oYjoMojN_g@07ojN_g@04o`000?nX[mgo
Z:oMojR_g@?o000000?oYjgLo`000?nY[]/02?nY[]/00ol0003oZjoJoj^_fP05oj^_fP;o00002On_
[]L00ol0003o/[7Gok:ae`03ok:ae`;o000000?o]:gBo`000?nj/]802Onj/]82o`0000Wo_kG@00Co
0000olb^_?l0003o0000C_ooool006?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000001Gooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00001OnX]>400ol0003o
Z;?PojRch006ojRch003o`000?nX/^3oZ;;P00;oZ;;P0ol000000onW/^3o0000ojNag`07ojNag`03
o`000?nW/=ooYk3O00KoYk3O0_l00007ojJ_gP03o`000?nW[mgoYjoM00OoYjoM00Co0000ojR_gOl0
003o00001OnW[M`00ol0003oZJkKojV^f`07ojV^f`04o`000?n[[m[oZjoJoj^_fP?o000000?oZjgH
o`000?n_[]L02On_[]L01Ol0003o/[7Gok:aeonb/MOo000000?o]:gB0_l00008okZbdP03o`000?nk
[<[o000000So_kG@00?o0000olb^_?o<[[`00_l0001>ooooo`00Hoooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000004_ooool3o`0000Kooooo0_l00008ojRdh@03o`000?nX
/n3oZ;?P00KoZ;?P00Co0000ojRbh?l0003o00001OnW/^000ol0003oYk7OojNag`06ojNag`03o`00
0?nW/=ooYk3O00;oYk3O0ol000000onV/=oo0000ojJ_gP07ojJ_gP03o`000?nW[mgoYjoM00KoYjoM
0_l00007ojN]g003o`000?nY[]_oZJkK00OoZJkK00Co0000oj^_f_l0003o00001On[[MP00ol0003o
[jkGojn^e`07ojn^e`04o`000?nb/MOo0000o`0000Co]:gB0_l00007okZbdP05o`000?nk[<[o^jc:
ok^/b_l000001_no]M001ol0003oc:jlolb^_?o<[[co0000ooooool00000COooool006?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00oooooo0_l00006ooooo`?o0000
00?oZ;GRo`000?nX]>401onX]>400ol0003oZ;?PojRch005ojRch0?o00002?nW/^000ol0003oYk7O
ojNag`05ojNag`03o`000?nW/=oo000000;o00001OnV/=l00ol0003oYZoNojJ_gP06ojJ_gP03o`00
0?nW[mgoYjoM00;oYjoM0ol000000onV[]go0000ojN]g007ojN]g003o`000?nY[]_oZJkK00KoZJkK
0_l00007oj^]f003o`000?n_[]Oo[jkG00Oo[jkG0_l00006okB]dP03o`000?nd[M;o000000Co^[;B
0_l00004ok^/bP03o`000?no]M3o_kG@00?o_kG@00?o0000olb^_?o<[[`00oo<[[`00ol0003ooooo
o`00001<ooooo`00Q?ooool3o`0000Kooooo0_l00005ojRehP03o`000?nX]>7oZ;CQ00KoZ;CQ00?o
0000ojRch?nX/n001?l00002ojNch@03o`000?nW/^3oYk;P00KoYk;P00?o0000ojNagonW/Ml01?nW
/Ml3o`0000WoY[3O00?o0000ojJ_g_nV[mh01OnV[mh00ol0003oYjoMo`000002o`0000GoYZkM00?o
0000ojN]g?nW[M`01_nW[M`00ol0003oZJkKojV^f`02ojV^f`?o000000?oZJcIo`000?n[[MP01on[
[MP00ol0003o[jkGojn^e`04ojn^e`;o000000?o[j_Co`000?nd[M801Ond[M801?l0003o]:gBokB]
d_l00002okZbdP03o`000?nk[<[o^jc:00Go^jc:00Go0000okned?no]M3o_kG@o`000006olb^_003
o`000?oooooo000004cooooo0022ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`;o0000
2?nX]N800ol0003oZ;CQojRdh@05ojRdh@?o00001onW/n400ol0003oYk;PojNbh006ojNbh003o`00
0?nW/MooYk7O00?o00000_nV/=l00ol0003oY[3OojJ`g`07ojJ`g`03o`000?nV[mkoYZoN00CoYZoN
0ol00008ojJ^g@03o`000?nW[McoYjgL00KoYjgL00?o0000ojV^fol000000_l00005ojV/f@03o`00
0?n[[MSoZjgH00KoZjgH00Co0000ojn^eon_[]Oo[jkG0_l00004ojn[d`03o`000?nd[M;o]:gB00?o
]:gB00Ko0000okB]d_nd[M;o0000okZbd_l00008ok^/bP04o`000?no]M3o_kG@o`0000Ooc:jl00Co
0000ooooool0003o0000Boooool007oooooo0ol00006ooooo`?o000000?oZ;KRo`000?nX]N801onX
]N800ol0003oZ;CQojRdh@02ojRdh@?o000000?oYk?Qo`000?nW/n402?nW/n400ol0003oYk;PojNb
h005ojNbh0?o00001_nV/=l00ol0003oY[3OojJ`g`07ojJ`g`03o`000?nV[mkoYZoN00?o00000_nU
[]h00ol0003oYZkMojJ^g@07ojJ^g@03o`000?nW[McoYjgL00GoYjgL0_l00008ojV/f@03o`000?n[
[MSoZjgH00KoZjgH00Co0000ojn^eol0003o00001_n_Zm<00ol0003o]:gBokB]dP03okB]dP03o`00
0?nd[M;o]:gB00;o00002Onk[<X00ol0003o_kG@o`000009olb^_0;o000000?oooooo`000?ooool0
BOooool007gooooo0_l00007ooooo`;o00001OnX]^800ol0003oZ;GRojRehP06ojRehP04o`000?nX
]>7o0000o`0000GoYk?Q00?o0000ojNchOnW/n401_nW/n400ol0003oYk;PojNbh002ojNbh0?o0000
00?oY[7Po`000?nV/=l01onV/=l00ol0003oY[3OojJ`g`06ojJ`g`?o00001_nU[]h00ol0003oYZkM
ojJ^g@07ojJ^g@04o`000?nW[McoYjgLojN]g0?o000000?oYjcKo`000?nY[=T02?nY[=T00ol0003o
ZjgHoj^]f005oj^]f0;o00002On_Zm<00ol0003o]:gBokB]dP02okB]dP?o000000?o]:O<o`000?nk
[<X02Onk[<X00ol0003oc:jlolb^_008olb^_004o`000?nnU:co0000o`0004[ooooo001jooooo`?o
00001_ooool3o`0000SoZ;KR00?o0000ojReh_nX]N801OnX]N82o`0000SoYk?Q00?o0000ojNchOnW
/n401_nW/n401?l0003oYk;Po`000?l00005ojJah003o`000?nV/=ooY[3O00GoY[3O00?o0000ojJ`
gonV/=l00onV/=l3o`000003ojF_gol0003oYJkN00OoYJkN00?o0000ojJ^gOnV[]d01_nV[]d01?l0
003oYjgLo`000?l00005ojN/f`03o`000?nY[=WoZJcI00OoZJcI00Co0000oj^]f?n[[MSoZjgH0ol0
00000on[ZMKo0000ojn[d`09ojn[d`05o`000?nd[M;o]:gBokB]d_l000001?ndYl`00ol0003o^jc:
ok^/bP06ok^/bP;o00002Oo<[[`01?l0003o_YB/okjD[?nnU:`2o`0004Wooooo001gooooo`?o0000
0_ooool01?l0003oooooooooooooool3o`0000;oZ;KS00?o0000ojRfh_nX]^801_nX]^800ol0003o
Z;GRojRehP02ojRehP?o000000?oYkCRo`000?nW/n402?nW/n400ol0003oYk?QojNch@04ojNch@?o
00002?nV/N000ol0003oY[3OojJ`g`05ojJ`g`03o`000?nV/=oo000000;o00001OnU[ml00ol0003o
YJkNojF^gP05ojF^gP03o`000?nV[]goYZkM00GoYZkM0ol00007ojN/f`03o`000?nY[=WoZJcI00Oo
ZJcI00Co0000oj^]f?l0003o00001On[ZMH00ol0003o[j_Cojn[d`07ojn[d`03o`000?nd[M;o0000
00;o00001?ndYl`00ol0003o^jc:ok^/bP05ok^/bP04o`000?nkX[oo^j:oo`0000Ooc:jl00?o0000
okjD[?nnU:`00_nnU:`00ol0003oooooo`000018ooooo`00MOooool2o`0000Kooooo0ol00006ojRf
h`03o`000?nX]^;oZ;KR00KoZ;KR00Co0000ojReh_l0003o00001OnW]>800ol0003oYk?QojNch@07
ojNch@03o`000?nW/n7oYk?Q00?o00000_nV/^400ol0003oY[7PojJah006ojJah003o`000?nV/=oo
Y[3O00CoY[3O0ol00008ojF_g`03o`000?nU[]koYJkN00KoYJkN00?o0000ojJ^gOnV[]d01?l00002
ojF/g003o`000?nW[=_oYjcK00KoYjcK00?o0000ojV/fOnY[=T01_nY[=T2o`0000OoZjWF00?o0000
ojn[don_Zm<01on_Zm<2o`0000;o]:O<00?o0000okBWc?ndYl`00ondYl`00ol0003o^jc:ok^/bP03
ok^/bP05o`000?nkX[oo^j:ook^R_ol000001oo<[[`00ol0003o_YB/okjD[002okjD[003o`000?oo
oooo000004Sooooo001booooo`?o00001Oooool3o`000003ojVgi?l0003oZ;KS00OoZ;KS00?o0000
ojRfh_nX]^801?nX]^83o`0000SoYkCR00?o0000ojNchOnW/n401_nW/n43o`0000KoY[;Q00?o0000
ojJah?nV/N001_nV/N000ol0003oY[3OojJ`g`03o`0000;oYK3P00?o0000ojF_gonU[ml01onU[ml0
0ol0003oYJkNojF^gP05ojF^gP?o00001onU[=`00ol0003oYjcKojN/f`06ojN/f`03o`000?nY[=Wo
ZJcI00;oZJcI0ol000000onWZMSo0000oj^YeP07oj^YeP03o`000?n_Zm?o[j_C00Co[j_C0_l00000
1On^Y/oo0000okBWc?ndYlco000000Go]:O<00?o0000ok^/b_nk[<X00_nk[<X00ol0003o^j:ook^R
_`03ok^R_`03o`000?o<[[coc:jl00?oc:jl00?o0000okjD[?nnU:`00_nnU:`2o`0000;ooooo00?o
0000ooooooooool0AOooool003[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`00027ooooo0_l00006ooooo`;o00001OnY]n@00ol0003oZ;KSojRfh`06ojRfh`03o`000?nX
]^;oZ;KR00?o00000_nW]N<00ol0003oYkCRojNdhP07ojNdhP03o`000?nW/n7oYk?Q00;oYk?Q0ol0
00000onV/n;o0000ojJbh@07ojJbh@03o`000?nV/N3oY[7P00GoY[7P0ol00006ojF`h003o`000?nU
[mooYJoO00OoYJoO00Co0000ojF^g_nU[]koYJkN0ol000000onT[Mko0000ojF/g008ojF/g003o`00
0?nW[=_oYjcK00GoYjcK00?o0000ojV/fOl000000_l00005ojNYf003o`000?n[ZMKoZjWF00KoZjWF
00Co0000ojn[don_Zm?o[j_C0_l00004ojjVc`03o`000?ndYlco000000Ko]:O<00Co0000ok^/b_nk
[<[o00001_nkX[l00ol0003oc:jlolb^_002olb^_003o`000?nnU:co_YB/00?o_YB/00Co0000olN>
V?l0003ooooo0_l00016ooooo`00>_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@07_ooool3o`0000;ooooo00Co0000oooooooooooooooo
0_l00008ojVgi003o`000?nX]^?oZ;KS00GoZ;KS0ol00006ojNeh`03o`000?nW]>;oYkCR00OoYkCR
00Co0000ojNchOl0003o00001OnV/n800ol0003oY[;QojJbh@05ojJbh@03o`000?nV/N3oY[7P00;o
Y[7P0ol000000onU/N7o0000ojF`h007ojF`h003o`000?nU[mooYJoO00KoYJoO00Co0000ojF^g_l0
003o00001OnT[Mh00ol0003oYJcLojF/g006ojF/g003o`000?nW[=_oYjcK00CoYjcK0ol00008ojNY
f003o`000?n[ZMKoZjWF00KoZjWF00Co0000ojn[dol0003o00001_n^Y/l01?l0003o]:O<okBWc?l0
0005okBWc003o`000?nk[<[o000000Oo^j:o00Go0000olb^_?o<[[coc:jlo`000006okjD[003o`00
0?o7SYSo000000;ooooo00?o0000ooooooooool01_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool09oooool003[ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01gooooo0_l00006ooooo`?o000000?oZKSTo`000?nY
]n@01onY]n@00ol0003oZ;KSojRfh`02ojRfh`?o000000?oYkKSo`000?nW]N<01onW]N<00ol0003o
YkCRojNdhP06ojNdhP;o00002?nV/n800ol0003oY[;QojJbh@05ojJbh@04o`000?nV/N3o0000o`00
00GoYK7Q00?o0000ojF`h?nU/>001OnU/>000ol0003oYJoOojF_g`05ojF_g`?o00001onT[Mh00ol0
003oYJcLojF/g007ojF/g003o`000?nW[=_oYjcK00?o00000_nUZ]X00ol0003oYjWHojNYf007ojNY
f003o`000?n[ZMKoZjWF00GoZjWF0_l00008ojjVc`04o`000?ndYlco]:O<o`0000Go]:O<0_l00009
ok^R_`04o`000?o<[[coc:jlo`0000Go_YB/00Co0000olN>V?o7SYSo00000oooool00ol0003ooooo
ooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool0:?ooool003[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01Wo
oooo0ol00006ooooo`;o00001OnY^>@00ol0003oZKOTojVgi006ojVgi004o`000?nX]^?o0000o`00
00GoYkKS00?o0000ojNehonW]N<01OnW]N<00ol0003oYkCRojNdhP03ojNdhP?o000000?oY[CSo`00
0?nV/n801onV/n800ol0003oY[;QojJbh@04ojJbh@?o00001onU/N400ol0003oYK3PojF`h006ojF`
h003o`000?nU[mooYJoO00Co00000_nT[]l00ol0003oY:gNojB]gP06ojB]gP03o`000?nU[=coYJcL
00KoYJcL0ol00006ojFZfP03o`000?nWZMSoYjWH00KoYjWH00?o0000oj^Ye_n[ZMH00_n[ZMH3o`00
0003ojVUdol0003o[ZK?00So[ZK?00?o0000okBWc?l000000ondYl`2o`000003ok:OaOl0003o^j:o
00So^j:o00?o0000olb^_?l000001_nnU:`01?l0003oahjHolN>V?l00004ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000:Oooool003[ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Kooooo0_l00007ooooo`;o00002?nY
^>@00ol0003oZKOTojVgi005ojVgi0;o00002?nW]^<00ol0003oYkGSojNeh`05ojNeh`03o`000?nW
]>;o000000;o00001OnV]><00ol0003oY[?RojJchP06ojJchP03o`000?nV/^7oY[;Q00?o00000_nU
/^800ol0003oYK7QojFah@06ojFah@03o`000?nU/>3oYK3P00GoYK3P0ol00007ojB^g`03o`000?nT
[MkoY:gN00KoY:gN00?o0000ojF/g?nU[=`00_nU[=`3o`000003ojB[g?l0003oYJ[J00KoYJ[J00?o
0000ojNYf?nWZMP01_nWZMP00ol0003oZjWFo`000002o`0000GoZJGC00?o0000ojjVcon^Y/l01_n^
Y/l01?l0003o]:O<o`000?ndYl`2o`0000Co/Yo500?o0000ok^R_onkX[l01onkX[l00ol0003o_YB/
okjD[005okjD[004o`000?o7SYSoahjHo`0000Cooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00002oooool3o`000003oa0@4?oooooo
oooo01Wooooo000jooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0B
ooooo`?o00000_ooool01?l0003oooooooooooooool3o`000003ojViiOl0003oZKST00OoZKST00?o
0000ojVgi?nY]n@00_nY]n@3o`000003ojRgi?l0003oYkKS00OoYkKS00?o0000ojNehonW]N<01?nW
]N<3o`0000WoY[CS00?o0000ojJch_nV/n801OnV/n83o`0000KoYK;R00?o0000ojFahOnU/N401_nU
/N401?l0003oYK3PojF`h?nU/>03o`000003oj>_h?l0003oY:kO00SoY:kO00?o0000ojB]g_nT[Mh0
1OnT[Mh00ol0003oYJcLo`000002o`0000GoY:_L00?o0000ojFZf_nUZ]X01OnUZ]X00ol0003oYjWH
ojNYf005ojNYf0;o00002?nYYM<00ol0003o[ZK?ojjVc`06ojjVc`04o`000?ndYlco0000o`0000Ko
/Yo500?o0000ok^R_onkX[l01_nkX[l2o`0000Oo_YB/00Co0000olN>V?o7SYSo00001Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool0
000=ooooo`03oa0@4?nj^[[ooooo01[ooooo000jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool01Ol0003o^[ZjoooooonHV9So410@01;ooooo0_l00007ooooo`;o00001OnY^ND00ol0003oZKST
ojVhi006ojVhi004o`000?nY]nCo0000o`0000GoZ;OT00?o0000ojNfhonW]^<01_nW]^<00ol0003o
YkGSojNeh`03o`0000?oY[GS00?o0000ojJdhonV]><01_nV]><00ol0003oY[?RojJchP02ojJchP?o
000000?oYK?Ro`000?nU/^801onU/^800ol0003oYK7QojFah@05ojFah@04o`000?nU/>3o0000o`00
00GoXjoP00?o0000ojB^gonT[]l01_nT[]l00ol0003oY:gNojB]gP04ojB]gP?o00002?nTZm`00ol0
003oYJ[JojFZfP06ojFZfP04o`000?nWZMSoYjWHojNYf0?o000000?oYJKFo`000?nYYM<02?nYYM<0
0ol0003o[ZK?ojjVc`05ojjVc`?o00002?nbWlD00ol0003o^j:ook^R_`04ok^R_`03o`000?nhUKCo
000000Ko_YB/00Go0000olN>V?o7SYSoahjHo`000006ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000gooooo00?oV9RHoc8b<_ooool0
6_ooool003[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03oooool3o`0000Kooooo0ol00008ojVii@03o`000?nY^>CoZKST00CoZKST0ol00008ojRgi003
o`000?nW]^?oYkKS00GoYkKS0ol00007ojJeh`03o`000?nV]>?oY[CS00KoY[CS00Co0000ojJch_l0
003o00001OnU/n800ol0003oYK;RojFbhP05ojFbhP03o`000?nU/N7oYK7Q00CoYK7Q0ol00008oj>_
h003o`000?nT[]ooY:kO00KoY:kO00?o0000ojB]g_nT[Mh00ol00002oj>/gP03o`000?nTZmcoY:_L
00OoY:_L00?o0000ojFZf_nUZ]X01OnUZ]X01?l0003oYjWHo`000?l00005ojFVeP03o`000?nYYM?o
ZJGC00KoZJGC00?o0000ojjVcon^Y/l00on^Y/l2o`000003oj^Obol0003o000000So/Yo500?o0000
ok^R_onkX[l00onkX[l01Ol0003o^9FdokRE]?nhUKCo000000Go_YB/00?o0000olN>V?o7SYP00_o7
SYP00ol0003oooooooooo`02ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000003Oooool00ooMgMgo0000okZj^P0Jooooo`00G?ooool3o`0000Gooooo0ol0
0003ojVii@03o`000?nY^NGoZKWU00KoZKWU00?o0000ojVhi?nY^>@00ol00003ojRhi003o`000?nX
]nCoZ;OT00KoZ;OT00?o0000ojNfhonW]^<00_nW]^<2o`000003ojNfi?l0003oY[GS00SoY[GS00?o
0000ojJdhonV]><01?nV]><3o`0000SoYK?R00?o0000ojFbh_nU/^801OnU/^800ol0003oYK7QojFa
h@03o`0000;oXk3Q00?o0000oj>_h?nS[n001_nS[n000ol0003oY:kOojB^g`05ojB^g`Co00001_nS
[=h00ol0003oY:_LojB[g006ojB[g003o`000?nUZ][oYJ[J00CoYJ[J0ol00007ojFVeP03o`000?nY
YM?oZJGC00OoZJGC00Go0000ojjVcon^Y/oo[ZK?o`000004oj^Ob`03o`000?nbWlGo/Yo500Ko/Yo5
00?o0000ok^R_onkX[l00_nkX[l00ol0003o^9FdokRE]002okRE]003o`000?nnU:co_YB/00?o_YB/
00?o0000olN>V?o7SYP00_o7SYP01Ol0003ooooooooooooooooo000000;ooooo00Wo0000oooooooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmg
MgOoA4A401[ooooo001Iooooo`?o00000_ooool00ol0003oooooooooo`03o`0000OoZKWU00?o0000
ojViiOnY^ND01OnY^ND3o`0000OoZ;ST00?o0000ojRgi?nX]n@01_nX]n@01?l0003oYkKSo`000?l0
0004ojNfi003o`000?nV]N?oY[GS00OoY[GS00?o0000ojJdhonV]><00ol00002ojFdh`03o`000?nU
/n;oYK?R00KoYK?R00?o0000ojFbh_nU/^801?nU/^84o`0000KoXk3Q00?o0000oj>_h?nS[n001_nS
[n000ol0003oY:kOojB^g`04o`0000;oXZgO00?o0000oj>/g_nS[=h01_nS[=h00ol0003oY:_LojB[
g005ojB[g003o`000?nUZ][oYJ[J00Co00000_nSYmT00ol0003oYJKFojFVeP06ojFVeP03o`000?nY
YM?oZJGC00KoZJGC00Co0000ojjVcol0003o00001On[Wl/00ol0003o/Yo5ok:Oa@07ok:Oa@04o`00
0?nkX[oo^j:oo`0000Go^9Fd00?o0000okjD[?nnU:`00onnU:`00ol0003oahjHolN>V002olN>V003
o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool01OoMgMgo410@oooooolQ8B7ogMgM
01Wooooo001Fooooo`?o00001_ooool2o`0000;oZK[U00?o0000ojViiOnY^ND01_nY^ND00ol0003o
ZKWUojVii@02ojVii@;o000000?oZ;SUo`000?nX^>@02?nX^>@00ol0003oZ;OTojRgi004ojRgi0?o
00001onW]^@00ol0003oY[GSojJeh`06ojJeh`?o00001_nU]><00ol0003oYK?RojFchP06ojFchP03
o`000?nU/^;oYK;R00?o00000_nS/N800ol0003oXk3Qoj>`h@06oj>`h@03o`000?nS[n3oXjoP00Go
XjoP0ol00007oj:]g`03o`000?nS[=koXjcN00GoXjcN00?o0000ojB[g?nTZm`01?nTZm`4o`0000Oo
XjOI00?o0000ojFVe_nUY]H01OnUY]H00ol0003oZJGCojVUd`06ojVUd`;o00001on[Wl/2o`0000So
/Yo500?o0000ok^R_ol000001onhUK@01Ol0003o_YB/okjD[?nnU:co000000GoahjH00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`05ofIVI_n7QhOooooooiRHV?mEEED06Oooool0
05Cooooo0_l00007ooooo`;o00001OnY^^D00ol0003oZKWUojVii@06ojVii@04o`000?nY^NGo0000
o`0000CoZ;SU00?o0000ojRhi?nX^>@01onX^>@00ol0003oZ;OTojRgi003o`0000;oYkOT00?o0000
ojNfi?nW]^@01_nW]^@00ol0003oY[GSojJeh`02ojJeh`?o000000?oYKGTo`000?nU]><01onU]><0
0ol0003oYK?RojFchP04ojFchPCo00001_nS/N800ol0003oXk3Qoj>`h@05oj>`h@03o`000?nS[n3o
XjoP00;oXjoP0ol000000onR[^7o0000oj:]g`08oj:]g`03o`000?nS[=koXjcN00GoXjcN00?o0000
ojB[g?nTZm`00ol00002oj6Yg003o`000?nSYmWoXjOI00KoXjOI00?o0000ojFVe_nUY]H01_nUY]H0
0ol0003oZJGCojVUd`02ojVUd`?o000000?oYJ7Ao`000?n[Wl/01_n[Wl/2o`0000So/Yo50_l00008
okRE]005o`000?nnU:co_YB/okjD[?l000001Oo7SYP00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01kooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`0Gooooo`00DOooool4
o`0000Gooooo0ol00008ojVji@03o`000?nY^NGoZKWU00CoZKWU0ol00007ojRhi@03o`000?nX^>Co
Z;ST00KoZ;ST0ol00006ojNgi003o`000?nW]^CoYkKT00KoYkKT00Co0000ojJehol0003o00001OnU
]N@00ol0003oYKCSojFdh`06ojFdh`03o`000?nU/n;oYK?R00?o00000_nT/^<00ol0003oXk7Roj>a
hP06oj>ahP03o`000?nS/>7oXk3Q00GoXk3Q00Co0000oj>_h?l0003o00001OnR[^400ol0003oXZgO
oj:]g`06oj:]g`03o`000?nS[=koXjcN00CoXjcN1?l00006oj6Yg003o`000?nSYmWoXjOI00KoXjOI
00?o0000ojFVe_nUY]H01OnUY]H00ol0003oZJGCo`000002o`0000GoYJ7A00?o0000oj^Obon[Wl/0
1?n[Wl/2o`0000Ko/Yo50_l000000on/U[oo0000okRE]007okRE]005o`000?nnU:co_YB/okjD[?l0
00001Oo7SYP00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`0Fooooo`00Coooool2o`0000Cooooo00?o0000ooooool0
00000_l00002ojVjiP03o`000?nY^^GoZK[U00OoZK[U00?o0000ojViiOnY^ND00ol00002ojRii@03
o`000?nX^>GoZ;SU00KoZ;SU00?o0000ojRhi?nX^>@00_nX^>@3o`000003ojNgiOl0003oYkOT00Oo
YkOT00?o0000ojNfi?nW]^@01?nW]^@3o`0000SoYKGT00?o0000ojFdhonU]><01OnU]><3o`0000Ko
Y;;S00?o0000oj>ah_nS/N801OnS/N800ol0003oXk3Qoj>`h@04oj>`h@?o00002?nR[^400ol0003o
XZgOoj:]g`06oj:]g`03o`000?nS[=koXjcN00?o00000_nPZmh00ol0003oXJWLoj6Yg005oj6Yg003
o`000?nSYmWoXjOI00OoXjOI00?o0000ojFVe_nUY]H00onUY]H3o`0000SoYJ7A00?o0000oj^Obon[
Wl/01?n[Wl/00ol0003oZio;o`000003ok:Oa@;o00000on/U[l00ol0003o^9FdokRE]006okRE]004
o`000?nnU:co_YB/o`0000KoahjH00?o0000ooooooooool01oooool00ol0003oooooooooo`0loooo
o`00C?ooool3o`0000Gooooo0ol00006ojVjiP03o`000?nY^^GoZK[U00KoZK[U0ol00006ojRii@03
o`000?nX^>GoZ;SU00KoZ;SU00Co0000ojRhi?l0003o00001OnW]nD00ol0003oYkOTojNgi006ojNg
i003o`000?nW]^CoYkKT00?o00000_nV]^@00ol0003oYKGTojFei006ojFei003o`000?nU]>?oYKCS
00;oYKCS0ol000000onT/nCo0000ojBbh`07ojBbh`03o`000?nS/N;oXk7R00GoXk7R00?o0000oj>`
hOnS/>400ol00002oj:`hP03o`000?nR[^7oXZkQ00KoXZkQ00?o0000oj:]gonR[Ml01OnR[Ml4o`00
00KoX:_N00?o0000oj6Yg?nQZM`01OnQZM`00ol0003oXjOIoj>Wf@06oj>Wf@03o`000?nUY]KoYJKF
00?o00000_nRXmH00ol0003oYJ7AojFQd@06ojFQd@03o`000?n[Wl_oZio;00CoZio;00Co0000oj^O
bol0003o/Yo50_l00006ojbF_`03o`000?nhUKCo^9Fd00Ko^9Fd00?o0000okjD[?l000001oo7SYP0
0ol0003oooooooooo`06ooooo`;o0000?Oooool002Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Q
ooooo`;o00001Oooool3o`0000;oZK_V00?o0000ojVji_nY^^H01OnY^^H00ol0003oZK[UojVji@02
ojVji@?o000000?oZ;[Vo`000?nX^ND01onX^ND00ol0003oZ;SUojRhi@04ojRhi@?o00002?nW]nD0
0ol0003oYkOTojNgi004ojNgi0Co00001_nV]^@00ol0003oYKGTojFei006ojFei004o`000?nU]>?o
0000o`0000GoY;?T00?o0000ojBbhonT/^<01OnT/^<00ol0003oXk7Roj>ahP04oj>ahPCo00001_nR
/>800ol0003oXZkQoj:^h@06oj:^h@03o`000?nR[MooXZgO00Co00000_nP[>000ol0003oX:_Noj2[
gP05oj2[gP03o`000?nQZMcoXJWL00KoXJWL00?o0000oj>WfOnSYmT01?nSYmT4o`0000KoXZ?F00?o
0000ojFQdOnUXM401_nUXM400ol0003oZio;oj^Ob`03oj^Ob`04o`000?n[Wl_o0000o`0000So[9Jo
00?o0000okRE]?nhUK@01_nhUK@00ol0003o_YB/o`000007olN>V003o`000?oooooooooo00Oooooo
00?o0000ooooooooool0>oooool002Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Nooooo`?o0000
00?oooooo`000?ooool00_ooool2o`0000KoZK_V00?o0000ojVji_nY^^H01OnY^^H01?l0003oZK[U
o`000?l00005ojRjiP03o`000?nX^NGoZ;WU00KoZ;WU00?o0000ojRhiOnX^>D00ol00002ojNhi@03
o`000?nW]nGoYkOU00OoYkOU00?o0000ojNgi?nW]n@00ol00002ojJgi@03o`000?nV]^CoY[KT00Ko
Y[KT00?o0000ojFei?nU]N@01?nU]N@3o`0000SoY;?T00?o0000ojBbhonT/^<01OnT/^<00ol0003o
Xk7Roj>ahP03o`0000;oX[7S00?o0000oj:`h_nR/>801_nR/>800ol0003oXZkQoj:^h@05oj:^h@?o
00001onP[>000ol0003oX:_Noj2[gP05oj2[gP03o`000?nQZMcoXJWL00GoXJWL00?o0000oj>WfOnS
YmT01?l00002oinUf@03o`000?nRXmKoXZ?F00GoXZ?F00?o0000ojFQdOnUXM401_nUXM400ol0003o
Zio;oj^Ob`02oj^Ob`?o000000?oY9S9o`000?n/U[l01on/U[l00ol0003o^9FdokRE]006okRE]003
o`000?nnU:co000000OoahjH00?o0000ooooooooool02?ooool00ol0003oooooooooo`0jooooo`00
9?ooool01Ol@413ooooooooooooooooo410@01cooooo0_l00006ooooo`;o00002OnY^nH00ol0003o
ZK[VojVjiP04ojVjiP;o00002?nX^^H00ol0003oZ;WUojRii@04ojRii@Co00001_nW^>D00ol0003o
YkOUojNgi@06ojNgi@?o00001_nV]nD00ol0003oY[KTojJfi006ojJfi003o`000?nU]NCoYKGT00?o
00000_nT]>@00ol0003oY;?TojBci006ojBci003o`000?nT/^?oY;;S00CoY;;S1?l00006oj:ah`03
o`000?nR/>;oX[3R00GoX[3R00?o0000oj:^hOnR[^400_nR[^43o`000003oj2^hOl0003oX:cP00Oo
X:cP00?o0000oj2[g_nPZmh01_nPZmh00ol0003oXJWLoj6Yg003oj6Yg0Co00001onOYMT00ol0003o
XZ?Foj:SeP05oj:SeP03o`000?nUXM7oYJ7A00GoYJ7A00?o0000oj^Obol000000_l00002ojBHb@04
o`000?nTV<WoY9S9o`0000So[9Jo00?o0000okRE]?nhUK@01_nhUK@00ol0003oahjHolN>V006olN>
V003o`000?oooooooooo00Wooooo00?o0000ooooooooool0>Oooool002Cooooo00Go0000oooooooo
ooooooooo`00000Iooooo`?o00001Oooool3o`0000;oZK_W00?o0000ojVki_nY^nH01onY^nH00ol0
003oZK[VojVjiP03o`0000;oZ;[V00?o0000ojRji_nX^^H01_nX^^H00ol0003oZ;WUojRii@03o`00
00?oYkWV00?o0000ojNhiOnW^>D01OnW^>D00ol0003oYkOUojNgi@02ojNgi@?o000000?oY[OUo`00
0?nV]nD01onV]nD00ol0003oY[KTojJfi004ojJfi0Co00001_nT]>@00ol0003oY;?TojBci006ojBc
i003o`000?nT/^?oY;;S00?o00000_nR/^<00ol0003oX[7Soj:ah`06oj:ah`03o`000?nR/>;oX[3R
00GoX[3R00Co0000oj:^hOl0003o00001OnP[^400ol0003oX:cPoj2/h006oj2/h003o`000?nPZmko
X:_N00GoX:_N00?o0000oj6Yg?nQZM`00ol00002oijWg003o`000?nOYMWoWjGI00KoWjGI00?o0000
oj:Se_nRXmH01_nRXmH00ol0003oYJ7AojFQd@03ojFQd@?o00001OnTV<T01?l0003oY9S9ojBHbOl0
0008ojbF_`03o`000?nhUKCo^9Fd00Go^9Fd0_l00008olN>V003o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>Oooool002Cooooo00Go0000ooooooooooooooooo`00000Gooooo`;o00001Ooo
ool3o`0000KoZK_W00?o0000ojVki_nY^nH01_nY^nH3o`0000KoZ;[V00?o0000ojRji_nX^^H01OnX
^^H3o`0000OoYkWV00?o0000ojNhiOnW^>D01OnW^>D01?l0003oYkOUo`000?l00005ojJgi@03o`00
0?nV]nGoY[OU00KoY[OU00?o0000ojJfi?nV]^@00ol00002ojFfi@03o`000?nT]>CoY;CT00KoY;CT
00?o0000ojBci?nT/n@01?nT/n@4o`0000KoX[;S00?o0000oj:ahonR/N<01OnR/N<00ol0003oX[3R
oj:`hP04oj:`hP?o00001onP[^400ol0003oX:cPoj2/h007oj2/h003o`000?nPZmkoX:_N00?oX:_N
1?l00006oijWg003o`000?nOYMWoWjGI00KoWjGI00?o0000oj:Se_nRXmH01OnRXmH00ol0003oYJ7A
ojFQd@03o`0000;oWi_@00?o0000ojBHbOnTV<T00onTV<T01?l0003oY9S9ojBHbOl00008ojbF_`03
o`000?nhUKCo^9Fd00Co^9Fd00?o0000oj^8/?l000002?o7SYP00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo03Sooooo000Tooooo`05oa0@4?ooooooooooooooool@41005?ooool3o`0000;o
oooo00?o0000ooooool000000_l000000onY_>Oo0000ojVki`07ojVki`03o`000?nY^nKoZK_V00;o
ZK_V0ol000000onX^nOo0000ojRjiP07ojRjiP03o`000?nX^^KoZ;[V00;oZ;[V0_l00002ojNiiP03
o`000?nW^NKoYkWV00KoYkWV00?o0000ojNhiOnW^>D01?nW^>D2o`0000SoY[OU00?o0000ojJgiOnV
]nD01OnV]nD3o`0000KoYKKU00?o0000ojBdi?nT]>@01_nT]>@00ol0003oY;?TojBci003o`0000;o
Xk?T00?o0000oj:bhonR/^<01_nR/^<00ol0003oX[7Soj:ah`05oj:ah`03o`000?nR/>;oX[3R00?o
00000_nP[n800ol0003oX:kQoj2^h@06oj2^h@03o`000?nP[>3oX:cP00KoX:cP00?o0000oj2[g_nP
Zmh00ol00002oifYg`03o`000?nNYmcoWZOL00GoWZOL00?o0000oinUfOnOYMT01_nOYMT00ol0003o
XZ?Foj:SeP04oj:SePCo00001_nOVm000ol0003oY9S9ojBHb@02ojBHb@05o`000?nTV<WoY9S9ojBH
bOl000002?n/U[l00ol0003o^9FdokRE]002okRE]004o`000?n[R;3oZhR`o`0000SoahjH00?o0000
ooooooooool02oooool00ol0003oooooooooo`0gooooo`009?ooool01OmgMgOoV9RHoooooonHV9So
MgMg017ooooo0ol00005ooooo`;o00001OnY_>L00ol0003oZK_WojVki`06ojVki`04o`000?nY^nKo
0000o`0000GoZ;_W00?o0000ojRji_nX^^H01_nX^^H01?l0003oZ;[Vo`000?l00005ojNiiP03o`00
0?nW^NKoYkWV00KoYkWV00?o0000ojNhiOnW^>D00ol00002ojJhiP03o`000?nV]nGoY[OU00GoY[OU
00?o0000ojJgiOnV]nD00_nV]nD3o`000003ojFfiOl0003oYKKU00OoYKKU00?o0000ojBdi?nT]>@0
1?nT]>@4o`0000KoXk?T00?o0000oj:bhonR/^<01OnR/^<00ol0003oX[7Soj:ah`04oj:ah`Co0000
1_nP[n800ol0003oX:kQoj2^h@06oj2^h@03o`000?nP[>3oX:cP00CoX:cP1?l00006oifYg`03o`00
0?nNYmcoWZOL00GoWZOL00?o0000oinUfOnOYMT01OnOYMT00ol0003oXZ?Foj:SeP04o`0000;oW9kF
00?o0000oinKd?nOVm001OnOVm000ol0003oY9S9ojBHb@02ojBHb@05o`000?nTV<WoY9S9ojBHbOl0
00002?n/U[l01Ol0003o^9FdokRE]?nhUKCo000000CoZhR`00?o0000olN>V?o7SYP01_o7SYP00ol0
003oooooooooo`09ooooo`;o0000>Oooool002Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?oooo
o`;o00001_ooool2o`0000SoZKcW00?o0000ojVkionY^nL01?nY^nL3o`0000SoZ;_W00?o0000ojRj
i_nX^^H01?nX^^H3o`0000SoYkWV00?o0000ojNii_nW^NH01?nW^NH4o`0000KoY[SV00?o0000ojJg
iOnV]nD01OnV]nD01?l0003oY[OUo`000?l00005ojFfi@03o`000?nU]^GoYKKU00KoYKKU00?o0000
ojBdi?nT]>@00ol00002oj>di@03o`000?nS/nCoXk?T00KoXk?T00?o0000oj:bhonR/^<01OnR/^<0
0ol0003oX[7Soj:ah`03o`0000;oXK7S00?o0000oj2_h_nP[n801_nP[n800ol0003oX:kQoj2^h@05
oj2^h@03o`000?nP[>3oX:cP00Co00000_nMZn400ol0003oWJWOoifYg`06oifYg`03o`000?nNYmco
WZOL00GoWZOL00?o0000oinUfOnOYMT00onOYMT4o`0000OoW9kF00?o0000oinKd?nOVm001OnOVm00
1Ol0003oY9S9ojBHbOnTV<Wo000000?oY9S900?o0000ojbF_on/U[l01_n/U[l01?l0003o^9FdokRE
]?l00005oj^8/003o`000?o7SYSoahjH00KoahjH00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0fooooo`00=Oooool5o`0000Cooooo0_l00002ojVli`03o`000?nY_>OoZKcW00KoZKcW00?o
0000ojVkionY^nL00ol00003ojRki`03o`000?nX^nOoZ;_W00KoZ;_W00?o0000ojRji_nX^^H00ol0
0002ojRjiP03o`000?nW^NKoYkWV00OoYkWV00?o0000ojNii_nW^NH00ol00002ojJiiP03o`000?nV
^>KoY[SV00KoY[SV00?o0000ojJgiOnV]nD01?nV]nD2o`0000SoYKKU00?o0000ojFfiOnU]^D01OnU
]^D3o`0000KoXkCU00?o0000oj>ci?nS/n@01OnS/n@00ol0003oX[;Soj:bh`04oj:bh`Co00001_nQ
/N<00ol0003oX:oRoj2_hP06oj2_hP03o`000?nP[^7oX:kQ00;oX:kQ1Ol00007oif[h@03o`000?nM
ZMooWJWO00GoWJWO00?o0000oijWg?nNYm`01OnNYm`00ol0003oWjGIoinUf@03o`0000;oVZ;J00?o
0000oibNe_nLW]H01_nLW]H00ol0003oWi_@oinKd005oinKd003o`000?nTV<WoY9S900;o00001?nT
V<T00ol0003o[9JoojbF_`06ojbF_`;o00001_n[R;000ol0003oahjHolN>V006olN>V003o`000?oo
oooooooo00cooooo00?o0000ooooooooool0=Oooool003?ooooo0_l00007ooooo`;o00001OnY_>L0
0ol0003oZKcWojVli`05ojVli`?o00001onX^nL00ol0003oZ;_WojRki`05ojRki`?o00001_nX^^H0
0ol0003oYkWVojNiiP06ojNiiP?o00001_nV^NH00ol0003oY[SVojJhiP06ojJhiP03o`000?nV]nGo
Y[OU00?o00000_nU]nH00ol0003oYKKUojFfi@05ojFfi@03o`000?nU]^GoYKKU00;oYKKU0ol00000
0onT]NGo0000oj>di@07oj>di@03o`000?nS/nCoXk?T00GoXk?T00?o0000oj:bhonR/^<00ol00002
oj6bi003o`000?nQ/N?oXK7S00KoXK7S00?o0000oj2_h_nP[n801?nP[n86o`0000?oWZgR00?o0000
oif[hOnMZn401_nMZn400ol0003oWJWOoifYg`06oifYg`03o`000?nNYmcoWZOL00;oWZOL1Ol00006
oiZRfP03o`000?nLW]KoW9kF00KoW9kF00?o0000oinKd?nOVm001?nOVm03o`000003ojBHbOl0003o
Y9S900?oY9S900?o0000ojbF_on/U[l01?n/U[l3o`0000OoZhR`00?o0000olN>V?o7SYP01_o7SYP0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Gooooo000`ooooo`?o00001_ooool4o`00
00OoZKcW00?o0000ojVlionY_>L00_nY_>L2o`0000;oZ;cW00?o0000ojRkionX^nL01_nX^nL00ol0
003oZ;_WojRki`02ojRki`;o00000_nX^nL00ol0003oZ;[VojRjiP05ojRjiP03o`000?nW^NKoYkWV
00;oYkWV0ol000000onW^NKo0000ojJiiP07ojJiiP03o`000?nV^>KoY[SV00CoY[SV1?l00006ojFg
iP03o`000?nU]^GoYKKU00GoYKKU00Co0000ojFfiOl0003o00001OnT]ND00ol0003oXkCUoj>di@05
oj>di@03o`000?nS/nCoXk?T00CoXk?T1?l00006oj6bi003o`000?nQ/N?oXK7S00KoXK7S00?o0000
oj2_h_nP[n800ol00002oij_h`03o`000?nN[N;oWZgR00GoWZgR00?o0000oif[hOnMZn401_nMZn40
0ol0003oWJWOoifYg`04oifYg`Ko00000onJYMd00ol0003oVZ;JoiZRfP05oiZRfP03o`000?nLW]Ko
W9kF00KoW9kF00Co0000oinKd?nOVm3oWi_@0ol000000onOVm3o0000ojBHb@02ojBHb@05o`000?nT
V<WoY9S9ojBHbOl000000_n/U[l4o`0000;oWH^o00?o0000oj^8/?n[R;001On[R;000ol0003oahjH
olN>V006olN>V003o`000?oooooooooo00gooooo00?o0000ooooooooool0=?ooool002kooooo0ol0
0005ooooo`?o00001?nY_NP00ol0003oZKcWojVli`05ojVli`04o`000?nY_>Oo0000o`0000GoZ;cW
00?o0000ojRkionX^nL01_nX^nL01?l0003oZ;_Wo`000?l00005ojRki`03o`000?nX^^KoZ;[V00Go
Z;[V00Co0000ojNii_l0003o00001OnW^NH00ol0003oY[WVojJiiP06ojJiiP03o`000?nV^>KoY[SV
00?o00000_nU^>H00ol0003oYKOVojFgiP06ojFgiP03o`000?nU]^GoYKKU00CoYKKU0_l00008ojBe
i@03o`000?nS]>GoXkCU00GoXkCU00?o0000oj>ci?nS/n@00ol00002oj6ci@03o`000?nQ/^CoXK;T
00KoXK;T00?o0000oj6ahonQ/N<01?nQ/N<4o`0000KoWZoS00?o0000oij]h_nN[N801OnN[N800ol0
003oWJ_Qoif[h@05oif[h@03o`000?nMZMooWJWO00Co00000_nJZ>000ol0003oVZGMoiZUg@05oiZU
g@03o`000?nJX][oVZ;J00GoVZ;J00?o0000oibNe_nLW]H01OnLW]H4o`0000CoWi_@00?o0000ojBH
bOnTV<T00_nTV<T6o`0000KoWH^o00?o0000oj^8/?n[R;001_n[R;000ol0003oahjHolN>V005olN>
V003o`000?oooooooooo00kooooo00?o0000ooooooooool0<oooool002oooooo00Co0000ooooool0
003ooooo0ol00008ojVmj003o`000?nY_>OoZKcW00CoZKcW0ol00007ojRli`03o`000?nX^nOoZ;_W
00CoZ;_W0ol00008ojRki`03o`000?nX^^KoZ;[V00CoZ;[V0_l00008ojNiiP03o`000?nV^NKoY[WV
00CoY[WV1?l00006ojFhiP03o`000?nU]nKoYKOV00KoYKOV00?o0000ojFfiOnU]^D00ol00002ojBf
iP03o`000?nT]NGoY;GU00GoY;GU00?o0000oj>diOnS]>D01?nS]>D4o`0000KoXK?U00?o0000oj6b
i?nQ/^@01_nQ/^@00ol0003oXK7Soj6ah`03o`0000;oWk3T00?o0000oij_honN[n<01_nN[n<00ol0
003oWZgRoij]hP04oij]hP03o`000?nMZn7oWJ_Q00CoWJ_Q1?l00007oiZXh003o`000?nJYMgoVZGM
00CoVZGM00?o0000oiZRf_nJX]X01OnJX]X00ol0003oW9kFoibNeP03oibNePCo00001OnOVm06o`00
0005oiR@b_l0003oV93:oiR@b_l000002?nMRkl00ol0003oZhR`oj^8/005oj^8/003o`000?o7SYSo
ahjH00KoahjH00?o0000ooooooooool03Oooool2o`0003Cooooo000_ooooo`Co00000_nY_NP00ol0
003oZKgXojVmj007ojVmj003o`000?nY_>OoZKcW00?o00000onX_>P00ol0003oZ;cWojRli`05ojRl
i`03o`000?nX^nOoZ;_W00?o00000onX^nL00ol0003oZ;_WojRki`06ojRki`03o`000?nX^^KoZ;[V
00?o00000_nW^^L00ol0003oYkWVojNiiP06ojNiiP03o`000?nV^NKoY[WV00?o00000_nV^NH00ol0
003oYKSVojFhiP06ojFhiP03o`000?nU]nKoYKOV00CoYKOV1?l00006ojBfiP03o`000?nT]NGoY;GU
00GoY;GU00?o0000oj>diOnS]>D00ol00002oj:di@03o`000?nQ/nGoXK?U00KoXK?U00?o0000oj6b
i?nQ/^@01?nQ/^@4o`0000KoWk3T00?o0000oij_honN[n<01OnN[n<00ol0003oWZgRoij]hP05oij]
hP03o`000?nMZn7oWJ_Q00?o00000_nJZn800ol0003oVZSPoiZXh006oiZXh003o`000?nJYMgoVZGM
00GoVZGM00?o0000oiZRf_nJX]X01OnJX]X00ol0003oW9kFo`000002o`0000?oW9kF00?o0000oinK
d?nOVm000ol00002oiFFdP03o`000?nHT<[oV93:00;oV93:00Go0000oiR@b_nHT<[oV93:o`000007
oif;_`03o`000?n[R;3oZhR`00GoZhR`00?o0000olN>V?o7SYP01_o7SYP00ol0003oooooooooo`0=
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`05oooool002oooooo0_l00005ojVmj003o`000?nY_NSoZKgX00KoZKgX0ol0
0007ojRlj003o`000?nX_>OoZ;cW00CoZ;cW0ol00007ojRki`03o`000?nX^nOoZ;_W00CoZ;_W1?l0
0006ojNji`03o`000?nW^NKoYkWV00GoYkWV0ol00006ojJiiP03o`000?nU^>KoYKSV00KoYKSV00?o
0000ojFgi_nU]nH00ol00002ojBgiP03o`000?nT]^KoY;KV00KoY;KV00?o0000ojBeiOnT]ND01?nT
]ND3o`0000KoX[CU00?o0000oj6ciOnQ/nD01_nQ/nD00ol0003oXK;Toj6bi003o`0000;oWk;U00?o
0000oin`i?nO/>@01_nO/>@00ol0003oWZoSoij_h`05oij_h`03o`000?nN[N;oWZgR00;oWZgR1Ol0
0006oiZ[hP03o`000?nJZ>3oVZSP00KoVZSP00?o0000oiZUgOnJYMd01OnJYMd00ol0003oVZ;JoiZR
fP03oiZRfP?o00000onLW]H6o`0000KoUIKB00?o0000oiR@b_nHT<X00_nHT<X01?l0003oV93:oiR@
b_l00007oif;_`03o`000?n[R;3oZhR`00GoZhR`00?o0000olN>V?o7SYP01_o7SYP00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01Oooooo000^ooooo`;o00001onY_NP00ol0003o
ZKgXojVmj002ojVmj0?o000000?oZKgXo`000?nX_>P02?nX_>P00ol0003oZ;cWojRli`03o`0000;o
Z;cX00?o0000ojRkionX^nL01_nX^nL00ol0003oZ;_WojRki`03o`0000;oYk[W00?o0000ojNjionW
^^L01_nW^^L00ol0003oYkWVojNiiP02ojNiiP;o00000_nV^NL00ol0003oY[WVojJiiP05ojJiiP03
o`000?nU^>KoYKSV00CoYKSV1?l00006ojBgiP03o`000?nT]^KoY;KV00KoY;KV00?o0000ojBeiOnT
]ND00ol000000onR]NKo0000oj:di@07oj:di@03o`000?nQ/nGoXK?U00CoXK?U1?l00006oinbi@03
o`000?nO/>CoWk3T00GoWk3T00?o0000oij_honN[n<01?nN[n<6o`0000?oVjgS00?o0000oiZ[h_nJ
Zn801_nJZn800ol0003oVZSPoiZXh005oiZXh003o`000?nJYMgoVZGM00GoVZGM00Co0000oiZRf_nJ
X][oVZ;J2?l00004oiBKf003o`000?nEU];oUIKB00GoUIKB00?o0000oiR@b_nHT<X00onHT<X00ol0
003oV93:o`000008oif;_`03o`000?n[R;3oZhR`00GoZhR`00?o0000olN>V?o7SYP01Oo7SYP00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000005oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooo000000OoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0003oZ;cX
ojRlj006ojRlj0?o00001_nX_>P00ol0003oZ;_WojRki`05ojRki`?o00001_nW^^L00ol0003oYk[W
ojNji`06ojNji`04o`000?nW^NKo0000o`0000GoY[WW00?o0000ojJii_nV^NH01OnV^NH00ol0003o
YKSVojFhiP03o`0000;oYKSW00?o0000ojBgi_nT]nH01_nT]nH00ol0003oY;KVojBfiP04ojBfiPCo
00001OnR]NH00ol0003oX[CUoj:di@06oj:di@03o`000?nQ/nGoXK?U00?o00000_nP/nH00ol0003o
Wk;Uoinbi@06oinbi@03o`000?nO/>CoWk3T00GoWk3T00?o0000oij_honN[n<00ol00002oib_i003
o`000?nK[N?oVjgS00GoVjgS00?o0000oiZ[h_nJZn801OnJZn800ol0003oVZSPoiZXh005oiZXh003
o`000?nJYMgoVZGM00;oVZGM2?l00003oiBOg003o`000?nDVmSoU9_H00KoU9_H00?o0000oiFFd_nE
U]801?nEU]800ol0003oV93:oiR@bP03oiR@bP04o`000?nHT<[oV93:o`0000OoWH^o00?o0000oj^8
/?n[R;001On[R;000ol0003oahjHolN>V005olN>V003o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@0Gooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l000000ooooooo0000ojVm
j005ojVmj0?o00001onY_NP00ol0003oZ;cXojRlj002ojRlj0?o000000?oZ;cXo`000?nX_>P01onX
_>P00ol0003oZ;_WojRki`02ojRki`;o00000_nW^nL00ol0003oYk[WojNji`05ojNji`03o`000?nW
^^OoYk[W00CoYk[W0ol00008ojJii`03o`000?nV^NKoY[WV00CoY[WV0ol00006ojFhi`03o`000?nT
]nKoY;OV00KoY;OV00?o0000ojBfi_nT]^H00ol00002oj>fiP03o`000?nR]NKoX[GV00GoX[GV00?o
0000oj:diOnR]>D01?nR]>D4o`0000KoX;?V00?o0000oinbiOnO/^D01_nO/^D00ol0003oWk3Toin`
i002oin`i0Go00001_nL[n@00ol0003oVjgSoi^]h`05oi^]h`03o`000?nJZn;oVZ_R00GoVZ_R00?o
0000oiZXh?nJZ>000_nJZ>07o`000003oiFSgol0003o000000;o00001onDWm`00ol0003oU9_HoiBK
f005oiBKf003o`000?nEU];oUIKB00GoUIKB00?o0000oiR@b_nHT<X00onHT<X00ol0003oV93:o`00
0007oif;_`03o`000?n[R;3oZhR`00GoZhR`00?o0000olN>V?o7SYP01Oo7SYP00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`05oooool002?ooooo00Go410@oooooooooooooooooa0@4005ooooo`;o
00000oooool00ol0003oZKgXojVmj003o`0000?oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003o
Z;cXo`000?l00005ojRlj003o`000?nX_>SoZ;cX00KoZ;cX00Co0000ojRkiol0003o00001OnW^nL0
0ol0003oYk[WojNji`05ojNji`03o`000?nW^^OoYk[W00?o00000onV^^L00ol0003oY[WWojJii`06
ojJii`03o`000?nV^NKoY[WV00?o000000?oYKWWo`000?nU^>L01onU^>L00ol0003oY;OVojBgiP04
ojBgiPCo00001_nS]^H00ol0003oX[GVoj:eiP05oj:eiP03o`000?nR]>GoX[CU00?o00000_nQ]>H0
0ol0003oX;?Voj2ciP06oj2ciP03o`000?nO/^GoWk;U00CoWk;U1_l00003oif`i@03o`000?nL[nCo
W:oT00KoW:oT00?o0000oi^]honK[N<01OnK[N<00ol0003oVZ_RoiZ[hP02oiZ[hPOo00000onFYn80
0ol0003oUJ?Oo`000002o`0000CoUJ?O00?o0000oiBOg?nDWm`01?nDWm`00ol0003oU9_HoiBKf005
oiBKf003o`000?nEU];oUIKB00GoUIKB00?o0000oiR@b_nHT<X01?nHT<X2o`0000OoWH^o00?o0000
oj^8/?n[R;001On[R;000ol0003oahjHolN>V005olN>V003o`000?oooooooooo017ooooo00?o0000
ooooooooool00oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool06Ooo
ool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo0_l0
0007ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00007ojRlj003o`000?nX_>SoZ;cX00CoZ;cX0ol0
0008ojNki`03o`000?nW^^OoYk[W00CoYk[W0ol00007ojJji`03o`000?nV^NOoY[WW00CoY[WW1?l0
0005ojFii`03o`000?nU^>OoYKSW00KoYKSW00?o0000ojBgi_nT]nH00ol00002oj>gi`03o`000?nS
]^KoXkKV00KoXkKV00?o0000oj:ei_nR]NH01?nR]NH3o`0000KoXKCV00?o0000oj2ci_nP/nH01_nP
/nH00ol0003oWk;Uoinbi@03o`0000;oW[;V00?o0000oif`iOnM/>D01OnM/>D00ol0003oW:oToib_
i005oib_i003o`000?nK[N?oVjgS00CoVjgS1_l00003oiNZh`03o`000?nFYn;oUZOR00?oUZOR0ol0
0007oiFSg`03o`000?nDWmcoU9oL00GoU9oL00?o0000oiBKf?nDVmP01OnDVmP00ol0003oUIKBoiFF
dP05oiFFdP03o`000?nHT<[oV93:00CoV93:0_l00007oif;_`03o`000?n[R;3oZhR`00CoZhR`00?o
0000olN>V?o7SYP01_o7SYP00ol0003oooooooooo`0?ooooo`?o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P06Oooool002?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Cooooo00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgX
ojVmj003o`0000?oZ;gX00?o0000ojRlj?nX_>P01OnX_>P00ol0003oZ;cXojRlj003o`0000?oYk_X
00?o0000ojNkionW^nL01_nW^nL00ol0003oYk[WojNji`03o`0000;oY[[W00?o0000ojJjionV^^L0
1_nV^^L00ol0003oY[WWojJii`03o`0000;oYKWW00?o0000ojFiionU^NL01OnU^NL00ol0003oYKSW
ojFhi`04ojFhi`Co00001_nS]nL00ol0003oXkKVoj>fiP06oj>fiP03o`000?nR]NKoX[GV00?o0000
00?oXKKWo`000?nQ]>H01onQ]>H00ol0003oX;?Voj2ciP04oj2ciPCo00001_nN/^H00ol0003oWK3U
oif`i@05oif`i@03o`000?nL[nCoW:oT00GoW:oT00?o0000oi^]honK[N<00ol00002oiR]i@03o`00
0?nGZ^?oUj[S00GoUj[S00?o0000oiJWh_l000000_l00003oiJWhP03o`000?nEXmooUJ?O00GoUJ?O
00?o0000oiBOg?nDWm`01OnDWm`00ol0003oU9_HoiBKf004oiBKf003o`000?nEU];oUIKB00GoUIKB
00?o0000oiR@b_nHT<X01?nHT<X2o`0000OoWH^o00?o0000oj^8/?n[R;001On[R;000ol0003oahjH
olN>V005olN>V003o`000?oooooooooo01;ooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@410Gooooo`008oooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool01_ooool00ol0003oZKgXojVmj004ojVmj0?o00001onX
_NP00ol0003oZ;cXojRlj004ojRlj0?o00001onW^nP00ol0003oYk_WojNki`04ojNki`Co00001_nV
^^L00ol0003oY[[WojJji`05ojJji`?o00001_nU^NL00ol0003oYKWWojFii`05ojFii`03o`000?nU
^>OoYKSW00?o00000_nT^>L00ol0003oXkOWoj>gi`06oj>gi`03o`000?nS]^KoXkKV00CoXkKV1?l0
0005oj6fi`03o`000?nQ]>KoXKCV00KoXKCV00?o0000oj2ci_nP/nH00ol00002oinci`03o`000?nN
/^KoW[;V00KoW[;V00?o0000oif`iOnM/>D01OnM/>D00ol0003oW:oToib_i002oib_i0Go00001_nH
[ND00ol0003oUj[SoiNZh`03oiNZh`?o00001_nFYn800ol0003oUJ?OoiFSg`05oiFSg`03o`000?nD
WmcoU9oL00GoU9oL00?o0000oiBKf?nDVmP01?nDVmP00ol0003oUIKBoiFFdP05oiFFdP03o`000?nH
T<[oV93:00GoV93:00?o0000oif;_onMRkl01OnMRkl00ol0003oZhR`oj^8/005oj^8/003o`000?o7
SYSoahjH00GoahjH00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`008oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01oooool00ol0003oZKgXojVm
j003o`0000;oZ;gY00?o0000ojRmj?nX_NP01_nX_NP00ol0003oZ;cXojRlj003o`0000;oYkcX00?o
0000ojNkj?nW^nP01_nW^nP00ol0003oYk_WojNki`03o`0000;oY[_X00?o0000ojJjionV^^L01_nV
^^L00ol0003oY[[WojJji`02ojJji`;o000000?oYK[Xo`000?nU^NL01onU^NL00ol0003oYKWWojFi
i`04ojFii`?o00001_nT^>L00ol0003oXkOWoj>gi`06oj>gi`03o`000?nS]^KoXkKV00?o00000_nR
]^L00ol0003oXKKWoj6fi`05oj6fi`03o`000?nQ]>KoXKCV00CoXKCV1?l00006oinci`03o`000?nN
/^KoW[;V00GoW[;V00?o0000oif`iOnM/>D01?nM/>D6o`0000?oVZoV00?o0000oiR]iOnH[ND01_nH
[ND00ol0003oUj[SoiNZh`02o`0000;oUj[S00?o0000oiJWh_nFYn801OnFYn800ol0003oUJ?OoiFS
g`02oiFSgbOo00000onMRkl00ol0003oZhR`oj^8/004oj^8/003o`000?o7SYSoahjH00GoahjH00?o
0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`008oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_l00009ooooo`;o00001_nX_NT00ol0003oZ;gXojRmj005ojRmj0?o00001_nW
_>P00ol0003oYk_XojNkj005ojNkj0?o00001_nV^nP00ol0003oY[[WojJji`06ojJji`04o`000?nV
^^Oo0000o`0000CoYK[X00?o0000ojFiionU^NL01_nU^NL00ol0003oYKWWojFii`03o`0000;oY;WW
00?o0000ojBhionT^>L01OnT^>L00ol0003oXkOWoj>gi`04oj>gi`Co00001_nR]^L00ol0003oXKKW
oj6fi`05oj6fi`03o`000?nQ]>KoXKCV00?o00000_nO]>L00ol0003oWk?Woinci`06oinci`03o`00
0?nN/^KoW[;V00GoW[;V00?o0000oif`iOnM/>D00ol00002oi^ai`03o`000?nJ[nKoVZoV00GoVZoV
00?o0000oiR]iOnH[ND01OnH[ND3o`0000GoUj[S00?o0000oiJWh_nFYn800_nFYn87o`0000?oSj;R
00?o0000ohbMgon<WMl01On<WMl00ol0003oRYOKohZGf`04ohZGf`03o`000?n7T=KoQi3F00GoQi3F
00?o0000ohB7c_n4Qlh01On4Qlh00ol0003oOg_5ogmka@02ogmka@Go00001On[R;000ol0003oahjH
olN>V005olN>V003o`000?oooooooooo01Cooooo00?o0000ooooooooool0:oooool002cooooo0_l0
000:ooooo`03o`000?nX_NWoZ;gY00KoZ;gY00?o0000ojRmj?nX_NP00_nX_NP2o`0000;oYkcX00?o
0000ojNlj?nW_>P01OnW_>P00ol0003oYk_XojNkj002ojNkj0;o00000_nW^nP00ol0003oY[_XojJk
j005ojJkj003o`000?nV^^OoY[[W00CoY[[W0ol00007ojFjj003o`000?nU^NOoYKWW00CoYKWW1?l0
0006ojBii`03o`000?nT^>OoY;SW00GoY;SW00?o0000oj>gionS]nL00ol00002oj>gi`03o`000?nR
]^OoX[KW00KoX[KW00?o0000oj6fionQ]^L01?nQ]^L3o`0000KoWkCW00?o0000oincionO/nL01_nO
/nL00ol0003oW[;VoijbiP02oijbiPGo00001_nK/NL00ol0003oVZoVoiZ_iP05oiZ_iP04o`000?nH
[NGoV:gUoiR]i@?o000000?oV:gUo`000?nGZ^<00onGZ^<7o`0000?oTJKT00?o0000ohnRh_n?X^80
1On?X^800ol0003oS9gOohbMg`05ohbMg`03o`000?n:Um_oRYOK00CoRYOK00?o0000ohN@e_n7T=H0
1On7T=H00ol0003oQ8O>ohB7cP05ohB7cP03o`000?moNlGoOg_500CoOg_500?o0000og1X^_l00000
0_l00002oj^8/003o`000?o7SYSoahjH00GoahjH00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0[ooooo`00;Oooool00ol0003oooooooooo`09ooooo`03o`000?nX_NWoZ;gY00KoZ;gY00Co
0000ojRmj?l0003o00001OnW_>P00ol0003oYkcXojNlj005ojNlj004o`000?nW^nSo0000o`0000Go
Yk_X00?o0000ojJkj?nV^nP01OnV^nP00ol0003oY[[WojJji`03o`0000?oY[[X00?o0000ojFjj?nU
^^P01OnU^^P00ol0003oYKWWojFii`03o`0000;oYKWX00?o0000ojBiionT^NL01_nT^NL00ol0003o
Y;SWojBhi`04ojBhi`?o00001_nS]nL00ol0003oX[KWoj:fi`06oj:fi`03o`000?nQ]^OoXKKW00?o
000000?oX;KWo`000?nO]>L01onO]>L00ol0003oWk?Woinci`04oinci`Ko00000onL/^L00ol0003o
Vk7Woi^ai`06oi^ai`03o`000?nJ[nKoVZoV00GoVZoV0ol00002oiR]i@Oo00000onCZ^H00ol0003o
TJKToi6Vi005oi6Vi003o`000?n?X^;oSj;R00CoSj;R00?o0000ohbMgon<WMl01On<WMl00ol0003o
RYOKohZGf`04ohZGf`03o`000?n7T=KoQi3F00GoQi3F00?o0000ohB7c_n4Qlh01On4Qlh2o`0000Go
Og_500?o0000og1X^_m`J;X00_m`J;X4o`0000KoahjH00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Zooooo`00;Oooool00ol0003oooooooooo`0:ooooo`03o`000?nX_NWoZ;gY00CoZ;gY
0ol00008ojNlj003o`000?nW_>SoYkcX00CoYkcX0_l00008ojNkj003o`000?nV^nSoY[_X00CoY[_X
0ol00007ojJjj003o`000?nU^^SoYK[X00CoYK[X0ol00006ojFij003o`000?nT^NOoY;WW00KoY;WW
00?o0000ojBhionT^>L00ol00002oj>hj003o`000?nS]nOoXkOW00GoXkOW00?o0000oj:fionR]^L0
1?nR]^L4o`0000GoX;KW00?o0000oindionO]>L01_nO]>L00ol0003oWk?Woinci`03o`0000;oWKCX
00?o0000oibbionL/^L01OnL/^L00ol0003oVk7Woi^ai`06oi^ai`04o`000?nJ[nKoVZoVoiZ_iPSo
00000onE[NL00ol0003oTj[Voi>ZiP05oi>ZiP03o`000?nAY^CoTJKT00GoTJKT00?o0000ohnRh_n?
X^801?n?X^800ol0003oS9gOohbMg`05ohbMg`03o`000?n:Um_oRYOK00CoRYOK00?o0000ohN@e_n7
T=H01On7T=H00ol0003oQ8O>ohB7cP04ohB7cP03o`000?moNlGo000000GoOg_500?o0000og1X^_m`
J;X01?m`J;X00ol0003oahjHolN>V005olN>V003o`000?oooooooooo01?ooooo0_l0000/ooooo`00
;?ooool2o`0000gooooo00?o0000ojRmjOnX_NT00ol00003ojNmj@03o`000?nW_>SoYkcX00KoYkcX
00?o0000ojNlj?nW_>P00ol00002ojNlj003o`000?nW^nSoYk_X00KoYk_X00?o0000ojJkj?nV^nP0
0ol00002ojJkj003o`000?nV^^SoY[[X00KoY[[X00?o0000ojFjj?nU^^P00ol00002ojFjj003o`00
0?nU^NSoYKWX00GoYKWX00?o0000ojBiionT^NL01?nT^NL4o`0000KoXkSX00?o0000oj>gionS]nL0
1OnS]nL00ol0003oX[KWoj:fi`03o`0000?oXKOX00?o0000oj2fionP]^L01?nP]^L00ol0003oWkCW
oindi`04oindi`Co00001_nM]>P00ol0003oW;;Woibbi`05oibbi`03o`000?nK/NOoVk7W00CoVk7W
1_l00003oiN_i`03o`000?nE[NOoUJgW00GoUJgW00?o0000oi>Zi_nCZ^H01OnCZ^H00ol0003oTJKT
oi6Vi004oi6Vi003o`000?n?X^;oSj;R00GoSj;R00?o0000ohbMgon<WMl01On<WMl00ol0003oRYOK
ohZGf`04ohZGf`03o`000?n7T=KoQi3F00CoQi3F00?o0000ohB7c_n4Qlh01On4Qlh2o`0000GoOg_5
00?o0000og1X^_m`J;X01?m`J;X00ol0003oahjHolN>V005olN>V003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0:Oooool002cooooo00?o0000ooooooooool03Oooool2o`0000OoYkgY00?o
0000ojNlj?nW_>P01?nW_>P4o`0000KoYkcX00?o0000ojNkj?nW^nP01?nW^nP4o`0000KoY[_X00?o
0000ojJjj?nV^^P01?nV^^P4o`0000KoYK[X00?o0000ojFij?nU^NP01OnU^NP00ol0003oY;WWojBi
i`03o`0000?oXkWX00?o0000oj>hj?nS^>P01OnS^>P00ol0003oXkOWoj>gi`02oj>gi`Go00001onQ
]nP00ol0003oX;KWoj2fi`04oj2fi`03o`000?nO]>OoWkCW00?o00000_nN]NP00ol0003oWKCXoifd
j006oifdj003o`000?nL/^OoW;;W00GoW;;W00?o0000oi^aionK/NL01_l00007oiN_i`03o`000?nE
[NOoUJgW00CoUJgW00?o0000oi>Zi_nCZ^H01OnCZ^H00ol0003oTJKToi6Vi005oi6Vi003o`000?n?
X^;oSj;R00CoSj;R00?o0000ohbMgon<WMl01On<WMl00ol0003oRYOKohZGf`04ohZGf`03o`000?n7
T=KoQi3F00CoQi3F00?o0000ohB7c_n4Qlh01On4Qlh00ol0003oOg_5o`000004ogmka@03o`000?m`
J;[oL6Rj00CoL6Rj0_l00006olN>V003o`000?oooooooooo01Kooooo00?o0000ooooooooool0:?oo
ool002cooooo00?o0000ooooooooool03oooool00ol0003oYkgYojNmj@05ojNmj@03o`000?nW_>So
YkcX00?o00000onW_>T00ol0003oYkcXojNlj005ojNlj003o`000?nW^nSoYk_X00?o00000onV^nP0
0ol0003oY[_XojJkj005ojJkj003o`000?nV^^SoY[[X00?o00000_nU^^P00ol0003oYK[XojFjj006
ojFjj003o`000?nU^NSoYKWX00CoYKWX0ol00007oj>ij003o`000?nS^>SoXkSX00CoXkSX1Ol00004
oj:gj003o`000?nQ]nSoXKOX00KoXKOX00Co0000oj2fionP]^OoX;KW1Ol00006oijej003o`000?nM
]>SoWKCX00KoWKCX00?o0000oibbionL/^L00_nL/^L7o`0000CoVK7X00?o0000oiN_ionG[nL01OnG
[nL00ol0003oUJgWoiF]i`04oiF]i`03o`000?nCZ^KoTj[V00GoTj[V00?o0000oi6Vi?nAY^@00_nA
Y^@Lo`0000CoQi3F00?o0000ohB7c_n4Qlh01?n4Qlh01?l0003oOg_5ogmkaOl00004ogmka@03o`00
0?m`J;[oL6Rj00CoL6Rj0_l00005olN>V003o`000?oooooooooo01Kooooo00?o0000ooooooooool0
:?ooool002_ooooo0ol0000Aooooo`03o`000?nW_NWoYkgY00CoYkgY0ol00007ojNlj@03o`000?nW
_>SoYkcX00CoYkcX0ol00007ojJkj003o`000?nV^nSoY[_X00CoY[_X0ol00006ojFjj003o`000?nU
^^SoYK[X00KoYK[X00?o0000ojFij?nU^NP00ol00002ojBij003o`000?nS^NSoXkWX00KoXkWX00?o
0000oj>hj?nS^>P00ol000000onR^>So0000oj:gj007oj:gj003o`000?nQ]nSoXKOX00CoXKOX1Ol0
0004oinfj003o`000?nN]NSoW[GX00GoW[GX00?o0000oifdj?nM]>P01?nM]>P6o`0000;oV[?X0ol0
0006oiVaj003o`000?nG[nOoUjoW00GoUjoW00?o0000oiF]ionE[NL01?nE[NL00ol0003oTj[Voi>Z
iP02oi>ZiPSo00000on<Y^L00ol0003oQj;UohNRi@04ohNRi@03o`000?n3W>?oPicS00GoPicS00?o
0000ogfEgommUMl01?mmUMl00ol0003oMX_KogJ;f`05o`0000OoQ8O>00Co0000ogmkaOmoNlGo0000
0omoNlD00ol0003oL6Rjog1X^P04og1X^P;o00001Oo7SYP00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02Oooooo000/ooooo`03o`000?oooooooooo017ooooo00?o0000ojNmjOnW_NT00ol0
0003ojNmj@03o`000?nW_>WoYkcY00GoYkcY00?o0000ojNlj?nW_>P00ol00003ojJlj@03o`000?nV
^nSoY[_X00GoY[_X00?o0000ojJkj?nV^nP00ol00002ojFkj003o`000?nU^^SoYK[X00GoYK[X00?o
0000ojFjj?nU^^P01?nU^^P4o`0000KoY;WX00?o0000oj>ij?nS^NP01?nS^NP4o`0000GoX[SX00?o
0000oj:gj?nR]nP01_nR]nP00ol0003oXKOXoj6gj003o`0000;oX;OX00?o0000oinfj?nO]^P01OnO
]^P00ol0003oW[GXoijej005oijej003o`000?nM]>SoWKCX00?o00000_nL]>T00ol0003oV[?XoiZc
j003o`0000;oV[?X00?o0000oiVaj?nI/NP01OnI/NP00ol0003oUjoWoiN_i`03oiN_i`go00001?n?
Z^P00ol0003oS:KWohbVi`05ohbVi`03o`000?n7X^GoQj;U00CoQj;U00?o0000oh>Lhon3W><01On3
W><00ol0003oOIGOogfEg`04ogfEg`03o`000?mfRm_oMX_K00?oMX_K1?l00004ohB7cP04o`000?mo
NlGoOg_5o`0000?oOg_500?o0000og1X^_m`J;X01?m`J;X00ol0003o7bNOo`000004olN>V003o`00
0?oooooooooo01Sooooo00?o0000ooooooooool09_ooool000Wooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01;ooooo0_l00007ojNmj@03o`000?nW_>WoYkcY00CoYkcY0ol00007ojJlj@03
o`000?nV^nSoY[_X00CoY[_X0ol00006ojFkj003o`000?nU^^SoYK[X00GoYK[X00?o0000ojFjj?nU
^^P00ol00003ojBjj003o`000?nT^NSoY;WX00GoY;WX00?o0000oj>ij?nS^NP00ol00002oj>ij003
o`000?nR^>SoX[SX00GoX[SX00?o0000oj:gj?nR]nP01?nR]nP4o`0000KoX;OX00?o0000oinfj?nO
]^P01OnO]^P00ol0003oW[GXoijej002oijej0Go00001OnL]>T3o`0000KoV[?X00?o0000oiVaj?nI
/NP01?nI/NP00ol0003oUjoWoiN_i`03o`0000;oUK3Y00?o0000oi:]jOnB[NT01?nB[NT00ol0003o
Sj[XohnZj006ohnZj003o`000?n<Y^OoS:KW00CoS:KW00?o0000ohNRiOn7X^D01On7X^D00ol0003o
PicSoh>Lh`04oh>Lh`03o`000?mmUMooOIGO00CoOIGO00?o0000ogJ;fomfRm/01?mfRm/00ol0003o
JgoEof]oe@05o`0000?oOg_500Co0000ogmkaOmoNlGo00001_m`J;X00ol0003o7bNOo`000004olN>
V003o`000?oooooooooo01Oooooo0_l0000Xooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03
ooooo`;o00005_ooool00ol0003oYkgYojNmj@05ojNmj@03o`000?nW_>WoYkcY00?o00000_nV_>T0
0ol0003oY[cYojJlj@06ojJlj@03o`000?nV^nSoY[_X00?o000000?oYK_Yo`000?nU^nP01onU^nP0
0ol0003oYK[XojFjj004ojFjj0?o00001onT^^P00ol0003oY;WXojBij004ojBij0?o00001_nS^NP0
0ol0003oX[SXoj:hj005oj:hj003o`000?nR]nSoX[OX00?o00000_nQ^>T00ol0003oX;OXoj2gj006
oj2gj003o`000?nO]^SoWkKX00CoWkKX1Ol00003oifej@04o`000?nL]>WoW;CYoibdj@?o00000_nL
]>T00ol0003oV[?XoiZcj004oiZcj003o`000?nI/NSoVK7X00;oVK7X1Ol00006oiF`j@03o`000?nB
[NWoTZgY00CoTZgY00?o0000ohnZj?n?Z^P01_n?Z^P00ol0003oS:KWohbVi`04ohbVi`03o`000?n7
X^GoQj;U00CoQj;U00?o0000oh>Lhon3W><01On3W><00ol0003oOIGOogfEg`04ogfEg`03o`000?mf
Rm_oMX_K00CoMX_K00?o0000of]oeOm[OmD00om[OmD3o`0000;oOg_500Co0000ogmkaOmoNlGo0000
1_m`J;X00ol0003o7bNOo`000004olN>V003o`000?oooooooooo01Oooooo0_l0000Wooooo`002Ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ojNmjOnW_NT01?nW_NT3o`0000KoY[cY
00?o0000ojJljOnV_>T01OnV_>T3o`0000GoYK_Y00?o0000ojFkj?nU^nP01_nU^nP00ol0003oYK[X
ojFjj003o`0000;oY;[Y00?o0000ojBjj?nT^^P01_nT^^P00ol0003oY;WXojBij003o`000003oj>i
jOl0003oXkWX00OoXkWX00?o0000oj:hj?nR^>P01?nR^>P3o`0000KoXKSY00?o0000oj2gj?nP]nP0
1_nP]nP00ol0003oWkKXoinfj003o`000003oijfjOl0003oWKGY00KoWKGY0ol00006oibdj@04o`00
0?nJ/nSoV[?XoiZcj0Oo00001?nG/^X00ol0003oUK3YoiF`j@05oiF`j@03o`000?nB[NWoTZgY00Co
TZgY00?o0000ohnZj?n?Z^P01On?Z^P00ol0003oS:KWohbVi`04ohbVi`03o`000?n7X^GoQj;U00Go
Qj;U00?o0000oh>Lhon3W><01?n3W><00ol0003oOIGOogfEg`04ogfEg`03o`000?mfRm_oMX_K00Co
MX_K00?o0000of]oeOm[OmD01?m[OmD00ol0003oEfc<o`000002o`0000;oOg_500?o0000og1X^_m`
J;X01?m`J;X01?l0003o7bNOoalWWol00003olN>V003o`000?oooooooooo01Oooooo0ol0000Voooo
o`002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ojNmjOnW_NT00ol000000onV
_NWo0000ojJlj@07ojJlj@03o`000?nV_>WoY[cY00;oY[cY0_l000000onV_>Wo0000ojFkj@06ojFk
j@03o`000?nU^nSoYK_X00CoYK_X1?l00006ojBjj@03o`000?nT^^SoY;[X00CoY;[X1?l00005oj>i
j@03o`000?nS^NSoXkWX00KoXkWX00?o0000oj:hj?nR^>P00ol000000onR^>Wo0000oj6hj@07oj6h
j@03o`000?nP]nSoX;OX00CoX;OX1?l00005oijfj@04o`000?nM]NWoWKGYoifej@?o000000?oWKGY
o`000?nL]>T01OnL]>T5o`0000?oVK?Z00?o0000oiNbj_nG/^X01_nG/^X00ol0003oUK3YoiF`j@05
oiF`j@03o`000?nB[NWoTZgY00CoTZgY00?o0000ohnZj?n?Z^P00_n?Z^PLo`0000CoOIGO00?o0000
ogJ;fomfRm/01?mfRm/00ol0003oJgoEof]oe@04of]oe@03o`000?mGK<coEfc<00;o000000?oOg_5
o`000?m`J;X01Om`J;X01?l0003o7bNOoalWWol00003olN>V003o`000?oooooooooo01Kooooo1?l0
000Vooooo`002Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0_l0000Iooooo`;o00001OnV_NT00ol0003oY[cY
ojJlj@06ojJlj@04o`000?nV_>Wo0000o`0000CoY[cY00?o0000ojFkjOnU^nT01OnU^nT00ol0003o
YK_XojFkj003o`0000?oYK_Y00?o0000ojBjjOnT^^T01OnT^^T00ol0003oY;[XojBjj003o`0000;o
Y;[Y00?o0000oj>ijOnS^NT01OnS^NT00ol0003oXkWXoj>ij004oj>ij0Co00001OnR^>T00ol0003o
XKSYoj6hj@06oj6hj@03o`000?nP]nSoX;OX00?o00000_nO]nT00ol0003oW[KYoijfj@05oijfj@?o
00001OnM]NT00ol0003oW;CYoibdj@03o`0000;oVkGZ00?o0000oiVcj_nI/nX01?nI/nX00ol0003o
Uk;ZoiNbjP06oiNbjP03o`000?nE/>WoUK3Y00;oUK3Y3_l00003oh^[j`03o`000?n6Yn[oQZOZ00Co
QZOZ00?o0000oh2RjOn0X^T01On0X^T00ol0003oNIcWogVLi`04ogVLi`03o`000?m_TnGoKi?U00Go
00001_mfRm/00ol0003oJgoEof]oe@04of]oe@03o`000?mGK<coEfc<00;oEfc<0ol00006og1X^P04
o`000?lO9ioo7bNOo`0000;oahjH00?o0000ooooooooool05_ooool2o`000003om[>D?l0003o0000
02Gooooo0009ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo0_l0000Jooooo`03o`000?nV_NWoY[gY00GoY[gY00?o0000ojJl
jOnV_>T01?nV_>T3o`0000OoY[cY00?o0000ojFkjOnU^nT01?nU^nT3o`0000OoYK_Y00?o0000ojBj
jOnT^^T01?nT^^T3o`0000KoY;[Y00?o0000oj>ijOnS^NT01OnS^NT00ol0003oXkWXoj>ij003o`00
00?oX[WY00?o0000oj:hjOnR^>T01?nR^>T00ol0003oXKSYoj6hj@04oj6hj@Co00001_nO]nT00ol0
003oW[KYoijfj@02oijfj@Co00001?nM]NT5o`0000KoVkGZ00?o0000oiVcj_nI/nX01?nI/nX00ol0
003oUk;ZoiNbjP04oiNbjPKo00000onB/N`00ol0003oSjk[ohn^j`04ohn^j`03o`000?n;Zn_oRj_[
00GoRj_[00?o0000ohJWj_n6YnX01?n6YnX00ol0003oP:;Yoh2Rj@05oh2Rj@03o`000?miW>OoNIcW
00CoNIcW00?o0000ofnCiOm_TnD00om_TnD6o`000003ogJ;fol0003oJgoE00GoJgoE00?o0000oeM/
c?mGK<`00omGK<`3o`0000GoL6Rj00Oo0000oalWWolO9ioo7bNOo`000?o7SYSo000001Sooooo0_l0
00001?oJcU3o0000ooooool0000Tooooo`002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool06Oooool00ol0003oY[gYojJmj@05ojJmj@03o`000?nV_>WoY[cY00?o00000onV_>T00ol0003o
Y[cYojJlj@05ojJlj@03o`000?nU^nWoYK_Y00?o00000onU^nT00ol0003oYK_YojFkj@05ojFkj@03
o`000?nT^^WoY;[Y00?o00000_nT^^T00ol0003oY;[YojBjj@05ojBjj@03o`000?nS^NWoXkWY00Co
XkWY0ol00007oj:ij@03o`000?nR^>WoX[SY00CoX[SY00?o0000oj6hjOnQ^>T00ol00003oj2hj@03
o`000?nO]nWoWkOY00GoWkOY1?l00002oijfj@Ko00001?nL]^X00ol0003oVkGZoi^ejP05oi^ejP03
o`000?nI/n[oVK?Z00CoVK?Z00?o0000oiNbj_nG/^X00ol00002oiFck003o`000?nB/NcoT[7/00Go
T[7/00?o0000ohn^jon?[^/01?n?[^/00ol0003oRj_[oh^[j`05oh^[j`03o`000?n6Yn[oQZOZ00Co
QZOZ00?o0000oh2RjOn0X^T01On0X^T00ol0003oNIcWogVLi`04ogVLi`03o`000?m_TnGoKi?U00?o
Ki?U00?o0000of>8hOmSR>400_mSR>44o`0000GoJgoE00?o0000oeM/c?mGK<`00_mGK<`2o`000003
obE6_Ol0003oL6Rj00?oL6Rj00Oo0000oalWWolO9ioo7bNOo`000?o7SYSo000001Sooooo0_l00000
1?oJcU3o0000o`000?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c007ooooo`002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Joooo
o`03o`000?nV_NWoY[gY00CoY[gY0ol00007ojJlj@03o`000?nV_>WoY[cY00CoY[cY0ol00007ojFk
j@03o`000?nU^nWoYK_Y00CoYK_Y0ol00006ojBjj@03o`000?nT^^WoY;[Y00GoY;[Y00?o0000oj>i
jOnS^NT00ol00002oj>ij@03o`000?nR^NWoX[WY00KoX[WY00Co0000oj:hjOnR^>WoX[SY1Ol00007
oj2hj@03o`000?nO]nWoWkOY00;oWkOY0ol00002oijfj@?o00000_nM]nX00ol0003oW;KZoibfjP06
oibfjP03o`000?nK]N[oVkGZ00CoVkGZ00?o0000oiVcj_nI/nX00_nI/nX5o`0000KoUK?/00?o0000
oi:ak?nB/N`01OnB/N`00ol0003oSjk[ohn^j`04ohn^j`03o`000?n;Zn_oRj_[00GoRj_[00?o0000
ohJWj_n6YnX01?n6YnX00ol0003oP:;Yoh2Rj@04oh2Rj@03o`000?miW>OoNIcW00CoNIcW00?o0000
ofnCiOm_TnD01?m_TnD00ol0003oHhSQof>8h@03of>8h@04o`000?mANM_o0000o`0000?oJgoE00?o
0000oeM/c?mGK<`00omGK<`2o`000003obE6_Ol0003oL6Rj00;oL6Rj00?o0000oalWWolO9il00_lO
9il2o`0001Oooooo00?o0000ok]SI?l000000_oJcU000ol0003oooooo`000007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@07ooooo`00
:_ooool00ol0003oooooooooo`0Looooo`03o`000?nV_NWoY[gY00?o00000onV_>T00ol0003oY[cY
ojJlj@05ojJlj@03o`000?nV_>WoY[cY00?o00000_nU_>T00ol0003oYK_YojFkj@06ojFkj@03o`00
0?nU^nWoYK_Y00?o00000_nT^nT00ol0003oY;[YojBjj@05ojBjj@03o`000?nT^^WoY;[Y00CoY;[Y
0ol00006oj>ij@03o`000?nR^NWoX[WY00CoX[WY1Ol00004oj6ij@03o`000?nP^>WoX;SY00KoX;SY
2Ol00006oifgjP03o`000?nL]^[oW;KZ00KoW;KZ00Co0000oi^ej_nK]N[oVkGZ1ol00004oiNdk003
o`000?nE/ncoUK?/00GoUK?/00?o0000oi:ak?nB/N`01OnB/N`00ol0003oSjk[ohn^j`04ohn^j`03
o`000?n;Zn_oRj_[00;oRj_[5_l00002ogVLi`03o`000?m_TnGoKi?U00?oKi?U00?o0000of>8hOmS
R>401?mSR>400ol0003oDGWKoe5if`02o`000003of]oeOl0003oEfc<00GoEfc<00Co0000obE6_OlU
A[go00000om`J;X01ol0003o7bNOoalWWolO9ioo0000olN>V?l000005_ooool00ol0003o^f=To`00
0002om[>D0;o000000?oooooo`000?ooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000007ooooo`00:_ooool00ol0003oooooooooo`0Mooooo`;o0000
1onV_>T00ol0003oY[cYojJlj@04ojJlj@?o00001_nU_>T00ol0003oYK_YojFkj@04ojFkj@Co0000
1_nT^nT00ol0003oY;[YojBjj@05ojBjj@03o`000?nT^^WoY;[Y00?o00000_nS^^T00ol0003oXkWY
oj>ij@05oj>ij@03o`000?nR^NWoX[WY00?o00000_nR^NT00ol0003oXKWYoj6ij@05oj6ij@03o`00
0?nP^>WoX;SY00?oX;SY1_l00004oijhjP03o`000?nM]n[oWKOZ00GoWKOZ00?o0000oibfj_nL]^X0
1?nL]^X5o`0000CoVKK[00?o0000oiNdk?nG]>`01OnG]>`00ol0003oUK?/oiFck005oiFck003o`00
0?nB/NcoT[7/00;oT[7/3_l00003ohN]kP03o`000?n1ZNkoPJW^00CoPJW^00?o0000ogVTk_miY>h0
1?miY>h00ol0003oKYg/ofjMk002ofjMk0Ko00000om_TnD00ol0003oHhSQof>8h@03of>8h@03o`00
0?mANM_oDGWK00;oDGWK0ol00006oeM/c004o`000?lUA[go9DJmo`0000;oL6Rj00?o0000oalWWolO
9il00_lO9il2o`0001Kooooo00?o0000ok]SI?nkHf@00_l00002onkf`P;o00001_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P07ooooo`00:_ooool00ol0
003oooooooooo`0Oooooo`03o`000?nV_>WoY[cY00GoY[cY00?o0000ojJljOnV_>T00ol00002ojFl
j@03o`000?nU_>WoYKcY00GoYKcY00?o0000ojFkjOnU^nT00ol00003ojBkj@03o`000?nT^nWoY;_Y
00GoY;_Y00?o0000ojBjjOnT^^T00_nT^^T5o`0000KoXk[Y00?o0000oj>ijOnS^NT01?nS^NT3o`00
00KoX[WY00?o0000oj6ijOnQ^NT01OnQ^NT00ol0003oX;SYo`000003o`0000;oWkSZ00?o0000oijh
j_nN^>X01OnN^>X00ol0003oWKOZoifgjP05oifgjP03o`000?nL]^[oW;KZ00?o00000_nK]n/00ol0
003oVKK[oiVfj`05oiVfj`03o`000?nG]>coUkC/00GoUkC/00?o0000oiFck?nE/n`00_nE/n`7o`00
00?oT;;^00?o0000ohb`k_n</>h01?n</>h00ol0003oQjg^ohN]kP05ohN]kP03o`000?n1ZNkoPJW^
00CoPJW^00?o0000ogVTk_miY>h01?miY>h00ol0003oKYg/ofjMk004ofjMk003o`000?mQTn[oHI?Z
00Co00001_mSR>400ol0003oDGWKoe5if`03oe5if`;o00001OmGK<`01ol0003o9DJmobE6_OlUA[go
0000og1X^_l000001OlO9il00ol0003oooooooooo`0Dooooo`04o`000?nkHfCo^f=To`0000?ok_K2
00?o0000ooooool000001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c007ooooo`00:Oooool3o`00027ooooo00?o0000ojJljOnV_>T01?nV_>T3o`0000Ko
YKcY00?o0000ojFljOnU_>T01?nU_>T3o`0000OoY;_Y00?o0000ojBkjOnT^nT01?nT^nT5o`0000Co
Xk[Y00?o0000oj>jjOnS^^T01OnS^^T00ol0003oXkWYoj>ij@03o`000003oj:jjOl0003oX[WY00Oo
X[WY00?o0000oj6ijOnQ^NT01?nQ^NT3o`0000KoWkSZ00?o0000oijhj_nN^>X01OnN^>X00ol0003o
WKOZoifgjP02oifgjPGo00001_nK]n/00ol0003oVKK[oiVfj`05oiVfj`03o`000?nG]>coUkC/00;o
UkC/1ol00003oi>dk@03o`000?n@/^koT;;^00GoT;;^00?o0000ohb`k_n</>h01?n</>h00ol0003o
Qjg^ohN]kP05ohN]kP03o`000?n1ZNkoPJW^00CoPJW^00?o0000ogVTk_miY>h01?miY>h00ol0003o
KYg/ofjMk004ofjMk003o`000?mQTn[oHI?Z00;oHI?Z1?l00004of>8h@03o`000?mANM_oDGWK00;o
DGWK00Co0000ocESd_l0003o00000omGK<`2o`0000?o9DJm0_l00005oalWW`03o`000?oooooooooo
01?ooooo00Go0000ok]SI?nkHfCo^f=To`000002onkf`P05o`000?oVi<oo0000ooooool000001?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4007ooooo`00
:_ooool00ol0003oooooooooo`0Qooooo`03o`000?nV_>WoY[cY00?o00000_nU_>X00ol0003oYKcY
ojFlj@05ojFlj@03o`000?nU_>WoYKcY00?o00000onU_>T00ol0003oY;_YojBkj@05ojBkj@03o`00
0?nT^nWoY;_Y00?o000000?oY;_Yo`000?nS^^T01onS^^T00ol0003oXk[Yoj>jj@04oj>jj@?o0000
1OnR^^T00ol0003oX[WYoj:ij@06oj:ij@03o`000?nQ^NWoXKWY00?o00000_nP^NX00ol0003oWkSZ
oinhjP05oinhjP03o`000?nN^>[oW[SZ00CoW[SZ1Ol00004oifhj`03o`000?nK]n_oVkO[00GoVkO[
00?o0000oiVfjonI]^/00onI]^/6o`0000?oU[K]00?o0000oi>dkOnC]>d01OnC]>d00ol0003oT;;^
oi2bkP05oi2bkP03o`000?n</>koS;3^00CoS;3^00?o0000ohN]k_n7[Nh01?n7[Nh00ol0003oPJW^
oh6YkP04oh6YkP03o`000?miY>koNJC^00GoNJC^00?o0000ofjMk?m^WN`01?m^WN`00ol0003oHI?Z
of6CjP02of6CjP03o`000?m?Q^KoChKV00Go00001OmANM/00ol0003o=F?BocESdP03o`000003oeM/
c?l0003o000000?o9DJm0_l00004oalWW`03o`000?oooooooooo01?ooooo00Oo0000ok]SI?nkHfCo
^f=To`000?o^m/;o000000;oi^C?0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Oooooo000Zooooo`03o`000?oooooooooo02;ooooo0_l00006
ojFljP03o`000?nU_>WoYKcY00CoYKcY0ol00007ojFlj@03o`000?nT^nWoY;_Y00CoY;_Y0ol00005
ojBkj@03o`000?nS^^WoXk[Y00KoXk[Y00?o0000oj>jjOnS^^T00ol00002oj>jjP03o`000?nR^^Wo
X[[Y00CoX[[Y00?o0000oj:ijOnR^NT01?nR^NT4o`0000KoX;WZ00?o0000oinhj_nO^>X01OnO^>X0
0ol0003oW[SZoijhjP03o`0000;oW[S[00?o0000oifhjonM^>/01OnM^>/00ol0003oVkO[oi^gj`04
oi^gj`03o`000?nI]^_oVKK[00?o00000_nI]nd00ol0003oU[K]oiJfk@05oiJfk@03o`000?nC]>go
TkC]00GoTkC]00?o0000oi2bk_n@/^h01?n@/^h00ol0003oS;3^ohb`kP02ohb`kQko000000?oKYg/
o`000?mQTnX01?mQTnX00ol0003oChKVodn6iP03odn6iP?o00000omANM/00ol0003o=F?BocESdP03
ocESdP?o00001?lUA[d00ol0003o7bNOoalWW`02oalWW`03o`000?oooooooooo01?ooooo00Co0000
ok]SI?nkHfCo^f=T0_l00004onKTc`03o`000?oooooo000000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01oooool002Wooooo0ol0000Tooooo`03o`00
0?nU_>[oYKcZ00GoYKcZ00?o0000ojFljOnU_>T00ol00003ojFljP03o`000?nU_>WoYKcY00GoYKcY
00?o0000ojBkjOnT^nT00ol000000onT^n[o0000ojBkj@06ojBkj@03o`000?nS^^WoXk[Y00CoXk[Y
1?l00006oj>jjP03o`000?nR^^WoX[[Y00CoX[[Y00?o0000oj:ijOnR^NT01?l00002oj6jjP03o`00
0?nP^N[oX;WZ00GoX;WZ00?o0000oinhj_nO^>X00_nO^>X5o`0000KoW[S[00?o0000oifhjonM^>/0
1OnM^>/01?l0003oVkO[oi^gjonK]n/5o`0000KoVKO]00?o0000oiJfkOnF]^d01OnF]^d00ol0003o
TkC]oi>dk@04oi>dk@03o`000?n@/^koT;;^00;oT;;^1ol00004ohZbl003o`000?n4[o7oQ:oa00Co
Q:oa00?o0000ogb[l_mlZo801?mlZo800ol0003oLZKbog:VlP04og:VlP03o`000?mTWo7oI9oa00;o
I9oa1Ol00003of6CjP03o`000?m?Q^KoChKV00?oChKV00Co0000ocMdgol0003o00000_mANM/00ol0
003o=F?BocESdP04ocESdP;o00000olUA[d00ol0003o7bNOoalWW`03oalWW`03o`000?oooooooooo
01;ooooo00Co0000ok]SI?nkHfCo^f=T0_l00004onKTc`04o`000?ooooooooooo`0001kooooo000Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ojFlj_nU_>X01?nU_>X3o`0000OoYKcZ00?o0000
ojFljOnU_>T01?nU_>T3o`0000GoY;_Z00?o0000ojBkjOnT^nT01OnT^nT00ol0003oXk[Yoj>jj@03
o`0000?oXk_Z00?o0000oj>jj_nS^^X01OnS^^X01?l0003oX[[Yoj:jjOnR^^T6o`0000KoXK[Z00?o
0000oj2ij_nP^NX01?nP^NX5o`0000CoWkW[00?o0000oijhjonN^>/01OnN^>/00ol0003oWKS[oifh
j`02oifhj`Ko00001?nJ^>`00ol0003oVKO]oiVgk@05oiVgk@03o`000?nF]^goU[K]00CoU[K]00?o
0000oi>dkOnC]>d00_nC]>d7o`0000CoSkC`00?o0000ohZbl?n:/_001On:/_000ol0003oQ:oaohB_
l@04ohB_l@03o`000?mlZo;oO:_b00CoO:_b00?o0000og:Vl_mbY_801?mbY_800ol0003oI9oaofBO
l@03ofBOl@03o`000?mBU>ooDYC_00Go00001Om?Q^H00ol0003o=gCOocMdg`02o`000003oe5ifol0
003o=F?B00Co=F?B0ol00003obE6_@03o`000?lO9ioo7bNO00;o7bNO00?o0000ooooooooool04_oo
ool01Ol0003o^f=Tok]SI?nkHfCo000000Goi^C?0_l000000ooooooo0000ooooo`0Mooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Vooooo`03o`000?nU_>[oYKcZ00?o00000_nU_>X00ol0003o
YKcZojFljP06ojFljP03o`000?nU_>WoYKcY00?o00000_nT^nX00ol0003oY;_ZojBkjP04ojBkjP03
o`000?nT^nWoY;_Y00CoY;_Y0ol00007oj>kjP03o`000?nS^^[oXk[Z00CoXk[Z1ol000000onR^^[o
0000oj6jjP07oj6jjP03o`000?nP^N[oX;WZ00?o000000?oX;W[o`000?nO^N/01onO^N/00ol0003o
W[S[oijhj`04oijhj`Go00000onL^>`00ol0003oV[S/oiZhk005oiZhk003o`000?nI]ngoVKO]00Go
VKO]00Co0000oiJfkOnF]^goU[K]1ol00004oi:fk`03o`000?n?]?3oSkC`00GoSkC`00?o0000ohZb
l?n:/_001On:/_000ol0003oQ:oaohB_l@04ohB_l@03o`000?mlZo;oO:_b00CoO:_b00?o0000og:V
l_mbY_801?mbY_800ol0003oI9oaofBOl@03ofBOl@03o`000?mBU>ooDYC_00?oDYC_0ol00003odn6
iP03o`000?lgM=oo=gCO00;o=gCO0_l00006ocESdP?o00000_lUA[d00ol0003o7bNOoalWW`02oalW
W`03o`000?oooooooooo017ooooo00?o0000ok]SI?nkHf@00_nkHf@01?l0003oi^C?onKTcooVi<l2
o`0000;ob]ST00?o0000ooooool000007Oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`;o0000:?ooool2o`0000KoYKcZ00?o0000
ojFlj_nU_>X01?nU_>X4o`0000KoY;_Z00?o0000ojBkj_nT^nX01?nT^nX00ol0003oY;_YojBkj@03
o`0000;oXk_Z00?o0000oj>kj_nS^nX01_nS^nX00ol0003oXk[Zoj>jjP03o`000004oj:jj_l0003o
0000o`0000GoX[[Z00?o0000oj6jj_nQ^^X01?nQ^^X4o`0000GoX;W[00?o0000oinijonO^N/01_nO
^N/00ol0003oW[S[oijhj`03o`000003oifik?l0003oW;S/00KoW;S/00?o0000oiZhk?nJ^>`01OnJ
^>`00ol0003oVKO]oiVgk@02oiVgk@Ko00001?nE]nl00ol0003oT[K_oi:fk`05oi:fk`03o`000?n?
]?3oSkC`00GoSkC`00?o0000ohZbl?n:/_000_n:/_0Fo`000003og:Vl_l0003oI9oa00GoI9oa00?o
0000oe:DkomBU>l00omBU>l00ol0003o>HGZo`000002o`000003odn6i_l0003o=gCO00Co=gCO0_l0
0004ocESdP03o`000?l9A<?o000000;o9DJm0_l00003oalWW`03o`000?oooooooooo017ooooo00?o
0000ok]SI?nkHf@00_nkHf@01?l0003oi^C?onKTcol00005ol[Hi003o`000?oooooo000001cooooo
000>ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o0000
:_ooool00ol0003oYKcZojFljP05ojFljP03o`000?nU_>[oYKcZ00?o00000onT_>X00ol0003oY;_Z
ojBkjP05ojBkjP04o`000?nT^n[oY;_ZojBkjPGo00001_nS^nX00ol0003oXk_Zoj>kjP04oj>kjPCo
000000CoX[[Zo`000?l0003o00000_nR^^X00ol0003oX[[Zoj:jjP04oj:jjP03o`000?nQ^^[oXK[Z
00?o00000onQ^^/00ol0003oX;W[oj2ij`04oj2ij`03o`000?nO^N_oWkW[00CoWkW[1?l00005oifi
k003o`000?nL^>coW;S/00GoW;S/00?o0000oiZhk?nJ^>`00_nJ^>`7o`0000?oV;S^00?o0000oiFg
konE]nl01OnE]nl00ol0003oT[K_oi:fk`05oi:fk`03o`000?n?]?3oSkC`00;oSkC`1ol00003ohRd
l`03o`000?n2/_CoP[;d00CoP[;d00?o0000ogV_mOmi[oD01?mi[oD00ol0003oK:[fofbZmP02ofbZ
mPOo000000?oI9oao`000?mBU>l01OmBU>l01?l0003o>HGZocV5j_liQNX2o`0000Go=gCO00?o0000
oaQNeOl000000oleHm801?l0003o2DC3o`U4`ol00002obE6_@05o`000?lO9ioo7bNOoalWWol00000
4_ooool2o`0000Co^f=T0ol00006ol[Hi0?o00007?ooool000kooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0:Oooool00ol0003oYKcZ
ojFljP04ojFljP?o00001onT_>X00ol0003oY;_ZojBkjP04ojBkjPCo00001?nT^nX00ol0003oXk_Z
oj>kjP05oj>kjP03o`000?nS^n[oXk_Z00?o00000onS^nX2o`0000KoX[[Z00Co0000oj:jj_nR^^[o
X[[Z1Ol00007oj6jj`03o`000?nP^N_oX;W[00CoX;W[00?o0000oinijonO^N/00ol00002oijjk003
o`000?nM^NcoWKW/00GoWKW/00?o0000oibhk?nL^>`01?nL^>`5o`0000CoV[W]00?o0000oiRhk_nH
^>h01?nH^>h00ol0003oUKO_oiFgk`05oiFgk`03o`000?nB]^ooT[K_00;oT[K_1ol00003ohjflP03
o`000?n8]??oR;Cc00GoR;Cc00?o0000oh:bm?n2/_@01?n2/_@00ol0003oNJoeogV_m@04ogV_m@03
o`000?m/Z_KoK:[f00CoK:[f00Co0000oe^RmOmKX_GoFj;e1ol00002oe:Dk`03o`000?liQN[o>HGZ
00;o>HGZ0_l00004ocMdg`04o`000?lHG]Go0000o`0000;o=F?B00Go0000o`U4`ol9A<?o0000obE6
_@02o`0000?o7bNO00?o0000ooooooooool03_ooool3o`0000Co^f=T00?o0000ol[Hi?o:f>@01?o:
f>@2o`000004ol_Bh?l0003oooooo`0001_ooooo000>ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0:_ooool00ol0003o
YKcZojFljP03o`0000?oY;cZ00?o0000ojBlj_nT_>X01OnT_>X00ol0003oY;_ZojBkjP03o`0000;o
Y;_Z00?o0000ojBkj_nT^nX01?nT^nX00ol0003oXk_Zoj>kjP04oj>kjP?o00000onS^nX3o`000003
oj>kj_l0003oX[[Z00GoX[[Z1?l00004oj6jj`03o`000?nQ^^_oXK[[00KoXK[[00Co0000oj2ijonP
^N_oX;W[1Ol00006oijjk003o`000?nM^NcoWKW/00GoWKW/00?o0000oibhk?nL^>`00ol00002oibi
k@03o`000?nJ^NgoV[W]00GoV[W]00?o0000oiRhk_nH^>h01?nH^>h00ol0003oUKO_oiFgk`02oiFg
k`Oo00000onA^?400ol0003oS[KbohjflP05ohjflP03o`000?n8]??oR;Cc00GoR;Cc00?o0000oh:b
m?n2/_@01?n2/_@00ol0003oNJoeogV_m@04ogV_m@03o`000?m/Z_KoK:[f00CoK:[f00?o0000oe^R
mOmKX_D01?mKX_D00ol0003o@iKbod>FlP05o`0000?o>HGZ1?l00002ocMdg`03o`000?lHG]Go65kE
00?o00000_l9A<<4o`0000?o7bNO00?o0000ooooooooool03Oooool3o`0000Go^f=T0_l00004ol[H
i003o`000?o;d^3obm;P00;obm;P00?o0000ooooool000006_ooool000kooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000]ooooo`;o00001onT_>X00ol0
003oY;cZojBljP04ojBljP?o00001_nT^nX00ol0003oY;_ZojBkjP04ojBkjP03o`000?nS^n[oXk_Z
00?o00000onS^nX3o`0000GoXk_Z00?o0000oj:jj_nR^^X00ol000000onR^n_o0000oj6jj`06oj6j
j`03o`000?nQ^^_oXK[[00CoXK[[1Ol00004oinjj`03o`000?nN^^coW[[/00GoW[[/00?o0000oifi
k?nM^N`00_nM^N`5o`0000KoW;W]00?o0000oiZikOnJ^Nd01OnJ^Nd01?l0003oV;S^oiRhk_nH^>h7
o`0000CoUKW`00?o0000oi6hlOnA^?401?nA^?400ol0003oS[KbohjflP05ohjflP03o`000?n8]??o
R;Cc00;oR;Cc7Ol00002oe^Rm@03o`000?m3U_;o@iKb00;o@iKb00?o0000ob63jOl000000_l00000
1?liQN[o0000oaY`h?lJL>03o`0000Co65kE00Co0000o`U4`ol9A<?o2DC31?l00002oalWW`03o`00
0?oooooooooo00cooooo1?l00005ok]SI004o`000?o<i>Wo0000ol[Hi0;o00001Oo;d^000ol0003o
ooooo`00000Jooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0^ooooo`03o`000?nT_>[oY;cZ00GoY;cZ00?o0000ojBlj_nT
_>X00ol00002ojBljP03o`000?nT^n[oY;_Z00GoY;_Z00Co0000ojBkj_nT^n[oY;_Z1Ol00003oj>k
jP?o000000?oXk_Zo`000?nS^nX01OnS^nX3o`0000GoX[_[00?o0000oj6jjonQ^^/01OnQ^^/00ol0
003oXK[[oj6jj`03o`0000;oX;[[00?o0000oinjjonO^^/01OnO^^/00ol0003oW[[/oijjk004oijj
k0Go00001?nM^^d00ol0003oW;W]oibik@05oibik@03o`000?nJ^NgoV[W]00;oV[W]1_l00004oiNi
k`03o`000?nE^O3oUKW`00GoUKW`00?o0000oi6hlOnA^?401?nA^?400ol0003oS[KbohjflP02ohjf
lPOo00000on8^?D00ol0003oPKKgoh6fm`05oh6fm`03o`000?mg/oSoMk?h00CoMk?h00?o0000ofV_
nOmY[oT01?mY[oT01?l0003oEJOhoeFWn?mEYoP6o`0000;o@iKb00Co0000ob63jOlQPnWo8H?Y0ol0
0004oaY`h0;o00000olHG]D2o`0000;o2DC30ol00002oalWW`03o`000?oooooooooo00_ooooo0ol0
00000onH:2ko0000ok]SI004ok]SI004o`000?o<i>Wo0000o`0000Oobm;P0_l000000ooooooo0000
ooooo`0Hooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo02oooooo00?o0000ojBlj_nT_>X01?nT_>X3o`0000KoY;cZ00?o0000ojBkj_nT^nX0
1?nT^nX4o`0000CoXk_Z1?l00005oj>kjP03o`000?nS^n[oXk_Z00?o00000_nR^n/00ol0003oX[_[
oj:kj`04oj:kj`03o`000?nQ^^_oXK[[00CoXK[[0ol00006oj2jj`03o`000?nO^^_oWk[[00GoWk[[
00?o0000oijjk?nN^^`00ol00002oijjk003o`000?nM^^goWK[]00GoWK[]00?o0000oibikOnL^Nd0
1?nL^Nd5o`0000?oV[[^00?o0000oiNikonG^Nl01OnG^Nl00ol0003oUKW`oiFil005oiFil004o`00
0?nA^?7oTKSaoi6hl@Oo00001?n=^O<00ol0003oR;SeohRhm@04ohRhm@03o`000?n1]_OoPKKg00Go
PKKg00?o0000ogNcn?mg/oP01?mg/oP00ol0003oJJoiofV_n@04ofV_n@03o`000?mEYoSoEJOh00Co
EJOh00?o0000ocJIl_l000000ol00005ob63j@;o00000_lJL>000ol0003o05SBo`000002oaQNe@03
o`000?l0A<Ko000000;o2DC30ol000000olO9ioo0000ooooo`0:ooooo`Co00000_nH:2h00ol0003o
^f=Tok]SI003ok]SI0;o000000?o`m[Zo`000?o;d^001Oo;d^001?l0003o^L_Xo`000?ooool2o`00
01Sooooo000Xooooo`03o`000?oooooooooo033ooooo00?o0000ojBlj_nT_>X00ol00002ojBljP03
o`000?nT_>[oY;cZ00GoY;cZ00?o0000ojBkj_nT^nX00ol00002oj>ljP04o`000?nS^n[oXk_Zoj>k
jPCo00001_nS^nX4o`0000KoX[_[00?o0000oj:kjonR^n/01?nR^n/00ol0003oXK[[oj6jj`03o`00
00;oXK_[00?o0000oj2jjonP^^/01OnP^^/00ol0003oWk[[oinjj`02oinjj`Go00001_nN^^`00ol0
003oWK[]oifjk@05oifjk@03o`000?nL^NgoW;W]00?o00000_nK^^h00ol0003oV[[^oiZjkP04oiZj
kP03o`000?nG^NooUkW_00GoUkW_00?o0000oiFil?nE^O000_nE^O06o`0000GoTK[b00?o0000ohfi
lon=^O<01?n=^O<00ol0003oR;SeohRhm@04ohRhm@03o`000?n1]_OoPKKg00;oPKKg3ol00002ofV_
n@03o`000?mEYoSoEJOh00CoEJOh00Co0000ocJIl_lfVO;o=YWb1?l00003ob63j@?o000000?o6W3P
o`000?l0F=800_l000001OlHG]Go0000o`14a_l0003o2DC300?o00000_lO9il00ol0003ooooooooo
o`06ooooo`Co00001?nH:2h00ol0003o^f=Tok]SI003ok]SI005o`000?o3f^[o`m[Zol?Jj_l00000
0oo;d^02o`0000?o^L_X0ol0000Hooooo`009oooool2o`0003?ooooo0_l00006ojBljP03o`000?nT
_>[oY;cZ00CoY;cZ0ol00006oj>ljP?o00001?nS^nX00ol0003oXk_Zoj>kjP03o`0000;oXk_[00?o
0000oj:kjonR^n/01_nR^n/01?l0003oX[_[oj:kjonR^n/5o`0000KoXK_[00?o0000oj2jjonP^^/0
1?nP^^/5o`0000CoWk_/00?o0000oijjk?nN^^`01OnN^^`00ol0003oWK[]oifjk@02oifjk@Go0000
1_nK^^h00ol0003oV[[^oiZjkP04oiZjkP03o`000?nG^NooUkW_00;oUkW_1ol00004oiFjl@03o`00
0?nA^_;oTK[b00GoTK[b00?o0000ohfilon=^O<01?n=^O<01?l0003oR;SeohRhmOn8^?D7o`0000Co
PK[i00?o0000ogNhn_mg^?X01Omg^?X00ol0003oJKGkofVen`0?o`000003ocJIl_l0003o000000Co
000000Co06SHo`000?l0003o00000_l0F=801?l0003o65kEo`000?l0A<H3o`000004o`0_^?l0003o
7bNOo`0000Oooooo1?l00005oiPX;P03o`000?nkHfCo^f=T00?o^f=T00?o0000ol?Jj_o3f^X00_o3
f^X00ol0003obm;Po`000006okW;j003o`000?oooooo000001Oooooo000Xooooo`03o`000?oooooo
oooo03;ooooo00?o0000ojBlj_nT_>X01OnT_>X00ol0003oY;cZojBljP03o`0000;oY;cZ00?o0000
oj>lj_nS_>X00_nS_>X2o`000003oj>lj_l0003oXk_Z00;oXk_Z1Ol00006oj>kj`03o`000?nR^n_o
X[_[00CoX[_[1Ol00004oj:kj`03o`000?nQ^n_oXK_[00GoXK_[00?o0000oj2jjonP^^/00ol00002
oj2kk003o`000?nO^ncoWk_/00GoWk_/00?o0000oijjk?nN^^`01?nN^^`5o`0000?oWK_]00?o0000
oi^jk_nK^^h01_nK^^h01?l0003oV[[^oiZjk_nJ^^h7o`0000?oUk_`00?o0000oiFjlOnE^_401_nE
^_400ol0003oTK[boi6jlP02oi6jlPgo00001On8^oL00ol0003oPK[ioh6jn@04oh6jn@03o`000?mg
^?[oMkSj00GoMkSj00?o0000ofVenomY]O/01?mY]O/00ol0003oDjkjoe>^nP04oe>^nP03o`000?l`
X?;o<:3b00Go000000Go2X7Ro`000?l0003o0000o`1Xf002o`0000;o05SB0_l00003o`14aP?o0000
00?o7bNOo`000?ooool01?ooool5o`0000KoV2P^00?o0000ok]SI?nkHf@01?nkHf@01?l0003o`m[Z
ol?Jj_o3f^X2o`0000Oo^L_X0ol0000Gooooo`009oooool2o`0003Gooooo00?o0000ojBlj_nT_>X0
1?nT_>X3o`0000KoY;cZ1?l00003oj>ljPCo00001?nS^nX00ol0003oXk_[oj>kj`05oj>kj`03o`00
0?nR^n_oX[_[00?o00000onR^n/00ol0003oX[_[oj:kj`04oj:kj`03o`000?nQ^n_oXK_[00CoXK_[
0ol00006oj2kk003o`000?nO^ncoWk_/00GoWk_/00?o0000oijjk?nN^^`00ol00002oijkk@03o`00
0?nM^ngoWK_]00CoWK_]00?o0000oi^jk_nK^^h01?nK^^h5o`0000CoV[__00?o0000oiNkl?nG^o00
1?nG^o000ol0003oUK[aoiFjl@04oiFjl@Ko00000onB_?<00ol0003oS[_eohjkm@05ohjkm@03o`00
0?n8^oOoR;_g00GoR;_g00?o0000oh6jnOn1^_T01?n1^_T00ol0003oMkSjogNhnP02ogNhnQKo0000
00?o<:3bo`000?l000001Ol000000ol0J=So0000o`000002o`1HdP04o`000?l0A<Ko04C6o`14aPCo
00000_ooool5o`0000;oJP0000?o0000oiPX;_nH:2h01?nH:2h00ol0003o^f=Tok]SI004ok]SI0Co
000000?o_=;[o`000?nibnP00onibnP3o`000004ok_9i_l0003oooooo`0001Kooooo000Wooooo`03
o`000?oooooooooo03Gooooo00?o0000ojBlj_nT_>X00ol00002ojBlj`03o`000?nT_>[oY;cZ00;o
Y;cZ1?l00002oj>ljP?o00000_nS_>/00ol0003oXk_Zoj>kjP04oj>kjP03o`000?nS^n_oXk_[00Co
Xk_[0ol00007oj:kj`03o`000?nR^n_oX[_[00CoX[_[00?o0000oj6kjonQ^n/00ol00002oj6kj`03
o`000?nP^ncoX;_/00GoX;_/00?o0000oinkk?nO^n`00_nO^n`5o`0000KoW[_]00?o0000oifkkOnM
^nd01?nM^nd00ol0003oVk[^oi^jkP03o`0000;oVk__00?o0000oiZkkonJ^nl01OnJ^nl00ol0003o
Uk_`oiNkl004oiNkl003o`000?nE^_7oUK[a00?o00000_nE_?800ol0003oT[ccoi:ll`05oi:ll`03
o`000?n>^oGoS[_e00GoS[_e00?o0000ohRkmon8^oL00_n8^oL>o`0000CoN[gl00?o0000offloOm]
_?d01Om]_?d00ol0003oF;OloeRgo004oeRgo003o`000?lgZo;o=j_b00co00000_l0F=82o`0000;o
04C61_l00005ofX00003o`000?nH:2koV2P^00GoV2P^00?o0000ok]SI?nkHf@01?nkHf@00ol0003o
_=;[okcBj`03okcBj`04o`000?nibnSo0000o`0000Go^lWV00?o0000ooooool000005Oooool002Oo
oooo00?o0000ooooooooool0=_ooool2o`0000KoY;c[1?l00003ojBljP?o00001_nS_>/00ol0003o
Xk_Zoj>kjP04oj>kjP03o`000?nS^n_oXk_[00?o00000_nS^n/00ol0003oX[_[oj:kj`06oj:kj`04
o`000?nR^n_oX[_[oj:kj`Go00001_nQ^n/00ol0003oX;_/oj2kk004oj2kk0Go00000onO^nd00ol0
003oW[_]oijkk@06oijkk@04o`000?nM^ngoWK_]oifkk@Go00001_nK^nl00ol0003oV[__oiZkk`05
oiZkk`04o`000?nG^o3oUk_`oiNkl0Go00001_nE_?800ol0003oT[ccoi:ll`05oi:ll`03o`000?n>
^oGoS[_e00;oS[_e1ol00004ohZnn003o`000?n3__[oPkkj00CoPkkj00?o0000ogZmo?mj_O`01Omj
_O`00ol0003oKKcmofflo@02offloA_o000000Co0472o`000?l0A<Ko04C61?l00006ofX00003o`00
0?nH:2koV2P^00CoV2P^00?o0000ok]SI?nkHf@01OnkHf@00ol0003o_=;[okcBj`03okcBj`;o0000
2?nkbNH3o`0000Sooooo1?l000000ol@413oooooooooo`05ooooo`009oooool00ol0003ooooooooo
o`0gooooo`03o`000?nT_>_oY;c[00;oY;c[1?l00002ojBljP?o00000_nS_>/00ol0003oXkc[oj>l
j`05oj>lj`04o`000?nS^n[oXk_Zoj>kjPGo00001_nS^n/00ol0003oX[_[oj:kj`04oj:kj`Go0000
1OnR^n/00ol0003oXK_[oj6kj`04oj6kj`03o`000?nP^ncoX;_/00?o00000_nP^n`00ol0003oWk_]
oinkk@04oinkk@03o`000?nN^ngoW[_]00CoW[_]1Ol00005oiflkP03o`000?nK^nooVk__00CoVk__
00?o0000oiZkkonJ^nl00_nJ^nl6o`0000GoV;ca00?o0000oiFll_nE_?801?nE_?800ol0003oT[cc
oi:ll`02oi:ll`Oo00001?n?__H00ol0003oR[khohZnn005ohZnn003o`000?n3__[oPkkj00CoPkkj
00?o0000ogZmo?mj_O`00_mj_O`7o`0000CoML?n00?o0000ofC2o_mT`_h01OmT`_h00ol0003oB[_f
odZkmP02odZkmP_o000000?o0472o`000?l0A<H00ol000000ol007[o0000ofX00004ofX00003o`00
0?nH:2koV2P^00CoV2P^00?o0000ok]SI?nkHf@01OnkHf@00ol0003o_=;[okcBj`03o`000003okK>
k?l0003o^lWV00Oo^lWV0ol0000:ooooo`03o`000?oooooooooo00Oooooo000Vooooo`?o0000>Ooo
ool4o`0000?oY;c[0ol00006oj>lj`03o`000?nS_>_oXkc[00CoXkc[1?l00004oj>lj`03o`000?nS
^n_oXk_[00GoXk_[00?o0000oj:kjonR^n/00ol00002oj:kj`03o`000?nR^n_oX[_[00KoX[_[00Co
0000oj6kjonQ^n_oXK_[1Ol00006oj2kk003o`000?nO^ngoWk_]00CoWk_]00?o0000oijkkOnN^nd0
0ol00002oijlk@03o`000?nM_>koWKc^00KoWKc^00Co0000oi^kkonK^nooVk__1ol00004oiZll003
o`000?nH_?7oV;ca00GoV;ca00Co0000oiFll_nE_?;oUKcb1ol00004oi>nm003o`000?n?__KoSkkf
00GoSkkf00?o0000ohZnn?n:__P00_n:__P>o`0000GoOl?m00?o0000ogG3o_me`oh01?me`oh00ol0
003oI<;nofC2oP02ofC2oPOo00000omVc?`7o`000003o`18_ol0003o047200Wo000000?oJP00o`00
0?nH:2h01_nH:2h00ol0003o^f=Tok]SI005ok]SI0?o00001Onfc^`00ol0003o^lWVok_9iP02ok_9
iP?o000000Co/<GZo`000?oooooo00002Oooool00ol0003oooooooooo`07ooooo`009oooool00ol0
003oooooooooo`0fooooo`Co00000_nT_>/3o`0000;oXkc[00?o0000oj>ljonS_>/01OnS_>/00ol0
003oXkc[oj>lj`03o`0000;oXkc[00?o0000oj>ljonS_>/01?nS_>/00ol0003oXk_[oj>kj`04oj>k
j`?o00001_nR^n/00ol0003oX[_[oj:kj`04oj:kj`Go00001?nQ_>`00ol0003oX;_/oj2kk005oj2k
k004o`000?nO^ngoWk_]oinkk@Go00001_nN_>d00ol0003oWKc^oiflkP04oiflkPGo00001?nL_Nl0
0ol0003oV[c`oiZll005oiZll003o`000?nH_?7oV;ca00;oV;ca1_l00005oiJnl`03o`000?nC__Co
Tkkd00CoTkkd00?o0000ohnnm_n?__H00_n?__H7o`0000CoSL;i00?o0000ohO2non7`_/01On7`_/0
0ol0003oOl?mogo3o@02ogo3o@ko00000omebol7o`0000CoPMOo1ol000001?l0@L;o0000o`000?l0
8jd2o`0000;oT@@00ol00006oiPX;P03o`000?nkHfCo^f=T00Go^f=T00?o0000okK>k?nfc^`01_nf
c^`01?l0003o^lWVo`000?l00005ok35jP;o00002Oooool00ol0003oooooooooo`07ooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;o
00001_nS_>/00ol0003oXkc[oj>lj`04oj>lj`?o00001_nS_>/00ol0003oXkc[oj>lj`04oj>lj`03
o`000?nS^n_oXk_[00?o00000_nR_>/00ol0003oX[_[oj:kj`05oj:kj`03o`000?nR^n_oX[_[00?o
00000_nR_>`00ol0003oXKc/oj6lk005oj6lk003o`000?nP^ncoX;_/00CoX;_/1?l00005oinlk@03
o`000?nN_>goW[c]00CoW[c]00?o0000oiflk_nM_>h00ol00002oifmk`03o`000?nL_NooW;g_00Go
W;g_00?o0000oiZll?nJ_?001?nJ_?05o`0000?oV;kb00?o0000oiJnlonF__<01_nF__<01?l0003o
Tkkdoi>nm?nC__@7o`0000CoTL7g00?o0000ohg2nOn=`_T01On=`_T00ol0003oQl;kohO2n`02ohO2
n`Oo00001?n6b?d00ol0003oOlWoogo9o`04ogo9o`Ko00001On5d_l00ol0003oPMOooh7Go`03o`00
00?oU=cn00?o0000oiWSoOl000000_l000001?l0@L;o0000o`000?l08jd2o`0000;oT@@000?o0000
okQ3:Ol000000_l00003oiPX;P03o`000?nkHfCo^f=T00Go^f=T0_l00006okK>k0?o00001on`aNX0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00Oooooo0003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`04
ooooo`;o0000<oooool3o`0000Oooooo00?o0000oj>ljonS_>/01OnS_>/00ol0003oXkc[oj>lj`03
o`0000;oXkc[00?o0000oj>ljonS_>/01OnS_>/01?l0003oXkc[oj>ljonS_>/5o`0000KoX[c[00?o
0000oj:kjonR^n/01?nR^n/3o`0000KoX[c/00?o0000oj6lk?nQ_>`01OnQ_>`00ol0003oX;_/oj2k
k003o`0000;oX;c]00?o0000oinlkOnO_>d01OnO_>d01?l0003oW[c]oijlkOnN_>d5o`0000KoWKg_
00?o0000oibmkonL_Nl01OnL_Nl00ol0003oV[c`oiZll003o`0000;oV[ka00?o0000oiRnl_nH__80
1?nH__800ol0003oU[kcoiJnl`04oiJnl`Go00001OnD`OD00ol0003oTL7goi71m`04oi71m`03o`00
0?n=`_WoSL;i00;oSL;i1ol00004ohc6n`03o`000?n6b?goQ/Sm00GoQ/Sm00?o0000ogo9oomobOl0
0ol00004ohW>oP03o`000?n5d_ooQM;o00;oQM;o1Ol00005oiCLoPOo000000Co0472o`000?l0003o
02>]0ol00005okQ3:@Co00001onkHf@00ol0003o/m7`o`000002okK>k0?o00000_nabnd00ol0003o
/<GZok35jP04ok35jPGo00001oooool00ol0003oooooooooo`07ooooo`000oooool01Ol@413ooooo
oooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02oooooo0ol0000;ooooo`03o`000?nS_>_oXkc[00CoXkc[0ol00006oj>lj`03
o`000?nS_>_oXkc[00CoXkc[1?l00005oj>lj`03o`000?nR_>_oX[c[00CoX[c[00?o0000oj:kjonR
^n/00ol00002oj:lj`03o`000?nR_>coX[c/00GoX[c/00?o0000oj6lk?nQ_>`00_nQ_>`5o`0000Ko
X;c]00?o0000oinlkOnO_>d01?nO_>d4o`0000GoW[g^00?o0000oifmkonM_Nl01?nM_Nl00ol0003o
W;g_oibmk`02oibmk`Go00001_nJ__400ol0003oV;kboiRnlP04oiRnlP03o`000?nF__?oU[kc00?o
00000_nG`?@00ol0003oU<7eoiC1m@06oiC1m@04o`000?nA`OOoTL7goi71m`Oo00001?n@aOT00ol0
003oS<Kkohc6n`05ohc6n`03o`000?n6b?goQ/Sm00;oQ/Sm1Ol00006ohW>oPKo00001?nBe_h00ol0
003oU=cnoiCLoP03o`0000CoWm_l1ol000000ol08jgo0000okQ3:@08okQ3:@03o`000?nkHfCo^f=T
00Go^f=T00?o0000ok?Al?l000000_l00006ok7;k@03o`000?n`aN[o/<GZ00?o00000_n_a>X00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00Oooooo0003ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool0;?ooool3o`0000oooooo00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[
00GoXkc[00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[00GoXkc[00Co0000oj:l
jonR_>_oX[c[1Ol00006oj:lj`03o`000?nR_>coX[c/00CoX[c/1Ol00004oj6lk003o`000?nP_>go
X;c]00GoX;c]00?o0000oinlkOnO_>d00ol00002oinmk@03o`000?nN_NkoW[g^00GoW[g^00Co0000
oifmkonM_NooWKg_1ol00004oibnl003o`000?nJ__7oV[ka00GoV[ka00Co0000oiRnl_nH__;oV;kb
1Ol00006oiO0m003o`000?nD`OGoU<7e00CoU<7e1Ol00005oi?3m`03o`000?n@aOWoT<Gi00CoT<Gi
00?o0000ohc6non<a_/00_n<a_/7o`0000GoSL_m00?o0000ohW>o_n9c_h00ol00004oi;Ao@04o`00
0?nBe_koT]Knoi;FoPGo00001?nOfo`3o`0000;oYMWj00?o0000oj_Ln?l000000ol000000ol08jgo
0000okQ3:@07okQ3:@03o`000?nkHfCo^f=T00Go^f=T0_l000000on`c_3o0000ok7;k@05ok7;k@Co
00001_n_a>X2o`0000Gooooo00?oEEEEofIVI_l000002Oooool000?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02Wooooo0ol0000Cooooo`;o00001_nS_>/00ol0003oXkc[oj>lj`04oj>l
j`?o00001_nS_>/00ol0003oXkc[oj>lj`04oj>lj`Co00001OnR_>/00ol0003oX[c[oj:lj`04oj:l
j`03o`000?nR_>coX[c/00?o00000_nR_>`00ol0003oXKc/oj6lk005oj6lk003o`000?nP_>goX;c]
00;oX;c]1Ol00006oinmk@03o`000?nN_NkoW[g^00CoW[g^1?l00004oifnk`03o`000?nL__3oW;k`
00GoW;k`00?o0000oiZnlOnJ__400_nJ__46o`0000GoVKob00?o0000oiO0m?nG`?@01?nG`?@00ol0
003oU<7eoiC1m@03o`0000?oU/?f00?o0000oi?3monC`oL01OnC`oL01?l0003oT<Gioi35nOn@aOT7
o`0000GoTLWk00?o0000ohg;oOn=bod00_n=bod5o`0000KoT]7m1Ol00005oi_Go004o`000?nOfoco
0000o`0000KoYMWj00?o0000oj_Ln?l000001Ol00007okQ3:@;o00001_nkHf@01Ol0003o/<k`ok3>
l?n`c_3o000000;o/L_]0ol00002ojg8kP03o`000?n_a>[o[lCZ00Ko[lCZ00?o0000ooooooooool0
3oooool000?ooooo00Go410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo
00?o0000ooooooooool01_ooool2o`0002Sooooo0ol0000Hooooo`03o`000?nS_>_oXkc[00CoXkc[
00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[00GoXkc[00?o0000oj>ljonS_>/0
0ol00002oj>lj`03o`000?nR_>_oX[c[00GoX[c[00Co0000oj:ljonR_>_oX[c[1Ol00006oj:lk003
o`000?nQ_>coXKc/00CoXKc/1Ol00004oj2mk@03o`000?nO_NgoWkg]00GoWkg]00?o0000oijmk_nN
_Nh00ol000000onO_Nko0000oifnk`06oifnk`03o`000?nL__3oW;k`00CoW;k`1Ol00004oi^ol@03
o`000?nI_o;oVKob00GoVKob00Co0000oiO0m?nG`?CoUl3d1Ol00007oiK3mP03o`000?nC`oOoTl?g
00;oTl?g1_l00004oi?7n@03o`000?nAbO_oTLWk00CoTLWk1_l00005oiC>o003o`000?nBdOgoT]7m
00?o00000_nId_`00ol0003oVmOloi_Go004oi_Go0Co00001_nUfOX3o`000006ojgHm_l0003o0000
o`000?l0=[[o00001_nh@bT01?l0003oc6UBolaYD_l00005ok]SI004o`000?n`c_3o/<k`ok3>l0?o
00001_n]b>h00ol0003o[lCZojo4jP04ojo4jP?o00004?ooool000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02Cooooo0ol0000Looooo`04o`000?nS_>_oXkc[oj>lj`Go00001_nS_>/0
0ol0003oXkc[oj>lj`04oj>lj`?o00001_nS_>/00ol0003oX[c[oj:lj`04oj:lj`Co00001?nR_>`0
0ol0003oX[c/oj:lk005oj:lk003o`000?nQ_>coXKc/00?o00000_nQ_N`00ol0003oX;g]oj2mk@05
oj2mk@03o`000?nO_NgoWkg]00;oWkg]1Ol00005oinmkP03o`000?nM_^ooWKk_00GoWKk_00?o0000
oibnl?nL__000ol00002oifol003o`000?nK_o7oVkoa00GoVkoa00?o0000oiVol_nI_o800_nI_o86
o`0000CoVL;d00?o0000oiK3m_nF`oH01?nF`oH6o`0000CoU/Kg00?o0000oi?7nOnCaoT01?nCaoT0
0ol0003oTLWkoi79n`03o`0000?oU/_j00?o0000oiC>o?nDc_`01?nDc_`4o`0000KoVM;l00?o0000
oi_Go?nKeo`00ol00004oj7FnP03o`000?nUfO[oYMWj00?o00000onXe_P00ol0003o[MSfojgHmP02
o`000003o`0f^_l0003o^4<Y00Co^4<Y00Co0000olaYD_o<JE;o00001OnkHf@01_l0003o/<k`o`00
0?l0003o[<cao`0000So[LS^00?o0000ojo4j_n_a>X00ol00002ooooo`03o`000?oooooooooo00ko
oooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00005ooooo`03
o`000?oooooooooo02;ooooo0_l0000Pooooo`?o00001OnS_>/00ol0003oXkc[oj>lj`04oj>lj`03
o`000?nS_>_oXkc[00?o00000_nS_>/00ol0003oXkc[oj>lj`05oj>lj`03o`000?nR_>_oX[c[00?o
00000_nS_>/00ol0003oX[c/oj:lk004oj:lk003o`000?nR_>coX[c/00CoX[c/0ol00006oj6mk003
o`000?nP_NgoX;g]00CoX;g]1Ol00003oj2mkP03o`000?nO_NkoWkg^00GoWkg^00?o0000oifnkonM
_^l00_nM_^l5o`0000KoWKo`00?o0000oi^olOnK_o401?nK_o45o`0000CoVl7c00?o0000oiW2m?nI
`_@01?nI`_@00ol0003oU/?foiK3mP03o`0000?oV<Cf00?o0000oiK6monFa_L01OnFa_L01?l0003o
TlOioi?7nOnCaoT5o`0000OoU/_j00?o0000oiC>o?nDc_`00ol00004oiW?n`04o`000?nId_coVM;l
oiWBo0Go00001_nQe_X4o`0000KoZ=Kh0ol000001On/e?Go0000o`000?l0=[[o000000Co^4<Y00Go
0000olaYD_o<JE;oc6UBo`000004ok]SI0;o00001?n/c?400ol0003o[LS^ojg8kP04ojg8kPCo0000
1Oooool00ol0003oooooooooo`0>ooooo`009Oooool2o`00023ooooo0ol0000Sooooo`03o`000?nS
_>_oXkc[00GoXkc[00Co0000oj>ljonS_>_oXkc[1Ol00006oj>lj`03o`000?nS_>_oXkc[00CoXkc[
0ol00006oj>lj`03o`000?nR_>coX[c/00CoX[c/00?o0000oj:lk?nR_>`00ol00002oj:mk003o`00
0?nQ_NcoXKg/00GoXKg/00?o0000oj2mkOnP_Nd00ol00002oj6mk@03o`000?nP_NkoX;g^00CoX;g^
00?o0000oinmk_nO_Nh01?nO_Nh5o`0000CoW[o_00?o0000oifol?nM_o001OnM_o000ol0003oVkoa
oi^ol@03o`0000;oW<7b00?o0000oi_1lonK`O<01OnK`O<01?l0003oVL;doiW2m?nI`_@5o`0000Oo
V<Cf00?o0000oiK6monFa_L00_nFa_L6o`0000GoUlWi00?o0000oiK;n_nFboX00_nFboX5o`0000Ko
VLok1Ol00005oikCnP03o`000?nQe_[oXMKj00?o00001?nTe?T00ol0003oZ=KhojSFn003o`0000?o
Z=Cg00?o0000ojcDmOl000000ol00003okQ3:@05o`000?o<JE;oc6UBolaYD_l000001?nkHf@00ol0
003o[<caojc<l@04ojc<l@03o`000?n]b>ko[LS^00?o00002Oooool00ol0003oooooooooo`0>oooo
o`009Oooool00ol0003oooooooooo`0Looooo`?o00009oooool00ol0003oXkc[oj>lj`04oj>lj`Co
00001OnS_>/00ol0003oXkc[oj>lj`04oj>lj`03o`000?nS_>_oXkc[00?o00000_nS_>/00ol0003o
Xkc[oj>lj`05oj>lj`04o`000?nR_>coX[c/oj:lk0Go00001_nR_N`00ol0003oXKg/oj6mk004oj6m
k0?o00001_nQ_Nd00ol0003oX;g^oj2mkP04oj2mkP03o`000?nO_NkoWkg^00?o00000onO_^l00ol0
003oW[o_oijok`04oijok`03o`000?nM_o3oWKo`00;oWKo`1Ol00006oic1lP03o`000?nK`O?oVl7c
00;oVl7c1_l00005oi[3m003o`000?nHa?KoV<Cf00CoV<Cf1Ol00004oiW7m`03o`000?nGbOWoUlWi
00CoUlWi1Ol00005oi[=n@03o`000?nIco_oVLok00?o00000_nMd?T00ol0003oW]?joikCnP04oikC
nPCo00001_nTe?T4o`0000KoZ=Cg1?l000000ol0:jgo0000o`000002okQ3:@03o`000?o<JE;oc6UB
00;oc6UB00Go0000ok]SI?nkHfCo^f=To`000005ojc<l@Co00003?ooool00ol0003oooooooooo`0>
ooooo`009Oooool00ol0003oooooooooo`0Iooooo`?o0000:oooool00ol0003oXkc[oj>lj`03o`00
00;oXkc[00?o0000oj>ljonS_>/01OnS_>/01?l0003oXkc[oj>ljonS_>/5o`0000KoXkc[00?o0000
oj>ljonS_>/01?nS_>/4o`0000GoX[c/00?o0000oj:mk?nR_N`01?nR_N`00ol0003oXKg/oj6mk003
o`0000;oXKg]00?o0000oj6mkOnQ_Nd01OnQ_Nd01?l0003oX;g^oj2mk_nP_Nh5o`0000OoWkk_00Co
0000oijokonN_nooW[o_1ol00004oik0l@03o`000?nL`O;oW<7b00CoW<7b1Ol00004oic3l`03o`00
0?nJ`oCoV/?d00GoV/?d00?o0000oiS4m_nHa?H00ol00002oi_6mP03o`000?nIaoOoVLOg00GoVLOg
00?o0000oiO9nOnGbOT00ol00002oi_;n003o`000?nJcOWoV/gi00CoV/gi1?l00006oig@n@03o`00
0?nNdo[oW]?j00?o00001?nRd_T00ol0003oY=CiojCDn@03o`0000;oY]?g00?o0000ojSDmonXe?L0
0_nXe?L3o`000004ojSBm_l0003oZm;do`0000;o02^]0ol00006olaYDP06o`000?nkHfCo^f=Tok]S
I?l0003o[<ca0ol0000@ooooo`03o`000?oooooooooo00kooooo000Uooooo`03o`000?oooooooooo
01Kooooo0ol0000_ooooo`;o00001_nS_>/00ol0003oXkc[oj>lj`04oj>lj`Co00001OnS_>/00ol0
003oXkc[oj>lj`04oj>lj`03o`000?nS_>_oXkc[00?o00000_nS_>/00ol0003oX[c/oj:lk005oj:l
k004o`000?nR_NcoX[g/oj:mk0Go00001_nQ_Nd00ol0003oXKg]oj6mk@04oj6mk@Co00001OnP_^h0
0ol0003oWkk_oinnk`04oinnk`Co00001OnO`?000ol0003oW/3aoik0l@04oik0l@03o`000?nL`O;o
W<7b00?o00000_nM`_800ol0003oW<?coic3l`05oic3l`03o`000?nJ`oCoV/?d00;oV/?d1Ol00006
oi_6mP03o`000?nIaoOoVLOg00;oVLOg1Ol00006oi_;n003o`000?nJcOWoV/gi00?o00000onMc_P0
0ol0003oWM3ioig@n@04oig@n@?o00001_nRd_T4o`0000KoY]?g00Co0000ojSDmol0003o00001OnX
d_H00ol0003oZm;do`000002o`0[[@;o00001_o<JE801?l0003o^f=Tok]SI?nkHf@2o`0001?ooooo
00?o0000ooooooooool03_ooool002Cooooo0_l0000Eooooo`?o0000<oooool00ol0003oXkc[oj>l
j`05oj>lj`03o`000?nS_>_oXkc[00?o00000_nS_>/00ol0003oXkc[oj>lj`05oj>lj`04o`000?nS
_>_oXkc[oj>lj`Go00001_nS_>/00ol0003oX[c/oj:lk004oj:lk0Co00001?nR_N`00ol0003oXKg]
oj6mk@05oj6mk@03o`000?nQ_NgoXKg]00?o000000?oXKk]o`000?nP_^h01onP_^h00ol0003oWkk_
oinnk`03o`000003oj2okol0003oWl3`00OoWl3`00Co0000oik0lOnN`?7oW/3a1Ol00006oig2lP03
o`000?nL`o?oW<?c00CoW<?c1Ol00004oic5m003o`000?nKa_KoVlKf00CoVlKf1Ol00005oic9m`04
o`000?nKboSoVl_hoi_;n0Go00001onMc_P00ol0003oWM3ioig@n@03o`0000?oXM3h00?o0000oj;B
nOnRd_T00ol00003ojCAm`03o`000?nVdoOoY]?g00CoY]?g0ol00006ojSBmPCo00000_l0:jd00ol0
003oc6UBolaYDP05olaYDP04o`000?nkHfCo^f=To`0001Cooooo00?o0000ooooooooool03_ooool0
02Cooooo00?o0000ooooooooool04Oooool3o`0003Oooooo00?o0000oj>ljonS_>/01?nS_>/3o`00
00KoXkc[00?o0000oj>ljonS_>/01?nS_>/4o`0000GoXkc[00?o0000oj>ljonS_>/01?nS_>/00ol0
003oX[c/oj:lk003o`000003oj:mk?l0003oX[g/00KoX[g/00?o0000oj6mkOnQ_Nd00_nQ_Nd5o`00
00GoXKk]00?o0000oj2nk_nP_^h01?nP_^h4o`0000GoX;o_00?o0000oio0l?nO`?001?nO`?05o`00
00CoWl7a00?o0000oig2l_nM`_801OnM`_800ol0003oW<?coic3l`03o`0000;oWLCc00?o0000oic5
m?nLaO@01OnLaO@00ol0003oVlKfoi_6mP03o`0000;oWLOe00?o0000oic9monLbOL01?nLbOL5o`00
00GoW/cg00?o0000oig>n?nMc_P00_nMc_P5o`0000KoXM3h0ol00007ojCAm`03o`000?nVdoOoY]?g
00?o00000onVd_L00ol0003oZ=;fojSBmP03o`0000;oYm7f0ol000000ol0:jgo0000o`000006olaY
DP04o`000?nkHfCo^f=To`0001Gooooo00?o0000ooooooooool03Oooool002Cooooo00?o0000oooo
ooooool03oooool2o`0003_ooooo00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[
00GoXkc[00?o0000oj>ljonS_>/00ol00002oj>lj`03o`000?nS_>_oXkc[00GoXkc[00Co0000oj>l
jonS_>_oXkc[1Ol00005oj:mk003o`000?nR_NcoX[g/00CoX[g/1Ol00004oj:nk@03o`000?nQ_^go
XKk]00CoXKk]00?o0000oj2nk_nP_^h00ol00003oj6okP03o`000?nP_nooX;o_00CoX;o_00?o0000
oio0l?nO`?000ol00002oj31l003o`000?nO`O7oWl7a00GoWl7a00?o0000oig2l_nM`_800_nM`_85
o`0000KoWLCc00?o0000oic5m?nLaO@00_nLaO@5o`0000KoWLOe00?o0000oic9monLbOL00ol00003
oik:mP03o`000?nNc?OoW/cg00CoW/cg1Ol00005oj3>n003o`000?nQd?SoXM3h00?o00000_nSd?L0
0ol0003oY=7gojCAm`04ojCAm`Co00001OnVd_L4o`0000KoYm7f0ol000000ol0:jgo0000olaYDP06
olaYDP03o`000?nkHfCo000001Gooooo00?o0000ooooooooool03Oooool002Cooooo0_l0000=oooo
o`?o0000?_ooool2o`0000KoXkc[00?o0000oj>ljonS_>/01?nS_>/3o`0000KoXkc[00?o0000oj>l
jonS_>/01?nS_>/4o`0000CoXkg/00?o0000oj:mk?nR_N`01?nR_N`00ol0003oX[g/oj:mk003o`00
00;oX[g/00?o0000oj:nkOnR_^d01OnR_^d01?l0003oXKk]oj6nkOnQ_^d5o`0000OoXKo^00Co0000
oj2okonP_nooX;o_1Ol00006oj31l003o`000?nO`O7oWl7a00CoWl7a1Ol00004oio3lP03o`000?nM
a??oWLCc00CoWLCc1Ol00005oik6m004o`000?nMaoGoWLOeoig7m@Go00001onNb_H00ol0003oW/cg
oik<m`03o`0000;oX<cg00?o0000oj3>n?nPc_P01?nPc_P4o`0000KoXm3g00?o0000ojCAmonTdOL0
0ol00003ojGAm`03o`000?nVd_OoY];g00?o00000_nVdOH00ol0003oYm7fojOAmP04ojOAmPOo0000
1oo<JE82o`0001Gooooo00?o0000ooooooooool03Oooool002?ooooo0_l0000;ooooo`?o0000@ooo
ool00ol0003oXkc[oj>lj`04oj>lj`03o`000?nS_>_oXkc[00?o00000_nS_>/00ol0003oXkc[oj>l
j`05oj>lj`03o`000?nS_>_oXkc[00?o000000?oXkc[o`000?nS_N`01_nS_N`01?l0003oX[g/oj:m
k?nR_N`5o`0000KoX[g/00?o0000oj:nkOnR_^d01?nR_^d4o`0000GoX[k^00?o0000oj6ok_nQ_nh0
1?nQ_nh4o`0000GoXL3_00?o0000oj31l?nP`O001?nP`O000ol0003oWl7aoio1l@03o`0000?oX<;a
00?o0000oio3l_nO`o801?nO`o800ol0003oWLCcoig4l`03o`0000;oWlGc00?o0000oik6m?nNa_@0
1?nNa_@5o`0000CoWlSe00?o0000oik:m_nNb_H01?nNb_H4o`0000KoX<cg00?o0000oj3>n?nPc_P0
0ol00002oj;>m`03o`000?nSd?OoXm3g00CoXm3g1?l00006ojGAm`?o00001_nVdOH00ol0003oYm7f
ojOAmP03o`0000?ooooo00?o0000ooooool000000_l00006olaYDP;o00005Oooool00ol0003ooooo
ooooo`0=ooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool3o`0004Oooooo00Co0000oj>ljonS_>_oXkc[1Ol00006oj>lj`03o`000?nS_>_oXkc[00CoXkc[
0ol00005oj>lj`03o`000?nS_NcoXkg/00CoXkg/1?l00005oj>mk003o`000?nR_NcoX[g/00CoX[g/
00?o0000oj:nkOnR_^d00ol00003oj:nk@03o`000?nR_^koX[k^00CoX[k^00?o0000oj6ok_nQ_nh0
0ol000000onR`>ko0000oj70k`07oj70k`04o`000?nP`O3oX<7`oj31l0Go00001onP`_401?l0003o
Wl?boio3l_nO`o85o`0000KoWlGc00?o0000oik6m?nNa_@00ol00003oj37m003o`000?nOb?GoWlSe
00CoWlSe00?o0000oik:m_nNb_H00ol00003oj7;mP03o`000?nPc?OoX<cg00CoX<cg0ol00006oj;>
m`03o`000?nSd?OoXm3g00?o00001?nTd?L00ol0003oYM7gojGAm`03o`0000;oY]7f00?o0000ojKA
m_nVdOH01?nVdOH3o`0000Oooooo00Co0000ooooool0003o00001oo<JE800ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00gooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool3o`0004_ooooo0ol00005oj>lj`03o`000?nS_>_oXkc[00CoXkc[00?o0000oj>l
jonS_>/00ol000000onS_>_o0000oj>lj`06oj>lj`03o`000?nS_NcoXkg/00?o00000_nS_N`00ol0
003oXkg/oj>mk005oj>mk004o`000?nR_NcoX[g/oj:mk0Go00001onR_^d01?l0003oX[k^oj:nk_nR
_^h5o`0000GoX/3^00?o0000oj70konQ`>l01?nQ`>l5o`0000CoXL;`00?o0000oj32lOnP`_401?nP
`_45o`0000CoX<Cb00?o0000oio5lonOaO<01?nOaO<3o`0000OoX<Od00Co0000oio8mOnOb?GoWlSe
1Ol00007oj7;mP03o`000?nPc?OoX<cg00?o00000onRcOH01?l0003oX/kgoj;>monRc_L5o`0000Ko
Y=3g1?l00006ojKAmP03o`000?nVdOKoY]7f00?o00002oooool01?l0003oooooo`000?l00006olaY
DP03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool001cooooo00?o0000oooooooo
ool01?ooool2o`0000;ooooo0ol0001?ooooo`03o`000?nS_>_oXkc[00GoXkc[00Co0000oj>ljonS
_>_oXkc[1Ol00005oj>lj`03o`000?nS_>_oXkc[00CoXkc[0ol00006oj>mk003o`000?nS_NcoXkg/
00CoXkg/1?l00005oj>nk003o`000?nR_^goX[k]00CoX[k]1?l00004oj:okP03o`000?nR`>koX/3^
00CoX/3^00?o0000oj70konQ`>l00ol00003oj;1k`03o`000?nQ`_3oXL;`00CoXL;`00?o0000oj32
lOnP`_400ol00003oj73l@03o`000?nPa?;oX<Cb00CoX<Cb00?o0000oio5lonOaO<00ol00003oj76
l`03o`000?nPaoCoX<Od00CoX<Od1?l00005oj79m003o`000?nQboKoXL_f00;oXL_f1Ol00006oj;=
mPCo00001OnTc_H00ol0003oY=3gojC@m`03o`0000;oYM3f00?o0000ojKAm_nVdOH01?nVdOH4o`00
00oooooo00Co0000ooooool0003o00001Oo<JE800ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00gooooo000Looooo`03o`000?oooooooooo00Cooooo1?l0001Cooooo`03o`000?nS_>_oXkc[
00CoXkc[1?l00004ojBlj`03o`000?nS_>_oXkc[00CoXkc[00?o0000oj>ljonS_>/00ol00003ojBm
j`03o`000?nS_NcoXkg/00CoXkg/00?o0000oj>mk?nS_N`00ol00002oj>nk003o`000?nS_^coXkk/
00GoXkk/00?o0000oj:nkOnR_^d00ol000000onS_ngo0000oj:okP06oj:okP04o`000?nR`>koX/3^
oj;0kPGo00001onR`Nl01?l0003oXL;`oj72l?nQ`_05o`0000OoXL?a00Co0000oj34l_nPa?;oX<Cb
1Ol00007oj76l`03o`000?nPaoCoX<Od00?o00000_nRb?<00ol0003oXLWdoj79m004oj79m0Go0000
1OnSboD00ol0003oX/gfoj;=mP03o`0000;oY<ge00?o0000ojC>m_nTc_H01?nTc_H3o`0000KoYM3f
00?o0000ojKAm_nVdOH00ol0000Cooooo`03o`000?oooooooooo00;o00001?o<JE800ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo00Cooooo0_l0
001Fooooo`03o`000?nS_>_oXkc[00?o00000_nT_>/00ol0003oY;c[ojBlj`04ojBlj`04o`000?nS
_>_oXkc[oj>lj`Go00001onT_N/01?l0003oXkg/oj>mk?nS_N`5o`0000KoXkk/00?o0000oj>nk?nS
_^`01?nS_^`3o`0000GoXko]00?o0000oj:ok_nR_nh01?nR_nh4o`0000GoX/3^00?o0000oj;1konR
`Nl01?nR`Nl4o`0000CoX/;`00?o0000oj73lOnQ`o401?nQ`o45o`0000CoX/Gb00?o0000oj76lonQ
a_<01?nQa_<4o`0000KoX/Sc00?o0000oj79m?nQbO@00ol00002oj?:m003o`000?nSboGoXl_e00Co
Xl_e1?l00006ojC=m@03o`000?nTc_KoY<kf00?o00000onUcoH01?l0003oYM3fojG@m_nUd?H5o`00
01Oooooo00Co0000oooooooooooo00001?o<JE800ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo000Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E?ooool2o`00
00KoY;c[00?o0000ojBljonT_>/00onT_>/4o`0000GoY;g[00?o0000ojBmjonT_N/01?nT_N/4o`00
00GoY;g/00?o0000oj>nk?nS_^`01?nS_^`00ol0003oXkk/oj>nk003o`0000;oXkk]00?o0000oj>o
kOnS_nd01?nS_nd00ol0003oX[o^oj:okP03o`0000?oXl3^00?o0000oj;0k_nR`>h01?nR`>h00ol0
003oX/7_oj;1k`03o`0000;oXl;_00?o0000oj;2l?nR`_001?nR`_000ol0003oXL?aoj73l@03o`00
00?oX/Ca00?o0000oj;5l_nRaO801?nRaO800ol0003oXLKcoj76l`03o`0000?oX/Ob00?o0000oj;8
lonRb?<01?nRb?<3o`0000KoXl[d00?o0000oj?;mOnSboD00ol00002ojC<m003o`000?nTcOGoY<ge
00CoY<ge1?l00006ojG?mPCo00007Oooool01?l0003oooooo`000?l00003olaYDP03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03?ooool001cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Eooooo`03o`000?nT_>_oY;c[00CoY;c[00?o0000ojBljol000000_l00002ojBl
j`03o`000?nT_N_oY;g[00GoY;g[00?o0000ojBmjonT_N/00ol00002ojBmj`03o`000?nT_NcoY;g/
00GoY;g/00Co0000oj>nk?nS_^coXkk/1Ol00006oj>nk@04o`000?nS_ngoXko]oj>ok@Go00001onS
`>h01?l0003oX/3^oj;0k_nR`>h5o`0000KoXl;_00Co0000oj;2l?nR`_3oX/;`1Ol00007oj;4l@04
o`000?nRaO;oX/Gboj;5lPGo00001onRao800ol0003oX/Scoj;8l`03o`0000;oXlSc00?o0000oj?:
m?nSb_@01?nSb_@3o`0000KoY<cd00?o0000ojC=mOnTcOD00ol00004ojG=m@03o`000?nUcoKoYLof
00?o00008Oooool01?l0003oooooooooool00002olaYDP03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool001[ooooo00?oEEEEofIVI_l000002_ooool00ol0003oooooooooo`1Eoooo
o`04o`000?nT_>_oY;c[ojBlj`Co00001_nT_>/00ol0003oY;g[ojBmj`04ojBmj`?o00001_nT_N/0
0ol0003oY;g/ojBmk004ojBmk0Co00001?nT_^`00ol0003oXkk]oj>nk@04oj>nk@Co00001OnS_nd0
0ol0003oXl3^oj?0kP04oj?0kPCo00001?nS`Nh00ol0003oXl;_oj?2k`04oj?2k`Co00001OnS`o00
0ol0003oX/Caoj;4l@04oj;4l@Co00001OnSa_400ol0003oX/Oboj;7lP02oj;7lPGo00001_nSb?<0
0ol0003oXl[doj?:m003o`0000;oYL[c00?o0000ojC<m?nTc?@01?nTc?@3o`0000KoYLge1?l0000U
ooooo`06o`000?oooooo0000o`000?o<JE;o00005oooool00ol0003oooooooooo`0<ooooo`00:?oo
ool2o`0005Kooooo0ol00004ojBljP03o`000?nT_>_oY;c[00CoY;c[00?o0000ojBmjonT_N/00ol0
0003ojBmj`03o`000?nT_N_oY;g[00CoY;g[00?o0000ojBmk?nT_N`00ol000000onT_^co0000ojBn
k006ojBnk003o`000?nS_^goXkk]00?o00000_nT_n`00ol0003oXko]oj>ok@05oj>ok@03o`000?nS
`>koXl3^00?o000000?oY<3^o`000?nS`Nh01_nS`Nh00ol0003oXl;_oj?2k`03o`0000?oY<;_00?o
0000oj?3l?nS`o001?nS`o000ol0003oX/Caoj;4l@03o`0000;oY<G`00?o0000oj?6lOnSa_401?nS
a_45o`0000GoY<Ob00Co0000oj?8lonSb??oXlSc1Ol00006ojG:l`03o`000?nTc?CoY<cd00?o0000
0onVc?@00ol0003oYLgeojG=m@03o`0002[ooooo00Go0000ooooool0003oc6UBo`00000Gooooo`03
o`000?oooooooooo00cooooo000Zooooo`03o`000?oooooooooo05?ooooo00?o0000ojBlj_nT_>X0
1OnT_>X01?l0003oY;c[ojBljonT_>/5o`0000OoY;g[00Co0000ojBmjonT_N_oY;g[1Ol00005ojBn
k003o`000?nT_^coY;k/00CoY;k/0ol00006ojBok003o`000?nS_ngoXko]00CoXko]0ol00005ojC0
kP03o`000?nS`NkoXl7^00CoXl7^0ol00007ojC2k`04o`000?nS`o3oXl?`oj?3l0Go00001_nTaO00
0ol0003oXlKaoj?6l@03o`0000;oY<Ka00?o0000ojC7l_nTao801?nTao85o`0000GoYLWc00Co0000
ojG:lonUb_?oYL[c1Ol00006ojK<m0?o0000;_ooool01?l0003oooooo`000?l0000Gooooo`03o`00
0?oooooooooo00cooooo000[ooooo`03o`000?oooooooooo05?ooooo00?o0000ojBlj_nT_>X01?nT
_>X4o`0000GoY;c[00?o0000ojBmjonT_N/01?nT_N/4o`0000CoY;g[00?o0000ojBnk?nT_^`01?nT
_^`00ol0003oY;k/ojBnk003o`0000?oY;k/00?o0000ojBok?nT_n`01?nT_n`00ol0003oXko]oj>o
k@03o`0000;oY<3]00?o0000ojC0k_nT`>h01?nT`>h00ol0003oXl7^oj?1kP03o`0000;oY<;^00?o
0000ojC2konT`^l01?nT`^l5o`0000CoY<C`00?o0000ojC5l?nTaO001?nTaO03o`0000KoY<Ka00?o
0000ojC7l_nTao800ol00003ojG8lP03o`000?nUbO?oYLWc00CoYLWc1?l00005ojK;l`03o`000?nV
c?CoY/cd00?o0000<Oooool01?l0003oooooo`000?l0000Hooooo`03o`000?oooooooooo00_ooooo
000/ooooo`03o`000?oooooooooo05?ooooo00?o0000ojBlj_nT_>X00ol00002ojBljP03o`000?nT
_>_oY;c[00GoY;c[00?o0000ojBmjonT_N/00ol000000onU_N_o0000ojBmj`06ojBmj`04o`000?nT
_^coY;k/ojBnk0Go00001onT_^`01?l0003oY;o/ojBok?nT_n`5o`0000KoY<3]00Co0000ojC0k_nT
`>koY<3^1Ol00006ojC2kP03o`000?nT`^ooY<;_00?o00000onU`nl00ol0003oY<C`ojC4l004ojC4
l003o`000?nTaO3oY<G`00?o00000_nUaO000ol0003oY<KaojC6l@04ojC6l@?o00001onUb?800ol0
003oYLWcojG9l`03o`0000;oY/Wb00?o0000ojK;lonVbo<01?nVbo<3o`0003Gooooo00?o0000oooo
ool000006?ooool00ol0003oooooooooo`0;ooooo`00;Oooool2o`0005Cooooo0_l00006ojBljP03
o`000?nT_>_oY;c[00CoY;c[0ol00005ojFmj`03o`000?nT_N_oY;g[00CoY;g[1?l00005ojFnk003
o`000?nT_^coY;k/00CoY;k/1?l00004ojFok003o`000?nT`>goY<3]00CoY<3]1?l00004ojC1kP03
o`000?nT`^koY<;^00CoY<;^0ol00007ojG3k`04o`000?nTa?3oY<C`ojC4l0Go00001_nUaO000ol0
003oY<KaojC6l@03o`0000;oY/Oa00?o0000ojG8l_nUb?801?nUb?84o`0000KoY/Wb00?o0000ojK;
lonVbo<00ol0000iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02oooool002oo
oooo00?o0000ooooooooool0Doooool00ol0003oY;cZojBljP04ojBljP03o`000?nT_>_oY;c[00?o
00000_nU_NX00ol0003oYKg[ojFmj`04ojFmj`03o`000?nT_N_oY;g[00?o00000_nU_^/00ol0003o
YKk/ojFnk005ojFnk003o`000?nT_^coY;k/00?o000000?oYKo/o`000?nU_n`01_nU_n`00ol0003o
Y<3]ojC0k@03o`0000;oYL3]00?o0000ojC1k_nT`Nh01?nT`Nh00ol0003oY<;^ojC2kP03o`0000?o
YL;^00?o0000ojG3konU`nl01?nU`nl4o`0000CoYLC_00?o0000ojG5l?nUaO001?nUaO03o`0000Ko
Y/Oa00?o0000ojG8l_nUb?800ol00002ojO8l@03o`000?nVbO;oY/Wb00CoY/Wb1?l0000mooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0033ooooo00?o0000ooooooooool0
Doooool01?l0003oY;cZojBlj_nT_>X5o`0000KoYKgZ00Co0000ojFmjonU_N_oYKg[1Ol00006ojFn
j`03o`000?nU_^coYKk/00CoYKk/0ol00005ojFok003o`000?nU_ncoYKo/00CoYKo/0ol00006ojG0
k@04o`000?nT`NkoY<7^ojC1kPGo00001onU`^h00ol0003oYL?_ojG3k`03o`0000;oY/?_00?o0000
ojG4konUa>l01?nUa>l00ol0003oYLG`ojG5l003o`0000;oY/K`00?o0000ojK7lOnVao401?nVao43
o`0000KoYlSa00?o0000ojK9l_nVbO800ol00011ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02oooool0037ooooo00?o0000ooooooooool0Doooool3o`0000GoYKcZ00?o0000ojFm
j_nU_NX00onU_NX4o`0000GoYKg[00?o0000ojFnjonU_^/01?nU_^/00ol0003oYKk/ojFnk003o`00
00;oYKk[00?o0000ojFok?nU_n`01?nU_n`00ol0003oYKo/ojFok003o`0000;oYL3/00?o0000ojG0
kOnU`>d01?nU`>d4o`0000GoYL7]00?o0000ojG2k_nU`^h01?nU`^h3o`0000KoY/?_00Co0000ojG4
konUa>ooYLC_1Ol00006ojK6l003o`000?nVao7oY/Oa00?o00000_nWao000ol0003oYlSaojO8l@04
ojO8l@?o0000AOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo000boooo
o`03o`000?oooooooooo05?ooooo00?o0000ojFlj_nU_>X01OnU_>X00ol0003oYKgZo`000002o`00
00;oYKgZ00?o0000ojFmjonU_N/01OnU_N/01?l0003oYKk[ojFnjonU_^/5o`0000KoYKk[00Co0000
ojFok?nU_ncoYKo/1Ol00006ojG0k003o`000?nU`>goYL3]00?o00000_nV`Nd00ol0003oYL7]ojG1
k@05ojG1k@03o`000?nU`^koYL;^00?o00000_nV`nh00ol0003oY/?_ojK3k`04ojK3k`Co00001?nV
aNl00ol0003oY/K`ojK6l004ojK6l0?o00001_nWao000ol0003oYlSaojO8l@03o`0004Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`00<oooool2o`0005Cooooo00?o0000
ojFlj_nU_>X01?nU_>X2o`0000KoYKgZ00?o0000ojFmjonU_N/01?nU_N/4o`0000CoYKk[00?o0000
ojFnjonU_^/01?nU_^/4o`0000CoYKo/00?o0000ojG0k?nU`>`01?nU`>`3o`0000KoY/7]00?o0000
ojG1kOnU`Nd01?nU`Nd3o`0000KoY/?^00?o0000ojK3konV`nl00ol00002ojO4kP03o`000?nVaNoo
Y/G_00CoY/G_00?o0000ojK6l?nVa_000ol00002ojO6k`03o`000?nWao3oYlO`00CoYlO`0ol0001<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool003Gooooo00?o0000oooo
ooooool0D_ooool00ol0003oYKcZojFljP03o`0000;oYKcZ00?o0000ojFmj_nU_NX01?nU_NX00ol0
003oYKg[ojFmj`03o`0000;oY[g[00?o0000ojFnjonU_^/01?nU_^/00ol0003oYKk[ojFnj`03o`00
00;oY[o[00?o0000ojFok?nU_n`01?nU_n`00ol0003oYL3/ojG0k003o`0000?oY/3/00?o0000ojK1
kOnV`Nd01?nV`Nd00ol0003oYL7]ojG1k@03o`0000;oY/;]00?o0000ojK3k_nV`nh01?nV`nh3o`00
00KoYlC^00Co0000ojK5konVaNooY/G_1Ol00006ojO6k`03o`000?nWao3oYlO`00?o0000D?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo000fooooo`03o`000?oooooooooo
05;ooooo0_l00006ojFljP04o`000?nU_N[oYKgZojFmjPGo00001_nV_N/01?l0003oYKk[ojFnjonU
_^/5o`0000KoY[o[00Co0000ojFok?nU_ncoYKo/1Ol00007ojK0k004o`000?nV`NgoY/7]ojK1k@Go
00001_nV`^d00ol0003oY/?^ojK3kP03o`0000;oYl?^00?o0000ojO4k_nWa>h01?nWa>h4o`0000Go
YlG_00Co0000ojO6konWa^ooYlK_1Ol0001Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02_ooool003Oooooo00?o0000ooooooooool0D_ooool00ol0003oYKcZojFljP04ojFljPCo
00001?nV_NX00ol0003oY[g[ojJmj`04ojJmj`Co00001OnV_^/00ol0003oY[o[ojJoj`03ojJoj`Co
00001OnV_n`00ol0003oY/3/ojK0k004ojK0k0Co00001?nV`Nd00ol0003oY/;]ojK2k@04ojK2k@?o
00001_nW`nh00ol0003oYlC^ojO4kP03o`0000;oZ<C^00?o0000ojO5konWaNl01?nWaNl4o`0005[o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`00>?ooool2o`0005?ooooo
00?o0000ojFlj_nU_>X00ol00002ojJlj@03o`000?nV_N[oY[gZ00CoY[gZ00?o0000ojJmjonV_N/0
0ol00002ojJnjP03o`000?nV_^_oY[k[00GoY[k[00?o0000ojJojol000000_l00002ojJoj`03o`00
0?nV_ncoY[o/00GoY[o/00?o0000ojK0k?nV`>`00ol00002ojO0k003o`000?nV`NgoY/7]00CoY/7]
00?o0000ojK2kOnV`^d00ol00002ojO2k@03o`000?nW`nkoYl?^00CoYl?^0ol00006ojS4kP03o`00
0?nWaNooYlG_00?o0000G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo
000jooooo`03o`000?oooooooooo057ooooo0_l00006ojJlj@03o`000?nV_N[oY[gZ00?oY[gZ0ol0
0006ojJnjP03o`000?nV_^_oY[k[00CoY[k[0_l00006ojJoj`03o`000?nV_ncoY[o/00CoY[o/0ol0
0006ojO0k004o`000?nV`NgoY/7]ojK1k@Go00001_nW`^d00ol0003oYl?^ojO3kP03o`0000;oZ<?]
00?o0000ojS4k_nXa>h01?nXa>h3o`0006;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0:ooooo`00>oooool00ol0003oooooooooo`1Booooo`03o`000?nV_>WoY[cY00CoY[cY00?o
0000ojJmj_l000000_l00003ojJmjP03o`000?nV_^[oY[kZ00CoY[kZ00?o0000ojJnjonV_^/00ol0
0002ojNnj`03o`000?nV_n_oY[o[00CoY[o[00?o0000ojJok?nV_n`00ol00002ojO0j`03o`000?nW
`>coYl3/00CoYl3/1?l00004ojO1k003o`000?nW`^goYl;]00CoYl;]0ol00006ojS3k@03o`000?nX
a>koZ<C^00?o0000I_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo000l
ooooo`03o`000?oooooooooo05;ooooo00Co0000ojJljOnV_>WoY[cY1?l00007ojJmjP04o`000?nV
_^[oY[kZojJnjPGo00001_nW_^/01?l0003oY[o[ojJojonV_n/5o`0000KoYl3[00?o0000ojO0k?nW
`>`00ol00002ojO1k003o`000?nW`NcoYl7/00CoYl7/00?o0000ojO2kOnW`^d00ol00002ojS2k@03
o`000?nX`ngoZ<?]00CoZ<?]0ol0001Zooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02_ooool003gooooo0_l0001Cooooo`?o00001?nV_NT00ol0003oY[gZojJmjP04ojJmjPCo0000
1?nW_^X00ol0003oYkk[ojNnj`04ojNnj`Co00001?nW_n/00ol0003oYl3[ojO0j`04ojO0j`?o0000
1_nW`N`01?l0003oYl7/ojO1k?nW`N`5o`0000KoZ<;]00?o0000ojS3kOnX`nd00ol0001]ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool003oooooo00?o0000ooooooooool0
D?ooool00ol0003oY[gYojJmj@05ojJmj@03o`000?nV_N[oY[gZ00?o000000?oYkgYo`000?nW_^X0
1_nW_^X00ol0003oYkk[ojNnj`03o`0000;oYkkZ00?o0000ojNojonW_n/01?nW_n/00ol0003oYl3[
ojO0j`03o`0000;oZ<3[00?o0000ojO1k?nW`N`01?nW`N`4o`0000CoZ<;/00?o0000ojS2kOnX`^d0
1?nX`^d3o`00077ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`00@?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?nV_NWoY[gY00CoY[gY0ol00005ojNmj@03o`000?nW
_^[oYkkZ00CoYkkZ0ol00006ojNnjP04o`000?nW_n_oYko[ojNoj`Go00001_nX`>/00ol0003oYl7/
ojO1k003o`0000;oZ<7[00?o0000ojS2k?nX`^`01?nX`^`00ol0003oZ<;]ojS2k@03o`0007Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`00@Oooool00ol0003ooooooooo
o`1@ooooo`03o`000?nV_NWoY[gY00?o00000onW_NT00ol0003oYkgYojNmj@03ojNmj@03o`000?nW
_^[oYkkZ00?o00000_nW_^X00ol0003oYkkZojNnjP04ojNnjPCo00001?nX_n/00ol0003oZ<3[ojS0
j`04ojS0j`?o00001_nX`N/01?l0003oZ<;/ojS2k?nX`^`5o`0007Sooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`09ooooo`00@_ooool2o`00057ooooo0_l00007ojNmj@04o`000?nW
_NWoYkgYojNmj@Co00001_nW_^X00ol0003oYkkZojNnjP03o`0000?oZ;oZ00?o0000ojRojonX_n/0
0onX_n/00ol0003oZ<3[ojS0j`03o`0000;oZ<3[00?o0000ojS1jonX`N/01?nX`N/4o`0007kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`00A?ooool00ol0003ooooooooo
o`1@ooooo`03o`000?nW_NWoYkgY00CoYkgY1?l00004ojNmj@03o`000?nW_^[oYkkZ00?oYkkZ0ol0
0007ojRojP04o`000?nX_n_oZ;o[ojRoj`Co00001_nX`>/00ol0003oZ<7[ojS1j`03o`0008?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`00AOooool00ol0003ooooooooo
o`1@ooooo`03o`000?nW_NWoYkgY00?o00000_nW_NT00ol0003oYkgYojNmj@04ojNmj@03o`000?nW
_^[o000000;o00000onX_^T00ol0003oZ;oZojRojP04ojRojPCo00001?nX_nX00ol0003oZ<3[ojS0
j`03ojS0j`?o0000Qoooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo0016
ooooo`03o`000?oooooooooo053ooooo0_l00006ojNmj@04o`000?nW_NWoYkgYojNmj@Co00001onX
_^T00ol0003oZ;oZojRojP03o`0000;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX00ol0003oZ<3[o`00
0002o`0008[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`00Aoooool0
0ol0003oooooooooo`1@ooooo`03o`000?nW_NWoYkgY00CoYkgY1?l00004ojRnj@03o`000?nX_^Wo
Z;kY00CoZ;kY0ol00006ojRojP04o`000?nX_n[oZ;oZojRojPCo0000S_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo0018ooooo`;o0000DOooool00ol0003oYkgYojNmj@03
o`0000;oZ;gY00?o0000ojRnjOnX_^T01?nX_^T00ol0003oZ;kYojRnj@03o`0000;oZ;kY00?o0000
ojRoj_nX_nX01?nX_nX4o`0009?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`00B_ooool00ol0003oooooooooo`1?ooooo`;o00001_nX_NT01?l0003oZ;kYojRnjOnX_^T5
o`0000KoZ;kY00?o0000ojRoj_nX_nX00ol0002Gooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool004_ooooo00?o0000ooooooooool0D?ooool00ol0003oZ;gYojRmj@03ojRm
j@Co00001?nY_^T00ol0003oZ;kYojRnj@04ojRnj@?o0000Voooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo001<ooooo`03o`000?oooooooooo053ooooo00?o0000ojRmjOl0
00000_l00002ojVmj003o`000?nY_^WoZKkY00CoZKkY00?o0000ojRnjOnX_^T00ol0002Oooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool004gooooo0_l0001Aooooo`03o`00
0?nY_NSoZKgX00CoZKgX00?o0000ojVnjOnY_^T00onY_^T3o`000:?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`00Coooool00ol0003oooooooooo`1?ooooo`03o`000?nY
_NSoZKgX00CoZKgX00?o0000ojVnjOl000000_l0002Vooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool0053ooooo00?o0000ooooooooool0Coooool01?l0003oZKgXojVmj?nY
_NP4o`000:[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`00DOooool0
0ol0003oooooooooo`1?ooooo`?o0000[oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo001Booooo`;o0000Coooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool005Cooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`2`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool005Gooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool005Oooooo0_l0001:
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`00FOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0;?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`00F_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo0;Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`00
Foooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;Gooooo00Go0000oooooooooooo
ooooo`000008ooooo`00G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;Gooooo
00Go0000ooooooooooooooooo`000008ooooo`00GOooool2o`0004Cooooo00?o0000ooooooooool0
]_ooool01?l0003oooooooooool00008ooooo`00Goooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo0;Oooooo00?o0000ooooool000002?ooool0063ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`2gooooo`04o`000?ooooooooooo`0000Oooooo001Qooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool0^?ooool00ol0003oooooo`000007ooooo`00H_ooool2
o`0003oooooo00?o0000ooooooooool0^Oooool2o`0000Oooooo001Tooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0^Oooool3o`0000Oooooo001Uooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool0]Oooool4o`0000[ooooo001Vooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0/Oooool4o`0000kooooo001Wooooo`;o0000>Oooool00ol0003ooooooooo
o`2^ooooo`?o00004_ooool006Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Z
ooooo`Co00005Oooool006[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Voooo
o`Co00006Oooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Rooooo`Co
00007Oooool006cooooo0_l0000dooooo`03o`000?oooooooooo09kooooo1?l0000Qooooo`00K_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09_ooooo0ol0000Uooooo`00Koooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Oooooo1?l0000Xooooo`00L?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000/ooooo`00LOooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo08oooooo1?l0000`ooooo`00L_ooool2o`0002kooooo
00?o0000ooooooooool0Roooool4o`0003Cooooo001dooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Qoooool4o`0003Sooooo001eooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0Q?ooool3o`0003cooooo001fooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0P?ooool4o`0003oooooo001gooooo`;o0000:Oooool00ol0003oooooooooo`1looooo`Co
0000@oooool007Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000
Aoooool007[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000Booo
ool007_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1aooooo`?o0000Coooool0
07cooooo0_l0000Tooooo`03o`000?oooooooooo06gooooo1?l0001Booooo`00O_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo06Wooooo1?l0001Fooooo`00Ooooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo06Gooooo1?l0001Jooooo`00P?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo067ooooo1?l0001Nooooo`00POooool2o`0001oooooo00?o0000
ooooooooool0GOooool4o`0006;ooooo0023ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0F_ooool3o`0006Kooooo0024ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0E_ooool4o`0006Wooooo0025ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
D_ooool4o`0006gooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_oo
ool4o`00077ooooo0027ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000MOooool0
08Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000NOooool008[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`13ooooo`?o0000OOooool008_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`Co0000P?ooool008cooooo0_l0
000Dooooo`03o`000?oooooooooo03_ooooo1?l00024ooooo`00S_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03Sooooo1?l00028ooooo`00Soooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03Cooooo1?l0002<ooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo037ooooo0ol0002@ooooo`00TOooool2o`0000kooooo00?o0000ooooooooool0
;Oooool4o`0009?ooooo002Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Ooo
ool4o`0009Oooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4
o`0009_ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`00
09oooooo002Fooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`Co0000Xoooool009Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`?o0000Yoooool009Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003ooooo`03
o`000?oooooooooo00[ooooo1?l0002fooooo`00W_ooool01?l0003oooooooooool00009ooooo`?o
0000^_ooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o000000?o
ooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo002/ooooo`?o000000?o410@ooooooooool0]_ooool0
06kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`2gooooo`00K_ooool00ol@413o
gMgMooooo`0mooooo`03o`000?oooooooooo0;Oooooo001/ooooo`05olc<c?l@413o0000o`000?n7
QhL02oooool5o`0000;ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`06oooo
o`06oiRHV?l0003o0000ogMgMol@413o00002Oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;o
oooo00Kok^k^oeEEEOl0003o0000ogMgMol00003ooooo`08oiRHV?l0003o0000ogMgMol0003o410@
oooooonHV9P2o`000005ogMgMol@413o0000ooooool@41001Ol00003ooooo`06onk^k_mEEEGo0000
o`000?m4A4Co^[Zj1_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0
003ooooo0_l000001?l@413ooooooooooomVIVH2o`000004odA4A?o<c<coooooooooo`Go00000ooo
ool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3
ooooo`05oiRHV?l0003o0000ogMgMol000000_l@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000
odA4A?nj^[Y=ooooo`00K?ooool01_lQ8B7oQhN7oc8b<_nYZJWoA4A4ohN7Q`cooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000olc<c?o^k^koQhN7o`00
000:ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koEEEE
o`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`05o`000?o<c<cok^k^ohN7Qol00000
1?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1_ooool01_mE
EEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000ooooooooooooooooo`000002ooooo`06ofIV
I_mgMgOooooooooooon7QhOo410@1?ooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooo
oooooomgMgOoEEEE0_ooool01_l0003oZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ojVYZOoo
ooooQhN7o`000003ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooook^k^ogMgMol@
411=ooooo`00K?ooool01_l0003oooooofIVI_n7QhOogMgMoa0@40cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Wooooo00Go410@ohN7Qoooooook^k^o`00000;oooo
o`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooooooookZj^_n7QhL2ofIVIP05oa0@
4?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0D?ooool006cooooo00Ko410@omgMgOmgMgOoMgMgooooool0000<ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03okZj^_l@413o000000;o00002_oo
ool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo00Ko0000ooooooooooooooooonk^k_l00003
ooooo`05o`000?ooooooooooooooool000000_ooool00onj^[[o410@o`000002o`0000Cooooo00?o
0000ooooooooool01?ooool6o`0000Kooooo1_l00003ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooolb<S;o8B4Q00;oMgMg00?oQhN7onk^k_ooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool6o`0004gooooo001/ooooo`06
ojVYZOm4A4CoV9RHodA4A?nHV9So410@3?ooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOo
ooooojVYZOl000003?ooool00oo<c<co0000ooooo`09ooooo`06o`000?nj^[[oooooonk^k_mgMgOo
00000_ooool01_mVIVKoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01?ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<PKooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOo
ooooojVYZOl000000_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000Cooooo00?o0000oooooooo
ool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko0000okZj^_ooooook^k^ogMg
Mol00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o<S8bomgMg@04ooooo`06
oeEEEOn7QhOok^k^oooooon7QhOo<S8bCOooool006gooooo00GoV9RHo`000?l0003o410@olc<c00:
ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`08
ooooo`04oc8b<_l0003o0000oiRHV0[ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`0:
onk^k_mEEEGo0000o`000?mgMgOo0000oa0@4?oooooo410@o`0000;ooooo0_l00003ooooo`04oc8b
<_l0003o0000oiRHV0?ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^1_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mg
MgL00_l000001OnHV9Soooooooooooo^k^koIVIV00;o000000?oA4A4o`000?ooool00oooool00ol0
003oooooooooo`03ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000;ooooo00Co410@o`000?oooooooooo0_l00002ooooo`;o000000CoZJVYob4Q
8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kTgooooo001^ooooo`03okZj^_lb
<S;ooooo07kooooo00?o0000ooooooooool0M_ooool006oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo07Kooooo001nooooo`03oa0@4?oooooooooo
06cooooo00?o410@o`000?l00000N?ooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.105785, 0.020481, \
0.0037547, 0.0037547}}]
}, Open  ]],

Cell[TextData[{
  "This solution is much better behaved than the previous eigenmode \
expansion.  There is still a  Gibbs phenomenon near the wall due to the \
discontinuity in the potential there, but by the time one reaches the middle \
of the box these oscillations are no longer apparent, as seen in Cell ",
  ButtonBox["4.26",
    ButtonData:>"Cell 4.26",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[{\[Phi][1, y], \[Phi][1/2, y]}], {y, 0, 1}, 
        PlotLabel \[Rule] "\<Potential along x=1/2 and x=1\>", 
        AxesLabel \[Rule] {"\<y\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.26"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0536204 0.498498 [
[.21429 .04112 -9 -9 ]
[.21429 .04112 9 0 ]
[.40476 .04112 -9 -9 ]
[.40476 .04112 9 0 ]
[.59524 .04112 -9 -9 ]
[.59524 .04112 9 0 ]
[.78571 .04112 -9 -9 ]
[.78571 .04112 9 0 ]
[.97619 .04112 -3 -9 ]
[.97619 .04112 3 0 ]
[1.025 .05362 0 -6 ]
[1.025 .05362 10 6 ]
[.01131 .15332 -18 -4.5 ]
[.01131 .15332 0 4.5 ]
[.01131 .25302 -18 -4.5 ]
[.01131 .25302 0 4.5 ]
[.01131 .35272 -18 -4.5 ]
[.01131 .35272 0 4.5 ]
[.01131 .45242 -18 -4.5 ]
[.01131 .45242 0 4.5 ]
[.01131 .55212 -6 -4.5 ]
[.01131 .55212 0 4.5 ]
[.5 .63053 -89 0 ]
[.5 .63053 89 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .05362 m
.21429 .05987 L
s
[(0.2)] .21429 .04112 0 1 Mshowa
.40476 .05362 m
.40476 .05987 L
s
[(0.4)] .40476 .04112 0 1 Mshowa
.59524 .05362 m
.59524 .05987 L
s
[(0.6)] .59524 .04112 0 1 Mshowa
.78571 .05362 m
.78571 .05987 L
s
[(0.8)] .78571 .04112 0 1 Mshowa
.97619 .05362 m
.97619 .05987 L
s
[(1)] .97619 .04112 0 1 Mshowa
.125 Mabswid
.07143 .05362 m
.07143 .05737 L
s
.11905 .05362 m
.11905 .05737 L
s
.16667 .05362 m
.16667 .05737 L
s
.2619 .05362 m
.2619 .05737 L
s
.30952 .05362 m
.30952 .05737 L
s
.35714 .05362 m
.35714 .05737 L
s
.45238 .05362 m
.45238 .05737 L
s
.5 .05362 m
.5 .05737 L
s
.54762 .05362 m
.54762 .05737 L
s
.64286 .05362 m
.64286 .05737 L
s
.69048 .05362 m
.69048 .05737 L
s
.7381 .05362 m
.7381 .05737 L
s
.83333 .05362 m
.83333 .05737 L
s
.88095 .05362 m
.88095 .05737 L
s
.92857 .05362 m
.92857 .05737 L
s
.25 Mabswid
0 .05362 m
1 .05362 L
s
gsave
1.025 .05362 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15332 m
.03006 .15332 L
s
[(0.2)] .01131 .15332 1 0 Mshowa
.02381 .25302 m
.03006 .25302 L
s
[(0.4)] .01131 .25302 1 0 Mshowa
.02381 .35272 m
.03006 .35272 L
s
[(0.6)] .01131 .35272 1 0 Mshowa
.02381 .45242 m
.03006 .45242 L
s
[(0.8)] .01131 .45242 1 0 Mshowa
.02381 .55212 m
.03006 .55212 L
s
[(1)] .01131 .55212 1 0 Mshowa
.125 Mabswid
.02381 .07855 m
.02756 .07855 L
s
.02381 .10347 m
.02756 .10347 L
s
.02381 .1284 m
.02756 .1284 L
s
.02381 .17824 m
.02756 .17824 L
s
.02381 .20317 m
.02756 .20317 L
s
.02381 .22809 m
.02756 .22809 L
s
.02381 .27794 m
.02756 .27794 L
s
.02381 .30287 m
.02756 .30287 L
s
.02381 .32779 m
.02756 .32779 L
s
.02381 .37764 m
.02756 .37764 L
s
.02381 .40257 m
.02756 .40257 L
s
.02381 .42749 m
.02756 .42749 L
s
.02381 .47734 m
.02756 .47734 L
s
.02381 .50227 m
.02756 .50227 L
s
.02381 .52719 m
.02756 .52719 L
s
.02381 .0287 m
.02756 .0287 L
s
.02381 .00377 m
.02756 .00377 L
s
.02381 .57704 m
.02756 .57704 L
s
.02381 .60197 m
.02756 .60197 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -150 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(along) show
159.000 13.000 moveto
(x) show
165.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
177.000 13.000 moveto
(\\220) show
183.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
195.000 13.000 moveto
(and) show
219.000 13.000 moveto
(x) show
225.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
237.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05362 m
.02499 .05362 L
.02605 .05362 L
.02729 .05362 L
.02846 .05361 L
.02954 .05361 L
.03053 .0536 L
.03163 .05359 L
.03279 .05357 L
.0352 .05352 L
.03746 .05346 L
.04262 .05327 L
.04751 .05306 L
.04993 .05298 L
.0511 .05294 L
.05217 .05292 L
.05341 .05289 L
.05409 .05289 L
.05473 .05288 L
.05544 .05288 L
.05608 .05288 L
.05679 .05288 L
.05754 .05289 L
.05875 .05292 L
.05988 .05295 L
.06112 .053 L
.06244 .05307 L
.06526 .05326 L
.06787 .0535 L
.07376 .05414 L
.07886 .0547 L
.08026 .05483 L
.08176 .05495 L
.08306 .05503 L
.08375 .05507 L
.08448 .05511 L
.08577 .05515 L
.08696 .05516 L
.08766 .05516 L
.08833 .05516 L
.08957 .05512 L
.09073 .05507 L
.0918 .055 L
.09298 .05491 L
.09423 .05478 L
.09677 .05446 L
.09916 .05408 L
.10458 .05304 L
.10956 .05209 L
.11219 .05167 L
Mistroke
.11363 .05148 L
.11499 .05134 L
.11628 .05124 L
.11701 .0512 L
.11768 .05117 L
.11886 .05115 L
.12011 .05116 L
.12129 .05121 L
.12238 .05129 L
.12358 .0514 L
.12487 .05157 L
.12726 .05198 L
.12985 .05257 L
.13457 .05388 L
.13882 .05517 L
.1434 .05637 L
.14464 .05663 L
.14594 .05686 L
.14705 .05702 L
.14827 .05715 L
.14941 .05723 L
.15063 .05726 L
.15178 .05724 L
.15283 .05718 L
.15348 .05713 L
.15416 .05705 L
.1554 .05687 L
.15672 .05662 L
.15818 .05627 L
.16322 .05457 L
.16886 .05216 L
.17164 .05098 L
.17421 .05 L
.17654 .04927 L
.17773 .04897 L
.17901 .04871 L
.18029 .04853 L
.18149 .04843 L
.18219 .04841 L
.18293 .04841 L
.18424 .04848 L
.18546 .04863 L
.18657 .04883 L
.18785 .04915 L
.18906 .04952 L
.19354 .05149 L
.19884 .05462 L
.20372 .05764 L
.20624 .059 L
.20859 .06003 L
Mistroke
.20978 .06044 L
.21105 .06078 L
.21177 .06093 L
.21246 .06104 L
.21375 .06115 L
.21506 .06114 L
.21579 .06108 L
.21645 .06098 L
.21774 .0607 L
.21895 .06032 L
.22037 .05974 L
.22168 .05907 L
.22463 .05715 L
.23372 .0491 L
.23612 .04698 L
.23873 .04498 L
.23992 .0442 L
.24119 .0435 L
.24229 .04301 L
.24347 .04261 L
.24419 .04244 L
.24484 .04232 L
.24613 .04224 L
.24681 .04228 L
.24756 .04238 L
.24834 .04255 L
.24906 .04278 L
.25036 .04335 L
.25153 .04403 L
.25416 .04613 L
.25662 .04875 L
.25929 .05217 L
.26414 .05926 L
.26871 .06578 L
.27122 .06875 L
.27246 .06996 L
.27361 .07089 L
.27496 .07173 L
.27567 .07205 L
.27643 .0723 L
.27712 .07243 L
.27777 .07247 L
.27899 .07233 L
.28026 .07186 L
.28142 .07114 L
.28269 .07002 L
.28403 .06847 L
.28654 .06457 L
.28923 .05909 L
.29407 .04658 L
Mistroke
.29979 .03039 L
.30231 .02407 L
.30364 .02119 L
.30508 .01857 L
.30576 .01752 L
.30641 .01666 L
.30763 .01545 L
.30878 .01482 L
.31003 .01476 L
.31135 .01546 L
.31209 .01622 L
.31276 .01716 L
.31406 .01966 L
.31529 .0229 L
.31663 .02747 L
.31806 .0335 L
.32061 .04753 L
.32336 .06735 L
.32637 .09471 L
.33679 .2277 L
.34651 .37864 L
.35151 .45162 L
.35695 .51853 L
.35945 .54331 L
.36209 .56505 L
.36436 .5797 L
.36557 .58609 L
.36685 .59168 L
.368 .59573 L
.36925 .59913 L
.37039 .60133 L
.37146 .60264 L
.37271 .60332 L
.37386 .60315 L
.37517 .60209 L
.37642 .60032 L
.37751 .5982 L
.37866 .59544 L
.38073 .58936 L
.38541 .57202 L
.39024 .5525 L
.39484 .53633 L
.39737 .52946 L
.39871 .52657 L
.40013 .5241 L
.40145 .5224 L
.40264 .52134 L
.40384 .52075 L
.40497 .52062 L
.40603 .52087 L
Mistroke
.4072 .52154 L
.40842 .52267 L
.40956 .52409 L
.41159 .52743 L
.41377 .53198 L
.42328 .55717 L
.42585 .56353 L
.42858 .56921 L
.43091 .57294 L
.43223 .57453 L
.43347 .57564 L
.43412 .57607 L
.43483 .57642 L
.43557 .57666 L
.43626 .57676 L
.43749 .57665 L
.43881 .57613 L
.43955 .57566 L
.44036 .575 L
.44182 .57346 L
.44455 .56947 L
.45414 .549 L
.45923 .53866 L
.46069 .53628 L
.46208 .53434 L
.46334 .53289 L
.46468 .53168 L
.4659 .53091 L
.46659 .53061 L
.46724 .53042 L
.46838 .53031 L
.46961 .53051 L
.47026 .53074 L
.47097 .5311 L
.47171 .53158 L
.4724 .53213 L
.47497 .53495 L
.4774 .53862 L
.47962 .54262 L
.48459 .55284 L
.48978 .56317 L
.49271 .56784 L
.4941 .56961 L
.49541 .57097 L
.49655 .5719 L
.49777 .57261 L
.49847 .57288 L
.49913 .57304 L
.50038 .5731 L
.50168 .57283 L
Mistroke
.50289 .57226 L
.50359 .5718 L
.50422 .5713 L
.50564 .56991 L
.50797 .56687 L
.51052 .56264 L
.51567 .5523 L
.52049 .54241 L
.5226 .53861 L
.52489 .53513 L
.52628 .53343 L
.52756 .53216 L
.52879 .53124 L
.53009 .53061 L
.53075 .53042 L
.53146 .53032 L
.53274 .53042 L
.53348 .53064 L
.53426 .53099 L
.53493 .5314 L
.53566 .53196 L
.53698 .53323 L
.53818 .53467 L
.54087 .53883 L
.54571 .54868 L
.55053 .55963 L
.55504 .56876 L
.5573 .57232 L
.55847 .5738 L
.55974 .57509 L
.56046 .57566 L
.56112 .57609 L
.56244 .57663 L
.56363 .57677 L
.5649 .57652 L
.56564 .5762 L
.56631 .57579 L
.56705 .57521 L
.56783 .57446 L
.57058 .57068 L
.57304 .566 L
.57573 .55972 L
.58051 .54685 L
.5857 .5332 L
.58844 .52738 L
.58964 .52529 L
.59096 .5234 L
.59221 .52203 L
.59338 .52116 L
.59461 .52068 L
Mistroke
.5953 .52062 L
.59594 .52069 L
.59712 .52119 L
.59822 .52206 L
.59943 .52347 L
.60072 .52549 L
.6031 .53059 L
.60526 .53662 L
.61056 .55565 L
.61616 .57819 L
.61846 .58666 L
.62094 .59437 L
.62236 .59791 L
.62365 .60044 L
.62495 .60224 L
.62619 .60317 L
.62729 .60332 L
.62851 .60268 L
.62978 .60106 L
.63097 .59861 L
.63208 .59548 L
.6331 .59187 L
.6354 .5811 L
.63773 .56635 L
.64028 .54582 L
.64542 .49136 L
.65632 .3347 L
.66623 .18414 L
.67106 .12238 L
.67361 .09491 L
.6763 .07013 L
.67866 .05231 L
.68126 .03686 L
.68239 .03146 L
.68361 .02654 L
.68468 .02299 L
.68582 .01994 L
.68655 .01837 L
.68721 .0172 L
.68851 .01559 L
.68923 .01505 L
.69001 .01475 L
.69075 .01472 L
.69143 .01489 L
.69267 .0157 L
.69337 .01641 L
.69403 .01722 L
.69676 .02202 L
.69929 .02798 L
.70159 .0342 L
Mistroke
.70677 .04891 L
.71158 .06087 L
.71401 .06554 L
.71541 .06771 L
.71669 .06935 L
.71778 .07047 L
.71897 .07141 L
.72017 .07205 L
.72143 .07241 L
.72254 .07246 L
.72373 .07226 L
.72485 .07183 L
.72587 .07125 L
.72717 .07028 L
.72854 .069 L
.731 .06615 L
.73656 .05821 L
.74183 .05068 L
.74432 .04768 L
.74664 .04541 L
.74896 .04372 L
.75019 .04309 L
.75149 .0426 L
.75273 .04233 L
.7539 .04224 L
.75495 .0423 L
.75609 .0425 L
.75732 .04286 L
.75801 .04314 L
.75866 .04343 L
.76138 .04505 L
.76623 .04906 L
.7705 .05303 L
.77502 .05688 L
.77738 .05852 L
.77863 .05924 L
.77998 .0599 L
.78121 .06038 L
.78234 .06073 L
.78347 .06097 L
.78455 .06111 L
.78581 .06116 L
.78652 .06114 L
.78716 .06109 L
.7884 .0609 L
.78957 .06063 L
.79094 .0602 L
.7922 .05971 L
.79505 .05833 L
.79978 .0555 L
Mistroke
.80497 .05231 L
.80722 .05109 L
.80964 .05 L
.81081 .04957 L
.81192 .04921 L
.81291 .04895 L
.814 .04872 L
.81515 .04854 L
.81637 .04843 L
.81751 .0484 L
.81857 .04844 L
.81982 .04854 L
.82096 .04871 L
.82222 .04896 L
.82354 .04929 L
.82854 .05105 L
.83308 .05301 L
.83798 .05503 L
.84055 .0559 L
.84196 .0563 L
.84328 .05662 L
.8445 .05685 L
.84562 .05702 L
.84686 .05716 L
.84755 .05721 L
.84819 .05724 L
.84932 .05726 L
.85036 .05724 L
.85151 .05717 L
.85273 .05705 L
.85389 .05689 L
.85514 .05667 L
.85741 .05618 L
.86165 .05503 L
.86664 .05353 L
.86938 .05276 L
.87198 .05214 L
.8744 .05168 L
.87576 .05148 L
.87703 .05134 L
.87809 .05125 L
.87926 .05118 L
.88048 .05115 L
.88162 .05115 L
.88285 .05119 L
.88415 .05127 L
.88525 .05136 L
.88646 .05149 L
.88916 .05187 L
.89167 .05231 L
Mistroke
.89697 .05335 L
.89975 .05389 L
.9027 .05438 L
.90531 .05473 L
.9068 .05489 L
.90819 .055 L
.90946 .05508 L
.91063 .05513 L
.91127 .05515 L
.91197 .05516 L
.91324 .05516 L
.91443 .05514 L
.91575 .0551 L
.91641 .05506 L
.91712 .05502 L
.91841 .05494 L
.92319 .05449 L
.93207 .0535 L
.9345 .05328 L
.9371 .0531 L
.93836 .05303 L
.93956 .05297 L
.94063 .05294 L
.94179 .05291 L
.94283 .05289 L
.9438 .05288 L
.94487 .05288 L
.94602 .05289 L
.94722 .0529 L
.94836 .05293 L
.9505 .05299 L
.95854 .05332 L
.96263 .05346 L
.96491 .05352 L
.96698 .05357 L
.96816 .05358 L
.96944 .0536 L
.97065 .05361 L
.97176 .05361 L
.97279 .05362 L
.97391 .05362 L
.97509 .05362 L
.97619 .05362 L
Mfstroke
.02381 .05362 m
.06244 .06096 L
.10458 .06893 L
.14415 .07633 L
.18221 .08329 L
.22272 .09044 L
.26171 .09694 L
.30316 .10327 L
.34309 .10859 L
.3815 .11282 L
.40095 .11457 L
.42237 .11617 L
.44268 .11735 L
.45178 .11777 L
.46172 .11814 L
.4671 .11831 L
.4721 .11844 L
.47727 .11856 L
.48196 .11864 L
.48658 .1187 L
.4887 .11873 L
.49093 .11875 L
.49332 .11876 L
.49438 .11877 L
.49552 .11877 L
.49675 .11878 L
.49789 .11878 L
.49859 .11878 L
.49925 .11878 L
.50049 .11878 L
.50163 .11878 L
.50286 .11878 L
.50401 .11878 L
.50508 .11877 L
.50754 .11876 L
.51014 .11874 L
.51268 .11871 L
.51504 .11868 L
.5204 .1186 L
.5293 .11841 L
.53882 .11812 L
.54906 .11773 L
.56016 .1172 L
.58032 .11599 L
.62123 .11255 L
.66064 .10813 L
.69852 .10302 L
.73886 .09685 L
.77769 .09037 L
.81897 .08308 L
Mistroke
.85873 .07579 L
.89697 .06864 L
.93767 .06094 L
.97619 .05362 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`;o0000oooooom=ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0;oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00005?ooool2o`0001;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo02Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<01Cooooo
00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<?ooool4o`000003oa0@4?oooooooooo01Wooooo000Jooooo`03
o`000?oooooooooo02oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401?ooooo00?o0000ooooool000004_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo02Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q01?ooooo00?o0000ooooool0
00004_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40<_ooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0_oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Cooooo`05o`000?oooooo
ooooooooool000004Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000Xooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oooo
ool000004_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo02oooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01;ooooo00Go0000oooooooooooooooo
o`00000Aooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000Yoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01;ooooo00Go
0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b03;ooooo00?o0000ooooooooool06oooool001[ooooo00?o0000oooooooo
ool0;oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool04Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0002Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0<_ooool0
0ol0003oooooooooo`0Kooooo`006_ooool2o`00033ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Yooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@400booooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo02oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41004Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000002Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH01?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000003;ooooo00?o0000oooo
ooooool06oooool001[ooooo00?o0000ooooooooool0;oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00@ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@4Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT0<?ooool00omEEEGoIVIVo`00000Booooo`?o000000?o410@
ooooooooool01Oooool001[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Yoooo
o`03oa0@4?nj^[[ooooo00Kooooo000Jooooo`03o`000?oooooooooo04;ooooo1?l0000>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo1?l0001Iooooo`03oiRHV?lb<S;ooooo00Kooooo000Jooooo`03o`00
0?oooooooooo04;ooooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo0_l00003ooooo`03o`000?oooooooooo05Kooooo00?ogMgMo`000?nj^[X01_ooool001[ooooo
00?o0000ooooooooool0;_ooool5o`0000gooooo0_l00005ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;o00003Oooool5o`0004Cooooo
00?oEEEEogMgMom4A4@01_ooool001[ooooo00?o0000ooooooooool01Oooool5o`0000cooooo2_l0
000;ooooo`?o00001Oooool2o`0000[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`?o00001Oooool3o`0000[ooooo2Ol0000=ooooo`Oo00006Oooool01OoMgMgo410@oooo
oolQ8B7ogMgM00Gooooo000Boooooooo0000@_l0000;ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
1Oooool001[ooooo00Co0000oooooooooooooooo1_l00005ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01Oooool6o`0000;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooo
ooooool0003ooooo00;o00002oooool2o`0000Oooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooo000000Go00001oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo1_l00003ooooo`03o`000?oooooooooo013ooooo00?o
k^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03ooooo`006_ooool00ol0003oooooooooo`07
ooooo`Go0000;?ooool5o`0000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`Go0000:_ooool6o`0000Wooooo00?o0000ooooooooool04?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00;ooooo000Jooooo`03o`000?oooooooooo00cooooo1Ol0000j
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1^
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0d
ooooo`Oo0000;Oooool001[ooooo00?o0000ooooooooool04Oooool5o`0003Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo1Ol0000doooo
o`006_ooool00ol0003oooooooooo`0Fooooo`Go0000<Oooool2o`000003ooooool0003o000000co
oooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`09ooooo`;o000000?oooooo`000?l0
0000;oooool4o`0003Wooooo000Jooooo`03o`000?oooooooooo01_ooooo1_l0000/ooooo`?o0000
3Oooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00_ooooo0_l0000/ooooo`Co0000
?Oooool001[ooooo00?o0000ooooooooool08Oooool6o`0003Kooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`0dooooo`Go0000@Oooool001[ooooo0_l0000Xooooo`Oo0000;oooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo02gooooo1ol00016ooooo`006_ooool00ol0
003oooooooooo`0^ooooo`Ko0000:_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo
02Oooooo1_l0001=ooooo`006_ooool00ol0003oooooooooo`0dooooo`Oo00008oooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo027ooooo1ol0001Cooooo`006_ooool00ol0003ooooo
ooooo`0kooooo`Go00007_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01cooooo
1Ol0001Jooooo`006_ooool00ol0003oooooooooo`10ooooo`Co00006_ooool00ol0003ooooooooo
o`1/ooooo`03o`000?oooooooooo01Sooooo1?l0001Oooooo`006_ooool00ol0003oooooooooo`14
ooooo`Co00005_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Cooooo1?l0001S
ooooo`006_ooool00ol0003oooooooooo`18ooooo`Go00004Oooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo00cooooo2?l0001Wooooo`006_ooool00ol0003oooooooooo`1=ooooo`Oo
00002_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo2_l0001_ooooo`00
6_ooool2o`0005Gooooo2ol0001]ooooo`Ko0000NOooool001[ooooo00?o0000ooooooooool0G_oo
ool9o`0005oooooo1_l000000ooooooo0000ooooo`1looooo`006_ooool00ol0003oooooooooo`1N
ooooo`03o`000?oooooooooo00Kooooo1_l0001Booooo`Oo00001_ooool00ol0003oooooooooo`1l
ooooo`006_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo3Ol0000loooo
o`Wo00003Oooool00ol0003oooooooooo`1looooo`006_ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo01Wooooo6Ol00005oooooako00005_ooool00ol0003oooooooooo`1looooo`00
6_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo033ooooo1ol0000cooooo`03o`00
0?oooooooooo07cooooo000Jooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`1looooo`006_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo06[ooooo00?o0000ooooooooool0O?ooool001[ooooo0_l0001Pooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool0O?ooool001[ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo07cooooo000Jooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`1looooo`006_ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0O?ooool001[ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07gooooo00001?lb
<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07gooooo00001?nHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07gooooo0003ooooo`03oa0@4?oooooo
oooo00[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooooooool0OOooool000?ooooo00?o0000ooooooooool02oooool00onH
V9So8B4Qonk^kP06ooooo`?o0000Goooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo
07gooooo0003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0OOooool000?ooooo
00?o410@ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0JOooool00ol0003oooooooooo`1mooooo`0000CoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooooooo07gooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
06Sooooo00?o0000ooooooooool0OOooool001[ooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1Wooooo`03o`000?oooooooooo07kooooo000Jooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1nooooo`006_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0O_ooool001[ooooo0_l0001Q
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0O_ooool001[ooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo07kooooo000Jooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1nooooo`00
6_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0
O_ooool001[ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo07kooooo000Jooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooooooo`1nooooo`006_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool0O_ooool001[ooooo0_l0001Qooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool0O_ooool001[ooooo00?o0000ooooooooool0H?ooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo07kooooo000Jooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`1nooooo`006_ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Ooooool001[ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo07oooooo000Jooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1oooooo`00
6_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
Ooooool001[ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo07oooooo000Jooooo`;o0000H_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo07oooooo000Jooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1oooooo`006_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Go
oooo00?o0000ooooooooool0Ooooool001[ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo07oooooo000Jooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`1oooooo`006_ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Ooooool00004oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0Ooooool00004oiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo07oooooo0003ooooo`03oa0@4?oooooooooo
00Wooooo1Ol00006ooooo`?o0000HOooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
07oooooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Ooooool000?o
oooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1oooooo`000oooool00ol@413o
ooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo083ooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03
onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo083ooooo00001?lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo083o
oooo000Jooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`20ooooo`006_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0P?ooool001[ooooo0_l0001Sooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0P?ooool001[ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo083ooooo000Jooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`20ooooo`006_ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0P?ooool001[ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo083ooooo000Jooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`20ooooo`006_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0P?ooool001[o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo083o
oooo000Jooooo`;o0000Hoooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo083ooooo
000Jooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`20ooooo`006_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0P?ooool001[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo083ooooo000Jooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`21ooooo`006_ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo067ooooo00?o0000ooooooooool0POooool001[ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo087ooooo000Jooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`21ooooo`006_ooool2o`00
06Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`21ooooo`006_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0POooool001[ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo087ooooo
000Jooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`21ooooo`006_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0POooool001[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo087ooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo087ooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo087ooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000
ooooooooooooooooo`000006ooooo`?o0000Hoooool00ol0003oooooooooo`1Qooooo`03o`000?oo
oooooooo087ooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`21ooooo`000oooool00ol0003oooooooooo`09ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0POoo
ool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`21ooooo`0000CoV9RHoooo
oonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`22ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`22ooooo`006_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0P_ooool001[ooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo08;ooooo000Jooooo`;o0000IOooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo08;ooooo000Jooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`22ooooo`006_ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0P_ooool001[ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08;ooooo000Joooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`22oooo
o`006_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0P_ooool001[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo08;ooooo000Jooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`22ooooo`006_ooool2o`0006Kooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`22ooooo`006_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0P_ooool001[ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo08;ooooo000Jooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0G_ooool00ol0003oooooooooo`22ooooo`006_ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0P_ooool001[ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo08?ooooo000Joooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`23oooo
o`006_ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0Poooool001[ooooo0_l0001Vooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
Poooool001[ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Mooooo`03o`000?oo
oooooooo08?ooooo000Jooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0GOooool0
0ol0003oooooooooo`23ooooo`006_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0Poooool001[ooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo08?ooooo000Jooooo`03o`000?oooooooooo06Kooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`23ooooo`0000Co<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`23ooooo`0000CoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
06Kooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`23ooooo`000oooool00ol@413o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001_ooool3o`0006Kooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`23ooooo`000oooool00ol0003oooooooooo`09ooooo`05
oc8b<_nHV9SooooooiRHV?lb<S801_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0Poooool000?ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo08?ooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oo
oooo^[Zjoa0@4006ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`23ooooo`0000CoV9RHoooooonHV9SoMgMg2oooool01Ol0003o^[Zjoooooonj^[[o
000000Kooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo08?ooooo00001?lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0Pooo
ool001[ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo08Cooooo000Jooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`24ooooo`006_ooool2o`0006Oooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`24ooooo`006_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool0Q?ooool001[ooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo08Cooooo000Jooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0F_ooool00ol0003oooooooooo`24ooooo`006_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Q?ooool001[ooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo08Cooooo000Jooooo`03o`00
0?oooooooooo06Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`24ooooo`006_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Q?oo
ool001[ooooo0_l0001Xooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0Q?ooool0
01[ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
08Cooooo000Jooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0FOooool00ol0003o
ooooooooo`25ooooo`006_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo05Wooooo
00?o0000ooooooooool0QOooool001[ooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo08Gooooo000Jooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`25ooooo`006_ooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo00cooooo0ol0000jooooo`?o00003Oooool00ol0003oooooooooo`25oooo
o`006_ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00_ooooo0_l000000ooooooo
0000ooooo`0hooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0QOooool001[o
oooo0_l0001Xooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000goooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`25ooooo`006_ooool00ol0
003oooooooooo`1Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`?o00004Oooool3o`00013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo08Gooooo000Jooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00004Oooool01?l0003oooooooooool0000?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`25ooooo`006_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003oooool01Ol0003ooooooooooooo
oooo000000oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo08Kooooo000Jooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Q_ooool0
01[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`26ooooo`004?ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`26ooooo`00
4_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Q_ooool001;ooooo00?o0000ooooooooool01Oooool3o`0006Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Q_oo
ool001;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo08Kooooo000Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`27ooooo`004_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Qoooool001;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Oooooo000@ooooo`03oeEEEOmVIVKo000000Oooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`006_ooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000o`00000@ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo000J
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`;o000000?oooooo`000?l000004?ooool3o`00017ooooo00Co0000oooooooooooo00003_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo000Jooooo`;o0000Joooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo0ol0000Vooooo`;o00003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo000Jooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0R?ooool001[ooooo00?o0000ooooooooool0J_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`28ooooo`006_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08Sooooo
000Jooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R?ooool001[ooooo00?o0000
ooooooooool0Joooool01Ol0003ooooooooooooooooo000004cooooo00Go0000oooooooooooooooo
o`00002:ooooo`006_ooool00ol0003oooooooooo`1[ooooo`04o`000?ooooooooooo`0004gooooo
00Co0000oooooooooooo0000Roooool001[ooooo00?o0000ooooooooool0Joooool01?l0003ooooo
ooooool0001=ooooo`;o000000?oooooo`000?ooool0R_ooool001[ooooo0_l0001]ooooo`;o0000
Coooool3o`0008_ooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000
ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03
o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00/ooo
ool01OlQ8B7o0000o`000?m4A4CogMgM0;3ooooo002fooooo`03ogMgMolb<S;ooooo0:oooooo002g
ooooo`03o`000?oooooooooo01cooooo00?o8B4QomgMgOooool0Soooool004Oooooo0ol000000ol@
413oooooooooo`02ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0003o0000
ooooo`;o000000Co410@ooooooooooooV9RH0_l000000om4A4Co^[Zjooooo`02ooooo`Go00000_oo
ool01_nHV9So0000o`000?mgMgOo410@o`0000;ooooo1Ol00006ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool5o`0000?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`04oa0@
4?l0003o0000ooooo`;o000000So410@ooooooo^k^koEEEEo`000?l@413oc<c<o`0000Oooooo0_l0
0002ooooo`;o00002_ooool4o`000005oa0@4?oooooooooooiRHV?mEEED01Oooool5o`0000[ooooo
00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@
ooooooo^k^koEEEE0_l000000onHV9So0000oa0@4007ooooo`;o00000_ooool2o`0000[ooooo1?l0
00000ol@413oooooooooo`17ooooo`00B?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOo
oooooooooomgMgOoEEEE0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMooo
ooook^k^ogMgMol@4103ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool01Ol0003oc<c<onk^k_n7QhOo000000Go
oooo00?o0000ooooooooool01_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo00?o0000oooo
ooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000oooooooooooooooo
o`000002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00001oooool01oo^k^ko8B4QohN7Qonj^[[o
0000omgMgOooool01_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000omgMgOooool00ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00Go0000olc<c?o^k^koQhN7o`000004ooooo`05
o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Sooooo00Oo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMgooooo00Ko00001Oooool00ol0003oooooooooo`19ooooo`00
B?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413oQhN7ooooooo^k^ko
000000Gooooo00?o0000ooooooooool01_ooool01Ol@413oQhN7ooooooo^k^ko000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`03onk^k_l0003ooooo00Oooooo00CogMgMo`000?l@
413oc<c<3Oooool00ol0003oooooooooo`03ooooo`;oMgMg1Oooool00onHV9So8B4Qonk^kP0;oooo
o`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko
0000ooooooooooooooooonk^k_l00009ooooo`04omgMgOl0003o410@olc<c0gooooo00?o0000oooo
ooooool0BOooool004Sooooo0ol000001OlQ8B7oc<c<oooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o00001Ooo
ool00ol0003oooooooooo`06ooooo`03okZj^_l@413o000000;o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?ok^k^o`000?ooool01oooool01?o^k^ko8B4Qoa0@4?o^k^h2oooo
o`Ko00001Oooool00ol0003oooooooooo`03ooooo`03onk^k_l@413ok^k^00Gooooo00?oV9RHob4Q
8Oo^k^h02_ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000ooooooooooooooooo`000002
ooooo`06o`000?ooooooooooooooooo^k^ko00002Oooool01?o^k^ko8B4Qoa0@4?o^k^h2ooooo`Ko
00001Oooool00ol0003oooooooooo`19ooooo`00B?ooool01Ol0003ooooooooooon7QhOo410@00;o
oooo00KoEEEEogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00Cooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?oc<c<o`000?ooool01?ooool00ol0003o
ooooooooo`09ooooo`03olc<c?l0003ooooo00Cooooo00?o0000ooooooooool00oooool01_mEEEGo
MgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06oeEEEOmg
MgOoooooonk^k_mEEEGo00002?ooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?oooooooooo
00Cooooo00?oEEEEoiRHV?ooool01Oooool00omgMgOoIVIVooooo`0<ooooo`03olc<c?l0003ooooo
00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo0000
2Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?oooooooooo04Wooooo0018ooooo`05o`00
0?ooooooooooooooool000000_ooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol0
0003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02o`000003
oiRHV?oooooo410@00Go00001?ooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o0000oiRH
V0Gooooo00?o0000ooooooooool01oooool01?lb<S;o0000o`000?nHV9P5ooooo`03o`000?oooooo
oooo00?ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003oMgMg00;o0000
00[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@1_ooool2o`0000;ooooo0_l0
000<ooooo`03o`000?oooooooooo00Cooooo00?ogMgMoa0@4?ooool01_ooool00ol0003ooooooooo
o`09ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000002OnHV9Sooooo
ooooooo^k^koEEEEo`000?l@413oc<c<o`000008ooooo`;o00000_ooool2o`0000cooooo00?o0000
ooooooooool0BOooool004Sooooo00Go0000ooooooooooooQhN7oa0@400;ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01Oooool02OmEEEGoV9RHoooooooooooo0000okZj^_oooooo
V9RHoa0@400Oooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0BOooool004Oooooo
1?l000000olQ8B7oc<c<ooooo`0:ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<?ooool00omEEEGoIVIVo`000007ooooo`09okZj^_m4A4CooooooooooonHV9So410@o`000?lQ8B7o
c<c<01oooooo00?o0000ooooooooool05_ooool00omEEEGoIVIVo`00001;ooooo`00N_ooool00ol@
413oooooooooo`0:ooooo`03oa0@4?l0003o0000013ooooo00?o410@o`000?l00000Hoooool2o`00
06Kooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0870454, -0.122766, \
0.00410642, 0.00784533}}]
}, Open  ]],

Cell[TextData[{
  "\tIn summary, we have found that for potential problems with sharply \
varying boundary conditions, choosing an arbitrary function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " that satisfies the boundary conditions and expanding the remainder in \
eigenmodes does not work very well. Rather, we found that it is better to use \
the direct solution of Laplace's equation, discussed  in Sec. ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "c:24"},
    ButtonStyle->"Hyperlink"],
  ", to allow for the inhomogeneous boundary conditions. "
}], "Text",
  CellTags->"i:113"],

Cell[TextData[{
  "\tIt is possible to circumvent some of the problems with the eigenmode \
expansion method by careful choice of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " [see Exercise (6) at the end of the section].   Nevertheless, we still \
recommend the direct solution for most applications with discontinuous \
boundary conditions, in view of its relative simplicity compared to the \
eigenmode expansion method. "
}], "Text"],

Cell[TextData[{
  "\t  On the other hand, for smoothly varying boundary conditions, the \
eigenmode expansion technique works quite well, as we saw in our first \
example. When nonzero charge density \[Rho] is present,  this method has the \
important advantage that a separate solution to the Laplace equation need not \
be generated; rather, an arbitrary (but smoothly varying) function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " can be chosen to match the boundary conditions. The situation is \
summarized in Table ",
  ButtonBox["4.1",
    ButtonData:>"Table 4.1",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Table 4.1 Pros and Cons of Different Choices for ",
  StyleBox["u",
    FontSlant->"Italic"],
  " \n",
  Cell[BoxData[GridBox[{
          {" ", 
            RowBox[{"Arbitrary", " ", "Choice", " ", "of", " ", 
              StyleBox["u",
                FontSlant->"Italic"], Cell[""], Cell[""]}], 
            RowBox[{Cell[TextData[Cell[BoxData[
                  \(TraditionalForm\`u\)]]]], " ", "satisfies", Cell[TextData[
              Cell[BoxData[
                  \(TraditionalForm\`\[Del]\^2 u = 0\)]]]], Cell[""]}]},
          {"Pro", \(No\ need\ to\ solve\ Laplace\ equation\), GridBox[{
                {\(\(Always\ works\)\(,\)\)},
                {
                  RowBox[{"efficient", " ", "if", " ", Cell["\[Rho]=0"]}]}
                }]},
          {"Con", GridBox[{
                {\(\(Does\)\(\ \)\(not\)\(\ \)\(work\)\(\ \)\(well\)\(\ \
\)\(for\)\(\ \)\(rapidly\)\(\ \)\)},
                {GridBox[{
                      {\(\(varying\)\(\ \)\(boundary\)\(\ \)\(conditions\)\(\ \
\)\(unless\)\(\ \)\)},
                      {
                        RowBox[{
                        "care", " ", "is", " ", "taken", " ", "in", " ", 
                          "choice", " ", "of", " ", 
                          StyleBox["u",
                            FontSlant->"Italic"], Cell[TextData[StyleBox["",
                            FontSlant->"Italic"]]]}]}
                      }]}
                }], 
            RowBox[{" ", GridBox[{
                  {
                    RowBox[{
                      RowBox[{"If", " ", Cell["\[Rho]\[NotEqual]0"]}], 
                      ",", \(\(must\)\(\ \)\(solve\)\(\ \)\(both\)\(\ \
\)\)}]},
                  {GridBox[{
                        {
                          RowBox[{
                          "Laplace", " ", "equation", " ", "for", " ", 
                            StyleBox["u",
                              FontSlant->"Italic"]}]},
                        {
                          RowBox[{
                          "and", " ", "Poisson", " ", "equation", " ", "for", 
                            " ", Cell["\[CapitalDelta]\[Phi]"]}]}
                        }]}
                  }]}]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]]
}], "Text",
  CellFrame->False,
  TextAlignment->Center,
  TextJustification->0,
  Background->GrayLevel[0.900008],
  CellTags->"Table 4.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cylindrical Geometry", "Section",
  CellTags->"c:30"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Cylindrical Eigenmodes",
  FontWeight->"Bold"]], "Subsubsection",
  CellTags->"i:65"],

Cell[TextData[{
  "\tEigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " can also be determined analytically inside a cylindrical tube. The tube \
has radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", and is closed at the ends. We again assume Dirichlet boundary conditions \
for the eigenmodes,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\( | \_S\)\(\(=\)\(0\)\)\)]],
  ".  "
}], "Text"],

Cell["\tWe look for eigenmodes of the form ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(r, \[Theta], 
          z) = \(R(r)\) \(\[CapitalTheta](\[Theta])\) \(Z(z)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.33)"],

Cell[TextData[{
  "Applying Eq. ",
  ButtonBox["(4.3.33)",
    ButtonData:>"(4.3.33)",
    ButtonStyle->"Hyperlink"],
  " to the eigenmode equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\((\[Del]\^2 \[Psi]\_\[Alpha])\)/\[Psi]\_\[Alpha]\),
            "TraditionalForm"], "=", \(\[Lambda]\_\[Alpha]\)}], 
        TraditionalForm]]],
  "yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(1\/\(r\ \(R(
                  r)\)\)\) \(\[PartialD]\/\[PartialD]r\) \((r \[PartialD]R\/\
\[PartialD]r)\) + \(1\/\(\(r\^2\) \(\[CapitalTheta](\[Theta])\)\)\) \
\[PartialD]\^2 \[CapitalTheta]\/\[PartialD]\[Theta]\^2 + \(1\/\(Z(
                z)\)\) \[PartialD]\^2 Z\/\[PartialD]z\^2 = \(\(\[Lambda]\_\
\[Alpha]\)\(.\)\)\)]]], "NE4",
  CellTags->"(4.3.34)"],

Cell[TextData[{
  "This equation can be separated into three ODEs  in the usual way, using \
two separation constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(-k\^2\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-m\^2\)\)]],
  ":  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\)\(\ \)\)\) \(\[PartialD]\/\[PartialD]r\) \
\((r \[PartialD]R\/\[PartialD]r)\) - \((m\^2\/r\^2 + k\^2)\) \(R(
              r)\) = \(\[Lambda]\_\[Alpha]\) \(R(r)\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.35)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \
\[CapitalTheta]\/\[PartialD]\[Theta]\^2 = \(-m\^2\) \
\(\[CapitalTheta](\[Theta])\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.36)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 Z\/\[DifferentialD]z\^2 = \
\(-k\^2\) \(Z(z)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.37)"],

Cell[TextData[{
  "Each equation provides a separate eigenvalue problem.  Starting with the \
last equation first,  the solution with Dirichlet boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`Z(0) = \(Z(L) = 0\)\)]],
  " is our standard trigonometric eigenfunctions"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Z(z)\  = \ sin\ l\ \[Pi]\ z/L\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{"  ", 
          FormBox[\(l = 1, 2, 3,  ... \),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.38)"],

Cell["with eigenvalues", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k = l\ \[Pi]/L\)]],
  ". "
}], "NE4",
  CellTags->"(4.3.39)"],

Cell[TextData[{
  "Next, we consider the \[Theta]-dependence of the eigenmodes.  This is also \
a familiar problem, given the periodic boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta] + 
            2\ \[Pi])\  = \ \[CapitalTheta](\[Theta])\)]],
  " required for  a single-valued solution. This eigenvalue problem has the \
solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalTheta](\[Theta])\  = \ \ \
\[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\(m\)\(\ \)\(\[Theta]\)\(\ \
\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Element] \ Integers\)]],
  "."
}], "NE4",
  CellTags->"(4.3.40)"],

Cell[TextData[{
  "Finally, we turn to Eq. ",
  ButtonBox["(4.3.35)",
    ButtonData:>"(4.3.35)",
    ButtonStyle->"Hyperlink"],
  ", which describes the radial dependence of the eigenmodes. The dependence \
of the solution on the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2 - \[Lambda]\_\[Alpha]\)]],
  " can be accommodated by a simple change of variables to"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\&_ = \@\(\(-\[Lambda]\_\[Alpha]\) - k\^2\)\ r\)]],
  "."
}], "NE4",
  CellTags->"(4.3.41)"],

Cell[TextData[{
  "In this variable, Eq. ",
  ButtonBox["(4.3.35)",
    ButtonData:>"(4.3.35)",
    ButtonStyle->"Hyperlink"],
  " becomes Bessel's equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\&_\)\(\ \)\)\) \
\(\[PartialD]\/\[PartialD]r\&_\) \((\(r\&_\) \[PartialD]R\/\[PartialD]r\&_)\) \
- \((m\^2\/r\&_\^2 - 1)\) \(R(r\&_)\) = 0\)]],
  ". "
}], "NE4",
  CellTags->"(4.3.42)"],

Cell["Thus, the general solution for the radial eigenmodes is ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R(r) = 
        A\ \(\(J\_m\)(\(\@\(\(-\[Lambda]\_\[Alpha]\) - k\^2\)\) r\ )\) + 
          B\ \(\(Y\_m\)(\(\@\(\(-\[Lambda]\_\[Alpha]\) - k\^2\)\) r)\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.43)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`J\_m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  " are the Bessel functions encountered previously in Sec.",
  ButtonBox[" 3.2.5",
    ButtonData:>{"Chapter3.nb", "c:39"},
    ButtonStyle->"Hyperlink"],
  ".  To find the eigenmodes, we match to the boundary conditions. The fact \
that the solution must be finite at the origin implies that ",
  Cell[BoxData[
      \(TraditionalForm\`B = 0\)]],
  ", because the ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  "'s are singular at the origin. The fact that ",
  Cell[BoxData[
      \(TraditionalForm\`R(a) = 0\)]],
  " in order to satisfy the Dirichlet boundary condition at the wall implies \
that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\@\(\(-\[Lambda]\_\[Alpha]\) - k\^2\)\) a = 
        j\_\(m, \ n\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]]
}], "NE4",
  CellTags->"(4.3.44)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(m, \ n\)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(J\_m\),
              "TraditionalForm"], " ", \((r)\)}]}], TraditionalForm]]],
  ", satisfying ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              FormBox[\(J\_m\),
                "TraditionalForm"], " ", \((j\_\(m, \ n\))\)}], "=", "0"}]}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell["Thus, the radial eigenmode takes the form ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R(r) = \ \(J\_m\)(\(j\_\(m, n\)\) r/a)\)]],
  ". "
}], "NE4",
  CellTags->{"i:68", "(4.3.45)"}],

Cell[TextData[{
  "Therefore, the cylindrical geometry Dirichlet eigenmodes of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha] = \(\(J\_m\)(\(j\_\(m, n\)\) 
              r/a)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) 
          sin\ \((l\ \[Pi]\ z/L)\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.46)"],

Cell[TextData[{
  "and the corresponding eigenvalues follow from Eqs. ",
  ButtonBox["(4.3.44)",
    ButtonData:>"(4.3.44)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.39)",
    ButtonData:>"(4.3.39)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha] = \(-\(j\_\(m\ , \
n\)\%2\/a\^2\)\) - \((\(l\ \[Pi]\)\/L)\)\^2\)]]
}], "NE4",
  CellTags->"(4.3.47)"],

Cell[TextData[{
  "The counter \[Alpha] is now a list of three integers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \((l, m, n)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`l > 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n > 0\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " taking on any integer value. "
}], "Text"],

Cell[TextData[{
  "\tAccording to our previous general arguments, these eigenmodes form an \
orthogonal set with respect to the inner product given by Eq. ",
  ButtonBox["(4.3.13)",
    ButtonData:>"(4.3.13)",
    ButtonStyle->"Hyperlink"],
  " .  In fact, writing out the inner product  as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\[DifferentialD]z \
\(\[Integral]\_0\%\(2  \[Pi]\)\[DifferentialD]\[Theta] \(\[Integral]\_0\%a 
                  r \[DifferentialD]r\)\)\)]],
  " and using Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>{"Chapter3.nb", "(3.2.55)"},
    ButtonStyle->"Hyperlink"],
  ", we find that the eigenmodes satisfy"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha]\&_, \[Psi]\_\[Alpha])\) = \(\
\[Delta]\_\(l\ l\&_\)\) \(\[Delta]\_\(m\ m\&_\)\) \(\[Delta]\_\(n\ n\&_\)\) \
\(\(\[Pi]\ \(a\^2\) L\)\/2\) \(\(J\_\(m + 1\)\%2\)(j\_\(m, n\))\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.48)"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example",
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  "We now have all that we need to construct generalized Fourier series \
solutions to Poisson's equation inside a cylindrical tube with closed ends, \
via our general solution, Eqs. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.3)",
    ButtonData:>"(4.3.3)",
    ButtonStyle->"Hyperlink"],
  ". As an example, let's take the case where the charge density inside the \
tube is linearly increasing with ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](r, \[Theta], z) = A\ z\)]],
  ". Also, lets assume that the base of the container has a potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(r)\  = \ V\_o[1 - \((r/a)\)\^2]\)]],
  ", but that the other walls are grounded.  This boundary condition is \
continuous, so  we can simply  choose an arbitrary  function ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, z)\)]],
  " that  matches these boundary conditions. A suitable choice is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(u(r, z)\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`V\_o[1 - \((r/a)\)\^2] \((1 - z/L)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.49)"],

Cell[TextData[{
  "Then according to Eqs. ",
  ButtonBox["(4.3.4)",
    ButtonData:>"(4.3.4)",
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(4.3.5)",
    ButtonData:>"(4.3.5)",
    ButtonStyle->"Hyperlink"],
  ", we require the solution to Poisson's equation with homogeneous Dirichlet \
boundary conditions and  a new charge density,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[Rho]\&_\  = \ \[Alpha]\  + \ \[Beta]\ z\)\(,\)\(\
\ \)\)\)]]], "NE4",
  CellTags->"(4.3.50)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(-4\)\ V\_o\ \[Epsilon]\_o/a\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 
        A\  + \ 4\ V\_o\ \[Epsilon]\_o/\((L\ a\^2)\)\)]],
  ". The inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Rho]\&_)\)\)]],
  " can then be worked out analytically:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Rho]\&_)\) = \
\[Integral]\_0\%a\(\( J\_m\)(\(j\_\(m, n\)\) 
                r/a)\)\ r\ \[DifferentialD]r \(\[Integral]\_0\%\(2\ \[Pi]\)\(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[Theta]\)\) \[DifferentialD]\
\[Theta] \(\[Integral]\_0\%L\ \((\[Alpha]\  + \ \[Beta]\ z)\)\ \(sin(
                      l\ \[Pi]\ z/L)\) \[DifferentialD]z\)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.51)"],

Cell[TextData[{
  "The \[Theta] integral implies that we only require the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " term. This is because the charge density is cylindrically-symmetric, so \
the potential is also cylindrically symmetric. For ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ", the integrals over ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(\ \)\)\)]],
  "can be done by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho][l_, n_]\  = \ 
      Simplify[2\ Pi\ Integrate[
            BesselJ[0, j0[n]\ r/a]\ r, {r, 0, 
              a}]\ Integrate[\((\[Alpha]\  + \ \[Beta]\ z)\)\ Sin[
                l\ Pi\ z/L], {z, 0, L}], l \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.27"],

Cell[BoxData[
    \(\(-\(\(2\ a\^2\ L\ \((\((\(-1\) + \((\(-1\))\)\^l)\)\ \[Alpha] + \
\((\(-1\))\)\^l\ L\ \[Beta])\)\ BesselJ[1, j0[n]]\)\/\(l\ j0[
              n]\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here, we have introduced the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["j0",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n'\) \(th\)\(\ \)\)\)]],
  "zero of the ",
  Cell[BoxData[
      \(TraditionalForm\`J\_o\)]],
  " Bessel function.  It can be defined as follows, up to the 20th zero:"
}], "Text"],

Cell[BoxData[{
    \(\(<< NumericalMath`;\)\), "\n", 
    \(\(zeros = \ BesselJZeros[0, 20];\)\), "\n", 
    \(\(j0[n_]\  := \ zeros[\([n]\)];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.28"],

Cell[TextData[{
  "Finally, the solution can be constructed using the general form for the \
Fourier expansion, Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  ", along with  our defined functions ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Rho]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["j0",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["n",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(u[r_, 
          z_]\  = \ \(V\_o\) \((1\  - \ \((r/a)\)^2)\) \((1 - 
              z/L)\);\)\), "\n", 
    \(\(\[Psi][l_, n_, r_, z_] := 
        BesselJ[0, \(j0[n]\ r\)\/a]\ Sin[\(l\ \[Pi]\ z\)\/L];\)\), "\n", 
    \(\(\[Lambda][l_, n_] := \(-\((\(l\ \[Pi]\)\/L)\)\^2\) - 
          j0[n]\^2\/a\^2;\)\), "\n", 
    \(\[Psi]\[Psi][l_, n_] := 
      1\/2\ \[Pi]\ a\^2\ L\ BesselJ[1, 
            j0[n]]^2; \  (*\ \(\(:\)\(the\ inner\ product\ of\ \[Psi]\ with\ \
itself\)\); \ see\ Eq . \ \((4  .3  .48)\)\ *) \n\[Phi][r_, z_] = 
      u[r, z]\  - \(1\/\[Epsilon]\_o\) \(\[Sum]\+\(l = 1\)\%20\(\[Sum]\+\(n = \
1\)\%5\( \[Rho][l, n]\ \[Psi][l, n, r, z]\)\/\(\[Lambda][l, n]\ \
\[Psi]\[Psi][l, n]\)\)\);\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.29"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Psi]",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox["[",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["l",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["n",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["r",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["z",
              FontFamily->"Courier",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["]",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  " is the eigenmode for given ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and for  ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ",",
  StyleBox[" ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Lambda]", "[", 
          RowBox[{
            StyleBox["l",
              FontSlant->"Plain"], ",", 
            StyleBox["n",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the eigenvalue, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]\[Psi]", "[", 
          RowBox[{
            StyleBox["l",
              FontSlant->"Plain"], ",", 
            StyleBox["n",
              FontSlant->"Plain"]}], "]"}], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Psi]\_\[Alpha])\)\)]],
  ".  Only the first five Bessel function zeros and the first 20 axial modes \
are kept in the sum, because this achieves reasonable convergence to within a \
few percent. [This can be verified by evaluating \[Phi] at a few  ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, z)\)\)]],
  " points  keeping different numbers of terms in the sum, which is left as \
an exercise for the reader.] In Cell ",
  ButtonBox["4.30",
    ButtonData:>"Cell 4.30",
    ButtonStyle->"Hyperlink"],
  " we plot the solution as a contour plot for the case ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"a", "=", 
            RowBox[{"1", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], ",", " ", 
          RowBox[{"L", "=", 
            RowBox[{"2", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}], ",", " ", 
          RowBox[{\(and\ A/\[Epsilon]\_o\), "=", 
            RowBox[{"1", " ", 
              RowBox[{
                StyleBox["V",
                  FontSlant->"Plain"], "/", 
                StyleBox["m",
                  FontSlant->"Plain"]}]}]}], ",", " ", 
          RowBox[{\(V\_o\), "=", 
            RowBox[{"0.3", " ", 
              StyleBox["V",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(a = 1; L = 2; A = \[Epsilon]\_o; \ V\_o\  = 0.3;\), "\n", 
    \(\(\[Alpha] = \(-4\)\ V\_o\ \[Epsilon]\_o/a\^2;\)\), "\n", 
    \(\(\[Beta] = A\  + \ 4\ V\_o\ \[Epsilon]\_o/\((L\ a\^2)\);\)\), "\n", 
    \(\(ContourPlot[\[Phi][r, z], {r, 0, a}, {z, 0, L}, 
        AspectRatio \[Rule] L/a, 
        PlotLabel \[Rule] "\<\[Phi] in a charge-filled \ncylindrical tube\>", 
        FrameLabel \[Rule] {"\<r\>", "\<z\>"}, 
        PlotPoints \[Rule] 25];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.30"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0384615 0.961538 [
[.01923 -0.0125 -3 -9 ]
[.01923 -0.0125 3 0 ]
[.21154 -0.0125 -9 -9 ]
[.21154 -0.0125 9 0 ]
[.40385 -0.0125 -9 -9 ]
[.40385 -0.0125 9 0 ]
[.59615 -0.0125 -9 -9 ]
[.59615 -0.0125 9 0 ]
[.78846 -0.0125 -9 -9 ]
[.78846 -0.0125 9 0 ]
[.98077 -0.0125 -3 -9 ]
[.98077 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .03846 -6 -4.5 ]
[-0.0125 .03846 0 4.5 ]
[-0.0125 .51923 -18 -4.5 ]
[-0.0125 .51923 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[-0.0125 1.48077 -18 -4.5 ]
[-0.0125 1.48077 0 4.5 ]
[-0.0125 1.96154 -6 -4.5 ]
[-0.0125 1.96154 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 1 -30 -5 ]
[-0.01875 1 -18 5 ]
[ 0 2 .125 0 ]
[ 1 0 .125 0 ]
[.5 2.0125 -65 0 ]
[.5 2.0125 65 24.5 ]
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01923 0 m
.01923 .00625 L
s
[(0)] .01923 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(0.2)] .21154 -0.0125 0 1 Mshowa
.40385 0 m
.40385 .00625 L
s
[(0.4)] .40385 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(0.6)] .59615 -0.0125 0 1 Mshowa
.78846 0 m
.78846 .00625 L
s
[(0.8)] .78846 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(1)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.06731 0 m
.06731 .00375 L
s
.11538 0 m
.11538 .00375 L
s
.16346 0 m
.16346 .00375 L
s
.25962 0 m
.25962 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.35577 0 m
.35577 .00375 L
s
.45192 0 m
.45192 .00375 L
s
.5 0 m
.5 .00375 L
s
.54808 0 m
.54808 .00375 L
s
.64423 0 m
.64423 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.74038 0 m
.74038 .00375 L
s
.83654 0 m
.83654 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.93269 0 m
.93269 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03846 m
.00625 .03846 L
s
[(0)] -0.0125 .03846 1 0 Mshowa
0 .51923 m
.00625 .51923 L
s
[(0.5)] -0.0125 .51923 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
0 1.48077 m
.00625 1.48077 L
s
[(1.5)] -0.0125 1.48077 1 0 Mshowa
0 1.96154 m
.00625 1.96154 L
s
[(2)] -0.0125 1.96154 1 0 Mshowa
.125 Mabswid
0 .13462 m
.00375 .13462 L
s
0 .23077 m
.00375 .23077 L
s
0 .32692 m
.00375 .32692 L
s
0 .42308 m
.00375 .42308 L
s
0 .61538 m
.00375 .61538 L
s
0 .71154 m
.00375 .71154 L
s
0 .80769 m
.00375 .80769 L
s
0 .90385 m
.00375 .90385 L
s
0 1.09615 m
.00375 1.09615 L
s
0 1.19231 m
.00375 1.19231 L
s
0 1.28846 m
.00375 1.28846 L
s
0 1.38462 m
.00375 1.38462 L
s
0 1.57692 m
.00375 1.57692 L
s
0 1.67308 m
.00375 1.67308 L
s
0 1.76923 m
.00375 1.76923 L
s
0 1.86538 m
.00375 1.86538 L
s
.25 Mabswid
0 0 m
0 2 L
s
gsave
-0.01875 1 -90 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.01923 1.99375 m
.01923 2 L
s
.21154 1.99375 m
.21154 2 L
s
.40385 1.99375 m
.40385 2 L
s
.59615 1.99375 m
.59615 2 L
s
.78846 1.99375 m
.78846 2 L
s
.98077 1.99375 m
.98077 2 L
s
.125 Mabswid
.06731 1.99625 m
.06731 2 L
s
.11538 1.99625 m
.11538 2 L
s
.16346 1.99625 m
.16346 2 L
s
.25962 1.99625 m
.25962 2 L
s
.30769 1.99625 m
.30769 2 L
s
.35577 1.99625 m
.35577 2 L
s
.45192 1.99625 m
.45192 2 L
s
.5 1.99625 m
.5 2 L
s
.54808 1.99625 m
.54808 2 L
s
.64423 1.99625 m
.64423 2 L
s
.69231 1.99625 m
.69231 2 L
s
.74038 1.99625 m
.74038 2 L
s
.83654 1.99625 m
.83654 2 L
s
.88462 1.99625 m
.88462 2 L
s
.93269 1.99625 m
.93269 2 L
s
.25 Mabswid
0 2 m
1 2 L
s
.99375 .03846 m
1 .03846 L
s
.99375 .51923 m
1 .51923 L
s
.99375 1 m
1 1 L
s
.99375 1.48077 m
1 1.48077 L
s
.99375 1.96154 m
1 1.96154 L
s
.125 Mabswid
.99625 .13462 m
1 .13462 L
s
.99625 .23077 m
1 .23077 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .42308 m
1 .42308 L
s
.99625 .61538 m
1 .61538 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .80769 m
1 .80769 L
s
.99625 .90385 m
1 .90385 L
s
.99625 1.09615 m
1 1.09615 L
s
.99625 1.19231 m
1 1.19231 L
s
.99625 1.28846 m
1 1.28846 L
s
.99625 1.38462 m
1 1.38462 L
s
.99625 1.57692 m
1 1.57692 L
s
.99625 1.67308 m
1 1.67308 L
s
.99625 1.76923 m
1 1.76923 L
s
.99625 1.86538 m
1 1.86538 L
s
.25 Mabswid
1 0 m
1 2 L
s
gsave
.5 2.0125 -126 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
93.000 13.000 moveto
(a) show
105.000 13.000 moveto
(charge) show
141.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
147.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(filled) show
63.000 25.500 moveto
(cylindrical) show
135.000 25.500 moveto
(tube) show
159.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
.01923 1.96154 m
.98077 1.96154 L
.98077 .03846 L
.01923 .03846 L
F
.5 Mabswid
.1 g
.01923 1.93699 m
.05929 1.93686 L
.09936 1.93651 L
.13942 1.93602 L
.17949 1.9355 L
.21955 1.93506 L
.25962 1.93474 L
.29968 1.93453 L
.33974 1.93434 L
.37981 1.93405 L
.41987 1.93352 L
.45994 1.93267 L
.5 1.93149 L
.54006 1.93002 L
.58013 1.92835 L
.62019 1.92657 L
.66026 1.92469 L
.70032 1.92251 L
.74038 1.91957 L
.78045 1.91497 L
.82051 1.90694 L
.86058 1.89084 L
.87412 1.88141 L
.90064 1.84748 L
.91686 1.80128 L
.92981 1.72115 L
.93563 1.64103 L
.93849 1.5609 L
.94005 1.48077 L
.9405 1.40064 L
.94051 1.32051 L
.93988 1.24038 L
.93898 1.16026 L
.93767 1.08013 L
.9361 1 L
.93433 .91987 L
.93227 .83974 L
.93027 .75962 L
.92812 .67949 L
.92642 .59936 L
.92504 .51923 L
.9247 .4391 L
.92555 .35897 L
.92804 .27885 L
.93248 .19872 L
.93852 .11859 L
.94071 .09737 L
.94628 .03846 L
.01923 .03846 L
F
0 g
.01923 1.93699 m
.05929 1.93686 L
.09936 1.93651 L
.13942 1.93602 L
.17949 1.9355 L
.21955 1.93506 L
.25962 1.93474 L
.29968 1.93453 L
.33974 1.93434 L
.37981 1.93405 L
.41987 1.93352 L
.45994 1.93267 L
.5 1.93149 L
.54006 1.93002 L
.58013 1.92835 L
.62019 1.92657 L
.66026 1.92469 L
.70032 1.92251 L
.74038 1.91957 L
.78045 1.91497 L
.82051 1.90694 L
.86058 1.89084 L
.87412 1.88141 L
.90064 1.84748 L
.91686 1.80128 L
.92981 1.72115 L
.93563 1.64103 L
.93849 1.5609 L
.94005 1.48077 L
.9405 1.40064 L
.94051 1.32051 L
.93988 1.24038 L
.93898 1.16026 L
.93767 1.08013 L
.9361 1 L
.93433 .91987 L
.93227 .83974 L
.93027 .75962 L
.92812 .67949 L
.92642 .59936 L
.92504 .51923 L
.9247 .4391 L
.92555 .35897 L
.92804 .27885 L
.93248 .19872 L
.93852 .11859 L
.94071 .09737 L
.94628 .03846 L
s
.2 g
.01923 1.90124 m
.05929 1.90097 L
.09936 1.90021 L
.13942 1.89914 L
.17949 1.89798 L
.21955 1.89694 L
.25962 1.89613 L
.29968 1.89548 L
.33974 1.89483 L
.37981 1.89388 L
.41987 1.89239 L
.45994 1.89015 L
.5 1.8871 L
.54006 1.88329 L
.55776 1.88141 L
.58013 1.87886 L
.62019 1.87385 L
.66026 1.86804 L
.70032 1.86065 L
.74038 1.84982 L
.78045 1.83142 L
.81543 1.80128 L
.82051 1.79533 L
.85569 1.72115 L
.86058 1.70396 L
.87173 1.64103 L
.87933 1.5609 L
.88333 1.48077 L
.8845 1.40064 L
.88449 1.32051 L
.88287 1.24038 L
.88053 1.16026 L
.87716 1.08013 L
.87307 1 L
.86843 .91987 L
.86307 .83974 L
.86058 .80142 L
.85782 .75962 L
.85225 .67949 L
.84783 .59936 L
.84438 .51923 L
.84364 .4391 L
.84595 .35897 L
.85234 .27885 L
.86058 .21305 L
.86339 .19872 L
.87834 .11859 L
.89739 .03846 L
.01923 .03846 L
F
0 g
.01923 1.90124 m
.05929 1.90097 L
.09936 1.90021 L
.13942 1.89914 L
.17949 1.89798 L
.21955 1.89694 L
.25962 1.89613 L
.29968 1.89548 L
.33974 1.89483 L
.37981 1.89388 L
.41987 1.89239 L
.45994 1.89015 L
.5 1.8871 L
.54006 1.88329 L
.55776 1.88141 L
.58013 1.87886 L
.62019 1.87385 L
.66026 1.86804 L
.70032 1.86065 L
.74038 1.84982 L
.78045 1.83142 L
.81543 1.80128 L
.82051 1.79533 L
.85569 1.72115 L
.86058 1.70396 L
.87173 1.64103 L
.87933 1.5609 L
.88333 1.48077 L
.8845 1.40064 L
.88449 1.32051 L
.88287 1.24038 L
.88053 1.16026 L
.87716 1.08013 L
.87307 1 L
.86843 .91987 L
.86307 .83974 L
.86058 .80142 L
.85782 .75962 L
.85225 .67949 L
.84783 .59936 L
.84438 .51923 L
.84364 .4391 L
.84595 .35897 L
.85234 .27885 L
.86058 .21305 L
.86339 .19872 L
.87834 .11859 L
.89739 .03846 L
s
.3 g
.01923 1.86114 m
.05929 1.86073 L
.09936 1.85959 L
.13942 1.85796 L
.17949 1.85614 L
.21955 1.85441 L
.25962 1.85289 L
.29968 1.8515 L
.33974 1.84997 L
.37981 1.84788 L
.41987 1.84483 L
.45994 1.84049 L
.5 1.83468 L
.54006 1.82733 L
.58013 1.81838 L
.62019 1.80752 L
.63971 1.80128 L
.66026 1.79407 L
.70032 1.77561 L
.74038 1.74554 L
.76067 1.72115 L
.78045 1.68822 L
.79719 1.64103 L
.81299 1.5609 L
.82051 1.49012 L
.82094 1.48077 L
.82356 1.40064 L
.8238 1.32051 L
.82126 1.24038 L
.82051 1.22166 L
.81736 1.16026 L
.8117 1.08013 L
.8048 1 L
.79699 .91987 L
.78812 .83974 L
.78045 .76873 L
.77946 .75962 L
.77072 .67949 L
.76402 .59936 L
.75946 .51923 L
.7593 .4391 L
.76409 .35897 L
.77494 .27885 L
.78045 .24747 L
.79249 .19872 L
.81581 .11859 L
.82051 .10598 L
.84562 .03846 L
.01923 .03846 L
F
0 g
.01923 1.86114 m
.05929 1.86073 L
.09936 1.85959 L
.13942 1.85796 L
.17949 1.85614 L
.21955 1.85441 L
.25962 1.85289 L
.29968 1.8515 L
.33974 1.84997 L
.37981 1.84788 L
.41987 1.84483 L
.45994 1.84049 L
.5 1.83468 L
.54006 1.82733 L
.58013 1.81838 L
.62019 1.80752 L
.63971 1.80128 L
.66026 1.79407 L
.70032 1.77561 L
.74038 1.74554 L
.76067 1.72115 L
.78045 1.68822 L
.79719 1.64103 L
.81299 1.5609 L
.82051 1.49012 L
.82094 1.48077 L
.82356 1.40064 L
.8238 1.32051 L
.82126 1.24038 L
.82051 1.22166 L
.81736 1.16026 L
.8117 1.08013 L
.8048 1 L
.79699 .91987 L
.78812 .83974 L
.78045 .76873 L
.77946 .75962 L
.77072 .67949 L
.76402 .59936 L
.75946 .51923 L
.7593 .4391 L
.76409 .35897 L
.77494 .27885 L
.78045 .24747 L
.79249 .19872 L
.81581 .11859 L
.82051 .10598 L
.84562 .03846 L
s
.4 g
.01923 1.81504 m
.05929 1.81448 L
.09936 1.81293 L
.13942 1.81067 L
.17949 1.80806 L
.21955 1.80541 L
.25962 1.80287 L
.28464 1.80128 L
.29968 1.80032 L
.33974 1.79741 L
.37981 1.79356 L
.41987 1.78821 L
.45994 1.7808 L
.5 1.77087 L
.54006 1.75797 L
.58013 1.74133 L
.61731 1.72115 L
.62019 1.71944 L
.66026 1.68974 L
.69909 1.64103 L
.70032 1.63909 L
.73184 1.5609 L
.74038 1.53159 L
.74737 1.48077 L
.75325 1.40064 L
.75459 1.32051 L
.75158 1.24038 L
.74621 1.16026 L
.74038 1.09883 L
.73824 1.08013 L
.72843 1 L
.71733 .91987 L
.70502 .83974 L
.70032 .80844 L
.69313 .75962 L
.68176 .67949 L
.67346 .59936 L
.66884 .51923 L
.67046 .4391 L
.67903 .35897 L
.69543 .27885 L
.70032 .25916 L
.71987 .19872 L
.74038 .14317 L
.75116 .11859 L
.78045 .06103 L
.79037 .03846 L
.01923 .03846 L
F
0 g
.01923 1.81504 m
.05929 1.81448 L
.09936 1.81293 L
.13942 1.81067 L
.17949 1.80806 L
.21955 1.80541 L
.25962 1.80287 L
.28464 1.80128 L
.29968 1.80032 L
.33974 1.79741 L
.37981 1.79356 L
.41987 1.78821 L
.45994 1.7808 L
.5 1.77087 L
.54006 1.75797 L
.58013 1.74133 L
.61731 1.72115 L
.62019 1.71944 L
.66026 1.68974 L
.69909 1.64103 L
.70032 1.63909 L
.73184 1.5609 L
.74038 1.53159 L
.74737 1.48077 L
.75325 1.40064 L
.75459 1.32051 L
.75158 1.24038 L
.74621 1.16026 L
.74038 1.09883 L
.73824 1.08013 L
.72843 1 L
.71733 .91987 L
.70502 .83974 L
.70032 .80844 L
.69313 .75962 L
.68176 .67949 L
.67346 .59936 L
.66884 .51923 L
.67046 .4391 L
.67903 .35897 L
.69543 .27885 L
.70032 .25916 L
.71987 .19872 L
.74038 .14317 L
.75116 .11859 L
.78045 .06103 L
.79037 .03846 L
s
.5 g
.01923 1.76196 m
.05929 1.76123 L
.09936 1.75918 L
.13942 1.75611 L
.17949 1.75245 L
.21955 1.74854 L
.25962 1.74447 L
.29968 1.74006 L
.33974 1.73476 L
.37981 1.72778 L
.40884 1.72115 L
.41987 1.71831 L
.45994 1.70561 L
.5 1.68807 L
.54006 1.66368 L
.56772 1.64103 L
.58013 1.62948 L
.62019 1.57602 L
.62804 1.5609 L
.65675 1.48077 L
.66026 1.46429 L
.66896 1.40064 L
.67299 1.32051 L
.67042 1.24038 L
.664 1.16026 L
.66026 1.12572 L
.65391 1.08013 L
.6412 1 L
.62666 .91987 L
.62019 .88713 L
.61068 .83974 L
.59523 .75962 L
.58087 .67949 L
.58013 .67633 L
.57086 .59936 L
.56643 .51923 L
.5708 .4391 L
.58013 .37991 L
.58477 .35897 L
.60888 .27885 L
.62019 .24782 L
.64231 .19872 L
.66026 .16069 L
.6828 .11859 L
.70032 .08962 L
.73085 .03846 L
.01923 .03846 L
F
0 g
.01923 1.76196 m
.05929 1.76123 L
.09936 1.75918 L
.13942 1.75611 L
.17949 1.75245 L
.21955 1.74854 L
.25962 1.74447 L
.29968 1.74006 L
.33974 1.73476 L
.37981 1.72778 L
.40884 1.72115 L
.41987 1.71831 L
.45994 1.70561 L
.5 1.68807 L
.54006 1.66368 L
.56772 1.64103 L
.58013 1.62948 L
.62019 1.57602 L
.62804 1.5609 L
.65675 1.48077 L
.66026 1.46429 L
.66896 1.40064 L
.67299 1.32051 L
.67042 1.24038 L
.664 1.16026 L
.66026 1.12572 L
.65391 1.08013 L
.6412 1 L
.62666 .91987 L
.62019 .88713 L
.61068 .83974 L
.59523 .75962 L
.58087 .67949 L
.58013 .67633 L
.57086 .59936 L
.56643 .51923 L
.5708 .4391 L
.58013 .37991 L
.58477 .35897 L
.60888 .27885 L
.62019 .24782 L
.64231 .19872 L
.66026 .16069 L
.6828 .11859 L
.70032 .08962 L
.73085 .03846 L
s
.6 g
.01923 1.69783 m
.05929 1.69685 L
.09936 1.69405 L
.13942 1.68976 L
.17949 1.68443 L
.21955 1.67839 L
.25962 1.67169 L
.29968 1.66393 L
.33974 1.65425 L
.37981 1.64123 L
.38036 1.64103 L
.41987 1.62384 L
.45994 1.59828 L
.49845 1.5609 L
.5 1.55933 L
.54006 1.49768 L
.54674 1.48077 L
.5683 1.40064 L
.5768 1.32051 L
.57559 1.24038 L
.56848 1.16026 L
.55608 1.08013 L
.54006 1.00129 L
.53977 1 L
.52065 .91987 L
.5 .84259 L
.49923 .83974 L
.47837 .75962 L
.45994 .68394 L
.45907 .67949 L
.44632 .59936 L
.44195 .51923 L
.45041 .4391 L
.45994 .3977 L
.4722 .35897 L
.5 .29134 L
.50737 .27885 L
.54006 .21969 L
.55388 .19872 L
.58013 .15755 L
.60724 .11859 L
.62019 .1011 L
.66026 .04701 L
.66588 .03846 L
.01923 .03846 L
F
0 g
.01923 1.69783 m
.05929 1.69685 L
.09936 1.69405 L
.13942 1.68976 L
.17949 1.68443 L
.21955 1.67839 L
.25962 1.67169 L
.29968 1.66393 L
.33974 1.65425 L
.37981 1.64123 L
.38036 1.64103 L
.41987 1.62384 L
.45994 1.59828 L
.49845 1.5609 L
.5 1.55933 L
.54006 1.49768 L
.54674 1.48077 L
.5683 1.40064 L
.5768 1.32051 L
.57559 1.24038 L
.56848 1.16026 L
.55608 1.08013 L
.54006 1.00129 L
.53977 1 L
.52065 .91987 L
.5 .84259 L
.49923 .83974 L
.47837 .75962 L
.45994 .68394 L
.45907 .67949 L
.44632 .59936 L
.44195 .51923 L
.45041 .4391 L
.45994 .3977 L
.4722 .35897 L
.5 .29134 L
.50737 .27885 L
.54006 .21969 L
.55388 .19872 L
.58013 .15755 L
.60724 .11859 L
.62019 .1011 L
.66026 .04701 L
.66588 .03846 L
s
.7 g
.01923 1.61441 m
.05929 1.61295 L
.09936 1.60869 L
.13942 1.60199 L
.17949 1.59322 L
.21955 1.58258 L
.25962 1.56978 L
.28307 1.5609 L
.29968 1.55457 L
.33974 1.53505 L
.37981 1.50465 L
.40076 1.48077 L
.41987 1.45638 L
.44265 1.40064 L
.45952 1.32051 L
.45994 1.31586 L
.46056 1.24038 L
.45994 1.22932 L
.45232 1.16026 L
.43575 1.08013 L
.41987 1.02223 L
.41278 1 L
.38484 .91987 L
.37981 .90687 L
.35278 .83974 L
.33974 .80746 L
.32099 .75962 L
.29968 .70582 L
.29174 .67949 L
.27356 .59936 L
.27108 .51923 L
.29047 .4391 L
.29968 .41013 L
.32882 .35897 L
.33974 .33924 L
.37981 .28162 L
.3822 .27885 L
.41987 .22983 L
.44739 .19872 L
.45994 .18398 L
.5 .13905 L
.51924 .11859 L
.54006 .09698 L
.58013 .05446 L
.5936 .03846 L
.01923 .03846 L
F
0 g
.01923 1.61441 m
.05929 1.61295 L
.09936 1.60869 L
.13942 1.60199 L
.17949 1.59322 L
.21955 1.58258 L
.25962 1.56978 L
.28307 1.5609 L
.29968 1.55457 L
.33974 1.53505 L
.37981 1.50465 L
.40076 1.48077 L
.41987 1.45638 L
.44265 1.40064 L
.45952 1.32051 L
.45994 1.31586 L
.46056 1.24038 L
.45994 1.22932 L
.45232 1.16026 L
.43575 1.08013 L
.41987 1.02223 L
.41278 1 L
.38484 .91987 L
.37981 .90687 L
.35278 .83974 L
.33974 .80746 L
.32099 .75962 L
.29968 .70582 L
.29174 .67949 L
.27356 .59936 L
.27108 .51923 L
.29047 .4391 L
.29968 .41013 L
.32882 .35897 L
.33974 .33924 L
.37981 .28162 L
.3822 .27885 L
.41987 .22983 L
.44739 .19872 L
.45994 .18398 L
.5 .13905 L
.51924 .11859 L
.54006 .09698 L
.58013 .05446 L
.5936 .03846 L
s
.8 g
.01923 .32432 m
.05929 .32168 L
.09936 .31387 L
.13942 .30124 L
.17949 .28461 L
.19204 .27885 L
.21955 .2624 L
.25962 .23583 L
.29968 .2075 L
.31196 .19872 L
.33974 .17668 L
.37981 .14459 L
.41268 .11859 L
.41987 .11295 L
.45994 .08166 L
.5 .04844 L
.51081 .03846 L
.01923 .03846 L
F
0 g
.01923 .32432 m
.05929 .32168 L
.09936 .31387 L
.13942 .30124 L
.17949 .28461 L
.19204 .27885 L
.21955 .2624 L
.25962 .23583 L
.29968 .2075 L
.31196 .19872 L
.33974 .17668 L
.37981 .14459 L
.41268 .11859 L
.41987 .11295 L
.45994 .08166 L
.5 .04844 L
.51081 .03846 L
s
.9 g
.01923 .17998 m
.05929 .17858 L
.09936 .17427 L
.13942 .16679 L
.17949 .15589 L
.21955 .14156 L
.25962 .1241 L
.2712 .11859 L
.29968 .10415 L
.33974 .08232 L
.37981 .05873 L
.4109 .03846 L
.01923 .03846 L
F
0 g
.01923 .17998 m
.05929 .17858 L
.09936 .17427 L
.13942 .16679 L
.17949 .15589 L
.21955 .14156 L
.25962 .1241 L
.2712 .11859 L
.29968 .10415 L
.33974 .08232 L
.37981 .05873 L
.4109 .03846 L
s
.8 g
.01923 1.48604 m
.05929 1.48299 L
.07775 1.48077 L
.09936 1.47496 L
.13942 1.46152 L
.17949 1.44049 L
.21955 1.40773 L
.22621 1.40064 L
.25962 1.35781 L
.27666 1.32051 L
.28754 1.24038 L
.27774 1.16026 L
.25962 1.0907 L
.25053 1.08013 L
.21955 1.01893 L
.20735 1 L
.17949 .96116 L
.14136 .91987 L
.13942 .91817 L
.09936 .88844 L
.05929 .87071 L
.01923 .8648 L
F
0 g
.01923 1.48604 m
.05929 1.48299 L
.07775 1.48077 L
.09936 1.47496 L
.13942 1.46152 L
.17949 1.44049 L
.21955 1.40773 L
.22621 1.40064 L
.25962 1.35781 L
.27666 1.32051 L
.28754 1.24038 L
.27774 1.16026 L
.25962 1.0907 L
.25053 1.08013 L
.21955 1.01893 L
.20735 1 L
.17949 .96116 L
.14136 .91987 L
.13942 .91817 L
.09936 .88844 L
.05929 .87071 L
.01923 .8648 L
s
1 g
.01923 .09028 m
.05929 .08918 L
.09936 .08579 L
.13942 .07989 L
.17949 .07119 L
.21955 .05951 L
.25962 .04475 L
.2745 .03846 L
.01923 .03846 L
F
0 g
.01923 .09028 m
.05929 .08918 L
.09936 .08579 L
.13942 .07989 L
.17949 .07119 L
.21955 .05951 L
.25962 .04475 L
.2745 .03846 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{192, 384},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003`0001h2000`400?l00000o`00003ol?ooool0
0?3ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00l?oo
ool00?3ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00l?ooool008Sooooo00?o410@o`00
0?l000000ol0001Rooooo`00R_ooool00ol0003oooooooooo`1Sooooo`00R_ooool00ol0003ooooo
ooooo`1Sooooo`00R_ooool00ol0003oooooooooo`1Sooooo`00R_ooool00ol0003o<S8bomgMg@1S
ooooo`00ROooool2o`000004ojVYZOlQ8B7o0000ob4Q8F7ooooo003`ooooo`00l?ooool00?3ooooo
003`ooooo`00l?ooool00?3ooooo003`ooooo`00:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Wo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00017ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<017ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
01[ooooo1?l00001oa0@407ooooo0Oooool002[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Ioooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
4?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B404Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B407?ooool00ol0003oooooooooo`02ooooo`00:_ooool01Ol@413ooooooooooooo
oooo410@01Wooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00004Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`00000Aooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000001cooooo00?o0000ooooooooool00_ooool002[ooooo00Go
0000ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP0Aooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000B
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q017ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S807?ooool00ol0
003oooooooooo`02ooooo`00:_ooool01Ol0003ooooooooooooooooo000001Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo013ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04omgMgOmEEEGoooooo`0001;ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?mEEEGo0000oa0@4?o<c<`04Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<
o`000?l0003o0000olc<c00Looooo`03o`000?oooooooooo00;ooooo000Zooooo`05oa0@4?oooooo
ooooooooool@41006Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
3oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000004_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool04oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Looooo`03o`000?oooooooooo00;ooooo000Z
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^
k^koA4A4o`00000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000001cooooo
00?o0000ooooooooool00_ooool002[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo017ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@417ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
ojVYZOl@413o0000oa0@4?nYZJT06_ooool00omEEEGoIVIVo`000004ooooo`00l?ooool00?3ooooo
003`ooooo`00:Oooooo6o`00007ooooo000Yooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00007ooooo000Yooooo`03o`000?oooooo
oooo0<;ooooo0Ol00001ooooo`00:Oooool00ol0003oooooooooo`32ooooo`7o00000Oooool002Wo
oooo00?o0000ooooooooool0`_ooool1o`00007ooooo000Oooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`32ooooo`7o00000Oooool001oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo0<;ooooo0Ol00001ooooo`007oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0`_ooool1o`00007ooooo000Oooooo`05o`00
0?ooooooooooooooool000001Oooool2o`0003?ooooo0_l0000Iooooo`;o00004oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00001ooooo`007oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0;oooool3o`0001[oi^KV00?o0000olc<c?o<
c<`04_o<c<`00ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02omoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc
<c<01olc<c<00ol0003o6ATIoaTI6@07oaTI6@Oo00000oooool1o`00007ooooo000Oooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0/ooooo`?o00006ooVi^H2o`0001?o
c<c<0_l0000?ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003o
IVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o
6ATIoaTI6@07oaTI6@Oo00000oooool1o`00007ooooo000Oooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0Yooooo`?o00007OoVi^H00ol0003oc<c<olc<c00Bolc<c003
o`000?nc/k?o/k>c00ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`0:ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?lI6AWo6ATI00So6ATI1ol00003ooooo`7o00000Oooool001oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`03o`000?oooooooooo02Kooooo0ol0000NonKViP;o00005?o<c<`00ol0003o
/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02omoOgl00ol0003o
IVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o
6ATIoaTI6@08oaTI6@Oo00000oooool1o`00007ooooo000Yooooo`03o`000?oooooooooo02;ooooo
1?l0000OonKViP;o00005?o<c<`2o`00013o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`0;ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<c
oc<c<`08oc<c<`03o`000?lI6AWo6ATI00So6ATI1ol00003ooooo`7o00000Oooool002Wooooo00?o
0000ooooooooool07_ooool4o`00027oi^KV0_l0000Eolc<c003o`000?nc/k?o/k>c00oo/k>c00?o
0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0;ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o
0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo6ATI00Oo6ATI2?l0
0003ooooo`7o00000Oooool002Wooooo00?o0000ooooooooool06_ooool4o`0002?oi^KV0_l0000F
olc<c003o`000?nc/k?o/k>c00oo/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`0;
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`08
oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00?o0000oooo
ooooool05?ooool6o`0002Goi^KV0_l0000Folc<c0;o00004Onc/k<00ol0003oVIVIoiVIV@0=oiVI
V@03o`000?moOgooOgmo00_oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C009oda<
C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001oooo
o`00:Oooool00ol0003oooooooooo`0<ooooo`So0000:_oVi^H00ol0003oc<c<olc<c00Eolc<c003
o`000?nc/k?o/k>c013o/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0;ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`08oc<c<`03
o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo2ol0000`onKViP;o00005oo<c<`00ol0003o/k>cok>c/`0@ok>c/`03o`000?nIVIWoVIVI00ko
VIVI00?o0000ogmoOomoOgl02omoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00Wo
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocWoi^KV0_l0000Golc<c0;o00004_nc/k<00ol0003o
VIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C009oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT02OlI6AT8o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolhonKViP03o`000?o<c<coc<c<01Ko
c<c<00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo00co
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00So
<c<c00?o0000oaTI6OlI6AT02OlI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolfonKViP;o00006?o<c<`00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00ko
VIVI00?o0000ogmoOomoOgl03?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00Wo
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@09oaTI6@So00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocCoi^KV0_l0000Iolc<c003o`000?nc/k?o/k>c01;o
/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00[o
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So
6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo<_oVi^H2o`0001[o
c<c<00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo00co
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c00Wo
<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
ooooooooool`onKViP;o00006_o<c<`2o`0001Co/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003o
OgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o
<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo;_oVi^H2o`0001_oc<c<00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo00coOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool[onKViP?o00007?o<c<`00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00ooVIVI00?o0000ogmoOomoOgl03?moOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o
6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobSo
i^KV0ol0000Nolc<c003o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003o
OgmoogmoO`0<ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o
<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo9_oVi^H2o`00023oc<c<00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolSonKViP?o00008?o<c<`2o`0001Oo
/k>c00?o0000oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`0=ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00[o
6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo8?oVi^H3o`0002;o
c<c<00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo00ko
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o
<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolMonKViP?o00009?o<c<`00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00ko
VIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00_o
C4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooaWoi^KV1?l0000Uolc<c0;o00006?nc/k<00ol0003o
VIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo00goOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00:oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02_lI6AT:o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolEonKViPCo0000:?o<c<`00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00ooVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o
6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa7o
i^KV1?l0000[olc<c003o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003o
OgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o
<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00[o6ATI2_l00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo1?oVi^H=o`0002goc<c<0_l0000Iok>c/`03o`000?nIVIWoVIVI013o
VIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00[o
C4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooo`Co0000>Oo<c<`00ol0003o/k>cok>c/`0Hok>c/`03
o`000?nIVIWoVIVI013oVIVI00?o0000ogmoOomoOgl03_moOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc_oc<c<0_l0000Iok>c/`;o
00004onIVIT00ol0003oOgmoogmoO`0>ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo>_o<c<`00ol0003o/k>cok>c/`0Hok>c/`03
o`000?nIVIWoVIVI01;oVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocWoc<c<00?o0000ok>c/onc
/k<06?nc/k<00ol0003oVIVIoiVIV@0BoiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI
6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolholc<c003
o`000?nc/k?o/k>c01Wo/k>c00?o0000oiVIVOnIVIT04_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0;oc<c<`03
o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo=_o<c<`2o`0001_o/k>c00?o0000oiVIVOnIVIT04_nIVIT00ol0003oOgmoogmoO`0?ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03
o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo=Oo<c<`00ol0003o/k>cok>c/`0Jok>c/`03o`000?nIVIWoVIVI01;oVIVI00?o0000ogmoOomo
Ogl04?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooocCoc<c<00?o0000ok>c/onc/k<06_nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03
o`000?moOgooOgmo00ooOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003ooooooooooooooolbolc<c0;o00007Onc/k<00ol0003oVIVIoiVIV@0BoiVIV@03
o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00<oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003ooooooooooooooolaolc<c003o`000?nc/k?o/k>c01co/k>c00?o0000oiVIVOnI
VIT04onIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<
C4`03?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo<?o<c<`00ol0003o/k>cok>c/`0Lok>c/`03
o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03
o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobkoc<c<0_l0000Ook>c/`03
o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl03omoOgl00ol0003oIVIVofIVIP0=ofIVIP03
o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobgoc<c<00?o0000ok>c/onc
/k<07_nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mV
IVH03OmVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT02olI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool[olc<c0;o
00008?nc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo00ooOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT02olI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolYolc<c0;o
00008Onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mV
IVH03OmVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT02olI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolXolc<c003
o`000?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT05?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0<oc<c<`03
o`000?lI6AWo6ATI00_o6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo9_o<c<`2o`0002;o/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0<oc<c<`03
o`000?lI6AWo6ATI00_o6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo9?o<c<`2o`0002?o/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0AogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03
o`000?lI6AWo6ATI00co6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo8oo<c<`00ol0003o/k>cok>c/`0Rok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomo
Ogl04?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooob7oc<c<0_l0000Tok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooakoc<c<0ol0000Vok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooacoc<c<0_l0000Yok>c/`03o`000?nIVIWoVIVI01GoVIVI00?o0000ogmoOomo
Ogl04_moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooa[oc<c<0_l0000Zok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooaSoc<c<0_l0000[ok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooaGoc<c<0ol0000/ok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomo
Ogl04_moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooa7oc<c<1?l0000_ok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomo
Ogl04OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooo`goc<c<1?l0000bok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomo
Ogl04_moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooo`Woc<c<1?l0000eok>c/`03o`000?nIVIWoVIVI01SoVIVI00?o0000ogmoOomo
Ogl04_moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc
<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooo`Wo0000>Onc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`000?moOgooOgmo01;o
Ogmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c00co
<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooom1ok>c/`03o`000?nIVIWoVIVI01SoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003o
IVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o
6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooood3o
/k>c00?o0000oiVIVOnIVIT06OnIVIT00ol0003oOgmoogmoO`0BogmoO`03o`000?mVIVKoIVIV00oo
IVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00go
6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo?onc/k<00ol0003o
VIVIoiVIV@0IoiVIV@03o`000?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003o
C4a<oda<C00>oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolook>c/`03o`000?nIVIWoVIVI01Wo
VIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00go
C4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocko/k>c00?o0000oiVIVOnIVIT06OnIVIT00ol0003o
OgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o
<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo?_nc/k<00ol0003oVIVIoiVIV@0IoiVIV@03o`000?moOgooOgmo01;o
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c00go
<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolmok>c/`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl04omoOgl00ol0003o
IVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocgo
/k>c00?o0000oiVIVOnIVIT06OnIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go
6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo??nc/k<00ol0003o
VIVIoiVIV@0JoiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003o
C4a<oda<C00>oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolkok>c/`03o`000?nIVIWoVIVI01[o
VIVI00?o0000ogmoOomoOgl04omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ko
C4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooc_o/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003o
OgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o
<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo>_nc/k<00ol0003oVIVIoiVIV@0KoiVIV@03o`000?moOgooOgmo01?o
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go
<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
ooooooooooljok>c/`03o`000?nIVIWoVIVI01_oVIVI00?o0000ogmoOomoOgl04omoOgl00ol0003o
IVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocWo
/k>c00?o0000oiVIVOnIVIT06onIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go
6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo>?nc/k<00ol0003o
VIVIoiVIV@0LoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003o
C4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolhok>c/`03o`000?nIVIWoVIVI01co
VIVI00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00ko
C4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@co00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocOo/k>c00?o0000oiVIVOnIVIT07OnIVIT00ol0003o
OgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o
<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI3?l00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo=onc/k<00ol0003oVIVIoiVIV@0LoiVIV@03o`000?moOgooOgmo01Co
Ogmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c00go
<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolfok>c/`03o`000?nIVIWoVIVI01goVIVI00?o0000ogmoOomoOgl05?moOgl00ol0003o
IVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@co00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocKo
/k>c00?o0000oiVIVOnIVIT07OnIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go
6ATI3?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo=_nc/k<00ol0003o
VIVIoiVIV@0MoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003o
C4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooleok>c/`03o`000?nIVIWoVIVI01go
VIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00oo
C4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@co00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocGo/k>c00?o0000oiVIVOnIVIT07OnIVIT00ol0003o
OgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o
<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI3?l00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo=Onc/k<00ol0003oVIVIoiVIV@0MoiVIV@03o`000?moOgooOgmo01Go
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go
<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
ooooooooooleok>c/`03o`000?nIVIWoVIVI01goVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003o
IVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@co00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocCo
/k>c00?o0000oiVIVOnIVIT07_nIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go
6ATI3?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo=?nc/k<00ol0003o
VIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003o
C4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooldok>c/`03o`000?nIVIWoVIVI01go
VIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00oo
C4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@co00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocCo/k>c00?o0000oiVIVOnIVIT07OnIVIT00ol0003o
OgmoogmoO`0FogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o
<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI3?l00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo<onc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01Ko
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go
<c<c00?o0000oaTI6OlI6AT03OlI6AT<o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolcok>c/`03o`000?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003o
IVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@co00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc?o
/k>c00?o0000oiVIVOnIVIT07_nIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV017o
IVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI00go
6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo<onc/k<00ol0003o
VIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003o
C4a<oda<C00?oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolbok>c/`03o`000?nIVIWoVIVI01oo
VIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00oo
C4a<00?o0000oc<c<olc<c<03_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooc;o/k>c00?o0000oiVIVOnIVIT07onIVIT00ol0003o
OgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o
<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool000oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Cooooo00Co0000oooooooooooooooo<_nc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`000?moOgoo
Ogmo01KoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o
<c<c00ko<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`003oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00Co0000
oooooooooooooooo<_nc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01KoOgmo00?o
0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00ko<c<c00?o
0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`003oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooooooooolaok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o0000
0oooool1o`00007ooooo000?ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`;o00000_oooolaok>c/`03o`000?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl0
5_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000_ooool2o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00Co0000oooooooo
oooooooo<Onc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`000?moOgooOgmo01KoOgmo00?o0000ofIV
I_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00ko<c<c00?o0000oaTI
6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`003oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool01?l0003ooooooooooooooolaok>c/`03o`000?nIVIWo
VIVI01ooVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4co
C4a<00ooC4a<00?o0000oc<c<olc<c<03_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1
o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`04o`000?oooooooooooooooc7o/k>c00?o0000oiVIVOnIVIT07onIVIT00ol0003oOgmoogmo
O`0FogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c
<`0>oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool000oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool01?l0003ooooooooooooooolaok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc7o/k>c00?o0000oiVIVOnIVIT0
7onIVIT00ol0003oOgmoogmoO`0FogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<Onc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`00
0?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`00
0?lc<c?o<c<c00ko<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolaok>c/`03o`000?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl0
5_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3_lc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc7o/k>c00?o0000oiVIVOnIVIT07onIVIT00ol0003oOgmoogmoO`0FogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`00
0?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<_nc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`000?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
3OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolbok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc;o/k>c00?o0000oiVIVOnIVIT0
7onIVIT00ol0003oOgmoogmoO`0FogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<_nc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`00
0?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolbok>c/`03o`000?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl0
5_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc;o/k>c00?o0000oiVIVOnIVIT07onIVIT00ol0003oOgmoogmoO`0FogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<_nc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`000?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
3OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolbok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc;o/k>c00?o0000oiVIVOnIVIT0
7onIVIT00ol0003oOgmoogmoO`0FogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<_nc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`00
0?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolcok>c/`03o`000?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl0
5_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc?o/k>c00?o0000oiVIVOnIVIT07_nIVIT00ol0003oOgmoogmoO`0FogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00go6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<onc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
3OlI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolcok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc?o/k>c00?o0000oiVIVOnIVIT0
7onIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00go6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=?nc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`00
0?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooldok>c/`03o`000?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl0
5_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocCo/k>c00?o0000oiVIVOnIVIT07_nIVIT00ol0003oOgmoogmoO`0FogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00co6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=?nc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01KoOgmo00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
3?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooldok>c/`03o`00
0?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocGo/k>c00?o0000oiVIVOnIVIT0
7_nIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00co6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=Onc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`00
0?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00?oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooleok>c/`03o`000?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl0
5OmoOgl2o`0001;oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00co6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=Onc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
3?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolfok>c/`03o`00
0?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocKo/k>c00?o0000oiVIVOnIVIT0
7_nIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`0
3om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00co6ATI2ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=_nc/k<00ol0003oVIVIoiVIV@0OoiVIV@03o`00
0?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolgok>c/`03o`000?nIVIWoVIVI01koVIVI00?o0000ogmoOomoOgl0
5OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocOo/k>c00?o0000oiVIVOnIVIT07_nIVIT00ol0003oOgmoogmoO`0EogmoO`03o`00
0?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`00
0?lI6AWo6ATI00co6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=onc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
3?lI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolhok>c/`03o`00
0?nIVIWoVIVI01goVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`00
0?m<C4coC4a<00ooC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@_o0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocSo/k>c00?o0000oiVIVOnIVIT0
7_nIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00co6ATI2_l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo>?nc/k<00ol0003oVIVIoiVIV@0NoiVIV@03o`00
0?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT03?lI6AT:o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooliok>c/`03o`000?nIVIWoVIVI01goVIVI00?o0000ogmoOomoOgl0
5?moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocWo/k>c00?o0000oiVIVOnIVIT07OnIVIT00ol0003oOgmoogmoO`0DogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00co6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
>_nc/k<00ol0003oVIVIoiVIV@0LoiVIV@03o`000?moOgooOgmo01GoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
3?lI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooljok>c/`03o`00
0?nIVIWoVIVI01goVIVI00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0AofIVIP03o`00
0?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc[o/k>c00?o0000oiVIVOnIVIT0
7OnIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0
3_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00co6ATI2_l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo>onc/k<00ol0003oVIVIoiVIV@0LoiVIV@03o`00
0?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT03?lI6AT:o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolkok>c/`03o`000?nIVIWoVIVI01coVIVI00?o0000ogmoOomoOgl0
5?moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocco/k>c00?o0000oiVIVOnIVIT06onIVIT00ol0003oOgmoogmoO`0DogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`00
0?lI6AWo6ATI00co6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
??nc/k<00ol0003oVIVIoiVIV@0LoiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
3?lI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooollok>c/`03o`00
0?nIVIWoVIVI01coVIVI00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`00
0?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@[o0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocgo/k>c00?o0000oiVIVOnIVIT0
6onIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`0
3_m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo?Onc/k<00ol0003oVIVIoiVIV@0KoiVIV@03o`00
0?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00=oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolnok>c/`03o`000?nIVIWoVIVI01_oVIVI00?o0000ogmoOomoOgl0
4omoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<0
3Olc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocko/k>c00?o0000oiVIVOnIVIT06onIVIT00ol0003oOgmoogmoO`0CogmoO`03o`00
0?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`00
0?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
?_nc/k<00ol0003oVIVIoiVIV@0KoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT0
2olI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolook>c/`03o`00
0?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl05?moOgl00ol0003oIVIVofIVIP0@ofIVIP03o`00
0?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocoo/k>c00?o0000oiVIVOnIVIT0
6onIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`0
3_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo@?nc/k<00ol0003oVIVIoiVIV@0JoiVIV@03o`00
0?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00>oda<C003o`00
0?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooom0ok>c/`03o`000?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl0
4omoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooood3o/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003oOgmoogmoO`0DogmoO`03o`00
0?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`00
0?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
@Onc/k<00ol0003oVIVIoiVIV@0JoiVIV@03o`000?moOgooOgmo01?oOgmo00?o0000ofIVI_mVIVH0
4?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT0
2olI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooom1ok>c/`03o`00
0?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl04omoOgl00ol0003oIVIVofIVIP0@ofIVIP03o`00
0?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooood7o/k>c00?o0000oiVIVOnIVIT0
6onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`0
3Om<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo@_nc/k<00ol0003oVIVIoiVIV@0JoiVIV@03o`00
0?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00=oda<C003o`00
0?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooom2ok>c/`03o`000?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl0
4omoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<0
3?lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooood?o/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`00
0?lI6AWo6ATI00_o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
1Ol0000nok>c/`03o`000?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0@ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooo`Goc<c<
1?l0000kok>c/`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0@ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooo`Woc<c<
0_l0000iok>c/`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0@ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooo`_oc<c<
0_l0000gok>c/`03o`000?nIVIWoVIVI01[oVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0;oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooo`goc<c<
0_l0000fok>c/`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATI
oaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooo`ooc<c<
0_l0000dok>c/`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATI
oaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa7oc<c<
00?o0000ok>c/onc/k<0<_nc/k<00ol0003oVIVIoiVIV@0IoiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00co<c<c
00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooo
oooooolBolc<c003o`000?nc/k?o/k>c037o/k>c00?o0000oiVIVOnIVIT06OnIVIT00ol0003oOgmo
ogmoO`0BogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0<oc<c<`03o`000?lI6AWo6ATI00[o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co
0000oooooooooooooooo4oo<c<`2o`0003;o/k>c00?o0000oiVIVOnIVIT06?nIVIT00ol0003oOgmo
ogmoO`0BogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<c
oc<c<`0;oc<c<`03o`000?lI6AWo6ATI00[o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co
0000oooooooooooooooo5Oo<c<`00ol0003o/k>cok>c/`0_ok>c/`03o`000?nIVIWoVIVI01SoVIVI
00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00goC4a<
00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007ooooo
000Yooooo`04o`000?oooooooooooooooaKoc<c<00?o0000ok>c/onc/k<0;onc/k<00ol0003oVIVI
oiVIV@0HoiVIV@03o`000?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00=oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo
0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolGolc<c0;o0000;onc/k<00ol0003oVIVI
oiVIV@0HoiVIV@03o`000?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00=oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo
0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolHolc<c003o`000?nc/k?o/k>c02go/k>c
00?o0000oiVIVOnIVIT06?nIVIT00ol0003oOgmoogmoO`0BogmoO`03o`000?mVIVKoIVIV00koIVIV
00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI00[o6ATI
2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo6Oo<c<`00ol0003o/k>c
ok>c/`0/ok>c/`03o`000?nIVIWoVIVI01SoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa[oc<c<
00?o0000ok>c/onc/k<0;?nc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`000?moOgooOgmo01;oOgmo
00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00_o<c<c
00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooo
oooooolKolc<c003o`000?nc/k?o/k>c02_o/k>c00?o0000oiVIVOnIVIT06?nIVIT00ol0003oOgmo
ogmoO`0AogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<c
oc<c<`0;oc<c<`03o`000?lI6AWo6ATI00[o6ATI2_l00003ooooo`7o00000Oooool002Wooooo00Co
0000oooooooooooooooo7?o<c<`00ol0003o/k>cok>c/`0Zok>c/`03o`000?nIVIWoVIVI01SoVIVI
00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<
00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007ooooo
000Yooooo`04o`000?oooooooooooooooagoc<c<00?o0000ok>c/onc/k<0:_nc/k<00ol0003oVIVI
oiVIV@0GoiVIV@03o`000?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<
oda<C00=oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo
0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolNolc<c003o`000?nc/k?o/k>c02Wo/k>c
00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`000?mVIVKoIVIV00koIVIV
00?o0000oda<C?m<C4`03Om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00[o6ATI
2_l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo7oo<c<`00ol0003o/k>c
ok>c/`0Xok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomoOgl04_moOgl00ol0003oIVIV
ofIVIP0>ofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATI
oaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooaooc<c<
00?o0000ok>c/onc/k<0:Onc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`000?moOgooOgmo017oOgmo
00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00_o<c<c
00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooo
oooooolPolc<c003o`000?nc/k?o/k>c02So/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmo
ogmoO`0AogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<c
oc<c<`0;oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co
0000oooooooooooooooo8Oo<c<`00ol0003o/k>cok>c/`0Wok>c/`03o`000?nIVIWoVIVI01OoVIVI
00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00coC4a<
00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00000oooool1o`00007ooooo
000Yooooo`04o`000?ooooooooooooooob;oc<c<00?o0000ok>c/onc/k<09onc/k<00ol0003oVIVI
oiVIV@0FoiVIV@03o`000?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<
oda<C00<oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo
0Ol00001ooooo`003?ooool5o`0000oooooo1?l000000ol@413oooooooooo`02ooooo`04o`000?oo
ooooooooooooob;oc<c<00?o0000ok>c/onc/k<09onc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`00
0?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00=oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`003?oo
ool2ogMgM`;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooooooob?oc<c<00?o0000ok>c/onc/k<09_nc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`00
0?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00<oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`003Ooo
ool00omEEEGoV9RHooooo`0Booooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo
9?o<c<`00ol0003o/k>cok>c/`0Vok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomoOgl0
4OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00000oooool1o`00007ooooo000>ooooo`03oeEEEOnH
V9Sooooo017ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo9Oo<c<`00ol0003o/k>cok>c
/`0Uok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIV
IP0?ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI
6@0:oaTI6@Wo00000_ooool2o`00007ooooo000<ooooo`05o`000?oooooooooooc8b<_n7QhL04Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooobGoc<c<00?o0000ok>c/onc/k<0
9Onc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`000?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH0
3omVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2_lI6AT9o`0000?ooooo0Ol00001ooooo`003?ooool5o`00017ooooo00?o0000ooooooooool01?oo
ool01?l0003ooooooooooooooolVolc<c003o`000?nc/k?o/k>c02Go/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0
3?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o0000
0Oooool002;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooooooooolVolc<c003o`00
0?nc/k?o/k>c02Go/k>c00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool0023ooooo00?oEEEEofIVI_l000001_oo
ool01?l0003ooooooooooooooolWolc<c003o`000?nc/k?o/k>c02Go/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`0
3?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo9oo<c<`00ol0003o/k>cok>c/`0Uok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobSoc<c<00?o0000ok>c/onc/k<0
9?nc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`000?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH0
3omVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolXolc<c003o`00
0?nc/k?o/k>c02Go/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
:Oo<c<`00ol0003o/k>cok>c/`0Tok>c/`03o`000?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooobWoc<c<00?o0000ok>c/onc/k<09?nc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`00
0?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00<oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolZolc<c003o`000?nc/k?o/k>c02?o/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`0
3?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo:_o<c<`00ol0003o/k>cok>c/`0Tok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooob_oc<c<00?o0000ok>c/onc/k<0
8onc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool[olc<c003o`00
0?nc/k?o/k>c02?o/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
;?o<c<`00ol0003o/k>cok>c/`0Rok>c/`03o`000?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl0
4OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooobcoc<c<00?o0000ok>c/onc/k<08onc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooool]olc<c003o`000?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo;_o<c<`00ol0003o/k>cok>c/`0Qok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobooc<c<00?o0000ok>c/onc/k<0
8?nc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool_olc<c003o`00
0?nc/k?o/k>c027o/k>c00?o0000oiVIVOnIVIT05?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
;oo<c<`00ol0003o/k>cok>c/`0Qok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc3oc<c<00?o0000ok>c/onc/k<08?nc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooool`olc<c003o`000?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<?o<c<`00ol0003o/k>cok>c/`0Pok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc7oc<c<00?o0000ok>c/onc/k<0
8?nc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolaolc<c003o`00
0?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT05?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<Oo<c<`00ol0003o/k>cok>c/`0Pok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc;oc<c<00?o0000ok>c/onc/k<07onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolbolc<c003o`000?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0?ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<_o<c<`00ol0003o/k>cok>c/`0Pok>c/`03o`00
0?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc?oc<c<00?o0000ok>c/onc/k<0
7onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolcolc<c003o`00
0?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT05?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<oo<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc?oc<c<00?o0000ok>c/onc/k<07onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolcolc<c003o`000?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT0
5?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<oo<c<`00ol0003o/k>cok>c/`0Pok>c/`03o`00
0?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocCoc<c<00?o0000ok>c/onc/k<0
7onc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooldolc<c003o`00
0?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT04onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=?o<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocCoc<c<00?o0000ok>c/onc/k<07onc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00<oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooldolc<c003o`000?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT0
5?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=?o<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`00
0?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocCoc<c<00?o0000ok>c/onc/k<0
8?nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooldolc<c003o`00
0?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT04onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=Oo<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocGoc<c<00?o0000ok>c/onc/k<07onc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooleolc<c003o`000?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT0
4onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=Oo<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`00
0?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocGoc<c<00?o0000ok>c/onc/k<0
7onc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooleolc<c003o`00
0?nc/k?o/k>c01oo/k>c00?o0000oiVIVOnIVIT04onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
=Oo<c<`00ol0003o/k>cok>c/`0Ook>c/`03o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooocCoc<c<00?o0000ok>c/onc/k<08?nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooooldolc<c003o`000?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT0
4onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo=?o<c<`00ol0003o/k>cok>c/`0Pok>c/`03o`00
0?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooocCoc<c<00?o0000ok>c/onc/k<0
8?nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT0
2?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooldolc<c003o`00
0?nc/k?o/k>c023o/k>c00?o0000oiVIVOnIVIT04onIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<oo<c<`00ol0003o/k>cok>c/`0Qok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc?oc<c<00?o0000ok>c/onc/k<08Onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolcolc<c003o`000?nc/k?o/k>c027o/k>c00?o0000oiVIVOnIVIT0
5?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<oo<c<`00ol0003o/k>cok>c/`0Qok>c/`03o`00
0?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc?oc<c<00?o0000ok>c/onc/k<0
8Onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT0
2?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolbolc<c003o`00
0?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT05?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<_o<c<`00ol0003o/k>cok>c/`0Rok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc;oc<c<00?o0000ok>c/onc/k<08_nc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolbolc<c003o`000?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT0
5?nIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo<Oo<c<`00ol0003o/k>cok>c/`0Sok>c/`03o`00
0?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl04?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So0000
0oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc7oc<c<00?o0000ok>c/onc/k<0
8_nc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3OmVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT0
2?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolaolc<c003o`00
0?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
<?o<c<`00ol0003o/k>cok>c/`0Sok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomoOgl0
4OmoOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0
2Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007ooooo000Yooooo`04o`000?oo
oooooooooooooc3oc<c<00?o0000ok>c/onc/k<08onc/k<00ol0003oVIVIoiVIV@0DoiVIV@03o`00
0?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C003o`00
0?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooool`olc<c003o`000?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0
2om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo;oo<c<`00ol0003o/k>cok>c/`0Sok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0=ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@08oaTI6@So0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobooc<c<00?o0000ok>c/onc/k<0
8onc/k<00ol0003oVIVIoiVIV@0EoiVIV@03o`000?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool^olc<c003o`00
0?nc/k?o/k>c02Co/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`0@ogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
;Oo<c<`00ol0003o/k>cok>c/`0Tok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomoOgl0
4?moOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooobcoc<c<00?o0000ok>c/onc/k<09Onc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`00
0?moOgooOgmo013oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003oooooooooooooool[olc<c003o`000?nc/k?o/k>c02Ko/k>c00?o0000oiVIVOnIVIT0
5OnIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`0
2_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo:_o<c<`00ol0003o/k>cok>c/`0Wok>c/`03o`00
0?nIVIWoVIVI01GoVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@08oaTI6@So0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobWoc<c<00?o0000ok>c/onc/k<0
9onc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`000?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolXolc<c003o`00
0?nc/k?o/k>c02So/k>c00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
9_o<c<`2o`0002_o/k>c00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
9Oo<c<`00ol0003o/k>cok>c/`0Zok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomoOgl0
4OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@08oaTI6@So00000oooool1o`00007ooooo000Yooooo`04o`000?oo
ooooooooooooobCoc<c<00?o0000ok>c/onc/k<0:onc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`00
0?moOgooOgmo01;oOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00:oda<C003o`00
0?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Ooo
ool01?l0003ooooooooooooooolSolc<c003o`000?nc/k?o/k>c02co/k>c00?o0000oiVIVOnIVIT0
5_nIVIT00ol0003oOgmoogmoO`0AogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`0
2_m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00So6ATI2?l00003ooooo`7o0000
0Oooool002Wooooo00Co0000oooooooooooooooo8_o<c<`00ol0003o/k>cok>c/`0/ok>c/`03o`00
0?nIVIWoVIVI01OoVIVI00?o0000ogmoOomoOgl04OmoOgl00ol0003oIVIVofIVIP0>ofIVIP03o`00
0?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@08oaTI6@So0000
0oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooob7oc<c<00?o0000ok>c/onc/k<0
;Onc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`000?moOgooOgmo017oOgmo00?o0000ofIVI_mVIVH0
3_mVIVH00ol0003oC4a<oda<C00;oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT0
2?lI6AT8o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolPolc<c003o`00
0?nc/k?o/k>c02ko/k>c00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
7_o<c<`2o`00033o/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
7?o<c<`2o`0003;o/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
6_o<c<`2o`0003Co/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
6?o<c<`2o`0003Go/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo
5_o<c<`2o`0003Oo/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`0BogmoO`03o`00
0?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`00
0?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool0013ooooo1?l000000ol@413ooooooooo
o`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00Co0000oooooooooooo
oooo4oo<c<`3o`0003So/k>c00?o0000oiVIVOnIVIT06?nIVIT00ol0003oOgmoogmoO`0BogmoO`03
o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03
o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool001;ooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool01?l0003oooooooooooooool@olc<c0?o
0000>_nc/k<00ol0003oVIVIoiVIV@0IoiVIV@03o`000?moOgooOgmo01;oOgmo00?o0000ofIVI_mV
IVH03_mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00Wo<c<c00?o0000oaTI6OlI
6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`004_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo3Oo<c<`3o`0003co/k>c00?o0000oiVIVOnI
VIT06OnIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<
C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o
00000Oooool001;ooooo00?o0000ooooooooool03_ooool00omgMgOo<S8booooo`03ooooo`;o0000
0_ooool4olc<c0Wo0000?_nc/k<00ol0003oVIVIoiVIV@0JoiVIV@03o`000?moOgooOgmo01?oOgmo
00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00Wo<c<c
00?o0000oaTI6OlI6AT02?lI6AT9o`0000;ooooo0_l00001ooooo`004_ooool00ol0003ooooooooo
o`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool01?l0003oooooooooooooool4o`0004Oo
/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003oOgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV00ko
IVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So
6ATI2Ol00003ooooo`7o00000Oooool001;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`06ooooo`04o`000?oooooooooooooood[o/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003o
OgmoogmoO`0CogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o
<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So6ATI2Ol00003ooooo`7o00000Oooool001;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooodWo
/k>c00?o0000oiVIVOnIVIT06_nIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV00oo
IVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So
6ATI2Ol00003ooooo`7o00000Oooool0013ooooo00?oEEEEofIVI_l000003Oooool4o`0000Gooooo
00Co0000ooooooooooooooooB?nc/k<00ol0003oVIVIoiVIV@0KoiVIV@03o`000?moOgooOgmo01Co
Ogmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00Wo
<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooom6ok>c/`;o00007OnIVIT00ol0003oOgmoogmoO`0DogmoO`03o`000?mVIVKoIVIV013o
IVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00So
6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000ooooooooooooooooAOnc/k<00ol0003o
VIVIoiVIV@0MoiVIV@03o`000?moOgooOgmo01CoOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003o
C4a<oda<C00<oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooom4ok>c/`03o`000?nIVIWoVIVI01go
VIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<00co
C4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@08oaTI6@Wo00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooood;o/k>c0_l0000OoiVIV@03o`000?moOgooOgmo01Go
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00<oda<C003o`000?lc<c?o<c<c00[o
<c<c00?o0000oaTI6OlI6AT02?lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooom1ok>c/`03o`000?nIVIWoVIVI01ooVIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003o
IVIVofIVIP0@ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o
6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooood3o
/k>c00?o0000oiVIVOnIVIT07onIVIT00ol0003oOgmoogmoO`0EogmoO`03o`000?mVIVKoIVIV017o
IVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI00Wo
6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo?_nc/k<2o`0002;o
VIVI00?o0000ogmoOomoOgl05OmoOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00co
C4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooc_o/k>c0ol0000SoiVIV@03o`000?moOgooOgmo01Ko
Ogmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00=oda<C003o`000?lc<c?o<c<c00Wo
<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolhok>c/`?o00009OnIVIT00ol0003oOgmoogmoO`0FogmoO`03o`000?mVIVKoIVIV017o
IVIV00?o0000oda<C?m<C4`03?m<C4`00ol0003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo
6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo=_nc/k<2o`0002So
VIVI00?o0000ogmoOomoOgl05_moOgl00ol0003oIVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00co
C4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooocGo/k>c00?o0000oiVIVOnIVIT09onIVIT00ol0003o
OgmoogmoO`0GogmoO`03o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03Om<C4`00ol0003o
<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo<_nc/k<3o`0002WoVIVI00?o0000ogmoOomoOgl05omoOgl00ol0003o
IVIVofIVIP0AofIVIP03o`000?m<C4coC4a<00goC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o
6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobko
/k>c1?l0000[oiVIV@03o`000?moOgooOgmo01SoOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003o
C4a<oda<C00=oda<C003o`000?lc<c?o<c<c00[o<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool[ok>c/`?o0000;_nIVIT00ol0003o
OgmoogmoO`0HogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o
<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo:?nc/k<3o`00033oVIVI00?o0000ogmoOomoOgl06?moOgl00ol0003o
IVIVofIVIP0BofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o
6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooobGo
/k>c0ol0000boiVIV@03o`000?moOgooOgmo01WoOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003o
C4a<oda<C00=oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolQok>c/`Co0000=?nIVIT00ol0003o
OgmoogmoO`0IogmoO`03o`000?mVIVKoIVIV01;oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o
<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI00Wo6ATI2Ol00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo7Onc/k<4o`0003OoVIVI00?o0000ogmoOomoOgl06OmoOgl00ol0003o
IVIVofIVIP0CofIVIP03o`000?m<C4coC4a<00koC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o
6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooaWo
/k>c1?l0000ioiVIV@;o00006omoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?m<C4coC4a<00oo
C4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@09oaTI6@Wo00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooa?o/k>c1_l0000loiVIV@03o`000?moOgooOgmo01[o
Ogmo00?o0000ofIVI_mVIVH05?mVIVH00ol0003oC4a<oda<C00?oda<C003o`000?lc<c?o<c<c00_o
<c<c00?o0000oaTI6OlI6AT02OlI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
ooooooooool;ok>c/`So0000@?nIVIT2o`0001goOgmo00?o0000ofIVI_mVIVH05?mVIVH00ol0003o
C4a<oda<C00>oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooool;o`0004KoVIVI0_l0000NogmoO`03
o`000?mVIVKoIVIV01CoIVIV00?o0000oda<C?m<C4`03om<C4`00ol0003o<c<coc<c<`0;oc<c<`03
o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
ooooD?nIVIT00ol0003oOgmoogmoO`0MogmoO`03o`000?mVIVKoIVIV01GoIVIV00?o0000oda<C?m<
C4`03om<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o
00000Oooool002Wooooo00Co0000ooooooooooooooooC_nIVIT2o`0001ooOgmo00?o0000ofIVI_mV
IVH05OmVIVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c00_o<c<c00?o0000oaTI6OlI
6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooom<oiVIV@;o
00008?moOgl00ol0003oIVIVofIVIP0FofIVIP03o`000?m<C4coC4a<013oC4a<00?o0000oc<c<olc
<c<02olc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooood[oVIVI0_l0000RogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o0000oda<C?m<
C4`03om<C4`00ol0003o<c<coc<c<`0<oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o
00000Oooool002Wooooo00Co0000ooooooooooooooooB?nIVIT2o`0002?oOgmo00?o0000ofIVI_mV
IVH05_mVIVH00ol0003oC4a<oda<C00@oda<C003o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI
6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooom5oiVIV@?o
00008omoOgl2o`0001WoIVIV00?o0000oda<C?m<C4`04?m<C4`00ol0003o<c<coc<c<`0<oc<c<`03
o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo@OnIVIT4o`0002GoOgmo00?o0000ofIVI_mVIVH06OmVIVH00ol0003oC4a<oda<C00@oda<C003
o`000?lc<c?o<c<c00co<c<c00?o0000oaTI6OlI6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003ooooooooooooooolmoiVIV@Co00009omoOgl2o`0001_oIVIV00?o0000oda<C?m<
C4`04?m<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00[o6ATI2Ol00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo>OnIVIT4o`0002[oOgmo00?o0000ofIVI_mV
IVH06_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI
6AT02_lI6AT9o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003oooooooooooooooleoiVIV@Co
0000;?moOgl2o`0001coIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o<c<coc<c<`0<oc<c<`03
o`000?lI6AWo6ATI00_o6ATI2Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo<OnIVIT4o`0002ooOgmo00?o0000ofIVI_mVIVH06omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT02_lI6AT:o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003oooooooooooooool[oiVIV@Ko0000<OmoOgl2o`0001goIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI00[o6ATI2_l00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo8onIVIT8o`0003KoOgmo00?o0000ofIVI_mV
IVH07?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI
6AT02_lI6AT:o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolKoiVIV@So
0000?OmoOgl00ol0003oIVIVofIVIP0LofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000oc<c<olc
<c<03_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooa?oVIVI2?l00013ogmoO`;o00007OmVIVH2o`0001OoC4a<00?o0000oc<c<olc
<c<03_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@[o00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooo`_oVIVI2?l00018ogmoO`?o00007_mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT02olI6AT:o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003oooooooooooooool;o`0004goOgmo0ol0000PofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000oc<c<olc<c<03_lc<c<00ol0003o6ATIoaTI6@0;oaTI6@[o00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooeKoOgmo0_l0000QofIVIP;o00006Om<C4`00ol0003o
<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI00[o6ATI2ol00003ooooo`7o00000Oooool002Wooooo
00Co0000ooooooooooooooooDomoOgl3o`0002;oIVIV00?o0000oda<C?m<C4`06Om<C4`00ol0003o
<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI00[o6ATI2ol00003ooooo`7o00000Oooool002Wooooo
00Co0000ooooooooooooooooD?moOgl3o`0002CoIVIV00?o0000oda<C?m<C4`06Om<C4`00ol0003o
<c<coc<c<`0?oc<c<`03o`000?lI6AWo6ATI00_o6ATI2ol00003ooooo`7o00000Oooool002Wooooo
00Co0000ooooooooooooooooC?moOgl4o`0002GoIVIV0_l0000Koda<C003o`000?lc<c?o<c<c013o
<c<c00?o0000oaTI6OlI6AT02olI6AT;o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooom9ogmoO`?o00009omVIVH2o`0001goC4a<00?o0000oc<c<olc<c<04?lc<c<00ol0003o
6ATIoaTI6@0;oaTI6@_o00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooood?o
Ogmo1_l0000XofIVIP;o00007_m<C4`00ol0003o<c<coc<c<`0@oc<c<`03o`000?lI6AWo6ATI00co
6ATI2ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo>omoOgl8o`0002co
IVIV0_l0000Ooda<C003o`000?lc<c?o<c<c017o<c<c00?o0000oaTI6OlI6AT03?lI6AT;o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolcogmoO`So0000<_mVIVH2o`00023o
C4a<00?o0000oc<c<olc<c<04Olc<c<00ol0003o6ATIoaTI6@0=oaTI6@_o00000oooool1o`00007o
oooo000Yooooo`04o`000?ooooooooooooooob_oOgmo2?l0000hofIVIP;o00008?m<C4`2o`0001Co
<c<c00?o0000oaTI6OlI6AT03?lI6AT<o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooolSogmoO`So0000?_mVIVH2o`00027oC4a<00?o0000oc<c<olc<c<04olc<c<00ol0003o
6ATIoaTI6@0=oaTI6@co00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa?o
Ogmo4?l00014ofIVIP;o00008_m<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?lI6AWo6ATI00go
6ATI3?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo4ol0001AofIVIP?o
00008_m<C4`2o`0001Ko<c<c00?o0000oaTI6OlI6AT03_lI6AT<o`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003ooooooooooooooomQofIVIP?o00009?m<C4`00ol0003o<c<coc<c<`0Foc<c<`03
o`000?lI6AWo6ATI00ko6ATI3?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
ooooGOmVIVH4o`0002KoC4a<00?o0000oc<c<olc<c<05olc<c<00ol0003o6ATIoaTI6@0>oaTI6@co
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooeWoIVIV1?l0000Xoda<C0;o
00006Olc<c<00ol0003o6ATIoaTI6@0?oaTI6@co00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooooeGoIVIV1?l0000Zoda<C0;o00006olc<c<00ol0003o6ATIoaTI6@0?oaTI6@co
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooe7oIVIV1?l0000/oda<C0;o
00007?lc<c<00ol0003o6ATIoaTI6@0?oaTI6@go00000oooool1o`00007ooooo000Yooooo`04o`00
0?oooooooooooooood_oIVIV1_l0000^oda<C0;o00007_lc<c<00ol0003o6ATIoaTI6@0?oaTI6@go
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooc_oIVIV4?l0000aoda<C0?o
00007olc<c<00ol0003o6ATIoaTI6@0@oaTI6@go00000oooool1o`00007ooooo000Yooooo`04o`00
0?ooooooooooooooob_oIVIV4?l0000moda<C0Co00008?lc<c<2o`0001?o6ATI3Ol00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo8omVIVH8o`0004[oC4a<0ol0000Soc<c<`03
o`000?lI6AWo6ATI01?o6ATI3Ol00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooo
oooo2omVIVHHo`0004ooC4a<0ol0000Uoc<c<`03o`000?lI6AWo6ATI01?o6ATI3_l00003ooooo`7o
00000Oooool002Wooooo00Co0000oooooooooooooooo2ol0001Toda<C0?o00009olc<c<00ol0003o
6ATIoaTI6@0DoaTI6@ko00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooof[o
C4a<1Ol0000Yoc<c<`03o`000?lI6AWo6ATI01Go6ATI3_l00003ooooo`7o00000Oooool002Wooooo
00Co0000ooooooooooooooooI?m<C4`6o`0002go<c<c00?o0000oaTI6OlI6AT05OlI6AT?o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooomQoda<C0?o0000<Olc<c<2o`0001So
6ATI3ol00003ooooo`7o00000Oooool002Wooooo00Co0000ooooooooooooooooFom<C4`6o`0003;o
<c<c0_l0000JoaTI6@oo00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooe?o
C4a<2?l0000foc<c<`;o00006olI6AT@o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooom3oda<C13o0000??lc<c<2o`0001go6ATI4?l00003ooooo`7o00000Oooool002Wooooo
00Co0000oooooooooooooooo:om<C4`Ho`0004Wo<c<c0ol0000OoaTI6A3o00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooa?oC4a<6?l0001Moc<c<`Co00008OlI6ATAo`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooolCo`0006oo<c<c1_l0000ToaTI6A;o
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooogco<c<c1_l0000YoaTI6A?o
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooogSo<c<c1?l0000^oaTI6ACo
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooog;o<c<c1_l0000aoaTI6AGo
00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooof?o<c<c3ol0000foaTI6AKo
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooe_o<c<c2?l00014oaTI6AOo
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooood?o<c<c6?l0001:oaTI6AWo
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa_o<c<c:?l0001OoaTI6Aco
00000oooool1o`00007ooooo000Yooooo`04o`000?oooooooooooooooa_o0000Q?lI6ATOo`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooonLoaTI6B;o00000oooool1o`00007o
oooo000Yooooo`04o`000?oooooooooooooooiSo6ATI9_l00003ooooo`7o00000Oooool002Wooooo
00Co0000ooooooooooooooooT_lI6AT/o`0000?ooooo0Ol00001ooooo`00:Oooool01?l0003ooooo
oooooooooon2oaTI6Cco00000oooool1o`00007ooooo000Yooooo`04o`000?ooooooooooooooof[o
6ATIE?l00003ooooo`7o00000Oooool002Wooooo00Co0000oooooooooooooooo>olI6AV3o`0000?o
oooo0Ol00001ooooo`00:Oooool01?l0003ooooooooooooooonno`0000?ooooo0Ol00001ooooo`00
:Oooool01?l0003ooooooooooooooonno`0000?ooooo0Ol00001ooooo`007oooool5o`0000Gooooo
00Co0000oooooooooooooooo__l00003ooooo`7o00000Oooool001oooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`04o`000?oooooooooooooookko00000oooool1o`00007ooooo000Pooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00Co0000oooooooooooooooo__l00003ooooo`7o00000Oooool0027o
oooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0000;ooooo__l00002ooooo`;o00000Oooool002;ooooo
00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`32ooooo`7o00000Oooool002?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`32ooooo`7o00000Oooool001oooooo00Go0000
okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0<;ooooo0Ol00001ooooo`007oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0`_ooool1o`00007ooooo000Y
ooooo`03o`000?oooooooooo0<;ooooo0Ol00001ooooo`00:Oooool01Ol0003ooooooooooooooooo
000002Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00001ooooo`00:Oooooo6
o`00007ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00AOooool3o`000003oa0@4?oooooo
oooo0:Gooooo0017ooooo`03oa0@4?nj^[[ooooo0:Kooooo0017ooooo`03oiRHV?lb<S;ooooo0:Ko
oooo000oooooo`05ofIVI_l0003o0000odA4A?o<c<`00oooool00ooMgMgo0000okZj^P04ooooo`Go
00001?ooool5o`0000;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2
o`000004oiRHV?l0003o410@oa0@40Go00001?ooool5o`0000?ooooo00GoIVIVo`000?l0003oA4A4
olc<c002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool5o`0000Kooooo00GoV9RHo`00
0?l0003oA4A4okZj^P03ooooo`0:oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o0000ohN7
Q`;o000000GoIVIVonk^k_ooooook^k^oeEEE@02o`000003odA4A?nj^[[ooooo03Wooooo000noooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool00omEEEGoMgMgodA4A006ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40;ooooo00Go0000olc<c?o^k^koQhN7
o`000005ooooo`03o`000?oooooooooo00Kooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05
o`000?nYZJWoooooohN7Qol000000oooool03Ol0003oEEEEonk^k_ooooooMgMgofIVI_ooooooEEEE
ogMgMoooooook^k^ogMgMol@4100>_ooool003kooooo00?o0000ooooooooool01Oooool01OoMgMgo
410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go410@ohN7Qoooooook^k^o`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000onk^k_ooool00_ooool00ol0
003oooooo`00000oooooo`00?_ooool00ol0003oooooooooo`05ooooo`05ofIVI_n7QhOooooooiRH
V?mEEED01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00onj^[[o410@
o`000002o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo000000Go
0000>_ooool003kooooo00[oIVIVogMgMoooooooooooohN7Qol0003oooooonk^k_l0003ok^k^0_oo
ool00ol0003ogMgMooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00003oooo
o`03o`000?lb<S;ogMgM00Oooooo00?o0000ooooooooool00_ooool01_mVIVKoMgMgoooooooooooo
QhN7o`0000Gooooo00?oc<c<o`000?ooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`0=o`000?mEEEGok^k^oooooomg
MgOoEEEEoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P0jooooo`00?_ooool02?o^k^koIVIVo`00
0?l0003oA4A4o`000?oooooo410@0_l000001?oooooo0000o`000?l@4104ooooo`03o`000?oooooo
oooo00Cooooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`000009oiRHV?oooooo
ooooonk^k_mEEEGo0000oa0@4?o<c<co000000;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B43oooo
o`03oa0@4?l0003o000000Cooooo00Kok^k^ofIVI_l0003o0000odA4A?l00003ooooo`04oc8b<_l0
003o0000oiRHV0Gooooo00?o0000ooooooooool01?ooool00ol@413o0000o`000003o`0000?ooooo
00Co410@o`000?oooooooooo0_l00003ooooo`09o`000?o<c<co410@o`000?mEEEGok^k^ooooooo^
k^koEEEE00;o000000?oA4A4onk^k_ooool0>Oooool0053ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`14ooooo`00D?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`14ooooo`00C_ooool00ol@413o
0000o`000008ooooo`03oa0@4?oooooooooo00kooooo0_l0000=ooooo`03oa0@4?oooooooooo01;o
oooo00?o410@o`000?l000005oooool00ol@413o0000ooooo`15ooooo`00l?ooool00?3ooooo003`
ooooo`00Toooool01OlQ8B7o0000o`000?m4A4CogMgM05Sooooo0010ooooo`03o`000?oooooooooo
05?ooooo00?oMgMgoc8b<_ooool0Eoooool0043ooooo00?o410@omgMgOooool0E?ooool00ol0003o
ooooooooo`1Fooooo`00?_ooool01Oo<c<co410@o`000?l0003oQhN700_ooooo1Ol00002ooooo`04
oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01Oooool01_nHV9So0000o`000?mgMgOo
410@o`0000[ooooo00GoIVIVo`000?l0003oA4A4olc<c002ooooo`04oa0@4?l0003o0000ooooo`;o
000000?o410@oooooonHV9P00_l000001OmgMgOo410@o`000?oooooo410@00Go00000oooool01_o^
k^koEEEEo`000?l@413oc<c<o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X7ooooo`03
oa0@4?l0003o000000;o000000Co410@oooooooooooooooo1Ol00002ooooo`Go00000oooool5o`00
00?ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`07onk^k_mEEEGo0000o`000?nHV9So
0000oa0@400Jooooo`00?_ooool01_lQ8B7oQhN7oc8b<_nYZJWoA4A4ohN7Q`cooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000olc<c?o^k^koQhN7o`00
000:ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Cooooo00KoEEEE
ogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@2Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mEEEGoMgMgoooo
ooo^k^koEEEEo`0001_ooooo000nooooo`06o`000?ooooooIVIVohN7QooMgMgo410@3?ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool01Ol@413oQhN7ooooooo^
k^ko000000[ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo
00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooo
ooooooooonk^k_l00002ooooo`03o`000?oooooooooo00;ooooo1_l00004ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0001_ooooo
000nooooo`06oa0@4?oMgMgoMgMgogMgMooooooo00003?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002?ooool00onj^[[o410@o`000002o`0000[ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o^[Zjoa0@4?l000000_l00004
ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`Ko0000
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01_l0003oooooooooooooooook^k^o`00
01_ooooo000nooooo`06ojVYZOm4A4CoV9RHodA4A?nHV9So410@3?ooool00ol0003oooooooooo`03
ooooo`05o`000?n7QhOoooooojVYZOl000002oooool00oo<c<co0000ooooo`09ooooo`06ofIVI_mg
MgOooooooooooon7QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?oc<c<o`00
0?ooool00oooool00ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000_oo
ool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PWooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01_mEEEGo
QhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl0000Kooooo`00?ooo
ool01OnHV9So0000o`000?l@413oc<c<00[ooooo00?o410@o`000?l000001?ooool00ol@413o0000
ogMgM`02o`000003oiRHV?oooooooooo00Oooooo00Co<S8bo`000?l0003oV9RH2_ooool01_o^k^ko
IVIVo`000?l0003oA4A4o`0000?ooooo00Go0000ogMgMol0003o0000oiRHV003ooooo`04oc8b<_l0
003o0000oiRHV0?ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`0:onk^k_mEEEGo0000ob4Q
8OnYZJWo0000oa0@4?ooooook^k^oeEEE@;o000000?oA4A4onk^k_ooool01_ooool00ol@413o0000
o`000003o`0000?ooooo00?o410@o`000?l000001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mEEEGo0000
oa0@4?o<c<co00006oooool0043ooooo00?o^[Zjoc8b<_ooool0>?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Wooooo0011ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0[ooooo`03oa0@4?nj^[[ooooo00Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06Oooool0053ooooo00?o410@ooooooooool09oooool00ol@413o0000ooooo`0/ooooo`04
okZj^_l@413o0000oa0@40Gooooo00?o410@ooooooooool00_ooool00ol@413o0000o`000005oooo
o`03oa0@4?l0003o0000017ooooo0_l0000Kooooo`00l?ooool00?3ooooo003`ooooo`00l?ooool0
0?3ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00l?ooool00?3ooooo003`ooooo`00l?oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 239}, {479, 0}} -> {-0.236838, -0.248785, \
0.00657775, 0.00657775}}]
}, Open  ]],

Cell[TextData[{
  "The potential is zero on the upper and side walls, as required by the \
boundary conditions. Along the bottom, the potential equals ",
  Cell[BoxData[
      \(TraditionalForm\`V(r)\)]],
  ". "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Spherical Geometry", "Section",
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Spherical Eigenmodes",
  FontWeight->"Bold"]], "Subsubsection",
  CellTags->"i:66"],

Cell[TextData[{
  "\tEigenmodes of  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " can also be determined analytically in spherical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((r, \[Theta], \[Phi])\)\(.\)\)\)]],
  " Here, we consider the Dirichlet eigenmodes inside a grounded spherical \
conducting shell of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". These eigenmodes satisfy the boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(a, \[Theta], \[Phi]) = 0\)]],
  ". The eigenmodes are separable in spherical coordinates:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(
          r, \[Theta], \[Phi]) = \(R(
            r)\) \(\[CapitalTheta](\[Theta])\) \(\[CapitalPhi](\[Phi])\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.52)"],

Cell[TextData[{
  "The eigenmode equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Psi]\_\[Alpha]/\[Psi]\_\[Alpha] = \
\[Lambda]\_\[Alpha]\)]],
  ", yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\^2\) \(R(
                    r)\)\)\) \(\[PartialD]\/\[PartialD]r\) \((\(r\^2\) \
\[PartialD]R\/\[PartialD]r)\) + \(1\/\(\(r\^2\) 
                  sin\[Theta]\ \ \(\[CapitalTheta](\[Theta])\)\)\) \(\
\[PartialD]\/\[PartialD]\[Theta]\) \((sin\[Theta] \
\[PartialD]\[CapitalTheta]\/\[PartialD]\[Theta])\) + \(1\/\(\(r\^2\) \(sin\^2\
\) \[Theta]\ \(\[CapitalPhi](\[Phi])\)\)\) \[PartialD]\^2 \[CapitalPhi]\/\
\[PartialD]\[Phi]\^2 = \[Lambda]\_\[Alpha]\)]],
  "."
}], "NE4",
  CellTags->"(4.3.53)"],

Cell[TextData[{
  "Following the approach of previous sub-subsections, one finds that this \
equation separates into three ODEs for ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[CapitalTheta]\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[PartialD]\^2 \[CapitalPhi]\/\[PartialD]\[Phi]\^2 \
= \(-m\^2\) \(\[CapitalPhi](\[Phi])\)\)\(,\)\)\)]]], "NE4",
  CellTags->"(4.3.54)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(sin\[Theta]\)\(\ \ \)\)\) \(\[PartialD]\/\
\[PartialD]\[Theta]\) \((sin\[Theta] \[PartialD]\[CapitalTheta]\/\[PartialD]\
\[Theta])\) - \(m\^2\/\(\(sin\^2\) \(\[Theta]\)\(\ \)\)\) \(\[CapitalTheta](\
\[Theta])\) = \(-\(l(l + 1)\)\)\ \(\[CapitalTheta](\[Theta])\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.55)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(1\/r\^2\) \(\[PartialD]\/\[PartialD]r\) \
\((\(r\^2\) \[PartialD]R\/\[PartialD]r)\)\  - \(l(l + 1)\)\/r\^2\ \(R(
              r)\) = \(\[Lambda]\_\[Alpha]\) \(R(r)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.56)"],

Cell[TextData[{
  "Here, we have introduced the separation constants ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  ", anticipating the form of the eigenvalues."
}], "Text"],

Cell[TextData[{
  "\tAs usual, Eqs. ",
  ButtonBox["(4.3.54)",
    ButtonData:>"(4.3.54)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(4.3.56)",
    ButtonData:>"(4.3.56)",
    ButtonStyle->"Hyperlink"],
  " are separate eigenvalue problems.  The solutions of the \[Theta] and \
\[Phi] equations were discussed in Sec. ",
  ButtonBox["3.2.4",
    ButtonData:>{"Chapter3.nb", "c:34"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalTheta](\[Theta])\) \
\(\[CapitalPhi](\[Phi])\)\  = \ \(Y\_\(l, \ m\)\)(\[Theta], \[Phi])\)]],
  ",   ",
  Cell[BoxData[
      FormBox[
        RowBox[{"l", ",", 
          
          RowBox[{\(m \[Element] \(\(Integers\ and\ \
l\)\(\[GreaterEqual]\)\)\), " ", "|", "m", "|", Cell[""]}]}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where\n\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(l, \ 
              m\)\)(\[Theta], \[Phi]) = \(\@\(\(\(2  l + 
                      1\)\/\(4  \[Pi]\)\) \(\((l - m)\)!\)\/\(\((l + \
m)\)!\)\)\) \(\(P\_l\%m\)(
            cos\[Theta])\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Phi]\)\)]],
  " \nis a spherical harmonic, and ",
  Cell[BoxData[
      \(TraditionalForm\`P\_l\%m\)]],
  " is an associated Legendre function, discussed in relation to Eqs. ",
  ButtonBox["(3.2.33)",
    ButtonData:>{"Chapter3.nb", "(3.2.33)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.34)",
    ButtonData:>{"Chapter3.nb", "(3.2.34)"},
    ButtonStyle->"Hyperlink"],
  ", and given in Table ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "Table 3.2"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Spherical Bessel Functions",
  FontWeight->"Bold"]], "Subsubsection",
  CellTags->"i:69"],

Cell[TextData[{
  "\tWe now determine the radial  eigenmodes defined by Eq. (",
  ButtonBox["4.3.56",
    ButtonData:>"(4.3.56)",
    ButtonStyle->"Hyperlink"],
  ") with boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`R(a) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R(0)\)]],
  " is finite.  The general solution of the ODE is given by ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "(we have added a negative sign to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\)]],
  ", anticipating that the eigenvalue will be negative):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DSolve[
      1/r^2\ D[r^2\ D[R[r], r], r]\  - \ 
          l \((l + 1)\)/r^2\ R[r]\  \[Equal] \ \(-\[Lambda]\_\[Alpha]\)\ R[
            r], R[r], r]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.31"],

Cell[BoxData[
    \({{R[
            r] \[Rule] \(BesselJ[1\/2\ \((\(-1\) - 2\ l)\), r\ \@\[Lambda]\_\
\[Alpha]]\ C[1]\)\/\@r + \(BesselJ[1\/2\ \((1 + 2\ l)\), r\ \@\[Lambda]\_\
\[Alpha]]\ C[2]\)\/\@r}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The solution is in terms of Bessel functions of order ",
  Cell[BoxData[
      \(TraditionalForm\`l + 1/2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-l\) - 1/2\)]],
  ". Since the ODE has a regular singular point at the origin, one of the two \
solutions is singular there.  The singular solution is  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(J\_\(\(-l\) - 1/2\)\)(
          r\ \@\(-\[Lambda]\_\[Alpha]\))\)/\ \@r\)]],
  ".  The other solution, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(J\_\(l + 1/2\)\)(
          r\ \@\(-\[Lambda]\_\[Alpha]\))\)/\ \@r\)]],
  " is well-behaved at the origin. These functions are called spherical \
Bessel functions.  Both sets of functions can be written in terms of \
trigonometric functions, as shown in the Tables ",
  ButtonBox["4.2",
    ButtonData:>"Table 4.2",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.3",
    ButtonData:>"Table 4.3",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[BoxData[{\(Table  4  .2 : \ 
      Spherical\ Bessel\ Functions\ That\ Are\ Finite\ at\ the\ Origin\), "\n\
", 
    TagBox[GridBox[{
          {
            StyleBox["l",
              FontSlant->"Italic"], \(\(\(J\_\(l + 1/2\)\) \((r)\)\)\/\@r\)},
          {"___", \(___  ___  ___  __\)},
          {"0", \(\(\@\(2\/\[Pi]\)\ Sin[r]\)\/r\)},
          {"1", \(\(\@\(2\/\[Pi]\)\ \((\(-Cos[r]\) + Sin[r]\/r)\)\)\/r\)},
          {
            "2", \(\(\@\(2\/\[Pi]\)\ \((\(-\(\(3\ Cos[r]\)\/r\)\) - 
                      Sin[r] + \(3\ Sin[r]\)\/r\^2)\)\)\/r\)},
          {
            "3", \(\(\@\(2\/\[Pi]\)\ \((Cos[
                        r] - \(15\ Cos[r]\)\/r\^2 + \(15\ Sin[r]\)\/r\^3 - \
\(6\ Sin[r]\)\/r)\)\)\/r\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 4.2"],

Cell[BoxData[{\(Table  4  .3 : \ 
      Spherical\ Bessel\ Functions\ That\ Are\ Singular\ at\ the\ Origin\), "\
\n", 
    TagBox[GridBox[{
          {
            StyleBox["l",
              
              FontSlant->
                "Italic"], \(\(\(J\_\(\(-l\) - 1/2\)\) \((r)\)\)\/\@r\)},
          {"___", \(___  ___  ___  __\)},
          {"0", \(\(\@\(2\/\[Pi]\)\ Cos[r]\)\/r\)},
          {
            "1", \(\(\@\(2\/\[Pi]\)\ \((\(-\(Cos[r]\/r\)\) - 
                      Sin[r])\)\)\/r\)},
          {
            "2", \(\(\@\(2\/\[Pi]\)\ \((\(-Cos[
                          r]\) + \(3\ Cos[r]\)\/r\^2 + \(3\ \
Sin[r]\)\/r)\)\)\/r\)},
          {
            "3", \(\(\@\(2\/\[Pi]\)\ \((\(-\(\(15\ Cos[
                                r]\)\/r\^3\)\) + \(6\ Cos[r]\)\/r + 
                      Sin[r] - \(15\ Sin[r]\)\/r\^2)\)\)\/r\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"Table 4.3"],

Cell[TextData[{
  "Examples from both sets of spherical Bessel functions are plotted in Cells \
",
  ButtonBox["4.32",
    ButtonData:>"Cell 4.32",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.33",
    ButtonData:>"Cell 4.33",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(Plot[
        Evaluate[Table[BesselJ[1/2\  + \ l, r]/\@r, {l, 0, 2}]], {r, 0, 15}, 
        PlotStyle \[Rule] {Red, Blue, Green}, 
        PlotLabel \[Rule] \*"\"\<\!\(J\_\(l\\\  + \\\ 1/2\)\)(r)/\!\(\@r\) \
for l=0,1,2\>\"", AxesLabel \[Rule] {"\<r\>", "\< \>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.32"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.119759 0.606053 [
[.15079 .10726 -3 -9 ]
[.15079 .10726 3 0 ]
[.27778 .10726 -3 -9 ]
[.27778 .10726 3 0 ]
[.40476 .10726 -3 -9 ]
[.40476 .10726 3 0 ]
[.53175 .10726 -3 -9 ]
[.53175 .10726 3 0 ]
[.65873 .10726 -6 -9 ]
[.65873 .10726 6 0 ]
[.78571 .10726 -6 -9 ]
[.78571 .10726 6 0 ]
[.9127 .10726 -6 -9 ]
[.9127 .10726 6 0 ]
[1.025 .11976 0 -6 ]
[1.025 .11976 10 6 ]
[.01131 .24097 -18 -4.5 ]
[.01131 .24097 0 4.5 ]
[.01131 .36218 -18 -4.5 ]
[.01131 .36218 0 4.5 ]
[.01131 .48339 -18 -4.5 ]
[.01131 .48339 0 4.5 ]
[.01131 .6046 -18 -4.5 ]
[.01131 .6046 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -72.2812 0 ]
[.5 .63053 72.2812 13.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .11976 m
.15079 .12601 L
s
[(2)] .15079 .10726 0 1 Mshowa
.27778 .11976 m
.27778 .12601 L
s
[(4)] .27778 .10726 0 1 Mshowa
.40476 .11976 m
.40476 .12601 L
s
[(6)] .40476 .10726 0 1 Mshowa
.53175 .11976 m
.53175 .12601 L
s
[(8)] .53175 .10726 0 1 Mshowa
.65873 .11976 m
.65873 .12601 L
s
[(10)] .65873 .10726 0 1 Mshowa
.78571 .11976 m
.78571 .12601 L
s
[(12)] .78571 .10726 0 1 Mshowa
.9127 .11976 m
.9127 .12601 L
s
[(14)] .9127 .10726 0 1 Mshowa
.125 Mabswid
.05556 .11976 m
.05556 .12351 L
s
.0873 .11976 m
.0873 .12351 L
s
.11905 .11976 m
.11905 .12351 L
s
.18254 .11976 m
.18254 .12351 L
s
.21429 .11976 m
.21429 .12351 L
s
.24603 .11976 m
.24603 .12351 L
s
.30952 .11976 m
.30952 .12351 L
s
.34127 .11976 m
.34127 .12351 L
s
.37302 .11976 m
.37302 .12351 L
s
.43651 .11976 m
.43651 .12351 L
s
.46825 .11976 m
.46825 .12351 L
s
.5 .11976 m
.5 .12351 L
s
.56349 .11976 m
.56349 .12351 L
s
.59524 .11976 m
.59524 .12351 L
s
.62698 .11976 m
.62698 .12351 L
s
.69048 .11976 m
.69048 .12351 L
s
.72222 .11976 m
.72222 .12351 L
s
.75397 .11976 m
.75397 .12351 L
s
.81746 .11976 m
.81746 .12351 L
s
.84921 .11976 m
.84921 .12351 L
s
.88095 .11976 m
.88095 .12351 L
s
.94444 .11976 m
.94444 .12351 L
s
.97619 .11976 m
.97619 .12351 L
s
.25 Mabswid
0 .11976 m
1 .11976 L
s
gsave
1.025 .11976 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .24097 m
.03006 .24097 L
s
[(0.2)] .01131 .24097 1 0 Mshowa
.02381 .36218 m
.03006 .36218 L
s
[(0.4)] .01131 .36218 1 0 Mshowa
.02381 .48339 m
.03006 .48339 L
s
[(0.6)] .01131 .48339 1 0 Mshowa
.02381 .6046 m
.03006 .6046 L
s
[(0.8)] .01131 .6046 1 0 Mshowa
.125 Mabswid
.02381 .02885 m
.02756 .02885 L
s
.02381 .05915 m
.02756 .05915 L
s
.02381 .08946 m
.02756 .08946 L
s
.02381 .15006 m
.02756 .15006 L
s
.02381 .18036 m
.02756 .18036 L
s
.02381 .21067 m
.02756 .21067 L
s
.02381 .27127 m
.02756 .27127 L
s
.02381 .30157 m
.02756 .30157 L
s
.02381 .33188 m
.02756 .33188 L
s
.02381 .39248 m
.02756 .39248 L
s
.02381 .42279 m
.02756 .42279 L
s
.02381 .45309 m
.02756 .45309 L
s
.02381 .51369 m
.02756 .51369 L
s
.02381 .544 m
.02756 .544 L
s
.02381 .5743 m
.02756 .5743 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -133.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5625 translate 1 -1 scale
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(J) show
69.000 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
73.188 16.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
77.375 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.562 16.000 moveto
(\\220) show
85.750 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.000 14.438 moveto
(H) show
97.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
103.000 14.438 moveto
(L) show
109.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.000 9.062 moveto
(\\217) show
123.188 9.062 moveto
(!!) show
128.000 9.062 moveto
(!) show
123.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
137.562 14.438 moveto
(for) show
161.562 14.438 moveto
(l) show
167.562 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
173.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
179.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
185.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
191.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
197.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
203.562 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.02499 .60329 L
.02605 .60322 L
.02729 .60308 L
.02846 .60289 L
.03053 .60242 L
.03279 .60171 L
.03527 .6007 L
.0379 .59936 L
.04262 .59628 L
.05205 .58753 L
.06244 .57402 L
.07293 .55651 L
.0842 .53364 L
.10458 .48305 L
.1458 .35612 L
.18551 .22614 L
.22371 .11872 L
.24338 .07622 L
.26435 .04283 L
.27464 .03119 L
.28005 .02634 L
.28576 .02215 L
.29077 .01926 L
.29342 .01802 L
.29627 .01692 L
.29888 .01611 L
.30127 .01553 L
.30241 .01531 L
.30366 .0151 L
.30477 .01496 L
.30593 .01485 L
.30715 .01476 L
.30827 .01472 L
.30947 .01472 L
.31078 .01475 L
.31192 .01482 L
.31314 .01492 L
.31429 .01506 L
.31533 .01521 L
.31789 .0157 L
.32067 .01641 L
.32571 .01815 L
.33102 .02061 L
.33664 .02387 L
.34672 .03123 L
.36629 .05015 L
.3846 .07166 L
.42343 .12059 L
.44318 .14292 L
Mistroke
.4536 .15313 L
.4647 .1625 L
.47553 .16998 L
.48534 .17522 L
.49007 .17722 L
.49519 .17897 L
.50002 .18024 L
.50446 .18108 L
.50693 .18141 L
.50918 .18163 L
.51042 .18172 L
.51108 .18176 L
.51177 .18179 L
.51305 .18182 L
.51423 .18184 L
.5153 .18183 L
.51646 .1818 L
.51755 .18175 L
.51855 .1817 L
.51967 .18162 L
.52088 .18151 L
.52333 .18122 L
.52605 .18079 L
.52851 .18032 L
.53405 .17894 L
.544 .17542 L
.55401 .17067 L
.56323 .16535 L
.58404 .15076 L
.62349 .11872 L
.64333 .10357 L
.66143 .09187 L
.67076 .0869 L
.68092 .08245 L
.68649 .08046 L
.69165 .07892 L
.69654 .07772 L
.69912 .0772 L
.70182 .07673 L
.70422 .07638 L
.70684 .07607 L
.70922 .07586 L
.71144 .07572 L
.71261 .07567 L
.71372 .07563 L
.71472 .07561 L
.7158 .0756 L
.71698 .0756 L
.71823 .07562 L
.71929 .07565 L
Mistroke
.72047 .0757 L
.72184 .07577 L
.72314 .07586 L
.72559 .07608 L
.72823 .07639 L
.7311 .0768 L
.73627 .07776 L
.74106 .07888 L
.75164 .08211 L
.7616 .086 L
.78021 .09509 L
.81878 .118 L
.83834 .12954 L
.8598 .14051 L
.86967 .14466 L
.88024 .14833 L
.89022 .151 L
.89454 .15191 L
.89931 .15272 L
.90412 .15335 L
.90676 .15361 L
.90923 .1538 L
.91036 .15387 L
.91154 .15393 L
.91256 .15397 L
.91365 .154 L
.91483 .15403 L
.91592 .15405 L
.91723 .15405 L
.91841 .15404 L
.91971 .15402 L
.92036 .154 L
.92108 .15398 L
.92354 .15386 L
.92492 .15378 L
.92641 .15367 L
.92909 .15343 L
.93436 .15278 L
.93918 .152 L
.94837 .15002 L
.95689 .14766 L
.97619 .14072 L
Mfstroke
0 0 1 r
.02381 .11976 m
.06244 .21426 L
.08255 .25651 L
.0932 .27575 L
.10458 .29349 L
.11531 .30725 L
.12507 .31711 L
.12977 .32092 L
.13488 .32435 L
.1397 .32692 L
.14415 .3287 L
.14658 .32943 L
.14881 .32995 L
.15004 .33018 L
.15138 .33038 L
.15264 .33052 L
.15382 .33061 L
.155 .33067 L
.15612 .33068 L
.15712 .33066 L
.1582 .33061 L
.15939 .33052 L
.16064 .33037 L
.16171 .33022 L
.16288 .33001 L
.16557 .32939 L
.16803 .32865 L
.17354 .3264 L
.17866 .3236 L
.1835 .32032 L
.19316 .31209 L
.20341 .30101 L
.22183 .27589 L
.25958 .21028 L
.29979 .13565 L
.31826 .10513 L
.33847 .07712 L
.35851 .05635 L
.36944 .04829 L
.37961 .04295 L
.38466 .04108 L
.38732 .04029 L
.39014 .03962 L
.3926 .03916 L
.3939 .03897 L
.3953 .0388 L
.39659 .03867 L
.39777 .03859 L
.39895 .03853 L
.40007 .03849 L
Mistroke
.40124 .03849 L
.40231 .0385 L
.40353 .03855 L
.40469 .03862 L
.40576 .0387 L
.40674 .0388 L
.40896 .03909 L
.41121 .03947 L
.41368 .03999 L
.41866 .04136 L
.42392 .04326 L
.42889 .04547 L
.43821 .05059 L
.45913 .06608 L
.49752 .10296 L
.51694 .12232 L
.53835 .14166 L
.54812 .1493 L
.55864 .15646 L
.56851 .16205 L
.57767 .1662 L
.58727 .16941 L
.59234 .17063 L
.59516 .17116 L
.59775 .17156 L
.60048 .17188 L
.60192 .17201 L
.60345 .17212 L
.60408 .17216 L
.60477 .17219 L
.60601 .17224 L
.60676 .17226 L
.60748 .17227 L
.60812 .17227 L
.60882 .17227 L
.61002 .17225 L
.6107 .17224 L
.61135 .17221 L
.61264 .17215 L
.61403 .17206 L
.61655 .17184 L
.61886 .17157 L
.62359 .17082 L
.62865 .16972 L
.63776 .16702 L
.6486 .1627 L
.65845 .15785 L
.6984 .13225 L
.73684 .10602 L
.7563 .09505 L
Mistroke
.76662 .09032 L
.77772 .08622 L
.78317 .08461 L
.78834 .08334 L
.79338 .08234 L
.79806 .08163 L
.80033 .08137 L
.80246 .08116 L
.80365 .08107 L
.80493 .08098 L
.80608 .08091 L
.80716 .08087 L
.80836 .08082 L
.80968 .08079 L
.81096 .08078 L
.81168 .08078 L
.81234 .08078 L
.81351 .0808 L
.81478 .08083 L
.81598 .08088 L
.81709 .08093 L
.81952 .08109 L
.82173 .08128 L
.82673 .08188 L
.83114 .0826 L
.83577 .08353 L
.84562 .08609 L
.85638 .08972 L
.89696 .10892 L
.93603 .12972 L
.97619 .14565 L
Mfstroke
0 1 0 r
.02381 .12048 m
.02499 .11977 L
.02605 .1198 L
.02729 .11986 L
.02846 .11993 L
.03053 .12012 L
.03279 .1204 L
.03527 .12081 L
.0379 .12134 L
.04262 .12257 L
.05205 .12605 L
.06244 .13138 L
.0842 .14709 L
.10458 .16616 L
.14335 .2078 L
.16306 .22817 L
.18458 .24711 L
.19454 .25418 L
.20517 .26026 L
.21033 .26263 L
.21519 .26449 L
.2199 .26593 L
.22428 .26695 L
.22653 .26735 L
.22894 .26769 L
.23031 .26784 L
.23161 .26795 L
.23278 .26802 L
.23405 .26808 L
.23528 .26811 L
.23599 .26811 L
.23665 .26811 L
.23734 .2681 L
.23797 .26808 L
.23867 .26805 L
.23941 .26801 L
.24063 .26793 L
.24177 .26783 L
.24436 .26751 L
.24677 .26712 L
.24904 .26666 L
.25329 .26556 L
.25787 .26403 L
.26284 .26197 L
.2723 .25693 L
.28271 .24975 L
.30375 .23056 L
.34409 .18111 L
.38292 .12851 L
.40267 .10411 L
Mistroke
.42419 .08167 L
.43419 .07315 L
.44483 .06558 L
.45487 .05996 L
.46396 .05618 L
.46885 .05467 L
.47152 .054 L
.47401 .05348 L
.47631 .05308 L
.47841 .05278 L
.48074 .05253 L
.48203 .05243 L
.48324 .05236 L
.48444 .05231 L
.48576 .05228 L
.48642 .05227 L
.48714 .05227 L
.48843 .0523 L
.48965 .05234 L
.49093 .05241 L
.49203 .05248 L
.49323 .05259 L
.49595 .0529 L
.49885 .05336 L
.50407 .05446 L
.50942 .05598 L
.51434 .0577 L
.52546 .06265 L
.54562 .07489 L
.58508 .1062 L
.62302 .13668 L
.6425 .14936 L
.65336 .15505 L
.66341 .1593 L
.67357 .16253 L
.67893 .16379 L
.68167 .16431 L
.68463 .16478 L
.6872 .16511 L
.68955 .16535 L
.69181 .16552 L
.69294 .16559 L
.69418 .16564 L
.69489 .16567 L
.69557 .16569 L
.69682 .16571 L
.69753 .16571 L
.69818 .16571 L
.69889 .1657 L
.69965 .16569 L
Mistroke
.7009 .16566 L
.70207 .16561 L
.70336 .16554 L
.70474 .16545 L
.70728 .16522 L
.70999 .16491 L
.71485 .16416 L
.72064 .16296 L
.72589 .1616 L
.74598 .1542 L
.76525 .14449 L
.78607 .13221 L
.82709 .10753 L
.84753 .09735 L
.85751 .09329 L
.8666 .09023 L
.87602 .08773 L
.88035 .08682 L
.88494 .08603 L
.88727 .0857 L
.88983 .08538 L
.89219 .08514 L
.89436 .08497 L
.8969 .08481 L
.89823 .08475 L
.89891 .08472 L
.89964 .0847 L
.90086 .08467 L
.902 .08466 L
.9027 .08466 L
.90336 .08466 L
.90459 .08467 L
.90575 .08469 L
.90699 .08473 L
.90816 .08477 L
.90923 .08482 L
.91184 .08499 L
.91432 .0852 L
.91925 .08576 L
.92462 .08659 L
.9342 .08861 L
.94308 .09105 L
.97619 .10397 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Jooooo`03o`000?oooooooooo05Kooooo1Ooo003`ooooo`006_ooool00ol0
003oooooooooo`1Cooooo`Coo`001?ooool4ool00>cooooo000Jooooo`03o`000?oooooooooo05;o
oooo00?oo`00ooooooooool02_ooool2ool00>[ooooo000Jooooo`03o`000?oooooooooo053ooooo
0_oo000?ooooo`03ool00?oooooooooo0>Oooooo000Jooooo`03o`000?oooooooooo04oooooo00?o
o`00ooooooooool04?ooool00ooo003oooooooooo`3Vooooo`006_ooool2o`0004oooooo00?oo`00
ooooooooool04_ooool00ooo003oooooooooo`3Uooooo`006_ooool00ol0003oooooooooo`1=oooo
o`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0i?ooool001[ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo0>?ooooo000Jooooo`03o`00
0?oooooooooo04_ooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`08ooooo`[o003o
d?ooool001[ooooo00?o0000ooooooooool0B_ooool00ooo003oooooooooo`0Jooooo`03ool00?oo
oooooooo00Cooooo0ol00?l:ooooo`?o003ocOooool001[ooooo00?o0000ooooooooool0B_ooool0
0ooo003oooooooooo`0Kooooo`04ool00?ooooooooooooooo`;o003o4?ooool2o`00ol_ooooo000J
ooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool07Oooool00ooo003oooooo`00o`0D
ooooo`03o`00oooooooooooo0<Sooooo000Jooooo`03o`000?oooooooooo04Sooooo00?oo`00oooo
ooooool07oooool00ol00?ooooooooooo`0Dooooo`;o003o2oooool7o`3o0;Kooooo000Jooooo`03
o`000?oooooooooo04Sooooo00?oo`00ooooooooool07_ooool00ol00?ooooooool0000Gooooo`03
o`00oooooooooooo00Gooooo1?l0o`06ooooo`Go0?l0/Oooool001[ooooo0_l00018ooooo`03ool0
0?oooooooooo01kooooo00Go003oooooooooooooooooool0000Gooooo`;o003o0oooool2o`3o00oo
oooo0_l0o`2_ooooo`006_ooool00ol0003oooooooooo`16ooooo`03ool00?oooooooooo01kooooo
00?o003oooooooooool00oooool00ooo003oooooooooo`0Fooooo`?o0?l04oooool00ol0o`3ooooo
ooooo`2/ooooo`006_ooool00ol0003oooooooooo`16ooooo`03ool00?oooooooooo01gooooo00?o
003oooooooooool01Oooool00ooo003oooooooooo`0Dooooo`03o`3o0?oooooo003o01Gooooo0_l0
o`2/ooooo`006_ooool00ol0003oooooooooo`15ooooo`03ool00?oooooooooo01gooooo00?o003o
ooooooooool01oooool00ooo003oooooooooo`0Aooooo`;o0?l00oooool2o`00oaGooooo0ol0o`2Y
ooooo`006_ooool00ol0003oooooooooo`15ooooo`03ool00?oooooooooo01cooooo00?o003ooooo
ooooool02Oooool00ooo003oooooooooo`0>ooooo`;o0?l01oooool00ol00?ooooooooooo`0Eoooo
o`;o0?l0Yoooool001[ooooo00?o0000ooooooooool0A?ooool00ooo003oooooooooo`0Looooo`03
o`00oooooooooooo00[ooooo00?oo`00ooooooooool03Oooool00ol0o`3oooooooooo`08ooooo`03
o`00oooooooooooo01Kooooo0_l0o`2Uooooo`006_ooool00ol0003oooooooooo`13ooooo`03ool0
0?oooooooooo01cooooo00?o003oooooooooool03?ooool00ooo003oooooooooo`0;ooooo`03o`3o
0?oooooooooo00[ooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`0Zooooo`ooo`00
JOooool001[ooooo00?o0000ooooooooool08oooool5o`0001_ooooo00?oo`00ooooooooool01ooo
ool2o`000003oa0@4?oooooooooo013ooooo00?o003oooooooooool03Oooool01ooo003oooooonk^
k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0o`3oooooooooo`0<ooooo`03o`00oooooooooooo00co
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`3o0?oooooooooo01Sooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool3ool000oooooo0ooo0006ooooo`Co0000
00?o410@ooooooooool01?l00006o`00oaOooooo1?l000000ol@413oooooooooo`02ooooo`;o0000
00?o410@ooooooooool0:_ooool001[ooooo00?o0000ooooooooool08oooool01OnHV9So8B4Qonk^
k_ooooooA4A401[ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`00
oooooooooooo00oooooo00Koo`00oeEEEOmgMgOooooooiRHV?lQ8B44ooooo`03o`3o0?oooooooooo
00kooooo00?o003oooooooooool02oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Oooooo00?o0?l0
ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_oo
000Eooooo`Coo`001?ooool01?l0003oooooooooooooool5o`00o`03odA4A?oooooooooo00?ooooo
2?l00?lAooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool001[ooooo00?o
0000ooooooooool09?ooool00onHV9So8B4Qonk^kP0Kooooo`03ool00?oooooooooo00Kooooo1Ol0
000@ooooo`03o`00oooooooooooo017ooooo00Goo`00ooooooooooooooooo`000003ooooo`03o`3o
0?oooooooooo013ooooo00?o003oooooooooool02_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0?l0ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03oa0@4?ooooooo`0000;o
o`006oooool2ool00003ooooool00?oo003o00?o003o0_ooool00onHV9So8B4Qonk^kP0>ooooo`?o
003o1ooooolBo`3o02_ooooo000Jooooo`;o00009_ooool00onHV9So8B4Qonk^kP0Iooooo`03ool0
0?oooooooooo00Oooooo00CoA4A4omgMgOoooooo00004?ooool00ol00?ooooooooooo`0Booooo`05
ool00?nHV9SooooooiRHV?lQ8B400_ooool00ol0o`3oooooooooo`0Booooo`03o`00oooooooooooo
00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P09ooooo`;o0?l06?ooool00ol0003oooooooooo`02
ooooo`05o`000?oo003oooooooooool000006oooool3o`00o`03ool00?l0003ooooo00Gooooo00?o
V9RHob4Q8Oo^k^h04?ooool2o`00o`Go0?l01oooool00ol0003oooooooooo`02ooooo`04odA4A?oM
gMgoooooo`0000;ooooo0ol0o`0Xooooo`006_ooool00ol0003oooooooooo`0Vooooo`03ogMgMomV
IVKooooo01Sooooo00?oo`00ooooooooool01oooool01?oMgMgoEEEEooooool0000?ooooo`03o`00
oooooooooooo01?ooooo00Oo0000ool00?l0003o410@olc<c?oooooo0?l001Kooooo00?o003ooooo
ooooool02?ooool01Oo<c<co0000o`000?l0003oc<c<00_ooooo00?o0?l0ooooooooool05Oooool0
1?l0003oooooooooooooool2ool000?ooooo00?o0000ooooooooool06?ooool00ol00?oooooooooo
o`02ooooo`;oo`001_ooool00omgMgOoIVIVooooo`0>ooooo`?o0?l00_l00?l:ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMoeEEEOoooooo00001Oooool2o`3o02Kooooo000Jooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`09ooooo`03ogMgMoo<
c<co000000oooooo00?o003oooooooooool04oooool00omEEEGoQhN7ool00002ooooo`03o`3o0?oo
oooooooo01Kooooo00?o003oooooooooool01oooool01Ol@413o^[Zjoooooonj^[[o410@00cooooo
00?o0?l0ooooooooool05?ooool01_l0003ooooooooooooo003ooooooa0@40?ooooo00?o410@oooo
ooooool05_ooool2o`00o`Gooooo00Co0000oooooooo003oo`001Oooool00ol0003oooooooooo`0<
ooooo`03o`3o0?oooooooooo00?ooooo0_l00?l8ooooo`03o`000?oooooooooo00?ooooo00?oMgMg
olc<c?l000001oooool3o`3o02?ooooo000Jooooo`03o`000?oooooooooo02?ooooo00Go0000okZj
^_ooooooV9RHoa0@400Hooooo`03ool00?oooooooooo00Wooooo00?ok^k^odA4A?l000003_ooool0
0ol00?ooooooooooo`0Dooooo`05omgMgOl@413oV9RHool00?l0o`006_ooool00ol00?oooooooooo
o`06ooooo`05o`000?nj^[[ooooookZj^_l000003Oooool00ol0o`3oooooooooo`0Cooooo`03o`00
0?oo003oo`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`;o003o1oooool01?l0003o
ooooooooooooool2ool00004okZj^_ooooooV9RHoa0@40cooooo0_l0o`08ooooo`?o003o1Oooool0
0ol0003oooooooooo`03ooooo`03onk^k_m4A4Co000000[ooooo0_l0o`0Qooooo`006_ooool00ol0
003oooooooooo`0Sooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06?ooool00ooo003oooooooooo`0:
ooooo`03ogMgMol0003ooooo00cooooo00?o003oooooooooool05_ooool01?o<c<coA4A4o`3o0?oo
000Kooooo`03o`00oooooooooooo00Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0>ooooo`03o`3o
0?oooooooooo013ooooo00?oEEEEofIVI_oo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Co
oooo0_l00?l7ooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHool00?l0003o8B4Qolc<c00:oooo
o`;o0?l03Oooool2o`00o`04oooooomEEEGoIVIVo`0000Kooooo00?oMgMgo`000?ooool02oooool3
o`3o01kooooo000Jooooo`03o`000?oooooooooo03oooooo00?oo`00ooooooooool06Oooool00ol0
0?ooooooooooo`0Hooooo`04o`3o0?ooooooooooool001_ooooo00?o003oooooooooool06?ooool2
o`3o013ooooo0_oo000Looooo`;o003o4_ooool2ool000Wooooo0_l0o`0Aooooo`;o003o6Oooool0
0ol0o`3oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0oooooo`03ool00?oooooooooo
01Wooooo00?o003oooooooooool06?ooool01?l0o`3ooooooooooooo000Looooo`03o`00oooooooo
oooo01Wooooo00?o0?l0ooooooooool03?ooool00ooo003oooooooooo`0Kooooo`03o`00oooooooo
oooo01Cooooo0_oo0005ooooo`;o0?l05Oooool2o`00ocGooooo000Jooooo`03o`000?oooooooooo
03kooooo00?oo`00ooooooooool06Oooool00ol00?ooooooooooo`0Hooooo`03o`3o0?oooooooooo
00;ooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`0Iooooo`03o`3o0?oooooooooo
00Wooooo0_oo000Mooooo`03o`00oooooooooooo01Oooooo00Goo`00ooooooooooooooooo`3o000I
ooooo`;o003o:?ooool00ol@413o0000o`000003o`0000Gooooo000Jooooo`03o`000?oooooooooo
03kooooo00?oo`00ooooooooool06?ooool00ol00?ooooooooooo`0Hooooo`03o`3o0?oooooooooo
00Cooooo00?oo`00ooooooooool06_ooool00ol00?ooooooooooo`0Iooooo`;o0?l02?ooool00ooo
003oooooooooo`0Kooooo`;o003o6oooool00ooo003o0?l0o`3o000Looooo`;o003o:?ooool00ol0
003oooooooooo`06ooooo`006_ooool00ol0003oooooooooo`0mooooo`03ool00?oooooooooo01Wo
oooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`06ooooo`03ool00?oooooooooo01[o
oooo00?o003oooooooooool06_ooool00ol0o`3oooooooooo`03ooooo`;oo`007Oooool00ol00?oo
ooooooooo`0Jooooo`;o0?l000?oooooool00?oo00007Oooool2o`00obKooooo00?o0000oooooooo
ool01_ooool001;ooooo2?l00006o`3o03[o000000?oo`00o`000?l000006?l000000ol00?oo0000
o`00000Ho`000003o`3o0?l0003o000000Oo000000?oo`00o`000?l000006_l000000ol00?oo0000
o`00000Jo`000005o`3o0?l0003o0000o`000?oo00007_l000000ol00?oo0000o`00000Jo`000003
o`3o0?l0003o000000?o000000?oo`00o`000?l000007?l000000ol00?oo0000o`00000Go`0000co
oooo00?o0000ooooooooool01_ooool001[ooooo00?o003oooooooooool00oooool3o`3o0003oooo
ool0003ooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooool00007ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0o`3oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Goo`00ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool01Ol00?oooooooooooooooooo000000Wooooo00?o0000oooo
ooooool02?ooool01ol0003ooooooooooooooooo0?l0oooooooo00000oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`00o`;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o0?l0
1?ooool00ol0003oooooooooo`02ool000Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooooooo`;o003o1?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01;ooooo00?o0000oc8b<_oMgMd01_ooool001[ooooo00?o0000o`00ooooool0
1_ooool2o`3o01kooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?oo`00ooooooooool06oooool01?l00?ooooooooooool0000Iooooo`;o
0?l03Oooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01Oooooo00Co0000ooooool0
o`3o0?l02oooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo0_l00?lPoooo
o`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool001[ooooo00?o0000o`00ooooool02?ooool00ol0
o`3oooooooooo`0aooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool05oooool00ol0
o`3oooooooooo`0<ooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool06?ooool01?oo
003oooooooooool0o`0Jooooo`03o`00oooooooooooo01Wooooo00?o0?l0ooooooooool03?ooool2
ool001kooooo0_l00?lXooooo`006_ooool00ol0003o003oooooo`09ooooo`;o0?l0<?ooool00ooo
003oooooooooo`0Hooooo`03o`00oooooooooooo01Oooooo00?o0?l0ooooooooool03Oooool00ooo
003oooooooooo`0Kooooo`03o`00oooooooooooo01Gooooo0_oo0004ooooo`03o`3o0?oooooooooo
01Gooooo0_l00?lJooooo`;o0?l04Oooool3ool001gooooo0ol00?lUooooo`006_ooool00ol0003o
ooooo`00o`0;ooooo`03o`3o0?oooooooooo02gooooo00?oo`00ooooooooool05oooool00ol00?oo
ooooooooo`0Gooooo`03o`3o0?oooooooooo00oooooo00?oo`00ooooooooool06oooool00ol00?oo
ooooooooo`0Cooooo`03ool00?oooooooooo00Gooooo0_l0o`0Dooooo`03o`00oooooooooooo01So
oooo0_l0o`0Fooooo`;oo`007_ooool2o`00ob?ooooo000Jooooo`03o`000?oooooo003o00cooooo
0_l0o`0]ooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool05_ooool00ol0o`3ooooo
ooooo`0Aooooo`03ool00?oooooooooo01_ooooo00?o003oooooooooool04Oooool00ooo003ooooo
ooooo`08ooooo`03o`3o0?oooooooooo00oooooo0_l00?lJooooo`03o`3o0?oooooooooo01Sooooo
0_oo000Nooooo`;o003o8Oooool001[ooooo00Co0000oooooooooooo003o3Oooool00ol0o`3ooooo
ooooo`0Yooooo`03ool00?oooooooooo01Oooooo00?o003oooooooooool05_ooool00ol0o`3ooooo
ooooo`0Cooooo`03ool00?oooooooooo01_ooooo0_l00?l@ooooo`03ool00?oooooooooo00[ooooo
0_l0o`0=ooooo`;o003o6_ooool2o`3o01gooooo00?oo`00ooooooooool07Oooool3o`00o`03ool0
0?oooooooooo01_ooooo000Jooooo`04o`000?ooooooooooo`00o`kooooo00?o0?l0ooooooooool0
:?ooool00ooo003oooooooooo`0Gooooo`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool0
5Oooool00ooo003oooooooooo`0Looooo`;o003o3Oooool00ooo003oooooooooo`0=ooooo`03o`3o
0?oooooooooo00Wooooo00?o003oooooooooool06?ooool2o`3o023ooooo0ooo000Kooooo`?oo`00
00?oooooo`00ooooool07?ooool001[ooooo00Co0000oooooooooooo003o3oooool2o`3o02Sooooo
00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Fooooo`03o`3o0?oooooooooo01Kooooo
00?oo`00ooooooooool07Oooool00ol00?ooooooooooo`09ooooo`03ool00?oooooooooo00oooooo
0_l0o`07ooooo`;o003o6Oooool2o`3o02Gooooo1?oo000Booooo`Goo`008_ooool001[ooooo0_l0
0002ooooo`03o`00oooooooooooo00kooooo00?o0?l0ooooooooool09?ooool00ooo003ooooooooo
o`0Gooooo`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool06?ooool2ool001kooooo00?o
003oooooooooool01_ooool2ool001Cooooo00?o0?l0ooooooooool00_ooool2o`00oaWooooo0_l0
o`0[ooooo`Coo`002Oooool5ool002Oooooo000Jooooo`05o`000?ooooooooooooooool00?l04Ooo
ool00ol0o`3oooooooooo`0Sooooo`03ool00?oooooooooo01Kooooo00?o003oooooooooool05Ooo
ool00ol0o`3oooooooooo`0Kooooo`03ool00?oooooooooo01cooooo00?o003oooooooooool00ooo
ool2ool001Oooooo0ol0o`000ol00?ooooooooooo`0Fooooo`?o0?l0<Oooool9ool002cooooo000J
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool03oooool00ol0o`3oooooooooo`0R
ooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool05Oooool00ol0o`3oooooooooo`0M
ooooo`03ool00?oooooooooo01cooooo0ol00?l00oooooooo`00ooooo`0Iooooo`;o003o0ol0o`0C
ooooo`?o0?l0JOooool001[ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0@oooo
o`03o`3o0?oooooooooo023ooooo00?oo`00ooooooooool05_ooool00ol00?ooooooooooo`0Doooo
o`03o`3o0?oooooooooo01oooooo00?oo`00ooooooooool07Oooool00ooo003o003oo`00o`0Ioooo
o`03o`00oooooooooooo00?ooooo0_l0o`0?ooooo`;o0?l0K?ooool001[ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooooooo01oooooo00?oo`00oooooooo
ool05Oooool00ol00?ooooooooooo`0Dooooo`03o`3o0?oooooooooo027ooooo00?oo`00oooooooo
ool06_ooool2ool000?ooooo00?o003oooooooooool04oooool3o`00o`Sooooo1_l0o`000ooooooo
0?l0o`3o0006o`3o06kooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
4Oooool00ol0o`3oooooooooo`0Nooooo`03ool00?oooooooooo01Gooooo00?o003oooooooooool0
5?ooool00ol0o`3oooooooooo`0Rooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
1?ooool3o`00o`oooooo0ol00?lAooooo`;o0?l0MOooool001[ooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooooooo01gooooo00?oo`00ooooooooool05Ooo
ool00ol00?ooooooooooo`0Dooooo`03o`3o0?oooooooooo02Cooooo0_oo000Fooooo`;oo`002_oo
ool5o`00o`Cooooo1_l00?n;ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00oooooooo
oooo017ooooo00?o0?l0ooooooooool07?ooool00ooo003oooooooooo`0Eooooo`03o`00oooooooo
oooo01?ooooo00?o0?l0ooooooooool09oooool2ool001?ooooo00?oo`00ooooooooool03oooool5
o`00oi3ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o003oooooooooool04_ooool00ol0
o`3oooooooooo`0Kooooo`03ool00?oooooooooo01Cooooo00?o003oooooooooool04oooool00ol0
o`3oooooooooo`0Zooooo`?oo`003_ooool2ool00:Oooooo000Jooooo`;o00001Oooool00ol00?oo
ooooooooo`0Cooooo`03o`3o0?oooooooooo01Wooooo00?oo`00ooooooooool05Oooool00ol00?oo
ooooooooo`0Booooo`03o`3o0?oooooooooo02kooooo1?oo0005ooooo`Goo`00ZOooool001[ooooo
00?o0000ooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo01Sooooo
00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo037ooooo
1_oo002^ooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo01Cooooo00?o
0?l0ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03o`00oooooooooooo01;ooooo00?o
0?l0ooooooooool0i_ooool001[ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`0D
ooooo`03o`3o0?oooooooooo01Gooooo00?oo`00ooooooooool05?ooool00ol00?ooooooooooo`0B
ooooo`03o`3o0?oooooooooo0>Oooooo000Jooooo`03o`000?oooooooooo00Kooooo00?o003ooooo
ooooool05Oooool00ol0o`3oooooooooo`0Dooooo`03ool00?oooooooooo01Cooooo00?o003ooooo
ooooool04Oooool00ol0o`3oooooooooo`3Xooooo`006_ooool00ol0003oooooooooo`06ooooo`03
o`00oooooooooooo01Kooooo00?o0?l0ooooooooool04oooool00ooo003oooooooooo`0Cooooo`03
o`00oooooooooooo017ooooo00?o0?l0ooooooooool0jOooool001[ooooo00?o0000ooooooooool0
1oooool00ol00?ooooooooooo`0Fooooo`03o`3o0?oooooooooo017ooooo00?oo`00ooooooooool0
4oooool00ol00?ooooooooooo`0Booooo`03o`3o0?oooooooooo0>Wooooo000Jooooo`03o`000?oo
oooooooo00Oooooo00?o003oooooooooool05oooool00ol0o`3oooooooooo`0@ooooo`03ool00?oo
oooooooo01?ooooo00?o003oooooooooool04Oooool00ol0o`3oooooooooo`3Zooooo`006_ooool0
0ol0003oooooooooo`08ooooo`03o`00oooooooooooo01Oooooo00?o0?l0ooooooooool03oooool0
0ooo003oooooooooo`0Booooo`03o`00oooooooooooo017ooooo00?o0?l0ooooooooool0joooool0
01[ooooo00?o0000ooooooooool02?ooool00ol00?ooooooooooo`0Hooooo`;o0?l03_ooool00ooo
003oooooooooo`0Cooooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0k?ooool001[o
oooo0_l00009ooooo`03o`00oooooooooooo01[ooooo00?o0?l0ooooooooool02oooool00ooo003o
ooooooooo`0Booooo`03o`00oooooooooooo013ooooo00?o0?l0ooooooooool0kOooool001[ooooo
00?o0000ooooooooool02Oooool00ol00?ooooooooooo`0Jooooo`03o`3o0?oooooooooo00[ooooo
00?oo`00ooooooooool04_ooool00ol00?ooooooooooo`0?ooooo`03o`3o0?oooooooooo0>kooooo
000Jooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool06oooool00ol0o`3ooooooooo
o`08ooooo`03ool00?oooooooooo01;ooooo00?o003oooooooooool04?ooool00ol0o`3ooooooooo
o`3^ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo01_ooooo00?o0?l0
ooooooooool01oooool00ooo003oooooooooo`0Booooo`03o`00oooooooooooo00oooooo00?o0?l0
ooooooooool0koooool001[ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`0Loooo
o`03o`3o0?oooooooooo00Kooooo00?oo`00ooooooooool04Oooool00ol00?ooooooooooo`0?oooo
o`03o`3o0?oooooooooo0?3ooooo000Jooooo`03o`000?oooooooooo00_ooooo00?o003ooooooooo
ool07?ooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?o003ooooooooo
ool03oooool00ol0o`3oooooooooo`3aooooo`006_ooool00ol0003oooooooooo`0;ooooo`03o`00
oooooooooooo01cooooo00?o0?l0ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03o`00
oooooooooooo00kooooo00?o0?l0ooooooooool0l_ooool00004oc8b<_l0003o<S8bonk^kPGooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01cooooo
00?o0?l0ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03o`00oooooooooooo00kooooo
00?o0?l0ooooooooool0loooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01go
oooo00Go0?l0ooooooooooooooooool0000Cooooo`03o`00oooooooooooo00gooooo00?o0?l0oooo
ooooool0m?ooool000?ooooo00?o410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo00gooooo00?o003oooooooooool07Oooool01?l0o`3ooooooooooooo000Boooo
o`03o`00oooooooooooo00gooooo00?o0?l0ooooooooool0mOooool000?ooooo00?o0000oooooooo
ool02oooool00onHV9So8B4Qonk^kP06ooooo`?o00003Oooool00ol00?ooooooooooo`0Nooooo`03
o`3o0?ooooooo`0001;ooooo00?o003oooooooooool03?ooool00ol0o`3oooooooooo`3fooooo`00
0oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
3_ooool00ol00?ooooooooooo`0Nooooo`03o`3o0?oooooooooo013ooooo00?o003oooooooooool0
3?ooool00ol0o`3oooooooooo`3gooooo`000oooool00ol@413oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol00?ooooooooooo`0Nooooo`03ool00?l0
o`3o0?l000oooooo00?o003oooooooooool02oooool2o`3o0?[ooooo00001?nHV9SooooooiRHV?mg
MgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0?ooooo`03o`00
oooooooooooo01gooooo00?oo`00ooooooooool00_l0o`0=ooooo`03o`00oooooooooooo00[ooooo
00?o0?l0ooooooooool0n_ooool00004oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo00oooooo00?o003oooooooooool07?ooool00ooo003o
ooooooooo`03ooooo`;o0?l02_ooool00ol00?ooooooooooo`0:ooooo`03o`3o0?oooooooooo0?_o
oooo000Jooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool06oooool00ooo003ooooo
ooooo`05ooooo`03o`3o0?oooooooooo00Oooooo00?o003oooooooooool02?ooool2o`3o0?kooooo
000Jooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool06oooool00ooo003ooooooooo
o`06ooooo`?o0?l01Oooool00ol00?ooooooooooo`07ooooo`;o0?l0ooooool1ooooo`006_ooool0
0ol0003oooooooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?oo`00ooooooooool02_ooool2
o`3o00?ooooo00?o003oooooooooool01?ooool3o`3o0?oooooo0oooool001[ooooo00?o0000oooo
ooooool04Oooool00ol00?ooooooooooo`0Iooooo`03ool00?oooooooooo00cooooo2_l0o`3ooooo
o`Kooooo000Jooooo`;o00004oooool00ol00?ooooooooooo`0Hooooo`03ool00?oooooooooo00go
oooo00?o003oooooooooool0ooooool<ooooo`006_ooool00ol0003oooooooooo`0Booooo`03o`00
oooooooooooo01Oooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`3oooooo`cooooo
000Jooooo`03o`000?oooooooooo01?ooooo00?o003oooooooooool05_ooool00ooo003ooooooooo
o`0=ooooo`03o`00oooooooooooo0?oooooo3Oooool001[ooooo00?o0000ooooooooool04oooool0
0ol00?ooooooooooo`0Fooooo`03ool00?oooooooooo00gooooo00?o003oooooooooool0ooooool=
ooooo`006_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo01Cooooo00?oo`00oooo
ooooool03Oooool00ol00?ooooooooooo`3oooooo`kooooo000Jooooo`03o`000?oooooooooo01Go
oooo00?o003oooooooooool04oooool00ooo003oooooooooo`0<ooooo`03o`00oooooooooooo0?oo
oooo3oooool001[ooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`0Booooo`03ool0
0?oooooooooo00_ooooo00?o003oooooooooool0ooooool@ooooo`006_ooool00ol0003ooooooooo
o`0Gooooo`03o`00oooooooooooo013ooooo00?oo`00ooooooooool03?ooool00ol00?oooooooooo
o`3ooooooa3ooooo000Jooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool04?ooool0
0ooo003oooooooooo`0;ooooo`03o`00oooooooooooo0?oooooo4Oooool001[ooooo00?o0000oooo
ooooool06?ooool00ol00?ooooooooooo`0?ooooo`03ool00?oooooooooo00[ooooo00?o003ooooo
ooooool0oooooolBooooo`006_ooool2o`0001[ooooo00?o003oooooooooool03_ooool00ooo003o
ooooooooo`09ooooo`03o`00oooooooooooo0?oooooo4oooool001[ooooo00?o0000ooooooooool0
6Oooool00ol00?ooooooooooo`0=ooooo`03ool00?oooooooooo00Wooooo00?o003oooooooooool0
oooooolDooooo`006_ooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo00cooooo00?o
o`00ooooooooool02?ooool00ol00?ooooooooooo`3ooooooaGooooo000Jooooo`03o`000?oooooo
oooo01_ooooo00?o003oooooooooool02oooool00ooo003oooooooooo`07ooooo`03o`00oooooooo
oooo0?oooooo5_ooool001[ooooo00?o0000ooooooooool07?ooool00ol00?ooooooooooo`09oooo
o`03ool00?oooooooooo00Oooooo00?o003oooooooooool0oooooolGooooo`006_ooool00ol0003o
ooooooooo`0Mooooo`;o003o2Oooool00ooo003oooooooooo`06ooooo`03o`00oooooooooooo0?oo
oooo6?ooool001[ooooo00?o0000ooooooooool07oooool00ol00?ooooooooooo`06ooooo`03ool0
0?oooooooooo00Cooooo0_l00?oooooooa_ooooo000Jooooo`03o`000?oooooooooo023ooooo0_l0
0?l5ooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool0oooooolKooooo`006_ooool0
0ol0003oooooooooo`0Rooooo`03o`00oooooooooooo00;ooooo00?oo`00ooooooooool00_ooool2
o`00oooooooo7_ooool001[ooooo00?o0000ooooooooool08oooool9o`00oooooooo8?ooool001[o
oooo0_l0000Wooooo`03ool00?oooooooooo0?oooooo8oooool001[ooooo00?o0000ooooooooool0
9_ooool00ooo003oooooooooo`3oooooob?ooooo000Jooooo`03o`000?oooooooooo02Kooooo00?o
o`00ooooooooool0oooooolSooooo`006_ooool00ol0003oooooooooo`0Uooooo`03ool00?oooooo
oooo0?oooooo9?ooool001[ooooo00?o0000ooooooooool09Oooool00ooo003oooooooooo`3ooooo
obCooooo000Jooooo`03o`000?oooooooooo02Gooooo00?oo`00ooooooooool0oooooolTooooo`00
6_ooool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo0?oooooo9Oooool00004oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0Tooooo`03ool00?oooooooooo0?oooooo9Oooool00004oiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ooo003ooooo
ooooo`3oooooobGooooo0003ooooo`03oa0@4?oooooooooo00Wooooo1Ol00006ooooo`?o00009?oo
ool00ooo003oooooooooo`3oooooobGooooo0003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`0Sooooo`03ool00?oooooooooo0?oooooo9_oo
ool000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oo
oooooooo02?ooooo00?oo`00ooooooooool0oooooolVooooo`000oooool00ol@413oooooooooo`0:
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool08oooool00ooo003oooooooooo`3o
ooooobKooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool08_ooool00ooo003oooooooooo`3oooooobOooooo00001?lb<S;o0000oc8b<_o^k^h=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool08_ooool00ooo003oooooooooo`3o
ooooobOooooo000Jooooo`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool0oooooolWoooo
o`006_ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo0?oooooo:?ooool001[ooooo
00?o0000ooooooooool08Oooool00ooo003oooooooooo`3oooooobSooooo000Jooooo`03o`000?oo
oooooooo027ooooo00?oo`00ooooooooool0oooooolXooooo`006_ooool2o`00027ooooo00?oo`00
ooooooooool0oooooolYooooo`006_ooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo
0?oooooo:Oooool001[ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`3oooooobWo
oooo000Jooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool0oooooolZooooo`006_oo
ool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo0?oooooo:_ooool001[ooooo00?o0000
ooooooooool07oooool00ooo003oooooooooo`3oooooob[ooooo000Jooooo`03o`000?oooooooooo
01kooooo00?oo`00ooooooooool0ooooool[ooooo`006_ooool00ol0003oooooooooo`0Nooooo`03
ool00?oooooooooo0?oooooo:oooool001[ooooo00?o0000ooooooooool07_ooool00ooo003ooooo
ooooo`3oooooob_ooooo000Jooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool0oooo
ool/ooooo`006_ooool2o`0001kooooo00?oo`00ooooooooool0ooooool/ooooo`006_ooool00ol0
003oooooooooo`0Mooooo`03ool00?oooooooooo0?oooooo;?ooool001[ooooo00?o0000oooooooo
ool07Oooool00ooo003oooooooooo`3oooooobcooooo000Jooooo`03o`000?oooooooooo01cooooo
00?oo`00ooooooooool0ooooool]ooooo`006_ooool00ol0003oooooooooo`0Looooo`03ool00?oo
oooooooo0?oooooo;Oooool001[ooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`3o
ooooobgooooo000Jooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0ooooool^oooo
o`006_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo0?oooooo;_ooool001[ooooo
00?o0000ooooooooool06oooool00ooo003oooooooooo`3oooooobkooooo000Jooooo`;o00006ooo
ool00ooo003oooooooooo`3ooooooboooooo000Jooooo`03o`000?oooooooooo01[ooooo00?oo`00
ooooooooool0ooooool_ooooo`006_ooool00ol0003oooooooooo`0Jooooo`03ool00?oooooooooo
0?oooooo;oooool001[ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`3ooooooc3o
oooo000Jooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0ooooool`ooooo`006_oo
ool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo0?oooooo<?ooool001[ooooo00?o0000
ooooooooool06?ooool00ooo003oooooooooo`3ooooooc7ooooo000Jooooo`03o`000?oooooooooo
01Sooooo00?oo`00ooooooooool0oooooolaooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo01Sooooo00?oo`00
ooooooooool0oooooolaooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0oooo
oolbooooo`000oooool00ol@413oooooooooo`09ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0001Oooooo00?oo`00ooooooooool0oooooolbooooo`000oooool00ol0003oooooooooo`09
ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Gooooo`03ool00?oo
oooooooo0?oooooo<_ooool000?ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`3ooooooc?ooooo0003
ooooo`03oa0@4?oooooooooo00Wooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo0?oooooo<oooool00004oiRHV?ooooooV9RHogMgM`_ooooo00?ogMgM
oa0@4?nHV9P02?ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo0?oooooo=?ooool0
0004oc8b<_l0003o<S8bonk^kPcooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooooooo
o`0Eooooo`03ool00?oooooooooo0?oooooo=?ooool001[ooooo00?o0000ooooooooool05Oooool0
0ooo003oooooooooo`3oooooocCooooo000Jooooo`03o`000?oooooooooo01Cooooo00?oo`00oooo
ooooool0ooooooleooooo`006_ooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo0?oo
oooo=Oooool001[ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`3oooooocKooooo
000Jooooo`;o00005?ooool00ooo003oooooooooo`3oooooocKooooo000Jooooo`03o`000?oooooo
oooo01;ooooo00?oo`00ooooooooool0oooooolgooooo`006_ooool00ol0003oooooooooo`0Boooo
o`03ool00?oooooooooo0?oooooo=oooool001[ooooo00?o0000ooooooooool04_ooool00ooo003o
ooooooooo`3oooooocOooooo000Jooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
oooooolhooooo`006_ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo0?oooooo>?oo
ool001[ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`3oooooocWooooo000Joooo
o`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0ooooooliooooo`006_ooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo0?oooooo>_ooool001[ooooo0_l0000@ooooo`03ool0
0?oooooooooo0?oooooo>_ooool001[ooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`3ooooooc_ooooo000Jooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0oooooolk
ooooo`006_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo>oooool001[o
oooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`3ooooooccooooo000Jooooo`03o`00
0?oooooooooo00gooooo00?oo`00ooooooooool0oooooollooooo`006_ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo0?oooooo?Oooool001[ooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`3oooooockooooo000Jooooo`03o`000?oooooooooo00_ooooo00?oo`00oooo
ooooool0oooooolnooooo`006_ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo0?oo
oooo?oooool001[ooooo0_l0000:ooooo`03ool00?oooooooooo0?oooooo@?ooool001[ooooo00?o
0000ooooooooool02Oooool00ooo003oooooooooo`3ooooood3ooooo000Jooooo`03o`000?oooooo
oooo00Sooooo00?oo`00ooooooooool0oooooom1ooooo`006_ooool00ol0003oooooooooo`07oooo
o`03ool00?oooooooooo0?oooooo@_ooool001[ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`3ooooood?ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0
oooooom4ooooo`006_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo0?ooooooAOoo
ool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo0?ooooooA_ooool00004oiRHV?oo
ooooV9RHogMgM`Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`02ooooo`03ool00?oooooooooo0?ooooooAoooool000?ooooo00?o410@ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000Kooooo1Ooo003ooooood[ooooo0003ooooo`03o`00
0?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooom<ooooo`00
0oooool00ol0003oooooooooo`09ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`3oooooodcooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go410@okZj^_oooooo
^[Zjoa0@4006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004oiRHV?ooooooV9RHogMgM`_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooC?ooool00004
oc8b<_l0003o<S8bonk^kP_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0?ooooooC?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool007?ooooo00?o0000ooooooooool0l_ooool006?ooooo0ol00003ooooo`04
o`000?ooooooooooooooo`?o00000oooool01?l0003oooooooooooooool4o`0000Oooooo00?oMgMg
ofIVI_ooool02?ooool00omVIVKoMgMgooooo`0@ooooo`03oiRHV?oooooooooo04_ooooo00?o0000
okZj^_ooool03?ooool00ol0003o^[Zjooooo`1Xooooo`00I?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Sooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@06ooooo`03ob4Q8OoMgMgo
oooo00Kooooo00?ok^k^o`000?o<c<`0C?ooool2oc8b<Pgooooo0_lb<S9Yooooo`00Foooool01Omg
MgOo410@o`000?l@413oV9RH00Cooooo00?o0000ooooooooool01Ol00002ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05oeEEEOnHV9So
ooooooooool@41001Ol00003ooooo`03ohN7QomVIVKooooo00Gooooo00?oV9RHoeEEEOooool01_oo
ool00omgMgOo0000ofIVIP04ooooo`03oa0@4?l0003o000000?o00003Oooool00ol@413o0000o`00
0002o`000005oa0@4?ooooooooooonk^k_mEEED00_l000001?mEEEGok^k^ooooool@4105o`0000Wo
oooo1Ol0000:ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00on7QhOo0000okZj^P05oooo
o`Co000000Ko410@ooooooooooooQhN7o`000?nj^[X4ooooo`Go0000Goooool005_ooooo00Go0000
ojVYZOooooooZJVYoa0@4004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?ok^k^o`000?ooool01_oo
ool00ol0003ogMgMooooo`04ooooo`04onk^k_l0003oV9RHob4Q8@Kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo1_l00002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00oo<c<co0000oa0@4007ooooo`03o`000?oooooooooo00;ooooo00?oc<c<
o`000?l@41001?ooool01OnHV9So8B4Qonk^k_ooooooA4A405oooooo001Kooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
<S8booooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_mg
MgL5ooooo`05ogMgMomEEEGoooooo`000?oMgMd01Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000oooo
ooooool02_ooool00onHV9So8B4Qonk^kP1Pooooo`00Goooool01?l0003oooooooooooooool2o`00
00Sooooo0_l00006ooooo`03o`000?oooooooooo00;o00001oooool00olb<S;oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP04oooo
o`05o`000?o<c<cooooooeEEEOn7QhL01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooooooool00_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`00
0?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h0Goooool005oooooo00?o0000ooooooooool07ooo
ool00ol0003ok^k^ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00?ok^k^o`000?ooool01ooo
ool01omEEEGoV9RHoooooooooooo<S8boeEEEOlb<S800_ooool00onYZJWo8B4Qooooo`04ooooo`03
o`000?lb<S;ogMgM013ooooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@?ooooo00?o0000oc8b<_oMgMd03?ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo05kooooo001O
ooooo`03o`000?oooooooooo01oooooo00?oEEEEogMgMoooool00_ooool2o`000004ojVYZOlQ8B7o
0000ob4Q8@;ooooo00?oMgMgoeEEEOooool01oooool01ooMgMgo410@oooooooooooo^[Zjoc8b<_nj
^[X00oooool00ol0003ogMgMooooo`02ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q3?ooool00ol@
413o0000o`000003o`0000;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^k^h2ooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q2_ooool00ol0003oooooooooo`0:ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05gooooo001Oooooo`03o`00
0?oooooooooo01oooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgMg@09ooooo`03oeEE
EOnHV9Sooooo00Kooooo00?oEEEEohN7Qoooool05_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo00Wo
oooo00Go0000okZj^_ooooooV9RHoa0@401Oooooo`00GOooool4o`000003oa0@4?oooooooooo01ko
oooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`09ooooo`03okZj^_m4A4Cooooo00Ko
oooo00?oZJVYoc8b<_ooool05_ooool00ol@413o^[Zjooooo`0Kooooo`03o`000?oooooooooo00[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03oeEEEOmVIVKo000000_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c01Oooooo`00X_ooool00oo^k^ko0000onk^kP0Fooooo`04okZj^_l@413o0000
oa0@41Sooooo00?o410@o`000?l00000S_ooool00:?ooooo00?oA4A4oiRHV?ooool0`_ooool00:?o
oooo00?oV9RHodA4A?ooool0`_ooool00:?ooooo00?ok^k^o`000?l000002_l0002hooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.30568, -0.199796, \
0.0615963, 0.00645303}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        Evaluate[Table[BesselJ[\(-1\)/2\  - \ l, r]/\@r, {l, 0, 2}]], {r, 0, 
          15}, PlotStyle \[Rule] {Red, Blue, Green}, 
        PlotLabel \[Rule] \*"\"\<\!\(J\_\(\(-l\) - 1/2\)\)(r)/\!\(\@r\) for \
l=0,1,2\>\"", AxesLabel \[Rule] {"\<r\>", "\< \>"}, 
        PlotRange \[Rule] {\(-1\), 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.33"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.309017 0.309017 [
[.15079 .29652 -3 -9 ]
[.15079 .29652 3 0 ]
[.27778 .29652 -3 -9 ]
[.27778 .29652 3 0 ]
[.40476 .29652 -3 -9 ]
[.40476 .29652 3 0 ]
[.53175 .29652 -3 -9 ]
[.53175 .29652 3 0 ]
[.65873 .29652 -6 -9 ]
[.65873 .29652 6 0 ]
[.78571 .29652 -6 -9 ]
[.78571 .29652 6 0 ]
[.9127 .29652 -6 -9 ]
[.9127 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -74.375 0 ]
[.5 .63053 74.375 13.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .30902 m
.15079 .31527 L
s
[(2)] .15079 .29652 0 1 Mshowa
.27778 .30902 m
.27778 .31527 L
s
[(4)] .27778 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(6)] .40476 .29652 0 1 Mshowa
.53175 .30902 m
.53175 .31527 L
s
[(8)] .53175 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(10)] .65873 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(12)] .78571 .29652 0 1 Mshowa
.9127 .30902 m
.9127 .31527 L
s
[(14)] .9127 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -135.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 21.5625 translate 1 -1 scale
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(J) show
69.000 16.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
73.188 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
77.375 16.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
81.562 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
85.750 16.000 moveto
(\\220) show
89.938 16.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
95.188 14.438 moveto
(H) show
101.188 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
107.188 14.438 moveto
(L) show
113.188 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
119.188 9.062 moveto
(\\217) show
127.375 9.062 moveto
(!!) show
132.188 9.062 moveto
(!) show
127.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
141.750 14.438 moveto
(for) show
165.750 14.438 moveto
(l) show
171.750 14.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
177.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
183.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
189.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
195.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
201.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
207.750 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.06479 .61803 m
.07287 .53752 L
.07874 .49385 L
.08414 .4599 L
.09471 .40587 L
.10458 .36605 L
.1234 .30936 L
.13338 .28698 L
.14407 .26767 L
.15424 .25322 L
.15961 .247 L
.16531 .24138 L
.17028 .23726 L
.17576 .23352 L
.18038 .231 L
.18543 .22886 L
.19034 .22738 L
.19303 .22681 L
.19431 .22659 L
.19552 .22642 L
.19665 .22629 L
.19787 .22618 L
.19897 .22611 L
.2 .22607 L
.2011 .22605 L
.20232 .22605 L
.20359 .22609 L
.20478 .22616 L
.20606 .22626 L
.20747 .22641 L
.21003 .22677 L
.21252 .22725 L
.21483 .22779 L
.22006 .22935 L
.22563 .2315 L
.23594 .23669 L
.24708 .24377 L
.26727 .25954 L
.30832 .2964 L
.32878 .31368 L
.34786 .32745 L
.36622 .33779 L
.37652 .34215 L
.38589 .34517 L
.39071 .34637 L
.39582 .34737 L
.40019 .34801 L
.40268 .34829 L
.40501 .34849 L
.40633 .34858 L
Mistroke
.40755 .34865 L
.40883 .3487 L
.40951 .34873 L
.41023 .34874 L
.41152 .34877 L
.41274 .34877 L
.41383 .34876 L
.41501 .34874 L
.41631 .3487 L
.41774 .34863 L
.41923 .34855 L
.42062 .34845 L
.4233 .3482 L
.42578 .34792 L
.43078 .34718 L
.43622 .34612 L
.44611 .3436 L
.46466 .33707 L
.50389 .31842 L
.54161 .30004 L
.56093 .29242 L
.57089 .28925 L
.58178 .28646 L
.58679 .28543 L
.59215 .2845 L
.59678 .28386 L
.6018 .28332 L
.60475 .28308 L
.60748 .28291 L
.60882 .28285 L
.61008 .2828 L
.6114 .28276 L
.6121 .28274 L
.61284 .28273 L
.61413 .28271 L
.61486 .28271 L
.61554 .28271 L
.61677 .28271 L
.61809 .28273 L
.61939 .28276 L
.62061 .28279 L
.62289 .28289 L
.6253 .28302 L
.62755 .28318 L
.63266 .28365 L
.63765 .28426 L
.64298 .28508 L
.66146 .28901 L
.68272 .29526 L
.70284 .30219 L
Mistroke
.74119 .31553 L
.76059 .32117 L
.77089 .32362 L
.78199 .32576 L
.78715 .32657 L
.79257 .32728 L
.79759 .32781 L
.80226 .32819 L
.80665 .32846 L
.80911 .32856 L
.81135 .32863 L
.81262 .32866 L
.8138 .32868 L
.81509 .32869 L
.81574 .3287 L
.81646 .3287 L
.81766 .3287 L
.81895 .32869 L
.82017 .32867 L
.82128 .32865 L
.82257 .32861 L
.82379 .32857 L
.82607 .32848 L
.82852 .32836 L
.83116 .32819 L
.84032 .32737 L
.84558 .32673 L
.85113 .32594 L
.86106 .32423 L
.8991 .31517 L
.9396 .30419 L
.97619 .29653 L
Mfstroke
0 0 1 r
.09157 0 m
.09309 .01301 L
.09906 .05024 L
.10458 .07895 L
.12324 .15111 L
.13387 .18195 L
.14385 .2069 L
.18253 .28159 L
.20257 .31043 L
.22367 .33439 L
.23322 .34306 L
.24341 .35083 L
.25297 .35671 L
.26178 .36093 L
.26666 .36278 L
.27202 .36443 L
.27742 .36567 L
.28037 .36618 L
.28313 .36655 L
.28437 .36668 L
.28573 .3668 L
.28693 .36689 L
.2882 .36696 L
.28947 .36701 L
.29061 .36704 L
.29176 .36705 L
.29284 .36704 L
.29412 .36702 L
.29476 .367 L
.29546 .36697 L
.2967 .3669 L
.29786 .36682 L
.30048 .36659 L
.30328 .36624 L
.30858 .36534 L
.31348 .36422 L
.32456 .36078 L
.33433 .3568 L
.34469 .35175 L
.3825 .32864 L
.42275 .30277 L
.44127 .29277 L
.45175 .28801 L
.46149 .28427 L
.47202 .28102 L
.48157 .27882 L
.48683 .27793 L
.49178 .27729 L
.49451 .27702 L
.49702 .27683 L
Mistroke
.49977 .27667 L
.50116 .27662 L
.5019 .27659 L
.50268 .27657 L
.50398 .27655 L
.50519 .27654 L
.50648 .27654 L
.50722 .27655 L
.50791 .27656 L
.50916 .27659 L
.5103 .27663 L
.51155 .27668 L
.51287 .27675 L
.51731 .27707 L
.51983 .27732 L
.52217 .27759 L
.53227 .27919 L
.53793 .28037 L
.54307 .28162 L
.56224 .28747 L
.58302 .29541 L
.62391 .31248 L
.64424 .32003 L
.65419 .32319 L
.66328 .32571 L
.67201 .32775 L
.68152 .32952 L
.68674 .33028 L
.69158 .33086 L
.69621 .33128 L
.69856 .33145 L
.70114 .3316 L
.70375 .33171 L
.70517 .33175 L
.70585 .33177 L
.7065 .33179 L
.70775 .33181 L
.70888 .33182 L
.7101 .33182 L
.71079 .33182 L
.71143 .33182 L
.71207 .33181 L
.71276 .3318 L
.714 .33178 L
.71548 .33174 L
.71683 .3317 L
.71962 .33158 L
.72256 .3314 L
.72756 .331 L
.7322 .33051 L
Mistroke
.74274 .32902 L
.75327 .32703 L
.76321 .32477 L
.7818 .31975 L
.82029 .30788 L
.83979 .30218 L
.86123 .29696 L
.87105 .29507 L
.8816 .29345 L
.88671 .29282 L
.89156 .29234 L
.89591 .29198 L
.90065 .29169 L
.90322 .29158 L
.90457 .29153 L
.90599 .29149 L
.90724 .29145 L
.9079 .29144 L
.9086 .29143 L
.90985 .29141 L
.91101 .2914 L
.91222 .2914 L
.91353 .2914 L
.91477 .29141 L
.91591 .29143 L
.91694 .29145 L
.91808 .29147 L
.92038 .29154 L
.9231 .29165 L
.9256 .29178 L
.93121 .29216 L
.93642 .29262 L
.94137 .29316 L
.95942 .29584 L
.97619 .29916 L
Mfstroke
0 1 0 r
.12229 .61803 m
.12504 .59928 L
.13471 .54814 L
.14363 .51283 L
.15306 .48355 L
.1632 .45831 L
.18151 .42267 L
.22279 .36424 L
.26255 .32077 L
.30079 .28882 L
.32051 .27696 L
.33152 .27188 L
.34149 .26827 L
.34638 .26685 L
.35154 .2656 L
.356 .26473 L
.36078 .26401 L
.36347 .2637 L
.36592 .26347 L
.3671 .26339 L
.36838 .26331 L
.36959 .26325 L
.37072 .2632 L
.37202 .26316 L
.37272 .26315 L
.37346 .26314 L
.37421 .26314 L
.37499 .26314 L
.37565 .26314 L
.37638 .26315 L
.37769 .26319 L
.37843 .26321 L
.37909 .26324 L
.38161 .26337 L
.38393 .26354 L
.38648 .26379 L
.39162 .26445 L
.39638 .26525 L
.40083 .26617 L
.41087 .26879 L
.42165 .27235 L
.46297 .29125 L
.50279 .31195 L
.52098 .32037 L
.54108 .32803 L
.55059 .3309 L
.56083 .33339 L
.56648 .33448 L
.57166 .3353 L
.57662 .33592 L
Mistroke
.5793 .33619 L
.58183 .3364 L
.58423 .33656 L
.58549 .33663 L
.58682 .33669 L
.58795 .33673 L
.58919 .33677 L
.59031 .3368 L
.59136 .33681 L
.59268 .33683 L
.59393 .33683 L
.59505 .33682 L
.59627 .3368 L
.59697 .33679 L
.5976 .33677 L
.59901 .33673 L
.60155 .33662 L
.60392 .33648 L
.60609 .33632 L
.61101 .33586 L
.61534 .33534 L
.61991 .33467 L
.6294 .33294 L
.63956 .33059 L
.6579 .32532 L
.69928 .31077 L
.72 .30354 L
.73915 .29768 L
.75775 .29319 L
.76714 .29147 L
.77219 .29072 L
.7775 .29005 L
.78232 .28956 L
.78488 .28935 L
.7876 .28915 L
.79012 .28901 L
.7924 .2889 L
.7935 .28886 L
.79469 .28882 L
.79574 .2888 L
.79686 .28877 L
.79816 .28875 L
.79937 .28874 L
.80011 .28874 L
.80082 .28874 L
.80213 .28874 L
.80281 .28875 L
.80352 .28875 L
.80481 .28878 L
.80633 .28881 L
Mistroke
.80772 .28885 L
.8102 .28895 L
.81287 .28909 L
.81772 .28942 L
.82266 .28987 L
.82726 .29038 L
.83771 .29186 L
.8588 .29601 L
.89778 .30624 L
.91764 .31172 L
.93921 .3171 L
.95844 .32096 L
.97619 .32348 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`007oooool4o`000003oa0@4?oooooooooo0?oooooo@oooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`005_ooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`00017ooooo
00?o003oooooooooool0oooooolYooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo017ooooo00?o003oooooooooool0oooooolYooooo`008Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0oooooolYooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0oooooolXoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o003ooooooooo
ool0oooooolXooooo`007oooool00omEEEGoIVIVo`000007ooooo`;o00004oooool00ol00?oooooo
ooooo`3oooooobSooooo000Yooooo`03o`000?oooooooooo01;ooooo00?o003oooooooooool0oooo
oolXooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo0?oooooo:?ooool0
02Wooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`3oooooobOooooo000Yooooo`03
o`000?oooooooooo01?ooooo00?o003oooooooooool0oooooolWooooo`00:Oooool2o`0001Cooooo
00?o003oooooooooool0oooooolWooooo`00:Oooool00ol0003oooooooooo`0Cooooo`03o`00oooo
oooooooo0?oooooo9oooool002Wooooo00?o0000ooooooooool04oooool00ol00?ooooooooooo`3o
ooooobOooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o003oooooooooool0oooooolVoooo
o`00:Oooool2o`0001Gooooo00?o003oooooooooool0oooooolVooooo`00:Oooool00ol0003ooooo
ooooo`0Dooooo`03o`00oooooooooooo0?oooooo9_ooool002Wooooo00?o0000ooooooooool05?oo
ool00ol00?ooooooooooo`3oooooobKooooo000Yooooo`03o`000?oooooooooo01Cooooo00?o003o
ooooooooool0oooooolVooooo`00:Oooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo
0?oooooo9_ooool002Wooooo0_l0000Eooooo`03o`00oooooooooooo0?oooooo9_ooool002Wooooo
00?o0000ooooooooool05Oooool00ol00?ooooooooooo`3oooooobGooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`3oooooobGo
oooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Gooooo00?o003ooooooooo
ool0oooooolUooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWo
EEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`3oooooobGooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00olQ8B7o
ooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Eooooo`03o`00oooooooooooo0?oo
oooo9Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Gooooo00?o003ooooo
ooooool0oooooolUooooo`001_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMg
Moooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o003ooooo
ooooool0oooooolUooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooo
oooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool0
0ol00?ooooooooooo`3oooooobCooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00006ooooo`;o00005oooool00ol00?ooooooooooo`3oooooobCooooo000Yoooo
o`03o`000?oooooooooo01Kooooo00?o003oooooooooool0oooooolTooooo`00:Oooool00ol0003o
ooooooooo`0Gooooo`03o`00oooooooooooo0?oooooo8oooool002Wooooo00?o0000ooooooooool0
5oooool00ol00?ooooooooooo`3oooooob?ooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o
003oooooooooool0oooooolSooooo`00:Oooool2o`0001Sooooo00?o003oooooooooool0oooooolS
ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo0?oooooo8_ooool002Wo
oooo00?o0000ooooooooool06?ooool00ol00?ooooooooooo`3oooooob;ooooo000Yooooo`03o`00
0?oooooooooo01Sooooo00?o003oooooooooool0oooooolRooooo`00:Oooool00ol0003ooooooooo
o`0Hooooo`03o`00oooooooooooo0?oooooo8_ooool002Wooooo0_l0000Jooooo`03o`00oooooooo
oooo0?oooooo8Oooool002Wooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`3ooooo
ob7ooooo000Yooooo`03o`000?oooooooooo01Wooooo00?o003oooooooooool0oooooolQooooo`00
:Oooool00ol0003oooooooooo`0Jooooo`03o`00oooooooooooo0?oooooo8?ooool002Wooooo00?o
0000ooooooooool06_ooool00ol00?ooooooooooo`3oooooob3ooooo000Yooooo`;o00006oooool0
0ol00?ooooooooooo`3oooooob3ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o003ooooo
ooooool0oooooolPooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Kooooo`03o`00oooooooo
oooo0?oooooo7oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01_ooooo00?o003oooooooooool0oooooolO
ooooo`001_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo0ol0000Kooooo`03o`00oooooooooooo0?oooooo7oooool000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool06oooool0
0ol00?ooooooooooo`3ooooooaoooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool07?ooool00ol00?oooooooooo
o`3ooooooakooooo000>ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01cooooo00?o003oooooooooool0oooooolNooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Looooo`03o`00oooooooooooo0?oooooo7_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001_ooool2o`0001kooooo00?o003oooooooooool0oooooolMooooo`00:Oooool0
0ol0003oooooooooo`0Mooooo`03o`00oooooooooooo0?oooooo7Oooool002Wooooo00?o0000oooo
ooooool07Oooool00ol00?ooooooooooo`3ooooooagooooo000Yooooo`03o`000?oooooooooo01ko
oooo00?o003oooooooooool0oooooolLooooo`00:Oooool00ol0003oooooooooo`0Nooooo`03o`00
oooooooooooo0?oooooo7?ooool002Wooooo0_l0000Oooooo`03o`00oooooooooooo0?oooooo7?oo
ool002Wooooo00?o0000ooooooooool07oooool00ol00?ooooooooooo`3ooooooa_ooooo000Yoooo
o`03o`000?oooooooooo01oooooo00?o003oooooooooool0oooooolKooooo`00:Oooool00ol0003o
ooooooooo`0Pooooo`03o`00oooooooooooo0?oooooo6_ooool002Wooooo0_l0000Qooooo`03o`00
oooooooooooo0?oooooo6_ooool002Wooooo00?o0000ooooooooool08?ooool00ol00?oooooooooo
o`3ooooooa[ooooo000Yooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0oooooolI
ooooo`00:Oooool00ol0003oooooooooo`0Qooooo`03o`00oooooooooooo0?oooooo6Oooool002Wo
oooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`3ooooooaSooooo000Yooooo`;o0000
8oooool00ol00?ooooooooooo`3ooooooaSooooo000Yooooo`03o`000?oooooooooo02?ooooo00?o
003oooooooooool0oooooolGooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
8oooool00ol00?ooooooooooo`3ooooooaOooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`08ooooo`Soo`00ooooool6ooooo`00
1?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`07ooooo`03
ool00?oooooooooo00Kooooo0ooo003oooooo`?ooooo0006ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0000Uooooo`03
o`00oooooooooooo00;ooooo1?oo000<ooooo`?oo`00ooooool000Kooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo02Gooooo00Go003oooooooooooooooooool0000Cooooo`;oo`00oOooool0
00Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Vooooo`04o`00ooooooooooooool001Gooooo0_oo
003kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RH
oa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol00?ooo`00
ool0000Hooooo`;oo`00nOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l0000Wooooo`03ool00?l00?oooooo01[o
oooo00?oo`00ooooooooool0m_ooool002Wooooo00?o0000ooooooooool09_ooool00ooo003ooooo
o`00o`0Kooooo`03ool00?oooooooooo0?Gooooo000Yooooo`03o`000?oooooooooo02Gooooo00Co
o`00oooooooooooo003o7?ooool00ooo003oooooooooo`3dooooo`00:Oooool00ol0003ooooooooo
o`0Uooooo`05ool00?ooooooooooooooool00?l07?ooool00ooo003oooooooooo`3cooooo`00:Ooo
ool00ol0003oooooooooo`0Tooooo`03ool00?oooooooooo00;ooooo00?o003oooooooooool06ooo
ool2ool00??ooooo000Yooooo`;o00009?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooo
oooo01cooooo00?oo`00ooooooooool06?ooool8o`3o0=3ooooo000Yooooo`03o`000?oooooooooo
02;ooooo00?oo`00ooooooooool01Oooool00ol00?ooooooooooo`0Mooooo`03ool00?oooooooooo
01;ooooo1_l0o`06ooooo`So0?l0bOooool002Wooooo00?o0000ooooooooool08Oooool00ooo003o
0000o`000002o`0000Gooooo00?o003oooooooooool06oooool2o`000003ool00?oooooooooo00oo
oooo0_l0o`0?ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00ol0o`0Oooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`07_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hKooooo`Co
000000?o410@ooooooooool01Ol0000Kooooo`Co000000?o410@ooooooooool00_ooool2o`000003
oa0@4?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo027ooooo00Goo`00ob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`00oooooooooooo01cooooo00?o0000oooooooo00003Oooool3o`3o017o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`;o0?l07Oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q023ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00?o
0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A401gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Yooooo`00:Oooool00ol0003oooooooooo`0Pooooo`05ool00?oo
ooooV9RHob4Q8Oo^k^h01oooool00ol00?ooooooooooo`0Hooooo`Go000000?oooooool00?oo0000
2Oooool2o`3o01Cooooo00Go0000ooooooooooooooooo`000005ooooo`;o0?l05?ooool5o`00o`;o
oooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Mooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h07_ooool0
0ol0003oooooooooo`02ooooo`Go0000:_ooool002Wooooo0_l0000Qooooo`06ool00?oooooooooo
oiRHV?lQ8B7ok^k^1_ooool00ol00?ooooooooooo`0Hooooo`04odA4A?oMgMgoooooo`0000Cooooo
00?oo`00ooooooooool01?ooool2o`3o01Kooooo00Go0000oiRHV?ooooooV9RHob4Q8@07ooooo`;o
0?l02oooool7o`00o`Gooooo1ol00?lPooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h07Oooool00ol0
003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0002_ooooo000Yooooo`03o`000?oooooooooo
01oooooo00?oo`00ooooooooool00_ooool00omgMgOoIVIVooooo`06ooooo`03o`00oooooooooooo
01Oooooo00CogMgMoeEEEOoooooo00001Oooool01?oo003oooooooooooooool2o`3o01Sooooo00Go
0000oeEEEOl0003o410@olc<c009ooooo`?o0?l01Oooool3o`00o`kooooo00Goc<c<o`000?l0003o
0000olc<c004o`00o`kooooo2_oo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Mooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool07?ooool00ol0
003oooooooooo`02ooooo`04omgMgOmEEEGoooooo`0002_ooooo000Yooooo`03o`000?oooooooooo
01oooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo
01Sooooo00?oMgMgolc<c?l000001_ooool00ooo003o0?l0o`3o000Jooooo`03oeEEEOn7QhOooooo
00kooooo0_l0o`03o`00oa7ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`?o003o1Oooool6
ool000[ooooo2?oo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo01_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?oMgMg
olc<c?l00000:oooool002Wooooo00?o0000ooooooooool07_ooool02?oo003oooooooooool0003o
^[ZjoooooonHV9So410@2?ooool00ol00?ooooooooooo`0Gooooo`03onk^k_m4A4Co000000Gooooo
0_l0o`000ooo003oooooooooo`0Iooooo`03omgMgOl@413oV9RH00gooooo0ol00?l2o`3o01;ooooo
00Go0000okZj^_oooooo^[Zjo`000007ooooo`?o003o0_oo000Dooooo`04o`000?oooooooooooooo
o`Coo`0000?oV9RHogMgMoooool07?ooool00ol0003oooooooooo`0>o`3o01Kooooo00?o0000oooo
ooooool00oooool00oo^k^koA4A4o`00000[ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`08
ool00?oooooooooooiRHV?l@413o0000ob4Q8Oo<c<`9ooooo`03o`00oooooooooooo01Oooooo00?o
MgMgo`000?ooool00oooool01Ol0o`3oooooooooooooooooo`0001_ooooo00Coc<c<odA4A?l0003o
410@2?ooool3o`00o`Gooooo0_l0o`0@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool3ool0
0004ooooool00?oo003oo`00oa7ooooo00?oEEEEofIVI_l000001?ooool00oo^k^ko<S8bo`000003
ool001Oooooo2?l0o`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01oooool7o`3o00[ooooo5_l0
0?lSooooo`00:Oooool2o`0001kooooo00?oo`00ooooooooool03oooool00ol00?ooooooooooo`0L
ooooo`03o`3o0?oooooooooo00?ooooo00?oo`00ooooooooool08_ooool2o`00o`[ooooo0_l0o`0G
ooooo`;oo`001oooool2o`00oacooooo1?oo000@ooooo`?o0?l07Oooool5o`3o00Go003o5_ooool5
o`00oakooooo000Yooooo`03o`000?oooooooooo01gooooo00?oo`00ooooooooool04?ooool00ol0
0?ooooooooooo`0Jooooo`03o`3o0?oooooooooo00Gooooo00?oo`00ooooooooool07oooool2o`00
o`kooooo0_l0o`0Cooooo`;oo`002oooool3o`00oagooooo0ooo000:ooooo`?o0?l08?ooool5o`00
o`Co0?l06_ooool2ool000;o003o7?ooool002Wooooo00?o0000ooooooooool07?ooool00ooo003o
ooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?o0?l0ooooooooool01oooool00ooo003o
ooooooooo`0Looooo`;o003o4_ooool2o`3o00oooooo0_oo000@ooooo`?o003o7Oooool2ool000Go
oooo0ol0o`0Oooooo`Co003o2Oooool4o`3o017ooooo1Ooo000Eooooo`03oa0@4?l0003o000000?o
00001Oooool002Wooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`0Booooo`03o`00
oooooooooooo01Oooooo00?o0?l0ooooooooool02Oooool00ooo003oooooooooo`0Jooooo`03o`00
oooooooooooo01Cooooo0_l0o`0:ooooo`?oo`005Oooool2o`00oagooooo0_oo0003o`3o01oooooo
0ol00?lAooooo`Co0?l02?ooool5ool001cooooo00?o0000ooooooooool01_ooool002;ooooo9Ol0
00000ooo003o0000o`00000Do`000003o`00ool0003o000001Go000000?o0?l0o`000?l000002ol0
00000ooo003o0000o`00000Go`0000;o003o6Ol00002o`3o00Ko00000_oo000Jo`0000?o003o6Ol0
0003o`3o0004o`000?oo003oo`00ool001_o00000ol00?lHo`0000?o0?l000?o0000ool00?oo0000
0_oo000Eo`0000cooooo00?o0000ooooooooool01_ooool002Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ool00?ooool01ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Go003ooooooooooooooooo
o`000009ooooo`03o`000?oooooooooo00Gooooo00?o0?l0o`000?ooool02?ooool00ol0003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?l0o`3o0?l000;ooooo0_oo0003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o003o2?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?l0o`3o0?l000;o0?l01Oooool00ol0003oooooool00002ool000Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`?o003o00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo0ooo0003o`3o00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
000Yooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`03o`00oooooooooooo017ooooo00?o0?l0ooooool000003oooool2ool001?ooooo0_l0
0?l00ol0003oooooooooo`0Looooo`03ool00?l0o`3o0?l000Gooooo00?o0000ooooooooool06ooo
ool2o`00o`Kooooo00?o0000ooooooooool01Oooool3o`3o00kooooo0ooo000;ooooo`04o`000?oo
ooooooooooooo`?o003o6_ooool4ool000;ooooo00Co0000oooooooooooooooo0ol0o`0Pooooo`03
o`000?lb<S;ogMgM00Kooooo000Yooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0
6?ooool00ol00?ooooooooooo`0?ooooo`03o`3o0?oooooooooo01;ooooo00?oo`00ooooooooool0
3oooool00ol00?ooooooooooo`0Mooooo`;oo`000oooool00ol0o`3oooooooooo`0Rooooo`;o003o
2Oooool3o`3o01Cooooo0ooo0009ooooo`?o003o6Oooool4ool000gooooo1Ol0o`0Jooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q1?ooool002Wooooo00?o0000ooooooooool06_ooool00ooo003ooooo
ooooo`0Iooooo`03o`00oooooooooooo00gooooo00?o0?l0ooooooooool05?ooool2ool000gooooo
0_l00?lNooooo`;oo`001_ooool3o`3o02?ooooo0ol00?l3ooooo`?o0?l06_ooool3ool00003oooo
ool00?oo003o00?o003o6?ooool4ool001Kooooo1_l0o`0Nooooo`00:Oooool2o`0001[ooooo00?o
o`00ooooooooool06oooool00ol00?ooooooooooo`0;ooooo`03o`3o0?oooooooooo01Oooooo00?o
o`00ooooooooool02Oooool00ol00?ooooooooooo`0Looooo`;oo`002oooool3o`3o02?ooooo0ol0
o`02o`00oa_ooooo1?l00?l4ool001?ooooo1_oo000Pooooo`;o0?l07?ooool002Wooooo00?o0000
ooooooooool06Oooool00ooo003oooooooooo`0Looooo`03o`00oooooooooooo00Wooooo00?o0?l0
ooooooooool06Oooool2ool000Oooooo0_l00?lMooooo`;oo`004?ooool3o`3o01gooooo0ol0o`05
ooooo`?o003o4_ooool6o`00o`Sooooo4ooo0014ooooo`00:Oooool00ol0003oooooooooo`0Ioooo
o`03ool00?oooooooooo01gooooo00?o003oooooooooool01oooool00ol0o`3oooooooooo`0Loooo
o`;oo`001?ooool00ol00?ooooooooooo`0Kooooo`;oo`005Oooool3o`3o01Oooooo0ol0o`0;oooo
oa;o003oIOooool002Wooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0Oooooo`03
o`00oooooooooooo00Gooooo00?o0?l0ooooooooool07oooool01?oo003oooooo`00ool00?lLoooo
o`;oo`006_ooool5o`3o00[ooooo2?l0o`25ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03
ool00?oooooooooo023ooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`0Pooooo`;o
003o0_oo000Jooooo`;oo`008Oooool:o`3o08gooooo000Yooooo`;o00006Oooool00ooo003ooooo
ooooo`0Qooooo`05o`00ooooooooooooooooool0o`008_ooool00ol00?ooooooooooo`02ooooo`?o
o`005?ooool3ool00;[ooooo000Yooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0
8oooool2o`00o`03o`3o0?oooooooooo01oooooo0_l00?l8ooooo`;oo`004?ooool2ool00;gooooo
000Yooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool09?ooool00ol0o`3o003ooooo
o`0Oooooo`03o`00oooooooooooo00[ooooo4?oo002oooooo`00:Oooool00ol0003oooooooooo`0G
ooooo`03ool00?oooooooooo02?ooooo00?o0?l0ooooooooool00_l00?lLooooo`;o003og?ooool0
02Wooooo0_l0000Gooooo`03ool00?oooooooooo02?ooooo00?o0?l0ooooooooool00oooool00ol0
0?ooooooooooo`0Gooooo`;o003og_ooool002Wooooo00?o0000ooooooooool05_ooool00ooo003o
ooooooooo`0Rooooo`03o`3o0?oooooooooo00Gooooo0_l00?lEooooo`;o003oh?ooool002Wooooo
00?o0000ooooooooool05_ooool00ooo003oooooooooo`0Qooooo`03o`3o0?oooooooooo00Sooooo
0_l00?l@ooooo`?o003oh_ooool002Wooooo00?o0000ooooooooool05Oooool00ooo003ooooooooo
o`0Qooooo`03o`3o0?oooooooooo00_ooooo0ol00?l9ooooo`Co003oiOooool002Wooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`0Qooooo`03o`3o0?oooooooooo00kooooo2Ol00?oY
ooooo`00:Oooool2o`0001Kooooo00?oo`00ooooooooool08?ooool00ol0o`3oooooooooo`3ooooo
o`;ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool07oooool00ol0o`3o
ooooooooo`3oooooo`?ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooooooo023ooooo00?o0?l0ooooooooool0ooooool3ooooo`001_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool07oooool0
0ol0o`3oooooooooo`3oooooo`Cooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool0
0ooo003oooooooooo`0Nooooo`03o`3o0?oooooooooo0?oooooo1Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0001Cooooo00?oo`00ooooooooool07_ooool00ol0o`3oooooooooo`3oooooo`Gooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01kooooo00?o
0?l0ooooooooool0ooooool6ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o
o`00ooooooooool07Oooool00ol0o`3oooooooooo`3oooooo`Oooooo0006ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01gooooo00?o0?l0ooooooooool0
ooooool7ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c004ooooo`Co00001_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01co
oooo00?o0?l0ooooooooool0ooooool8ooooo`00:Oooool2o`0001?ooooo00?oo`00ooooooooool0
7?ooool00ol0o`3oooooooooo`3oooooo`Wooooo000Yooooo`03o`000?oooooooooo01;ooooo00?o
o`00ooooooooool07?ooool00ol0o`3oooooooooo`3oooooo`Wooooo000Yooooo`03o`000?oooooo
oooo01;ooooo00?oo`00ooooooooool06oooool00ol0o`3oooooooooo`3oooooo`[ooooo000Yoooo
o`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool06_ooool00ol0o`3oooooooooo`3ooooo
o`_ooooo000Yooooo`;o00004oooool00ooo003oooooooooo`0Jooooo`03o`3o0?oooooooooo0?oo
oooo2oooool002Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0Jooooo`03o`3o
0?oooooooooo0?oooooo3?ooool002Wooooo00?o0000ooooooooool04Oooool00ooo003ooooooooo
o`0Iooooo`03o`3o0?oooooooooo0?oooooo3Oooool002Wooooo00?o0000ooooooooool04Oooool0
0ooo003oooooooooo`0Iooooo`03o`3o0?oooooooooo0?oooooo3Oooool002Wooooo00?o0000oooo
ooooool04Oooool00ooo003oooooooooo`0Hooooo`03o`3o0?oooooooooo0?oooooo3_ooool002Wo
oooo0_l0000Booooo`03ool00?oooooooooo01Sooooo00?o0?l0ooooooooool0ooooool>ooooo`00
:Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo01Sooooo00?o0?l0ooooooooool0
ooooool?ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo01Sooooo00?o
0?l0ooooooooool0ooooool?ooooo`00:Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo01Oooooo00?o0?l0ooooooooool0ooooool@ooooo`00:Oooool00ol0003oooooooooo`0@oooo
o`03ool00?oooooooooo01Kooooo00?o0?l0ooooooooool0oooooolAooooo`00:Oooool2o`00017o
oooo00?oo`00ooooooooool05_ooool00ol0o`3oooooooooo`3ooooooa7ooooo000Yooooo`03o`00
0?oooooooooo00oooooo00?oo`00ooooooooool05_ooool00ol0o`3oooooooooo`3ooooooa;ooooo
000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool05_ooool00ol0o`3o
ooooooooo`3ooooooa;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo01Go
oooo00?o0?l0ooooooooool0oooooolCooooo`003_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool3o`0000oooooo00?oo`00ooooooooool05Oooool00ol0o`3o
ooooooooo`3ooooooa?ooooo000>ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool05?ooool00ol0o`3o
ooooooooo`3ooooooaCooooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Doooo
o`03o`3o0?oooooooooo0?oooooo5?ooool000kooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Doooo
o`03o`3o0?oooooooooo0?oooooo5?ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`0Coooo
o`03o`3o0?oooooooooo0?oooooo5Oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001_ooool2o`0000oooooo00?oo`00ooooooooool05?ooool00ol0o`3oooooooooo`3ooooo
oaGooooo000Yooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool05?ooool00ol0o`3o
ooooooooo`3ooooooaGooooo000Yooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
4oooool00ol0o`3oooooooooo`3ooooooaKooooo000Yooooo`03o`000?oooooooooo00kooooo00?o
o`00ooooooooool04oooool00ol0o`3oooooooooo`3ooooooaKooooo000Yooooo`03o`000?oooooo
oooo00kooooo00?oo`00ooooooooool04_ooool00ol0o`3oooooooooo`3ooooooaOooooo000Yoooo
o`;o00003oooool00ooo003oooooooooo`0Booooo`03o`3o0?oooooooooo0?oooooo5oooool002Wo
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Booooo`03o`3o0?oooooooooo0?oo
oooo5oooool002Wooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Aooooo`03o`3o
0?oooooooooo0?oooooo6?ooool002Wooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`0Aooooo`03o`3o0?oooooooooo0?oooooo6?ooool002Wooooo00?o0000ooooooooool03Oooool0
0ooo003oooooooooo`0Booooo`03o`3o0?oooooooooo0?oooooo6?ooool002Wooooo0_l0000>oooo
o`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool0oooooolIooooo`00:Oooool00ol0003o
ooooooooo`0=ooooo`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool0oooooolIooooo`00
:Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool0
oooooolIooooo`00:Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo017ooooo00?o
0?l0ooooooooool0oooooolIooooo`00:Oooool2o`0000kooooo00?oo`00ooooooooool04?ooool0
0ol0o`3oooooooooo`3ooooooa[ooooo000Yooooo`03o`000?oooooooooo00gooooo00?oo`00oooo
ooooool04?ooool00ol0o`3oooooooooo`3ooooooa[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0Aooooo`03o`3o0?oooooo
oooo0?oooooo6_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool0
0omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool0
0ooo003oooooooooo`0Aooooo`03o`3o0?oooooooooo0?oooooo6_ooool000Kooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`03ool00?oooooooooo017ooooo00?o0?l0ooooooooool0oooooolJ
ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool0
0omgMgOo<S8booooo`04ooooo`?o00003?ooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooo
oooo0?oooooo6oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool04?ooool00ol0o`3oooooooooo`3ooooooa_ooooo0006ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo0?oooooo6ooo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S80
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
4?ooool00ol0o`3oooooooooo`3ooooooa_ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0
4Oooool00ol0o`3oooooooooo`3ooooooa_ooooo000Yooooo`;o00003?ooool00ooo003ooooooooo
o`0Aooooo`03o`3o0?oooooooooo0?oooooo6oooool002Wooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo0?oooooo7?ooool002Wooooo00?o0000oooo
ooooool02oooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo0?oooooo7?ooool002Wo
oooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0@ooooo`03o`3o0?oooooooooo0?oo
oooo7?ooool002Wooooo0_l0000<ooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0
oooooolLooooo`00:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo013ooooo00?o
0?l0ooooooooool0oooooolLooooo`00:Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo00oooooo00?o0?l0ooooooooool0oooooolMooooo`00:Oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0oooooolMooooo`00:Oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo013ooooo00?o0?l0ooooooooool0oooooolMooooo`00
:Oooool2o`0000_ooooo00?oo`00ooooooooool04?ooool00ol0o`3oooooooooo`3ooooooagooooo
000Yooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool04?ooool00ol0o`3ooooooooo
o`3ooooooagooooo000Yooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool03oooool0
0ol0o`3oooooooooo`3ooooooakooooo000Yooooo`03o`000?oooooooooo00[ooooo00?oo`00oooo
ooooool03oooool00ol0o`3oooooooooo`3ooooooakooooo000Yooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool03oooool00ol0o`3oooooooooo`3ooooooakooooo000Yooooo`;o0000
2oooool00ooo003oooooooooo`0?ooooo`03o`3o0?oooooooooo0?oooooo7_ooool002Wooooo00?o
0000ooooooooool02_ooool00ooo003oooooooooo`0?ooooo`03o`3o0?oooooooooo0?oooooo7_oo
ool001oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool04?ooool00ol0o`3oooooooooo`3ooooooakooooo000Qooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0?ooooo`03o`3o0?oooooooooo
0?oooooo7oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo00oooooo00?o0?l0ooooooooool0oooooolOooooo`008Oooool00ol0003ooooo
ooooo`05ooooo`?o00002Oooool00ooo003oooooooooo`0?ooooo`03o`3o0?oooooooooo0?oooooo
7oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001oooooo00?oEEEEofIVI_l0
0000oooooom7ooooo`00OOooool00ol0003oooooooooo`3Xooooo`00KOooool3o`0000Sooooo0ol0
0002ooooo`04o`000?ooooooooooooooo`Co00002?ooool00omgMgOoIVIVooooo`08ooooo`03ofIV
I_mgMgOooooo013ooooo00?oV9RHooooooooool0B_ooool00ol0003o^[Zjooooo`0<ooooo`03o`00
0?nj^[[ooooo05kooooo001^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Wooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@
omgMg@05ooooo`03ob4Q8OoMgMgooooo00Oooooo00?ok^k^o`000?o<c<`0Boooool2oc8b<Pgooooo
0_lb<S9Oooooo`00H?ooool01OmgMgOo410@o`000?l@413oV9RH00?ooooo1?l00002ooooo`04o`00
0?ooooooooooooooo`Co00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool01?mEEEGoV9RHooooool@4105o`0000Cooooo00?oQhN7ofIV
I_ooool01?ooool00onHV9SoEEEEooooo`07ooooo`03ogMgMol0003oIVIV00?ooooo00?o410@o`00
0?l000000ol0000=ooooo`03oa0@4?l0003o000000;o000000Go410@ooooooooooook^k^oeEEE@02
o`000004oeEEEOo^k^kooooooa0@40Go00002Oooool5o`0000[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`03ohN7Qol0003o^[Zj00Gooooo1?l000001_l@413ooooooooooon7QhOo0000okZj
^PCooooo1Ol0001Eooooo`00H?ooool01Ol0003oZJVYoooooonYZJWo410@00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?ok^k^o`00
0?ooool01Oooool00ol0003ogMgMooooo`05ooooo`04onk^k_l0003oV9RHob4Q8@Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`03ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo1_l00002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool00oo<c<co0000oa0@4007ooooo`03o`000?oooooooooo00;o
oooo00?oc<c<o`000?l@41001?ooool01OnHV9So8B4Qonk^k_ooooooA4A405Gooooo001Pooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05ooooo`03oc8b<_oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`;oMgMg1_ooool01Omg
MgOoEEEEooooool0003ogMgM00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo00[ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00[ooooo
00?oV9RHob4Q8Oo^k^h0E_ooool006Cooooo00?o0000ooooooooool01_ooool2o`0000Wooooo0_l0
0005ooooo`03o`000?oooooooooo00;o00002?ooool00olb<S;oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00oo^k^ko410@onk^kP05ooooo`05o`000?o<
c<cooooooeEEEOn7QhL01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool00_ooool6o`0000;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h0EOooool006Cooooo00?o0000ooooooooool09Oooool00ol0003o
k^k^ooooo`02ooooo`03o`000?lb<S;ogMgM00Gooooo00?ok^k^o`000?ooool01_ooool00omEEEGo
V9RHooooo`02ooooo`03oc8b<_mEEEGo<S8b00;ooooo00?oZJVYob4Q8Oooool00oooool00ol0003o
<S8bomgMg@0@ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`03o`000?lb<S;ogMgM00cooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`1Dooooo`00I?ooool0
0ol0003oooooooooo`0Uooooo`04oeEEEOmgMgOoooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q
0oooool00omgMgOoEEEEooooo`06ooooo`03omgMgOl@413ooooo00;ooooo00?o^[Zjoc8b<_nj^[X0
0oooool01?l0003ogMgMooooooooool2o`000004ojVYZOlQ8B7o0000ob4Q8@cooooo00?o410@o`00
0?l000000ol00002ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool2o`000004ojVYZOlQ
8B7o0000ob4Q8@[ooooo00?o0000ooooooooool02_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Cooooo`00I?ooool00ol0003ooooo
ooooo`0Uooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd02?ooool00omEEEGoV9RH
ooooo`07ooooo`03oeEEEOn7QhOooooo01Gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`09ooooo`05
o`000?nj^[[ooooooiRHV?l@4100EOooool006;ooooo1?l000000ol@413oooooooooo`0Tooooo`03
ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool02?ooool00onj^[[oA4A4ooooo`07ooooo`03
ojVYZOlb<S;ooooo01Gooooo00?o410@okZj^_ooool06oooool00ol0003oooooooooo`0:ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool00omEEEGoIVIVo`00000;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0EOooool00:gooooo00?ok^k^o`000?o^k^h05Oooool01?nj^[[o410@o`000?l@410H
ooooo`03oa0@4?l0003o000008Cooooo002^ooooo`03odA4A?nHV9Sooooo0;Oooooo002^ooooo`03
oiRHV?m4A4Cooooo0;Oooooo002^ooooo`03onk^k_l0003o000000Wo0000[_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2.13454, -1.08487, \
0.0645864, 0.0132702}}]
}, Open  ]],

Cell["\<\
Both sets of functions oscillate and have a similar form to the \
Bessel functions of integer order encountered in cylindrical geometry. \
\>", \
"Text"],

Cell["\<\
\tSince we require that the potential be finite throughout the \
spherical domain, we need not consider the singular spherical Bessel \
functions further. (However, they are required for problems where the origin \
is not included in the domain of interest.) The radial part of the spherical \
eigenfunction is then\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`R(
          r)\  = \ \(\(J\_\(l + 1/2\)\)(\(\@\(-\[Lambda]\_\[Alpha]\)\) 
              r)\)/\@r, \ l = 0, 1, 2,  ... \)]],
  "."
}], "NE4",
  CellTags->"(4.3.57)"],

Cell[TextData[{
  "\tWe are  finally in a position to determine the eigenvalue",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Lambda]\_\[Alpha]\)\)\)]],
  ". The eigenvalue is determined by the boundary condition that the \
eigenmode ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  "vanishes at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ". Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R(a) = 0\)\(,\)\)\)]],
  " and when applied to Eq. ",
  ButtonBox["(4.3.57)",
    ButtonData:>{"Chapter4.nb", "(4.3.57)"},
    ButtonStyle->"Hyperlink"],
  " this condition implies that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha] = \(-\ \((j\_\(l + 1/2, \ n\)/a)\
\)\^2\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.58)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(l + 1/2, \ n\)\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_\(l + 1/2\)\)(x)\)]],
  ", satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_\(l + 1/2\)\)(j\_\(l + 1/2, \ n\)) = 0\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0\)]],
  " the zeros can be determined analytically using the trigonometric form of \
the spherical Bessel function given in Table ",
  ButtonBox["4.2",
    ButtonData:>"Table 4.2",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`j\_\(1/2, \ n\) = \ n\ \[Pi]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  "."
}], "NE4",
  CellTags->"(4.3.59)"],

Cell[TextData[{
  "However, for ",
  Cell[BoxData[
      \(TraditionalForm\`l = 1\)]],
  " or larger, the zeros must be found numerically. The intrinsic function ",
  StyleBox["BesselJZeros",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " still works to determine lists of these zeros:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< NumericalMath`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(BesselJZeros[3/2, 10]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.34"],

Cell[BoxData[
    \({4.493409457909063`, 7.725251836937703`, 10.90412165949781`, 
      14.066193912850048`, 17.220755271937392`, 20.37130295929039`, 
      23.519452498690374`, 26.6660542588134`, 29.811598790893374`, 
      32.956389039822724`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tFor a given value of ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " these radial eigenfunctions are orthogonal with respect to the radial \
inner product:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Integral]\_0\%R\(\(\( 
                      J\_\(l + 1/2\)\)(\(j\_\(l + 1/2, n\)\) 
                    r/a)\)\/\@r\) \(\(\(J\_\(l + 1/2\)\)(\(j\_\(l + 1/2, 
                        n\&_\)\) 
                    r/a)\)\/\@r\) \(r\^2\) \[DifferentialD]r\)\(=\)\(0\)\(\ \
\)\)\)]],
  "if ",
  Cell[BoxData[
      \(TraditionalForm\`n\  \[NotEqual] \ n\&_\)]],
  "."
}], "NE4",
  CellTags->"(4.3.60)"],

Cell[TextData[{
  "In fact, using  Eq. ",
  ButtonBox["(3.2.55)",
    ButtonData:>{"Chapter3.nb", "(3.2.55)"},
    ButtonStyle->"Hyperlink"],
  "  one can show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%R\(\(\( 
                      J\_\(l + 1/2\)\)(\(j\_\(l + 1/2, n\)\) 
                    r/a)\)\/\@r\) \(\(\(J\_\(l + 1/2\)\)(\(j\_\(l + 1/2, 
                        n\&_\)\) 
                    r/a)\)\/\@r\) \(r\^2\) \[DifferentialD]r = \
\(\[Delta]\_\(n\ n\&_\)\) \(a\^2\/2\) \(\(J\_\(l + 3/2\)\%2\)(
            j\_\(l + 1/2, n\))\)\)]],
  "."
}], "NE4",
  CellTags->{"i:70", "(4.3.61)"}],

Cell[TextData[{
  "\tWe can now combine our results for the radial and angular eigenmodes to \
obtain the full spherical eigenmode ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Psi]\_\[Alpha]\),
            "TraditionalForm"], "(", \(r, \[Theta], \[Phi]\), ")"}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(
          r, \[Theta], \[Phi]) = \(\(Y\_\(l, \ 
                m\)\)(\[Theta], \[Phi])\) \(\(J\_\(l + 
                    1/2\)\)(\(j\_\(l + 1/2, n\)\) r/a)\)/\@r\)]],
  "."
}], "NE4",
  CellTags->{"i:78", "(4.3.62)"}],

Cell[TextData[{
  "The parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ", used to enumerate the eigenmodes, can now be seen to be a list of three \
integers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \((l, m, n)\)\)]],
  ". The integer ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " runs from 0 to infinity, determining the \[Theta] dependence of the mode, \
while ",
  Cell[BoxData[
      \(TraditionalForm\`\(-l\) \[LessEqual] \ m \[LessEqual] \ l\)]],
  " determines the \[Phi]-dependence,  and ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  " counts the zeros in the radial mode."
}], "Text"],

Cell[TextData[{
  "\tAccording to Eqs ",
  ButtonBox["(4.3.61)",
    ButtonData:>"(4.3.61)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.40)",
    ButtonData:>{"Chapter3.nb", "(3.2.40)"},
    ButtonStyle->"Hyperlink"],
  ", these spherical eigenmodes are orthogonal with respect to the combined \
radial and angular inner products:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(l\ m\ n\)\%\(\(\ \ \)\(*\)\), \
\[Psi]\_\(l\&_\ m\&_\ n\&_\))\) = \(\[Integral]\_0\%R\( 
                  r\^2\) \[DifferentialD]r \(\[Integral]\_0\%\[Pi] 
                  sin\ \[Theta] \[DifferentialD]\[Theta]\ \
\(\[Integral]\_0\%\(2  \[Pi]\)\[DifferentialD]\[Phi]\ \(\(\[Psi]\_\(l\ m\ n\)\
\%\(\(\ \ \)\(*\)\)\)(
                        r, \[Theta], \[Phi])\) \(\(\[Psi]\_\(l\&_\ m\&_\ n\&_\
\)\)(r, \[Theta], \[Phi])\)\)\) = \(\[Delta]\_\(l  l\&_\)\) \(\[Delta]\_\(m 
                   m\&_\)\) \(\[Delta]\_\(n 
                   n\&_\)\) \(a\^2\/2\) \(\(\(J\_\(l + 3/2\)\%2\)(
                j\_\(l + 1/2, n\))\)\(.\)\)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.63)"],

Cell[TextData[{
  "However, this combined inner product is simply the three-dimensional \
integral over the volume ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " interior to the sphere. This is as expected from the general arguments \
given in Sec. ",
  ButtonBox["4.3.3",
    ButtonData:>"c:26",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example",
  FontWeight->"Bold"]], "Subsubsection"],

Cell[TextData[{
  "We now use the spherical eigenmodes to solve the following potential \
problem: the upper half of a hollow sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is filled with charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  ". The sphere is a conducting shell, cut in half at the equator. The upper \
half is grounded, and the lower half is held at  potential ",
  Cell[BoxData[
      \(TraditionalForm\`V\_o\)]],
  ". (See Fig. ",
  ButtonBox["4.6",
    ButtonData:>"Fig. 4.6",
    ButtonStyle->"Hyperlink"],
  " ) "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;j000322000`400?l00000o`00003oo`3ooooo
0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo
003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0
ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool0
0?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3o
oool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00
o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooolQ0?oo
o`l0P8207`00000?0820P?l0ooooWP3oool00?l0oooo703ooom700000?l0ooooV@3oool00?l0oooo
5`3ooomA00000?l0ooooU03oool00?l0oooo4P3ooomK00000?l0ooooS`3oool00?l0oooo2@3oool4
0820P0030410@000000000000680000000D0@4100820P020P800P8200<30`03o0?ooohD0oooo003o
0?ooo`@0ooooM`00003o0?oooh40oooo003o0?ooogl0000000<0P8200?ooo`3oool0o`3ooomj0?oo
o`00n`3oool00`20P800000000000024000000030820P03oool0oooo0?l0ooooMP3oool00?@0oooo
0`20P8000`10@40000000000002<000000<0P820o`3ooomb0?ooo`00l@3ooonK00000?l0ooooK`3o
ool00>h0oooo>`00000/0?ooocX00000o`3ooom/0?ooo`00j`3ooolf000000030820P03oool0oooo
03P0oooo=P00003o0?ooofT0oooo003V0?ooo`<0P820:P0000070820P4X0oooo1P20P80[00000080
P82000<0`<300?ooo`3oool0o`3ooomQ0?ooo`00h`3oool[00000640oooo:`00003o0?ooof40oooo
003Q0?ooobP00000J`3ooolX00000?l0ooooG`3oool00=l0oooo9@0000000`20P800oooo0?ooo`1b
0?ooobH00000o`3ooomL0?ooo`00g@3ooolT000007`0oooo8`00003o0?oooe/0oooo003H0?ooo`80
P820800000030820P8<0oooo1020P80O00000080P820o`3ooomF0?ooo`00e@3oool00`20P8000000
0000000O000008l0oooo00<0P8200000000000007`00003o0?oooe<0oooo003D0?ooob000000UP3o
oolP00000?l0ooooD@3oool00=40oooo00<0P8200000000000007@00002K0?ooob000000o`3ooom?
0?ooo`00cP3oool20820P1/000000`20P82Q0?ooo`<0P8206`0000020820P?l0ooooC03oool00<`0
oooo7@00002[0?oooad00000o`3ooom:0?ooo`00bP3ooolL000000030820P03oool0oooo0:h0oooo
7000003o0?ooodP0oooo00390?oooa/00000]@3ooolK000000030820P03oool0oooo0?l0ooooA03o
ool00<@0oooo00<0`<300820P00000006@0000020820P0030<30`03oool0oooo0;H0oooo00<0`<30
0820P00000006@0000020820P?l0oooo@P3oool00<80oooo700000310?ooo`030820P00000000000
01T00000o`3ooom00?ooo`00`03oool00`20P80000000000000H00000<L0oooo6`00003o0?oooch0
oooo002o0?oooaX00000b`3ooolK00000?l0oooo?03oool00;/0oooo00<0P8200410@00000005`00
00020820P=00oooo0P20P80H000000030820P03oool0oooo0?l0oooo=`3oool00;X0oooo6000003I
0?oooaT00000o`3ooolg0?ooo`00^03oool00`20P80000000000000F00000=`0oooo6000003o0?oo
ocH0oooo002g0?oooaL00000h@3ooolG00000?l0oooo=@3oool00;D0oooo6000003S0?ooo`030820
P0000000000001D00000o`3ooolc0?ooo`00/`3oool00`20P80000000000000C000000030410@020
P800oooo0>H0oooo0P20P80E000000030410@03oool0oooo0?l0oooo;`3oool00;40oooo5`00003]
0?oooaL00000o`3oool_0?ooo`00[`3oool00`20P80000000000000D00000?40oooo5`00003o0?oo
obd0oooo002^0?oooaH0000000<0P8200?ooo`3oool0lP3ooolF00000?l0oooo;03oool00:/0oooo
00<0`<300820P00000004`0000020820P?L0oooo0P20P80D00000080P820o`3ooolY0?ooo`00ZP3o
oolF00000?d0oooo00<0P8200000000000004`00003o0?ooobP0oooo002Y0?oooaD00000o`3oool2
0?oooaD00000o`3ooolW0?ooo`00Y`3oool00`20P80000000000000B000000030820P03oool0oooo
0?l0oooo0`3ooolE00000?l0oooo9@3oool00:D0oooo00<0P8200000000000004@0000020820P?l0
oooo203oool20820P1<0000000<0P8200?ooo`3oool0o`3ooolQ0?ooo`00X`3oool00`20P8000000
0000000B00000?l0oooo3P3oool00`20P80000000000000B00000?l0oooo8@3oool00:80oooo5000
003o0?oooa80oooo5000003o0?ooob00oooo002Q0?oooa<0000000<0P8200?ooo`3oool0o`3ooolC
0?oooa<00000o`3ooolO0?ooo`00WP3oool00`20P800@4100000000@00000080P820o`3ooolH0?oo
o`80P8204P0000000`20P800oooo0?ooo`3o0?oooaX0oooo002M0?oooa80000000<0P8200?ooo`3o
ool0o`3ooolM0?oooa800000o`3ooolK0?ooo`00V`3ooolD00000?l0oooo8@3ooolC00000?l0oooo
6@3oool009X0oooo4`00003o0?ooob@0oooo4`0000000`20P800oooo0?ooo`3o0?oooaD0oooo002I
0?oooa80000000<0P8200?ooo`3oool0o`3ooolU0?oooa800000o`3ooolG0?ooo`00UP3oool00`20
P80000000000000?00000080P820o`3ooolZ0?ooo`80P8204@0000000`20P800`<300?ooo`3o0?oo
oa80oooo002E0?oooa80000000<0P8200?ooo`3oool0o`3oool]0?ooo`030820P000000000000100
0000o`3ooolB0?ooo`00T`3ooolC00000?l0oooo<P3ooolC00000?l0oooo4@3oool00980oooo00<0
P8200000000000004000003o0?ooocD0oooo4P00003o0?oooa00oooo002@0?ooo`80P8204@000000
0`30`<00oooo0?ooo`3o0?ooocD0oooo00<0P8200000000000003P0000000`10@400P8200?ooo`3o
0?ooo`d0oooo002?0?oooa800000o`3oooll0?oooa800000o`3oool=0?ooo`00SP3oool00`20P800
00000000000?00000?l0oooo?`3ooolA00000?l0oooo303oool008h0oooo4@00003o0?oood00oooo
00<0P8200000000000003P0000000`20P800oooo0?ooo`3o0?ooo`T0oooo002;0?ooo`030820P000
0000000000l0000000<0P8200?ooo`3oool0o`3ooom10?oooa40000000<0P8200?ooo`3oool0o`3o
ool70?ooo`00RP3ooolB00000?l0ooooA`3ooolA00000?l0oooo203oool008T0oooo00<0P8200000
000000003P0000000`20P800oooo0?ooo`3o0?ooodL0oooo4@00003o0?ooo`L0oooo00280?oooa80
0000o`3ooom;0?oooa400000o`3oool60?ooo`00QP3oool00`20P80000000000000>000000030820
P03oool0oooo0?l0ooooC03oool20820P0l0000000<0P8200?ooo`3oool0o`3oool20?ooo`00Q@3o
oolA00000?l0ooooDP3oool00`20P80000000000000>000000030820P03oool0oooo0?l0oooo0024
0?oooa400000o`3ooomE0?oooa000000o`3oool20?ooo`00P`3oool@00000?l0ooooF03oool@0000
0?l0oooo0@3oool00880oooo400000000`20P800oooo0?ooo`3o0?oooeL0oooo00<0P82000000000
00003@00003o0?ooo`00P03oool00`20P80000000000000>000000030820P03oool0oooo0?l0oooo
F03oool00`30`<0000000000000>000000030410@03oool0oooo0?/0oooo001o0?oooa400000o`3o
oomO0?oooa000000o03oool007h0oooo400000000`20P800oooo0?ooo`3o0?oooel0oooo4@00003j
0?ooo`00O@3oool00`20P80000000000000>00000?l0ooooHP3oool00`20P80000000000000>0000
00030820P03oool0oooo0?L0oooo001k0?ooo`030820P0000000000000d000000P20P83o0?ooof@0
oooo0P20P80?000000030820P03oool0oooo0?H0oooo001j0?oooa000000o`3ooomZ0?oooa400000
mP3oool007T0oooo00<0P8200000000000003@0000000`20P800oooo0?ooo`3o0?ooofP0oooo00<0
P8200000000000003P0000000`20P800oooo0?ooo`3c0?ooo`00N@3oool@00000?l0ooooK03ooolA
00000?D0oooo001f0?ooo`030820P0000000000000`0000000<0@4100820P03oool0o`3ooom_0?oo
o`80P8203P0000020820P?80oooo001e0?oooa000000o`3ooomd0?ooo`030820P0000000000000h0
0000>P3oool500000;80oooo001d0?ooo`030820P0000000000000d00000o`3ooomf0?oooa000000
>P3oool500000;80oooo001d0?ooo`l00000o`3ooomh0?ooo`l0000000<0P8200?ooo`3oool0=`3o
ool500000840oooo1P00000[0?ooo`00LP3oool00`20P80000000000000<000000030410@03oool0
oooo0?l0ooooN03oool00`20P800@4100000000<000000030820P03oool0oooo03H0oooo1@00001n
0?ooo`050820P0000000000000000010@4001020P804000000030820P03oool0oooo02@0oooo001a
0?ooo`l00000o`3ooomn0?ooo`l00000=`3oool00`20P800000000000002000000030820P03oool0
oooo07X0oooo100000080?ooo`D00000903oool00700oooo00<0P8200000000000003000003o0?oo
oh00oooo3`00000f0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0N@3oool40000
00X0oooo1@00000S0?ooo`00L03oool>00000?l0ooooPP3oool>000000030820P03oool0oooo03<0
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`1h0?ooo`@00000303oool00`20P800
00000000000200000280oooo001_0?ooo`h0000000<0P8200?ooo`3oool0o`3ooon10?ooo`h00000
=@3oool00`20P800000000000002000000030820P03oool0oooo07P0oooo1000000=0?ooo`D00000
8@3oool006d0oooo00<0P820000000000000300000000`20P800oooo0?ooo`3o0?oooh80oooo00<0
`<30000000000000300000000`20P800oooo0?ooo`0a0?ooo`030<30`000000000000080000000<0
@4100?ooo`3oool0M`3oool01@20P8000000000000000000@41000h0oooo1@0000000`20P800oooo
0?ooo`0M0?ooo`00K03oool00`20P80000000000000<00000?l0ooooR03oool?000003<0oooo1@00
001i0?ooo`@0000000<0P8200?ooo`3oool03@3oool5000000030820P03oool0oooo01`0oooo001/
0?ooo`h00000o`3ooon:0?ooo`h0000000<0P8200?ooo`3oool0<03oool5000007T0oooo10000000
0`20P800oooo0?ooo`0>0?ooo`D000007P3oool006/0oooo3P0000000`20P800oooo0?ooo`3o0?oo
ohT0oooo3P00000b0?ooo`D00000N@3oool4000000030820P03oool0oooo00h0oooo1@00000N0?oo
o`00J03oool00`30`<0000000000000=000000030820P03oool0oooo0?l0ooooRP3oool00`30`<00
00000000000=000000030820P03oool0oooo02d0oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`1f0?ooo`@0000000<0P8200?ooo`3oool03P3oool00`20P800000000000003000001d0
oooo001X0?ooo`l00000o`3ooonA0?ooo`h0000000<0P8200?ooo`3oool0;@3oool5000007P0oooo
1@00000A0?ooo`H00000703oool006L0oooo3P00003o0?oooi@0oooo3P00000_0?ooo`D00000E03o
ool2000000030820P03oool0oooo01l0oooo1@00000A0?ooo`H00000703oool006H0oooo3P000000
0`20P800oooo0?ooo`3o0?oooi<0oooo3P00000/0?ooo`T0000000<0P8200?ooo`3oool0C`3oool2
000000030820P03oool0oooo01l0oooo1@00000B0?ooo`H000006`3oool006D0oooo00<0P8200000
000000002`0000000`20P800oooo0?ooo`3o0?oooi@0oooo00<0`<300000000000003000000W0?oo
o`030820P0000000000000h0000000<0P8200?ooo`3oool0B`3oool01020P800000000000020P80P
0?ooo`030410@00000000000008000004P3oool00`20P800000000000003000000030<30`03oool0
oooo01P0oooo001T0?ooo`030820P0000000000000/00000o`3ooonJ0?ooo`h000009@3oool60000
0080oooo1@0000000`3oool0000000000004000004d0oooo0`00000P0?ooo`030820P00000000000
00<000004P3oool5000000030820P03oool0oooo01P0oooo001T0?ooo`d00000o`3ooonL0?ooo`d0
000000<0P8200?ooo`3oool08@3oool6000000<0oooo1@0000030?ooo`H00000B`3oool4000001l0
oooo00<0P8200000000000000`00000B0?ooo`D0000000<0P8200?ooo`3oool0603oool006<0oooo
3@0000000`20P800oooo0?ooo`3o0?oooi/0oooo3@00000R0?ooo`H00000103oool5000000@0oooo
1@0000000`20P800oooo0?ooo`180?ooo`D000007P3oool00`20P800000000000003000001<0oooo
100000000`20P800oooo0?ooo`0H0?ooo`00H@3oool00`20P80000000000000;000000030820P03o
ool0oooo0?l0ooooW03oool00`30`<0000000000000;000000030820P03oool0oooo01d0oooo00<0
`<300000000000000`0000050?ooo`030820P00000000000008000001@3oool00`10@40000000000
0002000000030820P03oool0oooo04L0oooo1@0000000`20P800oooo0?ooo`0L0?ooo`H000004P3o
ool5000001X0oooo001P0?ooo`h00000o`3ooonR0?ooo`h000007P3oool00`20P800000000000002
000000L0oooo1@0000050?ooo`H00000B03oool6000001l0oooo1P00000A0?ooo`D000006P3oool0
05l0oooo00<0P8200000000000002`00003o0?oooj@0oooo3P00000M0?ooo`D000001`3oool50000
00H0oooo1P0000170?ooo`L000007P3oool600000140oooo1@00000J0?ooo`00G`3oool=00000003
0820P03oool0oooo0?l0ooooX`3oool=000000030820P03oool0oooo01X0oooo1@0000070?ooo`D0
00001P3oool6000004L0oooo2000000N0?ooo`D0000000<0P8200?ooo`3oool03P3oool00`20P800
000000000002000001X0oooo001N0?ooo`h00000o`3ooonV0?ooo`030820P0000000000000/00000
703oool5000000L0oooo1@0000070?ooo`D0000000<0P8200?ooo`3oool0A03oool8000001h0oooo
1@0000000`20P800oooo0?ooo`0>0?ooo`030820P00000000000008000006P3oool005`0oooo00<0
P8200000000000002`0000000`20P800oooo0?ooo`3o0?ooojH0oooo00<0P8200000000000002`00
00000`20P800oooo0?ooo`0H0?ooo`@0000000<0P8200?ooo`3oool01P3oool4000000L0oooo00<0
P8200000000000000P0000000`10@400oooo0?ooo`150?ooo`D0000000@0P820000000000000`<30
7@3oool00`10@40000000000000200000100oooo00<0P8200000000000000P00000J0?ooo`00G03o
ool=00000?l0oooo[03oool>000001P0oooo1@0000000`20P800oooo0?ooo`060?ooo`@0000000<0
P8200?ooo`3oool01@3oool5000004L0oooo1@000000103oool0000000000000000N0?ooo`D00000
3`3oool00`20P800000000000002000001X0oooo001K0?ooo`030820P0000000000000X0000000<0
P8200?ooo`3oool0o`3ooon[0?ooo`d00000603oool5000000030820P03oool0oooo00H0oooo1000
00000`20P800oooo0?ooo`050?ooo`030820P0000000000000<00000AP3oool500000080oooo0P00
000N0?ooo`H000003P3oool01@20P8000000000000000000P82001X0oooo001K0?ooo`d00000o`3o
oon^0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool05P3oool4000000030820P03o
ool0oooo00H0oooo00D0P82000000000000000000820P0070?ooo`030820P0000000000000<00000
AP3oool5000000<0oooo0P00000N0?ooo`H000003@3oool4000000030820P03oool0oooo01P0oooo
001I0?ooo`030820P0000000000000X0000000<0P8200?ooo`3oool0o`3ooon^0?ooo`030820P000
0000000000X0000000<0P8200?ooo`3oool05@3oool5000000P0oooo00D0P8200000000000000000
0820P0070?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0@`3oool5000000<0oooo
00<0P8200000000000007`3oool01@10@4000000000000000000`<3000`0oooo1000000K0?ooo`00
F03oool>00000?l0oooo/`3oool=000001H0oooo1@0000080?ooo`050820P0000000000000000020
P800203oool6000004D0oooo1@0000040?ooo`<000007`3oool5000000X0oooo1000000L0?ooo`00
E`3oool00`20P80000000000000;00000?l0oooo]03oool>000001D0oooo1@0000090?ooo`@00000
203oool6000004D0oooo1@0000050?ooo`<00000803oool4000000P0oooo1000000M0?ooo`00E`3o
ool=000000030820P03oool0oooo0?l0oooo/`3oool=000000030820P03oool0oooo0180oooo1@00
00090?ooo`@00000203oool6000004D0oooo00<0P8200000000000000`0000050?ooo`80000000<0
P8200?ooo`3oool07P3oool00`20P800000000000002000000@0oooo00<0P8200000000000000P00
000N0?ooo`00E@3oool00`20P80000000000000;000000030820P03oool0oooo0?l0oooo]03oool0
0`30`<0000000000000;000000030820P03oool0oooo0140oooo00<0P8200000000000000`000008
0?ooo`@00000203oool6000001<0oooo9020P80>0?ooo`030820P0000000000000<000001@3oool0
0`20P80000000410@00R0?ooo`<0P8201P0000020820P1l0oooo001E0?ooo`d00000o`3ooonj0?oo
o`d000004`3oool00`20P800000000000003000000P0oooo100000090?ooo`H000004P3ooolT0000
00h0oooo00<0P8200000000000000`0000070?ooo`800000B`3oool005@0oooo3@00003o0?oook`0
oooo3@00000C0?ooo`H00000203oool4000000P0oooo1P00000B0?ooob@000003P3oool00`20P800
000000000003000000L0oooo00<0P820000000000000BP3oool005<0oooo00<0P820000000000000
2`00003o0?oook`0oooo3P00000B0?ooo`H00000203oool4000000P0oooo1@0000150?ooo`030820
P0000000000000<000001`3oool00`20P80000000000001:0?ooo`00D`3oool<000000030410@03o
ool0oooo0?l0oooo_03oool00`20P80000000000000:000000030410@03oool0oooo0100oooo1P00
00070?ooo`@000001`3oool6000004D0oooo00<0P8200000000000000`0000080?ooo`040820P000
000000000<30`4P0oooo001B0?ooo`d00000o`3oooo00?ooo`030820P0000000000000X000004`3o
ool5000000030820P03oool0oooo00D0oooo0`0000070?ooo`H00000A@3oool00`20P80000000000
0003000000T0oooo0`0000180?ooo`00D@3oool=00000?l0oooo`P3oool=00000180oooo1@000000
0`20P800oooo0?ooo`050?ooo`<000001`3oool6000004D0oooo00<0P8200000000000000`00000:
0?ooo`800000B03oool00500oooo3@00003o0?oool@0oooo3@00000B0?ooo`D000001`3oool40000
00D0oooo00<0P8200000000000000`0000170?ooo`H000002P3oool2000004L0oooo001?0?ooo`03
0820P0000000000000/00000o`3oooo40?ooo`h000004@3oool00`20P800000000000003000000H0
oooo100000050?ooo`030820P0000000000000<00000A`3oool6000000X0oooo00<0P82000000000
0000AP3oool004l0oooo00<0@4100000000000002@0000000`10@400oooo0?ooo`3o0?oool@0oooo
00<0P8200000000000002P0000000`30`<00oooo0?ooo`0?0?ooo`030820P0000000000000<00000
00<0P8200?ooo`3oool00P3oool01020P80000000000000000050?ooo`D00000B03oool6000000X0
oooo00@0`<30000000000000P820A@3oool004h0oooo3@00003o0?ooolP0oooo00<0P82000000000
00002P00000C0?ooo`H0000000@0P8200?ooo`3oool0oooo0`0000040?ooo`D0000000<0P8200?oo
o`3oool0AP3oool6000000`0oooo0P0000000`20P800oooo0?ooo`120?ooo`00CP3oool=00000?l0
oooob@3oool<000001@0oooo00<0P820000000000000100000020?ooo`<000000P3oool7000004T0
oooo1P00000=0?ooo`800000A03oool004d0oooo3@00003o0?ooolX0oooo3@00000D0?oooa<00000
5`3ooolT000000l0oooo1P00000=0?ooo`800000A03oool004`0oooo00<0P8200000000000002@00
00000`20P800oooo0?ooo`3o0?ooolX0oooo00<0P8200000000000002@0000000`20P800oooo0?oo
o`0D0?ooo`80P8202P0000020820P1T0oooo9000000?0?ooo`H000003P3oool00`10@40000000820
P0120?ooo`00B`3oool<000000030820P03oool0oooo0?l0ooooc@3oool<000001X0oooo00@0P820
0000000000000000DP3oool6000000d0oooo00@0P8200000000000000000@@3oool004X0oooo00<0
P8200000000000002P0000000`20P800oooo0?ooo`3o0?ooold0oooo3@00000I0?ooo`040820P000
0000000000000580oooo1P00000>0?ooo`<00000@@3oool004X0oooo00<0P8200000000000002P00
003o0?ooom00oooo00<0P8200000000000002P00000I0?ooo`040820P0000000000000000580oooo
1P00000?0?ooo`80000000<0P8200?ooo`3oool0?P3oool004T0oooo00<0P8200000000000002@00
00000`20P800oooo0?ooo`3o0?ooom00oooo00<0P8200000000000002@0000000`10@400oooo0?oo
o`0G0?ooo`<0000000<0P8200?ooo`3oool0C`3oool600000100oooo0P0000000`20P800oooo0?oo
o`0m0?ooo`00B@3oool<00000?l0ooooe03oool<000001T0oooo0`0000000`20P800oooo0?ooo`1?
0?ooo`H000004@3oool2000003l0oooo00180?ooo``00000o`3ooooF0?ooo``00000603oool30000
00030820P03oool0oooo04l0oooo1P00000A0?ooo`030820P0000000000003h0oooo00170?ooo``0
000000<0P8200?ooo`3oool0o`3ooooE0?ooo``00000603oool2000000030820P03oool0oooo04l0
oooo1P00000A0?ooo`040820P00000000000000003d0oooo00160?ooo`030820P0000000000000X0
0000o`3ooooH0?ooo`030820P0000000000000X000005`3oool300000540oooo1P0000000`30`<00
oooo0?ooo`0?0?ooo`040820P00000000000000003`0oooo00160?ooo``00000o`3ooooJ0?ooo``0
000000<0P8200?ooo`3oool0503oool300000540oooo1P0000000`20P800oooo0?ooo`0@0?ooo`<0
000000<0P8200?ooo`3oool0>@3oool004D0oooo3000003o0?ooom`0oooo3000000G0?ooo`800000
D@3oool6000000030820P03oool0oooo0140oooo0`00000k0?ooo`00A@3oool<00000?l0oooog03o
ool<000001L0oooo0P00001A0?ooo`H0000000<0P8200?ooo`3oool04@3oool4000003X0oooo0014
0?ooo``00000o`3ooooN0?ooo``000005P3oool200000540oooo1`00000C0?ooo`H00000>03oool0
04<0oooo300000000`30`<00oooo0?ooo`3o0?ooomd0oooo00<0@4100000000000002@00000E0?oo
o`<00000CP3oool00`30`<0000000000000600000080P8203`3oool00`20P8000000000000050000
00030410@020P800oooo03D0oooo00120?ooo`030820P0000000000000X00000o`3ooooP0?ooo`03
0820P0000000000000X000005@3oool2000004X0oooo00<0P820000000000000400000090?ooo`h0
000000<0P8200?ooo`3oool0<@3oool00480oooo3000003o0?ooon80oooo300000000`20P800oooo
0?ooo`1N0?ooo`030820P00000000000010000002P3oool=000000030820P03oool0oooo0340oooo
00120?ooo`/00000o`3ooooT0?ooo`/0000000<0P8200?ooo`3oool0_03oool00400oooo00<0P820
0000000000002@0000000`20P800oooo0?ooo`3o0?ooon80oooo00<0P8200000000000002@000000
0`20P800oooo0?ooo`2k0?ooo`00@03oool<00000?l0ooooiP3oool<00000;d0oooo000o0?ooo``0
0000o`3ooooX0?ooo``00000_03oool003h0oooo00<0P8200000000000002@0000000`20P800oooo
0?ooo`3o0?ooonL0oooo3000002k0?ooo`00?P3oool00`10@400000000000009000000030<30`03o
ool0oooo0?l0ooooi`3oool00`10@400000000000009000000030<30`03oool0oooo0;P0oooo000m
0?ooo`d00000o`3ooooZ0?ooo`030820P0000000000000X00000^P3oool003d0oooo3000003o0?oo
on`0oooo3000002j0?ooo`00?03oool<00000?l0ooookP3oool<00000;T0oooo000k0?ooo`030820
P0000000000000T0000000<0P8200?ooo`3oool0o`3oooo/0?ooo`030820P0000000000000T00000
00<0P8200?ooo`3oool0]P3oool003/0oooo3000003o0?oooo00oooo3000002h0?ooo`00>P3oool<
000000030820P03oool0oooo0?l0ooook`3oool<00000;L0oooo000j0?ooo``00000o`3oooob0?oo
o`030820P0000000000000T0000000<0P8200?ooo`3oool0]03oool003T0oooo00<0P82000000000
00002P00003o0?oooo80oooo00<0P8200000000000002@0000000`20P800oooo0?ooo`2d0?ooo`00
>@3oool<00000?l0oooom03oool<00000;H0oooo000h0?ooo``00000o`3oooof0?ooo``00000]@3o
ool003P0oooo2`00003o0?ooooP0oooo2`00002e0?ooo`00=`3oool<00000?l0oooon03oool<0000
0;@0oooo000f0?ooo`030820P0000000000000T0000000<0P8200?ooo`3oool0o`3oooog0?ooo`/0
000000<0P8200?ooo`3oool0/@3oool003H0oooo3000003o0?ooooX0oooo00<0P820000000000000
2P00002b0?ooo`00=@3oool00`20P80000000000000900000?l0ooooo03oool<00000;80oooo000e
0?ooo`030820P0000000000000T00000o`3ooool0?ooo``0000000<0P8200?ooo`3oool0[`3oool0
03D0oooo2`00003o0?ooooh0oooo2`0000000`10@400oooo0?ooo`2_0?ooo`00=03oool;00000?l0
ooooo`3oool10?ooo`/00000/@3oool003@0oooo2`00003o0?ooool0oooo0P3oool;00000;00oooo
000c0?ooo`/0000000<0P8200?ooo`3oool0o`3ooooo0?ooo`/00000/03oool00380oooo00<0P820
0000000000002@00003o0?ooool0oooo0`3oool00`20P80000000000000900000:l0oooo000b0?oo
o`/00000o`3ooooo0?ooo`D0oooo3000002^0?ooo`00<@3oool00`20P80000000000000900000?l0
ooooo`3oool50?ooo``00000[P3oool00340oooo00<0P8200000000000002000003o0?ooool0oooo
1`3oool;000000030820P03oool0oooo0:/0oooo000a0?ooo`/00000o`3ooooo0?ooo`L0oooo2`00
00000`20P800oooo0?ooo`2[0?ooo`00<03oool00`20P80000000000000800000?l0ooooo`3oool9
0?ooo`/00000[@3oool00300oooo2P00003o0?ooool0oooo2`3oool;00000:`0oooo000_0?ooo`/0
0000o`3ooooo0?ooo`/0oooo2`00002/0?ooo`00;`3oool:000000030820P03oool0oooo0?l0oooo
o`3oool90?ooo`030820P0000000000000T00000Z`3oool002h0oooo2`0000000`30`<00oooo0?oo
o`3o0?ooool0oooo2@3oool00`30`<00000000000009000000030820P03oool0oooo0:P0oooo000]
0?ooo`030820P0000000000000T00000o`3ooooo0?ooo`d0oooo3000002Z0?ooo`00;@3oool00`20
P80000000000000800000?l0ooooo`3oool?0?ooo`/0000000<0P8200?ooo`3oool0Y`3oool002d0
oooo2`00003o0?ooool0oooo3`3oool;000000030820P03oool0oooo0:L0oooo000/0?ooo`030820
P0000000000000P00000o`3ooooo0?oooa40oooo2`00002Y0?ooo`00;03oool:00000?l0ooooo`3o
oolC0?ooo`/00000Z03oool002/0oooo2`00003o0?ooool0oooo4`3oool;00000:P0oooo000[0?oo
o`/00000o`3ooooo0?oooa@0oooo2`00002W0?ooo`00:P3oool;000000030820P03oool0oooo0?l0
ooooo`3ooolB0?ooo`/0000000<0P8200?ooo`3oool0Y03oool002T0oooo00<0P820000000000000
2@00003o0?ooool0oooo5@3oool00`20P80000000000000900000:H0oooo000Y0?ooo`030820P000
0000000000T00000o`3ooooo0?oooaD0oooo00<0P8200000000000002@00002V0?ooo`00:@3oool;
00000?l0ooooo`3ooolG0?ooo`/0000000<0P8200?ooo`3oool0X`3oool002T0oooo2P0000000`20
P800oooo0?ooo`3o0?ooool0oooo5@3oool00`20P800000000000008000000030820P03oool0oooo
0:<0oooo000X0?ooo`/00000o`3ooooo0?oooaT0oooo2`00002U0?ooo`00:03oool;00000?l0oooo
o`3ooolI0?ooo`/00000Y@3oool002P0oooo2P00003o0?ooool0oooo6`3oool:00000:D0oooo000W
0?ooo`/00000o`3ooooo0?oooa/0oooo2`00002T0?ooo`009`3oool:000000030820P03oool0oooo
0?l0ooooo`3ooolJ0?ooo`X0000000<0P8200?ooo`3oool0X@3oool002H0oooo2`0000000`20P800
oooo0?ooo`3o0?ooool0oooo6P3oool;00000:<0oooo000V0?ooo`/00000o`3ooooo0?oooad0oooo
00<0P8200000000000002000002S0?ooo`009@3oool<00000?l0ooooo`3ooolM0?ooo`030820P000
0000000000T00000XP3oool002D0oooo2`00003o0?ooool0oooo7`3oool;00000:80oooo000T0?oo
o`030820P0000000000000T00000o`3ooooo0?ooob00oooo2P0000000`20P800oooo0?ooo`2O0?oo
o`00903oool00`20P80000000000000800000?l0ooooo`3ooolQ0?ooo`X0000000<0P8200?ooo`3o
ool0W`3oool002@0oooo00<0P8200000000000002000003o0?ooool0oooo8@3oool:000000030820
P03oool0oooo09l0oooo000T0?ooo`X00000o`3ooooo0?ooob<0oooo2P00002Q0?ooo`00903oool:
00000?l0ooooo`3ooolT0?ooo`T00000X@3oool002<0oooo2`00003o0?ooool0oooo903oool:0000
0:00oooo000S0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?ooob80oooo00<0P82000000000
00001`00002P0?ooo`008P3oool00`20P800000000000008000000030820P03oool0oooo0?l0oooo
o`3ooolR0?ooo`030820P0000000000000L0000000<0P8200?ooo`3oool0W@3oool00280oooo2`00
003o0?ooool0oooo9@3oool00`20P800000000000008000009l0oooo000R0?ooo`/00000o`3ooooo
0?ooobH0oooo2`00002N0?ooo`008@3oool<00000?l0ooooo`3ooolV0?ooo`/00000WP3oool00240
oooo2`00003o0?ooool0oooo9`3oool;000009h0oooo000P0?ooo`030820P0000000000000T00000
o`3ooooo0?ooobP0oooo2`00002M0?ooo`00803oool00`20P80000000000000800000?l0ooooo`3o
oolY0?ooo`/00000W@3oool00200oooo2`00003o0?ooool0oooo:P3oool:000000030820P03oool0
oooo09X0oooo000P0?ooo`X00000o`3ooooo0?ooob/0oooo2P0000000`20P800oooo0?ooo`2J0?oo
o`007`3oool00`20P80000000000000800000?l0ooooo`3oool[0?ooo`X0000000<0@4100?ooo`3o
ool0VP3oool001l0oooo2P0000000`20P800oooo0?ooo`3o0?ooool0oooo:P3oool:000009`0oooo
000O0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?ooobX0oooo2P00002L0?ooo`007`3oool:
000000030820P03oool0oooo0?l0ooooo`3ooolZ0?ooo`X00000W03oool001h0oooo2`00003o0?oo
ool0oooo;@3oool00`20P800000000000008000009/0oooo000N0?ooo`/00000o`3ooooo0?ooobd0
oooo00<0P8200000000000002000002K0?ooo`007P3oool;00000?l0ooooo`3oool]0?ooo`030820
P0000000000000T00000VP3oool001d0oooo2`00003o0?ooool0oooo;`3oool;000009X0oooo000M
0?ooo`/00000o`3ooooo0?ooobl0oooo2`00002J0?ooo`00703oool00`20P8000000000000080000
0?l0ooooo`3ooola0?ooo`/00000V@3oool001`0oooo00<0P8200000000000002000003o0?ooool0
oooo<@3oool;000009T0oooo000L0?ooo`030820P0000000000000P00000o`3ooooo0?oooc40oooo
2`00002I0?ooo`00703oool00`20P80000000000000800000?l0ooooo`3ooolb0?ooo`X00000V@3o
ool001`0oooo2P00003o0?ooool0oooo<`3oool:000000030820P03oool0oooo09H0oooo000L0?oo
o`X00000o`3ooooo0?oooc<0oooo2P0000000`20P800oooo0?ooo`2F0?ooo`00703oool900000?l0
ooooo`3ooole0?ooo`T0000000<0P8200?ooo`3oool0UP3oool001/0oooo2P00003o0?ooool0oooo
=@3oool:000009P0oooo000K0?ooo`X00000o`3ooooo0?ooocD0oooo2P00002H0?ooo`006`3oool9
000000030820P03oool0oooo0?l0ooooo`3ooolc0?ooo`030820P0000000000000L00000V03oool0
01X0oooo2P0000000`20P800oooo0?ooo`3o0?ooool0oooo<`3oool00`20P8000000000000080000
09L0oooo000J0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?oooc<0oooo00<0P82000000000
00002000002G0?ooo`006P3oool:000000030<30`03oool0oooo0?l0ooooo`3ooolc0?ooo`030<30
`0000000000000P00000U`3oool001X0oooo2P00003o0?ooool0oooo=`3oool:000009L0oooo000I
0?ooo`/00000o`3ooooo0?ooocL0oooo2`00002F0?ooo`006@3oool;00000?l0ooooo`3ooolg0?oo
o`/00000UP3oool001T0oooo2P0000000`20P800oooo0?ooo`3o0?ooool0oooo=@3oool00`20P800
000000000008000009H0oooo000H0?ooo`030820P0000000000000P00000o`3ooooo0?ooocT0oooo
2`00002E0?ooo`00603oool00`20P80000000000000800000?l0ooooo`3oooli0?ooo`/00000U@3o
ool001P0oooo00<0P8200000000000002000003o0?ooool0oooo>@3oool;000009D0oooo000H0?oo
o`030820P0000000000000L00000o`3ooooo0?oooc/0oooo2P00002E0?ooo`00603oool00`10@400
00000000000700000?l0ooooo`3ooolk0?ooo`X0000000<0`<300?ooo`3oool0TP3oool001P0oooo
2P00003o0?ooool0oooo>`3oool:000000030820P03oool0oooo0980oooo000H0?ooo`X00000o`3o
oooo0?oooc`0oooo2@0000000`20P800oooo0?ooo`2B0?ooo`00603oool900000?l0ooooo`3ooolm
0?ooo`T0000000<0P8200?ooo`3oool0TP3oool001L0oooo2P00003o0?ooool0oooo?@3oool:0000
09@0oooo000G0?ooo`X00000o`3ooooo0?ooocd0oooo2P00002D0?ooo`005`3oool:00000?l0oooo
o`3ooolm0?ooo`X00000U03oool001L0oooo2P00003o0?ooool0oooo?P3oool9000009@0oooo000F
0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?oooc`0oooo2P00002C0?ooo`005P3oool:0000
00030820P03oool0oooo0?l0ooooo`3oooll0?ooo`X00000T`3oool001H0oooo2P0000000`20P800
oooo0?ooo`3o0?ooool0oooo?03oool:000009<0oooo000E0?ooo`/0000000<0P8200?ooo`3oool0
o`3ooooo0?oooc`0oooo2`00002B0?ooo`005@3oool;000000030<30`03oool0oooo0?l0ooooo`3o
ooll0?ooo`030820P0000000000000P00000TP3oool001D0oooo2`00003o0?ooool0oooo?`3oool0
0`20P80000000000000800000980oooo000E0?ooo`/00000o`3ooooo0?ooocl0oooo00<0P8200000
000000002000002B0?ooo`005@3oool;00000?l0ooooo`3ooolo0?ooo`030820P0000000000000P0
0000TP3oool001D0oooo2`00003o0?ooool0oooo?`3oool00`20P80000000000000800000980oooo
000D0?ooo`030820P0000000000000P0000000<0P8200?ooo`3oool0o`3ooooo0?oooch0oooo2`00
002A0?ooo`00503oool00`20P80000000000000800000?l0ooooo`3ooom10?ooo`/00000T@3oool0
01@0oooo00<0P8200000000000002000003o0?ooool0oooo@@3oool;00000940oooo000D0?ooo`03
0820P0000000000000P00000o`3ooooo0?oood40oooo2`00002A0?ooo`00503oool00`20P8000000
0000000800000?l0ooooo`3ooom10?ooo`030820P0000000000000P00000T@3oool001@0oooo00<0
P8200000000000001`00003o0?ooool0oooo@`3oool:00000940oooo000D0?ooo`030820P0000000
000000L00000o`3ooooo0?oood<0oooo2P00002A0?ooo`00503oool:00000?l0ooooo`3ooom30?oo
o`X0000000<0P8200?ooo`3oool0SP3oool001@0oooo2P00003o0?ooool0oooo@`3oool:00000003
0820P03oool0oooo08h0oooo000D0?ooo`X00000o`3ooooo0?oood@0oooo2@0000000`20P800oooo
0?ooo`2>0?ooo`00503oool900000?l0ooooo`3ooom50?ooo`T0000000<0P8200?ooo`3oool0SP3o
ool001@0oooo2@00003o0?ooool0ooooA@3oool9000000030820P03oool0oooo08h0oooo000D0?oo
o`T00000o`3ooooo0?ooodD0oooo2@0000000`20P800oooo0?ooo`2>0?ooo`00503oool900000?l0
ooooo`3ooom50?ooo`T0000000<0P8200?ooo`3oool0SP3oool001@0oooo2@00003o0?ooool0oooo
A@3oool9000000030820P03oool0oooo08h0oooo000C0?ooo`X00000o`3ooooo0?ooodD0oooo2P00
002@0?ooo`004`3oool:00000?l0ooooo`3ooom50?ooo`X00000T03oool001<0oooo2P00003o0?oo
ool0ooooA@3oool:00000900oooo000C0?ooo`X00000o`3ooooo0?ooodD0oooo2P00002@0?ooo`00
4`3oool:00000?l0ooooo`3ooom60?ooo`T00000T03oool001<0oooo2@0000000`20P800oooo0?oo
o`3o0?ooool0ooooA03oool900000900oooo000C0?ooo`T0000000<0P8200?ooo`3oool0o`3ooooo
0?oood@0oooo2@00002@0?ooo`004P3oool:000000030820P03oool0oooo0?l0ooooo`3ooom40?oo
o`X00000S`3oool00180oooo2P0000000`20P800oooo0?ooo`3o0?ooool0ooooA03oool:000008l0
oooo000B0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?oood@0oooo2P00002?0?ooo`004P3o
ool:000000030820P03oool0oooo0?l0ooooo`3ooom40?ooo`X00000S`3oool00180oooo2P000000
0`20P800oooo0?ooo`3o0?ooool0ooooA03oool:000008l0oooo000B0?ooo`X0000000<0P8200?oo
o`3oool0o`3ooooo0?oood@0oooo2P00002?0?ooo`004P3oool:000000030820P03oool0oooo0?l0
ooooo`3ooom40?ooo`X00000S`3oool00180oooo2P0000000`20P800oooo0?ooo`3o0?ooool0oooo
A03oool:000008l0oooo000B0?ooo`X0000000<0P8200?ooo`3oool0o`3ooooo0?oood@0oooo2P00
002?0?ooo`004P3oool:000000030820P03oool0oooo0?l0ooooo`3ooom40?ooo`X00000S`3oool0
0180oooo2P0000000`20P800oooo0?ooo`3o0?ooool0ooooA03oool:000008l0oooo000B0?ooo`X0
000000<0P8200?ooo`3oool0o`3ooooo0?oood@0oooo2P00002?0?ooo`004P3oool:000000030820
P03oool0oooo0?l0ooooo`3ooom40?ooo`030410@0000000000000L00000S`3oool00180oooo2P00
003o0?ooool0ooooA`3oool00`20P800000000000007000008l0oooo000B0?ooo`X00000o`3ooooo
0?ooodL0oooo00<0P8200000000000001`00002?0?ooo`004P3oool:00000?l0ooooo`3ooom70?oo
o`030820P0000000000000L00000S`3oool00180oooo2P00003o0?ooool0ooooA`3oool00`20P800
000000000007000008l0oooo000B0?ooo`X00000o`3ooooo0?ooodL0oooo00<0P820000000000000
1`00002?0?ooo`004P3oool:00000?l0ooooo`3ooom70?ooo`030820P0000000000000L00000S`3o
ool00180oooo2P00003o0?ooool0ooooA`3oool00`20P800000000000007000008l0oooo003o0?oo
odP0oooo00<0@41000000020P800o`3ooona0?ooo`00o`3ooom70?ooo`D00000o`3ooon`0?ooo`00
o`3ooom70?ooo`D0000000<0P8200?ooo`3oool0o`3ooon]0?ooo`00o`3ooom10?ooo`<0000000<0
P8200?ooo`0000001`00003o0?ooojh0oooo003o0?oood40oooo0`0000000`10@400000000000008
000000030820P03oool0oooo0?l0ooooZP3oool00?l0oooo@@3oool?000000030820P03oool0oooo
0?l0ooooZ@3oool00?l0oooo@@3oool@00000?l0ooooZ`3oool00?l0oooo@@3ooolA00000?l0oooo
ZP3oool00?l0oooo@@3ooolB00000?l0ooooZ@3oool00180oooo2P20P83o0?ooobD0oooo0`000002
0820P0h0000000<0P8200?ooo`3oool0o`3oool<0?ooo`030<30`020P800P82000L0P820S`3oool0
0180oooo2P00003o0=SHf2D0f=SH0`000000101/K6`0f=SH0=SHf03Hf=P=0000000306a/K03Hf=P0
f=SH0?l0f=SH2`3Hf=P00`1/K6`0000000000007000008l0oooo000B0?ooo`X00000o`3Hf=PU0=SH
f0<0000000D0K6a/0=SHf03Hf=P0f=SH06a/K00>00000?l0f=SH303Hf=P00`1/K6`0000000000007
000008l0oooo000B0?ooo`X00000o`3Hf=PU0=SHf0<0000000<0K6a/0=SHf03Hf=P00P3Hf=P?0000
0?l0f=SH2`3Hf=P00`1/K6`0000000000007000008l0oooo000B0?ooo`X00000o`3Hf=PU0=SHf0<0
000000<0K6a/0=SHf03Hf=P00`3Hf=P00`1/K6`000000000000<000000030::RXP3Hf=P0f=SH0?l0
f=SH1`3Hf=P00`1/K6`0000000000007000008l0oooo000B0?ooo`X00000o`3Hf=PU0=SHf0<00000
00<0K6a/0=SHf03Hf=P01@3Hf=P>00000?l0f=SH2@3Hf=P00`1/K6`0000000000007000008l0oooo
000B0?ooo`X00000o`3Hf=PU0=SHf0<0000000<0K6a/0=SHf03Hf=P01@3Hf=P00`1/K6`000000000
000<00000?l0f=SH203Hf=P00`1/K6`0000000000007000008l0oooo000B0?ooo`X00000o`3Hf=PU
0=SHf0<0000000<0K6a/0=SHf03Hf=P01P3Hf=P?00000?l0f=SH1`3Hf=P00`1/K6`0000000000007
000008l0oooo000B0?ooo`X0000000<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SH
f03Hf=P01`3Hf=P00`1/K6`000000000000<000000030::RXP3Hf=P0f=SH0?l0f=SH0`3Hf=P00`0f
=SH0000000000007000008l0oooo000B0?ooo`X0000000<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0
000000<0K6a/0=SHf03Hf=P02@3Hf=P00`1/K6`000000000000;00000?l0f=SH1@3Hf=P:000008l0
oooo000B0?ooo`X0000000<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P0
2P3Hf=P?00000?l0f=SH0`3Hf=P:000008l0oooo000B0?ooo`X0000000<0K6a/0=SHf03Hf=P0o`3H
f=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P02`3Hf=P?00000?l0f=SH0P3Hf=P:000008l0oooo000B
0?ooo`X0000000<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P0303Hf=P0
0`1/K6`000000000000;0000000303Hf=P3Hf=P0f=SH0?h0f=SH2P00002?0?ooo`004P3oool:0000
000306a/K03Hf=P0f=SH0?l0f=SH8P3Hf=P30000000306a/K03Hf=P0f=SH00h0f=SH3P00003o0=SH
f0X00000S`3oool00180oooo2P0000000`1/K6`0f=SH0=SHf03o0=SHf280f=SH0`0000000`1/K6`0
f=SH0=SHf00>0=SHf00306a/K0000000000000`00000oP3Hf=P:000008l0oooo000B0?ooo`X00000
00<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P03`3Hf=P?00000?d0f=SH
2P00002?0?ooo`004P3oool:0000000306a/K03Hf=P0f=SH0?l0f=SH8P3Hf=P30000000306a/K03H
f=P0f=SH0100f=SH3P0000000`1/K6`0f=SH0=SHf03j0=SHf0X00000S`3oool00180oooo2P000000
0`1/K6`0f=SH0=SHf03o0=SHf280f=SH0`0000000`1/K6`0f=SH0=SHf00A0=SHf00306a/K00f=SH0
000000/0000000<0K6a/0=SHf03Hf=P0n@3Hf=P:000008l0oooo000B0?ooo`X0000000<0K6a/0=SH
f03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P04`3Hf=P?00000?T0f=SH2P00002?0?oo
o`004P3oool:0000000306a/K03Hf=P0f=SH0?l0f=SH8P3Hf=P30000000306a/K03Hf=P0f=SH01@0
f=SH3`00003h0=SHf0X00000S`3oool001<0oooo2@0000000`1/K6`0f=SH0=SHf03o0=SHf280f=SH
0`0000000`1/K6`0f=SH0=SHf00E0=SHf0h0000000<0K6a/0=SHf03Hf=P0m@3Hf=P900000900oooo
000C0?ooo`T0000000<0K6a/0=SHf03Hf=P0o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03Hf=P05P3H
f=P00`0f=SH000000000000;0000000306a/K03Hf=P0f=SH0?@0f=SH2@00002@0?ooo`004`3oool:
00000?l0f=SH903Hf=P30000000306a/K03Hf=P0f=SH01L0f=SH3`00003e0=SHf0T00000T03oool0
01<0oooo2P00003o0=SHf2@0f=SH0`0000000`1/K6`0f=SH0=SHf00H0=SHf0l00000l`3Hf=P:0000
0900oooo000C0?ooo`X00000o`3Hf=PT0=SHf0<0000000<0K6a/0=SHf03Hf=P06@3Hf=P>00000003
06a/K03Hf=P0f=SH0?00f=SH2P00002@0?ooo`004`3oool:00000?l0f=SH903Hf=P30000000306a/
K03Hf=P0f=SH01X0f=SH00<0K6a/0000000000002`0000000`1/K6`0f=SH0=SHf03_0=SHf0X00000
T03oool001<0oooo2P00003o0=SHf2@0f=SH0`0000000`1/K6`0f=SH0=SHf00L0=SHf0l00000k`3H
f=P:00000900oooo000D0?ooo`T00000o`3Hf=PT0=SHf0<0000000<0K6a/0=SHf03Hf=P07@3Hf=P>
0000000306a/K03Hf=P0f=SH0>`0f=SH2@0000000`20P800oooo0?ooo`2>0?ooo`00503oool90000
0?l0f=SH903Hf=P30000000306a/K03Hf=P0f=SH01h0f=SH3P00003^0=SHf0T0000000<0P8200?oo
o`3oool0SP3oool001@0oooo2@00003o0=SHf2@0f=SH0`0000000`1/K6`0f=SH0=SHf00N0=SHf003
0::RXP000000000000`0000000<0K6a/0=SHf03Hf=P0jP3Hf=P9000000030820P03oool0oooo08h0
oooo000D0?ooo`T00000o`3Hf=PT0=SHf0<0000000<0K6a/0=SHf03Hf=P0803Hf=P?00000>/0f=SH
2@0000000`20P800oooo0?ooo`2>0?ooo`00503oool900000?l0f=SH903Hf=P30000000306a/K03H
f=P0f=SH0240f=SH3P0000000`1/K6`0f=SH0=SHf03X0=SHf0T0000000<0P8200?ooo`3oool0SP3o
ool001@0oooo2P00003o0=SHf2<0f=SH0`0000000`1/K6`0f=SH0=SHf00R0=SHf0h00000jP3Hf=P9
000000030820P03oool0oooo08h0oooo000D0?ooo`X00000o`3Hf=PS0=SHf0<0000000<0K6a/0=SH
f03Hf=P08`3Hf=P>00000>P0f=SH2P0000000`20P800oooo0?ooo`2>0?ooo`00503oool00`10@400
00000000000700000?l0f=SH8`3Hf=P30000000306a/K03Hf=P0f=SH02@0f=SH00<0K6a/00000000
0000300000000`2RXZ80f=SH0=SHf03S0=SHf0X0000000<0P8200?ooo`3oool0SP3oool001@0oooo
00<0P8200000000000001`00003o0=SHf2<0f=SH0`0000000`1/K6`0f=SH0=SHf00V0=SHf0h00000
i@3Hf=P:00000940oooo000D0?ooo`030820P0000000000000L00000o`3Hf=PS0=SHf0<0000000<0
K6a/0=SHf03Hf=P09`3Hf=P>00000>@0f=SH2P00002A0?ooo`00503oool00`20P800000000000008
00000?l0f=SH8P3Hf=P30000000306a/K03Hf=P0f=SH02L0f=SH00<0K6a/0000000000003000003S
0=SHf0X00000T@3oool001@0oooo00<0P8200000000000002000003o0=SHf280f=SH0`0000000`1/
K6`0f=SH0=SHf00X0=SHf00306a/K0000000000000`0000000<0K6a/0=SHf03Hf=P0gP3Hf=P;0000
0940oooo000D0?ooo`030820P0000000000000P00000o`3Hf=PR0=SHf0<0000000<0K6a/0=SHf03H
f=P0:P3Hf=P>0000000306a/K03Hf=P0f=SH0=d0f=SH2`00002A0?ooo`00503oool00`20P8000000
0000000800000?l0f=SH8P3Hf=P30000000306a/K03Hf=P0f=SH02/0f=SH3P00003O0=SHf0/00000
T@3oool001@0oooo00<0P8200000000000002000003o0=SHf280f=SH0`0000000`1/K6`0f=SH0=SH
f00Z0=SHf1000000gP3Hf=P;00000940oooo000D0?ooo`030<30`0000000000000T00000o`3Hf=PQ
0=SHf0<0000000<0K6a/0=SHf03Hf=P0:03Hf=P00`1/K6`000000000000A000000030::RXP3Hf=P0
f=SH0=P0f=SH00<0XZ:R000000000000200000000`20P800oooo0?ooo`2?0?ooo`005@3oool;0000
0?l0f=SH8@3Hf=P30000000306a/K03Hf=P0f=SH02L0f=SH1P0000020=SHf0h00000fP3Hf=P00`1/
K6`000000000000800000980oooo000E0?ooo`/00000o`3Hf=PQ0=SHf0<0000000<0K6a/0=SHf03H
f=P09P3Hf=P6000000<0f=SH00<0K6a/0000000000003000003I0=SHf00306a/K0000000000000P0
0000TP3oool001D0oooo2`00003o0=SHf240f=SH0`0000000`1/K6`0f=SH0=SHf00T0=SHf0L00000
00<0K6a/0=SHf03Hf=P00P3Hf=P?00000=P0f=SH00<0K6a/0000000000002000002B0?ooo`005@3o
ool;000000030::RXP3Hf=P0f=SH0?l0f=SH7P3Hf=P30000000306a/K03Hf=P0f=SH0280f=SH00<0
K6a/03Hf=P000000100000000`1/K6`0f=SH0=SHf0050=SHf00306a/K0000000000000`0000000<0
XZ:R0=SHf03Hf=P0e03Hf=P00`1/K6`000000000000800000980oooo000E0?ooo`/0000000<0K6a/
0=SHf03Hf=P0o`3Hf=PN0=SHf0<0000000<0K6a/0=SHf03Hf=P0803Hf=P8000000/0f=SH3P00003F
0=SHf0/00000TP3oool001H0oooo2P0000000`1/K6`0f=SH0=SHf03o0=SHf1h0f=SH0`0000000`1/
K6`0f=SH0=SHf00N0=SHf00306a/K0000000000000D000003@3Hf=P00`1/K6`000000000000<0000
0=D0f=SH2P00002C0?ooo`005P3oool:0000000306a/K03Hf=P0f=SH0?l0f=SH7P3Hf=P300000003
06a/K03Hf=P0f=SH01d0f=SH2000000@0=SHf0h00000e03Hf=P:000009<0oooo000F0?ooo`X00000
00<0K6a/0=SHf03Hf=P0o`3Hf=PN0=SHf0<0000000<0K6a/0=SHf03Hf=P0703Hf=P70000000306a/
K03Hf=P0f=SH0100f=SH3P0000000`1/K6`0f=SH0=SHf03@0=SHf0X00000T`3oool001H0oooo00<0
P8200000000000001`0000000`0f=SH0f=SH0=SHf03o0=SHf1h0f=SH0`0000000`1/K6`0f=SH0=SH
f00I0=SHf00306a/K00f=SH0000000@000000P1/K6`E0=SHf00306a/K0000000000000/0000000<0
K6a/0=SHf03Hf=P0c`3Hf=P9000000030820P03oool0oooo0940oooo000G0?ooo`X00000o`3Hf=PP
0=SHf0<0000000<0K6a/0=SHf03Hf=P05P3Hf=P00`1/K6`00000000000050000000306a/K03Hf=P0
f=SH01L0f=SH00<0K6a/0000000000003000003?0=SHf0X00000U03oool001L0oooo2P00003o0=SH
f200f=SH0`0000000`1/K6`0f=SH0=SHf00C0=SHf0/000006`3Hf=P?00000<h0f=SH2P00002D0?oo
o`005`3oool:00000?l0f=SH803Hf=P30000000306a/K03Hf=P0f=SH0140f=SH2`00000N0=SHf0h0
000000<0K6a/0=SHf03Hf=P0b`3Hf=P:000009@0oooo000G0?ooo`030820P0000000000000L00000
o`3Hf=PP0=SHf0<0000000<0K6a/0=SHf03Hf=P02`3Hf=P306a/K00303Hf=P000000000000L00000
0P1/K6`00`2RXZ80f=SH0=SHf00N0=SHf00306a/K0000000000000/0000000<0K6a/0=SHf03Hf=P0
bP3Hf=P9000000030410@03oool0oooo0980oooo000H0?ooo`X00000o`3Hf=PO0=SHf0<0000000<0
K6a/0=SHf03Hf=P0103Hf=PA000002L0f=SH00<0K6a/0000000000003000003;0=SHf0T0000000<0
P8200?ooo`3oool0TP3oool001P0oooo2P00003o0=SHf1l0f=SH6000000/0=SHf0h00000b@3Hf=P:
000000030820P03oool0oooo0980oooo000H0?ooo`X00000o`3Hf=PO0=SHf1D00000<03Hf=P>0000
000306a/K03Hf=P0f=SH0<D0f=SH2P0000000`20P800oooo0?ooo`2B0?ooo`00603oool00`20P800
00000000000700000?l0f=SH7`3Hf=P:000000P0K6a/=03Hf=P00`0f=SH000000000000;00000003
06a/K03Hf=P0f=SH0<@0f=SH2P00002E0?ooo`00603oool00`20P80000000000000800000?l0f=SH
7P3Hf=P30000000306a/K03Hf=P0f=SH0440f=SH3`0000340=SHf0/00000U@3oool001P0oooo00<0
P8200000000000002000003o0=SHf1h0f=SH0`0000000`1/K6`0f=SH0=SHf0120=SHf0l00000``3H
f=P;000009D0oooo000H0?ooo`030820P0000000000000P00000o`3Hf=PN0=SHf0<0000000<0K6a/
0=SHf03Hf=P0@`3Hf=P>0000000306a/K03Hf=P0f=SH0<00f=SH2`00002E0?ooo`006@3oool:0000
000306a/K03Hf=P0f=SH0?l0f=SH6`3Hf=P30000000306a/K03Hf=P0f=SH04@0f=SH00<0=SHf0000
000000002`0000000`1/K6`0f=SH0=SHf02n0=SHf00306a/K0000000000000P00000UP3oool001T0
oooo2`00003o0=SHf1d0f=SH0`0000000`1/K6`0f=SH0=SHf0150=SHf0l00000_`3Hf=P;000009H0
oooo000I0?ooo`/00000o`3Hf=PM0=SHf0<0000000<0K6a/0=SHf03Hf=P0A`3Hf=P>00000;h0f=SH
2`00002F0?ooo`006P3oool:00000?l0f=SH7@3Hf=P30000000306a/K03Hf=P0f=SH04P0f=SH3P00
002m0=SHf0X00000U`3oool001X0oooo2P00003o0=SHf1d0f=SH0`0000000`1/K6`0f=SH0=SHf018
0=SHf00306a/K0000000000000`00000_03Hf=P:000009L0oooo000J0?ooo`X0000000<0K6a/0=SH
f03Hf=P0o`3Hf=PJ0=SHf0<0000000<0K6a/0=SHf03Hf=P05P3Hf=P00`1/K6`00000000000050000
000303Hf=P1/K6`0K6a/02P0f=SH00<0K6a/000000000000300000000`1/K6`0f=SH0=SHf02g0=SH
f00306a/K0000000000000P00000U`3oool001X0oooo2P0000000`1/K6`0f=SH0=SHf03o0=SHf1X0
f=SH0`0000000`1/K6`0f=SH0=SHf00D0=SHf0@000001@3Hf=P5000002T0f=SH3P0000000`1/K6`0
f=SH0=SHf02f0=SHf00306a/K0000000000000P00000U`3oool001/0oooo2@0000000`1/K6`0f=SH
0=SHf03o0=SHf1X0f=SH0`0000000`1/K6`0f=SH0=SHf00C0=SHf0@000001`3Hf=P00`1/K6`00000
000000020000000306a/K03Hf=P0f=SH02H0f=SH3P00002h0=SHf00306a/K0000000000000L00000
V03oool001/0oooo2P00003o0=SHf1`0f=SH0`0000000`1/K6`0f=SH0=SHf00B0=SHf00506a/K000
000000000000001/K6`02@3Hf=P4000002T0f=SH3P00002g0=SHf0X00000V03oool001/0oooo2P00
003G0=SHf0L0K6a/?@3Hf=P30000000306a/K03Hf=P0f=SH0180f=SH1000000;0=SHf0@0000000<0
K6a/0=SHf03Hf=P09@3Hf=P00`2RXZ8000000000000<0000000306a/K03Hf=P0f=SH0;<0f=SH2P00
002H0?ooo`00703oool900000=H0f=SH2`00000j0=SHf0<0000000<0K6a/0=SHf03Hf=P04@3Hf=P5
000000`0f=SH1@00000Y0=SHf0d0000000<0K6a/0=SHf03Hf=P0/P3Hf=P9000000030820P03oool0
oooo09H0oooo000L0?ooo`X00000d`3Hf=P5000000D0f=SH1@00000h0=SHf0<0000000<0K6a/0=SH
f03Hf=P04@3Hf=P5000000d0f=SH100000000`1/K6`0f=SH0=SHf00W0=SHf0h00000/P3Hf=P:0000
00030820P03oool0oooo09H0oooo000L0?ooo`X00000dP3Hf=P4000000P0f=SH00<0K6a/00000000
00000P00000g0=SHf0<0000000<0K6a/0=SHf03Hf=P0403Hf=P5000000h0f=SH1@00000Y0=SHf003
06a/K0000000000000`00000/@3Hf=P:000000030820P03oool0oooo09H0oooo000L0?ooo`030410
@0000000000000L00000d@3Hf=P01@0f=SH00000000000000000XZ:R00T0f=SH0P1/K6`300000080
K6a/=03Hf=P30000000306a/K03Hf=P0f=SH0100f=SH1@00000>0=SHf00306a/K000000000000080
000000<0K6a/0=SHf03Hf=P09`3Hf=P00`1/K6`000000000000<0000000306a/K03Hf=P0f=SH0:d0
f=SH2P0000000`30`<00oooo0?ooo`2F0?ooo`00703oool00`20P80000000000000800000=00f=SH
1000000=0=SHf0@0000000<0K6a/0=SHf03Hf=P0<@3Hf=P30000000306a/K03Hf=P0f=SH0100f=SH
1@00000>0=SHf00306a/K0000000000000@00000:P3Hf=P>0000000306a/K03Hf=P0f=SH0:/0f=SH
2`00002I0?ooo`00703oool00`20P80000000000000800000<l0f=SH1@00000=0=SHf00306a/K000
0000000000800000<`3Hf=P30000000306a/K03Hf=P0f=SH0100f=SH1@00000?0=SHf0H00000:`3H
f=P>00000:d0f=SH2`00002I0?ooo`00703oool00`20P800000000000008000004D0f=SH00<0K6a/
0000000000000`00001K0=SHf0D00000903Hf=P4000000h0f=SH00<0K6a/0000000000000`00000b
0=SHf0<0000000<0K6a/0=SHf03Hf=P0403Hf=P5000000l0f=SH1`00000Z0=SHf00306a/K0000000
000000`00000[03Hf=P;000009T0oooo000M0?ooo`/00000A@3Hf=P6000005X0f=SH00<0K6a/0000
000000000`00000R0=SHf0D000003`3Hf=P00`1/K6`00000000000030000000306a/K03Hf=P0f=SH
02h0f=SH0`0000000`1/K6`0f=SH0=SHf00?0=SHf00306a/K0000000000000@000003P3Hf=P00`1/
K6`0000000000004000000030::RXP3Hf=P0f=SH02P0f=SH00<0K6a/000000000000300000000`1/
K6`0f=SH0=SHf02W0=SHf0/00000VP3oool001d0oooo2`0000150=SHf0H00000FP3Hf=P00`1/K6`0
00000000000300000280f=SH1@00000@0=SHf0H00000<03Hf=P30000000306a/K03Hf=P0f=SH00l0
f=SH1`00000?0=SHf0H0000000<0K6a/0=SHf03Hf=P0:`3Hf=P>00000:P0f=SH2`00002J0?ooo`00
7P3oool;000004@0f=SH1P00001J0=SHf00306a/K0000000000000<000008P3Hf=P500000140f=SH
1@0000000`1/K6`0f=SH0=SHf00]0=SHf0<0000000<0K6a/0=SHf03Hf=P03`3Hf=P7000000l0f=SH
1P0000000`1/K6`0f=SH0=SHf00[0=SHf00306a/K0000000000000`00000Y`3Hf=P:000009/0oooo
000N0?ooo`/00000A03Hf=P6000005X0f=SH00<0K6a/0000000000000`00000R0=SHf0D000004@3H
f=P50000000306a/K03Hf=P0f=SH02d0f=SH0`0000000`1/K6`0f=SH0=SHf00@0=SHf0H000003`3H
f=P7000002h0f=SH3`00002U0=SHf00306a/K0000000000000P00000V`3oool001h0oooo2`000015
0=SHf0H00000FP3Hf=P600000240f=SH1P00000A0=SHf0D00000;`3Hf=P30000000306a/K03Hf=P0
f=SH0100f=SH1P00000@0=SHf0H00000;`3Hf=P?00000:@0f=SH00<0K6a/0000000000002000002K
0?ooo`007`3oool:000000030::RXP3Hf=P0f=SH0480f=SH1P00001J0=SHf0H000008@3Hf=P60000
0140f=SH00<0=SHf0000000000000P0000000`1/K6`0f=SH0=SHf00/0=SHf0<0000000<0K6a/0=SH
f03Hf=P0403Hf=P600000100f=SH1P0000000`1/K6`0f=SH0=SHf00]0=SHf00306a/K00000000000
00/0000000<0=SHf0=SHf03Hf=P0X@3Hf=P00`0f=SH0000000000007000000030820P03oool0oooo
09T0oooo000O0?ooo`X0000000<0K6a/0=SHf03Hf=P0@P3Hf=P6000005X0f=SH1P00000Q0=SHf0H0
00004@3Hf=P00`1/K6`0000000000003000002h0f=SH0`0000000`1/K6`0f=SH0=SHf00@0=SHf0H0
000000<0K6a/0=SHf03Hf=P03@3Hf=P700000300f=SH00<0K6a/0000000000003000002R0=SHf0X0
0000W03oool001l0oooo2P0000000`1/K6`0f=SH0=SHf0120=SHf0H00000FP3Hf=P600000280f=SH
1@00000B0=SHf0H00000;@3Hf=P30000000306a/K03Hf=P0f=SH0100f=SH1P0000000`1/K6`0f=SH
0=SHf00>0=SHf0H00000<@3Hf=P?00000:40f=SH2P00002L0?ooo`00803oool:000004D0f=SH1@00
00000`1/K6`0f=SH0=SHf01H0=SHf0H000008@3Hf=P50000000306a/K03Hf=P0f=SH00l0f=SH1P00
000]0=SHf0<0000000<0K6a/0=SHf03Hf=P0403Hf=P60000000306a/K03Hf=P0f=SH00h0f=SH1`00
000a0=SHf0l00000903Hf=P5000007H0f=SH2P0000000`20P800oooo0?ooo`2J0?ooo`00803oool:
000004D0f=SH1@0000000`1/K6`0f=SH0=SHf01H0=SHf0H000008@3Hf=P50000000306a/K03Hf=P0
f=SH00l0f=SH00<0K6a/0000000000000`00000]0=SHf0<0000000<0K6a/0=SHf03Hf=P0403Hf=P6
0000000306a/K03Hf=P0f=SH00h0f=SH1`00000c0=SHf00306a/K0000000000000X0000000<0=SHf
06a/K03Hf=P08@3Hf=P00`1/K6`0000000000003000007D0f=SH2P0000000`20P800oooo0?ooo`2J
0?ooo`00803oool;000004@0f=SH1@0000000`1/K6`0f=SH0=SHf01H0=SHf0H000008P3Hf=P50000
0180f=SH1P00000/0=SHf0<0000000<0K6a/0=SHf03Hf=P04@3Hf=P600000100f=SH1`00000d0=SH
f00306a/K0000000000000`000002P3Hf=P2000001H0f=SH1@00001e0=SHf0X0000000<0P8200?oo
o`3oool0VP3oool00200oooo00<0P820000000000000200000140=SHf0D0000000<0K6a/0=SHf03H
f=P0F03Hf=P600000280f=SH1@00000B0=SHf0H00000;03Hf=P30000000306a/K03Hf=P0f=SH0140
f=SH1P00000@0=SHf00306a/K0000000000000D00000=03Hf=P?000000L0f=SH1000000F0=SHf0D0
000000<0K6a/0=SHf03Hf=P0L@3Hf=P;000009d0oooo000P0?ooo`030820P0000000000000P00000
A@3Hf=P5000005/0f=SH1@0000000`1/K6`0f=SH0=SHf00O0=SHf00306a/K0000000000000<00000
4@3Hf=P6000002`0f=SH0`0000000`1/K6`0f=SH0=SHf00A0=SHf1h00000=@3Hf=P?000000@0f=SH
00<0K6a/0000000000001000000F0=SHf0@0000000<0K6a/0=SHf03Hf=P0L@3Hf=P;000009d0oooo
000P0?ooo`030<30`0000000000000T00000A03Hf=P5000005/0f=SH1@0000000`1/K6`0f=SH0=SH
f00O0=SHf0030::RXP000000000000<0000000<0K6a/0=SHf03Hf=P03P3Hf=P00`1/K6`000000000
0003000002`0f=SH0`0000000`1/K6`0f=SH0=SHf00A0=SHf1h00000=P3Hf=P00`1/K6`000000000
000;0000000403Hf=P3Hf=P0f=SH06a/K0L0000000<0K6a/0=SHf03Hf=P04`3Hf=P40000000306a/
K03Hf=P0f=SH0700f=SH00<0K6a/000000000000200000000`20P800oooo0?ooo`2K0?ooo`008@3o
ool<000004<0f=SH1@0000070=SHf0L00000C@3Hf=P50000000306a/K03Hf=P0f=SH00@0f=SH1`00
000E0=SHf0H000004@3Hf=P5000002`0f=SH0`0000000`1/K6`0f=SH0=SHf00B0=SHf0H00000403H
f=P7000003L0f=SH00<0K6a/0000000000005P00000E0=SHf0D00000LP3Hf=P;000009h0oooo000Q
0?ooo``00000@`3Hf=P5000000D0f=SH2`0000000`1/K6`0f=SH0=SHf0180=SHf0D0000000<0K6a/
0=SHf03Hf=P00P3Hf=P<000001<0f=SH1P00000@0=SHf0D00000;03Hf=P30000000306a/K03Hf=P0
f=SH0180f=SH1P00000@0=SHf0L0000000<0K6a/0=SHf03Hf=P0=@3Hf=PH0000000306a/K03Hf=P0
f=SH0180f=SH00<0K6a/0000000000000P00001b0=SHf0/00000WP3oool00280oooo2`0000130=SH
f0H000000`3Hf=P40000000306a/K03Hf=P0f=SH00<0f=SH100000190=SHf0H000000`3Hf=P50000
00D0f=SH1000000C0=SHf0D00000403Hf=P5000002`0f=SH0`0000000`1/K6`0f=SH0=SHf00B0=SH
f0H00000403Hf=P70000000306a/K03Hf=P0f=SH03H0f=SH6000000D0=SHf00306a/K00000000000
00<00000L@3Hf=P:000009l0oooo000R0?ooo`030820P0000000000000P0000000<0K6a/0=SHf03H
f=P0@03Hf=P00`1/K6`00000000000030000000306a/K000000000000080000000<0K6a/0=SHf03H
f=P01`3Hf=P01@0f=SH00000000000000000XZ:R04L0f=SH1@0000000`1/K6`00000000000020000
000306a/K03Hf=P0f=SH00L0f=SH00D0K6a/000000000000000006a/K00A0=SHf0@0000000<0=SHf
0=SHf03Hf=P03@3Hf=P40000000306a/K03Hf=P0f=SH02X0f=SH0`0000000`1/K6`0f=SH0=SHf00B
0=SHf00303Hf=P000000000000<00000403Hf=P70000000306a/K03Hf=P0f=SH03P0f=SH00<0=SHf
0000000000004`0000000`1/K6`0f=SH0=SHf00A0=SHf0030::RXP000000000000<00000L03Hf=P0
0`1/K6`0000000000008000009l0oooo000S0?ooo`X0000000<0K6a/0=SHf03Hf=P0@03Hf=P00`1/
K6`0000000000007000000`0f=SH1@0000160=SHf0T00000303Hf=P00`1/K6`00000000000020000
0100f=SH00<0K6a/0000000000000`00000=0=SHf0D00000;@3Hf=P30000000306a/K03Hf=P0f=SH
0180f=SH00<0K6a/0000000000001000000@0=SHf0H0000000<0K6a/0=SHf03Hf=P0>@3Hf=PG0000
01<0f=SH1P00001_0=SHf00306a/K0000000000000L00000X03oool002<0oooo2`0000120=SHf003
06a/K0000000000000L000003@3Hf=P5000004D0f=SH2@00000=0=SHf0D000004@3Hf=P4000000d0
f=SH1000000^0=SHf0<0000000<0K6a/0=SHf03Hf=P04P3Hf=P00`1/K6`000000000000400000100
f=SH1P0000000`1/K6`0f=SH0=SHf00j0=SHf1H000004`3Hf=P6000006l0f=SH2P00002P0?ooo`00
903oool:00000480f=SH00<0K6a/0000000000001P0000000`1/K6`0f=SH0=SHf00<0=SHf0D00000
A03Hf=P80000000306a/K03Hf=P0f=SH00`0f=SH1@00000A0=SHf0@00000303Hf=P4000002h0f=SH
0`0000000`1/K6`0f=SH0=SHf00C0=SHf0H00000403Hf=P60000000306a/K03Hf=P0f=SH03/0f=SH
5P00000C0=SHf0H00000KP3Hf=P900000:40oooo000T0?ooo`X00000@`3Hf=P80000000306a/K03H
f=P0f=SH00d0f=SH1@0000130=SHf00306a/K0000000000000D0000000<0K6a/0=SHf03Hf=P03@3H
f=P500000140f=SH1@0000090=SHf0@00000;`3Hf=P30000000306a/K03Hf=P0f=SH01<0f=SH1P00
000@0=SHf0H0000000<0K6a/0=SHf03Hf=P0?03Hf=PE000001<0f=SH1P00001]0=SHf0X00000X@3o
ool002@0oooo00<0@4100000000000001`0000000`1/K6`0f=SH0=SHf0100=SHf0P0000000<0K6a/
0=SHf03Hf=P03@3Hf=P5000000030::RXP3Hf=P0f=SH0400f=SH00<0K6a/0000000000001@000000
0`1/K6`0f=SH0=SHf00=0=SHf0D0000000<0XZ:R0=SHf03Hf=P03`3Hf=P206a/K080000000<0=SHf
06a/K03Hf=P0103Hf=P00`1/K6`0=SHf00000002000000030::RXP3Hf=P0f=SH02d0f=SH0`000000
0`1/K6`0f=SH0=SHf00C0=SHf00306a/K0000000000000@000003`3Hf=P60000000306a/K03Hf=P0
f=SH03`0f=SH00<0K6a/0000000000004P0000000`1/K6`0f=SH0=SHf00@0=SHf0D0000000<0K6a/
0000003Hf=P0JP3Hf=P00`1/K6`0000000000007000000030410@03oool0oooo09l0oooo000T0?oo
o`030820P0000000000000P00000@P3Hf=P800000100f=SH00<0K6a/0000000000000`0000120=SH
f00306a/K0000000000000D000004@3Hf=P5000001D0f=SH2P00000b0=SHf0<0000000<0K6a/0=SH
f03Hf=P0503Hf=P6000000l0f=SH1P0000000`1/K6`0f=SH0=SHf00l0=SHf1H000004`3Hf=P60000
000306a/K03Hf=P0f=SH06P0f=SH2P0000000`20P800oooo0?ooo`2O0?ooo`00903oool00`20P800
00000000000800000480f=SH2000000@0=SHf00306a/K0000000000000<00000@P3Hf=P00`1/K6`0
00000000000500000140f=SH1@00000G0=SHf0H0000000<0K6a/0=SHf03Hf=P0<@3Hf=P300000003
06a/K03Hf=P0f=SH01D0f=SH1@0000000`1/K6`0f=SH0=SHf00=0=SHf0D0000000<0K6a/0=SHf03H
f=P0>`3Hf=PG000001<0f=SH1@0000000`3Hf=P000000=SHf01Y0=SHf0X0000000<0P8200?ooo`3o
ool0W`3oool002D0oooo2`0000120=SHf0L000004@3Hf=P600000480f=SH1`00000A0=SHf00306a/
K0000000000000<00000D03Hf=P30000000306a/K03Hf=P0f=SH01D0f=SH1@0000000`1/K6`0f=SH
0=SHf00=0=SHf0D0000000<0K6a/0=SHf03Hf=P0>`3Hf=PG000001<0f=SH1@0000000`3Hf=P00000
0=SHf01X0=SHf0/00000XP3oool002D0oooo2`0000000`1/K6`0f=SH0=SHf00o0=SHf0L000004@3H
f=P60000000306a/K03Hf=P0f=SH03l0f=SH1`00000A0=SHf00306a/K0000000000000<0000000<0
K6a/0=SHf03Hf=P0C@3Hf=P30000000306a/K03Hf=P0f=SH01H0f=SH100000000`0f=SH0f=SH0=SH
f00=0=SHf0D0000000<0K6a/0=SHf03Hf=P0>@3Hf=P00`1/K6`000000000000G000001<0f=SH1@00
00000`2RXZ80000006a/K01V0=SHf0030::RXP000000000000T00000XP3oool002H0oooo2`000011
0=SHf0L000004@3Hf=P700000440f=SH1`00000A0=SHf00306a/K0000000000000@00000C`3Hf=P3
0000000306a/K03Hf=P0f=SH01H0f=SH00<0K6a/0000000000000P00000?0=SHf0D0000000<0K6a/
0=SHf03Hf=P0>@3Hf=PK00000180f=SH1@0000000`3Hf=P000000000001V0=SHf00306a/K0000000
000000P00000X`3oool002H0oooo2`0000000`1/K6`0f=SH0=SHf00n0=SHf0L000004@3Hf=P70000
0440f=SH1`00000A0=SHf00306a/K0000000000000@00000C`3Hf=P30000000306a/K03Hf=P0f=SH
01H0f=SH00<0K6a/0000000000000`00000>0=SHf0D0000000<0K6a/0=SHf03Hf=P0>03Hf=P00`1/
K6`000000000000I00000180f=SH1@000000101/K6`0f=SH00000000001U0=SHf00306a/K0000000
000000P00000X`3oool002H0oooo2`0000000`1/K6`0f=SH0=SHf00o0=SHf0H000004P3Hf=P70000
0440f=SH1P00000B0=SHf0L00000CP3Hf=P30000000306a/K03Hf=P0f=SH01L0f=SH1@00000>0=SH
f0D00000>`3Hf=P00`1/K6`000000000000J00000140f=SH00<0K6a/0000000000000P0000001@1/
K6`0f=SH0=SHf0000000K6a/06@0f=SH2`00002S0?ooo`009`3oool:0000000303Hf=P3Hf=P0f=SH
03l0f=SH1P00000B0=SHf0L00000@@3Hf=P600000180f=SH1`00001>0=SHf0<0000000<0K6a/0=SH
f03Hf=P0603Hf=P00`1/K6`0000000000002000000`0f=SH1P00000m0=SHf080K6a/00<0=SHf0000
000000005P0000000`1/K6`0f=SH0=SHf00>0=SHf00306a/K000000000000080000000D0K6a/0=SH
f03Hf=P0K6a/000000060=SHf080K6a/F`3Hf=P00`1/K6`000000000000800000:@0oooo000X0?oo
o`X00000@@3Hf=P60000000306a/K03Hf=P0f=SH00l0f=SH1`0000110=SHf0H0000000<0K6a/0=SH
f03Hf=P03`3Hf=P7000004h0f=SH0`0000000`1/K6`0f=SH0=SHf00J0=SHf0@000002`3Hf=P50000
0480f=SH6000000A0=SHf0D000000`3Hf=P00`1/K6`000000=SHf0030=SHf0@00000FP3Hf=P;0000
0:@0oooo000X0?ooo`/00000@@3Hf=P50000000306a/K03Hf=P0f=SH00l0f=SH1`0000120=SHf0D0
000000<0K6a/0=SHf03Hf=P03`3Hf=P7000004h0f=SH0`0000000`1/K6`0f=SH0=SHf00J0=SHf005
06a/K000000000000000001/K6`02P3Hf=P5000004@0f=SH5P0000000`1/K6`0f=SH0=SHf00>0=SH
f0D000000`3Hf=P00`1/K6`00000000000030=SHf0D00000F03Hf=P;00000:D0oooo000X0?ooo`/0
0000@@3Hf=P50000000306a/K03Hf=P0f=SH00l0f=SH1`0000000`1/K6`0f=SH0=SHf00A0=SHf2@0
00002P3Hf=P50000000306a/K03Hf=P0f=SH00l0f=SH2000001=0=SHf0<0000000<0K6a/0=SHf03H
f=P06`3Hf=P4000000T0f=SH1@0000170=SHf1D00000403Hf=P5000000@0f=SH0`0000020=SHf0D0
0000F03Hf=P;00000:D0oooo000Y0?ooo`X0000000<0K6a/0=SHf03Hf=P0?P3Hf=P00`0f=SH00000
000000020000000303Hf=P3Hf=P0f=SH00l0f=SH1`0000000`1/K6`0f=SH0=SHf00A0=SHf2@00000
2P3Hf=P00`1/K6`00000000000020000000303Hf=P3Hf=P0f=SH00l0f=SH2000001=0=SHf0<00000
00<0K6a/0=SHf03Hf=P0703Hf=P206a/K08000000P1/K6`50=SHf00503Hf=P00000000000000000f
=SH0BP3Hf=P206a/K1<0000000<0K6a/0=SHf03Hf=P02`3Hf=P6000000@0f=SH00<0K6a/00000000
00001`00001F0=SHf00306a/K0000000000000P0000000<0P8200?ooo`3oool0X`3oool002T0oooo
2`0000100=SHf00306a/K0000000000000<000004@3Hf=P70000000306a/K03Hf=P0f=SH0400f=SH
1@00000A0=SHf0P00000C@3Hf=P30000000306a/K03Hf=P0f=SH01h0f=SH00<0K6a/000000000000
2@00001@0=SHf180000000<0K6a/0=SHf03Hf=P02P3Hf=P6000000H0f=SH2000001F0=SHf0/00000
00<0P8200?ooo`3oool0X`3oool002T0oooo00<0P8200000000000002@0000100=SHf0D000004@3H
f=P70000000306a/K03Hf=P0f=SH0400f=SH00<0K6a/0000000000000P00000A0=SHf0P00000C@3H
f=P30000000306a/K03Hf=P0f=SH0240f=SH1`00001C0=SHf00306a/K0000000000000l000001`3H
f=P00`1/K6`0000000000009000000D0f=SH00<0K6a/0000000000001@00001E0=SHf00306a/K000
0000000000T00000YP3oool002T0oooo00<0P8200000000000002@0000100=SHf0H00000403Hf=P7
000004<0f=SH00<0K6a/0000000000000`00000@0=SHf0L00000CP3Hf=P30000000306a/K03Hf=P0
f=SH07h0f=SH400000060=SHf00306a/K0000000000000T000001P3Hf=P7000005D0f=SH00<0K6a/
0000000000002@00002V0?ooo`00:P3oool;0000000306a/K03Hf=P0f=SH03h0f=SH1@00000@0=SH
f0L00000A03Hf=P500000100f=SH1`00001>0=SHf0<0000000<0K6a/0=SHf03Hf=P0O`3Hf=P00`1/
K6`000000000000;000000/0f=SH200000070=SHf0H00000E@3Hf=P<00000:H0oooo000Z0?ooo`03
0820P0000000000000P0000000<0=SHf0=SHf03Hf=P0?P3Hf=P00`1/K6`0000000000003000000h0
f=SH00<0K6a/0000000000001@0000140=SHf00306a/K0000000000000<000003P3Hf=P00`2RXZ80
000000000005000004h0f=SH0`0000000`1/K6`0f=SH0=SHf0210=SHf00306a/K0000000000000P0
000000<0K6a/0=SHf03Hf=P03P3Hf=P0102RXZ80K6a/06a/K01/K6`80=SHf0<0K6a/EP3Hf=P;0000
0:L0oooo000[0?ooo`/00000@P3Hf=P5000000d0f=SH1`0000170=SHf0D000003@3Hf=P00`1/K6`0
000000000004000004l0f=SH0`0000000`1/K6`0f=SH0=SHf0230=SHf0T0000000<0K6a/0=SHf03H
f=P0LP3Hf=P;00000:P0oooo000/0?ooo`X00000@`3Hf=P4000000`0f=SH00<0K6a/000000000000
1@0000180=SHf0@000003@3Hf=P7000004l0f=SH0`0000000`1/K6`0f=SH0=SHf0240=SHf0T00000
M03Hf=P;00000:P0oooo000/0?ooo`/00000@P3Hf=P01@1/K6`00000000000000000K6a/00/0f=SH
00<0K6a/000000000000100000190=SHf00306a/K0000000000000800000303Hf=P600000500f=SH
0`0000000`1/K6`0f=SH0=SHf0250=SHf0P00000L`3Hf=P;00000:T0oooo000]0?ooo`X0000000<0
K6a/0=SHf03Hf=P0@03Hf=P206a/K08000000P1/K6`80=SHf00306a/K0000000000000<0000000<0
=SHf0=SHf03Hf=P0B@3Hf=P206a/K080000000<0=SHf06a/K03Hf=P01`3Hf=P00`1/K6`000000000
00030000000303Hf=P3Hf=P0f=SH04l0f=SH0`0000000`1/K6`0f=SH0=SHf0260=SHf00306a/K000
0000=SHf0080f=SH0P1/K6`00`000000f=SH0=SHf01_0=SHf00306a/K0000000000000P0000000<0
@4100?ooo`3oool0Y`3oool002d0oooo00<0P820000000000000200000150=SHf00506a/K0000000
00000000001/K6`0103Hf=P8000001P0f=SH9000000D0=SHf0@00000103Hf=P00`1/K6`000000000
000500000580f=SH0`0000000`1/K6`0f=SH0=SHf03o0=SHf0/0000000<0P8200?ooo`3oool0Y`3o
ool002d0oooo00<0P8200000000000002@0000160=SHf0d000006P3Hf=PT000001D0f=SH3@00001D
0=SHf0<0000000<0K6a/0=SHf03Hf=P0oP3Hf=P<00000:X0oooo000^0?ooo`/00000B03Hf=P00`1/
K6`00000000000050000000306a/K03Hf=P0f=SH01X0f=SH9000000H0=SHf0P00000EP3Hf=P30000
000306a/K03Hf=P0f=SH0?h0f=SH3000002Z0?ooo`00;P3oool00`20P80000000000000800000003
06a/K03Hf=P0f=SH0?l0f=SH1@3Hf=P30000000306a/K03Hf=P0f=SH0?d0f=SH00<0XZ:R00000000
00002@00002[0?ooo`00;`3oool;00000?l0f=SH1`3Hf=P30000000306a/K03Hf=P0f=SH0?d0f=SH
2`00002/0?ooo`00<03oool:00000?l0f=SH1`3Hf=P30000000306a/K03Hf=P0f=SH0?d0f=SH2`00
002/0?ooo`00<03oool;00000?l0f=SH1P3Hf=P30000000306a/K03Hf=P0f=SH0?`0f=SH2`00002]
0?ooo`00<@3oool:0000000306a/K03Hf=P0f=SH0?l0f=SH0`3Hf=P30000000306a/K03Hf=P0f=SH
0?/0f=SH00<0K6a/000000000000200000000`10@400oooo0?ooo`2[0?ooo`00<@3oool00`20P800
00000000000800000?l0f=SH1@3Hf=P30000000306a/K03Hf=P0f=SH0?/0f=SH2`0000000`20P800
oooo0?ooo`2[0?ooo`00<@3oool00`20P80000000000000900000?l0f=SH103Hf=P30000000306a/
K03Hf=P0f=SH0?X0f=SH3000002^0?ooo`00<P3oool;00000?l0f=SH103Hf=P30000000306a/K03H
f=P0f=SH0?X0f=SH3000002^0?ooo`00<P3oool<00000?l0f=SH0`3Hf=P30000000306a/K03Hf=P0
f=SH0?T0f=SH00<0K6a/0000000000002@00002_0?ooo`00<`3oool;000000030::RXP3Hf=P0f=SH
0?l0f=SH0`0000000`1/K6`0f=SH0=SHf03i0=SHf00303Hf=P000000000000P0000000<0P8200?oo
o`3oool0[@3oool003@0oooo2P0000000`1/K6`0f=SH0=SHf03o0=SHf0<0000000<0K6a/0=SHf03H
f=P0n@3Hf=P;00000;00oooo000d0?ooo`/00000o`3Hf=P20=SHf0<0000000<0K6a/0=SHf03Hf=P0
n03Hf=P;00000;40oooo000e0?ooo`/00000o`3Hf=P10=SHf0<0000000<0K6a/0=SHf03Hf=P0m`3H
f=P<00000;40oooo000e0?ooo`030410@0000000000000P0000000<0K6a/0=SHf03Hf=P0o@3Hf=P3
0000000306a/K03Hf=P0f=SH0?H0f=SH00<0K6a/0000000000002@0000000`20P800oooo0?ooo`2_
0?ooo`00=@3oool00`20P80000000000000900000?l0f=SH0`0000000`1/K6`0f=SH0=SHf03f0=SH
f0`00000/P3oool003H0oooo3000003n0=SHf0<0000000<0K6a/0=SHf03Hf=P0m@3Hf=P00`1/K6`0
00000000000:00000;80oooo000f0?ooo``0000000<0K6a/0=SHf03Hf=P0n`3Hf=P30000000306a/
K03Hf=P0f=SH0?D0f=SH3000002c0?ooo`00=`3oool;0000000303Hf=P3Hf=P0f=SH0?/0f=SH0`00
00000`1/K6`0f=SH0=SHf03d0=SHf00306a/K0000000000000T00000]03oool003P0oooo2`00003m
0=SHf0<0000000<0K6a/0=SHf03Hf=P0m03Hf=P;00000;D0oooo000h0?ooo``00000o03Hf=P30000
000306a/K03Hf=P0f=SH0?<0f=SH3000002e0?ooo`00>@3oool<00000?/0f=SH0`0000000`1/K6`0
f=SH0=SHf03b0=SHf0`00000]P3oool003T0oooo00<0@4100000000000002@0000000`1/K6`0f=SH
0=SHf03h0=SHf0<0000000<0K6a/0=SHf03Hf=P0l@3Hf=P00`2RXZ80000000000009000000030410
@03oool0oooo0;@0oooo000j0?ooo``00000nP3Hf=P30000000306a/K03Hf=P0f=SH0?40f=SH00<0
K6a/0000000000002@0000000`20P800oooo0?ooo`2d0?ooo`00>P3oool<0000000306a/K03Hf=P0
f=SH0?L0f=SH0`0000000`1/K6`0f=SH0=SHf03a0=SHf0`00000]`3oool003/0oooo3000003i0=SH
f0<0000000<0K6a/0=SHf03Hf=P0l03Hf=P<000000P0oooo1@00002[0?ooo`00>`3oool<00000?T0
f=SH0`0000000`1/K6`0f=SH0=SHf03`0=SHf0`00000203oool500000:/0oooo000l0?ooo``00000
n03Hf=P30000000306a/K03Hf=P0f=SH0>l0f=SH300000090?ooo`D00000Z`3oool003d0oooo3000
003g0=SHf0<0000000<0K6a/0=SHf03Hf=P0kP3Hf=P<000000X0oooo1@00002[0?ooo`00?@3oool=
00000?H0f=SH0`0000000`1/K6`0f=SH0=SHf03]0=SHf00306a/K0000000000000X000002`3oool5
00000:X0oooo000n0?ooo``00000mP3Hf=P30000000306a/K03Hf=P0f=SH0>d0f=SH00<0K6a/0000
000000002@0000000`20P800oooo0?ooo`090?ooo`D00000ZP3oool003h0oooo00<0P82000000000
00002@0000000`1/K6`0f=SH0=SHf03c0=SHf0<0000000<0K6a/0=SHf03Hf=P0k@3Hf=P<000000`0
oooo1@00002Z0?ooo`00?`3oool<00000?D0f=SH0`0000000`1/K6`0f=SH0=SHf03/0=SHf0`00000
3@3oool500000:X0oooo00100?ooo``00000m03Hf=P30000000306a/K03Hf=P0f=SH0>/0f=SH3000
000?0?ooo`@0000000<0P8200?ooo`3oool0Y`3oool00400oooo3000003d0=SHf0<0000000<0K6a/
0=SHf03Hf=P0j`3Hf=P<000000l0oooo100000000`20P800oooo0?ooo`2W0?ooo`00@@3oool00`20
P80000000000000900000?<0f=SH0`0000000`1/K6`0f=SH0=SHf03Z0=SHf0/0000000<0@4100?oo
o`3oool03P3oool4000000030820P03oool0oooo0:L0oooo00120?ooo``00000lP3Hf=P300000003
06a/K03Hf=P0f=SH0>T0f=SH300000000`20P800oooo0?ooo`0>0?ooo`@0000000<0P8200?ooo`3o
ool0Y`3oool00480oooo00<0P8200000000000002P00003a0=SHf0<0000000<0K6a/0=SHf03Hf=P0
j03Hf=P00`1/K6`000000000000:00000140oooo00<0P8200000000000000P00002Y0?ooo`00@`3o
ool<00000?40f=SH0`0000000`1/K6`0f=SH0=SHf03X0=SHf00306a/K0000000000000T000004P3o
ool00`20P80000000000000200000:T0oooo00130?ooo`030820P0000000000000T0000000<0=SHf
0=SHf03Hf=P0kP3Hf=P30000000306a/K03Hf=P0f=SH0>L0f=SH00<0K6a/0000000000002@000000
0`20P800oooo0?ooo`0>0?ooo`80P82000<0@4100000000000000P0000030820P6@0oooo0P20P805
000000<0P820>03oool004D0oooo3000003_0=SHf0<0000000<0K6a/0=SHf03Hf=P0iP3Hf=P<0000
0100oooo3`00001P0?ooo``00000=`3oool004D0oooo3000003_0=SHf0<0000000<0K6a/0=SHf03H
f=P0iP3Hf=P<000000h0oooo4P0000000`20P800oooo0?ooo`1J0?ooo`030820P0000000000000<0
0000103oool5000003H0oooo00160?ooo``00000kP3Hf=P30000000306a/K03Hf=P0f=SH0>D0f=SH
300000000`20P800oooo0?ooo`0;0?ooo`L0000000<0oooo0000000000000`0000000`3oool00000
00000004000005`0oooo100000000`20P800oooo0?ooo`040?ooo`D00000=@3oool004H0oooo00<0
P8200000000000002P00003]0=SHf0<0000000<0K6a/0=SHf03Hf=P0i03Hf=P00`1/K6`000000000
000:000000d0oooo1P0000030?ooo`D000000`3oool6000005T0oooo1@0000090?ooo`@00000=03o
ool004H0oooo00<0`<300000000000002P0000000`2RXZ80f=SH0=SHf03Z0=SHf0<0000000<0K6a/
0=SHf03Hf=P0i03Hf=P00`0f=SH0000000000009000000030820P03oool0oooo00X0oooo00<0P820
0000000000000P0000000`10@400oooo0?ooo`020?ooo`D00000103oool00`20P800000000000003
000000030820P03oool0oooo05@0oooo00<0P8200000000000000P00000:0?ooo`050820P0000000
000000000010@400<`3oool004P0oooo3000003/0=SHf0<0000000<0K6a/0=SHf03Hf=P0h`3Hf=P<
000000h0oooo1@0000000`20P800oooo0?ooo`030?ooo`@000001P3oool5000000030820P03oool0
oooo0580oooo1@00000<0?ooo`D00000<P3oool004T0oooo3000003[0=SHf0<0000000<0K6a/0=SH
f03Hf=P0hP3Hf=P<000000l0oooo1@0000060?ooo`D000001@3oool00`20P8000000000000030000
05@0oooo1@00000<0?ooo`D00000<P3oool004T0oooo3000003[0=SHf0<0000000<0K6a/0=SHf03H
f=P0hP3Hf=P<000000h0oooo1P0000060?ooo`D000001P3oool600000580oooo00<0P82000000000
00000`00000=0?ooo`D00000<@3oool004X0oooo00<0@4100000000000002@0000000`1/K6`0f=SH
0=SHf03W0=SHf0<0000000<0K6a/0=SHf03Hf=P0h03Hf=P00`2RXZ8000000000000:000000030<30
`03oool0oooo00`0oooo1P0000060?ooo`D000001P3oool00`20P800000000000003000000030820
P03oool0oooo04l0oooo00<0@4100000000000000P00000>0?ooo`D0000000<0P8200?ooo`3oool0
;P3oool004X0oooo00<0P8200000000000002P0000000`1/K6`0f=SH0=SHf03V0=SHf0<0000000<0
K6a/0=SHf03Hf=P0h03Hf=P=000000l0oooo1@0000080?ooo`@000001`3oool600000540oooo1@00
000>0?ooo`H00000<03oool004/0oooo300000000`1/K6`0f=SH0=SHf03V0=SHf0<0000000<0K6a/
0=SHf03Hf=P0h03Hf=P<00000100oooo1@0000080?ooo`@00000203oool6000004l0oooo1@000000
0`20P800oooo0?ooo`0=0?ooo`D0000000<0P8200?ooo`3oool0;@3oool004`0oooo3000003X0=SH
f0<0000000<0K6a/0=SHf03Hf=P0g`3Hf=P<00000100oooo1P0000080?ooo`D000001`3oool60000
04l0oooo1@0000000`20P800oooo0?ooo`0=0?ooo`D0000000<0P8200?ooo`3oool0;@3oool004d0
oooo300000000`1/K6`0f=SH0=SHf03T0=SHf0<0000000<0K6a/0=SHf03Hf=P0g@3Hf=P00`1/K6`0
00000000000:00000140oooo00<0P8200000000000000`0000080?ooo`030820P000000000000080
0000203oool5000000030820P03oool0oooo04`0oooo1@0000000`20P800oooo0?ooo`0=0?ooo`D0
000000<0P8200?ooo`3oool0;@3oool004h0oooo3@00003U0=SHf0<0000000<0K6a/0=SHf03Hf=P0
g@3Hf=P<000001<0oooo1P0000080?ooo`@00000203oool5000000030820P03oool0oooo04/0oooo
1P0000000`20P800oooo0?ooo`0=0?ooo`H00000;`3oool004h0oooo3@00003U0=SHf0<0000000<0
K6a/0=SHf03Hf=P0g03Hf=P00`1/K6`000000000000:000001<0oooo1P0000080?ooo`@000002@3o
ool5000004d0oooo1P0000000`20P800oooo0?ooo`0=0?ooo`H00000;`3oool004l0oooo30000000
0`1/K6`0f=SH0=SHf03R0=SHf0<0000000<0K6a/0=SHf03Hf=P0g03Hf=P<000000030820P03oool0
oooo0140oooo1P0000080?ooo`@000002@3oool5000004d0oooo1P00000@0?ooo`H00000;`3oool0
04l0oooo00<0`<300000000000002P0000000`1/K6`0f=SH0=SHf03Q0=SHf0<0000000<0K6a/0=SH
f03Hf=P0fP3Hf=P00`1/K6`000000000000;000001@0oooo1P0000080?ooo`050820P00000000000
00000020P800203oool5000004`0oooo00<0P8200000000000001000000A0?ooo`D00000;`3oool0
0500oooo3@00003S0=SHf0<0000000<0K6a/0=SHf03Hf=P0fP3Hf=P=000001H0oooo1@0000000`20
P800oooo0?ooo`050?ooo`050820P0000000000000000020P800203oool5000004`0oooo1`00000A
0?ooo`H00000;P3oool00540oooo3@00003R0=SHf0<0000000<0K6a/0=SHf03Hf=P0f@3Hf=P=0000
01L0oooo1@0000000`20P800oooo0?ooo`050?ooo`050820P0000000000000000020P800203oool5
00000180oooo900000000`20P800oooo0?ooo`0C0?ooo`L000004@3oool6000002h0oooo001B0?oo
o`d00000h@3Hf=P30000000306a/K03Hf=P0f=SH0=P0f=SH00<0K6a/0000000000002P00000H0?oo
o`D0000000<0P8200?ooo`3oool01@3oool01@20P8000000000000000000P82000P0oooo00<0P820
0000000000000`00000A0?ooob@0000000<0P8200?ooo`3oool04`3oool700000140oooo1P00000^
0?ooo`00D`3oool<0000000306a/K03Hf=P0f=SH0=h0f=SH0`0000000`1/K6`0f=SH0=SHf03H0=SH
f0`0000000<0P8200?ooo`3oool05P3oool00`20P800000000000003000000P0oooo100000080?oo
o`030820P0000000000000<000004@3ooolT000000030820P03oool0oooo01<0oooo1`00000A0?oo
o`H00000;P3oool005<0oooo00<0`<300000000000002P0000000`1/K6`0f=SH0=SHf03M0=SHf0<0
000000<0K6a/0=SHf03Hf=P0e`3Hf=P<000000030820P03oool0oooo01L0oooo00<0`<3000000000
00000`0000000`20P800oooo0?ooo`050?ooo`@00000203oool00`10@400000000000002000004`0
oooo1`00000A0?ooo`H00000;P3oool005@0oooo3@00003O0=SHf0<0000000<0K6a/0=SHf03Hf=P0
eP3Hf=P=000001/0oooo1P0000070?ooo`@00000203oool5000004`0oooo1`00000A0?ooo`H00000
;P3oool005D0oooo3@00003N0=SHf0<0000000<0K6a/0=SHf03Hf=P0e@3Hf=P=000001d0oooo1P00
00070?ooo`<00000203oool5000004`0oooo1`00000A0?ooo`H00000;P3oool005H0oooo3@00003M
0=SHf0<0000000<0K6a/0=SHf03Hf=P0e03Hf=P=000001h0oooo1P0000070?ooo`<00000203oool5
000004`0oooo1`00000A0?ooo`H00000;P3oool005L0oooo3@0000000`2RXZ80f=SH0=SHf03I0=SH
f0<0000000<0K6a/0=SHf03Hf=P0d`3Hf=P00`0f=SH000000000000:000000030820P03oool0oooo
01d0oooo00<0P8200000000000000`0000000`30`<00oooo0?ooo`030?ooo`@000001P3oool50000
00030820P03oool0oooo04X0oooo1`00000A0?ooo`H00000;P3oool005L0oooo00<0P82000000000
00002`00003K0=SHf0<0000000<0K6a/0=SHf03Hf=P0dP3Hf=P>00000280oooo1@0000050?ooo`@0
00001@3oool6000004d0oooo1`00000A0?ooo`H00000;P3oool005P0oooo3@00003K0=SHf0<00000
00<0K6a/0=SHf03Hf=P0dP3Hf=P=000002<0oooo00<0P8200000000000000`0000050?ooo`<00000
1@3oool6000004d0oooo1`00000A0?ooo`H00000;P3oool005T0oooo3@00003J0=SHf0<0000000<0
K6a/0=SHf03Hf=P0d@3Hf=P=000002D0oooo1`0000030?ooo`<00000103oool6000004h0oooo1`00
000A0?ooo`H00000;P3oool005X0oooo00<0P8200000000000002P0000000`1/K6`0f=SH0=SHf03F
0=SHf0<0000000<0K6a/0=SHf03Hf=P0c`3Hf=P00`2RXZ8000000000000:000000030410@03oool0
oooo02H0oooo00<0P8200000000000000`0000020820P0<000000P20P8000`10@400000000000003
000000030820P03oool0oooo01<0oooo9020P8000`30`<00oooo0?ooo`0D0?ooo`H0000000<0`<30
0?ooo`3oool03P3oool5000000030820P03oool0oooo02`0oooo001K0?ooo`030820P00000000000
00X0000000<0K6a/0=SHf03Hf=P0e@3Hf=P30000000306a/K03Hf=P0f=SH0<l0f=SH3@0000000`20
P800oooo0?ooo`0Y0?ooo`l000005`3ooolT000000030820P03oool0oooo01@0oooo1P0000000`20
P800oooo0?ooo`0>0?ooo`D00000;`3oool005/0oooo00<0P8200000000000002`00003G0=SHf0<0
000000<0K6a/0=SHf03Hf=P0cP3Hf=P>000002h0oooo00<0P8200000000000001`00000J0?ooob@0
000000<0P8200?ooo`3oool0503oool6000000030820P03oool0oooo00h0oooo1@00000_0?ooo`00
G03oool>00000=H0f=SH0`0000000`1/K6`0f=SH0=SHf03=0=SHf0h00000<`3oool3000005P0oooo
1P0000000`20P800oooo0?ooo`0=0?ooo`H00000;`3oool005d0oooo00<0P8200000000000002`00
00000`1/K6`0f=SH0=SHf03B0=SHf0<0000000<0K6a/0=SHf03Hf=P0b`3Hf=P00`2RXZ8000000000
000;000000030820P03oool0oooo0380oooo0`00001I0?ooo`D0000000<0P8200?ooo`3oool03@3o
ool5000000030410@03oool0oooo02d0oooo001O0?ooo`d0000000<0K6a/0=SHf03Hf=P0d@3Hf=P3
0000000306a/K03Hf=P0f=SH0</0f=SH3@0000000`20P800oooo0?ooo`0c0?ooo`040820P0000000
0000000005P0oooo1@0000000`20P800oooo0?ooo`0=0?ooo`D0000000<0P8200?ooo`3oool0;@3o
ool005l0oooo00<0P8200000000000002`00003C0=SHf0<0000000<0K6a/0=SHf03Hf=P0bP3Hf=P>
000003H0oooo00@0P8200000000000000000F@3oool5000000l0oooo1@0000000`20P800oooo0?oo
o`0]0?ooo`00H03oool>00000=80f=SH0`0000000`1/K6`0f=SH0=SHf0390=SHf0h00000=`3oool0
1020P800000000000000001I0?ooo`D000003`3oool500000300oooo001Q0?ooo`h00000d@3Hf=P3
0000000306a/K03Hf=P0f=SH0<P0f=SH3P00000h0?ooo`040820P00000000000000005T0oooo1@00
000>0?ooo`H00000<03oool00680oooo00<0P8200000000000002`0000000`2RXZ80f=SH0=SHf03=
0=SHf0<0000000<0K6a/0=SHf03Hf=P0a`3Hf=P00`0f=SH000000000000:000000030820P03oool0
oooo03P0oooo0`0000000`30`<00oooo0?ooo`1F0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool02`3oool500000340oooo001T0?ooo`d00000c`3Hf=P30000000306a/K03Hf=P0f=SH
0<H0f=SH3@0000000`20P800oooo0?ooo`0i0?ooo`<0000000<0P8200?ooo`3oool0E`3oool50000
00`0oooo1@00000b0?ooo`00I03oool00`20P80000000000000;00000<h0f=SH0`0000000`1/K6`0
f=SH0=SHf0350=SHf0h00000?03oool3000000030820P03oool0oooo05L0oooo1@00000<0?ooo`D0
0000<P3oool006D0oooo3P00003=0=SHf0<0000000<0K6a/0=SHf03Hf=P0a03Hf=P?000003d0oooo
0P0000000`20P800oooo0?ooo`1H0?ooo`D000002P3oool00`20P800000000000002000003<0oooo
001U0?ooo`030820P0000000000000`0000000<0XZ:R0=SHf03Hf=P0b@3Hf=P30000000306a/K03H
f=P0f=SH0<<0f=SH00<0=SHf0000000000002`0000000`20P800oooo0?ooo`0l0?ooo`80000000<0
P8200?ooo`3oool0F@3oool00`20P800000000000002000000T0oooo00D0@4100000000000000000
0<30`00c0?ooo`00I`3oool>00000</0f=SH0`0000000`1/K6`0f=SH0=SHf0320=SHf0h00000@03o
ool3000005`0oooo00<0P8200000000000000P0000070?ooo`@00000=@3oool006P0oooo3`000039
0=SHf0<0000000<0K6a/0=SHf03Hf=P0`@3Hf=P>000000030820P03oool0oooo03h0oooo0`00001M
0?ooo`D00000103oool5000003H0oooo001X0?ooo`030820P0000000000000d00000b03Hf=P30000
000306a/K03Hf=P0f=SH0;l0f=SH400000120?ooo`800000GP3oool<000003L0oooo001Y0?ooo`03
0820P0000000000000d0000000<0XZ:R0=SHf03Hf=P0a03Hf=P30000000306a/K03Hf=P0f=SH0;h0
f=SH00<0=SHf000000000000300000000`20P800oooo0?ooo`2S0?ooo`030820P0000000000000@0
00000P20P8000`30`<00oooo0?ooo`0e0?ooo`00K03oool>00000<H0f=SH0`0000000`1/K6`0f=SH
0=SHf02m0=SHf0h0000000<0P8200?ooo`3oool0iP3oool006`0oooo00<0P8200000000000003000
00350=SHf0<0000000<0K6a/0=SHf03Hf=P0_03Hf=P?00000>T0oooo001]0?ooo`l00000a03Hf=P3
0000000306a/K03Hf=P0f=SH0;/0f=SH3`00003Z0?ooo`00KP3oool00`20P80000000000000<0000
00030::RXP3Hf=P0f=SH0<00f=SH0`0000000`1/K6`0f=SH0=SHf02j0=SHf00303Hf=P0000000000
00/0000000<0P8200?ooo`3oool0j@3oool00700oooo3P0000320=SHf0<0000000<0K6a/0=SHf03H
f=P0^@3Hf=P>000000030820P03oool0oooo0>X0oooo001`0?ooo`030820P0000000000000`00000
`@3Hf=P30000000306a/K03Hf=P0f=SH0;P0f=SH3`00003]0?ooo`00L@3oool?00000<00f=SH0`00
00000`1/K6`0f=SH0=SHf02g0=SHf0l00000kP3oool00780oooo3`0000000`1/K6`0f=SH0=SHf02l
0=SHf0<0000000<0K6a/0=SHf03Hf=P0]P3Hf=P00`1/K6`000000000000<00000>l0oooo001c0?oo
o`030820P0000000000000`0000000<0K6a/0=SHf03Hf=P0^`3Hf=P30000000306a/K03Hf=P0f=SH
0;@0f=SH00<0K6a/000000000000300000000`10@400oooo0?ooo`3^0?ooo`00M03oool00`20P800
00000000000=00000;`0f=SH0`0000000`1/K6`0f=SH0=SHf02c0=SHf1000000l@3oool007H0oooo
3`00002k0=SHf0<0000000<0K6a/0=SHf03Hf=P0/P3Hf=P00`1/K6`000000000000=00000?80oooo
001g0?ooo`h0000000<0K6a/0=SHf03Hf=P0^03Hf=P30000000306a/K03Hf=P0f=SH0;80f=SH3`00
003c0?ooo`00N03oool00`20P80000000000000<00000080K6a/]`3Hf=P30000000306a/K03Hf=P0
f=SH0:l0f=SH00<0K6a/000000000000300000000`10@400P8200?ooo`3c0?ooo`00N@3oool00`20
P80000000000000=0000000306a/K03Hf=P0f=SH0;@0f=SH0`0000000`1/K6`0f=SH0=SHf02]0=SH
f00306a/K0000000000000h00000mP3oool007/0oooo3`00002f0=SHf0<0000000<0K6a/0=SHf03H
f=P0[@3Hf=P@00000?L0oooo001l0?ooo`l00000]@3Hf=P30000000306a/K03Hf=P0f=SH0:`0f=SH
4000003h0?ooo`00O@3oool00`10@40000000000000=0000000306a/K03Hf=P0f=SH0;00f=SH0`00
00000`1/K6`0f=SH0=SHf02Y0=SHf0030::RXP000000000000h0000000<0@4100?ooo`3oool0m`3o
ool007h0oooo400000000`1/K6`0f=SH0=SHf02_0=SHf0<0000000<0K6a/0=SHf03Hf=P0Z@3Hf=P@
00000?/0oooo001o0?oooa000000/@3Hf=P30000000306a/K03Hf=P0f=SH0:P0f=SH4000003l0?oo
o`00P03ooolA00000:l0f=SH0`0000000`1/K6`0f=SH0=SHf02V0=SHf1400000o@3oool00840oooo
00<0P8200000000000003P0000000`2RXZ80f=SH0=SHf02[0=SHf0<0000000<0K6a/0=SHf03Hf=P0
Y@3Hf=P00`1/K6`000000000000>000000030<30`03oool0oooo0?/0oooo00230?oooa000000[@3H
f=P30000000306a/K03Hf=P0f=SH0:@0f=SH4000003o0?ooo`40oooo00240?oooa400000Z`3Hf=P3
0000000306a/K03Hf=P0f=SH0:<0f=SH4000003o0?ooo`80oooo00250?oooa400000ZP3Hf=P30000
000306a/K03Hf=P0f=SH0:40f=SH00<0K6a/0000000000003P0000000`20P800oooo0?ooo`3o0?oo
o`00QP3ooolA00000:T0f=SH0`0000000`1/K6`0f=SH0=SHf02Q0=SHf1000000o`3oool40?ooo`00
Q`3oool00`20P80000000000000>00000080K6a/YP3Hf=P30000000306a/K03Hf=P0f=SH09h0f=SH
00<0K6a/0000000000003P0000000`20P800oooo0?ooo`3o0?ooo`<0oooo00290?oooa40000000<0
K6a/0=SHf03Hf=P0X`3Hf=P30000000306a/K03Hf=P0f=SH09d0f=SH4@00003o0?ooo`L0oooo002:
0?oooa800000Y03Hf=P30000000306a/K03Hf=P0f=SH09`0f=SH4@00003o0?ooo`P0oooo002;0?oo
oa800000X`3Hf=P30000000306a/K03Hf=P0f=SH09X0f=SH4P00003o0?ooo`T0oooo002<0?ooo`80
P820400000000`1/K6`0f=SH0=SHf02O0=SHf0<0000000<0K6a/0=SHf03Hf=P0V03Hf=P00`2RXZ80
K6a/0000000?000000030820P03oool0oooo0?l0oooo203oool008h0oooo00<0P820000000000000
3`00002P0=SHf0<0000000<0K6a/0=SHf03Hf=P0V03Hf=PA00000?l0oooo303oool008l0oooo4P00
002O0=SHf0<0000000<0K6a/0=SHf03Hf=P0UP3Hf=PB00000?l0oooo3@3oool00900oooo4`00002M
0=SHf0<0000000<0K6a/0=SHf03Hf=P0U@3Hf=PB00000?l0oooo3P3oool00980oooo00<0@4100000
000000003P0000000`0f=SH0K6a/0=SHf02J0=SHf0<0000000<0K6a/0=SHf03Hf=P0T`3Hf=P00`1/
K6`000000000000?000000030<30`03oool0oooo0?l0oooo3@3oool009<0oooo4`00002J0=SHf0<0
000000<0K6a/0=SHf03Hf=P0T@3Hf=PC00000?l0oooo4@3oool009@0oooo4`0000000`1/K6`0f=SH
0=SHf02F0=SHf0<0000000<0K6a/0=SHf03Hf=P0T03Hf=P00`1/K6`000000000000@00000?l0oooo
4P3oool009H0oooo4P00002H0=SHf0<0000000<0K6a/0=SHf03Hf=P0S`3Hf=PB000000030820P03o
ool0oooo0?l0oooo4@3oool009H0oooo00<0`<300820P020P8004@0000000`1/K6`0XZ:R0=SHf02C
0=SHf0<0000000<0K6a/0=SHf03Hf=P0S03Hf=P00`1/K6`000000000000?000000<0P820o`3ooolD
0?ooo`00VP3ooolC000009<0f=SH0`0000000`1/K6`0f=SH0=SHf02:0=SHf1<0000000<0P8200?oo
o`3oool0o`3ooolE0?ooo`00V`3ooolD00000940f=SH0`0000000`1/K6`0f=SH0=SHf0290=SHf1<0
0000o`3ooolI0?ooo`00W@3ooolB0000000306a/K03Hf=P0f=SH08h0f=SH0`0000000`1/K6`0f=SH
0=SHf0280=SHf1800000o`3ooolK0?ooo`00WP3oool00`20P800@4100000000@00000080K6a/S@3H
f=P30000000306a/K03Hf=P0f=SH08@0f=SH0P1/K6`B000000030820P03oool0oooo0?l0oooo6P3o
ool00:40oooo4`0000000`1/K6`0f=SH0=SHf0290=SHf0<0000000<0K6a/0=SHf03Hf=P0P`3Hf=PC
00000?l0oooo7`3oool00:80oooo5000002:0=SHf0<0000000<0K6a/0=SHf03Hf=P0P@3Hf=PD0000
0?l0oooo803oool00:<0oooo00<0P8200000000000004P0000280=SHf0<0000000<0K6a/0=SHf03H
f=P0O`3Hf=P00`1/K6`000000000000B00000?l0oooo8@3oool00:D0oooo500000270=SHf0<00000
00<0K6a/0=SHf03Hf=P0OP3Hf=PD00000?l0oooo8`3oool00:H0oooo00<0P8200410@00000004P00
00000`1/K6`0XZ:R0=SHf0220=SHf0<0000000<0K6a/0=SHf03Hf=P0N`3Hf=P00`1/K6`000000000
000B000000030820P03oool0oooo0?l0oooo8P3oool00:T0oooo5@0000220=SHf0<0000000<0K6a/
0=SHf03Hf=P0N@3Hf=PE00000?l0oooo9`3oool00:X0oooo5P0000200=SHf0<0000000<0K6a/0=SH
f03Hf=P0M`3Hf=P00`1/K6`000000000000C00000?l0oooo:03oool00:/0oooo00<0P82000000000
00004`00001o0=SHf0<0000000<0K6a/0=SHf03Hf=P0MP3Hf=PF00000?l0oooo:@3oool00:d0oooo
00<0P8200000000000004`0000000`1/K6`0XZ:R0=SHf01j0=SHf0<0000000<0K6a/0=SHf03Hf=P0
L`3Hf=P00`1/K6`000000000000C000000030820P03oool0oooo0?l0oooo:@3oool00:l0oooo00<0
P8200000000000005000001j0=SHf0<0000000<0K6a/0=SHf03Hf=P0L@3Hf=PG00000?l0oooo;@3o
ool00;40oooo5`00001h0=SHf0<0000000<0K6a/0=SHf03Hf=P0K`3Hf=PG00000?l0oooo;`3oool0
0;<0oooo5P0000000`1/K6`0f=SH0=SHf01d0=SHf0<0000000<0K6a/0=SHf03Hf=P0KP3Hf=PG0000
0?l0oooo<03oool00;@0oooo00<0P8200000000000005000000206a/K7<0f=SH0`0000000`1/K6`0
f=SH0=SHf01Z0=SHf0030::RXP1/K6`0000001D0000000<0P8200<30`03oool0o`3oool`0?ooo`00
]`3ooolG00000780f=SH0`0000000`1/K6`0f=SH0=SHf01Y0=SHf1L00000o`3ooole0?ooo`00^03o
ool00`20P80000000000000F000006l0f=SH0`0000000`1/K6`0f=SH0=SHf01W0=SHf1P00000o`3o
oolf0?ooo`00^@3ooolI000006h0f=SH0`0000000`1/K6`0f=SH0=SHf01U0=SHf1T00000o`3ooolg
0?ooo`00^`3oool00`20P800@4100000000G00000080K6a/J@3Hf=P30000000306a/K03Hf=P0f=SH
0640f=SH0P1/K6`H000000030820P03oool0oooo0?l0oooo=`3oool00;h0oooo6`00001W0=SHf0<0
000000<0K6a/0=SHf03Hf=P0GP3Hf=PK00000?l0oooo?03oool00<00oooo00<0P820000000000000
6000001U0=SHf0<0000000<0K6a/0=SHf03Hf=P0G03Hf=PK00000?l0oooo?P3oool00<80oooo7000
001R0=SHf0<0000000<0K6a/0=SHf03Hf=P0F@3Hf=P00`1/K6`000000000000I00000?l0oooo@03o
ool00<@0oooo00<0P8200000000000006@00001P0=SHf0<0000000<0K6a/0=SHf03Hf=P0E`3Hf=PL
00000?l0oooo@P3oool00<H0oooo0`20P80I0000000303Hf=P1/K6`0f=SH05/0f=SH0`0000000`1/
K6`0f=SH0=SHf01C0=SHf080K6a/00<0=SHf0000000000005`0000020820P?l0ooooA03oool00<X0
oooo700000000`1/K6`0f=SH0=SHf01G0=SHf0<0000000<0K6a/0=SHf03Hf=P0D@3Hf=PL00000?l0
ooooB03oool00<`0oooo7@00001G0=SHf0<0000000<0K6a/0=SHf03Hf=P0CP3Hf=PM00000?l0oooo
BP3oool00<h0oooo7@00001E0=SHf0<0000000<0K6a/0=SHf03Hf=P0C@3Hf=PM00000?l0ooooB`3o
ool00=00oooo00<0P8200410@00000006`00000306a/K4l0f=SH0`0000000`1/K6`0f=SH0=SHf016
0=SHf0<0K6a/7@0000000`20P800oooo0?ooo`3o0?oood`0oooo003C0?ooob00000000<0K6a/0=SH
f03Hf=P0BP3Hf=P30000000306a/K03Hf=P0f=SH04@0f=SH8000003o0?oooe40oooo003E0?ooo`03
0820P0000000000001l00000B@3Hf=P30000000306a/K03Hf=P0f=SH0400f=SH00<0K6a/00000000
00007`00003o0?oooe<0oooo003G0?ooob<00000AP3Hf=P30000000306a/K03Hf=P0f=SH03h0f=SH
8P00003o0?oooeD0oooo003J0?ooo`<0P8208000000406a/K3l0f=SH0`0000000`1/K6`0f=SH0=SH
f00g0=SHf0<0K6a/800000030820P?l0ooooF03oool00=l0oooo9@0000000`1/K6`0f=SH0=SHf00i
0=SHf0<0000000<0K6a/0=SHf03Hf=P0<`3Hf=PV00000?l0ooooG03oool00>40oooo:000000g0=SH
f0<0000000<0K6a/0=SHf03Hf=P0;P3Hf=PX00000?l0ooooG`3oool00><0oooo:`00000b0=SHf0<0
000000<0K6a/0=SHf03Hf=P0:@3Hf=P[00000?l0ooooH@3oool00>H0oooo0P20P80[000000L0K6a/
9P3Hf=P30000000306a/K03Hf=P0f=SH01h0f=SH1P1/K6`[00000080P82000<0`<300?ooo`3oool0
o`3ooomQ0?ooo`00j`3ooolf0000000306a/K03Hf=P0f=SH01`0f=SH0`0000000`1/K6`0f=SH0=SH
f00F0=SHf3H00000o`3ooomY0?ooo`00kP3ooolk000001L0f=SH0`0000000`1/K6`0f=SH0=SHf00?
0=SHf3X00000o`3ooom/0?ooo`00l@3ooolo00000100f=SH0`0000000`1/K6`0f=SH0=SHf0070=SH
f4000000o`3ooom^0?ooo`00l`3oool00`20P80000000000002D00000?l0ooooL@3oool00?L0oooo
00D0`<300820P020P800P8200410@026000000040410@020P800P8200820P?l0ooooM@3oool00?l0
ooooO`0000000`20P800oooo0?ooo`3o0?ooogX0oooo003o0?ooo`<0ooooN@00003o0?oooh00oooo
003o0?ooo`T0ooooKP00003o0?ooohD0oooo003o0?ooo`d0oooo00<0`<300820P020P8000P20P81L
000000@0P82000<0`<300?ooo`3oool0o`3ooon70?ooo`00o`3ooolG0?oooe400000o`3ooonD0?oo
o`00o`3ooolL0?ooodL00000o`3ooonI0?ooo`00o`3ooolQ0?ooocd00000o`3ooonN0?ooo`00o`3o
ool`0?oooa40P8200`0000000`10@400P8200820P0080820P?l0oooo[@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo
@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03o
ool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool0
0?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool300000003
0820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo
]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3
000000030820P03oool0oooo0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo
0?l0oooo]@3oool00?l0oooo@@3oool3000000030820P03oool0oooo00h0oooo00<0P82000000000
00004P0000000`20P800oooo0?ooo`3o0?ooohl0oooo003o0?oood40oooo0`0000000`20P800oooo
0?ooo`0>0?ooo`030820P0000000000001<00000o`3ooonA0?ooo`00o`3ooom10?ooo`<0000000<0
P8200?ooo`3oool03`3ooolE00000?l0ooooT@3oool00?l0oooo@@3oool3000000030820P03oool0
oooo0100oooo5@00003o0?oooi00oooo003o0?oood40oooo0`0000000`20P800oooo0?ooo`0A0?oo
oa@00000o`3ooon@0?ooo`00o`3ooom10?ooo`<0000000<0P8200?ooo`3oool04P3oool00`10@400
P8200?ooo`0=0?ooo`040820P010@40000000820P?l0ooooS`3oool00?l0oooo@@3oool300000003
0820P03oool0oooo01<0oooo0P00000>0?ooo`030820P000000000000?l0ooooS`3oool00?l0oooo
@@3oool3000000030820P03oool0oooo01@0oooo0P00000>0?ooo`800000o`3ooon?0?ooo`00o`3o
oom10?ooo`<0000000<0P8200?ooo`3oool05@3oool00`000000P8200?ooo`0<0?ooo`<00000o`3o
oon>0?ooo`00o`3ooolk0?ooo`H0P8200`0000000`10@400P8200820P0040820P180oooo00<0@410
0820P03oool0303oool20820P?l0ooooSP3oool00?l0oooo>03ooolE00000140oooo0P00003o0?oo
oi`0oooo003o0?ooocH0oooo6P00000?0?ooo`800000o`3ooonK0?ooo`00o`3ooolf0?oooaX00000
403oool00`000000P8200?ooo`3o0?oooiT0oooo003o0?ooocL0oooo6@00000@0?ooo`800000o`3o
oonJ0?ooo`00o`3ooolg0?oooaP0000000<0P8200?ooo`3oool03`3oool00`10@40000000820P03o
0?oooiP0oooo003o0?ooocL0oooo00<0P8200000000000005@00000C0?ooo`<00000o`3ooonG0?oo
o`00o`3ooolg0?ooo`030820P0000000000001D00000503oool2000000030820P03oool0oooo0?l0
ooooU03oool00?l0oooo=`3oool00`20P80000000000000D000001H0oooo0P00003o0?oooiH0oooo
003o0?ooocP0oooo5@0000000`20P800oooo0?ooo`0E0?ooo`030410@020P800oooo0?l0ooooU03o
ool00?l0oooo>03ooolE000001T0oooo0P00003o0?oooi@0oooo003o0?ooocT0oooo4`0000000`20
P800oooo0?ooo`0H0?ooo`800000o`3ooonC0?ooo`00o`3oooli0?oooa<0000000<0P8200?ooo`3o
ool06@3oool200000?l0ooooTP3oool00?l0oooo>P3ooolB000000030<30`03oool0oooo00X0oooo
00<0P82000000020P8003@3oool00`20P800@4100?ooo`3o0?oooi00oooo003o0?ooocX0oooo4P00
000>0?ooo`8000003P3oool00`20P80000000?ooo`3o0?ooohl0oooo003o0?oooc/0oooo4@00000>
0?ooo`<000003P3oool200000?l0ooooS`3oool00?l0oooo>`3ooolA000000h0oooo1000000>0?oo
o`800000o`3ooon>0?ooo`00o`3ooolk0?ooo`030410@0000000000000d00000403ooolC00000003
0410@03oool0oooo0?l0ooooR`3oool00?l0oooo>`3oool00`20P80000000000000=00000100oooo
5@00003o0?oooh`0oooo003o0?oooc/0oooo00<0P8200000000000003000000B0?oooaD00000o`3o
oon;0?ooo`00o`3oooll0?ooo`h000004P3ooolF00000?l0ooooRP3oool00?l0oooo?03oool>0000
0180oooo5P00003o0?ooohX0oooo003o0?oooc`0oooo00<0P8200000000000002P00003o0?oook<0
oooo003o0?ooocd0oooo2`0000000`20P800oooo0?ooo`3o0?oook40oooo003o0?ooocd0oooo2`00
00000`20P800oooo0?ooo`3o0?oook40oooo003o0?oooch0oooo2P0000000`20P800oooo0?ooo`3o
0?oook40oooo003o0?oooch0oooo2P00003o0?oook@0oooo003o0?ooocl0oooo2000003o0?oookD0
oooo003o0?ooocl0oooo2000003o0?oookD0oooo003o0?ooocl0oooo2000003o0?oookD0oooo003o
0?ooocl0oooo00<0P8200000000000001000003o0?oookH0oooo003o0?oood00oooo1@00003o0?oo
okL0oooo003o0?oood00oooo1@00003o0?oookL0oooo003o0?oood00oooo1@00003o0?oookL0oooo
003o0?oood40oooo0`0000000`20P800oooo0?ooo`3o0?oookD0oooo003o0?oood40oooo0`000000
0`20P800oooo0?ooo`3o0?oookD0oooo003o0?oood80oooo0P00003o0?oookP0oooo003o0?oood80
oooo0P00003o0?oookP0oooo003o0?oood80oooo0P00003o0?oookP0oooo003o0?ooool0ooooo03o
ool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0oooo
o`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?oo
o`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo
0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo
003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0
ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool0
0?l0ooooo`3ooool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3o
oool0?ooo`00o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00
o`3ooooo0?oooo`0oooo003o0?ooool0ooooo03oool00?l0ooooo`3ooool0?ooo`00o`3ooooo0?oo
oo`0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{146.562, 149.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.6", "Caption",
  CellTags->"Fig. 4.6"],

Cell[TextData[{
  "\tAs in the previous examples, we take account of the inhomogeneous \
boundary condition by using a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"u", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " that matches this boundary condition:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(u(a, \[Theta], \[Phi])\), " ", "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(0, \ \ \ \ 0 \[LessEqual] \ \[Theta] \[LessEqual] \ \
\[Pi]/2, \)},
                    {\(V\_o, \ \[Pi]/
                          2 < \[Theta] < \(\(\[Pi]\)\(\ \)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            (#&)], " "}], TraditionalForm]]]
}], "NE4",
  CellTags->"(4.3.64)"],

Cell[TextData[{
  "However, this boundary condition is rapidly varying. Therefore, it is best \
to choose a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta], \[Phi])\)]],
  " that satisfies the Laplace equation  with these boundary conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u\  = \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe considered this part of the problem previously, in Sec. ",
  ButtonBox["3.2.4",
    ButtonData:>{"Chapter3.nb", "c:34"},
    ButtonStyle->"Hyperlink"],
  ". The solution is a sum of spherical harmonics, given by Eqs. ",
  ButtonBox["(3.2.41)",
    ButtonData:>{"Chapter3.nb", "(3.2.41)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.2.42)",
    ButtonData:>{"Chapter3.nb", "(3.2.42)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(u(r, \[Theta], \[Phi])\), "=", 
          
          FormBox[\(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \(-l\)\)\%l \
B\_\(l\ m\)\ r\^l\ \(\(Y\_\(l\ , m\)\)(\[Theta], \[Phi])\)\)\),
            "TraditionalForm"]}], ","}], TraditionalForm]]]], "NE4",
  CellTags->"(4.3.65)"],

Cell[TextData[{
  "where the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(l\ m\)\)]],
  " are determined by matching to the boundary conditions:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`B\_\(l\ m\)\ a\^l = \(\(V\_o\) \(\[Integral]\_0\%\(2\ \
\[Pi]\)\[DifferentialD]\[Phi] \(\[Integral]\_\(\[Pi]/2\)\%\[Pi] 
                  sin\ \[Theta] \[DifferentialD]\[Theta]\ \(\(Y\_\(l, \ \
m\)\^*\)(\[Theta], \[Phi])\)\)\) = \[Delta]\_\(m\ 0\)\ 2  \[Pi]\ \(V\_o\) \(\
\[Integral]\_\(\[Pi]/2\)\%\[Pi] 
              sin\ \[Theta] \[DifferentialD]\[Theta]\ \(\(\(Y\_\(l, \ \
0\)\^*\)(\[Theta])\)\(.\)\)\)\)\)]]], "NE4",
  CellTags->"(4.3.66)"],

Cell[TextData[{
  "As expected for cylindrically symmetric boundary conditions, only \
spherical harmonics with ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " enter in  the expansion for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe then write the potential \[Phi] as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = \[CapitalDelta]\[Phi]\  + \ u\)]],
  ", and solve for \[CapitalDelta]\[Phi] using Eq. ",
  ButtonBox["(4.3.17)",
    ButtonData:>"(4.3.17)",
    ButtonStyle->"Hyperlink"],
  ". The fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = 0\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\&_ = \[Rho]\)]],
  ". Therefore the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi]\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi](
          r, \[Theta], \[Phi])\  = \ \(-\(1\/\[Epsilon]\_o\)\) \(\[Sum]\+\
\[Alpha]\(\((\[Psi]\_\[Alpha], \[Rho])\)\/\(\[Lambda]\_\[Alpha]\ \((\[Psi]\_\
\[Alpha], \[Psi]\_\[Alpha])\)\)\) \(\(\[Psi]\_\[Alpha]\)(
                r, \[Theta], \[Phi])\)\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.67)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \((l, m, n)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha]\)]],
  " is given by Eq. ",
  ButtonBox["(4.3.58)",
    ButtonData:>"(4.3.58)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  " is given by Eq. ",
  ButtonBox["(4.3.62)",
    ButtonData:>"(4.3.62)",
    ButtonStyle->"Hyperlink"],
  ". The inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Rho])\)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(l\ m\ n\), \[Rho])\) = \
\[Integral]\_0\%a\( 
                r\^2\) \[DifferentialD]r\ \(\(\(J\_\(l + 
                        1/2\)\)(\(j\_\(l + 1/2, \ n\)\) 
                    r/a)\)\/\@r\) \(\[Integral]\_0\%\(2\ \[Pi]\)\
\[DifferentialD]\[Phi] \(\[Integral]\_0\%\(\[Pi]/2\)sin\[Theta] \
\[DifferentialD]\[Theta]\ \(\[Rho]\_o\) \(\(Y\_\(l, \ 
                          m\)\)(\[Theta], \[Phi])\)\)\)\)]],
  "."
}], "NE4",
  CellTags->"(4.3.68)"],

Cell[TextData[{
  " The \[Phi]-integral picks out only the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " eigenmodes, since the charge distribution is cylindrically symmetric. The \
",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and \[Theta] integrals can also be performed analytically, although the \
results are rather messy. It is best to simply leave the work to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by defining this inner product as a function ",
  StyleBox["\[Rho][l,n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". It is fastest and easiest to perform the radial integrals numerically \
using ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This requires scaling the radius to ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " so that the radial integral runs from 0 to 1:"
}], "Text"],

Cell[BoxData[
    \(\[Rho][l_, 
        n_]\  := \ \(\[Rho][l, 
          n]\  = \[IndentingNewLine]\[Rho]\_o\ \(a\^\(\(5/2\)\(\ \)\)\) 
          NIntegrate[\(r\^\(3/2\)\) BesselJ[l + 1/2, j[l, n]\ r], {r, 0, 
              1}]*\[IndentingNewLine]2\ \[Pi]\ Integrate[
            Sin[\[Theta]]\ SphericalHarmonicY[l, 
                0, \[Theta], \[Phi]], {\[Theta], 0, Pi/2}]\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.35"],

Cell[TextData[{
  "Here, we have also introduced another function, ",
  StyleBox["j[l,n]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "which is ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(l + 1/2, \ n\)\)]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th zero of the ",
  Cell[BoxData[
      \(TraditionalForm\`J\_\(l + 1/2\)\)]],
  " . This can be defined as follows:"
}], "Text"],

Cell[BoxData[{
    \(\(<< NumericalMath`;\)\), "\n", 
    \(\(zeros = Table[BesselJZeros[l + 1/2, 10], {l, 0, 9}];\)\), "\n", 
    \(j[l_, n_]\  := \ zeros[\([l + 1, n]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.36"],

Cell[TextData[{
  "For example, the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\[Alpha], \[Rho])\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(\((l, m, n)\)\  = \ \((3, 0, 
            4)\)\)\)]],
  " is given by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Rho][3, 4]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.37"],

Cell[BoxData[
    \(0.0037593875498197135`\ a\^\(5/2\)\ \[Rho]\_o\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Phi]\)]],
  " is given in terms of the spherical eigenmodes by Eq. ",
  ButtonBox["(4.3.67)",
    ButtonData:>"(4.3.67)",
    ButtonStyle->"Hyperlink"],
  ".  This generalized Fourier series is evaluated below:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["(*",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[" ",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[\(define\ the\ spherical\ eigenmodes\),
          FontColor->RGBColor[1, 0, 0]], " ", 
        StyleBox["*)",
          FontColor->RGBColor[1, 0, 0]]}], 
      RowBox[{
        RowBox[{\(\[Psi][l_, m_, n_, r_, \[Theta]_, \[Phi]_]\  := \ 
              BesselJ[l + 1/2, \ j[l, n]\ r/a]/Sqrt[r]\ \ SphericalHarmonicY[
                  l, m, \[Theta], \[Phi]];\), "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{
            StyleBox["(*",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox[\(define\ the\ eigenvalues\),
              FontColor->RGBColor[1, 0, 0]], " ", 
            StyleBox["*)",
              FontColor->RGBColor[1, 0, 0]]}], 
          "\[IndentingNewLine]", \(\[Lambda][l_, n_]\  := \ \(-j[l, n]^2\)/
                a^2;\), "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          StyleBox[\( (*\ 
              define\ the\ inner\ product\ \((\[Psi]\_\[Alpha], \[Psi]\_\
\[Alpha])\)\ *) \),
            FontColor->RGBColor[1, 0, 0]], 
          "\[IndentingNewLine]", \(\[Psi]\[Psi][l_, n_]\  := \ \(a\^2\/2\) 
                BesselJ[l + 3/2, j[l, n]]^2;\)}], "\[IndentingNewLine]", 
        StyleBox[\( (*\ sum\ the\ series\ to\ determine\ the\ potential, \ 
            using\ Eq . \ \((4  .3  .67)\)\ *) \),
          FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(\[CapitalDelta]\[Phi][
              r_, \[Theta]_]\  = \ \ \(-\(1\/\[Epsilon]\_o\)\) 
              Sum[\(\(\(\[Rho][l, 
                        n]\)\(\ \)\)\/\(\[Lambda][l, n]\ \[Psi]\[Psi][l, 
                          n]\)\) \[Psi][l, 0, n, r, \[Theta], \[Phi]], {l, 0, 
                  4}, {n, 1, 5}];\), "\[IndentingNewLine]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.38"],

Cell[TextData[{
  "Now we must add to this the potential ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta], \[Phi])\)]],
  " arising from the boundary conditions, using Eqs. ",
  ButtonBox["(4.3.65)",
    ButtonData:>"(4.3.65)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.66)",
    ButtonData:>"(4.3.66)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(\(b[l_]\  = 
        2\ \[Pi]\ \(V\_o\) 
          Integrate[
              Sin[\[Theta]]\ SphericalHarmonicY[l, 
                  0, \[Theta], \[Phi]], {\[Theta], Pi/2, Pi}]\ /
            a\^l;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(u[r_, \[Theta]_]\  = \ 
        Sum[b[l]\ r\^l\ SphericalHarmonicY[l, 0, \[Theta], \[Phi]], {l, 0, 
            40}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.39"],

Cell[TextData[{
  "Finally, we plot  in Cell ",
  ButtonBox["4.40",
    ButtonData:>"Cell 4.40",
    ButtonStyle->"Hyperlink"],
  " the resulting potential  on a cut through the center of the sphere, along \
the ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " plane, taking the potential on the boundary to be ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\_o\), "=", 
          RowBox[{"1", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and a charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o = 3\ \[Epsilon]\_o\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ parameters\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
      RowBox[{\(V\_\(\(o\)\(\ \)\)\  = \ 1\ ; \[Rho]\_o\  = \ 
          3  \[Epsilon]\_o\ ; a = 1;\), "\n", 
        StyleBox[\( (*\ construct\ the\ total\ potential\ *) \),
          FontColor->RGBColor[1, 0, 0]], 
        "\n", \(\[CapitalPhi][
              r_, \[Theta]_]\  = \ \[CapitalDelta]\[Phi][r, \[Theta]] + 
              u[r, \[Theta]];\), "\n", 
        "\[IndentingNewLine]", \(ParametricPlot3D[{r\ Sin[\[Theta]], 
              r\ Cos[\[Theta]], \[CapitalPhi][r, \[Theta]]}, {r, 0.001, 
              1}, {\[Theta], 0, 2  Pi}, PlotPoints \[Rule] {20, 80}, 
            BoxRatios \[Rule] {1, 1, 1/2}, 
            ViewPoint -> {2.899, \ 0.307, \ 1.718}, 
            AxesLabel \[Rule] {"\<x\>", "\<z\>", "\<\[Phi]\>"}, 
            PlotLabel \[Rule] "\<Potential inside a sphere\>"];\)}]}]], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 4.40"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .84146 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.08862e-16 1.09001 -0.0811538 1.09001 [
[.5 .85396 -77 0 ]
[.5 .85396 77 12 ]
[.18818 .83492 -12 -4.30936 ]
[.18818 .83492 0 4.69064 ]
[.14784 .75883 -24 -4.298 ]
[.14784 .75883 0 4.702 ]
[.10251 .67334 -6 -4.2852 ]
[.10251 .67334 0 4.7148 ]
[.05121 .5766 -18 -4.27067 ]
[.05121 .5766 0 4.72933 ]
[-0.00732 .46621 -6 -4.25404 ]
[-0.00732 .46621 0 4.74596 ]
[.03446 .67659 -10 -5.7136 ]
[.03446 .67659 0 6.2864 ]
[.0666 .04719 -5.35009 -9 ]
[.0666 .04719 6.64991 0 ]
[.27997 .03264 -11.2775 -9 ]
[.27997 .03264 12.7225 0 ]
[.49633 .01792 -2.96671 -9 ]
[.49633 .01792 3.03329 0 ]
[.71573 .00302 -9.3514 -9 ]
[.71573 .00302 8.6486 0 ]
[.93826 -0.01205 -3.27074 -9 ]
[.93826 -0.01205 2.72926 0 ]
[.49725 -0.05021 -4.94472 -12 ]
[.49725 -0.05021 5.05528 0 ]
[.97817 .02644 0 -4.80082 ]
[.97817 .02644 6 4.19918 ]
[.98583 .1067 0 -4.78934 ]
[.98583 .1067 24 4.21066 ]
[.99377 .18994 0 -4.77744 ]
[.99377 .18994 18 4.22256 ]
[1.00201 .27633 0 -4.7651 ]
[1.00201 .27633 24 4.2349 ]
[1.01058 .36606 0 -4.75228 ]
[1.01058 .36606 6 4.24772 ]
[1.06175 .18556 0 -6.36996 ]
[1.06175 .18556 10 5.63004 ]
[ 0 0 0 0 ]
[ 1 .84146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .85396 -138 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Potential) show
123.000 13.000 moveto
(inside) show
165.000 13.000 moveto
(a) show
177.000 13.000 moveto
(sphere) show
213.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.20557 .84146 m
0 .45361 L
s
.20179 .83434 m
.2086 .83405 L
s
[(-1)] .18818 .83492 1 -0.04237 Mshowa
.16145 .75822 m
.16825 .75792 L
s
[(-0.5)] .14784 .75883 1 -0.04489 Mshowa
.11612 .6727 m
.12292 .67237 L
s
[(0)] .10251 .67334 1 -0.04773 Mshowa
.06482 .57591 m
.07162 .57556 L
s
[(0.5)] .05121 .5766 1 -0.05096 Mshowa
.00628 .46547 m
.01309 .4651 L
s
[(1)] -0.00732 .46621 1 -0.05466 Mshowa
.125 Mabswid
.19408 .81979 m
.19817 .81962 L
s
.1862 .80492 m
.19028 .80474 L
s
.17814 .78971 m
.18222 .78953 L
s
.16989 .77415 m
.17397 .77396 L
s
.15281 .74192 m
.15689 .74174 L
s
.14396 .72523 m
.14805 .72505 L
s
.13491 .70814 m
.13899 .70795 L
s
.12563 .69064 m
.12971 .69044 L
s
.10637 .65431 m
.11045 .65411 L
s
.09638 .63545 m
.10046 .63525 L
s
.08613 .61611 m
.09021 .61591 L
s
.07561 .59627 m
.07969 .59606 L
s
.05374 .555 m
.05782 .55479 L
s
.04235 .53352 m
.04644 .53331 L
s
.03066 .51146 m
.03474 .51124 L
s
.01864 .48878 m
.02272 .48856 L
s
gsave
.03446 .67659 -71 -9.7136 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.04424 .06215 m
.96197 0 L
s
.06513 .06073 m
.0644 .06751 L
s
[(-1)] .0666 .04719 -0.10832 1 Mshowa
.27915 .04624 m
.27874 .05304 L
s
[(-0.5)] .27997 .03264 -0.06021 1 Mshowa
.49618 .03154 m
.4961 .03836 L
s
[(0)] .49633 .01792 -0.0111 1 Mshowa
.71626 .01664 m
.71653 .02345 L
s
[(0.5)] .71573 .00302 .03904 1 Mshowa
.93948 .00152 m
.94009 .00831 L
s
[(1)] .93826 -0.01205 .09025 1 Mshowa
.125 Mabswid
.1077 .05785 m
.1073 .06192 L
s
.15038 .05496 m
.15002 .05903 L
s
.19319 .05206 m
.19286 .05614 L
s
.23611 .04915 m
.23582 .05323 L
s
.32231 .04332 m
.32211 .0474 L
s
.3656 .04039 m
.36543 .04447 L
s
.409 .03745 m
.40888 .04153 L
s
.45253 .0345 m
.45244 .03859 L
s
.53995 .02858 m
.53994 .03267 L
s
.58384 .02561 m
.58388 .02969 L
s
.62786 .02263 m
.62793 .02671 L
s
.672 .01964 m
.67212 .02372 L
s
.76065 .01363 m
.76085 .01772 L
s
.80517 .01062 m
.80541 .0147 L
s
.84981 .00759 m
.8501 .01167 L
s
.89458 .00456 m
.89491 .00864 L
s
gsave
.49725 -0.05021 -65.9447 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.96197 0 m
1 .39856 L
s
.96458 .02735 m
.95778 .0278 L
s
[(0)] .97817 .02644 -1 .06685 Mshowa
.97223 .10757 m
.96543 .10801 L
s
[(0.25)] .98583 .1067 -1 .0643 Mshowa
.98017 .19078 m
.97337 .1912 L
s
[(0.5)] .99377 .18994 -1 .06165 Mshowa
.98841 .27714 m
.98161 .27754 L
s
[(0.75)] 1.00201 .27633 -1 .05891 Mshowa
.99697 .36683 m
.99017 .36721 L
s
[(1)] 1.01058 .36606 -1 .05606 Mshowa
.125 Mabswid
.96609 .04316 m
.96201 .04343 L
s
.96761 .05909 m
.96353 .05936 L
s
.96914 .07514 m
.96506 .0754 L
s
.97068 .0913 m
.9666 .09156 L
s
.9738 .12397 m
.96972 .12423 L
s
.97537 .14049 m
.97129 .14075 L
s
.97696 .15713 m
.97288 .15738 L
s
.97856 .17389 m
.97448 .17415 L
s
.9818 .20779 m
.97772 .20804 L
s
.98343 .22493 m
.97935 .22518 L
s
.98508 .2422 m
.981 .24245 L
s
.98674 .2596 m
.98266 .25985 L
s
.9901 .2948 m
.98602 .29504 L
s
.9918 .3126 m
.98772 .31284 L
s
.99351 .33054 m
.98943 .33077 L
s
.99523 .34861 m
.99115 .34884 L
s
.96308 .01165 m
.959 .01192 L
s
.99872 .38518 m
.99464 .38541 L
s
gsave
1.06175 .18556 -61 -10.37 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.2272 .50946 m
.20557 .84146 L
s
.20557 .84146 m
.97532 .80904 L
s
.97532 .80904 m
.94726 .47141 L
s
.94726 .47141 m
.2272 .50946 L
s
.04424 .06215 m
.96197 0 L
s
.96197 0 m
1 .39856 L
s
1 .39856 m
0 .45361 L
s
0 .45361 m
.04424 .06215 L
s
.2272 .50946 m
.20557 .84146 L
s
.20557 .84146 m
0 .45361 L
s
0 .45361 m
.04424 .06215 L
s
.04424 .06215 m
.2272 .50946 L
s
.94726 .47141 m
.96197 0 L
s
.96197 0 m
1 .39856 L
s
1 .39856 m
.97532 .80904 L
s
.97532 .80904 m
.94726 .47141 L
s
0 0 m
1 0 L
1 .84146 L
0 .84146 L
closepath
clip
newpath
.5 Mabswid
.60019 .56558 m .60193 .4882 L .62955 .51173 L p .69 .439 .538 r
F P
0 g
s
.57423 .67343 m .57589 .7167 L .60193 .4882 L p .994 .789 .518 r
F P
0 g
s
.60193 .4882 m .60019 .56558 L .57423 .67343 L p .994 .789 .518 r
F P
0 g
s
.65155 .5162 m .65608 .4899 L .68282 .49884 L p .638 .327 .428 r
F P
0 g
s
.65608 .4899 m .65155 .5162 L .626 .5316 L p .387 .077 .313 r
F P
0 g
s
.626 .5316 m .62955 .51173 L .65608 .4899 L p .387 .077 .313 r
F P
0 g
s
.62955 .51173 m .626 .5316 L .60019 .56558 L p .69 .439 .538 r
F P
0 g
s
.67672 .50818 m .68282 .49884 L .70824 .48127 L p .021 0 0 r
F P
0 g
s
.68282 .49884 m .67672 .50818 L .65155 .5162 L p .638 .327 .428 r
F P
0 g
s
.70125 .49887 m .70824 .48127 L .73365 .48434 L p .553 .202 .327 r
F P
0 g
s
.70824 .48127 m .70125 .49887 L .67672 .50818 L p .021 0 0 r
F P
0 g
s
.64677 .53627 m .65155 .5162 L .67672 .50818 L p .494 .163 .334 r
F P
0 g
s
.65155 .5162 m .64677 .53627 L .62245 .55667 L p .488 .188 .383 r
F P
0 g
s
.62245 .55667 m .626 .5316 L .65155 .5162 L p .488 .188 .383 r
F P
0 g
s
.626 .5316 m .62245 .55667 L .59782 .59507 L p .412 .147 .399 r
F P
0 g
s
.59782 .59507 m .60019 .56558 L .626 .5316 L p .412 .147 .399 r
F P
0 g
s
.72515 .49186 m .73365 .48434 L .75745 .46719 L p 0 0 0 r
F P
0 g
s
.73365 .48434 m .72515 .49186 L .70125 .49887 L p .553 .202 .327 r
F P
0 g
s
.67066 .52338 m .67672 .50818 L .70125 .49887 L p .395 .029 .22 r
F P
0 g
s
.67672 .50818 m .67066 .52338 L .64677 .53627 L p .494 .163 .334 r
F P
0 g
s
.74814 .48231 m .75745 .46719 L .78103 .46654 L p .448 .073 .233 r
F P
0 g
s
.75745 .46719 m .74814 .48231 L .72515 .49186 L p 0 0 0 r
F P
0 g
s
.57272 .65848 m .57423 .67343 L .60019 .56558 L p .996 .86 .535 r
F P
0 g
s
.60019 .56558 m .59782 .59507 L .57272 .65848 L p .996 .86 .535 r
F P
0 g
s
.694 .51312 m .70125 .49887 L .72515 .49186 L p .386 .004 .187 r
F P
0 g
s
.70125 .49887 m .694 .51312 L .67066 .52338 L p .395 .029 .22 r
F P
0 g
s
.71667 .50403 m .72515 .49186 L .74814 .48231 L p .236 0 .042 r
F P
0 g
s
.72515 .49186 m .71667 .50403 L .694 .51312 L p .386 .004 .187 r
F P
0 g
s
.78103 .46654 m .77026 .47403 L .74814 .48231 L p .448 .073 .233 r
F P
0 g
s
.77026 .47403 m .78103 .46654 L .80271 .44864 L p .543 .89 .655 r
F P
0 g
s
.6418 .5533 m .64677 .53627 L .67066 .52338 L p .389 .043 .253 r
F P
0 g
s
.64677 .53627 m .6418 .5533 L .61871 .5752 L p .347 .027 .273 r
F P
0 g
s
.61871 .5752 m .62245 .55667 L .64677 .53627 L p .347 .027 .273 r
F P
0 g
s
.66446 .53819 m .67066 .52338 L .694 .51312 L p .357 0 .19 r
F P
0 g
s
.67066 .52338 m .66446 .53819 L .6418 .5533 L p .389 .043 .253 r
F P
0 g
s
.62245 .55667 m .61871 .5752 L .59521 .60826 L p 0 0 .09 r
F P
0 g
s
.59521 .60826 m .59782 .59507 L .62245 .55667 L p 0 0 .09 r
F P
0 g
s
.73854 .49483 m .74814 .48231 L .77026 .47403 L p .23 0 .035 r
F P
0 g
s
.74814 .48231 m .73854 .49483 L .71667 .50403 L p .236 0 .042 r
F P
0 g
s
.68658 .52648 m .694 .51312 L .71667 .50403 L p .309 0 .122 r
F P
0 g
s
.694 .51312 m .68658 .52648 L .66446 .53819 L p .357 0 .19 r
F P
0 g
s
.79121 .46313 m .80271 .44864 L .82396 .4452 L p .316 0 .127 r
F P
0 g
s
.80271 .44864 m .79121 .46313 L .77026 .47403 L p .543 .89 .655 r
F P
0 g
s
.70804 .51632 m .71667 .50403 L .73854 .49483 L p .228 0 .036 r
F P
0 g
s
.71667 .50403 m .70804 .51632 L .68658 .52648 L p .309 0 .122 r
F P
0 g
s
.57124 .65099 m .57272 .65848 L .59782 .59507 L p .969 .918 .583 r
F P
0 g
s
.59521 .60826 m .58863 .61999 L p .59412 .60285 L .969 .918 .583 r
F P
0 g
s
.58863 .61999 m .57124 .65099 L p .58201 .62834 L .969 .918 .583 r
F P
0 g
s
.58201 .62834 m .59412 .60285 L .58863 .61999 L .969 .918 .583 r
F
.61871 .5752 m .61478 .58744 L .59248 .61447 L p 0 0 0 r
F P
0 g
s
.59248 .61447 m .59521 .60826 L .60552 .59375 L p 0 0 0 r
F P
0 g
s
.60552 .59375 m .61871 .5752 L p .60404 .59716 L 0 0 0 r
F P
0 g
s
.59248 .61447 m .60552 .59375 L .60404 .59716 L 0 0 0 r
F
.60624 .5978 m .61478 .58744 L p .60985 .59325 L .613 .863 .511 r
F P
0 g
s
.61071 .59507 m .60018 .60604 L p .60985 .59325 L .613 .863 .511 r
F P
0 g
s
.59248 .61447 m .60624 .5978 L p .60055 .60438 L .613 .863 .511 r
F P
0 g
s
.56975 .64557 m .57124 .65099 L .59521 .60826 L p .935 .958 .652 r
F P
0 g
s
.59521 .60826 m .59248 .61447 L p .58225 .62726 L .935 .958 .652 r
F P
0 g
s
.58967 .61699 m .59248 .61447 L p .60055 .60438 L .613 .863 .511 r
F P
0 g
s
.59248 .61447 m .56975 .64557 L p .58225 .62726 L .935 .958 .652 r
F P
0 g
s
.60157 .60299 m .60624 .5978 L .60985 .59325 L .613 .863 .511 r
F
.58967 .61699 m .60335 .60115 L .60157 .60299 L F
.60335 .60115 m .60624 .5978 L .60157 .60299 L F
.60018 .60604 m .58967 .61699 L p .60145 .60313 L F P
0 g
s
.60145 .60313 m .60985 .59325 L .60018 .60604 L .613 .863 .511 r
F
.58679 .61733 m .58967 .61699 L .60212 .60402 L p .71 .952 .67 r
F P
0 g
s
.60212 .60402 m .61071 .59507 L p .59899 .60598 L .71 .952 .67 r
F P
0 g
s
.58679 .61733 m .60212 .60402 L .59899 .60598 L .71 .952 .67 r
F
.60653 .59953 m .59405 .61078 L p .59917 .60595 L F P
0 g
s
.61071 .59507 m .60653 .59953 L p .59917 .60595 L .71 .952 .67 r
F P
0 g
s
.63134 .57655 m .62588 .5835 L .60653 .59953 L p 0 0 0 r
F P
0 g
s
.60653 .59953 m .62588 .5835 L p .61696 .59042 L .556 .892 .644 r
F P
0 g
s
.59603 .60873 m .61071 .59507 L .59405 .61078 L .71 .952 .67 r
F
.60653 .59953 m .61071 .59507 L .61494 .59128 L p 0 0 0 r
F P
0 g
s
.61494 .59128 m .63134 .57655 L p .61589 .59086 L 0 0 0 r
F P
0 g
s
.60653 .59953 m .61494 .59128 L .61589 .59086 L 0 0 0 r
F
.63789 .57573 m .62028 .58822 L p .62765 .58259 L F P
0 g
s
.64478 .5695 m .63789 .57573 L p .62765 .58259 L 0 0 0 r
F P
0 g
s
.66316 .55724 m .65499 .56431 L .63789 .57573 L p 0 0 0 r
F P
0 g
s
.63789 .57573 m .65499 .56431 L p .64875 .56844 L .405 .811 .601 r
F P
0 g
s
.63789 .57573 m .64478 .5695 L .66316 .55724 L p 0 0 0 r
F P
0 g
s
.63084 .58028 m .63789 .57573 L p .64875 .56844 L .405 .811 .601 r
F P
0 g
s
.62028 .58822 m .63789 .57573 L p .63108 .58024 L .503 .877 .669 r
F P
0 g
s
.62588 .5835 m .62028 .58822 L p .61848 .58956 L .556 .892 .644 r
F P
0 g
s
.61705 .59036 m .62588 .5835 L .61802 .58993 L .556 .892 .644 r
F
.63666 .56669 m .63134 .57655 L .61071 .59507 L p 0 0 0 r
F P
0 g
s
.62028 .58822 m .62588 .5835 L .64478 .5695 L p 0 0 0 r
F P
0 g
s
.61456 .59119 m .62028 .58822 L p .63108 .58024 L .503 .877 .669 r
F P
0 g
s
.62028 .58822 m .61802 .58993 L p .61848 .58956 L .556 .892 .644 r
F P
0 g
s
.60225 .60185 m .60653 .59953 L p .61696 .59042 L .556 .892 .644 r
F P
0 g
s
.61802 .58993 m .60225 .60185 L p .61705 .59036 L .556 .892 .644 r
F P
0 g
s
.59658 .60135 m .59521 .60826 L p .59412 .60285 L .969 .918 .583 r
F P
0 g
s
.60653 .59953 m .60225 .60185 L .58925 .61206 L p .743 .985 .765 r
F P
0 g
s
.58925 .61206 m .58386 .6163 L p .59141 .61071 L .743 .985 .765 r
F P
0 g
s
.59141 .61071 m .60653 .59953 L .58925 .61206 L .743 .985 .765 r
F
.59405 .61078 m .58679 .61733 L p .59603 .60873 L .71 .952 .67 r
F P
0 g
s
.61478 .58744 m .61257 .59159 L p .60985 .59325 L .613 .863 .511 r
F P
0 g
s
.61257 .59159 m .61071 .59507 L p .60985 .59325 L .613 .863 .511 r
F P
0 g
s
.59782 .59507 m .59658 .60135 L p .59412 .60285 L .969 .918 .583 r
F P
0 g
s
.75949 .48547 m .77026 .47403 L .79121 .46313 L p .024 0 0 r
F P
0 g
s
.77026 .47403 m .75949 .48547 L .73854 .49483 L p .23 0 .035 r
F P
0 g
s
.72873 .50667 m .73854 .49483 L .75949 .48547 L p .147 0 0 r
F P
0 g
s
.73854 .49483 m .72873 .50667 L .70804 .51632 L p .228 0 .036 r
F P
0 g
s
.63666 .56669 m .6418 .5533 L .66446 .53819 L p .246 0 .12 r
F P
0 g
s
.6418 .5533 m .63666 .56669 L .61478 .58744 L p .114 0 .067 r
F P
0 g
s
.61478 .58744 m .61871 .5752 L .6418 .5533 L p .114 0 .067 r
F P
0 g
s
.65808 .55099 m .66446 .53819 L .68658 .52648 L p .257 0 .091 r
F P
0 g
s
.66446 .53819 m .65808 .55099 L .63666 .56669 L p .246 0 .12 r
F P
0 g
s
.81104 .45317 m .79121 .46313 L p .80814 .45386 L .316 0 .127 r
F P
0 g
s
.82396 .4452 m .81104 .45317 L p .80814 .45386 L .316 0 .127 r
F P
0 g
s
.81104 .45317 m .82396 .4452 L .84299 .4261 L p .724 .984 .788 r
F P
0 g
s
.81104 .45317 m .82946 .44069 L p .81415 .45244 L 0 0 0 r
F P
0 g
s
.79813 .46473 m .81104 .45317 L p .81415 .45244 L 0 0 0 r
F P
0 g
s
.77939 .47536 m .79121 .46313 L .81104 .45317 L p .018 0 0 r
F P
0 g
s
.79121 .46313 m .77939 .47536 L .75949 .48547 L p .024 0 0 r
F P
0 g
s
.67896 .53843 m .68658 .52648 L .70804 .51632 L p .22 0 .031 r
F P
0 g
s
.68658 .52648 m .67896 .53843 L .65808 .55099 L p .257 0 .091 r
F P
0 g
s
.57589 .7167 m .57423 .67343 L .54698 .74731 L p .869 .677 .639 r
F P
0 g
s
.57423 .67343 m .57272 .65848 L .54686 .71136 L p .924 .759 .658 r
F P
0 g
s
.54686 .71136 m .54698 .74731 L .57423 .67343 L p .924 .759 .658 r
F P
0 g
s
.54698 .74731 m .5471 .81044 L .57589 .7167 L p .869 .677 .639 r
F P
0 g
s
.74854 .49698 m .75949 .48547 L .77939 .47536 L p .028 0 0 r
F P
0 g
s
.75949 .48547 m .74854 .49698 L .72873 .50667 L p .147 0 0 r
F P
0 g
s
.69921 .52759 m .70804 .51632 L .72873 .50667 L p .152 0 0 r
F P
0 g
s
.70804 .51632 m .69921 .52759 L .67896 .53843 L p .22 0 .031 r
F P
0 g
s
.82946 .44069 m .84299 .4261 L .86141 .42047 L p .14 0 0 r
F P
0 g
s
.84299 .4261 m .82946 .44069 L .81104 .45317 L p .724 .984 .788 r
F P
0 g
s
.57272 .65848 m .57124 .65099 L .54675 .68946 L p .95 .832 .693 r
F P
0 g
s
.54675 .68946 m .54686 .71136 L .57272 .65848 L p .95 .832 .693 r
F P
0 g
s
.81104 .45317 m .79813 .46473 L .77939 .47536 L p .018 0 0 r
F P
0 g
s
.71871 .51751 m .72873 .50667 L .74854 .49698 L p .062 0 0 r
F P
0 g
s
.72873 .50667 m .71871 .51751 L .69921 .52759 L p .152 0 0 r
F P
0 g
s
.76734 .48691 m .77939 .47536 L .79813 .46473 L p 0 0 0 r
F P
0 g
s
.77939 .47536 m .76734 .48691 L .74854 .49698 L p .028 0 0 r
F P
0 g
s
.63134 .57655 m .63666 .56669 L .65808 .55099 L p .046 0 0 r
F P
0 g
s
.61071 .59507 m .61478 .58744 L .63666 .56669 L p 0 0 0 r
F P
0 g
s
.65152 .56137 m .65808 .55099 L .67896 .53843 L p .107 0 0 r
F P
0 g
s
.65808 .55099 m .65152 .56137 L .63134 .57655 L p .046 0 0 r
F P
0 g
s
.67116 .54867 m .67896 .53843 L .69921 .52759 L p .094 0 0 r
F P
0 g
s
.67896 .53843 m .67116 .54867 L .65152 .56137 L p .107 0 0 r
F P
0 g
s
.73737 .50759 m .74854 .49698 L .76734 .48691 L p 0 0 0 r
F P
0 g
s
.74854 .49698 m .73737 .50759 L .71871 .51751 L p .062 0 0 r
F P
0 g
s
.57124 .65099 m .56975 .64557 L .54664 .67443 L p .95 .889 .735 r
F P
0 g
s
.54664 .67443 m .54675 .68946 L .57124 .65099 L p .95 .889 .735 r
F P
0 g
s
.69018 .53752 m .69921 .52759 L .71871 .51751 L p .039 0 0 r
F P
0 g
s
.69921 .52759 m .69018 .53752 L .67116 .54867 L p .094 0 0 r
F P
0 g
s
.84652 .42907 m .86141 .42047 L .87727 .39994 L p .826 .995 .853 r
F P
0 g
s
.87727 .39994 m .8619 .41506 L .84652 .42907 L p .826 .995 .853 r
F P
0 g
s
.84652 .42907 m .8619 .41506 L p .84704 .42786 L .534 .871 .609 r
F P
0 g
s
.84652 .42907 m .82946 .44069 L p .84603 .43021 L .14 0 0 r
F P
0 g
s
.81558 .45321 m .82946 .44069 L .84652 .42907 L p 0 0 0 r
F P
0 g
s
.84652 .42907 m .83164 .44112 L .81558 .45321 L p 0 0 0 r
F P
0 g
s
.83164 .44112 m .84652 .42907 L p .84704 .42786 L .534 .871 .609 r
F P
0 g
s
.86141 .42047 m .84652 .42907 L p .84603 .43021 L .14 0 0 r
F P
0 g
s
.82946 .44069 m .81558 .45321 L .79813 .46473 L p 0 0 0 r
F P
0 g
s
.59248 .61447 m .58967 .61699 L .56825 .64065 L p .905 .982 .722 r
F P
0 g
s
.56825 .64065 m .56975 .64557 L .59248 .61447 L p .905 .982 .722 r
F P
0 g
s
.78502 .4763 m .79813 .46473 L .81558 .45321 L p 0 0 0 r
F P
0 g
s
.79813 .46473 m .78502 .4763 L .76734 .48691 L p 0 0 0 r
F P
0 g
s
.70848 .5272 m .71871 .51751 L .73737 .50759 L p 0 0 0 r
F P
0 g
s
.71871 .51751 m .70848 .5272 L .69018 .53752 L p .039 0 0 r
F P
0 g
s
.5471 .81044 m .54698 .74731 L .51921 .76245 L p .531 .493 .759 r
F P
0 g
s
.54698 .74731 m .54686 .71136 L .52058 .73682 L p .794 .694 .755 r
F P
0 g
s
.52058 .73682 m .51921 .76245 L .54698 .74731 L p .794 .694 .755 r
F P
0 g
s
.51921 .76245 m .51788 .78352 L .5471 .81044 L p .531 .493 .759 r
F P
0 g
s
.51788 .78352 m .51921 .76245 L .49146 .77051 L p .793 .696 .757 r
F P
0 g
s
.49146 .77051 m .48862 .7964 L .51788 .78352 L p .793 .696 .757 r
F P
0 g
s
.75505 .49749 m .76734 .48691 L .78502 .4763 L p 0 0 0 r
F P
0 g
s
.76734 .48691 m .75505 .49749 L .73737 .50759 L p 0 0 0 r
F P
0 g
s
.54686 .71136 m .54675 .68946 L .52193 .71445 L p .865 .775 .761 r
F P
0 g
s
.52193 .71445 m .52058 .73682 L .54686 .71136 L p .865 .775 .761 r
F P
0 g
s
.64478 .5695 m .65152 .56137 L .67116 .54867 L p 0 0 0 r
F P
0 g
s
.65152 .56137 m .64478 .5695 L .62588 .5835 L p 0 0 0 r
F P
0 g
s
.62588 .5835 m .63134 .57655 L .65152 .56137 L p 0 0 0 r
F P
0 g
s
.56975 .64557 m .56825 .64065 L .54653 .66285 L p .932 .928 .779 r
F P
0 g
s
.54653 .66285 m .54664 .67443 L .56975 .64557 L p .932 .928 .779 r
F P
0 g
s
.66316 .55724 m .67116 .54867 L .69018 .53752 L p 0 0 0 r
F P
0 g
s
.67116 .54867 m .66316 .55724 L .64478 .5695 L p 0 0 0 r
F P
0 g
s
.51921 .76245 m .52058 .73682 L .49426 .74858 L p .777 .705 .784 r
F P
0 g
s
.49426 .74858 m .49146 .77051 L .51921 .76245 L p .777 .705 .784 r
F P
0 g
s
.72596 .51716 m .73737 .50759 L .75505 .49749 L p 0 0 0 r
F P
0 g
s
.73737 .50759 m .72596 .51716 L .70848 .5272 L p 0 0 0 r
F P
0 g
s
.54675 .68946 m .54664 .67443 L .52328 .69611 L p .89 .831 .782 r
F P
0 g
s
.52328 .69611 m .52193 .71445 L .54675 .68946 L p .89 .831 .782 r
F P
0 g
s
.46394 .77068 m .45983 .78506 L .48862 .7964 L p .629 .635 .837 r
F P
0 g
s
.45983 .78506 m .46394 .77068 L .43674 .77046 L p .769 .742 .828 r
F P
0 g
s
.43674 .77046 m .43116 .78795 L .45983 .78506 L p .769 .742 .828 r
F P
0 g
s
.48862 .7964 m .49146 .77051 L .46394 .77068 L p .629 .635 .837 r
F P
0 g
s
.80147 .46507 m .81558 .45321 L .83164 .44112 L p 0 0 0 r
F P
0 g
s
.81558 .45321 m .80147 .46507 L .78502 .4763 L p 0 0 0 r
F P
0 g
s
.8619 .41506 m .87727 .39994 L .89236 .39267 L p 0 0 0 r
F P
0 g
s
.68095 .5462 m .69018 .53752 L .70848 .5272 L p 0 0 0 r
F P
0 g
s
.69018 .53752 m .68095 .5462 L .66316 .55724 L p 0 0 0 r
F P
0 g
s
.77166 .487 m .78502 .4763 L .80147 .46507 L p 0 0 0 r
F P
0 g
s
.78502 .4763 m .77166 .487 L .75505 .49749 L p 0 0 0 r
F P
0 g
s
.52058 .73682 m .52193 .71445 L .49707 .72844 L p .807 .749 .798 r
F P
0 g
s
.49707 .72844 m .49426 .74858 L .52058 .73682 L p .807 .749 .798 r
F P
0 g
s
.58967 .61699 m .58679 .61733 L .56673 .63577 L p .877 .993 .783 r
F P
0 g
s
.56673 .63577 m .56825 .64065 L .58967 .61699 L p .877 .993 .783 r
F P
0 g
s
.49146 .77051 m .49426 .74858 L .46813 .75319 L p .735 .707 .824 r
F P
0 g
s
.46813 .75319 m .46394 .77068 L .49146 .77051 L p .735 .707 .824 r
F P
0 g
s
.43116 .78795 m .43674 .77046 L .41005 .76707 L p .669 .698 .868 r
F P
0 g
s
.41005 .76707 m .40321 .77952 L .43116 .78795 L p .669 .698 .868 r
F P
0 g
s
.69804 .53588 m .70848 .5272 L .72596 .51716 L p 0 0 0 r
F P
0 g
s
.70848 .5272 m .69804 .53588 L .68095 .5462 L p 0 0 0 r
F P
0 g
s
.74253 .50708 m .75505 .49749 L .77166 .487 L p 0 0 0 r
F P
0 g
s
.75505 .49749 m .74253 .50708 L .72596 .51716 L p 0 0 0 r
F P
0 g
s
.46394 .77068 m .46813 .75319 L .44233 .7543 L p .743 .731 .841 r
F P
0 g
s
.44233 .7543 m .43674 .77046 L .46394 .77068 L p .743 .731 .841 r
F P
0 g
s
.54664 .67443 m .54653 .66285 L .52462 .68088 L p .893 .871 .808 r
F P
0 g
s
.52462 .68088 m .52328 .69611 L .54664 .67443 L p .893 .871 .808 r
F P
0 g
s
.52193 .71445 m .52328 .69611 L .49987 .7102 L p .834 .793 .813 r
F P
0 g
s
.49987 .7102 m .49707 .72844 L .52193 .71445 L p .834 .793 .813 r
F P
0 g
s
.49426 .74858 m .49707 .72844 L .47236 .73549 L p .771 .743 .827 r
F P
0 g
s
.47236 .73549 m .46813 .75319 L .49426 .74858 L p .771 .743 .827 r
F P
0 g
s
.56825 .64065 m .56673 .63577 L .54642 .65313 L p .906 .949 .819 r
F P
0 g
s
.54642 .65313 m .54653 .66285 L .56825 .64065 L p .906 .949 .819 r
F P
0 g
s
.40321 .77952 m .41005 .76707 L .38392 .76343 L p .744 .765 .87 r
F P
0 g
s
.38392 .76343 m .37567 .77733 L .40321 .77952 L p .744 .765 .87 r
F P
0 g
s
.8619 .41506 m .84618 .42818 L .83164 .44112 L p .534 .871 .609 r
F P
0 g
s
.83164 .44112 m .81657 .45321 L .80147 .46507 L p 0 0 0 r
F P
0 g
s
.81657 .45321 m .83164 .44112 L .84618 .42818 L p .521 .864 .604 r
F P
0 g
s
.43674 .77046 m .44233 .7543 L .41699 .7529 L p .722 .734 .861 r
F P
0 g
s
.41699 .7529 m .41005 .76707 L .43674 .77046 L p .722 .734 .861 r
F P
0 g
s
.80147 .46507 m .7871 .47601 L .77166 .487 L p 0 0 0 r
F P
0 g
s
.7871 .47601 m .80147 .46507 L .81657 .45321 L p .452 .825 .578 r
F P
0 g
s
.71435 .52589 m .72596 .51716 L .74253 .50708 L p 0 0 0 r
F P
0 g
s
.72596 .51716 m .71435 .52589 L .69804 .53588 L p 0 0 0 r
F P
0 g
s
.89236 .39267 m .8757 .40199 L .8619 .41506 L p 0 0 0 r
F P
0 g
s
.84618 .42818 m .8619 .41506 L .8757 .40199 L p .543 .874 .606 r
F P
0 g
s
.58386 .6163 m .58679 .61733 L .60653 .59953 L p .743 .985 .765 r
F P
0 g
s
.65499 .56431 m .66316 .55724 L .68095 .5462 L p 0 0 0 r
F P
0 g
s
.46813 .75319 m .47236 .73549 L .44796 .73829 L p .754 .747 .846 r
F P
0 g
s
.44796 .73829 m .44233 .7543 L .46813 .75319 L p .754 .747 .846 r
F P
0 g
s
.49707 .72844 m .49987 .7102 L .47661 .7184 L p .794 .775 .835 r
F P
0 g
s
.47661 .7184 m .47236 .73549 L .49707 .72844 L p .794 .775 .835 r
F P
0 g
s
.75806 .49673 m .77166 .487 L .7871 .47601 L p 0 0 0 r
F P
0 g
s
.77166 .487 m .75806 .49673 L .74253 .50708 L p 0 0 0 r
F P
0 g
s
.52328 .69611 m .52462 .68088 L .50269 .69384 L p .847 .83 .83 r
F P
0 g
s
.50269 .69384 m .49987 .7102 L .52328 .69611 L p .847 .83 .83 r
F P
0 g
s
.67152 .55374 m .68095 .5462 L .69804 .53588 L p 0 0 0 r
F P
0 g
s
.68095 .5462 m .67152 .55374 L .65499 .56431 L p 0 0 0 r
F P
0 g
s
.58679 .61733 m .58386 .6163 L .56518 .63085 L p .848 .996 .83 r
F P
0 g
s
.56518 .63085 m .56673 .63577 L .58679 .61733 L p .848 .996 .83 r
F P
0 g
s
.54653 .66285 m .54642 .65313 L .52597 .66785 L p .883 .899 .836 r
F P
0 g
s
.52597 .66785 m .52462 .68088 L .54653 .66285 L p .883 .899 .836 r
F P
0 g
s
.37567 .77733 m .38392 .76343 L .35854 .75799 L p .693 .737 .885 r
F P
0 g
s
.35854 .75799 m .34903 .76945 L .37567 .77733 L p .693 .737 .885 r
F P
0 g
s
.41005 .76707 m .41699 .7529 L .39223 .74996 L p .728 .753 .872 r
F P
0 g
s
.39223 .74996 m .38392 .76343 L .41005 .76707 L p .728 .753 .872 r
F P
0 g
s
.8757 .40199 m .89236 .39267 L .90453 .37055 L p .863 .954 .868 r
F P
0 g
s
.44233 .7543 m .44796 .73829 L .424 .73831 L p .739 .752 .862 r
F P
0 g
s
.424 .73831 m .41699 .7529 L .44233 .7543 L p .739 .752 .862 r
F P
0 g
s
.72978 .51591 m .74253 .50708 L .75806 .49673 L p 0 0 0 r
F P
0 g
s
.74253 .50708 m .72978 .51591 L .71435 .52589 L p 0 0 0 r
F P
0 g
s
.47236 .73549 m .47661 .7184 L .45363 .72248 L p .769 .769 .853 r
F P
0 g
s
.45363 .72248 m .44796 .73829 L .47236 .73549 L p .769 .769 .853 r
F P
0 g
s
.6874 .54371 m .69804 .53588 L .71435 .52589 L p 0 0 0 r
F P
0 g
s
.69804 .53588 m .6874 .54371 L .67152 .55374 L p 0 0 0 r
F P
0 g
s
.56673 .63577 m .56518 .63085 L .5463 .64452 L p .875 .961 .853 r
F P
0 g
s
.5463 .64452 m .54642 .65313 L .56673 .63577 L p .875 .961 .853 r
F P
0 g
s
.49987 .7102 m .50269 .69384 L .48088 .70223 L p .809 .804 .847 r
F P
0 g
s
.48088 .70223 m .47661 .7184 L .49987 .7102 L p .809 .804 .847 r
F P
0 g
s
.84618 .42818 m .83022 .44073 L .81657 .45321 L p .521 .864 .604 r
F P
0 g
s
.80125 .46448 m .81657 .45321 L .83022 .44073 L p .577 .909 .674 r
F P
0 g
s
.81657 .45321 m .80125 .46448 L .7871 .47601 L p .452 .825 .578 r
F P
0 g
s
.52462 .68088 m .52597 .66785 L .50551 .67916 L p .848 .858 .85 r
F P
0 g
s
.50551 .67916 m .50269 .69384 L .52462 .68088 L p .848 .858 .85 r
F P
0 g
s
.8757 .40199 m .85911 .41478 L .84618 .42818 L p .543 .874 .606 r
F P
0 g
s
.83022 .44073 m .84618 .42818 L .85911 .41478 L p .628 .931 .685 r
F P
0 g
s
.38392 .76343 m .39223 .74996 L .36816 .74568 L p .717 .757 .884 r
F P
0 g
s
.36816 .74568 m .35854 .75799 L .38392 .76343 L p .717 .757 .884 r
F P
0 g
s
.34903 .76945 m .35854 .75799 L .33399 .75205 L p .72 .776 .896 r
F P
0 g
s
.33399 .75205 m .32315 .76355 L .34903 .76945 L p .72 .776 .896 r
F P
0 g
s
.77248 .486 m .7871 .47601 L .80125 .46448 L p .529 .888 .667 r
F P
0 g
s
.7871 .47601 m .77248 .486 L .75806 .49673 L p 0 0 0 r
F P
0 g
s
.41699 .7529 m .424 .73831 L .4006 .73642 L p .733 .76 .875 r
F P
0 g
s
.4006 .73642 m .39223 .74996 L .41699 .7529 L p .733 .76 .875 r
F P
0 g
s
.62028 .58822 m .61456 .59119 L .59788 .60262 L p .632 .951 .756 r
F P
0 g
s
.59788 .60262 m .60225 .60185 L .62028 .58822 L p .632 .951 .756 r
F P
0 g
s
.70252 .53394 m .71435 .52589 L .72978 .51591 L p 0 0 0 r
F P
0 g
s
.71435 .52589 m .70252 .53394 L .6874 .54371 L p 0 0 0 r
F P
0 g
s
.44796 .73829 m .45363 .72248 L .43107 .72366 L p .752 .768 .867 r
F P
0 g
s
.43107 .72366 m .424 .73831 L .44796 .73829 L p .752 .768 .867 r
F P
0 g
s
.63789 .57573 m .63084 .58028 L .61456 .59119 L p .503 .877 .669 r
F P
0 g
s
.54642 .65313 m .5463 .64452 L .52732 .65641 L p .865 .918 .863 r
F P
0 g
s
.52732 .65641 m .52597 .66785 L .54642 .65313 L p .865 .918 .863 r
F P
0 g
s
.90453 .37055 m .88758 .38663 L p .87702 .40055 L .863 .954 .868 r
F P
0 g
s
.88758 .38663 m .90453 .37055 L .91581 .36235 L p 0 0 0 r
F P
0 g
s
.91581 .36235 m .89887 .37176 L p .88758 .38663 L 0 0 0 r
F P
0 g
s
.89887 .37176 m .89767 .37243 L .88758 .38663 L p 0 0 0 r
F P
0 g
s
.88758 .38663 m .8757 .40199 L p .87702 .40055 L .863 .954 .868 r
F P
0 g
s
.85911 .41478 m .8757 .40199 L .88758 .38663 L p .744 .986 .768 r
F P
0 g
s
.60225 .60185 m .59788 .60262 L .58088 .61433 L p .749 .994 .828 r
F P
0 g
s
.58088 .61433 m .58386 .6163 L .60225 .60185 L p .749 .994 .828 r
F P
0 g
s
.74423 .50576 m .75806 .49673 L .77248 .486 L p .485 .864 .653 r
F P
0 g
s
.75806 .49673 m .74423 .50576 L .72978 .51591 L p 0 0 0 r
F P
0 g
s
.47661 .7184 m .48088 .70223 L .45934 .70701 L p .782 .791 .86 r
F P
0 g
s
.45934 .70701 m .45363 .72248 L .47661 .7184 L p .782 .791 .86 r
F P
0 g
s
.64665 .56996 m .65499 .56431 L .67152 .55374 L p 0 0 0 r
F P
0 g
s
.67152 .55374 m .66192 .56012 L .64665 .56996 L p 0 0 0 r
F P
0 g
s
.64665 .56996 m .66192 .56012 L p .66029 .56108 L .487 .879 .706 r
F P
0 g
s
.65499 .56431 m .64665 .56996 L p .63389 .57827 L .405 .811 .601 r
F P
0 g
s
.63815 .57409 m .64665 .56996 L p .66029 .56108 L .487 .879 .706 r
F P
0 g
s
.64665 .56996 m .63084 .58028 L p .63389 .57827 L .405 .811 .601 r
F P
0 g
s
.50269 .69384 m .50551 .67916 L .48517 .68709 L p .816 .83 .86 r
F P
0 g
s
.48517 .68709 m .48088 .70223 L .50269 .69384 L p .816 .83 .86 r
F P
0 g
s
.58386 .6163 m .58088 .61433 L .56362 .62587 L p .818 .993 .867 r
F P
0 g
s
.56362 .62587 m .56518 .63085 L .58386 .6163 L p .818 .993 .867 r
F P
0 g
s
.66192 .56012 m .67152 .55374 L .6874 .54371 L p 0 0 0 r
F P
0 g
s
.39223 .74996 m .4006 .73642 L .37787 .73309 L p .726 .768 .886 r
F P
0 g
s
.37787 .73309 m .36816 .74568 L .39223 .74996 L p .726 .768 .886 r
F P
0 g
s
.35854 .75799 m .36816 .74568 L .34491 .74041 L p .719 .772 .894 r
F P
0 g
s
.34491 .74041 m .33399 .75205 L .35854 .75799 L p .719 .772 .894 r
F P
0 g
s
.424 .73831 m .43107 .72366 L .40904 .72277 L p .741 .772 .878 r
F P
0 g
s
.40904 .72277 m .4006 .73642 L .424 .73831 L p .741 .772 .878 r
F P
0 g
s
.52597 .66785 m .52732 .65641 L .50835 .66596 L p .841 .88 .87 r
F P
0 g
s
.50835 .66596 m .50551 .67916 L .52597 .66785 L p .841 .88 .87 r
F P
0 g
s
.71682 .52421 m .72978 .51591 L .74423 .50576 L p .451 .844 .637 r
F P
0 g
s
.72978 .51591 m .71682 .52421 L .70252 .53394 L p 0 0 0 r
F P
0 g
s
.56518 .63085 m .56362 .62587 L .54619 .63666 L p .843 .965 .882 r
F P
0 g
s
.54619 .63666 m .5463 .64452 L .56518 .63085 L p .843 .965 .882 r
F P
0 g
s
.32315 .76355 m .33399 .75205 L .31042 .74496 L p .707 .77 .902 r
F P
0 g
s
.31042 .74496 m .29833 .75549 L .32315 .76355 L p .707 .77 .902 r
F P
0 g
s
.45363 .72248 m .45934 .70701 L .43819 .70905 L p .763 .785 .872 r
F P
0 g
s
.43819 .70905 m .43107 .72366 L .45363 .72248 L p .763 .785 .872 r
F P
0 g
s
.83022 .44073 m .81401 .45242 L .80125 .46448 L p .577 .909 .674 r
F P
0 g
s
.78567 .47483 m .80125 .46448 L .81401 .45242 L p .632 .948 .742 r
F P
0 g
s
.80125 .46448 m .78567 .47483 L .77248 .486 L p .529 .888 .667 r
F P
0 g
s
.85911 .41478 m .84232 .4277 L .83022 .44073 L p .628 .931 .685 r
F P
0 g
s
.81401 .45242 m .83022 .44073 L .84232 .4277 L p .676 .963 .746 r
F P
0 g
s
.67656 .55062 m .6874 .54371 L .70252 .53394 L p .389 .803 .601 r
F P
0 g
s
.6874 .54371 m .67656 .55062 L .66192 .56012 L p 0 0 0 r
F P
0 g
s
.48088 .70223 m .48517 .68709 L .46509 .69205 L p .79 .812 .869 r
F P
0 g
s
.46509 .69205 m .45934 .70701 L .48088 .70223 L p .79 .812 .869 r
F P
0 g
s
.75763 .49533 m .77248 .486 L .78567 .47483 L p .588 .928 .729 r
F P
0 g
s
.77248 .486 m .75763 .49533 L .74423 .50576 L p .485 .864 .653 r
F P
0 g
s
.88758 .38663 m .87029 .40065 L .85911 .41478 L p .744 .986 .768 r
F P
0 g
s
.84232 .4277 m .85911 .41478 L .87029 .40065 L p .73 .981 .761 r
F P
0 g
s
.5463 .64452 m .54619 .63666 L .52869 .64617 L p .841 .93 .888 r
F P
0 g
s
.52869 .64617 m .52732 .65641 L .5463 .64452 L p .841 .93 .888 r
F P
0 g
s
.50551 .67916 m .50835 .66596 L .48949 .67304 L p .815 .851 .876 r
F P
0 g
s
.48949 .67304 m .48517 .68709 L .50551 .67916 L p .815 .851 .876 r
F P
0 g
s
.4006 .73642 m .40904 .72277 L .38765 .72035 L p .733 .778 .889 r
F P
0 g
s
.38765 .72035 m .37787 .73309 L .4006 .73642 L p .733 .778 .889 r
F P
0 g
s
.36816 .74568 m .37787 .73309 L .35592 .72864 L p .722 .777 .896 r
F P
0 g
s
.35592 .72864 m .34491 .74041 L .36816 .74568 L p .722 .777 .896 r
F P
0 g
s
.43107 .72366 m .43819 .70905 L .41755 .70902 L p .75 .785 .882 r
F P
0 g
s
.41755 .70902 m .40904 .72277 L .43107 .72366 L p .75 .785 .882 r
F P
0 g
s
.69049 .54128 m .70252 .53394 L .71682 .52421 L p .45 .847 .648 r
F P
0 g
s
.70252 .53394 m .69049 .54128 L .67656 .55062 L p .389 .803 .601 r
F P
0 g
s
.73019 .51436 m .74423 .50576 L .75763 .49533 L p .545 .906 .708 r
F P
0 g
s
.74423 .50576 m .73019 .51436 L .71682 .52421 L p .451 .844 .637 r
F P
0 g
s
.60873 .59258 m .61456 .59119 L .63084 .58028 L p .595 .942 .783 r
F P
0 g
s
.61456 .59119 m .60873 .59258 L .59344 .60208 L p .676 .977 .834 r
F P
0 g
s
.59344 .60208 m .59788 .60262 L .61456 .59119 L p .676 .977 .834 r
F P
0 g
s
.33399 .75205 m .34491 .74041 L .3226 .7342 L p .713 .778 .903 r
F P
0 g
s
.3226 .7342 m .31042 .74496 L .33399 .75205 L p .713 .778 .903 r
F P
0 g
s
.87029 .40065 m .88758 .38663 L .89767 .37243 L p .746 .984 .76 r
F P
0 g
s
.62366 .58322 m .63084 .58028 L .64665 .56996 L p .527 .904 .735 r
F P
0 g
s
.63084 .58028 m .62366 .58322 L .60873 .59258 L p .595 .942 .783 r
F P
0 g
s
.59788 .60262 m .59344 .60208 L .57784 .61155 L p .746 .992 .874 r
F P
0 g
s
.57784 .61155 m .58088 .61433 L .59788 .60262 L p .746 .992 .874 r
F P
0 g
s
.45934 .70701 m .46509 .69205 L .44537 .6946 L p .771 .802 .878 r
F P
0 g
s
.44537 .6946 m .43819 .70905 L .45934 .70701 L p .771 .802 .878 r
F P
0 g
s
.52732 .65641 m .52869 .64617 L .5112 .65403 L p .827 .897 .891 r
F P
0 g
s
.5112 .65403 m .50835 .66596 L .52732 .65641 L p .827 .897 .891 r
F P
0 g
s
.64665 .56996 m .63815 .57409 L .62366 .58322 L p .527 .904 .735 r
F P
0 g
s
.58088 .61433 m .57784 .61155 L .56203 .62071 L p .792 .985 .897 r
F P
0 g
s
.56203 .62071 m .56362 .62587 L .58088 .61433 L p .792 .985 .897 r
F P
0 g
s
.29833 .75549 m .31042 .74496 L .28794 .73711 L p .695 .777 .915 r
F P
0 g
s
.28794 .73711 m .27466 .74643 L .29833 .75549 L p .695 .777 .915 r
F P
0 g
s
.48517 .68709 m .48949 .67304 L .47088 .67779 L p .793 .831 .881 r
F P
0 g
s
.47088 .67779 m .46509 .69205 L .48517 .68709 L p .793 .831 .881 r
F P
0 g
s
.65212 .56516 m .66192 .56012 L .67656 .55062 L p .479 .874 .699 r
F P
0 g
s
.66192 .56012 m .65212 .56516 L .63815 .57409 L p .487 .879 .706 r
F P
0 g
s
.56362 .62587 m .56203 .62071 L .54608 .62922 L p .812 .963 .906 r
F P
0 g
s
.54608 .62922 m .54619 .63666 L .56362 .62587 L p .812 .963 .906 r
F P
0 g
s
.84232 .4277 m .82529 .4399 L .81401 .45242 L p .676 .963 .746 r
F P
0 g
s
.79755 .46323 m .81401 .45242 L .82529 .4399 L p .713 .983 .796 r
F P
0 g
s
.81401 .45242 m .79755 .46323 L .78567 .47483 L p .632 .948 .742 r
F P
0 g
s
.70364 .53196 m .71682 .52421 L .73019 .51436 L p .523 .895 .703 r
F P
0 g
s
.71682 .52421 m .70364 .53196 L .69049 .54128 L p .45 .847 .648 r
F P
0 g
s
.76986 .48455 m .78567 .47483 L .79755 .46323 L p .673 .97 .787 r
F P
0 g
s
.78567 .47483 m .76986 .48455 L .75763 .49533 L p .588 .928 .729 r
F P
0 g
s
.37787 .73309 m .38765 .72035 L .36702 .71672 L p .728 .785 .898 r
F P
0 g
s
.36702 .71672 m .35592 .72864 L .37787 .73309 L p .728 .785 .898 r
F P
0 g
s
.40904 .72277 m .41755 .70902 L .39752 .70742 L p .741 .789 .891 r
F P
0 g
s
.39752 .70742 m .38765 .72035 L .40904 .72277 L p .741 .789 .891 r
F P
0 g
s
.87029 .40065 m .85277 .41418 L .84232 .4277 L p .73 .981 .761 r
F P
0 g
s
.82529 .4399 m .84232 .4277 L .85277 .41418 L p .752 .992 .797 r
F P
0 g
s
.50835 .66596 m .5112 .65403 L .49384 .66009 L p .808 .869 .892 r
F P
0 g
s
.49384 .66009 m .48949 .67304 L .50835 .66596 L p .808 .869 .892 r
F P
0 g
s
.43819 .70905 m .44537 .6946 L .42613 .69522 L p .758 .799 .886 r
F P
0 g
s
.42613 .69522 m .41755 .70902 L .43819 .70905 L p .758 .799 .886 r
F P
0 g
s
.34491 .74041 m .35592 .72864 L .33487 .72324 L p .718 .785 .905 r
F P
0 g
s
.33487 .72324 m .3226 .7342 L .34491 .74041 L p .718 .785 .905 r
F P
0 g
s
.74256 .50429 m .75763 .49533 L .76986 .48455 L p .631 .953 .768 r
F P
0 g
s
.75763 .49533 m .74256 .50429 L .73019 .51436 L p .545 .906 .708 r
F P
0 g
s
.54619 .63666 m .54608 .62922 L .53007 .63677 L p .815 .935 .909 r
F P
0 g
s
.53007 .63677 m .52869 .64617 L .54619 .63666 L p .815 .935 .909 r
F P
0 g
s
.66551 .55638 m .67656 .55062 L .69049 .54128 L p .501 .887 .712 r
F P
0 g
s
.67656 .55062 m .66551 .55638 L .65212 .56516 L p .479 .874 .699 r
F P
0 g
s
.89767 .37243 m .91581 .36235 L .92378 .33838 L p .861 .892 .857 r
F P
0 g
s
.46509 .69205 m .47088 .67779 L .4526 .68052 L p .776 .819 .886 r
F P
0 g
s
.4526 .68052 m .44537 .6946 L .46509 .69205 L p .776 .819 .886 r
F P
0 g
s
.31042 .74496 m .3226 .7342 L .30134 .72718 L p .708 .787 .913 r
F P
0 g
s
.30134 .72718 m .28794 .73711 L .31042 .74496 L p .708 .787 .913 r
F P
0 g
s
.89767 .37243 m .87965 .38623 L .87029 .40065 L p .746 .984 .76 r
F P
0 g
s
.85277 .41418 m .87029 .40065 L .87965 .38623 L p .789 .997 .8 r
F P
0 g
s
.48949 .67304 m .49384 .66009 L .4767 .66437 L p .791 .849 .895 r
F P
0 g
s
.4767 .66437 m .47088 .67779 L .48949 .67304 L p .791 .849 .895 r
F P
0 g
s
.71593 .52253 m .73019 .51436 L .74256 .50429 L p .599 .938 .756 r
F P
0 g
s
.73019 .51436 m .71593 .52253 L .70364 .53196 L p .523 .895 .703 r
F P
0 g
s
.52869 .64617 m .53007 .63677 L .51408 .64312 L p .807 .907 .91 r
F P
0 g
s
.51408 .64312 m .5112 .65403 L .52869 .64617 L p .807 .907 .91 r
F P
0 g
s
.67825 .54765 m .69049 .54128 L .70364 .53196 L p .543 .912 .74 r
F P
0 g
s
.69049 .54128 m .67825 .54765 L .66551 .55638 L p .501 .887 .712 r
F P
0 g
s
.38765 .72035 m .39752 .70742 L .37821 .70458 L p .734 .794 .9 r
F P
0 g
s
.37821 .70458 m .36702 .71672 L .38765 .72035 L p .734 .794 .9 r
F P
0 g
s
.41755 .70902 m .42613 .69522 L .40747 .69432 L p .748 .799 .894 r
F P
0 g
s
.40747 .69432 m .39752 .70742 L .41755 .70902 L p .748 .799 .894 r
F P
0 g
s
.60279 .59244 m .60873 .59258 L .62366 .58322 L p .66 .973 .865 r
F P
0 g
s
.60873 .59258 m .60279 .59244 L .58891 .60028 L p .705 .982 .891 r
F P
0 g
s
.58891 .60028 m .59344 .60208 L .60873 .59258 L p .705 .982 .891 r
F P
0 g
s
.27466 .74643 m .28794 .73711 L .26668 .72856 L p .712 .801 .921 r
F P
0 g
s
.26668 .72856 m .25218 .73802 L .27466 .74643 L p .712 .801 .921 r
F P
0 g
s
.35592 .72864 m .36702 .71672 L .34725 .71211 L p .723 .793 .907 r
F P
0 g
s
.34725 .71211 m .33487 .72324 L .35592 .72864 L p .723 .793 .907 r
F P
0 g
s
.59344 .60208 m .58891 .60028 L .57476 .60792 L p .744 .982 .91 r
F P
0 g
s
.57476 .60792 m .57784 .61155 L .59344 .60208 L p .744 .982 .91 r
F P
0 g
s
.61633 .58451 m .62366 .58322 L .63815 .57409 L p .62 .958 .839 r
F P
0 g
s
.62366 .58322 m .61633 .58451 L .60279 .59244 L p .66 .973 .865 r
F P
0 g
s
.44537 .6946 m .4526 .68052 L .43478 .68155 L p .764 .813 .892 r
F P
0 g
s
.43478 .68155 m .42613 .69522 L .44537 .6946 L p .764 .813 .892 r
F P
0 g
s
.57784 .61155 m .57476 .60792 L .56042 .61519 L p .771 .972 .921 r
F P
0 g
s
.56042 .61519 m .56203 .62071 L .57784 .61155 L p .771 .972 .921 r
F P
0 g
s
.82529 .4399 m .80802 .45124 L .79755 .46323 L p .713 .983 .796 r
F P
0 g
s
.78086 .47343 m .79755 .46323 L .80802 .45124 L p .738 .992 .828 r
F P
0 g
s
.79755 .46323 m .78086 .47343 L .76986 .48455 L p .673 .97 .787 r
F P
0 g
s
.92378 .33838 m .9056 .35599 L .89767 .37243 L p .861 .892 .857 r
F P
0 g
s
.87965 .38623 m .89767 .37243 L .9056 .35599 L p .846 .995 .837 r
F P
0 g
s
.62947 .57657 m .63815 .57409 L .65212 .56516 L p .595 .947 .819 r
F P
0 g
s
.63815 .57409 m .62947 .57657 L .61633 .58451 L p .62 .958 .839 r
F P
0 g
s
.5112 .65403 m .51408 .64312 L .49822 .64815 L p .796 .883 .909 r
F P
0 g
s
.49822 .64815 m .49384 .66009 L .5112 .65403 L p .796 .883 .909 r
F P
0 g
s
.75384 .49395 m .76986 .48455 L .78086 .47343 L p .702 .982 .814 r
F P
0 g
s
.76986 .48455 m .75384 .49395 L .74256 .50429 L p .631 .953 .768 r
F P
0 g
s
.85277 .41418 m .83501 .42697 L .82529 .4399 L p .752 .992 .797 r
F P
0 g
s
.80802 .45124 m .82529 .4399 L .83501 .42697 L p .772 .997 .831 r
F P
0 g
s
.3226 .7342 m .33487 .72324 L .31484 .71701 L p .713 .793 .914 r
F P
0 g
s
.31484 .71701 m .30134 .72718 L .3226 .7342 L p .713 .793 .914 r
F P
0 g
s
.47088 .67779 m .4767 .66437 L .45989 .66702 L p .777 .835 .897 r
F P
0 g
s
.45989 .66702 m .4526 .68052 L .47088 .67779 L p .777 .835 .897 r
F P
0 g
s
.56203 .62071 m .56042 .61519 L .54596 .62189 L p .786 .954 .925 r
F P
0 g
s
.54596 .62189 m .54608 .62922 L .56203 .62071 L p .786 .954 .925 r
F P
0 g
s
.69025 .53888 m .70364 .53196 L .71593 .52253 L p .596 .941 .773 r
F P
0 g
s
.70364 .53196 m .69025 .53888 L .67825 .54765 L p .543 .912 .74 r
F P
0 g
s
.64214 .56864 m .65212 .56516 L .66551 .55638 L p .589 .944 .811 r
F P
0 g
s
.65212 .56516 m .64214 .56864 L .62947 .57657 L p .595 .947 .819 r
F P
0 g
s
.87965 .38623 m .86146 .40029 L .85277 .41418 L p .789 .997 .8 r
F P
0 g
s
.83501 .42697 m .85277 .41418 L .86146 .40029 L p .803 1 .828 r
F P
0 g
s
.72728 .51292 m .74256 .50429 L .75384 .49395 L p .668 .971 .8 r
F P
0 g
s
.74256 .50429 m .72728 .51292 L .71593 .52253 L p .599 .938 .756 r
F P
0 g
s
.54608 .62922 m .54596 .62189 L .53146 .62784 L p .79 .932 .926 r
F P
0 g
s
.53146 .62784 m .53007 .63677 L .54608 .62922 L p .79 .932 .926 r
F P
0 g
s
.39752 .70742 m .40747 .69432 L .38949 .69219 L p .741 .803 .901 r
F P
0 g
s
.38949 .69219 m .37821 .70458 L .39752 .70742 L p .741 .803 .901 r
F P
0 g
s
.28794 .73711 m .30134 .72718 L .28126 .71938 L p .704 .795 .922 r
F P
0 g
s
.28126 .71938 m .26668 .72856 L .28794 .73711 L p .704 .795 .922 r
F P
0 g
s
.49384 .66009 m .49822 .64815 L .48258 .65183 L p .783 .864 .909 r
F P
0 g
s
.48258 .65183 m .4767 .66437 L .49384 .66009 L p .783 .864 .909 r
F P
0 g
s
.42613 .69522 m .43478 .68155 L .4175 .68118 L p .754 .811 .898 r
F P
0 g
s
.4175 .68118 m .40747 .69432 L .42613 .69522 L p .754 .811 .898 r
F P
0 g
s
.36702 .71672 m .37821 .70458 L .35972 .70072 L p .729 .8 .908 r
F P
0 g
s
.35972 .70072 m .34725 .71211 L .36702 .71672 L p .729 .8 .908 r
F P
0 g
s
.9056 .35599 m .92378 .33838 L .93085 .33033 L p .554 .861 .558 r
F P
0 g
s
.65427 .56069 m .66551 .55638 L .67825 .54765 L p .602 .949 .814 r
F P
0 g
s
.66551 .55638 m .65427 .56069 L .64214 .56864 L p .589 .944 .811 r
F P
0 g
s
.4526 .68052 m .45989 .66702 L .44349 .66824 L p .765 .827 .9 r
F P
0 g
s
.44349 .66824 m .43478 .68155 L .4526 .68052 L p .765 .827 .9 r
F P
0 g
s
.53007 .63677 m .53146 .62784 L .51699 .6329 L p .787 .91 .925 r
F P
0 g
s
.51699 .6329 m .51408 .64312 L .53007 .63677 L p .787 .91 .925 r
F P
0 g
s
.33487 .72324 m .34725 .71211 L .32845 .70664 L p .718 .8 .916 r
F P
0 g
s
.32845 .70664 m .31484 .71701 L .33487 .72324 L p .718 .8 .916 r
F P
0 g
s
.9056 .35599 m .88706 .37125 L .87965 .38623 L p .846 .995 .837 r
F P
0 g
s
.86146 .40029 m .87965 .38623 L .88706 .37125 L p .836 .998 .831 r
F P
0 g
s
.70145 .53 m .71593 .52253 L .72728 .51292 L p .653 .966 .807 r
F P
0 g
s
.71593 .52253 m .70145 .53 L .69025 .53888 L p .596 .941 .773 r
F P
0 g
s
.80802 .45124 m .79053 .462 L .78086 .47343 L p .738 .992 .828 r
F P
0 g
s
.76396 .48335 m .78086 .47343 L .79053 .462 L p .756 .995 .845 r
F P
0 g
s
.78086 .47343 m .76396 .48335 L .75384 .49395 L p .702 .982 .814 r
F P
0 g
s
.4767 .66437 m .48258 .65183 L .46723 .65424 L p .772 .85 .91 r
F P
0 g
s
.46723 .65424 m .45989 .66702 L .4767 .66437 L p .772 .85 .91 r
F P
0 g
s
.83501 .42697 m .81701 .43893 L .80802 .45124 L p .772 .997 .831 r
F P
0 g
s
.79053 .462 m .80802 .45124 L .81701 .43893 L p .785 .998 .853 r
F P
0 g
s
.66579 .5527 m .67825 .54765 L .69025 .53888 L p .629 .961 .826 r
F P
0 g
s
.67825 .54765 m .66579 .5527 L .65427 .56069 L p .602 .949 .814 r
F P
0 g
s
.51408 .64312 m .51699 .6329 L .50265 .63697 L p .78 .89 .923 r
F P
0 g
s
.50265 .63697 m .49822 .64815 L .51408 .64312 L p .78 .89 .923 r
F P
0 g
s
.25218 .73802 m .26668 .72856 L .2468 .71898 L p .666 .77 .927 r
F P
0 g
s
.2468 .71898 m .23126 .726 L .25218 .73802 L p .666 .77 .927 r
F P
0 g
s
.30134 .72718 m .31484 .71701 L .29595 .71002 L p .708 .801 .923 r
F P
0 g
s
.29595 .71002 m .28126 .71938 L .30134 .72718 L p .708 .801 .923 r
F P
0 g
s
.73761 .50311 m .75384 .49395 L .76396 .48335 L p .726 .989 .833 r
F P
0 g
s
.75384 .49395 m .73761 .50311 L .72728 .51292 L p .668 .971 .8 r
F P
0 g
s
.5843 .59723 m .58891 .60028 L .60279 .59244 L p .722 .973 .927 r
F P
0 g
s
.58891 .60028 m .5843 .59723 L .57163 .60337 L p .742 .966 .935 r
F P
0 g
s
.57163 .60337 m .57476 .60792 L .58891 .60028 L p .742 .966 .935 r
F P
0 g
s
.59674 .59081 m .60279 .59244 L .61633 .58451 L p .7 .975 .917 r
F P
0 g
s
.60279 .59244 m .59674 .59081 L .5843 .59723 L p .722 .973 .927 r
F P
0 g
s
.40747 .69432 m .4175 .68118 L .40086 .67965 L p .747 .813 .904 r
F P
0 g
s
.40086 .67965 m .38949 .69219 L .40747 .69432 L p .747 .813 .904 r
F P
0 g
s
.57476 .60792 m .57163 .60337 L .55879 .60912 L p .757 .954 .938 r
F P
0 g
s
.55879 .60912 m .56042 .61519 L .57476 .60792 L p .757 .954 .938 r
F P
0 g
s
.37821 .70458 m .38949 .69219 L .37229 .68905 L p .736 .808 .909 r
F P
0 g
s
.37229 .68905 m .35972 .70072 L .37821 .70458 L p .736 .808 .909 r
F P
0 g
s
.60888 .58418 m .61633 .58451 L .62947 .57657 L p .681 .975 .905 r
F P
0 g
s
.61633 .58451 m .60888 .58418 L .59674 .59081 L p .7 .975 .917 r
F P
0 g
s
.86146 .40029 m .84306 .41373 L .83501 .42697 L p .803 1 .828 r
F P
0 g
s
.81701 .43893 m .83501 .42697 L .84306 .41373 L p .812 .997 .852 r
F P
0 g
s
.43478 .68155 m .44349 .66824 L .4276 .66823 L p .757 .824 .904 r
F P
0 g
s
.4276 .66823 m .4175 .68118 L .43478 .68155 L p .757 .824 .904 r
F P
0 g
s
.56042 .61519 m .55879 .60912 L .54584 .61437 L p .766 .939 .939 r
F P
0 g
s
.54584 .61437 m .54596 .62189 L .56042 .61519 L p .766 .939 .939 r
F P
0 g
s
.62064 .57739 m .62947 .57657 L .64214 .56864 L p .669 .973 .895 r
F P
0 g
s
.62947 .57657 m .62064 .57739 L .60888 .58418 L p .681 .975 .905 r
F P
0 g
s
.34725 .71211 m .35972 .70072 L .34216 .696 L p .724 .807 .916 r
F P
0 g
s
.34216 .696 m .32845 .70664 L .34725 .71211 L p .724 .807 .916 r
F P
0 g
s
.49822 .64815 m .50265 .63697 L .4885 .64003 L p .772 .874 .922 r
F P
0 g
s
.4885 .64003 m .48258 .65183 L .49822 .64815 L p .772 .874 .922 r
F P
0 g
s
.93085 .33033 m .91155 .34108 L .9056 .35599 L p .554 .861 .558 r
F P
0 g
s
.88706 .37125 m .9056 .35599 L .91155 .34108 L p .845 .997 .826 r
F P
0 g
s
.67663 .54461 m .69025 .53888 L .70145 .53 L p .664 .974 .842 r
F P
0 g
s
.69025 .53888 m .67663 .54461 L .66579 .5527 L p .629 .961 .826 r
F P
0 g
s
.71177 .52098 m .72728 .51292 L .73761 .50311 L p .705 .985 .835 r
F P
0 g
s
.72728 .51292 m .71177 .52098 L .70145 .53 L p .653 .966 .807 r
F P
0 g
s
.45989 .66702 m .46723 .65424 L .45227 .65547 L p .763 .842 .911 r
F P
0 g
s
.45227 .65547 m .44349 .66824 L .45989 .66702 L p .763 .842 .911 r
F P
0 g
s
.54596 .62189 m .54584 .61437 L .53287 .61902 L p .77 .923 .938 r
F P
0 g
s
.53287 .61902 m .53146 .62784 L .54596 .62189 L p .77 .923 .938 r
F P
0 g
s
.63198 .57046 m .64214 .56864 L .65427 .56069 L p .667 .973 .889 r
F P
0 g
s
.64214 .56864 m .63198 .57046 L .62064 .57739 L p .669 .973 .895 r
F P
0 g
s
.26668 .72856 m .28126 .71938 L .26249 .71083 L p .693 .798 .93 r
F P
0 g
s
.26249 .71083 m .2468 .71898 L .26668 .72856 L p .693 .798 .93 r
F P
0 g
s
.88706 .37125 m .86833 .38609 L .86146 .40029 L p .836 .998 .831 r
F P
0 g
s
.84306 .41373 m .86146 .40029 L .86833 .38609 L p .838 .995 .846 r
F P
0 g
s
.31484 .71701 m .32845 .70664 L .31073 .70041 L p .713 .807 .924 r
F P
0 g
s
.31073 .70041 m .29595 .71002 L .31484 .71701 L p .713 .807 .924 r
F P
0 g
s
.53146 .62784 m .53287 .61902 L .51993 .62299 L p .769 .906 .935 r
F P
0 g
s
.51993 .62299 m .51699 .6329 L .53146 .62784 L p .769 .906 .935 r
F P
0 g
s
.48258 .65183 m .4885 .64003 L .47463 .64209 L p .764 .862 .921 r
F P
0 g
s
.47463 .64209 m .46723 .65424 L .48258 .65183 L p .764 .862 .921 r
F P
0 g
s
.64283 .56342 m .65427 .56069 L .66579 .5527 L p .676 .976 .887 r
F P
0 g
s
.65427 .56069 m .64283 .56342 L .63198 .57046 L p .667 .973 .889 r
F P
0 g
s
.4175 .68118 m .4276 .66823 L .41232 .66715 L p .75 .824 .909 r
F P
0 g
s
.41232 .66715 m .40086 .67965 L .4175 .68118 L p .75 .824 .909 r
F P
0 g
s
.38949 .69219 m .40086 .67965 L .38496 .67714 L p .742 .817 .911 r
F P
0 g
s
.38496 .67714 m .37229 .68905 L .38949 .69219 L p .742 .817 .911 r
F P
0 g
s
.81701 .43893 m .7988 .45032 L .79053 .462 L p .785 .998 .853 r
F P
0 g
s
.77284 .47251 m .79053 .462 L .7988 .45032 L p .794 .996 .863 r
F P
0 g
s
.79053 .462 m .77284 .47251 L .76396 .48335 L p .756 .995 .845 r
F P
0 g
s
.74685 .4931 m .76396 .48335 L .77284 .47251 L p .77 .996 .856 r
F P
0 g
s
.76396 .48335 m .74685 .4931 L .73761 .50311 L p .726 .989 .833 r
F P
0 g
s
.68674 .53641 m .70145 .53 L .71177 .52098 L p .702 .984 .859 r
F P
0 g
s
.70145 .53 m .68674 .53641 L .67663 .54461 L p .664 .974 .842 r
F P
0 g
s
.35972 .70072 m .37229 .68905 L .35597 .68503 L p .73 .814 .917 r
F P
0 g
s
.35597 .68503 m .34216 .696 L .35972 .70072 L p .73 .814 .917 r
F P
0 g
s
.44349 .66824 m .45227 .65547 L .43779 .65564 L p .756 .837 .913 r
F P
0 g
s
.43779 .65564 m .4276 .66823 L .44349 .66824 L p .756 .837 .913 r
F P
0 g
s
.51699 .6329 m .51993 .62299 L .50711 .62621 L p .766 .891 .933 r
F P
0 g
s
.50711 .62621 m .50265 .63697 L .51699 .6329 L p .766 .891 .933 r
F P
0 g
s
.84306 .41373 m .82443 .42638 L .81701 .43893 L p .812 .997 .852 r
F P
0 g
s
.7988 .45032 m .81701 .43893 L .82443 .42638 L p .816 .993 .867 r
F P
0 g
s
.72116 .51179 m .73761 .50311 L .74685 .4931 L p .749 .994 .856 r
F P
0 g
s
.73761 .50311 m .72116 .51179 L .71177 .52098 L p .705 .985 .835 r
F P
0 g
s
.28126 .71938 m .29595 .71002 L .2783 .70229 L p .701 .806 .931 r
F P
0 g
s
.2783 .70229 m .26249 .71083 L .28126 .71938 L p .701 .806 .931 r
F P
0 g
s
.91155 .34108 m .89247 .35621 L .88706 .37125 L p .845 .997 .826 r
F P
0 g
s
.86833 .38609 m .88706 .37125 L .89247 .35621 L p .859 .988 .842 r
F P
0 g
s
.65312 .55625 m .66579 .5527 L .67663 .54461 L p .693 .98 .89 r
F P
0 g
s
.66579 .5527 m .65312 .55625 L .64283 .56342 L p .676 .976 .887 r
F P
0 g
s
.23126 .726 m .2468 .71898 L .22837 .70908 L p .708 .833 .942 r
F P
0 g
s
.22837 .70908 m .21163 .71739 L .23126 .726 L p .708 .833 .942 r
F P
0 g
s
.32845 .70664 m .34216 .696 L .32563 .6905 L p .719 .813 .924 r
F P
0 g
s
.32563 .6905 m .31073 .70041 L .32845 .70664 L p .719 .813 .924 r
F P
0 g
s
.46723 .65424 m .47463 .64209 L .46112 .64322 L p .758 .853 .921 r
F P
0 g
s
.46112 .64322 m .45227 .65547 L .46723 .65424 L p .758 .853 .921 r
F P
0 g
s
.50265 .63697 m .50711 .62621 L .49448 .62868 L p .761 .878 .931 r
F P
0 g
s
.49448 .62868 m .4885 .64003 L .50265 .63697 L p .761 .878 .931 r
F P
0 g
s
.57963 .59303 m .5843 .59723 L .59674 .59081 L p .729 .955 .947 r
F P
0 g
s
.5843 .59723 m .57963 .59303 L .56845 .59791 L p .739 .946 .949 r
F P
0 g
s
.56845 .59791 m .57163 .60337 L .5843 .59723 L p .739 .946 .949 r
F P
0 g
s
.59059 .58784 m .59674 .59081 L .60888 .58418 L p .72 .961 .943 r
F P
0 g
s
.59674 .59081 m .59059 .58784 L .57963 .59303 L p .729 .955 .947 r
F P
0 g
s
.86833 .38609 m .84938 .40027 L .84306 .41373 L p .838 .995 .846 r
F P
0 g
s
.82443 .42638 m .84306 .41373 L .84938 .40027 L p .838 .988 .863 r
F P
0 g
s
.57163 .60337 m .56845 .59791 L .55713 .60241 L p .746 .935 .949 r
F P
0 g
s
.55713 .60241 m .55879 .60912 L .57163 .60337 L p .746 .935 .949 r
F P
0 g
s
.60129 .58237 m .60888 .58418 L .62064 .57739 L p .712 .966 .938 r
F P
0 g
s
.60888 .58418 m .60129 .58237 L .59059 .58784 L p .72 .961 .943 r
F P
0 g
s
.55879 .60912 m .55713 .60241 L .54573 .60648 L p .751 .922 .947 r
F P
0 g
s
.54573 .60648 m .54584 .61437 L .55879 .60912 L p .751 .922 .947 r
F P
0 g
s
.91155 .34108 m .93085 .33033 L .93401 .30273 L p .834 .811 .827 r
F P
0 g
s
.40086 .67965 m .41232 .66715 L .39772 .66516 L p .745 .826 .914 r
F P
0 g
s
.39772 .66516 m .38496 .67714 L .40086 .67965 L p .745 .826 .914 r
F P
0 g
s
.69604 .52807 m .71177 .52098 L .72116 .51179 L p .738 .991 .873 r
F P
0 g
s
.71177 .52098 m .69604 .52807 L .68674 .53641 L p .702 .984 .859 r
F P
0 g
s
.4276 .66823 m .43779 .65564 L .42386 .65489 L p .75 .835 .917 r
F P
0 g
s
.42386 .65489 m .41232 .66715 L .4276 .66823 L p .75 .835 .917 r
F P
0 g
s
.61166 .57667 m .62064 .57739 L .63198 .57046 L p .709 .969 .933 r
F P
0 g
s
.62064 .57739 m .61166 .57667 L .60129 .58237 L p .712 .966 .938 r
F P
0 g
s
.54584 .61437 m .54573 .60648 L .5343 .61007 L p .754 .91 .944 r
F P
0 g
s
.5343 .61007 m .53287 .61902 L .54584 .61437 L p .754 .91 .944 r
F P
0 g
s
.66279 .54895 m .67663 .54461 L .68674 .53641 L p .715 .984 .895 r
F P
0 g
s
.67663 .54461 m .66279 .54895 L .65312 .55625 L p .693 .98 .89 r
F P
0 g
s
.37229 .68905 m .38496 .67714 L .36988 .67377 L p .737 .821 .917 r
F P
0 g
s
.36988 .67377 m .35597 .68503 L .37229 .68905 L p .737 .821 .917 r
F P
0 g
s
.29595 .71002 m .31073 .70041 L .29421 .69345 L p .707 .813 .931 r
F P
0 g
s
.29421 .69345 m .2783 .70229 L .29595 .71002 L p .707 .813 .931 r
F P
0 g
s
.4885 .64003 m .49448 .62868 L .48209 .63037 L p .756 .867 .929 r
F P
0 g
s
.48209 .63037 m .47463 .64209 L .4885 .64003 L p .756 .867 .929 r
F P
0 g
s
.7988 .45032 m .7804 .4615 L .77284 .47251 L p .794 .996 .863 r
F P
0 g
s
.75495 .48291 m .77284 .47251 L .7804 .4615 L p .802 .994 .87 r
F P
0 g
s
.77284 .47251 m .75495 .48291 L .74685 .4931 L p .77 .996 .856 r
F P
0 g
s
.45227 .65547 m .46112 .64322 L .44804 .64347 L p .752 .848 .922 r
F P
0 g
s
.44804 .64347 m .43779 .65564 L .45227 .65547 L p .752 .848 .922 r
F P
0 g
s
.2468 .71898 m .26249 .71083 L .24514 .70158 L p .69 .808 .938 r
F P
0 g
s
.24514 .70158 m .22837 .70908 L .2468 .71898 L p .69 .808 .938 r
F P
0 g
s
.53287 .61902 m .5343 .61007 L .52291 .61312 L p .755 .897 .941 r
F P
0 g
s
.52291 .61312 m .51993 .62299 L .53287 .61902 L p .755 .897 .941 r
F P
0 g
s
.62165 .57076 m .63198 .57046 L .64283 .56342 L p .71 .971 .929 r
F P
0 g
s
.63198 .57046 m .62165 .57076 L .61166 .57667 L p .709 .969 .933 r
F P
0 g
s
.34216 .696 m .35597 .68503 L .34062 .68023 L p .725 .82 .923 r
F P
0 g
s
.34062 .68023 m .32563 .6905 L .34216 .696 L p .725 .82 .923 r
F P
0 g
s
.82443 .42638 m .80561 .43848 L .7988 .45032 L p .816 .993 .867 r
F P
0 g
s
.7804 .4615 m .7988 .45032 L .80561 .43848 L p .821 .989 .873 r
F P
0 g
s
.72954 .50245 m .74685 .4931 L .75495 .48291 L p .783 .995 .87 r
F P
0 g
s
.74685 .4931 m .72954 .50245 L .72116 .51179 L p .749 .994 .856 r
F P
0 g
s
.89247 .35621 m .87327 .37173 L .86833 .38609 L p .859 .988 .842 r
F P
0 g
s
.84938 .40027 m .86833 .38609 L .87327 .37173 L p .858 .982 .855 r
F P
0 g
s
.93401 .30273 m .91512 .32368 L .91155 .34108 L p .834 .811 .827 r
F P
0 g
s
.89247 .35621 m .91155 .34108 L .91512 .32368 L p .879 .955 .851 r
F P
0 g
s
.51993 .62299 m .52291 .61312 L .51163 .61561 L p .754 .886 .939 r
F P
0 g
s
.51163 .61561 m .50711 .62621 L .51993 .62299 L p .754 .886 .939 r
F P
0 g
s
.63119 .56465 m .64283 .56342 L .65312 .55625 L p .717 .973 .926 r
F P
0 g
s
.64283 .56342 m .63119 .56465 L .62165 .57076 L p .71 .971 .929 r
F P
0 g
s
.6718 .54151 m .68674 .53641 L .69604 .52807 L p .738 .986 .9 r
F P
0 g
s
.68674 .53641 m .6718 .54151 L .66279 .54895 L p .715 .984 .895 r
F P
0 g
s
.47463 .64209 m .48209 .63037 L .47004 .63132 L p .752 .86 .929 r
F P
0 g
s
.47004 .63132 m .46112 .64322 L .47463 .64209 L p .752 .86 .929 r
F P
0 g
s
.84938 .40027 m .83022 .41369 L .82443 .42638 L p .838 .988 .863 r
F P
0 g
s
.80561 .43848 m .82443 .42638 L .83022 .41369 L p .837 .982 .873 r
F P
0 g
s
.70448 .5196 m .72116 .51179 L .72954 .50245 L p .769 .992 .883 r
F P
0 g
s
.72116 .51179 m .70448 .5196 L .69604 .52807 L p .738 .991 .873 r
F P
0 g
s
.41232 .66715 m .42386 .65489 L .41057 .6533 L p .746 .836 .92 r
F P
0 g
s
.41057 .6533 m .39772 .66516 L .41232 .66715 L p .746 .836 .92 r
F P
0 g
s
.31073 .70041 m .32563 .6905 L .31023 .68427 L p .713 .819 .931 r
F P
0 g
s
.31023 .68427 m .29421 .69345 L .31073 .70041 L p .713 .819 .931 r
F P
0 g
s
.38496 .67714 m .39772 .66516 L .38389 .66236 L p .741 .83 .92 r
F P
0 g
s
.38389 .66236 m .36988 .67377 L .38496 .67714 L p .741 .83 .92 r
F P
0 g
s
.26249 .71083 m .2783 .70229 L .26202 .69386 L p .694 .811 .938 r
F P
0 g
s
.26202 .69386 m .24514 .70158 L .26249 .71083 L p .694 .811 .938 r
F P
0 g
s
.43779 .65564 m .44804 .64347 L .43548 .64292 L p .748 .846 .924 r
F P
0 g
s
.43548 .64292 m .42386 .65489 L .43779 .65564 L p .748 .846 .924 r
F P
0 g
s
.50711 .62621 m .51163 .61561 L .50052 .61752 L p .752 .876 .936 r
F P
0 g
s
.50052 .61752 m .49448 .62868 L .50711 .62621 L p .752 .876 .936 r
F P
0 g
s
.64024 .55837 m .65312 .55625 L .66279 .54895 L p .729 .975 .925 r
F P
0 g
s
.65312 .55625 m .64024 .55837 L .63119 .56465 L p .717 .973 .926 r
F P
0 g
s
.35597 .68503 m .36988 .67377 L .35573 .66964 L p .732 .827 .923 r
F P
0 g
s
.35573 .66964 m .34062 .68023 L .35597 .68503 L p .732 .827 .923 r
F P
0 g
s
.57488 .58789 m .57963 .59303 L .59059 .58784 L p .728 .934 .956 r
F P
0 g
s
.57963 .59303 m .57488 .58789 L .56523 .59169 L p .732 .926 .956 r
F P
0 g
s
.56523 .59169 m .56845 .59791 L .57963 .59303 L p .732 .926 .956 r
F P
0 g
s
.56845 .59791 m .56523 .59169 L .55545 .59515 L p .735 .916 .954 r
F P
0 g
s
.55545 .59515 m .55713 .60241 L .56845 .59791 L p .735 .916 .954 r
F P
0 g
s
.46112 .64322 m .47004 .63132 L .45839 .63157 L p .748 .855 .929 r
F P
0 g
s
.45839 .63157 m .44804 .64347 L .46112 .64322 L p .748 .855 .929 r
F P
0 g
s
.91512 .32368 m .89576 .34076 L .89247 .35621 L p .879 .955 .851 r
F P
0 g
s
.87327 .37173 m .89247 .35621 L .89576 .34076 L p .876 .968 .849 r
F P
0 g
s
.58435 .58377 m .59059 .58784 L .60129 .58237 L p .725 .942 .955 r
F P
0 g
s
.59059 .58784 m .58435 .58377 L .57488 .58789 L p .728 .934 .956 r
F P
0 g
s
.68007 .53393 m .69604 .52807 L .70448 .5196 L p .761 .985 .904 r
F P
0 g
s
.69604 .52807 m .68007 .53393 L .6718 .54151 L p .738 .986 .9 r
F P
0 g
s
.87327 .37173 m .85388 .38671 L .84938 .40027 L p .858 .982 .855 r
F P
0 g
s
.83022 .41369 m .84938 .40027 L .85388 .38671 L p .854 .974 .867 r
F P
0 g
s
.55713 .60241 m .55545 .59515 L .54561 .59824 L p .738 .906 .952 r
F P
0 g
s
.54561 .59824 m .54573 .60648 L .55713 .60241 L p .738 .906 .952 r
F P
0 g
s
.49448 .62868 m .50052 .61752 L .48963 .61884 L p .75 .868 .934 r
F P
0 g
s
.48963 .61884 m .48209 .63037 L .49448 .62868 L p .75 .868 .934 r
F P
0 g
s
.21163 .71739 m .22837 .70908 L .2116 .69785 L p .638 .75 .93 r
F P
0 g
s
.2116 .69785 m .19406 .70232 L .21163 .71739 L p .638 .75 .93 r
F P
0 g
s
.7804 .4615 m .76182 .47261 L .75495 .48291 L p .802 .994 .87 r
F P
0 g
s
.73686 .49299 m .75495 .48291 L .76182 .47261 L p .809 .99 .878 r
F P
0 g
s
.75495 .48291 m .73686 .49299 L .72954 .50245 L p .783 .995 .87 r
F P
0 g
s
.80561 .43848 m .7866 .45039 L .7804 .4615 L p .821 .989 .873 r
F P
0 g
s
.76182 .47261 m .7804 .4615 L .7866 .45039 L p .825 .986 .877 r
F P
0 g
s
.59358 .57936 m .60129 .58237 L .61166 .57667 L p .723 .948 .953 r
F P
0 g
s
.60129 .58237 m .59358 .57936 L .58435 .58377 L p .725 .942 .955 r
F P
0 g
s
.91512 .32368 m .93401 .30273 L .93768 .30979 L p 0 0 0 r
F P
0 g
s
.54573 .60648 m .54561 .59824 L .53574 .60093 L p .741 .897 .949 r
F P
0 g
s
.53574 .60093 m .5343 .61007 L .54573 .60648 L p .741 .897 .949 r
F P
0 g
s
.64874 .55192 m .66279 .54895 L .6718 .54151 L p .743 .975 .924 r
F P
0 g
s
.66279 .54895 m .64874 .55192 L .64024 .55837 L p .729 .975 .925 r
F P
0 g
s
.32563 .6905 m .34062 .68023 L .32636 .67471 L p .72 .825 .93 r
F P
0 g
s
.32636 .67471 m .31023 .68427 L .32563 .6905 L p .72 .825 .93 r
F P
0 g
s
.2783 .70229 m .29421 .69345 L .27899 .68578 L p .701 .817 .937 r
F P
0 g
s
.27899 .68578 m .26202 .69386 L .2783 .70229 L p .701 .817 .937 r
F P
0 g
s
.60253 .57469 m .61166 .57667 L .62165 .57076 L p .724 .952 .95 r
F P
0 g
s
.61166 .57667 m .60253 .57469 L .59358 .57936 L p .723 .948 .953 r
F P
0 g
s
.712 .51101 m .72954 .50245 L .73686 .49299 L p .793 .988 .889 r
F P
0 g
s
.72954 .50245 m .712 .51101 L .70448 .5196 L p .769 .992 .883 r
F P
0 g
s
.5343 .61007 m .53574 .60093 L .52592 .60321 L p .742 .887 .946 r
F P
0 g
s
.52592 .60321 m .52291 .61312 L .5343 .61007 L p .742 .887 .946 r
F P
0 g
s
.83022 .41369 m .81087 .42656 L .80561 .43848 L p .837 .982 .873 r
F P
0 g
s
.7866 .45039 m .80561 .43848 L .81087 .42656 L p .838 .978 .878 r
F P
0 g
s
.39772 .66516 m .41057 .6533 L .398 .65097 L p .742 .838 .924 r
F P
0 g
s
.398 .65097 m .38389 .66236 L .39772 .66516 L p .742 .838 .924 r
F P
0 g
s
.42386 .65489 m .43548 .64292 L .42351 .64163 L p .744 .845 .926 r
F P
0 g
s
.42351 .64163 m .41057 .6533 L .42386 .65489 L p .744 .845 .926 r
F P
0 g
s
.61115 .56977 m .62165 .57076 L .63119 .56465 L p .728 .956 .946 r
F P
0 g
s
.62165 .57076 m .61115 .56977 L .60253 .57469 L p .724 .952 .95 r
F P
0 g
s
.48209 .63037 m .48963 .61884 L .47905 .61959 L p .748 .863 .933 r
F P
0 g
s
.47905 .61959 m .47004 .63132 L .48209 .63037 L p .748 .863 .933 r
F P
0 g
s
.36988 .67377 m .38389 .66236 L .37093 .65882 L p .736 .834 .925 r
F P
0 g
s
.37093 .65882 m .35573 .66964 L .36988 .67377 L p .736 .834 .925 r
F P
0 g
s
.52291 .61312 m .52592 .60321 L .51619 .60506 L p .743 .879 .943 r
F P
0 g
s
.51619 .60506 m .51163 .61561 L .52291 .61312 L p .743 .879 .943 r
F P
0 g
s
.44804 .64347 m .45839 .63157 L .4472 .63114 L p .745 .853 .93 r
F P
0 g
s
.4472 .63114 m .43548 .64292 L .44804 .64347 L p .745 .853 .93 r
F P
0 g
s
.22837 .70908 m .24514 .70158 L .22935 .69157 L p .675 .801 .942 r
F P
0 g
s
.22935 .69157 m .2116 .69785 L .22837 .70908 L p .675 .801 .942 r
F P
0 g
s
.68757 .52624 m .70448 .5196 L .712 .51101 L p .781 .981 .906 r
F P
0 g
s
.70448 .5196 m .68757 .52624 L .68007 .53393 L p .761 .985 .904 r
F P
0 g
s
.65664 .54531 m .6718 .54151 L .68007 .53393 L p .758 .973 .923 r
F P
0 g
s
.6718 .54151 m .65664 .54531 L .64874 .55192 L p .743 .975 .924 r
F P
0 g
s
.89576 .34076 m .87623 .35727 L .87327 .37173 L p .876 .968 .849 r
F P
0 g
s
.85388 .38671 m .87327 .37173 L .87623 .35727 L p .87 .964 .857 r
F P
0 g
s
.61938 .56463 m .63119 .56465 L .64024 .55837 L p .735 .958 .943 r
F P
0 g
s
.63119 .56465 m .61938 .56463 L .61115 .56977 L p .728 .956 .946 r
F P
0 g
s
.85388 .38671 m .8343 .40095 L .83022 .41369 L p .854 .974 .867 r
F P
0 g
s
.81087 .42656 m .83022 .41369 L .8343 .40095 L p .85 .968 .875 r
F P
0 g
s
.29421 .69345 m .31023 .68427 L .29607 .67733 L p .708 .823 .936 r
F P
0 g
s
.29607 .67733 m .27899 .68578 L .29421 .69345 L p .708 .823 .936 r
F P
0 g
s
.51163 .61561 m .51619 .60506 L .50662 .60647 L p .743 .872 .94 r
F P
0 g
s
.50662 .60647 m .50052 .61752 L .51163 .61561 L p .743 .872 .94 r
F P
0 g
s
.34062 .68023 m .35573 .66964 L .34258 .66479 L p .727 .831 .929 r
F P
0 g
s
.34258 .66479 m .32636 .67471 L .34062 .68023 L p .727 .831 .929 r
F P
0 g
s
.47004 .63132 m .47905 .61959 L .46882 .61978 L p .746 .859 .932 r
F P
0 g
s
.46882 .61978 m .45839 .63157 L .47004 .63132 L p .746 .859 .932 r
F P
0 g
s
.93768 .30979 m .91671 .31015 L .91512 .32368 L p 0 0 0 r
F P
0 g
s
.89576 .34076 m .91512 .32368 L .91671 .31015 L p .871 .984 .837 r
F P
0 g
s
.7866 .45039 m .76743 .46226 L .76182 .47261 L p .825 .986 .877 r
F P
0 g
s
.74305 .48346 m .76182 .47261 L .76743 .46226 L p .827 .981 .882 r
F P
0 g
s
.76182 .47261 m .74305 .48346 L .73686 .49299 L p .809 .99 .878 r
F P
0 g
s
.62717 .55928 m .64024 .55837 L .64874 .55192 L p .745 .959 .94 r
F P
0 g
s
.64024 .55837 m .62717 .55928 L .61938 .56463 L p .735 .958 .943 r
F P
0 g
s
.24514 .70158 m .26202 .69386 L .24722 .68471 L p .686 .813 .943 r
F P
0 g
s
.24722 .68471 m .22935 .69157 L .24514 .70158 L p .686 .813 .943 r
F P
0 g
s
.41057 .6533 m .42351 .64163 L .4122 .63967 L p .741 .846 .929 r
F P
0 g
s
.4122 .63967 m .398 .65097 L .41057 .6533 L p .741 .846 .929 r
F P
0 g
s
.71855 .50234 m .73686 .49299 L .74305 .48346 L p .812 .981 .891 r
F P
0 g
s
.73686 .49299 m .71855 .50234 L .712 .51101 L p .793 .988 .889 r
F P
0 g
s
.50052 .61752 m .50662 .60647 L .49725 .60743 L p .743 .867 .937 r
F P
0 g
s
.49725 .60743 m .48963 .61884 L .50052 .61752 L p .743 .867 .937 r
F P
0 g
s
.81087 .42656 m .79137 .43925 L .7866 .45039 L p .838 .978 .878 r
F P
0 g
s
.76743 .46226 m .7866 .45039 L .79137 .43925 L p .84 .975 .879 r
F P
0 g
s
.43548 .64292 m .4472 .63114 L .43655 .63009 L p .742 .852 .931 r
F P
0 g
s
.43655 .63009 m .42351 .64163 L .43548 .64292 L p .742 .852 .931 r
F P
0 g
s
.66389 .53856 m .68007 .53393 L .68757 .52624 L p .773 .97 .922 r
F P
0 g
s
.68007 .53393 m .66389 .53856 L .65664 .54531 L p .758 .973 .923 r
F P
0 g
s
.38389 .66236 m .398 .65097 L .38623 .64794 L p .738 .841 .928 r
F P
0 g
s
.38623 .64794 m .37093 .65882 L .38389 .66236 L p .738 .841 .928 r
F P
0 g
s
.56196 .58492 m .56523 .59169 L .57488 .58789 L p .721 .909 .96 r
F P
0 g
s
.56523 .59169 m .56196 .58492 L .55375 .5875 L p .723 .901 .959 r
F P
0 g
s
.55375 .5875 m .55545 .59515 L .56523 .59169 L p .723 .901 .959 r
F P
0 g
s
.57006 .58204 m .57488 .58789 L .58435 .58377 L p .721 .916 .961 r
F P
0 g
s
.57488 .58789 m .57006 .58204 L .56196 .58492 L p .721 .909 .96 r
F P
0 g
s
.69424 .51846 m .712 .51101 L .71855 .50234 L p .798 .975 .906 r
F P
0 g
s
.712 .51101 m .69424 .51846 L .68757 .52624 L p .781 .981 .906 r
F P
0 g
s
.55545 .59515 m .55375 .5875 L .54548 .58977 L p .724 .893 .957 r
F P
0 g
s
.54548 .58977 m .54561 .59824 L .55545 .59515 L p .724 .893 .957 r
F P
0 g
s
.57801 .57887 m .58435 .58377 L .59358 .57936 L p .721 .923 .96 r
F P
0 g
s
.58435 .58377 m .57801 .57887 L .57006 .58204 L p .721 .916 .961 r
F P
0 g
s
.31023 .68427 m .32636 .67471 L .31326 .66849 L p .715 .829 .935 r
F P
0 g
s
.31326 .66849 m .29607 .67733 L .31023 .68427 L p .715 .829 .935 r
F P
0 g
s
.63448 .55373 m .64874 .55192 L .65664 .54531 L p .755 .958 .937 r
F P
0 g
s
.64874 .55192 m .63448 .55373 L .62717 .55928 L p .745 .959 .94 r
F P
0 g
s
.54561 .59824 m .54548 .58977 L .53721 .59173 L p .726 .886 .954 r
F P
0 g
s
.53721 .59173 m .53574 .60093 L .54561 .59824 L p .726 .886 .954 r
F P
0 g
s
.87623 .35727 m .85652 .37315 L .85388 .38671 L p .87 .964 .857 r
F P
0 g
s
.8343 .40095 m .85388 .38671 L .85652 .37315 L p .863 .958 .867 r
F P
0 g
s
.45839 .63157 m .46882 .61978 L .45901 .61942 L p .744 .857 .933 r
F P
0 g
s
.45901 .61942 m .4472 .63114 L .45839 .63157 L p .744 .857 .933 r
F P
0 g
s
.35573 .66964 m .37093 .65882 L .35891 .65459 L p .732 .838 .93 r
F P
0 g
s
.35891 .65459 m .34258 .66479 L .35573 .66964 L p .732 .838 .93 r
F P
0 g
s
.58576 .57543 m .59358 .57936 L .60253 .57469 L p .723 .929 .959 r
F P
0 g
s
.59358 .57936 m .58576 .57543 L .57801 .57887 L p .721 .923 .96 r
F P
0 g
s
.48963 .61884 m .49725 .60743 L .48814 .60796 L p .743 .863 .936 r
F P
0 g
s
.48814 .60796 m .47905 .61959 L .48963 .61884 L p .743 .863 .936 r
F P
0 g
s
.8343 .40095 m .81455 .41466 L .81087 .42656 L p .85 .968 .875 r
F P
0 g
s
.79137 .43925 m .81087 .42656 L .81455 .41466 L p .849 .964 .878 r
F P
0 g
s
.19406 .70232 m .2116 .69785 L .19653 .68676 L p .697 .869 .963 r
F P
0 g
s
.19653 .68676 m .17778 .69408 L .19406 .70232 L p .697 .869 .963 r
F P
0 g
s
.53574 .60093 m .53721 .59173 L .52897 .59335 L p .728 .879 .951 r
F P
0 g
s
.52897 .59335 m .52592 .60321 L .53574 .60093 L p .728 .879 .951 r
F P
0 g
s
.26202 .69386 m .27899 .68578 L .26519 .67742 L p .695 .82 .942 r
F P
0 g
s
.26519 .67742 m .24722 .68471 L .26202 .69386 L p .695 .82 .942 r
F P
0 g
s
.59327 .57172 m .60253 .57469 L .61115 .56977 L p .727 .934 .956 r
F P
0 g
s
.60253 .57469 m .59327 .57172 L .58576 .57543 L p .723 .929 .959 r
F P
0 g
s
.91671 .31015 m .89691 .32566 L .89576 .34076 L p .871 .984 .837 r
F P
0 g
s
.87623 .35727 m .89576 .34076 L .89691 .32566 L p .882 .953 .848 r
F P
0 g
s
.67044 .53171 m .68757 .52624 L .69424 .51846 L p .786 .965 .92 r
F P
0 g
s
.68757 .52624 m .67044 .53171 L .66389 .53856 L p .773 .97 .922 r
F P
0 g
s
.52592 .60321 m .52897 .59335 L .52081 .59465 L p .73 .874 .948 r
F P
0 g
s
.52081 .59465 m .51619 .60506 L .52592 .60321 L p .73 .874 .948 r
F P
0 g
s
.6005 .56778 m .61115 .56977 L .61938 .56463 L p .733 .938 .953 r
F P
0 g
s
.61115 .56977 m .6005 .56778 L .59327 .57172 L p .727 .934 .956 r
F P
0 g
s
.42351 .64163 m .43655 .63009 L .42649 .62844 L p .74 .853 .933 r
F P
0 g
s
.42649 .62844 m .4122 .63967 L .42351 .64163 L p .74 .853 .933 r
F P
0 g
s
.64127 .54803 m .65664 .54531 L .66389 .53856 L p .766 .956 .934 r
F P
0 g
s
.65664 .54531 m .64127 .54803 L .63448 .55373 L p .755 .958 .937 r
F P
0 g
s
.398 .65097 m .4122 .63967 L .40162 .63707 L p .738 .848 .932 r
F P
0 g
s
.40162 .63707 m .38623 .64794 L .398 .65097 L p .738 .848 .932 r
F P
0 g
s
.47905 .61959 m .48814 .60796 L .47935 .60805 L p .743 .861 .935 r
F P
0 g
s
.47935 .60805 m .46882 .61978 L .47905 .61959 L p .743 .861 .935 r
F P
0 g
s
.32636 .67471 m .34258 .66479 L .33054 .65926 L p .722 .835 .934 r
F P
0 g
s
.33054 .65926 m .31326 .66849 L .32636 .67471 L p .722 .835 .934 r
F P
0 g
s
.76743 .46226 m .74808 .47393 L .74305 .48346 L p .827 .981 .882 r
F P
0 g
s
.72408 .49364 m .74305 .48346 L .74808 .47393 L p .826 .972 .891 r
F P
0 g
s
.74305 .48346 m .72408 .49364 L .71855 .50234 L p .812 .981 .891 r
F P
0 g
s
.51619 .60506 m .52081 .59465 L .51279 .59562 L p .732 .869 .945 r
F P
0 g
s
.51279 .59562 m .50662 .60647 L .51619 .60506 L p .732 .869 .945 r
F P
0 g
s
.4472 .63114 m .45901 .61942 L .44968 .61854 L p .742 .857 .934 r
F P
0 g
s
.44968 .61854 m .43655 .63009 L .4472 .63114 L p .742 .857 .934 r
F P
0 g
s
.79137 .43925 m .77171 .45194 L .76743 .46226 L p .84 .975 .879 r
F P
0 g
s
.74808 .47393 m .76743 .46226 L .77171 .45194 L p .84 .97 .882 r
F P
0 g
s
.6074 .5636 m .61938 .56463 L .62717 .55928 L p .74 .941 .95 r
F P
0 g
s
.61938 .56463 m .6074 .5636 L .6005 .56778 L p .733 .938 .953 r
F P
0 g
s
.70002 .51063 m .71855 .50234 L .72408 .49364 L p .811 .967 .905 r
F P
0 g
s
.71855 .50234 m .70002 .51063 L .69424 .51846 L p .798 .975 .906 r
F P
0 g
s
.37093 .65882 m .38623 .64794 L .37533 .64424 L p .735 .844 .932 r
F P
0 g
s
.37533 .64424 m .35891 .65459 L .37093 .65882 L p .735 .844 .932 r
F P
0 g
s
.27899 .68578 m .29607 .67733 L .28326 .66971 L p .703 .826 .941 r
F P
0 g
s
.28326 .66971 m .26519 .67742 L .27899 .68578 L p .703 .826 .941 r
F P
0 g
s
.2116 .69785 m .22935 .69157 L .21523 .68094 L p .674 .816 .951 r
F P
0 g
s
.21523 .68094 m .19653 .68676 L .2116 .69785 L p .674 .816 .951 r
F P
0 g
s
.85652 .37315 m .83663 .38828 L .8343 .40095 L p .863 .958 .867 r
F P
0 g
s
.81455 .41466 m .8343 .40095 L .83663 .38828 L p .858 .952 .873 r
F P
0 g
s
.50662 .60647 m .51279 .59562 L .50495 .59625 L p .734 .865 .942 r
F P
0 g
s
.50495 .59625 m .49725 .60743 L .50662 .60647 L p .734 .865 .942 r
F P
0 g
s
.89691 .32566 m .87713 .34287 L .87623 .35727 L p .882 .953 .848 r
F P
0 g
s
.85652 .37315 m .87623 .35727 L .87713 .34287 L p .876 .946 .856 r
F P
0 g
s
.81455 .41466 m .79465 .42819 L .79137 .43925 L p .849 .964 .878 r
F P
0 g
s
.77171 .45194 m .79137 .43925 L .79465 .42819 L p .85 .961 .878 r
F P
0 g
s
.64749 .54219 m .66389 .53856 L .67044 .53171 L p .777 .953 .93 r
F P
0 g
s
.66389 .53856 m .64749 .54219 L .64127 .54803 L p .766 .956 .934 r
F P
0 g
s
.61392 .55922 m .62717 .55928 L .63448 .55373 L p .749 .943 .946 r
F P
0 g
s
.62717 .55928 m .61392 .55922 L .6074 .5636 L p .74 .941 .95 r
F P
0 g
s
.67625 .52479 m .69424 .51846 L .70002 .51063 L p .797 .958 .918 r
F P
0 g
s
.69424 .51846 m .67625 .52479 L .67044 .53171 L p .786 .965 .92 r
F P
0 g
s
.46882 .61978 m .47935 .60805 L .47093 .60771 L p .743 .86 .935 r
F P
0 g
s
.47093 .60771 m .45901 .61942 L .46882 .61978 L p .743 .86 .935 r
F P
0 g
s
.34258 .66479 m .35891 .65459 L .34791 .64969 L p .728 .841 .934 r
F P
0 g
s
.34791 .64969 m .33054 .65926 L .34258 .66479 L p .728 .841 .934 r
F P
0 g
s
.49725 .60743 m .50495 .59625 L .49732 .59655 L p .736 .863 .94 r
F P
0 g
s
.49732 .59655 m .48814 .60796 L .49725 .60743 L p .736 .863 .94 r
F P
0 g
s
.4122 .63967 m .42649 .62844 L .4171 .62621 L p .738 .854 .935 r
F P
0 g
s
.4171 .62621 m .40162 .63707 L .4122 .63967 L p .738 .854 .935 r
F P
0 g
s
.22935 .69157 m .24722 .68471 L .23403 .67487 L p .68 .816 .948 r
F P
0 g
s
.23403 .67487 m .21523 .68094 L .22935 .69157 L p .68 .816 .948 r
F P
0 g
s
.29607 .67733 m .31326 .66849 L .30142 .66158 L p .71 .832 .94 r
F P
0 g
s
.30142 .66158 m .28326 .66971 L .29607 .67733 L p .71 .832 .94 r
F P
0 g
s
.43655 .63009 m .44968 .61854 L .44088 .61715 L p .74 .857 .935 r
F P
0 g
s
.44088 .61715 m .42649 .62844 L .43655 .63009 L p .74 .857 .935 r
F P
0 g
s
.62004 .55465 m .63448 .55373 L .64127 .54803 L p .759 .942 .942 r
F P
0 g
s
.63448 .55373 m .62004 .55465 L .61392 .55922 L p .749 .943 .946 r
F P
0 g
s
.55864 .57778 m .56196 .58492 L .57006 .58204 L p .709 .896 .964 r
F P
0 g
s
.56196 .58492 m .55864 .57778 L .55202 .57963 L p .708 .89 .963 r
F P
0 g
s
.55202 .57963 m .55375 .5875 L .56196 .58492 L p .708 .89 .963 r
F P
0 g
s
.56517 .57567 m .57006 .58204 L .57801 .57887 L p .71 .902 .964 r
F P
0 g
s
.57006 .58204 m .56517 .57567 L .55864 .57778 L p .709 .896 .964 r
F P
0 g
s
.55375 .5875 m .55202 .57963 L .54536 .58124 L p .709 .884 .962 r
F P
0 g
s
.54536 .58124 m .54548 .58977 L .55375 .5875 L p .709 .884 .962 r
F P
0 g
s
.38623 .64794 m .40162 .63707 L .39183 .63385 L p .735 .85 .934 r
F P
0 g
s
.39183 .63385 m .37533 .64424 L .38623 .64794 L p .735 .85 .934 r
F P
0 g
s
.57158 .57333 m .57801 .57887 L .58576 .57543 L p .713 .908 .964 r
F P
0 g
s
.57801 .57887 m .57158 .57333 L .56517 .57567 L p .71 .902 .964 r
F P
0 g
s
.54548 .58977 m .54536 .58124 L .53869 .58259 L p .71 .878 .959 r
F P
0 g
s
.53869 .58259 m .53721 .59173 L .54548 .58977 L p .71 .878 .959 r
F P
0 g
s
.83663 .38828 m .81658 .40287 L .81455 .41466 L p .858 .952 .873 r
F P
0 g
s
.79465 .42819 m .81455 .41466 L .81658 .40287 L p .856 .949 .876 r
F P
0 g
s
.6531 .53624 m .67044 .53171 L .67625 .52479 L p .786 .948 .927 r
F P
0 g
s
.67044 .53171 m .6531 .53624 L .64749 .54219 L p .777 .953 .93 r
F P
0 g
s
.57783 .57075 m .58576 .57543 L .59327 .57172 L p .717 .913 .962 r
F P
0 g
s
.58576 .57543 m .57783 .57075 L .57158 .57333 L p .713 .908 .964 r
F P
0 g
s
.53721 .59173 m .53869 .58259 L .53205 .58369 L p .712 .874 .957 r
F P
0 g
s
.53205 .58369 m .52897 .59335 L .53721 .59173 L p .712 .874 .957 r
F P
0 g
s
.74808 .47393 m .72854 .48497 L .72408 .49364 L p .826 .972 .891 r
F P
0 g
s
.70489 .50279 m .72408 .49364 L .72854 .48497 L p .82 .958 .903 r
F P
0 g
s
.72408 .49364 m .70489 .50279 L .70002 .51063 L p .811 .967 .905 r
F P
0 g
s
.77171 .45194 m .75189 .46447 L .74808 .47393 L p .84 .97 .882 r
F P
0 g
s
.72854 .48497 m .74808 .47393 L .75189 .46447 L p .836 .961 .89 r
F P
0 g
s
.45901 .61942 m .47093 .60771 L .46292 .60695 L p .742 .86 .935 r
F P
0 g
s
.46292 .60695 m .44968 .61854 L .45901 .61942 L p .742 .86 .935 r
F P
0 g
s
.93476 .26798 m .91548 .29092 L .91671 .31015 L p .682 .606 .764 r
F P
0 g
s
.91671 .31015 m .93768 .30979 L .93476 .26798 L p .682 .606 .764 r
F P
0 g
s
.89691 .32566 m .91671 .31015 L .91548 .29092 L p .864 .88 .847 r
F P
0 g
s
.48814 .60796 m .49732 .59655 L .48997 .59651 L p .737 .862 .939 r
F P
0 g
s
.48997 .59651 m .47935 .60805 L .48814 .60796 L p .737 .862 .939 r
F P
0 g
s
.87713 .34287 m .85721 .35968 L .85652 .37315 L p .876 .946 .856 r
F P
0 g
s
.83663 .38828 m .85652 .37315 L .85721 .35968 L p .868 .94 .864 r
F P
0 g
s
.58388 .56795 m .59327 .57172 L .6005 .56778 L p .723 .918 .96 r
F P
0 g
s
.59327 .57172 m .58388 .56795 L .57783 .57075 L p .717 .913 .962 r
F P
0 g
s
.52897 .59335 m .53205 .58369 L .52549 .58454 L p .715 .87 .954 r
F P
0 g
s
.52549 .58454 m .52081 .59465 L .52897 .59335 L p .715 .87 .954 r
F P
0 g
s
.62571 .54992 m .64127 .54803 L .64749 .54219 L p .768 .941 .938 r
F P
0 g
s
.64127 .54803 m .62571 .54992 L .62004 .55465 L p .759 .942 .942 r
F P
0 g
s
.68129 .51782 m .70002 .51063 L .70489 .50279 L p .805 .95 .915 r
F P
0 g
s
.70002 .51063 m .68129 .51782 L .67625 .52479 L p .797 .958 .918 r
F P
0 g
s
.35891 .65459 m .37533 .64424 L .36537 .63992 L p .732 .847 .935 r
F P
0 g
s
.36537 .63992 m .34791 .64969 L .35891 .65459 L p .732 .847 .935 r
F P
0 g
s
.24722 .68471 m .26519 .67742 L .25291 .66835 L p .689 .822 .947 r
F P
0 g
s
.25291 .66835 m .23403 .67487 L .24722 .68471 L p .689 .822 .947 r
F P
0 g
s
.79465 .42819 m .77462 .44174 L .77171 .45194 L p .85 .961 .878 r
F P
0 g
s
.75189 .46447 m .77171 .45194 L .77462 .44174 L p .848 .957 .881 r
F P
0 g
s
.31326 .66849 m .33054 .65926 L .31968 .65305 L p .718 .837 .938 r
F P
0 g
s
.31968 .65305 m .30142 .66158 L .31326 .66849 L p .718 .837 .938 r
F P
0 g
s
.5897 .56493 m .6005 .56778 L .6074 .5636 L p .73 .922 .957 r
F P
0 g
s
.6005 .56778 m .5897 .56493 L .58388 .56795 L p .723 .918 .96 r
F P
0 g
s
.52081 .59465 m .52549 .58454 L .51903 .58513 L p .717 .867 .952 r
F P
0 g
s
.51903 .58513 m .51279 .59562 L .52081 .59465 L p .717 .867 .952 r
F P
0 g
s
.42649 .62844 m .44088 .61715 L .43268 .61526 L p .739 .858 .936 r
F P
0 g
s
.43268 .61526 m .4171 .62621 L .42649 .62844 L p .739 .858 .936 r
F P
0 g
s
.47935 .60805 m .48997 .59651 L .48294 .59614 L p .739 .862 .938 r
F P
0 g
s
.48294 .59614 m .47093 .60771 L .47935 .60805 L p .739 .862 .938 r
F P
0 g
s
.40162 .63707 m .4171 .62621 L .40843 .62343 L p .735 .855 .937 r
F P
0 g
s
.40843 .62343 m .39183 .63385 L .40162 .63707 L p .735 .855 .937 r
F P
0 g
s
.59525 .56172 m .6074 .5636 L .61392 .55922 L p .738 .925 .953 r
F P
0 g
s
.6074 .5636 m .59525 .56172 L .5897 .56493 L p .73 .922 .957 r
F P
0 g
s
.91548 .29092 m .89578 .31002 L .89691 .32566 L p .864 .88 .847 r
F P
0 g
s
.87713 .34287 m .89691 .32566 L .89578 .31002 L p .883 .923 .846 r
F P
0 g
s
.65807 .53023 m .67625 .52479 L .68129 .51782 L p .794 .942 .923 r
F P
0 g
s
.67625 .52479 m .65807 .53023 L .6531 .53624 L p .786 .948 .927 r
F P
0 g
s
.51279 .59562 m .51903 .58513 L .51272 .58547 L p .72 .864 .95 r
F P
0 g
s
.51272 .58547 m .50495 .59625 L .51279 .59562 L p .72 .864 .95 r
F P
0 g
s
.44968 .61854 m .46292 .60695 L .45538 .60577 L p .742 .861 .936 r
F P
0 g
s
.45538 .60577 m .44088 .61715 L .44968 .61854 L p .742 .861 .936 r
F P
0 g
s
.6309 .54505 m .64749 .54219 L .6531 .53624 L p .777 .938 .934 r
F P
0 g
s
.64749 .54219 m .6309 .54505 L .62571 .54992 L p .768 .941 .938 r
F P
0 g
s
.81658 .40287 m .79641 .41729 L .79465 .42819 L p .856 .949 .876 r
F P
0 g
s
.77462 .44174 m .79465 .42819 L .79641 .41729 L p .855 .947 .876 r
F P
0 g
s
.17778 .69408 m .19653 .68676 L .1834 .67388 L p .611 .711 .916 r
F P
0 g
s
.1834 .67388 m .16418 .67521 L .17778 .69408 L p .611 .711 .916 r
F P
0 g
s
.26519 .67742 m .28326 .66971 L .27189 .66139 L p .698 .828 .945 r
F P
0 g
s
.27189 .66139 m .25291 .66835 L .26519 .67742 L p .698 .828 .945 r
F P
0 g
s
.85721 .35968 m .83714 .37575 L .83663 .38828 L p .868 .94 .864 r
F P
0 g
s
.81658 .40287 m .83663 .38828 L .83714 .37575 L p .862 .936 .87 r
F P
0 g
s
.33054 .65926 m .34791 .64969 L .33802 .64414 L p .724 .843 .937 r
F P
0 g
s
.33802 .64414 m .31968 .65305 L .33054 .65926 L p .724 .843 .937 r
F P
0 g
s
.37533 .64424 m .39183 .63385 L .38292 .63004 L p .733 .851 .937 r
F P
0 g
s
.38292 .63004 m .36537 .63992 L .37533 .64424 L p .733 .851 .937 r
F P
0 g
s
.6005 .55832 m .61392 .55922 L .62004 .55465 L p .747 .927 .949 r
F P
0 g
s
.61392 .55922 m .6005 .55832 L .59525 .56172 L p .738 .925 .953 r
F P
0 g
s
.50495 .59625 m .51272 .58547 L .5066 .58556 L p .723 .863 .948 r
F P
0 g
s
.5066 .58556 m .49732 .59655 L .50495 .59625 L p .723 .863 .948 r
F P
0 g
s
.75189 .46447 m .73189 .47639 L .72854 .48497 L p .836 .961 .89 r
F P
0 g
s
.7088 .49501 m .72854 .48497 L .73189 .47639 L p .827 .949 .9 r
F P
0 g
s
.72854 .48497 m .7088 .49501 L .70489 .50279 L p .82 .958 .903 r
F P
0 g
s
.68551 .51088 m .70489 .50279 L .7088 .49501 L p .812 .942 .911 r
F P
0 g
s
.70489 .50279 m .68551 .51088 L .68129 .51782 L p .805 .95 .915 r
F P
0 g
s
.47093 .60771 m .48294 .59614 L .47626 .59544 L p .74 .862 .938 r
F P
0 g
s
.47626 .59544 m .46292 .60695 L .47093 .60771 L p .74 .862 .938 r
F P
0 g
s
.19653 .68676 m .21523 .68094 L .20292 .66952 L p .659 .798 .949 r
F P
0 g
s
.20292 .66952 m .1834 .67388 L .19653 .68676 L p .659 .798 .949 r
F P
0 g
s
.77462 .44174 m .75445 .45515 L .75189 .46447 L p .848 .957 .881 r
F P
0 g
s
.73189 .47639 m .75189 .46447 L .75445 .45515 L p .843 .95 .887 r
F P
0 g
s
.63557 .54009 m .6531 .53624 L .65807 .53023 L p .784 .935 .929 r
F P
0 g
s
.6531 .53624 m .63557 .54009 L .6309 .54505 L p .777 .938 .934 r
F P
0 g
s
.60541 .55475 m .62004 .55465 L .62571 .54992 L p .756 .927 .945 r
F P
0 g
s
.62004 .55465 m .60541 .55475 L .6005 .55832 L p .747 .927 .949 r
F P
0 g
s
.91548 .29092 m .93476 .26798 L .93221 .261 L p .858 .992 .736 r
F P
0 g
s
.89578 .31002 m .87592 .32854 L .87713 .34287 L p .883 .923 .846 r
F P
0 g
s
.85721 .35968 m .87713 .34287 L .87592 .32854 L p .878 .925 .852 r
F P
0 g
s
.28326 .66971 m .30142 .66158 L .29095 .65399 L p .706 .833 .943 r
F P
0 g
s
.29095 .65399 m .27189 .66139 L .28326 .66971 L p .706 .833 .943 r
F P
0 g
s
.49732 .59655 m .5066 .58556 L .50069 .58539 L p .726 .863 .946 r
F P
0 g
s
.50069 .58539 m .48997 .59651 L .49732 .59655 L p .726 .863 .946 r
F P
0 g
s
.66236 .52419 m .68129 .51782 L .68551 .51088 L p .8 .936 .919 r
F P
0 g
s
.68129 .51782 m .66236 .52419 L .65807 .53023 L p .794 .942 .923 r
F P
0 g
s
.4171 .62621 m .43268 .61526 L .42512 .61288 L p .737 .859 .938 r
F P
0 g
s
.42512 .61288 m .40843 .62343 L .4171 .62621 L p .737 .859 .938 r
F P
0 g
s
.44088 .61715 m .45538 .60577 L .44836 .60417 L p .741 .861 .936 r
F P
0 g
s
.44836 .60417 m .43268 .61526 L .44088 .61715 L p .741 .861 .936 r
F P
0 g
s
.55528 .57031 m .55864 .57778 L .56517 .57567 L p .697 .884 .967 r
F P
0 g
s
.55864 .57778 m .55528 .57031 L .55027 .57158 L p .695 .879 .967 r
F P
0 g
s
.55027 .57158 m .55202 .57963 L .55864 .57778 L p .695 .879 .967 r
F P
0 g
s
.55202 .57963 m .55027 .57158 L .54523 .57265 L p .695 .875 .966 r
F P
0 g
s
.54523 .57265 m .54536 .58124 L .55202 .57963 L p .695 .875 .966 r
F P
0 g
s
.56022 .56886 m .56517 .57567 L .57158 .57333 L p .7 .888 .967 r
F P
0 g
s
.56517 .57567 m .56022 .56886 L .55528 .57031 L p .697 .884 .967 r
F P
0 g
s
.34791 .64969 m .36537 .63992 L .35644 .63497 L p .729 .848 .937 r
F P
0 g
s
.35644 .63497 m .33802 .64414 L .34791 .64969 L p .729 .848 .937 r
F P
0 g
s
.54536 .58124 m .54523 .57265 L .54019 .57354 L p .695 .871 .965 r
F P
0 g
s
.54019 .57354 m .53869 .58259 L .54536 .58124 L p .695 .871 .965 r
F P
0 g
s
.56506 .56722 m .57158 .57333 L .57783 .57075 L p .704 .893 .966 r
F P
0 g
s
.57158 .57333 m .56506 .56722 L .56022 .56886 L p .7 .888 .967 r
F P
0 g
s
.83714 .37575 m .81693 .39128 L .81658 .40287 L p .862 .936 .87 r
F P
0 g
s
.79641 .41729 m .81658 .40287 L .81693 .39128 L p .859 .934 .872 r
F P
0 g
s
.79641 .41729 m .77613 .43174 L .77462 .44174 L p .855 .947 .876 r
F P
0 g
s
.75445 .45515 m .77462 .44174 L .77613 .43174 L p .853 .944 .878 r
F P
0 g
s
.39183 .63385 m .40843 .62343 L .40054 .6201 L p .733 .855 .938 r
F P
0 g
s
.40054 .6201 m .38292 .63004 L .39183 .63385 L p .733 .855 .938 r
F P
0 g
s
.53869 .58259 m .54019 .57354 L .53517 .57423 L p .696 .868 .963 r
F P
0 g
s
.53517 .57423 m .53205 .58369 L .53869 .58259 L p .696 .868 .963 r
F P
0 g
s
.60996 .55104 m .62571 .54992 L .6309 .54505 L p .764 .927 .941 r
F P
0 g
s
.62571 .54992 m .60996 .55104 L .60541 .55475 L p .756 .927 .945 r
F P
0 g
s
.56979 .56541 m .57783 .57075 L .58388 .56795 L p .709 .898 .964 r
F P
0 g
s
.57783 .57075 m .56979 .56541 L .56506 .56722 L p .704 .893 .966 r
F P
0 g
s
.21523 .68094 m .23403 .67487 L .22254 .66434 L p .673 .815 .951 r
F P
0 g
s
.22254 .66434 m .20292 .66952 L .21523 .68094 L p .673 .815 .951 r
F P
0 g
s
.46292 .60695 m .47626 .59544 L .46998 .5944 L p .74 .863 .938 r
F P
0 g
s
.46998 .5944 m .45538 .60577 L .46292 .60695 L p .74 .863 .938 r
F P
0 g
s
.53205 .58369 m .53517 .57423 L .53021 .57473 L p .698 .865 .961 r
F P
0 g
s
.53021 .57473 m .52549 .58454 L .53205 .58369 L p .698 .865 .961 r
F P
0 g
s
.48997 .59651 m .50069 .58539 L .49505 .58497 L p .728 .863 .944 r
F P
0 g
s
.49505 .58497 m .48294 .59614 L .48997 .59651 L p .728 .863 .944 r
F P
0 g
s
.57436 .56342 m .58388 .56795 L .5897 .56493 L p .716 .902 .962 r
F P
0 g
s
.58388 .56795 m .57436 .56342 L .56979 .56541 L p .709 .898 .964 r
F P
0 g
s
.30142 .66158 m .31968 .65305 L .31009 .64617 L p .714 .839 .942 r
F P
0 g
s
.31009 .64617 m .29095 .65399 L .30142 .66158 L p .714 .839 .942 r
F P
0 g
s
.6397 .53507 m .65807 .53023 L .66236 .52419 L p .791 .93 .925 r
F P
0 g
s
.65807 .53023 m .6397 .53507 L .63557 .54009 L p .784 .935 .929 r
F P
0 g
s
.52549 .58454 m .53021 .57473 L .52534 .57504 L p .7 .863 .959 r
F P
0 g
s
.52534 .57504 m .51903 .58513 L .52549 .58454 L p .7 .863 .959 r
F P
0 g
s
.87592 .32854 m .85593 .34639 L .85721 .35968 L p .878 .925 .852 r
F P
0 g
s
.83714 .37575 m .85721 .35968 L .85593 .34639 L p .87 .922 .859 r
F P
0 g
s
.57875 .56126 m .5897 .56493 L .59525 .56172 L p .723 .905 .959 r
F P
0 g
s
.5897 .56493 m .57875 .56126 L .57436 .56342 L p .716 .902 .962 r
F P
0 g
s
.73189 .47639 m .71172 .48733 L .7088 .49501 L p .827 .949 .9 r
F P
0 g
s
.68888 .504 m .7088 .49501 L .71172 .48733 L p .817 .934 .908 r
F P
0 g
s
.7088 .49501 m .68888 .504 L .68551 .51088 L p .812 .942 .911 r
F P
0 g
s
.61412 .54722 m .6309 .54505 L .63557 .54009 L p .772 .926 .936 r
F P
0 g
s
.6309 .54505 m .61412 .54722 L .60996 .55104 L p .764 .927 .941 r
F P
0 g
s
.36537 .63992 m .38292 .63004 L .37493 .62565 L p .731 .852 .938 r
F P
0 g
s
.37493 .62565 m .35644 .63497 L .36537 .63992 L p .731 .852 .938 r
F P
0 g
s
.75445 .45515 m .73411 .46798 L .73189 .47639 L p .843 .95 .887 r
F P
0 g
s
.71172 .48733 m .73189 .47639 L .73411 .46798 L p .832 .939 .896 r
F P
0 g
s
.51903 .58513 m .52534 .57504 L .52058 .57516 L p .703 .862 .958 r
F P
0 g
s
.52058 .57516 m .51272 .58547 L .51903 .58513 L p .703 .862 .958 r
F P
0 g
s
.93221 .261 m .91215 .27577 L .91548 .29092 L p .858 .992 .736 r
F P
0 g
s
.89578 .31002 m .91548 .29092 L .91215 .27577 L p .891 .922 .836 r
F P
0 g
s
.66594 .51817 m .68551 .51088 L .68888 .504 L p .805 .929 .916 r
F P
0 g
s
.68551 .51088 m .66594 .51817 L .66236 .52419 L p .8 .936 .919 r
F P
0 g
s
.23403 .67487 m .25291 .66835 L .24226 .6586 L p .685 .823 .949 r
F P
0 g
s
.24226 .6586 m .22254 .66434 L .23403 .67487 L p .685 .823 .949 r
F P
0 g
s
.43268 .61526 m .44836 .60417 L .4419 .60215 L p .74 .862 .937 r
F P
0 g
s
.4419 .60215 m .42512 .61288 L .43268 .61526 L p .74 .862 .937 r
F P
0 g
s
.48294 .59614 m .49505 .58497 L .4897 .58429 L p .731 .863 .943 r
F P
0 g
s
.4897 .58429 m .47626 .59544 L .48294 .59614 L p .731 .863 .943 r
F P
0 g
s
.58294 .55896 m .59525 .56172 L .6005 .55832 L p .731 .908 .956 r
F P
0 g
s
.59525 .56172 m .58294 .55896 L .57875 .56126 L p .723 .905 .959 r
F P
0 g
s
.81693 .39128 m .79661 .40663 L .79641 .41729 L p .859 .934 .872 r
F P
0 g
s
.77613 .43174 m .79641 .41729 L .79661 .40663 L p .859 .933 .873 r
F P
0 g
s
.40843 .62343 m .42512 .61288 L .41825 .61002 L p .735 .859 .939 r
F P
0 g
s
.41825 .61002 m .40054 .6201 L .40843 .62343 L p .735 .859 .939 r
F P
0 g
s
.45538 .60577 m .46998 .5944 L .46414 .59303 L p .741 .864 .938 r
F P
0 g
s
.46414 .59303 m .44836 .60417 L .45538 .60577 L p .741 .864 .938 r
F P
0 g
s
.31968 .65305 m .33802 .64414 L .32931 .63794 L p .721 .844 .94 r
F P
0 g
s
.32931 .63794 m .31009 .64617 L .31968 .65305 L p .721 .844 .94 r
F P
0 g
s
.51272 .58547 m .52058 .57516 L .51596 .57509 L p .706 .861 .956 r
F P
0 g
s
.51596 .57509 m .5066 .58556 L .51272 .58547 L p .706 .861 .956 r
F P
0 g
s
.77613 .43174 m .75572 .44605 L .75445 .45515 L p .853 .944 .878 r
F P
0 g
s
.73411 .46798 m .75445 .45515 L .75572 .44605 L p .847 .938 .884 r
F P
0 g
s
.5869 .55651 m .6005 .55832 L .60541 .55475 L p .739 .91 .952 r
F P
0 g
s
.6005 .55832 m .5869 .55651 L .58294 .55896 L p .731 .908 .956 r
F P
0 g
s
.64325 .53002 m .66236 .52419 L .66594 .51817 L p .796 .925 .921 r
F P
0 g
s
.66236 .52419 m .64325 .53002 L .6397 .53507 L p .791 .93 .925 r
F P
0 g
s
.61785 .54331 m .63557 .54009 L .6397 .53507 L p .78 .923 .932 r
F P
0 g
s
.63557 .54009 m .61785 .54331 L .61412 .54722 L p .772 .926 .936 r
F P
0 g
s
.25291 .66835 m .27189 .66139 L .26205 .65239 L p .694 .829 .947 r
F P
0 g
s
.26205 .65239 m .24226 .6586 L .25291 .66835 L p .694 .829 .947 r
F P
0 g
s
.85593 .34639 m .8358 .36346 L .83714 .37575 L p .87 .922 .859 r
F P
0 g
s
.81693 .39128 m .83714 .37575 L .8358 .36346 L p .863 .919 .865 r
F P
0 g
s
.38292 .63004 m .40054 .6201 L .3935 .61624 L p .732 .856 .939 r
F P
0 g
s
.3935 .61624 m .37493 .62565 L .38292 .63004 L p .732 .856 .939 r
F P
0 g
s
.5066 .58556 m .51596 .57509 L .51151 .57483 L p .709 .861 .954 r
F P
0 g
s
.51151 .57483 m .50069 .58539 L .5066 .58556 L p .709 .861 .954 r
F P
0 g
s
.47626 .59544 m .4897 .58429 L .48467 .58335 L p .733 .864 .942 r
F P
0 g
s
.48467 .58335 m .46998 .5944 L .47626 .59544 L p .733 .864 .942 r
F P
0 g
s
.5906 .55394 m .60541 .55475 L .60996 .55104 L p .747 .911 .948 r
F P
0 g
s
.60541 .55475 m .5906 .55394 L .5869 .55651 L p .739 .91 .952 r
F P
0 g
s
.91215 .27577 m .89238 .29493 L .89578 .31002 L p .891 .922 .836 r
F P
0 g
s
.87592 .32854 m .89578 .31002 L .89238 .29493 L p .884 .908 .839 r
F P
0 g
s
.16418 .67521 m .1834 .67388 L .17217 .66195 L p .673 .927 .972 r
F P
0 g
s
.17217 .66195 m .15162 .66953 L .16418 .67521 L p .673 .927 .972 r
F P
0 g
s
.33802 .64414 m .35644 .63497 L .34859 .62939 L p .726 .849 .939 r
F P
0 g
s
.34859 .62939 m .32931 .63794 L .33802 .64414 L p .726 .849 .939 r
F P
0 g
s
.71172 .48733 m .69137 .49723 L .68888 .504 L p .817 .934 .908 r
F P
0 g
s
.66879 .51222 m .68888 .504 L .69137 .49723 L p .809 .923 .912 r
F P
0 g
s
.68888 .504 m .66879 .51222 L .66594 .51817 L p .805 .929 .916 r
F P
0 g
s
.73411 .46798 m .71362 .47983 L .71172 .48733 L p .832 .939 .896 r
F P
0 g
s
.69137 .49723 m .71172 .48733 L .71362 .47983 L p .82 .926 .904 r
F P
0 g
s
.44836 .60417 m .46414 .59303 L .45877 .59131 L p .741 .865 .938 r
F P
0 g
s
.45877 .59131 m .4419 .60215 L .44836 .60417 L p .741 .865 .938 r
F P
0 g
s
.79661 .40663 m .77619 .422 L .77613 .43174 L p .859 .933 .873 r
F P
0 g
s
.75572 .44605 m .77613 .43174 L .77619 .422 L p .856 .931 .874 r
F P
0 g
s
.42512 .61288 m .4419 .60215 L .43604 .59971 L p .739 .862 .938 r
F P
0 g
s
.43604 .59971 m .41825 .61002 L .42512 .61288 L p .739 .862 .938 r
F P
0 g
s
.50069 .58539 m .51151 .57483 L .50727 .57438 L p .712 .861 .953 r
F P
0 g
s
.50727 .57438 m .49505 .58497 L .50069 .58539 L p .712 .861 .953 r
F P
0 g
s
.27189 .66139 m .29095 .65399 L .28192 .64573 L p .702 .834 .946 r
F P
0 g
s
.28192 .64573 m .26205 .65239 L .27189 .66139 L p .702 .834 .946 r
F P
0 g
s
.62115 .53935 m .6397 .53507 L .64325 .53002 L p .786 .92 .928 r
F P
0 g
s
.6397 .53507 m .62115 .53935 L .61785 .54331 L p .78 .923 .932 r
F P
0 g
s
.59402 .55125 m .60996 .55104 L .61412 .54722 L p .755 .911 .944 r
F P
0 g
s
.60996 .55104 m .59402 .55125 L .5906 .55394 L p .747 .911 .948 r
F P
0 g
s
.64621 .525 m .66594 .51817 L .66879 .51222 L p .801 .92 .918 r
F P
0 g
s
.66594 .51817 m .64621 .525 L .64325 .53002 L p .796 .925 .921 r
F P
0 g
s
.55187 .5624 m .55528 .57031 L .56022 .56886 L p .689 .871 .967 r
F P
0 g
s
.55528 .57031 m .55187 .5624 L .5485 .56318 L p .687 .868 .967 r
F P
0 g
s
.5485 .56318 m .55027 .57158 L .55528 .57031 L p .687 .868 .967 r
F P
0 g
s
.55027 .57158 m .5485 .56318 L .54511 .56384 L p .685 .865 .967 r
F P
0 g
s
.54511 .56384 m .54523 .57265 L .55027 .57158 L p .685 .865 .967 r
F P
0 g
s
.55519 .56149 m .56022 .56886 L .56506 .56722 L p .693 .874 .966 r
F P
0 g
s
.56022 .56886 m .55519 .56149 L .55187 .5624 L p .689 .871 .967 r
F P
0 g
s
.54523 .57265 m .54511 .56384 L .54171 .56437 L p .684 .862 .966 r
F P
0 g
s
.54171 .56437 m .54019 .57354 L .54523 .57265 L p .684 .862 .966 r
F P
0 g
s
.75572 .44605 m .73517 .45979 L .73411 .46798 L p .847 .938 .884 r
F P
0 g
s
.71362 .47983 m .73411 .46798 L .73517 .45979 L p .836 .929 .893 r
F P
0 g
s
.8358 .36346 m .81555 .37998 L .81693 .39128 L p .863 .919 .865 r
F P
0 g
s
.79661 .40663 m .81693 .39128 L .81555 .37998 L p .861 .918 .868 r
F P
0 g
s
.46998 .5944 m .48467 .58335 L .48001 .58215 L p .734 .864 .942 r
F P
0 g
s
.48001 .58215 m .46414 .59303 L .46998 .5944 L p .734 .864 .942 r
F P
0 g
s
.40054 .6201 m .41825 .61002 L .41213 .60668 L p .734 .859 .94 r
F P
0 g
s
.41213 .60668 m .3935 .61624 L .40054 .6201 L p .734 .859 .94 r
F P
0 g
s
.55846 .56045 m .56506 .56722 L .56979 .56541 L p .697 .877 .965 r
F P
0 g
s
.56506 .56722 m .55846 .56045 L .55519 .56149 L p .693 .874 .966 r
F P
0 g
s
.54019 .57354 m .54171 .56437 L .53834 .56476 L p .685 .86 .966 r
F P
0 g
s
.53834 .56476 m .53517 .57423 L .54019 .57354 L p .685 .86 .966 r
F P
0 g
s
.35644 .63497 m .37493 .62565 L .36794 .62068 L p .729 .853 .94 r
F P
0 g
s
.36794 .62068 m .34859 .62939 L .35644 .63497 L p .729 .853 .94 r
F P
0 g
s
.1834 .67388 m .20292 .66952 L .1925 .65761 L p .663 .825 .961 r
F P
0 g
s
.1925 .65761 m .17217 .66195 L .1834 .67388 L p .663 .825 .961 r
F P
0 g
s
.56163 .5593 m .56979 .56541 L .57436 .56342 L p .702 .88 .964 r
F P
0 g
s
.56979 .56541 m .56163 .5593 L .55846 .56045 L p .697 .877 .965 r
F P
0 g
s
.49505 .58497 m .50727 .57438 L .50324 .57374 L p .715 .861 .951 r
F P
0 g
s
.50324 .57374 m .4897 .58429 L .49505 .58497 L p .715 .861 .951 r
F P
0 g
s
.89238 .29493 m .87257 .31446 L .87592 .32854 L p .884 .908 .839 r
F P
0 g
s
.85593 .34639 m .87592 .32854 L .87257 .31446 L p .877 .905 .846 r
F P
0 g
s
.53517 .57423 m .53834 .56476 L .535 .56502 L p .685 .858 .965 r
F P
0 g
s
.535 .56502 m .53021 .57473 L .53517 .57423 L p .685 .858 .965 r
F P
0 g
s
.59715 .54848 m .61412 .54722 L .61785 .54331 L p .762 .91 .94 r
F P
0 g
s
.61412 .54722 m .59715 .54848 L .59402 .55125 L p .755 .911 .944 r
F P
0 g
s
.29095 .65399 m .31009 .64617 L .30186 .63862 L p .711 .839 .944 r
F P
0 g
s
.30186 .63862 m .28192 .64573 L .29095 .65399 L p .711 .839 .944 r
F P
0 g
s
.56471 .55804 m .57436 .56342 L .57875 .56126 L p .707 .883 .962 r
F P
0 g
s
.57436 .56342 m .56471 .55804 L .56163 .5593 L p .702 .88 .964 r
F P
0 g
s
.53021 .57473 m .535 .56502 L .53172 .56515 L p .686 .857 .964 r
F P
0 g
s
.53172 .56515 m .52534 .57504 L .53021 .57473 L p .686 .857 .964 r
F P
0 g
s
.62398 .53536 m .64325 .53002 L .64621 .525 L p .791 .917 .924 r
F P
0 g
s
.64325 .53002 m .62398 .53536 L .62115 .53935 L p .786 .92 .928 r
F P
0 g
s
.56766 .55666 m .57875 .56126 L .58294 .55896 L p .713 .885 .96 r
F P
0 g
s
.57875 .56126 m .56766 .55666 L .56471 .55804 L p .707 .883 .962 r
F P
0 g
s
.52534 .57504 m .53172 .56515 L .52852 .56515 L p .688 .856 .963 r
F P
0 g
s
.52852 .56515 m .52058 .57516 L .52534 .57504 L p .688 .856 .963 r
F P
0 g
s
.4419 .60215 m .45877 .59131 L .45392 .58925 L p .741 .865 .938 r
F P
0 g
s
.45392 .58925 m .43604 .59971 L .4419 .60215 L p .741 .865 .938 r
F P
0 g
s
.77619 .422 m .75567 .43724 L .75572 .44605 L p .856 .931 .874 r
F P
0 g
s
.73517 .45979 m .75572 .44605 L .75567 .43724 L p .849 .926 .88 r
F P
0 g
s
.4897 .58429 m .50324 .57374 L .49947 .5729 L p .717 .861 .95 r
F P
0 g
s
.49947 .5729 m .48467 .58335 L .4897 .58429 L p .717 .861 .95 r
F P
0 g
s
.20292 .66952 m .22254 .66434 L .21288 .65315 L p .67 .818 .954 r
F P
0 g
s
.21288 .65315 m .1925 .65761 L .20292 .66952 L p .67 .818 .954 r
F P
0 g
s
.37493 .62565 m .3935 .61624 L .38734 .61185 L p .73 .855 .94 r
F P
0 g
s
.38734 .61185 m .36794 .62068 L .37493 .62565 L p .73 .855 .94 r
F P
0 g
s
.46414 .59303 m .48001 .58215 L .47573 .58068 L p .736 .865 .941 r
F P
0 g
s
.47573 .58068 m .45877 .59131 L .46414 .59303 L p .736 .865 .941 r
F P
0 g
s
.71362 .47983 m .69297 .49064 L .69137 .49723 L p .82 .926 .904 r
F P
0 g
s
.67088 .50639 m .69137 .49723 L .69297 .49064 L p .811 .916 .909 r
F P
0 g
s
.69137 .49723 m .67088 .50639 L .66879 .51222 L p .809 .923 .912 r
F P
0 g
s
.57048 .55519 m .58294 .55896 L .5869 .55651 L p .72 .887 .957 r
F P
0 g
s
.58294 .55896 m .57048 .55519 L .56766 .55666 L p .713 .885 .96 r
F P
0 g
s
.59995 .54564 m .61785 .54331 L .62115 .53935 L p .769 .909 .936 r
F P
0 g
s
.61785 .54331 m .59995 .54564 L .59715 .54848 L p .762 .91 .94 r
F P
0 g
s
.81555 .37998 m .79521 .39629 L .79661 .40663 L p .861 .918 .868 r
F P
0 g
s
.77619 .422 m .79661 .40663 L .79521 .39629 L p .86 .918 .868 r
F P
0 g
s
.52058 .57516 m .52852 .56515 L .52542 .56501 L p .69 .855 .961 r
F P
0 g
s
.52542 .56501 m .51596 .57509 L .52058 .57516 L p .69 .855 .961 r
F P
0 g
s
.31009 .64617 m .32931 .63794 L .32185 .63109 L p .719 .845 .942 r
F P
0 g
s
.32185 .63109 m .30186 .63862 L .31009 .64617 L p .719 .845 .942 r
F P
0 g
s
.64855 .52003 m .66879 .51222 L .67088 .50639 L p .804 .915 .914 r
F P
0 g
s
.66879 .51222 m .64855 .52003 L .64621 .525 L p .801 .92 .918 r
F P
0 g
s
.41825 .61002 m .43604 .59971 L .43084 .59686 L p .738 .862 .939 r
F P
0 g
s
.43084 .59686 m .41213 .60668 L .41825 .61002 L p .738 .862 .939 r
F P
0 g
s
.87257 .31446 m .85263 .33338 L .85593 .34639 L p .877 .905 .846 r
F P
0 g
s
.8358 .36346 m .85593 .34639 L .85263 .33338 L p .869 .903 .854 r
F P
0 g
s
.73517 .45979 m .71448 .47255 L .71362 .47983 L p .836 .929 .893 r
F P
0 g
s
.69297 .49064 m .71362 .47983 L .71448 .47255 L p .823 .918 .901 r
F P
0 g
s
.57313 .55363 m .5869 .55651 L .5906 .55394 L p .726 .888 .954 r
F P
0 g
s
.5869 .55651 m .57313 .55363 L .57048 .55519 L p .72 .887 .957 r
F P
0 g
s
.51596 .57509 m .52542 .56501 L .52244 .56474 L p .692 .854 .96 r
F P
0 g
s
.52244 .56474 m .51151 .57483 L .51596 .57509 L p .692 .854 .96 r
F P
0 g
s
.62632 .53138 m .64621 .525 L .64855 .52003 L p .795 .913 .92 r
F P
0 g
s
.64621 .525 m .62632 .53138 L .62398 .53536 L p .791 .917 .924 r
F P
0 g
s
.22254 .66434 m .24226 .6586 L .23334 .64818 L p .681 .823 .951 r
F P
0 g
s
.23334 .64818 m .21288 .65315 L .22254 .66434 L p .681 .823 .951 r
F P
0 g
s
.48467 .58335 m .49947 .5729 L .49598 .57188 L p .72 .861 .949 r
F P
0 g
s
.49598 .57188 m .48001 .58215 L .48467 .58335 L p .72 .861 .949 r
F P
0 g
s
.32931 .63794 m .34859 .62939 L .3419 .62321 L p .724 .849 .94 r
F P
0 g
s
.3419 .62321 m .32185 .63109 L .32931 .63794 L p .724 .849 .94 r
F P
0 g
s
.60241 .54276 m .62115 .53935 L .62398 .53536 L p .774 .907 .932 r
F P
0 g
s
.62115 .53935 m .60241 .54276 L .59995 .54564 L p .769 .909 .936 r
F P
0 g
s
.57561 .55198 m .5906 .55394 L .59402 .55125 L p .733 .889 .951 r
F P
0 g
s
.5906 .55394 m .57561 .55198 L .57313 .55363 L p .726 .888 .954 r
F P
0 g
s
.3935 .61624 m .41213 .60668 L .4068 .60286 L p .733 .858 .94 r
F P
0 g
s
.4068 .60286 m .38734 .61185 L .3935 .61624 L p .733 .858 .94 r
F P
0 g
s
.91215 .27577 m .93221 .261 L .92542 .23463 L p .804 .763 .815 r
F P
0 g
s
.51151 .57483 m .52244 .56474 L .51959 .56434 L p .694 .854 .959 r
F P
0 g
s
.51959 .56434 m .50727 .57438 L .51151 .57483 L p .694 .854 .959 r
F P
0 g
s
.75567 .43724 m .73504 .45189 L .73517 .45979 L p .849 .926 .88 r
F P
0 g
s
.71448 .47255 m .73517 .45979 L .73504 .45189 L p .838 .919 .889 r
F P
0 g
s
.45877 .59131 m .47573 .58068 L .47187 .57895 L p .737 .865 .94 r
F P
0 g
s
.47187 .57895 m .45392 .58925 L .45877 .59131 L p .737 .865 .94 r
F P
0 g
s
.79521 .39629 m .7748 .41261 L .77619 .422 L p .86 .918 .868 r
F P
0 g
s
.75567 .43724 m .77619 .422 L .7748 .41261 L p .858 .918 .87 r
F P
0 g
s
.43604 .59971 m .45392 .58925 L .44961 .58685 L p .741 .865 .938 r
F P
0 g
s
.44961 .58685 m .43084 .59686 L .43604 .59971 L p .741 .865 .938 r
F P
0 g
s
.85263 .33338 m .83258 .3515 L .8358 .36346 L p .869 .903 .854 r
F P
0 g
s
.81555 .37998 m .8358 .36346 L .83258 .3515 L p .863 .902 .859 r
F P
0 g
s
.57791 .55027 m .59402 .55125 L .59715 .54848 L p .739 .89 .948 r
F P
0 g
s
.59402 .55125 m .57791 .55027 L .57561 .55198 L p .733 .889 .951 r
F P
0 g
s
.24226 .6586 m .26205 .65239 L .25385 .64271 L p .691 .829 .949 r
F P
0 g
s
.25385 .64271 m .23334 .64818 L .24226 .6586 L p .691 .829 .949 r
F P
0 g
s
.92542 .23463 m .90617 .25851 L .91215 .27577 L p .804 .763 .815 r
F P
0 g
s
.89238 .29493 m .91215 .27577 L .90617 .25851 L p .873 .867 .83 r
F P
0 g
s
.50727 .57438 m .51959 .56434 L .5169 .56381 L p .696 .854 .958 r
F P
0 g
s
.5169 .56381 m .50324 .57374 L .50727 .57438 L p .696 .854 .958 r
F P
0 g
s
.69297 .49064 m .67219 .50072 L .67088 .50639 L p .811 .916 .909 r
F P
0 g
s
.65025 .51517 m .67088 .50639 L .67219 .50072 L p .806 .91 .911 r
F P
0 g
s
.67088 .50639 m .65025 .51517 L .64855 .52003 L p .804 .915 .914 r
F P
0 g
s
.34859 .62939 m .36794 .62068 L .36199 .61513 L p .728 .852 .94 r
F P
0 g
s
.36199 .61513 m .3419 .62321 L .34859 .62939 L p .728 .852 .94 r
F P
0 g
s
.48001 .58215 m .49598 .57188 L .49278 .57066 L p .722 .861 .947 r
F P
0 g
s
.49278 .57066 m .47573 .58068 L .48001 .58215 L p .722 .861 .947 r
F P
0 g
s
.60453 .53985 m .62398 .53536 L .62632 .53138 L p .779 .905 .929 r
F P
0 g
s
.62398 .53536 m .60453 .53985 L .60241 .54276 L p .774 .907 .932 r
F P
0 g
s
.71448 .47255 m .69365 .48427 L .69297 .49064 L p .823 .918 .901 r
F P
0 g
s
.67219 .50072 m .69297 .49064 L .69365 .48427 L p .813 .91 .906 r
F P
0 g
s
.62816 .52745 m .64855 .52003 L .65025 .51517 L p .799 .91 .917 r
F P
0 g
s
.64855 .52003 m .62816 .52745 L .62632 .53138 L p .795 .913 .92 r
F P
0 g
s
.41213 .60668 m .43084 .59686 L .42631 .5936 L p .737 .861 .939 r
F P
0 g
s
.42631 .5936 m .4068 .60286 L .41213 .60668 L p .737 .861 .939 r
F P
0 g
s
.57999 .5485 m .59715 .54848 L .59995 .54564 L p .744 .889 .945 r
F P
0 g
s
.59715 .54848 m .57999 .5485 L .57791 .55027 L p .739 .89 .948 r
F P
0 g
s
.26205 .65239 m .28192 .64573 L .27442 .63679 L p .7 .834 .947 r
F P
0 g
s
.27442 .63679 m .25385 .64271 L .26205 .65239 L p .7 .834 .947 r
F P
0 g
s
.50324 .57374 m .5169 .56381 L .51438 .56315 L p .698 .853 .957 r
F P
0 g
s
.51438 .56315 m .49947 .5729 L .50324 .57374 L p .698 .853 .957 r
F P
0 g
s
.5467 .55418 m .5485 .56318 L .55187 .5624 L p .685 .853 .963 r
F P
0 g
s
.5485 .56318 m .5467 .55418 L .54498 .5545 L p .684 .852 .963 r
F P
0 g
s
.54498 .5545 m .54511 .56384 L .5485 .56318 L p .684 .852 .963 r
F P
0 g
s
.54841 .5538 m .55187 .5624 L .55519 .56149 L p .688 .855 .963 r
F P
0 g
s
.55187 .5624 m .54841 .5538 L .5467 .55418 L p .685 .853 .963 r
F P
0 g
s
.54511 .56384 m .54498 .5545 L .54325 .55474 L p .683 .85 .963 r
F P
0 g
s
.54325 .55474 m .54171 .56437 L .54511 .56384 L p .683 .85 .963 r
F P
0 g
s
.83258 .3515 m .81242 .36903 L .81555 .37998 L p .863 .902 .859 r
F P
0 g
s
.79521 .39629 m .81555 .37998 L .81242 .36903 L p .86 .902 .862 r
F P
0 g
s
.5501 .55336 m .55519 .56149 L .55846 .56045 L p .69 .857 .962 r
F P
0 g
s
.55519 .56149 m .5501 .55336 L .54841 .5538 L p .688 .855 .963 r
F P
0 g
s
.36794 .62068 m .38734 .61185 L .38212 .60693 L p .729 .855 .94 r
F P
0 g
s
.38212 .60693 m .36199 .61513 L .36794 .62068 L p .729 .855 .94 r
F P
0 g
s
.90617 .25851 m .88665 .27984 L .89238 .29493 L p .873 .867 .83 r
F P
0 g
s
.87257 .31446 m .89238 .29493 L .88665 .27984 L p .879 .882 .832 r
F P
0 g
s
.54171 .56437 m .54325 .55474 L .54154 .55492 L p .682 .849 .963 r
F P
0 g
s
.54154 .55492 m .53834 .56476 L .54171 .56437 L p .682 .849 .963 r
F P
0 g
s
.55176 .55286 m .55846 .56045 L .56163 .5593 L p .693 .858 .961 r
F P
0 g
s
.55846 .56045 m .55176 .55286 L .5501 .55336 L p .69 .857 .962 r
F P
0 g
s
.45392 .58925 m .47187 .57895 L .46845 .57695 L p .738 .865 .94 r
F P
0 g
s
.46845 .57695 m .44961 .58685 L .45392 .58925 L p .738 .865 .94 r
F P
0 g
s
.7748 .41261 m .7543 .42878 L .75567 .43724 L p .858 .918 .87 r
F P
0 g
s
.73504 .45189 m .75567 .43724 L .7543 .42878 L p .851 .915 .876 r
F P
0 g
s
.73504 .45189 m .71427 .46556 L .71448 .47255 L p .838 .919 .889 r
F P
0 g
s
.69365 .48427 m .71448 .47255 L .71427 .46556 L p .824 .911 .897 r
F P
0 g
s
.53834 .56476 m .54154 .55492 L .53985 .55502 L p .682 .848 .963 r
F P
0 g
s
.53985 .55502 m .535 .56502 L .53834 .56476 L p .682 .848 .963 r
F P
0 g
s
.55337 .55229 m .56163 .5593 L .56471 .55804 L p .696 .86 .96 r
F P
0 g
s
.56163 .5593 m .55337 .55229 L .55176 .55286 L p .693 .858 .961 r
F P
0 g
s
.58186 .54668 m .59995 .54564 L .60241 .54276 L p .75 .889 .942 r
F P
0 g
s
.59995 .54564 m .58186 .54668 L .57999 .5485 L p .744 .889 .945 r
F P
0 g
s
.47573 .58068 m .49278 .57066 L .48989 .56925 L p .724 .861 .946 r
F P
0 g
s
.48989 .56925 m .47187 .57895 L .47573 .58068 L p .724 .861 .946 r
F P
0 g
s
.28192 .64573 m .30186 .63862 L .29505 .63042 L p .709 .839 .945 r
F P
0 g
s
.29505 .63042 m .27442 .63679 L .28192 .64573 L p .709 .839 .945 r
F P
0 g
s
.535 .56502 m .53985 .55502 L .53818 .55506 L p .682 .847 .962 r
F P
0 g
s
.53818 .55506 m .53172 .56515 L .535 .56502 L p .682 .847 .962 r
F P
0 g
s
.60627 .53694 m .62632 .53138 L .62816 .52745 L p .784 .903 .925 r
F P
0 g
s
.62632 .53138 m .60627 .53694 L .60453 .53985 L p .779 .905 .929 r
F P
0 g
s
.55493 .55168 m .56471 .55804 L .56766 .55666 L p .7 .861 .959 r
F P
0 g
s
.56471 .55804 m .55493 .55168 L .55337 .55229 L p .696 .86 .96 r
F P
0 g
s
.49947 .5729 m .51438 .56315 L .51205 .56237 L p .7 .853 .955 r
F P
0 g
s
.51205 .56237 m .49598 .57188 L .49947 .5729 L p .7 .853 .955 r
F P
0 g
s
.43084 .59686 m .44961 .58685 L .44588 .5841 L p .741 .864 .938 r
F P
0 g
s
.44588 .5841 m .42631 .5936 L .43084 .59686 L p .741 .864 .938 r
F P
0 g
s
.53172 .56515 m .53818 .55506 L .53656 .55503 L p .682 .846 .962 r
F P
0 g
s
.53656 .55503 m .52852 .56515 L .53172 .56515 L p .682 .846 .962 r
F P
0 g
s
.55643 .55101 m .56766 .55666 L .57048 .55519 L p .704 .862 .957 r
F P
0 g
s
.56766 .55666 m .55643 .55101 L .55493 .55168 L p .7 .861 .959 r
F P
0 g
s
.38734 .61185 m .4068 .60286 L .4023 .59857 L p .732 .857 .94 r
F P
0 g
s
.4023 .59857 m .38212 .60693 L .38734 .61185 L p .732 .857 .94 r
F P
0 g
s
.52852 .56515 m .53656 .55503 L .53499 .55492 L p .682 .845 .961 r
F P
0 g
s
.53499 .55492 m .52542 .56501 L .52852 .56515 L p .682 .845 .961 r
F P
0 g
s
.69365 .48427 m .67271 .49527 L .67219 .50072 L p .813 .91 .906 r
F P
0 g
s
.65129 .51045 m .67219 .50072 L .67271 .49527 L p .808 .905 .909 r
F P
0 g
s
.67219 .50072 m .65129 .51045 L .65025 .51517 L p .806 .91 .911 r
F P
0 g
s
.62949 .52359 m .65025 .51517 L .65129 .51045 L p .801 .906 .914 r
F P
0 g
s
.65025 .51517 m .62949 .52359 L .62816 .52745 L p .799 .91 .917 r
F P
0 g
s
.55786 .55029 m .57048 .55519 L .57313 .55363 L p .708 .863 .956 r
F P
0 g
s
.57048 .55519 m .55786 .55029 L .55643 .55101 L p .704 .862 .957 r
F P
0 g
s
.58351 .54483 m .60241 .54276 L .60453 .53985 L p .754 .888 .939 r
F P
0 g
s
.60241 .54276 m .58351 .54483 L .58186 .54668 L p .75 .889 .942 r
F P
0 g
s
.30186 .63862 m .32185 .63109 L .31571 .6236 L p .717 .844 .943 r
F P
0 g
s
.31571 .6236 m .29505 .63042 L .30186 .63862 L p .717 .844 .943 r
F P
0 g
s
.81242 .36903 m .7922 .38634 L .79521 .39629 L p .86 .902 .862 r
F P
0 g
s
.7748 .41261 m .79521 .39629 L .7922 .38634 L p .86 .904 .863 r
F P
0 g
s
.88665 .27984 m .86702 .30065 L .87257 .31446 L p .879 .882 .832 r
F P
0 g
s
.85263 .33338 m .87257 .31446 L .86702 .30065 L p .874 .885 .839 r
F P
0 g
s
.52542 .56501 m .53499 .55492 L .53348 .55475 L p .683 .845 .961 r
F P
0 g
s
.53348 .55475 m .52244 .56474 L .52542 .56501 L p .683 .845 .961 r
F P
0 g
s
.5592 .54952 m .57313 .55363 L .57561 .55198 L p .711 .864 .954 r
F P
0 g
s
.57313 .55363 m .5592 .54952 L .55786 .55029 L p .708 .863 .956 r
F P
0 g
s
.49598 .57188 m .51205 .56237 L .50992 .56146 L p .702 .852 .954 r
F P
0 g
s
.50992 .56146 m .49278 .57066 L .49598 .57188 L p .702 .852 .954 r
F P
0 g
s
.7543 .42878 m .7337 .44434 L .73504 .45189 L p .851 .915 .876 r
F P
0 g
s
.71427 .46556 m .73504 .45189 L .7337 .44434 L p .839 .909 .885 r
F P
0 g
s
.71427 .46556 m .6934 .47818 L .69365 .48427 L p .824 .911 .897 r
F P
0 g
s
.67271 .49527 m .69365 .48427 L .6934 .47818 L p .815 .904 .903 r
F P
0 g
s
.60763 .53406 m .62816 .52745 L .62949 .52359 L p .787 .9 .922 r
F P
0 g
s
.62816 .52745 m .60763 .53406 L .60627 .53694 L p .784 .903 .925 r
F P
0 g
s
.47187 .57895 m .48989 .56925 L .48735 .56765 L p .726 .86 .945 r
F P
0 g
s
.48735 .56765 m .46845 .57695 L .47187 .57895 L p .726 .86 .945 r
F P
0 g
s
.15162 .66953 m .17217 .66195 L .16324 .64698 L p .565 .605 .852 r
F P
0 g
s
.16324 .64698 m .14297 .64169 L .15162 .66953 L p .565 .605 .852 r
F P
0 g
s
.52244 .56474 m .53348 .55475 L .53204 .55451 L p .684 .844 .96 r
F P
0 g
s
.53204 .55451 m .51959 .56434 L .52244 .56474 L p .684 .844 .96 r
F P
0 g
s
.4068 .60286 m .42631 .5936 L .42251 .58992 L p .736 .86 .939 r
F P
0 g
s
.42251 .58992 m .4023 .59857 L .4068 .60286 L p .736 .86 .939 r
F P
0 g
s
.44961 .58685 m .46845 .57695 L .4655 .57469 L p .739 .864 .939 r
F P
0 g
s
.4655 .57469 m .44588 .5841 L .44961 .58685 L p .739 .864 .939 r
F P
0 g
s
.32185 .63109 m .3419 .62321 L .33642 .61642 L p .723 .848 .941 r
F P
0 g
s
.33642 .61642 m .31571 .6236 L .32185 .63109 L p .723 .848 .941 r
F P
0 g
s
.56046 .54872 m .57561 .55198 L .57791 .55027 L p .715 .864 .952 r
F P
0 g
s
.57561 .55198 m .56046 .54872 L .5592 .54952 L p .711 .864 .954 r
F P
0 g
s
.58491 .54295 m .60453 .53985 L .60627 .53694 L p .758 .887 .936 r
F P
0 g
s
.60453 .53985 m .58491 .54295 L .58351 .54483 L p .754 .888 .939 r
F P
0 g
s
.17217 .66195 m .1925 .65761 L .18413 .64484 L p .647 .781 .946 r
F P
0 g
s
.18413 .64484 m .16324 .64698 L .17217 .66195 L p .647 .781 .946 r
F P
0 g
s
.51959 .56434 m .53204 .55451 L .53068 .5542 L p .684 .843 .959 r
F P
0 g
s
.53068 .5542 m .5169 .56381 L .51959 .56434 L p .684 .843 .959 r
F P
0 g
s
.56161 .54789 m .57791 .55027 L .57999 .5485 L p .719 .864 .95 r
F P
0 g
s
.57791 .55027 m .56161 .54789 L .56046 .54872 L p .715 .864 .952 r
F P
0 g
s
.49278 .57066 m .50992 .56146 L .508 .56043 L p .704 .851 .953 r
F P
0 g
s
.508 .56043 m .48989 .56925 L .49278 .57066 L p .704 .851 .953 r
F P
0 g
s
.7922 .38634 m .77192 .40363 L .7748 .41261 L p .86 .904 .863 r
F P
0 g
s
.7543 .42878 m .7748 .41261 L .77192 .40363 L p .858 .904 .865 r
F P
0 g
s
.86702 .30065 m .84729 .32071 L .85263 .33338 L p .874 .885 .839 r
F P
0 g
s
.83258 .3515 m .85263 .33338 L .84729 .32071 L p .867 .885 .847 r
F P
0 g
s
.3419 .62321 m .36199 .61513 L .35715 .60903 L p .727 .851 .94 r
F P
0 g
s
.35715 .60903 m .33642 .61642 L .3419 .62321 L p .727 .851 .94 r
F P
0 g
s
.1925 .65761 m .21288 .65315 L .20515 .6413 L p .667 .813 .954 r
F P
0 g
s
.20515 .6413 m .18413 .64484 L .1925 .65761 L p .667 .813 .954 r
F P
0 g
s
.67271 .49527 m .65167 .50591 L .65129 .51045 L p .808 .905 .909 r
F P
0 g
s
.63029 .51985 m .65129 .51045 L .65167 .50591 L p .803 .902 .911 r
F P
0 g
s
.65129 .51045 m .63029 .51985 L .62949 .52359 L p .801 .906 .914 r
F P
0 g
s
.42631 .5936 m .44588 .5841 L .44276 .58101 L p .741 .863 .937 r
F P
0 g
s
.44276 .58101 m .42251 .58992 L .42631 .5936 L p .741 .863 .937 r
F P
0 g
s
.5169 .56381 m .53068 .5542 L .52941 .55383 L p .685 .842 .959 r
F P
0 g
s
.52941 .55383 m .51438 .56315 L .5169 .56381 L p .685 .842 .959 r
F P
0 g
s
.56267 .54703 m .57999 .5485 L .58186 .54668 L p .722 .864 .948 r
F P
0 g
s
.57999 .5485 m .56267 .54703 L .56161 .54789 L p .719 .864 .95 r
F P
0 g
s
.58606 .54108 m .60627 .53694 L .60763 .53406 L p .762 .885 .933 r
F P
0 g
s
.60627 .53694 m .58606 .54108 L .58491 .54295 L p .758 .887 .936 r
F P
0 g
s
.7337 .44434 m .713 .4589 L .71427 .46556 L p .839 .909 .885 r
F P
0 g
s
.6934 .47818 m .71427 .46556 L .713 .4589 L p .825 .903 .894 r
F P
0 g
s
.6086 .53122 m .62949 .52359 L .63029 .51985 L p .79 .897 .919 r
F P
0 g
s
.62949 .52359 m .6086 .53122 L .60763 .53406 L p .787 .9 .922 r
F P
0 g
s
.46845 .57695 m .48735 .56765 L .48516 .56587 L p .727 .859 .944 r
F P
0 g
s
.48516 .56587 m .4655 .57469 L .46845 .57695 L p .727 .859 .944 r
F P
0 g
s
.6934 .47818 m .67243 .49006 L .67271 .49527 L p .815 .904 .903 r
F P
0 g
s
.65167 .50591 m .67271 .49527 L .67243 .49006 L p .809 .901 .906 r
F P
0 g
s
.36199 .61513 m .38212 .60693 L .37789 .6015 L p .729 .853 .94 r
F P
0 g
s
.37789 .6015 m .35715 .60903 L .36199 .61513 L p .729 .853 .94 r
F P
0 g
s
.90617 .25851 m .92542 .23463 L .9174 .22547 L p .916 .95 .804 r
F P
0 g
s
.51438 .56315 m .52941 .55383 L .52823 .55339 L p .686 .841 .958 r
F P
0 g
s
.52823 .55339 m .51205 .56237 L .51438 .56315 L p .686 .841 .958 r
F P
0 g
s
.21288 .65315 m .23334 .64818 L .22624 .6371 L p .68 .823 .952 r
F P
0 g
s
.22624 .6371 m .20515 .6413 L .21288 .65315 L p .68 .823 .952 r
F P
0 g
s
.56361 .54614 m .58186 .54668 L .58351 .54483 L p .725 .863 .946 r
F P
0 g
s
.58186 .54668 m .56361 .54614 L .56267 .54703 L p .722 .864 .948 r
F P
0 g
s
.48989 .56925 m .508 .56043 L .50631 .55928 L p .706 .85 .951 r
F P
0 g
s
.50631 .55928 m .48735 .56765 L .48989 .56925 L p .706 .85 .951 r
F P
0 g
s
.84729 .32071 m .82745 .33992 L .83258 .3515 L p .867 .885 .847 r
F P
0 g
s
.81242 .36903 m .83258 .3515 L .82745 .33992 L p .861 .885 .853 r
F P
0 g
s
.44588 .5841 m .4655 .57469 L .46304 .57216 L p .739 .863 .938 r
F P
0 g
s
.46304 .57216 m .44276 .58101 L .44588 .5841 L p .739 .863 .938 r
F P
0 g
s
.77192 .40363 m .75158 .42072 L .7543 .42878 L p .858 .904 .865 r
F P
0 g
s
.7337 .44434 m .7543 .42878 L .75158 .42072 L p .851 .903 .871 r
F P
0 g
s
.38212 .60693 m .4023 .59857 L .39866 .59382 L p .731 .855 .939 r
F P
0 g
s
.39866 .59382 m .37789 .6015 L .38212 .60693 L p .731 .855 .939 r
F P
0 g
s
.58695 .53921 m .60763 .53406 L .6086 .53122 L p .765 .883 .931 r
F P
0 g
s
.60763 .53406 m .58695 .53921 L .58606 .54108 L p .762 .885 .933 r
F P
0 g
s
.51205 .56237 m .52823 .55339 L .52716 .55289 L p .687 .84 .957 r
F P
0 g
s
.52716 .55289 m .50992 .56146 L .51205 .56237 L p .687 .84 .957 r
F P
0 g
s
.23334 .64818 m .25385 .64271 L .24737 .63239 L p .69 .829 .95 r
F P
0 g
s
.24737 .63239 m .22624 .6371 L .23334 .64818 L p .69 .829 .95 r
F P
0 g
s
.56443 .54524 m .58351 .54483 L .58491 .54295 L p .728 .863 .945 r
F P
0 g
s
.58351 .54483 m .56443 .54524 L .56361 .54614 L p .725 .863 .946 r
F P
0 g
s
.713 .4589 m .6922 .47239 L .6934 .47818 L p .825 .903 .894 r
F P
0 g
s
.67243 .49006 m .6934 .47818 L .6922 .47239 L p .815 .898 .9 r
F P
0 g
s
.4023 .59857 m .42251 .58992 L .41946 .58584 L p .736 .858 .938 r
F P
0 g
s
.41946 .58584 m .39866 .59382 L .4023 .59857 L p .736 .858 .938 r
F P
0 g
s
.65167 .50591 m .63055 .51624 L .63029 .51985 L p .803 .902 .911 r
F P
0 g
s
.60917 .52846 m .63029 .51985 L .63055 .51624 L p .792 .894 .917 r
F P
0 g
s
.63029 .51985 m .60917 .52846 L .6086 .53122 L p .79 .897 .919 r
F P
0 g
s
.48735 .56765 m .50631 .55928 L .50487 .55802 L p .707 .849 .95 r
F P
0 g
s
.50487 .55802 m .48516 .56587 L .48735 .56765 L p .707 .849 .95 r
F P
0 g
s
.67243 .49006 m .65139 .50159 L .65167 .50591 L p .809 .901 .906 r
F P
0 g
s
.63055 .51624 m .65167 .50591 L .65139 .50159 L p .805 .898 .908 r
F P
0 g
s
.4655 .57469 m .48516 .56587 L .48334 .5639 L p .728 .857 .942 r
F P
0 g
s
.48334 .5639 m .46304 .57216 L .4655 .57469 L p .728 .857 .942 r
F P
0 g
s
.54488 .54431 m .5467 .55418 L .54841 .5538 L p .69 .837 .954 r
F P
0 g
s
.5467 .55418 m .54488 .54431 L .54485 .54431 L p .689 .836 .954 r
F P
0 g
s
.54485 .54431 m .54498 .5545 L .5467 .55418 L p .689 .836 .954 r
F P
0 g
s
.54491 .5443 m .54841 .5538 L .5501 .55336 L p .691 .837 .953 r
F P
0 g
s
.54841 .5538 m .54491 .5443 L .54488 .54431 L p .69 .837 .954 r
F P
0 g
s
.25385 .64271 m .27442 .63679 L .26853 .62722 L p .699 .834 .947 r
F P
0 g
s
.26853 .62722 m .24737 .63239 L .25385 .64271 L p .699 .834 .947 r
F P
0 g
s
.54498 .5545 m .54485 .54431 L .54482 .54432 L p .689 .836 .954 r
F P
0 g
s
.54482 .54432 m .54325 .55474 L .54498 .5545 L p .689 .836 .954 r
F P
0 g
s
.82745 .33992 m .80753 .3585 L .81242 .36903 L p .861 .885 .853 r
F P
0 g
s
.7922 .38634 m .81242 .36903 L .80753 .3585 L p .859 .887 .856 r
F P
0 g
s
.54495 .54429 m .5501 .55336 L .55176 .55286 L p .692 .838 .953 r
F P
0 g
s
.5501 .55336 m .54495 .54429 L .54491 .5443 L p .691 .837 .953 r
F P
0 g
s
.50992 .56146 m .52716 .55289 L .5262 .55233 L p .687 .839 .956 r
F P
0 g
s
.5262 .55233 m .508 .56043 L .50992 .56146 L p .687 .839 .956 r
F P
0 g
s
.54325 .55474 m .54482 .54432 L .54478 .54432 L p .688 .835 .954 r
F P
0 g
s
.54478 .54432 m .54154 .55492 L .54325 .55474 L p .688 .835 .954 r
F P
0 g
s
.56513 .54433 m .58491 .54295 L .58606 .54108 L p .73 .862 .943 r
F P
0 g
s
.58491 .54295 m .56513 .54433 L .56443 .54524 L p .728 .863 .945 r
F P
0 g
s
.54498 .54428 m .55176 .55286 L .55337 .55229 L p .693 .838 .953 r
F P
0 g
s
.55176 .55286 m .54498 .54428 L .54495 .54429 L p .692 .838 .953 r
F P
0 g
s
.54154 .55492 m .54478 .54432 L .54475 .54432 L p .688 .835 .954 r
F P
0 g
s
.54475 .54432 m .53985 .55502 L .54154 .55492 L p .688 .835 .954 r
F P
0 g
s
.54501 .54427 m .55337 .55229 L .55493 .55168 L p .694 .838 .952 r
F P
0 g
s
.55337 .55229 m .54501 .54427 L .54498 .54428 L p .693 .838 .953 r
F P
0 g
s
.53985 .55502 m .54475 .54432 L .54472 .54432 L p .688 .835 .954 r
F P
0 g
s
.54472 .54432 m .53818 .55506 L .53985 .55502 L p .688 .835 .954 r
F P
0 g
s
.9174 .22547 m .89786 .24348 L .90617 .25851 L p .916 .95 .804 r
F P
0 g
s
.88665 .27984 m .90617 .25851 L .89786 .24348 L p .882 .871 .822 r
F P
0 g
s
.54504 .54426 m .55493 .55168 L .55643 .55101 L p .695 .839 .952 r
F P
0 g
s
.55493 .55168 m .54504 .54426 L .54501 .54427 L p .694 .838 .952 r
F P
0 g
s
.75158 .42072 m .73115 .43718 L .7337 .44434 L p .851 .903 .871 r
F P
0 g
s
.713 .4589 m .7337 .44434 L .73115 .43718 L p .839 .899 .881 r
F P
0 g
s
.42251 .58992 m .44276 .58101 L .44026 .57759 L p .741 .861 .936 r
F P
0 g
s
.44026 .57759 m .41946 .58584 L .42251 .58992 L p .741 .861 .936 r
F P
0 g
s
.53818 .55506 m .54472 .54432 L .54469 .54432 L p .687 .834 .954 r
F P
0 g
s
.54469 .54432 m .53656 .55503 L .53818 .55506 L p .687 .834 .954 r
F P
0 g
s
.58758 .53737 m .6086 .53122 L .60917 .52846 L p .767 .882 .929 r
F P
0 g
s
.6086 .53122 m .58758 .53737 L .58695 .53921 L p .765 .883 .931 r
F P
0 g
s
.54506 .54425 m .55643 .55101 L .55786 .55029 L p .696 .839 .951 r
F P
0 g
s
.55643 .55101 m .54506 .54425 L .54504 .54426 L p .695 .839 .952 r
F P
0 g
s
.27442 .63679 m .29505 .63042 L .28973 .62159 L p .708 .839 .945 r
F P
0 g
s
.28973 .62159 m .26853 .62722 L .27442 .63679 L p .708 .839 .945 r
F P
0 g
s
.53656 .55503 m .54469 .54432 L .54466 .54432 L p .687 .834 .954 r
F P
0 g
s
.54466 .54432 m .53499 .55492 L .53656 .55503 L p .687 .834 .954 r
F P
0 g
s
.54509 .54424 m .55786 .55029 L .5592 .54952 L p .697 .839 .951 r
F P
0 g
s
.55786 .55029 m .54509 .54424 L .54506 .54425 L p .696 .839 .951 r
F P
0 g
s
.508 .56043 m .5262 .55233 L .52535 .55172 L p .688 .838 .955 r
F P
0 g
s
.52535 .55172 m .50631 .55928 L .508 .56043 L p .688 .838 .955 r
F P
0 g
s
.6922 .47239 m .67134 .48514 L .67243 .49006 L p .815 .898 .9 r
F P
0 g
s
.65139 .50159 m .67243 .49006 L .67134 .48514 L p .81 .896 .903 r
F P
0 g
s
.56571 .54341 m .58606 .54108 L .58695 .53921 L p .732 .861 .941 r
F P
0 g
s
.58606 .54108 m .56571 .54341 L .56513 .54433 L p .73 .862 .943 r
F P
0 g
s
.53499 .55492 m .54466 .54432 L .54463 .54432 L p .687 .834 .954 r
F P
0 g
s
.54463 .54432 m .53348 .55475 L .53499 .55492 L p .687 .834 .954 r
F P
0 g
s
.54512 .54422 m .5592 .54952 L .56046 .54872 L p .699 .839 .95 r
F P
0 g
s
.5592 .54952 m .54512 .54422 L .54509 .54424 L p .697 .839 .951 r
F P
0 g
s
.44276 .58101 m .46304 .57216 L .46108 .56938 L p .74 .861 .937 r
F P
0 g
s
.46108 .56938 m .44026 .57759 L .44276 .58101 L p .74 .861 .937 r
F P
0 g
s
.29505 .63042 m .31571 .6236 L .31096 .61551 L p .716 .844 .943 r
F P
0 g
s
.31096 .61551 m .28973 .62159 L .29505 .63042 L p .716 .844 .943 r
F P
0 g
s
.53348 .55475 m .54463 .54432 L .54461 .54431 L p .687 .833 .954 r
F P
0 g
s
.54461 .54431 m .53204 .55451 L .53348 .55475 L p .687 .833 .954 r
F P
0 g
s
.80753 .3585 m .78756 .37683 L .7922 .38634 L p .859 .887 .856 r
F P
0 g
s
.77192 .40363 m .7922 .38634 L .78756 .37683 L p .858 .889 .858 r
F P
0 g
s
.48516 .56587 m .50487 .55802 L .50367 .55665 L p .709 .847 .948 r
F P
0 g
s
.50367 .55665 m .48334 .5639 L .48516 .56587 L p .709 .847 .948 r
F P
0 g
s
.54514 .54421 m .56046 .54872 L .56161 .54789 L p .7 .839 .949 r
F P
0 g
s
.56046 .54872 m .54514 .54421 L .54512 .54422 L p .699 .839 .95 r
F P
0 g
s
.53204 .55451 m .54461 .54431 L .54458 .54431 L p .687 .833 .953 r
F P
0 g
s
.54458 .54431 m .53068 .5542 L .53204 .55451 L p .687 .833 .953 r
F P
0 g
s
.31571 .6236 m .33642 .61642 L .3322 .60905 L p .723 .848 .941 r
F P
0 g
s
.3322 .60905 m .31096 .61551 L .31571 .6236 L p .723 .848 .941 r
F P
0 g
s
.65139 .50159 m .63028 .5128 L .63055 .51624 L p .805 .898 .908 r
F P
0 g
s
.60934 .52578 m .63055 .51624 L .63028 .5128 L p .793 .891 .914 r
F P
0 g
s
.63055 .51624 m .60934 .52578 L .60917 .52846 L p .792 .894 .917 r
F P
0 g
s
.54516 .54419 m .56161 .54789 L .56267 .54703 L p .701 .839 .949 r
F P
0 g
s
.56161 .54789 m .54516 .54419 L .54514 .54421 L p .7 .839 .949 r
F P
0 g
s
.73115 .43718 m .71065 .45262 L .713 .4589 L p .839 .899 .881 r
F P
0 g
s
.6922 .47239 m .713 .4589 L .71065 .45262 L p .826 .895 .89 r
F P
0 g
s
.89786 .24348 m .87858 .26527 L .88665 .27984 L p .882 .871 .822 r
F P
0 g
s
.86702 .30065 m .88665 .27984 L .87858 .26527 L p .875 .864 .825 r
F P
0 g
s
.56615 .54249 m .58695 .53921 L .58758 .53737 L p .734 .86 .94 r
F P
0 g
s
.58695 .53921 m .56615 .54249 L .56571 .54341 L p .732 .861 .941 r
F P
0 g
s
.50631 .55928 m .52535 .55172 L .52463 .55105 L p .689 .836 .954 r
F P
0 g
s
.52463 .55105 m .50487 .55802 L .50631 .55928 L p .689 .836 .954 r
F P
0 g
s
.46304 .57216 m .48334 .5639 L .4819 .56177 L p .73 .856 .941 r
F P
0 g
s
.4819 .56177 m .46108 .56938 L .46304 .57216 L p .73 .856 .941 r
F P
0 g
s
.58795 .53556 m .60917 .52846 L .60934 .52578 L p .769 .879 .927 r
F P
0 g
s
.60917 .52846 m .58795 .53556 L .58758 .53737 L p .767 .882 .929 r
F P
0 g
s
.53068 .5542 m .54458 .54431 L .54456 .5443 L p .686 .832 .953 r
F P
0 g
s
.54456 .5443 m .52941 .55383 L .53068 .5542 L p .686 .832 .953 r
F P
0 g
s
.54518 .54418 m .56267 .54703 L .56361 .54614 L p .702 .838 .948 r
F P
0 g
s
.56267 .54703 m .54518 .54418 L .54516 .54419 L p .701 .839 .949 r
F P
0 g
s
.33642 .61642 m .35715 .60903 L .35344 .60238 L p .727 .85 .94 r
F P
0 g
s
.35344 .60238 m .3322 .60905 L .33642 .61642 L p .727 .85 .94 r
F P
0 g
s
.52941 .55383 m .54456 .5443 L .54454 .54429 L p .686 .832 .953 r
F P
0 g
s
.54454 .54429 m .52823 .55339 L .52941 .55383 L p .686 .832 .953 r
F P
0 g
s
.67134 .48514 m .65043 .49751 L .65139 .50159 L p .81 .896 .903 r
F P
0 g
s
.63028 .5128 m .65139 .50159 L .65043 .49751 L p .806 .893 .906 r
F P
0 g
s
.5452 .54416 m .56361 .54614 L .56443 .54524 L p .702 .838 .948 r
F P
0 g
s
.56361 .54614 m .5452 .54416 L .54518 .54418 L p .702 .838 .948 r
F P
0 g
s
.35715 .60903 m .37789 .6015 L .37469 .59558 L p .729 .852 .939 r
F P
0 g
s
.37469 .59558 m .35344 .60238 L .35715 .60903 L p .729 .852 .939 r
F P
0 g
s
.78756 .37683 m .76756 .39509 L .77192 .40363 L p .858 .889 .858 r
F P
0 g
s
.75158 .42072 m .77192 .40363 L .76756 .39509 L p .856 .89 .86 r
F P
0 g
s
.52823 .55339 m .54454 .54429 L .54452 .54428 L p .686 .831 .953 r
F P
0 g
s
.54452 .54428 m .52716 .55289 L .52823 .55339 L p .686 .831 .953 r
F P
0 g
s
.48334 .5639 m .50367 .55665 L .50273 .55519 L p .71 .845 .946 r
F P
0 g
s
.50273 .55519 m .4819 .56177 L .48334 .5639 L p .71 .845 .946 r
F P
0 g
s
.14297 .64169 m .16324 .64698 L .15643 .63305 L p .404 .653 .96 r
F P
0 g
s
.15643 .63305 m .13561 .62685 L .14297 .64169 L p .404 .653 .96 r
F P
0 g
s
.56646 .54158 m .58758 .53737 L .58795 .53556 L p .735 .859 .939 r
F P
0 g
s
.58758 .53737 m .56646 .54158 L .56615 .54249 L p .734 .86 .94 r
F P
0 g
s
.50487 .55802 m .52463 .55105 L .52404 .55034 L p .69 .834 .952 r
F P
0 g
s
.52404 .55034 m .50367 .55665 L .50487 .55802 L p .69 .834 .952 r
F P
0 g
s
.37789 .6015 m .39866 .59382 L .39593 .58862 L p .732 .854 .938 r
F P
0 g
s
.39593 .58862 m .37469 .59558 L .37789 .6015 L p .732 .854 .938 r
F P
0 g
s
.54521 .54414 m .56443 .54524 L .56513 .54433 L p .703 .838 .947 r
F P
0 g
s
.56443 .54524 m .54521 .54414 L .5452 .54416 L p .702 .838 .948 r
F P
0 g
s
.71065 .45262 m .69007 .46696 L .6922 .47239 L p .826 .895 .89 r
F P
0 g
s
.67134 .48514 m .6922 .47239 L .69007 .46696 L p .816 .892 .897 r
F P
0 g
s
.52716 .55289 m .54452 .54428 L .5445 .54427 L p .686 .83 .952 r
F P
0 g
s
.5445 .54427 m .5262 .55233 L .52716 .55289 L p .686 .83 .952 r
F P
0 g
s
.39866 .59382 m .41946 .58584 L .41718 .58138 L p .737 .856 .937 r
F P
0 g
s
.41718 .58138 m .39593 .58862 L .39866 .59382 L p .737 .856 .937 r
F P
0 g
s
.87858 .26527 m .85928 .28724 L .86702 .30065 L p .875 .864 .825 r
F P
0 g
s
.84729 .32071 m .86702 .30065 L .85928 .28724 L p .87 .865 .832 r
F P
0 g
s
.54523 .54413 m .56513 .54433 L .56571 .54341 L p .704 .837 .947 r
F P
0 g
s
.56513 .54433 m .54523 .54413 L .54521 .54414 L p .703 .838 .947 r
F P
0 g
s
.63028 .5128 m .6091 .52322 L .60934 .52578 L p .793 .891 .914 r
F P
0 g
s
.58804 .5338 m .60934 .52578 L .6091 .52322 L p .77 .877 .925 r
F P
0 g
s
.60934 .52578 m .58804 .5338 L .58795 .53556 L p .769 .879 .927 r
F P
0 g
s
.41946 .58584 m .44026 .57759 L .43842 .57385 L p .742 .859 .935 r
F P
0 g
s
.43842 .57385 m .41718 .58138 L .41946 .58584 L p .742 .859 .935 r
F P
0 g
s
.5262 .55233 m .5445 .54427 L .54448 .54426 L p .686 .829 .952 r
F P
0 g
s
.54448 .54426 m .52535 .55172 L .5262 .55233 L p .686 .829 .952 r
F P
0 g
s
.44026 .57759 m .46108 .56938 L .45965 .56636 L p .741 .859 .935 r
F P
0 g
s
.45965 .56636 m .43842 .57385 L .44026 .57759 L p .741 .859 .935 r
F P
0 g
s
.65043 .49751 m .62946 .50955 L .63028 .5128 L p .806 .893 .906 r
F P
0 g
s
.6091 .52322 m .63028 .5128 L .62946 .50955 L p .794 .887 .912 r
F P
0 g
s
.56663 .54069 m .58795 .53556 L .58804 .5338 L p .736 .858 .937 r
F P
0 g
s
.58795 .53556 m .56663 .54069 L .56646 .54158 L p .735 .859 .939 r
F P
0 g
s
.76756 .39509 m .74751 .41312 L .75158 .42072 L p .856 .89 .86 r
F P
0 g
s
.73115 .43718 m .75158 .42072 L .74751 .41312 L p .85 .89 .867 r
F P
0 g
s
.54524 .54411 m .56571 .54341 L .56615 .54249 L p .704 .837 .946 r
F P
0 g
s
.56571 .54341 m .54524 .54411 L .54523 .54413 L p .704 .837 .947 r
F P
0 g
s
.50367 .55665 m .52404 .55034 L .52357 .54958 L p .691 .832 .951 r
F P
0 g
s
.52357 .54958 m .50273 .55519 L .50367 .55665 L p .691 .832 .951 r
F P
0 g
s
.46108 .56938 m .4819 .56177 L .48086 .55947 L p .731 .853 .939 r
F P
0 g
s
.48086 .55947 m .45965 .56636 L .46108 .56938 L p .731 .853 .939 r
F P
0 g
s
.69007 .46696 m .66945 .48053 L .67134 .48514 L p .816 .892 .897 r
F P
0 g
s
.65043 .49751 m .67134 .48514 L .66945 .48053 L p .811 .891 .901 r
F P
0 g
s
.52535 .55172 m .54448 .54426 L .54447 .54425 L p .687 .829 .951 r
F P
0 g
s
.54447 .54425 m .52463 .55105 L .52535 .55172 L p .687 .829 .951 r
F P
0 g
s
.4819 .56177 m .50273 .55519 L .50205 .55363 L p .711 .842 .945 r
F P
0 g
s
.50205 .55363 m .48086 .55947 L .4819 .56177 L p .711 .842 .945 r
F P
0 g
s
.54524 .54409 m .56615 .54249 L .56646 .54158 L p .705 .837 .946 r
F P
0 g
s
.56615 .54249 m .54524 .54409 L .54524 .54411 L p .704 .837 .946 r
F P
0 g
s
.85928 .28724 m .83989 .30847 L .84729 .32071 L p .87 .865 .832 r
F P
0 g
s
.82745 .33992 m .84729 .32071 L .83989 .30847 L p .863 .866 .84 r
F P
0 g
s
.52463 .55105 m .54447 .54425 L .54446 .54423 L p .687 .828 .951 r
F P
0 g
s
.54446 .54423 m .52404 .55034 L .52463 .55105 L p .687 .828 .951 r
F P
0 g
s
.54525 .54408 m .56646 .54158 L .56663 .54069 L p .705 .837 .945 r
F P
0 g
s
.56646 .54158 m .54525 .54408 L .54524 .54409 L p .705 .837 .946 r
F P
0 g
s
.6091 .52322 m .58786 .5321 L .58804 .5338 L p .77 .877 .925 r
F P
0 g
s
.56667 .53981 m .58804 .5338 L .58786 .5321 L p .737 .857 .936 r
F P
0 g
s
.58804 .5338 m .56667 .53981 L .56663 .54069 L p .736 .858 .937 r
F P
0 g
s
.50273 .55519 m .52357 .54958 L .52324 .54878 L p .692 .83 .949 r
F P
0 g
s
.52324 .54878 m .50205 .55363 L .50273 .55519 L p .692 .83 .949 r
F P
0 g
s
.66945 .48053 m .64879 .4937 L .65043 .49751 L p .811 .891 .901 r
F P
0 g
s
.62946 .50955 m .65043 .49751 L .64879 .4937 L p .806 .889 .904 r
F P
0 g
s
.74751 .41312 m .72739 .43047 L .73115 .43718 L p .85 .89 .867 r
F P
0 g
s
.71065 .45262 m .73115 .43718 L .72739 .43047 L p .839 .889 .877 r
F P
0 g
s
.62946 .50955 m .60845 .52078 L .6091 .52322 L p .794 .887 .912 r
F P
0 g
s
.58786 .5321 m .6091 .52322 L .60845 .52078 L p .771 .874 .923 r
F P
0 g
s
.16324 .64698 m .18413 .64484 L .17788 .63166 L p .632 .798 .962 r
F P
0 g
s
.17788 .63166 m .15643 .63305 L .16324 .64698 L p .632 .798 .962 r
F P
0 g
s
.52404 .55034 m .54446 .54423 L .54445 .54422 L p .687 .827 .95 r
F P
0 g
s
.54445 .54422 m .52357 .54958 L .52404 .55034 L p .687 .827 .95 r
F P
0 g
s
.54525 .54406 m .56663 .54069 L .56667 .53981 L p .705 .836 .945 r
F P
0 g
s
.56663 .54069 m .54525 .54406 L .54525 .54408 L p .705 .837 .945 r
F P
0 g
s
.83989 .30847 m .82041 .32879 L .82745 .33992 L p .863 .866 .84 r
F P
0 g
s
.80753 .3585 m .82745 .33992 L .82041 .32879 L p .858 .868 .846 r
F P
0 g
s
.52357 .54958 m .54445 .54422 L .54444 .5442 L p .688 .826 .949 r
F P
0 g
s
.54444 .5442 m .52324 .54878 L .52357 .54958 L p .688 .826 .949 r
F P
0 g
s
.64879 .4937 m .62811 .50651 L .62946 .50955 L p .806 .889 .904 r
F P
0 g
s
.60845 .52078 m .62946 .50955 L .62811 .50651 L p .795 .883 .91 r
F P
0 g
s
.18413 .64484 m .20515 .6413 L .19944 .62887 L p .665 .816 .956 r
F P
0 g
s
.19944 .62887 m .17788 .63166 L .18413 .64484 L p .665 .816 .956 r
F P
0 g
s
.58786 .5321 m .56656 .53896 L .56667 .53981 L p .737 .857 .936 r
F P
0 g
s
.54525 .54404 m .56667 .53981 L .56656 .53896 L p .705 .836 .945 r
F P
0 g
s
.56667 .53981 m .54525 .54404 L .54525 .54406 L p .705 .836 .945 r
F P
0 g
s
.45965 .56636 m .48086 .55947 L .48022 .55701 L p .731 .851 .937 r
F P
0 g
s
.48086 .55947 m .50205 .55363 L .50164 .55198 L p .712 .84 .943 r
F P
0 g
s
.50164 .55198 m .48022 .55701 L .48086 .55947 L p .712 .84 .943 r
F P
0 g
s
.60845 .52078 m .5874 .53047 L .58786 .5321 L p .771 .874 .923 r
F P
0 g
s
.56656 .53896 m .58786 .5321 L .5874 .53047 L p .738 .855 .935 r
F P
0 g
s
.72739 .43047 m .70722 .44675 L .71065 .45262 L p .839 .889 .877 r
F P
0 g
s
.69007 .46696 m .71065 .45262 L .70722 .44675 L p .826 .887 .887 r
F P
0 g
s
.50205 .55363 m .52324 .54878 L .52305 .54795 L p .693 .828 .947 r
F P
0 g
s
.52305 .54795 m .50164 .55198 L .50205 .55363 L p .693 .828 .947 r
F P
0 g
s
.43842 .57385 m .45965 .56636 L .45875 .56311 L p .742 .857 .934 r
F P
0 g
s
.48022 .55701 m .45875 .56311 L .45965 .56636 L p .731 .851 .937 r
F P
0 g
s
.52324 .54878 m .54444 .5442 L .54444 .54419 L p .688 .825 .948 r
F P
0 g
s
.54444 .54419 m .52305 .54795 L .52324 .54878 L p .688 .825 .948 r
F P
0 g
s
.41718 .58138 m .43842 .57385 L .43724 .56981 L p .742 .857 .934 r
F P
0 g
s
.45875 .56311 m .43724 .56981 L .43842 .57385 L p .742 .857 .934 r
F P
0 g
s
.20515 .6413 m .22624 .6371 L .22105 .62542 L p .679 .823 .953 r
F P
0 g
s
.22105 .62542 m .19944 .62887 L .20515 .6413 L p .679 .823 .953 r
F P
0 g
s
.56656 .53896 m .54525 .54403 L .54525 .54404 L p .705 .836 .945 r
F P
0 g
s
.5874 .53047 m .56632 .53814 L .56656 .53896 L p .738 .855 .935 r
F P
0 g
s
.54525 .54403 m .56656 .53896 L .56632 .53814 L p .705 .836 .945 r
F P
0 g
s
.82041 .32879 m .80088 .34845 L .80753 .3585 L p .858 .868 .846 r
F P
0 g
s
.78756 .37683 m .80753 .3585 L .80088 .34845 L p .856 .871 .85 r
F P
0 g
s
.56632 .53814 m .54525 .54401 L .54525 .54403 L p .705 .836 .945 r
F P
0 g
s
.52305 .54795 m .54444 .54419 L .54444 .54417 L p .689 .824 .948 r
F P
0 g
s
.56595 .53735 m .54524 .544 L .54525 .54401 L p .706 .835 .944 r
F P
0 g
s
.54525 .54401 m .56632 .53814 L .56595 .53735 L p .706 .835 .944 r
F P
0 g
s
.54444 .54417 m .52299 .54709 L .52305 .54795 L p .689 .824 .948 r
F P
0 g
s
.52299 .54709 m .54444 .54417 L .54444 .54416 L p .689 .823 .947 r
F P
0 g
s
.56544 .5366 m .54523 .54398 L .54524 .544 L p .706 .835 .944 r
F P
0 g
s
.54524 .544 m .56595 .53735 L .56544 .5366 L p .706 .835 .944 r
F P
0 g
s
.54444 .54416 m .52307 .5462 L .52299 .54709 L p .689 .823 .947 r
F P
0 g
s
.52307 .5462 m .54444 .54416 L .54444 .54414 L p .69 .822 .946 r
F P
0 g
s
.62811 .50651 m .6074 .51849 L .60845 .52078 L p .795 .883 .91 r
F P
0 g
s
.5874 .53047 m .60845 .52078 L .6074 .51849 L p .771 .872 .921 r
F P
0 g
s
.5648 .5359 m .54522 .54397 L .54523 .54398 L p .706 .834 .944 r
F P
0 g
s
.54523 .54398 m .56544 .5366 L .5648 .5359 L p .706 .834 .944 r
F P
0 g
s
.54444 .54414 m .52329 .5453 L .52307 .5462 L p .69 .822 .946 r
F P
0 g
s
.52329 .5453 m .54444 .54414 L .54445 .54412 L p .691 .822 .945 r
F P
0 g
s
.56403 .53525 m .5452 .54396 L .54522 .54397 L p .706 .834 .943 r
F P
0 g
s
.54522 .54397 m .5648 .5359 L .56403 .53525 L p .706 .834 .943 r
F P
0 g
s
.54445 .54412 m .52365 .54438 L .52329 .5453 L p .691 .822 .945 r
F P
0 g
s
.52365 .54438 m .54445 .54412 L .54446 .5441 L p .692 .821 .945 r
F P
0 g
s
.56314 .53466 m .54519 .54395 L .5452 .54396 L p .706 .833 .943 r
F P
0 g
s
.5452 .54396 m .56403 .53525 L .56314 .53466 L p .706 .833 .943 r
F P
0 g
s
.54446 .5441 m .52414 .54346 L .52365 .54438 L p .692 .821 .945 r
F P
0 g
s
.52414 .54346 m .54446 .5441 L .54447 .54409 L p .692 .821 .944 r
F P
0 g
s
.56213 .53411 m .54517 .54394 L .54519 .54395 L p .706 .833 .943 r
F P
0 g
s
.54519 .54395 m .56314 .53466 L .56213 .53411 L p .706 .833 .943 r
F P
0 g
s
.54447 .54409 m .52476 .54253 L .52414 .54346 L p .692 .821 .944 r
F P
0 g
s
.52476 .54253 m .54447 .54409 L .54449 .54407 L p .693 .82 .944 r
F P
0 g
s
.56101 .53363 m .54515 .54393 L .54517 .54394 L p .706 .832 .942 r
F P
0 g
s
.54517 .54394 m .56213 .53411 L .56101 .53363 L p .706 .832 .942 r
F P
0 g
s
.70722 .44675 m .687 .46192 L .69007 .46696 L p .826 .887 .887 r
F P
0 g
s
.66945 .48053 m .69007 .46696 L .687 .46192 L p .816 .886 .894 r
F P
0 g
s
.54449 .54407 m .52551 .54162 L .52476 .54253 L p .693 .82 .944 r
F P
0 g
s
.52551 .54162 m .54449 .54407 L .5445 .54405 L p .693 .82 .943 r
F P
0 g
s
.55979 .53321 m .54512 .54392 L .54515 .54393 L p .706 .831 .942 r
F P
0 g
s
.54515 .54393 m .56101 .53363 L .55979 .53321 L p .706 .831 .942 r
F P
0 g
s
.5445 .54405 m .52639 .54072 L .52551 .54162 L p .693 .82 .943 r
F P
0 g
s
.52639 .54072 m .5445 .54405 L .54452 .54404 L p .694 .82 .943 r
F P
0 g
s
.55847 .53286 m .5451 .54391 L .54512 .54392 L p .705 .83 .942 r
F P
0 g
s
.54512 .54392 m .55979 .53321 L .55847 .53286 L p .705 .83 .942 r
F P
0 g
s
.54452 .54404 m .52738 .53983 L .52639 .54072 L p .694 .82 .943 r
F P
0 g
s
.52738 .53983 m .54452 .54404 L .54454 .54402 L p .694 .82 .942 r
F P
0 g
s
.55707 .53258 m .54507 .54391 L .5451 .54391 L p .705 .829 .941 r
F P
0 g
s
.5451 .54391 m .55847 .53286 L .55707 .53258 L p .705 .829 .941 r
F P
0 g
s
.54454 .54402 m .52849 .53897 L .52738 .53983 L p .694 .82 .942 r
F P
0 g
s
.52849 .53897 m .54454 .54402 L .54457 .54401 L p .695 .82 .942 r
F P
0 g
s
.55558 .53236 m .54505 .5439 L .54507 .54391 L p .705 .828 .941 r
F P
0 g
s
.54507 .54391 m .55707 .53258 L .55558 .53236 L p .705 .828 .941 r
F P
0 g
s
.54457 .54401 m .52969 .53814 L .52849 .53897 L p .695 .82 .942 r
F P
0 g
s
.52969 .53814 m .54457 .54401 L .54459 .54399 L p .695 .82 .942 r
F P
0 g
s
.39593 .58862 m .41718 .58138 L .4157 .57655 L p .737 .855 .935 r
F P
0 g
s
.43724 .56981 m .4157 .57655 L .41718 .58138 L p .742 .857 .934 r
F P
0 g
s
.55403 .53221 m .54502 .5439 L .54505 .5439 L p .704 .827 .941 r
F P
0 g
s
.54505 .5439 m .55558 .53236 L .55403 .53221 L p .704 .827 .941 r
F P
0 g
s
.54459 .54399 m .531 .53735 L .52969 .53814 L p .695 .82 .942 r
F P
0 g
s
.531 .53735 m .54459 .54399 L .54462 .54398 L p .696 .82 .942 r
F P
0 g
s
.55242 .53214 m .54499 .5439 L .54502 .5439 L p .703 .826 .941 r
F P
0 g
s
.54502 .5439 m .55403 .53221 L .55242 .53214 L p .703 .826 .941 r
F P
0 g
s
.54462 .54398 m .5324 .53659 L .531 .53735 L p .696 .82 .942 r
F P
0 g
s
.5324 .53659 m .54462 .54398 L .54464 .54397 L p .696 .82 .942 r
F P
0 g
s
.55076 .53213 m .54496 .5439 L .54499 .5439 L p .703 .825 .94 r
F P
0 g
s
.54499 .5439 m .55242 .53214 L .55076 .53213 L p .703 .825 .94 r
F P
0 g
s
.54464 .54397 m .53387 .53589 L .5324 .53659 L p .696 .82 .942 r
F P
0 g
s
.53387 .53589 m .54464 .54397 L .54467 .54395 L p .696 .82 .941 r
F P
0 g
s
.54906 .5322 m .54492 .5439 L .54496 .5439 L p .702 .824 .94 r
F P
0 g
s
.54496 .5439 m .55076 .53213 L .54906 .5322 L p .702 .824 .94 r
F P
0 g
s
.54467 .54395 m .53542 .53523 L .53387 .53589 L p .696 .82 .941 r
F P
0 g
s
.53542 .53523 m .54467 .54395 L .5447 .54394 L p .697 .82 .941 r
F P
0 g
s
.54733 .53234 m .54489 .5439 L .54492 .5439 L p .701 .823 .94 r
F P
0 g
s
.54492 .5439 m .54906 .5322 L .54733 .53234 L p .701 .823 .94 r
F P
0 g
s
.5447 .54394 m .53702 .53463 L .53542 .53523 L p .697 .82 .941 r
F P
0 g
s
.53702 .53463 m .5447 .54394 L .54473 .54393 L p .697 .82 .941 r
F P
0 g
s
.54559 .53255 m .54486 .54391 L .54489 .5439 L p .7 .822 .94 r
F P
0 g
s
.54489 .5439 m .54733 .53234 L .54559 .53255 L p .7 .822 .94 r
F P
0 g
s
.54473 .54393 m .53868 .53409 L .53702 .53463 L p .697 .82 .941 r
F P
0 g
s
.53868 .53409 m .54473 .54393 L .54476 .54392 L p .698 .821 .941 r
F P
0 g
s
.54384 .53284 m .54483 .54391 L .54486 .54391 L p .7 .822 .94 r
F P
0 g
s
.54486 .54391 m .54559 .53255 L .54384 .53284 L p .7 .822 .94 r
F P
0 g
s
.54476 .54392 m .54037 .5336 L .53868 .53409 L p .698 .821 .941 r
F P
0 g
s
.54037 .5336 m .54476 .54392 L .5448 .54392 L p .698 .821 .941 r
F P
0 g
s
.5421 .53319 m .5448 .54392 L .54483 .54391 L p .699 .821 .941 r
F P
0 g
s
.54483 .54391 m .54384 .53284 L .5421 .53319 L p .699 .821 .941 r
F P
0 g
s
.5448 .54392 m .5421 .53319 L .54037 .5336 L p .698 .821 .941 r
F P
0 g
s
.50164 .55198 m .52305 .54795 L .52299 .54709 L p .695 .826 .946 r
F P
0 g
s
.22624 .6371 m .24737 .63239 L .24268 .62145 L p .69 .829 .95 r
F P
0 g
s
.24268 .62145 m .22105 .62542 L .22624 .6371 L p .69 .829 .95 r
F P
0 g
s
.37469 .59558 m .39593 .58862 L .39413 .58301 L p .732 .852 .937 r
F P
0 g
s
.4157 .57655 m .39413 .58301 L .39593 .58862 L p .737 .855 .935 r
F P
0 g
s
.58668 .52892 m .56595 .53735 L .56632 .53814 L p .738 .854 .934 r
F P
0 g
s
.56632 .53814 m .5874 .53047 L .58668 .52892 L p .738 .854 .934 r
F P
0 g
s
.6074 .51849 m .58668 .52892 L .5874 .53047 L p .771 .872 .921 r
F P
0 g
s
.48022 .55701 m .50164 .55198 L .50151 .55026 L p .713 .837 .941 r
F P
0 g
s
.52299 .54709 m .50151 .55026 L .50164 .55198 L p .695 .826 .946 r
F P
0 g
s
.35344 .60238 m .37469 .59558 L .37254 .5892 L p .729 .85 .938 r
F P
0 g
s
.39413 .58301 m .37254 .5892 L .37469 .59558 L p .732 .852 .937 r
F P
0 g
s
.24737 .63239 m .26853 .62722 L .26432 .61703 L p .699 .834 .947 r
F P
0 g
s
.26432 .61703 m .24268 .62145 L .24737 .63239 L p .699 .834 .947 r
F P
0 g
s
.687 .46192 m .66675 .47628 L .66945 .48053 L p .816 .886 .894 r
F P
0 g
s
.64879 .4937 m .66945 .48053 L .66675 .47628 L p .811 .885 .899 r
F P
0 g
s
.3322 .60905 m .35344 .60238 L .35093 .59522 L p .727 .849 .939 r
F P
0 g
s
.37254 .5892 m .35093 .59522 L .35344 .60238 L p .729 .85 .938 r
F P
0 g
s
.26853 .62722 m .28973 .62159 L .28598 .61215 L p .708 .839 .945 r
F P
0 g
s
.28598 .61215 m .26432 .61703 L .26853 .62722 L p .708 .839 .945 r
F P
0 g
s
.50151 .55026 m .52299 .54709 L .52307 .5462 L p .696 .824 .944 r
F P
0 g
s
.31096 .61551 m .3322 .60905 L .32929 .60113 L p .723 .847 .94 r
F P
0 g
s
.35093 .59522 m .32929 .60113 L .3322 .60905 L p .727 .849 .939 r
F P
0 g
s
.28973 .62159 m .31096 .61551 L .30764 .60683 L p .716 .843 .942 r
F P
0 g
s
.30764 .60683 m .28598 .61215 L .28973 .62159 L p .716 .843 .942 r
F P
0 g
s
.32929 .60113 m .30764 .60683 L .31096 .61551 L p .723 .847 .94 r
F P
0 g
s
.80088 .34845 m .7813 .36781 L .78756 .37683 L p .856 .871 .85 r
F P
0 g
s
.76756 .39509 m .78756 .37683 L .7813 .36781 L p .856 .874 .852 r
F P
0 g
s
.58569 .52747 m .56544 .5366 L .56595 .53735 L p .738 .852 .933 r
F P
0 g
s
.56595 .53735 m .58668 .52892 L .58569 .52747 L p .738 .852 .933 r
F P
0 g
s
.45875 .56311 m .48022 .55701 L .47998 .55443 L p .732 .849 .936 r
F P
0 g
s
.50151 .55026 m .47998 .55443 L .48022 .55701 L p .713 .837 .941 r
F P
0 g
s
.66675 .47628 m .64649 .49019 L .64879 .4937 L p .811 .885 .899 r
F P
0 g
s
.62811 .50651 m .64879 .4937 L .64649 .49019 L p .806 .884 .902 r
F P
0 g
s
.52307 .5462 m .50165 .54848 L .50151 .55026 L p .696 .824 .944 r
F P
0 g
s
.50165 .54848 m .52307 .5462 L .52329 .5453 L p .697 .822 .942 r
F P
0 g
s
.64649 .49019 m .62622 .5037 L .62811 .50651 L p .806 .884 .902 r
F P
0 g
s
.6074 .51849 m .62811 .50651 L .62622 .5037 L p .794 .879 .908 r
F P
0 g
s
.58443 .52611 m .5648 .5359 L .56544 .5366 L p .738 .85 .932 r
F P
0 g
s
.56544 .5366 m .58569 .52747 L .58443 .52611 L p .738 .85 .932 r
F P
0 g
s
.60595 .51636 m .58569 .52747 L .58668 .52892 L p .771 .868 .92 r
F P
0 g
s
.58668 .52892 m .6074 .51849 L .60595 .51636 L p .771 .868 .92 r
F P
0 g
s
.47998 .55443 m .50151 .55026 L .50165 .54848 L p .714 .835 .939 r
F P
0 g
s
.62622 .5037 m .60595 .51636 L .6074 .51849 L p .794 .879 .908 r
F P
0 g
s
.43724 .56981 m .45875 .56311 L .4584 .55965 L p .742 .855 .932 r
F P
0 g
s
.47998 .55443 m .4584 .55965 L .45875 .56311 L p .732 .849 .936 r
F P
0 g
s
.7813 .36781 m .76171 .38706 L .76756 .39509 L p .856 .874 .852 r
F P
0 g
s
.74751 .41312 m .76756 .39509 L .76171 .38706 L p .854 .876 .855 r
F P
0 g
s
.52329 .5453 m .50206 .54665 L .50165 .54848 L p .697 .822 .942 r
F P
0 g
s
.50206 .54665 m .52329 .5453 L .52365 .54438 L p .698 .821 .941 r
F P
0 g
s
.58293 .52486 m .56403 .53525 L .5648 .5359 L p .738 .848 .931 r
F P
0 g
s
.5648 .5359 m .58443 .52611 L .58293 .52486 L p .738 .848 .931 r
F P
0 g
s
.52365 .54438 m .50275 .54478 L .50206 .54665 L p .698 .821 .941 r
F P
0 g
s
.50275 .54478 m .52365 .54438 L .52414 .54346 L p .699 .819 .939 r
F P
0 g
s
.4157 .57655 m .43724 .56981 L .43674 .56548 L p .743 .855 .932 r
F P
0 g
s
.4584 .55965 m .43674 .56548 L .43724 .56981 L p .742 .855 .932 r
F P
0 g
s
.58118 .52373 m .56314 .53466 L .56403 .53525 L p .738 .845 .931 r
F P
0 g
s
.56403 .53525 m .58293 .52486 L .58118 .52373 L p .738 .845 .931 r
F P
0 g
s
.76171 .38706 m .74209 .40601 L .74751 .41312 L p .854 .876 .855 r
F P
0 g
s
.72739 .43047 m .74751 .41312 L .74209 .40601 L p .848 .878 .862 r
F P
0 g
s
.4584 .55965 m .47998 .55443 L .48016 .55172 L p .733 .846 .934 r
F P
0 g
s
.50165 .54848 m .48016 .55172 L .47998 .55443 L p .714 .835 .939 r
F P
0 g
s
.60411 .51439 m .58443 .52611 L .58569 .52747 L p .771 .865 .918 r
F P
0 g
s
.58569 .52747 m .60595 .51636 L .60411 .51439 L p .771 .865 .918 r
F P
0 g
s
.89786 .24348 m .9174 .22547 L .90543 .20069 L p .8 .748 .805 r
F P
0 g
s
.48016 .55172 m .50165 .54848 L .50206 .54665 L p .715 .832 .937 r
F P
0 g
s
.90543 .20069 m .8869 .22695 L .89786 .24348 L p .8 .748 .805 r
F P
0 g
s
.87858 .26527 m .89786 .24348 L .8869 .22695 L p .861 .827 .813 r
F P
0 g
s
.52414 .54346 m .50371 .54289 L .50275 .54478 L p .699 .819 .939 r
F P
0 g
s
.50371 .54289 m .52414 .54346 L .52476 .54253 L p .699 .818 .938 r
F P
0 g
s
.57919 .52271 m .56213 .53411 L .56314 .53466 L p .737 .843 .93 r
F P
0 g
s
.56314 .53466 m .58118 .52373 L .57919 .52271 L p .737 .843 .93 r
F P
0 g
s
.74209 .40601 m .72243 .42422 L .72739 .43047 L p .848 .878 .862 r
F P
0 g
s
.70722 .44675 m .72739 .43047 L .72243 .42422 L p .837 .878 .872 r
F P
0 g
s
.62381 .50113 m .60411 .51439 L .60595 .51636 L p .794 .875 .907 r
F P
0 g
s
.60595 .51636 m .62622 .5037 L .62381 .50113 L p .794 .875 .907 r
F P
0 g
s
.52476 .54253 m .50493 .54099 L .50371 .54289 L p .699 .818 .938 r
F P
0 g
s
.50493 .54099 m .52476 .54253 L .52551 .54162 L p .7 .816 .937 r
F P
0 g
s
.39413 .58301 m .4157 .57655 L .41504 .57138 L p .738 .853 .934 r
F P
0 g
s
.43674 .56548 m .41504 .57138 L .4157 .57655 L p .743 .855 .932 r
F P
0 g
s
.57698 .52182 m .56101 .53363 L .56213 .53411 L p .736 .84 .929 r
F P
0 g
s
.56213 .53411 m .57919 .52271 L .57698 .52182 L p .736 .84 .929 r
F P
0 g
s
.64353 .48699 m .62381 .50113 L .62622 .5037 L p .805 .879 .9 r
F P
0 g
s
.62622 .5037 m .64649 .49019 L .64353 .48699 L p .805 .879 .9 r
F P
0 g
s
.60189 .51259 m .58293 .52486 L .58443 .52611 L p .77 .861 .917 r
F P
0 g
s
.58443 .52611 m .60411 .51439 L .60189 .51259 L p .77 .861 .917 r
F P
0 g
s
.72243 .42422 m .70273 .44133 L .70722 .44675 L p .837 .878 .872 r
F P
0 g
s
.687 .46192 m .70722 .44675 L .70273 .44133 L p .825 .878 .883 r
F P
0 g
s
.50206 .54665 m .48075 .54891 L .48016 .55172 L p .715 .832 .937 r
F P
0 g
s
.48075 .54891 m .50206 .54665 L .50275 .54478 L p .715 .83 .936 r
F P
0 g
s
.8869 .22695 m .86815 .25093 L .87858 .26527 L p .861 .827 .813 r
F P
0 g
s
.85928 .28724 m .87858 .26527 L .86815 .25093 L p .867 .84 .816 r
F P
0 g
s
.66326 .47239 m .64353 .48699 L .64649 .49019 L p .81 .879 .896 r
F P
0 g
s
.64649 .49019 m .66675 .47628 L .66326 .47239 L p .81 .879 .896 r
F P
0 g
s
.52551 .54162 m .50641 .5391 L .50493 .54099 L p .7 .816 .937 r
F P
0 g
s
.50641 .5391 m .52551 .54162 L .52639 .54072 L p .701 .815 .936 r
F P
0 g
s
.43674 .56548 m .4584 .55965 L .45859 .556 L p .743 .853 .931 r
F P
0 g
s
.48016 .55172 m .45859 .556 L .4584 .55965 L p .733 .846 .934 r
F P
0 g
s
.70273 .44133 m .683 .45728 L .687 .46192 L p .825 .878 .883 r
F P
0 g
s
.66675 .47628 m .687 .46192 L .683 .45728 L p .816 .879 .891 r
F P
0 g
s
.683 .45728 m .66326 .47239 L .66675 .47628 L p .816 .879 .891 r
F P
0 g
s
.57457 .52105 m .55979 .53321 L .56101 .53363 L p .734 .837 .928 r
F P
0 g
s
.56101 .53363 m .57698 .52182 L .57457 .52105 L p .734 .837 .928 r
F P
0 g
s
.37254 .5892 m .39413 .58301 L .39328 .57701 L p .733 .85 .936 r
F P
0 g
s
.41504 .57138 m .39328 .57701 L .39413 .58301 L p .738 .853 .934 r
F P
0 g
s
.45859 .556 m .48016 .55172 L .48075 .54891 L p .733 .844 .933 r
F P
0 g
s
.52639 .54072 m .50813 .53723 L .50641 .5391 L p .701 .815 .936 r
F P
0 g
s
.50813 .53723 m .52639 .54072 L .52738 .53983 L p .701 .814 .935 r
F P
0 g
s
.57196 .52041 m .55847 .53286 L .55979 .53321 L p .733 .834 .927 r
F P
0 g
s
.55979 .53321 m .57457 .52105 L .57196 .52041 L p .733 .834 .927 r
F P
0 g
s
.52738 .53983 m .51009 .53539 L .50813 .53723 L p .701 .814 .935 r
F P
0 g
s
.51009 .53539 m .52738 .53983 L .52849 .53897 L p .701 .813 .935 r
F P
0 g
s
.59929 .51098 m .58118 .52373 L .58293 .52486 L p .769 .857 .916 r
F P
0 g
s
.58293 .52486 m .60189 .51259 L .59929 .51098 L p .769 .857 .916 r
F P
0 g
s
.50275 .54478 m .48175 .54603 L .48075 .54891 L p .715 .83 .936 r
F P
0 g
s
.48175 .54603 m .50275 .54478 L .50371 .54289 L p .716 .828 .934 r
F P
0 g
s
.86815 .25093 m .84934 .27427 L .85928 .28724 L p .867 .84 .816 r
F P
0 g
s
.83989 .30847 m .85928 .28724 L .84934 .27427 L p .864 .844 .824 r
F P
0 g
s
.56917 .51991 m .55707 .53258 L .55847 .53286 L p .731 .831 .927 r
F P
0 g
s
.55847 .53286 m .57196 .52041 L .56917 .51991 L p .731 .831 .927 r
F P
0 g
s
.35093 .59522 m .37254 .5892 L .37148 .58238 L p .73 .849 .937 r
F P
0 g
s
.39328 .57701 m .37148 .58238 L .37254 .5892 L p .733 .85 .936 r
F P
0 g
s
.62088 .49881 m .60189 .51259 L .60411 .51439 L p .792 .87 .905 r
F P
0 g
s
.60411 .51439 m .62381 .50113 L .62088 .49881 L p .792 .87 .905 r
F P
0 g
s
.52849 .53897 m .51228 .5336 L .51009 .53539 L p .701 .813 .935 r
F P
0 g
s
.51228 .5336 m .52849 .53897 L .52969 .53814 L p .702 .813 .934 r
F P
0 g
s
.41504 .57138 m .43674 .56548 L .43693 .56091 L p .744 .854 .931 r
F P
0 g
s
.45859 .556 m .43693 .56091 L .43674 .56548 L p .743 .853 .931 r
F P
0 g
s
.56622 .51954 m .55558 .53236 L .55707 .53258 L p .729 .828 .926 r
F P
0 g
s
.55707 .53258 m .56917 .51991 L .56622 .51954 L p .729 .828 .926 r
F P
0 g
s
.52969 .53814 m .51467 .53187 L .51228 .5336 L p .702 .813 .934 r
F P
0 g
s
.51467 .53187 m .52969 .53814 L .531 .53735 L p .702 .812 .933 r
F P
0 g
s
.32929 .60113 m .35093 .59522 L .34963 .58759 L p .728 .848 .938 r
F P
0 g
s
.37148 .58238 m .34963 .58759 L .35093 .59522 L p .73 .849 .937 r
F P
0 g
s
.56314 .5193 m .55403 .53221 L .55558 .53236 L p .726 .825 .926 r
F P
0 g
s
.55558 .53236 m .56622 .51954 L .56314 .5193 L p .726 .825 .926 r
F P
0 g
s
.84934 .27427 m .83044 .29671 L .83989 .30847 L p .864 .844 .824 r
F P
0 g
s
.82041 .32879 m .83989 .30847 L .83044 .29671 L p .858 .848 .832 r
F P
0 g
s
.50371 .54289 m .48316 .5431 L .48175 .54603 L p .716 .828 .934 r
F P
0 g
s
.48316 .5431 m .50371 .54289 L .50493 .54099 L p .716 .825 .933 r
F P
0 g
s
.59634 .50956 m .57919 .52271 L .58118 .52373 L p .767 .852 .915 r
F P
0 g
s
.58118 .52373 m .59929 .51098 L .59634 .50956 L p .767 .852 .915 r
F P
0 g
s
.531 .53735 m .51727 .53022 L .51467 .53187 L p .702 .812 .933 r
F P
0 g
s
.51727 .53022 m .531 .53735 L .5324 .53659 L p .702 .811 .933 r
F P
0 g
s
.48075 .54891 m .45934 .5522 L .45859 .556 L p .733 .844 .933 r
F P
0 g
s
.45934 .5522 m .48075 .54891 L .48175 .54603 L p .733 .841 .931 r
F P
0 g
s
.63992 .48411 m .62088 .49881 L .62381 .50113 L p .804 .873 .898 r
F P
0 g
s
.62381 .50113 m .64353 .48699 L .63992 .48411 L p .804 .873 .898 r
F P
0 g
s
.55993 .51921 m .55242 .53214 L .55403 .53221 L p .724 .822 .926 r
F P
0 g
s
.55403 .53221 m .56314 .5193 L .55993 .51921 L p .724 .822 .926 r
F P
0 g
s
.43693 .56091 m .45859 .556 L .45934 .5522 L p .743 .851 .93 r
F P
0 g
s
.5324 .53659 m .52004 .52865 L .51727 .53022 L p .702 .811 .933 r
F P
0 g
s
.52004 .52865 m .5324 .53659 L .53387 .53589 L p .703 .811 .932 r
F P
0 g
s
.55662 .51925 m .55076 .53213 L .55242 .53214 L p .721 .82 .926 r
F P
0 g
s
.55242 .53214 m .55993 .51921 L .55662 .51925 L p .721 .82 .926 r
F P
0 g
s
.30764 .60683 m .32929 .60113 L .32773 .5927 L p .724 .846 .939 r
F P
0 g
s
.34963 .58759 m .32773 .5927 L .32929 .60113 L p .728 .848 .938 r
F P
0 g
s
.53387 .53589 m .52297 .52718 L .52004 .52865 L p .703 .811 .932 r
F P
0 g
s
.52297 .52718 m .53387 .53589 L .53542 .53523 L p .703 .81 .931 r
F P
0 g
s
.83044 .29671 m .81147 .31817 L .82041 .32879 L p .858 .848 .832 r
F P
0 g
s
.80088 .34845 m .82041 .32879 L .81147 .31817 L p .854 .851 .839 r
F P
0 g
s
.13561 .62685 m .15643 .63305 L .15182 .62034 L p .324 .81 .813 r
F P
0 g
s
.15182 .62034 m .12948 .62609 L .13561 .62685 L p .324 .81 .813 r
F P
0 g
s
.55324 .51943 m .54906 .5322 L .55076 .53213 L p .719 .817 .926 r
F P
0 g
s
.55076 .53213 m .55662 .51925 L .55324 .51943 L p .719 .817 .926 r
F P
0 g
s
.53542 .53523 m .52605 .52582 L .52297 .52718 L p .703 .81 .931 r
F P
0 g
s
.52605 .52582 m .53542 .53523 L .53702 .53463 L p .704 .81 .931 r
F P
0 g
s
.61746 .49675 m .59929 .51098 L .60189 .51259 L p .79 .864 .904 r
F P
0 g
s
.60189 .51259 m .62088 .49881 L .61746 .49675 L p .79 .864 .904 r
F P
0 g
s
.65899 .46888 m .63992 .48411 L .64353 .48699 L p .81 .873 .893 r
F P
0 g
s
.64353 .48699 m .66326 .47239 L .65899 .46888 L p .81 .873 .893 r
F P
0 g
s
.5498 .51976 m .54733 .53234 L .54906 .5322 L p .716 .815 .926 r
F P
0 g
s
.54906 .5322 m .55324 .51943 L .5498 .51976 L p .716 .815 .926 r
F P
0 g
s
.39328 .57701 m .41504 .57138 L .4152 .5659 L p .74 .851 .932 r
F P
0 g
s
.43693 .56091 m .4152 .5659 L .41504 .57138 L p .744 .854 .931 r
F P
0 g
s
.53702 .53463 m .52925 .52457 L .52605 .52582 L p .704 .81 .931 r
F P
0 g
s
.52925 .52457 m .53702 .53463 L .53868 .53409 L p .705 .81 .93 r
F P
0 g
s
.50493 .54099 m .48496 .54013 L .48316 .5431 L p .716 .825 .933 r
F P
0 g
s
.48496 .54013 m .50493 .54099 L .50641 .5391 L p .715 .823 .932 r
F P
0 g
s
.54632 .52022 m .54559 .53255 L .54733 .53234 L p .714 .813 .927 r
F P
0 g
s
.54733 .53234 m .5498 .51976 L .54632 .52022 L p .714 .813 .927 r
F P
0 g
s
.59305 .50833 m .57698 .52182 L .57919 .52271 L p .764 .848 .914 r
F P
0 g
s
.57919 .52271 m .59634 .50956 L .59305 .50833 L p .764 .848 .914 r
F P
0 g
s
.53868 .53409 m .53255 .52344 L .52925 .52457 L p .705 .81 .93 r
F P
0 g
s
.53255 .52344 m .53868 .53409 L .54037 .5336 L p .706 .81 .929 r
F P
0 g
s
.81147 .31817 m .79246 .33892 L .80088 .34845 L p .854 .851 .839 r
F P
0 g
s
.7813 .36781 m .80088 .34845 L .79246 .33892 L p .852 .854 .843 r
F P
0 g
s
.54284 .52082 m .54384 .53284 L .54559 .53255 L p .712 .812 .927 r
F P
0 g
s
.54559 .53255 m .54632 .52022 L .54284 .52082 L p .712 .812 .927 r
F P
0 g
s
.54037 .5336 m .53593 .52243 L .53255 .52344 L p .706 .81 .929 r
F P
0 g
s
.53593 .52243 m .54037 .5336 L .5421 .53319 L p .708 .81 .929 r
F P
0 g
s
.28598 .61215 m .30764 .60683 L .3058 .59761 L p .717 .843 .942 r
F P
0 g
s
.32773 .5927 m .3058 .59761 L .30764 .60683 L p .724 .846 .939 r
F P
0 g
s
.53936 .52156 m .5421 .53319 L .54384 .53284 L p .71 .811 .928 r
F P
0 g
s
.54384 .53284 m .54284 .52082 L .53936 .52156 L p .71 .811 .928 r
F P
0 g
s
.5421 .53319 m .53936 .52156 L .53593 .52243 L p .708 .81 .929 r
F P
0 g
s
.67808 .45308 m .65899 .46888 L .66326 .47239 L p .815 .872 .888 r
F P
0 g
s
.66326 .47239 m .683 .45728 L .67808 .45308 L p .815 .872 .888 r
F P
0 g
s
.79246 .33892 m .77343 .35934 L .7813 .36781 L p .852 .854 .843 r
F P
0 g
s
.76171 .38706 m .7813 .36781 L .77343 .35934 L p .852 .858 .845 r
F P
0 g
s
.48175 .54603 m .46063 .54827 L .45934 .5522 L p .733 .841 .931 r
F P
0 g
s
.46063 .54827 m .48175 .54603 L .48316 .5431 L p .733 .839 .93 r
F P
0 g
s
.26432 .61703 m .28598 .61215 L .28383 .60217 L p .709 .839 .944 r
F P
0 g
s
.3058 .59761 m .28383 .60217 L .28598 .61215 L p .717 .843 .942 r
F P
0 g
s
.50641 .5391 m .48715 .53716 L .48496 .54013 L p .715 .823 .932 r
F P
0 g
s
.48715 .53716 m .50641 .5391 L .50813 .53723 L p .715 .821 .931 r
F P
0 g
s
.77343 .35934 m .7544 .37958 L .76171 .38706 L p .852 .858 .845 r
F P
0 g
s
.74209 .40601 m .76171 .38706 L .7544 .37958 L p .851 .862 .849 r
F P
0 g
s
.58945 .5073 m .57457 .52105 L .57698 .52182 L p .762 .843 .913 r
F P
0 g
s
.57698 .52182 m .59305 .50833 L .58945 .5073 L p .762 .843 .913 r
F P
0 g
s
.69718 .43638 m .67808 .45308 L .683 .45728 L p .824 .869 .879 r
F P
0 g
s
.683 .45728 m .70273 .44133 L .69718 .43638 L p .824 .869 .879 r
F P
0 g
s
.24268 .62145 m .26432 .61703 L .26185 .60629 L p .7 .835 .947 r
F P
0 g
s
.28383 .60217 m .26185 .60629 L .26432 .61703 L p .709 .839 .944 r
F P
0 g
s
.4152 .5659 m .43693 .56091 L .43782 .55612 L p .745 .852 .93 r
F P
0 g
s
.45934 .5522 m .43782 .55612 L .43693 .56091 L p .743 .851 .93 r
F P
0 g
s
.37148 .58238 m .39328 .57701 L .39339 .57067 L p .735 .849 .934 r
F P
0 g
s
.4152 .5659 m .39339 .57067 L .39328 .57701 L p .74 .851 .932 r
F P
0 g
s
.7544 .37958 m .73535 .39943 L .74209 .40601 L p .851 .862 .849 r
F P
0 g
s
.72243 .42422 m .74209 .40601 L .73535 .39943 L p .845 .865 .857 r
F P
0 g
s
.63568 .48157 m .61746 .49675 L .62088 .49881 L p .802 .867 .896 r
F P
0 g
s
.62088 .49881 m .63992 .48411 L .63568 .48157 L p .802 .867 .896 r
F P
0 g
s
.71628 .41848 m .69718 .43638 L .70273 .44133 L p .835 .867 .868 r
F P
0 g
s
.70273 .44133 m .72243 .42422 L .71628 .41848 L p .835 .867 .868 r
F P
0 g
s
.43782 .55612 m .45934 .5522 L .46063 .54827 L p .743 .849 .929 r
F P
0 g
s
.61356 .49495 m .59634 .50956 L .59929 .51098 L p .788 .858 .902 r
F P
0 g
s
.59929 .51098 m .61746 .49675 L .61356 .49495 L p .788 .858 .902 r
F P
0 g
s
.73535 .39943 m .71628 .41848 L .72243 .42422 L p .845 .865 .857 r
F P
0 g
s
.22105 .62542 m .24268 .62145 L .23985 .60996 L p .691 .83 .95 r
F P
0 g
s
.26185 .60629 m .23985 .60996 L .24268 .62145 L p .7 .835 .947 r
F P
0 g
s
.15643 .63305 m .17788 .63166 L .17384 .61817 L p .646 .835 .973 r
F P
0 g
s
.17384 .61817 m .15182 .62034 L .15643 .63305 L p .646 .835 .973 r
F P
0 g
s
.19944 .62887 m .22105 .62542 L .21784 .61319 L p .68 .825 .953 r
F P
0 g
s
.23985 .60996 m .21784 .61319 L .22105 .62542 L p .691 .83 .95 r
F P
0 g
s
.50813 .53723 m .48972 .53421 L .48715 .53716 L p .715 .821 .931 r
F P
0 g
s
.48972 .53421 m .50813 .53723 L .51009 .53539 L p .714 .82 .93 r
F P
0 g
s
.58555 .50646 m .57196 .52041 L .57457 .52105 L p .758 .838 .912 r
F P
0 g
s
.57457 .52105 m .58945 .5073 L .58555 .50646 L p .758 .838 .912 r
F P
0 g
s
.17788 .63166 m .19944 .62887 L .19584 .61594 L p .667 .821 .957 r
F P
0 g
s
.19584 .61594 m .17384 .61817 L .17788 .63166 L p .667 .821 .957 r
F P
0 g
s
.21784 .61319 m .19584 .61594 L .19944 .62887 L p .68 .825 .953 r
F P
0 g
s
.48316 .5431 m .46247 .54424 L .46063 .54827 L p .733 .839 .93 r
F P
0 g
s
.46247 .54424 m .48316 .5431 L .48496 .54013 L p .732 .837 .93 r
F P
0 g
s
.34963 .58759 m .37148 .58238 L .37152 .57517 L p .732 .848 .936 r
F P
0 g
s
.39339 .57067 m .37152 .57517 L .37148 .58238 L p .735 .849 .934 r
F P
0 g
s
.65396 .46577 m .63568 .48157 L .63992 .48411 L p .808 .866 .891 r
F P
0 g
s
.63992 .48411 m .65899 .46888 L .65396 .46577 L p .808 .866 .891 r
F P
0 g
s
.51009 .53539 m .49265 .53131 L .48972 .53421 L p .714 .82 .93 r
F P
0 g
s
.49265 .53131 m .51009 .53539 L .51228 .5336 L p .714 .818 .93 r
F P
0 g
s
.58138 .50582 m .56917 .51991 L .57196 .52041 L p .755 .833 .912 r
F P
0 g
s
.57196 .52041 m .58555 .50646 L .58138 .50582 L p .755 .833 .912 r
F P
0 g
s
.6092 .49342 m .59305 .50833 L .59634 .50956 L p .785 .852 .901 r
F P
0 g
s
.59634 .50956 m .61356 .49495 L .6092 .49342 L p .785 .852 .901 r
F P
0 g
s
.39339 .57067 m .4152 .5659 L .41619 .56017 L p .741 .851 .931 r
F P
0 g
s
.43782 .55612 m .41619 .56017 L .4152 .5659 L p .745 .852 .93 r
F P
0 g
s
.51228 .5336 m .49591 .52848 L .49265 .53131 L p .714 .818 .93 r
F P
0 g
s
.49591 .52848 m .51228 .5336 L .51467 .53187 L p .713 .816 .929 r
F P
0 g
s
.63085 .47936 m .61356 .49495 L .61746 .49675 L p .8 .861 .894 r
F P
0 g
s
.61746 .49675 m .63568 .48157 L .63085 .47936 L p .8 .861 .894 r
F P
0 g
s
.46063 .54827 m .43939 .55115 L .43782 .55612 L p .743 .849 .929 r
F P
0 g
s
.43939 .55115 m .46063 .54827 L .46247 .54424 L p .743 .848 .928 r
F P
0 g
s
.57696 .50538 m .56622 .51954 L .56917 .51991 L p .751 .829 .912 r
F P
0 g
s
.56917 .51991 m .58138 .50582 L .57696 .50538 L p .751 .829 .912 r
F P
0 g
s
.8869 .22695 m .90543 .20069 L .89204 .19168 L p .909 .888 .799 r
F P
0 g
s
.48496 .54013 m .46485 .54016 L .46247 .54424 L p .732 .837 .93 r
F P
0 g
s
.46485 .54016 m .48496 .54013 L .48715 .53716 L p .731 .835 .929 r
F P
0 g
s
.67227 .44933 m .65396 .46577 L .65899 .46888 L p .814 .864 .885 r
F P
0 g
s
.65899 .46888 m .67808 .45308 L .67227 .44933 L p .814 .864 .885 r
F P
0 g
s
.32773 .5927 m .34963 .58759 L .34957 .57954 L p .729 .848 .937 r
F P
0 g
s
.37152 .57517 m .34957 .57954 L .34963 .58759 L p .732 .848 .936 r
F P
0 g
s
.41619 .56017 m .43782 .55612 L .43939 .55115 L p .745 .852 .929 r
F P
0 g
s
.51467 .53187 m .4995 .52575 L .49591 .52848 L p .713 .816 .929 r
F P
0 g
s
.4995 .52575 m .51467 .53187 L .51727 .53022 L p .713 .814 .928 r
F P
0 g
s
.57233 .50515 m .56314 .5193 L .56622 .51954 L p .747 .824 .912 r
F P
0 g
s
.56622 .51954 m .57696 .50538 L .57233 .50515 L p .747 .824 .912 r
F P
0 g
s
.60442 .49216 m .58945 .5073 L .59305 .50833 L p .782 .846 .9 r
F P
0 g
s
.59305 .50833 m .6092 .49342 L .60442 .49216 L p .782 .846 .9 r
F P
0 g
s
.51727 .53022 m .50339 .52312 L .4995 .52575 L p .713 .814 .928 r
F P
0 g
s
.50339 .52312 m .51727 .53022 L .52004 .52865 L p .712 .813 .927 r
F P
0 g
s
.69061 .43193 m .67227 .44933 L .67808 .45308 L p .822 .86 .875 r
F P
0 g
s
.67808 .45308 m .69718 .43638 L .69061 .43193 L p .822 .86 .875 r
F P
0 g
s
.56752 .50512 m .55993 .51921 L .56314 .5193 L p .743 .82 .912 r
F P
0 g
s
.56314 .5193 m .57233 .50515 L .56752 .50512 L p .743 .82 .912 r
F P
0 g
s
.89204 .19168 m .87359 .21269 L .8869 .22695 L p .909 .888 .799 r
F P
0 g
s
.86815 .25093 m .8869 .22695 L .87359 .21269 L p .867 .825 .805 r
F P
0 g
s
.48715 .53716 m .46775 .53606 L .46485 .54016 L p .731 .835 .929 r
F P
0 g
s
.46775 .53606 m .48715 .53716 L .48972 .53421 L p .73 .833 .929 r
F P
0 g
s
.37152 .57517 m .39339 .57067 L .39448 .56402 L p .736 .849 .933 r
F P
0 g
s
.41619 .56017 m .39448 .56402 L .39339 .57067 L p .741 .851 .931 r
F P
0 g
s
.3058 .59761 m .32773 .5927 L .32756 .58382 L p .725 .847 .939 r
F P
0 g
s
.34957 .57954 m .32756 .58382 L .32773 .5927 L p .729 .848 .937 r
F P
0 g
s
.6482 .46308 m .63085 .47936 L .63568 .48157 L p .806 .859 .888 r
F P
0 g
s
.63568 .48157 m .65396 .46577 L .6482 .46308 L p .806 .859 .888 r
F P
0 g
s
.52004 .52865 m .50755 .52063 L .50339 .52312 L p .712 .813 .927 r
F P
0 g
s
.50755 .52063 m .52004 .52865 L .52297 .52718 L p .712 .811 .926 r
F P
0 g
s
.56255 .50529 m .55662 .51925 L .55993 .51921 L p .739 .816 .913 r
F P
0 g
s
.55993 .51921 m .56752 .50512 L .56255 .50529 L p .739 .816 .913 r
F P
0 g
s
.46247 .54424 m .44165 .54606 L .43939 .55115 L p .743 .848 .928 r
F P
0 g
s
.44165 .54606 m .46247 .54424 L .46485 .54016 L p .743 .847 .928 r
F P
0 g
s
.62543 .4775 m .6092 .49342 L .61356 .49495 L p .797 .854 .893 r
F P
0 g
s
.61356 .49495 m .63085 .47936 L .62543 .4775 L p .797 .854 .893 r
F P
0 g
s
.87359 .21269 m .85541 .23727 L .86815 .25093 L p .867 .825 .805 r
F P
0 g
s
.84934 .27427 m .86815 .25093 L .85541 .23727 L p .861 .821 .808 r
F P
0 g
s
.70896 .41329 m .69061 .43193 L .69718 .43638 L p .833 .856 .863 r
F P
0 g
s
.69718 .43638 m .71628 .41848 L .70896 .41329 L p .833 .856 .863 r
F P
0 g
s
.59923 .49118 m .58555 .50646 L .58945 .5073 L p .778 .84 .9 r
F P
0 g
s
.58945 .5073 m .60442 .49216 L .59923 .49118 L p .778 .84 .9 r
F P
0 g
s
.52297 .52718 m .51195 .5183 L .50755 .52063 L p .712 .811 .926 r
F P
0 g
s
.51195 .5183 m .52297 .52718 L .52605 .52582 L p .712 .809 .925 r
F P
0 g
s
.55746 .50567 m .55324 .51943 L .55662 .51925 L p .734 .813 .913 r
F P
0 g
s
.55662 .51925 m .56255 .50529 L .55746 .50567 L p .734 .813 .913 r
F P
0 g
s
.52605 .52582 m .51657 .51612 L .51195 .5183 L p .712 .809 .925 r
F P
0 g
s
.51657 .51612 m .52605 .52582 L .52925 .52457 L p .713 .808 .924 r
F P
0 g
s
.48972 .53421 m .47115 .53197 L .46775 .53606 L p .73 .833 .929 r
F P
0 g
s
.47115 .53197 m .48972 .53421 L .49265 .53131 L p .729 .831 .928 r
F P
0 g
s
.28383 .60217 m .3058 .59761 L .30548 .58792 L p .719 .844 .941 r
F P
0 g
s
.32756 .58382 m .30548 .58792 L .3058 .59761 L p .725 .847 .939 r
F P
0 g
s
.55229 .50626 m .5498 .51976 L .55324 .51943 L p .73 .811 .914 r
F P
0 g
s
.55324 .51943 m .55746 .50567 L .55229 .50626 L p .73 .811 .914 r
F P
0 g
s
.7273 .39342 m .70896 .41329 L .71628 .41848 L p .842 .852 .852 r
F P
0 g
s
.71628 .41848 m .73535 .39943 L .7273 .39342 L p .842 .852 .852 r
F P
0 g
s
.85541 .23727 m .83721 .26184 L .84934 .27427 L p .861 .821 .808 r
F P
0 g
s
.83044 .29671 m .84934 .27427 L .83721 .26184 L p .857 .825 .816 r
F P
0 g
s
.39448 .56402 m .41619 .56017 L .41802 .55421 L p .742 .85 .93 r
F P
0 g
s
.43939 .55115 m .41802 .55421 L .41619 .56017 L p .745 .852 .929 r
F P
0 g
s
.41802 .55421 m .43939 .55115 L .44165 .54606 L p .746 .851 .928 r
F P
0 g
s
.52925 .52457 m .52138 .51412 L .51657 .51612 L p .713 .808 .924 r
F P
0 g
s
.52138 .51412 m .52925 .52457 L .53255 .52344 L p .714 .807 .923 r
F P
0 g
s
.54706 .50706 m .54632 .52022 L .5498 .51976 L p .727 .809 .916 r
F P
0 g
s
.5498 .51976 m .55229 .50626 L .54706 .50706 L p .727 .809 .916 r
F P
0 g
s
.74563 .37267 m .7273 .39342 L .73535 .39943 L p .847 .847 .843 r
F P
0 g
s
.73535 .39943 m .7544 .37958 L .74563 .37267 L p .847 .847 .843 r
F P
0 g
s
.53255 .52344 m .52634 .51231 L .52138 .51412 L p .714 .807 .923 r
F P
0 g
s
.52634 .51231 m .53255 .52344 L .53593 .52243 L p .716 .807 .921 r
F P
0 g
s
.83721 .26184 m .81896 .2855 L .83044 .29671 L p .857 .825 .816 r
F P
0 g
s
.81147 .31817 m .83044 .29671 L .81896 .2855 L p .852 .829 .825 r
F P
0 g
s
.54182 .50807 m .54284 .52082 L .54632 .52022 L p .723 .807 .917 r
F P
0 g
s
.54632 .52022 m .54706 .50706 L .54182 .50807 L p .723 .807 .917 r
F P
0 g
s
.76397 .35145 m .74563 .37267 L .7544 .37958 L p .848 .842 .839 r
F P
0 g
s
.7544 .37958 m .77343 .35934 L .76397 .35145 L p .848 .842 .839 r
F P
0 g
s
.53593 .52243 m .53143 .5107 L .52634 .51231 L p .716 .807 .921 r
F P
0 g
s
.53143 .5107 m .53593 .52243 L .53936 .52156 L p .718 .806 .92 r
F P
0 g
s
.5366 .50928 m .53936 .52156 L .54284 .52082 L p .72 .807 .919 r
F P
0 g
s
.54284 .52082 m .54182 .50807 L .5366 .50928 L p .72 .807 .919 r
F P
0 g
s
.34957 .57954 m .37152 .57517 L .37267 .56764 L p .733 .848 .935 r
F P
0 g
s
.39448 .56402 m .37267 .56764 L .37152 .57517 L p .736 .849 .933 r
F P
0 g
s
.78231 .32998 m .76397 .35145 L .77343 .35934 L p .848 .838 .836 r
F P
0 g
s
.77343 .35934 m .79246 .33892 L .78231 .32998 L p .848 .838 .836 r
F P
0 g
s
.81896 .2855 m .80065 .30811 L .81147 .31817 L p .852 .829 .825 r
F P
0 g
s
.79246 .33892 m .81147 .31817 L .80065 .30811 L p .848 .833 .832 r
F P
0 g
s
.53936 .52156 m .5366 .50928 L .53143 .5107 L p .718 .806 .92 r
F P
0 g
s
.80065 .30811 m .78231 .32998 L .79246 .33892 L p .848 .833 .832 r
F P
0 g
s
.6656 .44606 m .6482 .46308 L .65396 .46577 L p .812 .856 .881 r
F P
0 g
s
.65396 .46577 m .67227 .44933 L .6656 .44606 L p .812 .856 .881 r
F P
0 g
s
.59368 .49046 m .58138 .50582 L .58555 .50646 L p .773 .834 .899 r
F P
0 g
s
.58555 .50646 m .59923 .49118 L .59368 .49046 L p .773 .834 .899 r
F P
0 g
s
.46485 .54016 m .44458 .54087 L .44165 .54606 L p .743 .847 .928 r
F P
0 g
s
.44458 .54087 m .46485 .54016 L .46775 .53606 L p .742 .845 .928 r
F P
0 g
s
.26185 .60629 m .28383 .60217 L .28334 .5917 L p .71 .84 .944 r
F P
0 g
s
.30548 .58792 m .28334 .5917 L .28383 .60217 L p .719 .844 .941 r
F P
0 g
s
.49265 .53131 m .47504 .52793 L .47115 .53197 L p .729 .831 .928 r
F P
0 g
s
.47504 .52793 m .49265 .53131 L .49591 .52848 L p .727 .829 .928 r
F P
0 g
s
.61947 .47599 m .60442 .49216 L .6092 .49342 L p .794 .847 .891 r
F P
0 g
s
.6092 .49342 m .62543 .4775 L .61947 .47599 L p .794 .847 .891 r
F P
0 g
s
.64174 .4608 m .62543 .4775 L .63085 .47936 L p .804 .852 .886 r
F P
0 g
s
.63085 .47936 m .6482 .46308 L .64174 .4608 L p .804 .852 .886 r
F P
0 g
s
.5878 .49002 m .57696 .50538 L .58138 .50582 L p .768 .829 .899 r
F P
0 g
s
.58138 .50582 m .59368 .49046 L .5878 .49002 L p .768 .829 .899 r
F P
0 g
s
.23985 .60996 m .26185 .60629 L .26117 .59506 L p .701 .836 .947 r
F P
0 g
s
.28334 .5917 m .26117 .59506 L .26185 .60629 L p .71 .84 .944 r
F P
0 g
s
.49591 .52848 m .47938 .52398 L .47504 .52793 L p .727 .829 .928 r
F P
0 g
s
.47938 .52398 m .49591 .52848 L .4995 .52575 L p .726 .827 .927 r
F P
0 g
s
.68305 .42801 m .6656 .44606 L .67227 .44933 L p .82 .851 .871 r
F P
0 g
s
.67227 .44933 m .69061 .43193 L .68305 .42801 L p .82 .851 .871 r
F P
0 g
s
.32756 .58382 m .34957 .57954 L .35077 .57113 L p .731 .848 .936 r
F P
0 g
s
.37267 .56764 m .35077 .57113 L .34957 .57954 L p .733 .848 .935 r
F P
0 g
s
.37267 .56764 m .39448 .56402 L .39654 .55712 L p .738 .849 .932 r
F P
0 g
s
.41802 .55421 m .39654 .55712 L .39448 .56402 L p .742 .85 .93 r
F P
0 g
s
.44165 .54606 m .42068 .54809 L .41802 .55421 L p .746 .851 .928 r
F P
0 g
s
.42068 .54809 m .44165 .54606 L .44458 .54087 L p .746 .851 .928 r
F P
0 g
s
.46775 .53606 m .44817 .53564 L .44458 .54087 L p .742 .845 .928 r
F P
0 g
s
.44817 .53564 m .46775 .53606 L .47115 .53197 L p .741 .844 .928 r
F P
0 g
s
.58162 .48986 m .57233 .50515 L .57696 .50538 L p .763 .824 .9 r
F P
0 g
s
.57696 .50538 m .5878 .49002 L .58162 .48986 L p .763 .824 .9 r
F P
0 g
s
.61301 .47483 m .59923 .49118 L .60442 .49216 L p .79 .84 .89 r
F P
0 g
s
.60442 .49216 m .61947 .47599 L .61301 .47483 L p .79 .84 .89 r
F P
0 g
s
.21784 .61319 m .23985 .60996 L .23895 .598 L p .692 .832 .95 r
F P
0 g
s
.26117 .59506 m .23895 .598 L .23985 .60996 L p .701 .836 .947 r
F P
0 g
s
.39654 .55712 m .41802 .55421 L .42068 .54809 L p .743 .851 .93 r
F P
0 g
s
.4995 .52575 m .48417 .52015 L .47938 .52398 L p .726 .827 .927 r
F P
0 g
s
.48417 .52015 m .4995 .52575 L .50339 .52312 L p .725 .824 .927 r
F P
0 g
s
.70051 .40866 m .68305 .42801 L .69061 .43193 L p .83 .845 .858 r
F P
0 g
s
.69061 .43193 m .70896 .41329 L .70051 .40866 L p .83 .845 .858 r
F P
0 g
s
.6581 .44328 m .64174 .4608 L .6482 .46308 L p .81 .847 .878 r
F P
0 g
s
.6482 .46308 m .6656 .44606 L .6581 .44328 L p .81 .847 .878 r
F P
0 g
s
.19584 .61594 m .21784 .61319 L .2167 .6005 L p .682 .827 .953 r
F P
0 g
s
.23895 .598 m .2167 .6005 L .21784 .61319 L p .692 .832 .95 r
F P
0 g
s
.57519 .48998 m .56752 .50512 L .57233 .50515 L p .758 .819 .9 r
F P
0 g
s
.57233 .50515 m .58162 .48986 L .57519 .48998 L p .758 .819 .9 r
F P
0 g
s
.63461 .45896 m .61947 .47599 L .62543 .4775 L p .801 .845 .884 r
F P
0 g
s
.62543 .4775 m .64174 .4608 L .63461 .45896 L p .801 .845 .884 r
F P
0 g
s
.50339 .52312 m .48935 .51646 L .48417 .52015 L p .725 .824 .927 r
F P
0 g
s
.48935 .51646 m .50339 .52312 L .50755 .52063 L p .723 .822 .926 r
F P
0 g
s
.30548 .58792 m .32756 .58382 L .32878 .57455 L p .727 .848 .938 r
F P
0 g
s
.35077 .57113 m .32878 .57455 L .32756 .58382 L p .731 .848 .936 r
F P
0 g
s
.47115 .53197 m .4524 .53041 L .44817 .53564 L p .741 .844 .928 r
F P
0 g
s
.4524 .53041 m .47115 .53197 L .47504 .52793 L p .739 .843 .928 r
F P
0 g
s
.17384 .61817 m .19584 .61594 L .19442 .60253 L p .671 .82 .955 r
F P
0 g
s
.2167 .6005 m .19442 .60253 L .19584 .61594 L p .682 .827 .953 r
F P
0 g
s
.71799 .38801 m .70051 .40866 L .70896 .41329 L p .837 .838 .846 r
F P
0 g
s
.70896 .41329 m .7273 .39342 L .71799 .38801 L p .837 .838 .846 r
F P
0 g
s
.60607 .47404 m .59368 .49046 L .59923 .49118 L p .785 .834 .889 r
F P
0 g
s
.59923 .49118 m .61301 .47483 L .60607 .47404 L p .785 .834 .889 r
F P
0 g
s
.56855 .49038 m .56255 .50529 L .56752 .50512 L p .753 .815 .901 r
F P
0 g
s
.56752 .50512 m .57519 .48998 L .56855 .49038 L p .753 .815 .901 r
F P
0 g
s
.35077 .57113 m .37267 .56764 L .37495 .55982 L p .734 .849 .934 r
F P
0 g
s
.39654 .55712 m .37495 .55982 L .37267 .56764 L p .738 .849 .932 r
F P
0 g
s
.44458 .54087 m .42416 .54186 L .42068 .54809 L p .746 .851 .928 r
F P
0 g
s
.42416 .54186 m .44458 .54087 L .44817 .53564 L p .746 .851 .928 r
F P
0 g
s
.50755 .52063 m .49491 .51295 L .48935 .51646 L p .723 .822 .926 r
F P
0 g
s
.49491 .51295 m .50755 .52063 L .51195 .5183 L p .723 .819 .925 r
F P
0 g
s
.15182 .62034 m .17384 .61817 L .17213 .60401 L p .662 .803 .95 r
F P
0 g
s
.19442 .60253 m .17213 .60401 L .17384 .61817 L p .671 .82 .955 r
F P
0 g
s
.56174 .49106 m .55746 .50567 L .56255 .50529 L p .748 .812 .903 r
F P
0 g
s
.56255 .50529 m .56855 .49038 L .56174 .49106 L p .748 .812 .903 r
F P
0 g
s
.73546 .36639 m .71799 .38801 L .7273 .39342 L p .842 .832 .837 r
F P
0 g
s
.7273 .39342 m .74563 .37267 L .73546 .36639 L p .842 .832 .837 r
F P
0 g
s
.51195 .5183 m .5008 .50964 L .49491 .51295 L p .723 .819 .925 r
F P
0 g
s
.5008 .50964 m .51195 .5183 L .51657 .51612 L p .723 .816 .923 r
F P
0 g
s
.12948 .62609 m .15182 .62034 L .14986 .60468 L p .662 .71 .883 r
F P
0 g
s
.17213 .60401 m .14986 .60468 L .15182 .62034 L p .662 .803 .95 r
F P
0 g
s
.67452 .42465 m .6581 .44328 L .6656 .44606 L p .817 .841 .867 r
F P
0 g
s
.6656 .44606 m .68305 .42801 L .67452 .42465 L p .817 .841 .867 r
F P
0 g
s
.28334 .5917 m .30548 .58792 L .3067 .57783 L p .721 .846 .941 r
F P
0 g
s
.32878 .57455 m .3067 .57783 L .30548 .58792 L p .727 .848 .938 r
F P
0 g
s
.42068 .54809 m .39958 .55003 L .39654 .55712 L p .743 .851 .93 r
F P
0 g
s
.39958 .55003 m .42068 .54809 L .42416 .54186 L p .744 .852 .93 r
F P
0 g
s
.37495 .55982 m .39654 .55712 L .39958 .55003 L p .739 .85 .932 r
F P
0 g
s
.47504 .52793 m .45725 .52524 L .4524 .53041 L p .739 .843 .928 r
F P
0 g
s
.45725 .52524 m .47504 .52793 L .47938 .52398 L p .738 .841 .928 r
F P
0 g
s
.55482 .49202 m .55229 .50626 L .55746 .50567 L p .743 .81 .905 r
F P
0 g
s
.55746 .50567 m .56174 .49106 L .55482 .49202 L p .743 .81 .905 r
F P
0 g
s
.75296 .3442 m .73546 .36639 L .74563 .37267 L p .843 .827 .832 r
F P
0 g
s
.74563 .37267 m .76397 .35145 L .75296 .3442 L p .843 .827 .832 r
F P
0 g
s
.51657 .51612 m .50698 .50654 L .5008 .50964 L p .723 .816 .923 r
F P
0 g
s
.50698 .50654 m .51657 .51612 L .52138 .51412 L p .723 .814 .921 r
F P
0 g
s
.62687 .45757 m .61301 .47483 L .61947 .47599 L p .797 .837 .882 r
F P
0 g
s
.61947 .47599 m .63461 .45896 L .62687 .45757 L p .797 .837 .882 r
F P
0 g
s
.59872 .47361 m .5878 .49002 L .59368 .49046 L p .781 .828 .889 r
F P
0 g
s
.59368 .49046 m .60607 .47404 L .59872 .47361 L p .781 .828 .889 r
F P
0 g
s
.54782 .49327 m .54706 .50706 L .55229 .50626 L p .739 .808 .907 r
F P
0 g
s
.55229 .50626 m .55482 .49202 L .54782 .49327 L p .739 .808 .907 r
F P
0 g
s
.52138 .51412 m .51341 .50367 L .50698 .50654 L p .723 .814 .921 r
F P
0 g
s
.51341 .50367 m .52138 .51412 L .52634 .51231 L p .724 .812 .919 r
F P
0 g
s
.64982 .44102 m .63461 .45896 L .64174 .4608 L p .807 .839 .875 r
F P
0 g
s
.64174 .4608 m .6581 .44328 L .64982 .44102 L p .807 .839 .875 r
F P
0 g
s
.77047 .32167 m .75296 .3442 L .76397 .35145 L p .842 .821 .829 r
F P
0 g
s
.76397 .35145 m .78231 .32998 L .77047 .32167 L p .842 .821 .829 r
F P
0 g
s
.5408 .4948 m .54182 .50807 L .54706 .50706 L p .735 .808 .909 r
F P
0 g
s
.54706 .50706 m .54782 .49327 L .5408 .4948 L p .735 .808 .909 r
F P
0 g
s
.52634 .51231 m .52006 .50106 L .51341 .50367 L p .724 .812 .919 r
F P
0 g
s
.52006 .50106 m .52634 .51231 L .53143 .5107 L p .726 .81 .917 r
F P
0 g
s
.14986 .60468 m .1278 .60229 L .12948 .62609 L p .662 .71 .883 r
F P
0 g
s
.44817 .53564 m .42843 .53556 L .42416 .54186 L p .746 .851 .928 r
F P
0 g
s
.42843 .53556 m .44817 .53564 L .4524 .53041 L p .745 .851 .929 r
F P
0 g
s
.5338 .49661 m .5366 .50928 L .54182 .50807 L p .731 .808 .912 r
F P
0 g
s
.54182 .50807 m .5408 .4948 L .5338 .49661 L p .731 .808 .912 r
F P
0 g
s
.53143 .5107 m .52687 .4987 L .52006 .50106 L p .726 .81 .917 r
F P
0 g
s
.52687 .4987 m .53143 .5107 L .5366 .50928 L p .728 .808 .914 r
F P
0 g
s
.32878 .57455 m .35077 .57113 L .35325 .56242 L p .732 .849 .936 r
F P
0 g
s
.37495 .55982 m .35325 .56242 L .35077 .57113 L p .734 .849 .934 r
F P
0 g
s
.5366 .50928 m .5338 .49661 L .52687 .4987 L p .728 .808 .914 r
F P
0 g
s
.78799 .29869 m .77047 .32167 L .78231 .32998 L p .842 .816 .824 r
F P
0 g
s
.78231 .32998 m .80065 .30811 L .78799 .29869 L p .842 .816 .824 r
F P
0 g
s
.47938 .52398 m .46268 .52015 L .45725 .52524 L p .738 .841 .928 r
F P
0 g
s
.46268 .52015 m .47938 .52398 L .48417 .52015 L p .736 .839 .928 r
F P
0 g
s
.8749 .16816 m .85771 .19726 L .87359 .21269 L p .788 .724 .793 r
F P
0 g
s
.87359 .21269 m .89204 .19168 L .8749 .16816 L p .788 .724 .793 r
F P
0 g
s
.85541 .23727 m .87359 .21269 L .85771 .19726 L p .844 .787 .796 r
F P
0 g
s
.26117 .59506 m .28334 .5917 L .28454 .58082 L p .712 .843 .944 r
F P
0 g
s
.3067 .57783 m .28454 .58082 L .28334 .5917 L p .721 .846 .941 r
F P
0 g
s
.80549 .2749 m .78799 .29869 L .80065 .30811 L p .845 .811 .817 r
F P
0 g
s
.80065 .30811 m .81896 .2855 L .80549 .2749 L p .845 .811 .817 r
F P
0 g
s
.69098 .40464 m .67452 .42465 L .68305 .42801 L p .826 .833 .854 r
F P
0 g
s
.68305 .42801 m .70051 .40866 L .69098 .40464 L p .826 .833 .854 r
F P
0 g
s
.85771 .19726 m .84035 .22403 L .85541 .23727 L p .844 .787 .796 r
F P
0 g
s
.83721 .26184 m .85541 .23727 L .84035 .22403 L p .851 .799 .8 r
F P
0 g
s
.59098 .47355 m .58162 .48986 L .5878 .49002 L p .776 .822 .889 r
F P
0 g
s
.5878 .49002 m .59872 .47361 L .59098 .47355 L p .776 .822 .889 r
F P
0 g
s
.82295 .25 m .80549 .2749 L .81896 .2855 L p .848 .805 .808 r
F P
0 g
s
.81896 .2855 m .83721 .26184 L .82295 .25 L p .848 .805 .808 r
F P
0 g
s
.84035 .22403 m .82295 .25 L .83721 .26184 L p .851 .799 .8 r
F P
0 g
s
.61856 .45664 m .60607 .47404 L .61301 .47483 L p .793 .83 .88 r
F P
0 g
s
.61301 .47483 m .62687 .45757 L .61856 .45664 L p .793 .83 .88 r
F P
0 g
s
.48417 .52015 m .46866 .51519 L .46268 .52015 L p .736 .839 .928 r
F P
0 g
s
.46866 .51519 m .48417 .52015 L .48935 .51646 L p .735 .837 .928 r
F P
0 g
s
.42416 .54186 m .40358 .54281 L .39958 .55003 L p .744 .852 .93 r
F P
0 g
s
.40358 .54281 m .42416 .54186 L .42843 .53556 L p .744 .853 .93 r
F P
0 g
s
.35325 .56242 m .37495 .55982 L .37835 .5518 L p .736 .85 .934 r
F P
0 g
s
.39958 .55003 m .37835 .5518 L .37495 .55982 L p .739 .85 .932 r
F P
0 g
s
.58293 .47387 m .57519 .48998 L .58162 .48986 L p .77 .818 .89 r
F P
0 g
s
.58162 .48986 m .59098 .47355 L .58293 .47387 L p .77 .818 .89 r
F P
0 g
s
.4524 .53041 m .43348 .52925 L .42843 .53556 L p .745 .851 .929 r
F P
0 g
s
.43348 .52925 m .4524 .53041 L .45725 .52524 L p .744 .851 .929 r
F P
0 g
s
.23895 .598 m .26117 .59506 L .26231 .58344 L p .703 .839 .947 r
F P
0 g
s
.28454 .58082 m .26231 .58344 L .26117 .59506 L p .712 .843 .944 r
F P
0 g
s
.66509 .42188 m .64982 .44102 L .6581 .44328 L p .814 .831 .863 r
F P
0 g
s
.6581 .44328 m .67452 .42465 L .66509 .42188 L p .814 .831 .863 r
F P
0 g
s
.70745 .38326 m .69098 .40464 L .70051 .40866 L p .833 .825 .841 r
F P
0 g
s
.70051 .40866 m .71799 .38801 L .70745 .38326 L p .833 .825 .841 r
F P
0 g
s
.37835 .5518 m .39958 .55003 L .40358 .54281 L p .74 .851 .932 r
F P
0 g
s
.3067 .57783 m .32878 .57455 L .33143 .56496 L p .728 .85 .938 r
F P
0 g
s
.35325 .56242 m .33143 .56496 L .32878 .57455 L p .732 .849 .936 r
F P
0 g
s
.64081 .4393 m .62687 .45757 L .63461 .45896 L p .804 .831 .872 r
F P
0 g
s
.63461 .45896 m .64982 .44102 L .64081 .4393 L p .804 .831 .872 r
F P
0 g
s
.48935 .51646 m .47515 .51039 L .46866 .51519 L p .735 .837 .928 r
F P
0 g
s
.47515 .51039 m .48935 .51646 L .49491 .51295 L p .734 .834 .927 r
F P
0 g
s
.5746 .47456 m .56855 .49038 L .57519 .48998 L p .765 .814 .892 r
F P
0 g
s
.57519 .48998 m .58293 .47387 L .5746 .47456 L p .765 .814 .892 r
F P
0 g
s
.72393 .3608 m .70745 .38326 L .71799 .38801 L p .836 .818 .832 r
F P
0 g
s
.71799 .38801 m .73546 .36639 L .72393 .3608 L p .836 .818 .832 r
F P
0 g
s
.60972 .45618 m .59872 .47361 L .60607 .47404 L p .789 .824 .88 r
F P
0 g
s
.60607 .47404 m .61856 .45664 L .60972 .45618 L p .789 .824 .88 r
F P
0 g
s
.2167 .6005 m .23895 .598 L .24002 .58565 L p .694 .835 .95 r
F P
0 g
s
.26231 .58344 m .24002 .58565 L .23895 .598 L p .703 .839 .947 r
F P
0 g
s
.49491 .51295 m .48212 .50579 L .47515 .51039 L p .734 .834 .927 r
F P
0 g
s
.48212 .50579 m .49491 .51295 L .5008 .50964 L p .733 .831 .925 r
F P
0 g
s
.45725 .52524 m .43928 .52297 L .43348 .52925 L p .744 .851 .929 r
F P
0 g
s
.43928 .52297 m .45725 .52524 L .46268 .52015 L p .743 .851 .93 r
F P
0 g
s
.56606 .47564 m .56174 .49106 L .56855 .49038 L p .76 .812 .894 r
F P
0 g
s
.56855 .49038 m .5746 .47456 L .56606 .47564 L p .76 .812 .894 r
F P
0 g
s
.42843 .53556 m .40853 .5355 L .40358 .54281 L p .744 .853 .93 r
F P
0 g
s
.40853 .5355 m .42843 .53556 L .43348 .52925 L p .744 .854 .931 r
F P
0 g
s
.68041 .40128 m .66509 .42188 L .67452 .42465 L p .821 .822 .849 r
F P
0 g
s
.67452 .42465 m .69098 .40464 L .68041 .40128 L p .821 .822 .849 r
F P
0 g
s
.74044 .33765 m .72393 .3608 L .73546 .36639 L p .837 .811 .826 r
F P
0 g
s
.73546 .36639 m .75296 .3442 L .74044 .33765 L p .837 .811 .826 r
F P
0 g
s
.28454 .58082 m .3067 .57783 L .30949 .56741 L p .722 .849 .942 r
F P
0 g
s
.33143 .56496 m .30949 .56741 L .3067 .57783 L p .728 .85 .938 r
F P
0 g
s
.33143 .56496 m .35325 .56242 L .35699 .55348 L p .733 .852 .936 r
F P
0 g
s
.37835 .5518 m .35699 .55348 L .35325 .56242 L p .736 .85 .934 r
F P
0 g
s
.5008 .50964 m .4895 .50141 L .48212 .50579 L p .733 .831 .925 r
F P
0 g
s
.4895 .50141 m .5008 .50964 L .50698 .50654 L p .733 .827 .923 r
F P
0 g
s
.19442 .60253 m .2167 .6005 L .21766 .58744 L p .684 .831 .954 r
F P
0 g
s
.24002 .58565 m .21766 .58744 L .2167 .6005 L p .694 .835 .95 r
F P
0 g
s
.63112 .43814 m .61856 .45664 L .62687 .45757 L p .8 .824 .87 r
F P
0 g
s
.62687 .45757 m .64081 .4393 L .63112 .43814 L p .8 .824 .87 r
F P
0 g
s
.55737 .4771 m .55482 .49202 L .56174 .49106 L p .756 .81 .896 r
F P
0 g
s
.56174 .49106 m .56606 .47564 L .55737 .4771 L p .756 .81 .896 r
F P
0 g
s
.60043 .45621 m .59098 .47355 L .59872 .47361 L p .785 .819 .879 r
F P
0 g
s
.59872 .47361 m .60972 .45618 L .60043 .45621 L p .785 .819 .879 r
F P
0 g
s
.65481 .41974 m .64081 .4393 L .64982 .44102 L p .81 .822 .86 r
F P
0 g
s
.64982 .44102 m .66509 .42188 L .65481 .41974 L p .81 .822 .86 r
F P
0 g
s
.50698 .50654 m .49727 .49728 L .4895 .50141 L p .733 .827 .923 r
F P
0 g
s
.49727 .49728 m .50698 .50654 L .51341 .50367 L p .734 .824 .921 r
F P
0 g
s
.75698 .31407 m .74044 .33765 L .75296 .3442 L p .836 .805 .822 r
F P
0 g
s
.75296 .3442 m .77047 .32167 L .75698 .31407 L p .836 .805 .822 r
F P
0 g
s
.40358 .54281 m .38286 .54362 L .37835 .5518 L p .74 .851 .932 r
F P
0 g
s
.38286 .54362 m .40358 .54281 L .40853 .5355 L p .741 .853 .932 r
F P
0 g
s
.54858 .47893 m .54782 .49327 L .55482 .49202 L p .751 .81 .899 r
F P
0 g
s
.55482 .49202 m .55737 .4771 L .54858 .47893 L p .751 .81 .899 r
F P
0 g
s
.35699 .55348 m .37835 .5518 L .38286 .54362 L p .737 .852 .934 r
F P
0 g
s
.46268 .52015 m .44579 .51678 L .43928 .52297 L p .743 .851 .93 r
F P
0 g
s
.44579 .51678 m .46268 .52015 L .46866 .51519 L p .742 .85 .93 r
F P
0 g
s
.51341 .50367 m .50535 .49343 L .49727 .49728 L p .734 .824 .921 r
F P
0 g
s
.50535 .49343 m .51341 .50367 L .52006 .50106 L p .735 .82 .917 r
F P
0 g
s
.53976 .48114 m .5408 .4948 L .54782 .49327 L p .747 .81 .903 r
F P
0 g
s
.54782 .49327 m .54858 .47893 L .53976 .48114 L p .747 .81 .903 r
F P
0 g
s
.17213 .60401 m .19442 .60253 L .19525 .5888 L p .673 .827 .958 r
F P
0 g
s
.21766 .58744 m .19525 .5888 L .19442 .60253 L p .684 .831 .954 r
F P
0 g
s
.52006 .50106 m .5137 .48986 L .50535 .49343 L p .735 .82 .917 r
F P
0 g
s
.5137 .48986 m .52006 .50106 L .52687 .4987 L p .737 .817 .914 r
F P
0 g
s
.77354 .28997 m .75698 .31407 L .77047 .32167 L p .835 .799 .817 r
F P
0 g
s
.77047 .32167 m .78799 .29869 L .77354 .28997 L p .835 .799 .817 r
F P
0 g
s
.69575 .37922 m .68041 .40128 L .69098 .40464 L p .827 .813 .836 r
F P
0 g
s
.69098 .40464 m .70745 .38326 L .69575 .37922 L p .827 .813 .836 r
F P
0 g
s
.53096 .4837 m .5338 .49661 L .5408 .4948 L p .743 .812 .906 r
F P
0 g
s
.5408 .4948 m .53976 .48114 L .53096 .4837 L p .743 .812 .906 r
F P
0 g
s
.52687 .4987 m .52225 .48662 L .5137 .48986 L p .737 .817 .914 r
F P
0 g
s
.52225 .48662 m .52687 .4987 L .5338 .49661 L p .74 .814 .91 r
F P
0 g
s
.5338 .49661 m .53096 .4837 L .52225 .48662 L p .74 .814 .91 r
F P
0 g
s
.43348 .52925 m .41439 .52817 L .40853 .5355 L p .744 .854 .931 r
F P
0 g
s
.41439 .52817 m .43348 .52925 L .43928 .52297 L p .744 .855 .931 r
F P
0 g
s
.26231 .58344 m .28454 .58082 L .28745 .56963 L p .714 .846 .945 r
F P
0 g
s
.30949 .56741 m .28745 .56963 L .28454 .58082 L p .722 .849 .942 r
F P
0 g
s
.59074 .45674 m .58293 .47387 L .59098 .47355 L p .78 .815 .88 r
F P
0 g
s
.59098 .47355 m .60043 .45621 L .59074 .45674 L p .78 .815 .88 r
F P
0 g
s
.79009 .26501 m .77354 .28997 L .78799 .29869 L p .837 .793 .809 r
F P
0 g
s
.78799 .29869 m .80549 .2749 L .79009 .26501 L p .837 .793 .809 r
F P
0 g
s
.46866 .51519 m .45298 .51071 L .44579 .51678 L p .742 .85 .93 r
F P
0 g
s
.45298 .51071 m .46866 .51519 L .47515 .51039 L p .742 .848 .929 r
F P
0 g
s
.14986 .60468 m .17213 .60401 L .1728 .58971 L p .657 .831 .967 r
F P
0 g
s
.19525 .5888 m .1728 .58971 L .17213 .60401 L p .673 .827 .958 r
F P
0 g
s
.62081 .43759 m .60972 .45618 L .61856 .45664 L p .796 .818 .869 r
F P
0 g
s
.61856 .45664 m .63112 .43814 L .62081 .43759 L p .796 .818 .869 r
F P
0 g
s
.30949 .56741 m .33143 .56496 L .33549 .55514 L p .73 .853 .939 r
F P
0 g
s
.35699 .55348 m .33549 .55514 L .33143 .56496 L p .733 .852 .936 r
F P
0 g
s
.85771 .19726 m .8749 .16816 L .85632 .16048 L p .891 .833 .783 r
F P
0 g
s
.8066 .23887 m .79009 .26501 L .80549 .2749 L p .84 .786 .8 r
F P
0 g
s
.80549 .2749 m .82295 .25 L .8066 .23887 L p .84 .786 .8 r
F P
0 g
s
.66886 .39864 m .65481 .41974 L .66509 .42188 L p .817 .812 .846 r
F P
0 g
s
.66509 .42188 m .68041 .40128 L .66886 .39864 L p .817 .812 .846 r
F P
0 g
s
.71111 .35596 m .69575 .37922 L .70745 .38326 L p .83 .804 .826 r
F P
0 g
s
.70745 .38326 m .72393 .3608 L .71111 .35596 L p .83 .804 .826 r
F P
0 g
s
.82308 .21166 m .8066 .23887 L .82295 .25 L p .843 .781 .792 r
F P
0 g
s
.82295 .25 m .84035 .22403 L .82308 .21166 L p .843 .781 .792 r
F P
0 g
s
.1278 .60229 m .14986 .60468 L .15028 .59041 L p .577 .883 .992 r
F P
0 g
s
.1728 .58971 m .15028 .59041 L .14986 .60468 L p .657 .831 .967 r
F P
0 g
s
.85632 .16048 m .83957 .1843 L .85771 .19726 L p .891 .833 .783 r
F P
0 g
s
.84035 .22403 m .85771 .19726 L .83957 .1843 L p .848 .783 .788 r
F P
0 g
s
.83957 .1843 m .82308 .21166 L .84035 .22403 L p .848 .783 .788 r
F P
0 g
s
.64374 .41828 m .63112 .43814 L .64081 .4393 L p .807 .814 .857 r
F P
0 g
s
.64081 .4393 m .65481 .41974 L .64374 .41828 L p .807 .814 .857 r
F P
0 g
s
.58072 .45778 m .5746 .47456 L .58293 .47387 L p .776 .812 .882 r
F P
0 g
s
.58293 .47387 m .59074 .45674 L .58072 .45778 L p .776 .812 .882 r
F P
0 g
s
.40853 .5355 m .38846 .53536 L .38286 .54362 L p .741 .853 .932 r
F P
0 g
s
.38846 .53536 m .40853 .5355 L .41439 .52817 L p .741 .855 .933 r
F P
0 g
s
.15028 .59041 m .12755 .59277 L .1278 .60229 L p .577 .883 .992 r
F P
0 g
s
.47515 .51039 m .46078 .5048 L .45298 .51071 L p .742 .848 .929 r
F P
0 g
s
.46078 .5048 m .47515 .51039 L .48212 .50579 L p .741 .845 .928 r
F P
0 g
s
.24002 .58565 m .26231 .58344 L .26532 .57152 L p .705 .843 .948 r
F P
0 g
s
.28745 .56963 m .26532 .57152 L .26231 .58344 L p .714 .846 .945 r
F P
0 g
s
.33549 .55514 m .35699 .55348 L .36198 .54438 L p .734 .854 .937 r
F P
0 g
s
.38286 .54362 m .36198 .54438 L .35699 .55348 L p .737 .852 .934 r
F P
0 g
s
.43928 .52297 m .42113 .52087 L .41439 .52817 L p .744 .855 .931 r
F P
0 g
s
.42113 .52087 m .43928 .52297 L .44579 .51678 L p .744 .856 .932 r
F P
0 g
s
.36198 .54438 m .38286 .54362 L .38846 .53536 L p .738 .855 .935 r
F P
0 g
s
.7265 .33188 m .71111 .35596 L .72393 .3608 L p .83 .796 .819 r
F P
0 g
s
.72393 .3608 m .74044 .33765 L .7265 .33188 L p .83 .796 .819 r
F P
0 g
s
.60995 .43767 m .60043 .45621 L .60972 .45618 L p .792 .813 .868 r
F P
0 g
s
.60972 .45618 m .62081 .43759 L .60995 .43767 L p .792 .813 .868 r
F P
0 g
s
.57043 .45934 m .56606 .47564 L .5746 .47456 L p .772 .81 .884 r
F P
0 g
s
.5746 .47456 m .58072 .45778 L .57043 .45934 L p .772 .81 .884 r
F P
0 g
s
.48212 .50579 m .46917 .49908 L .46078 .5048 L p .741 .845 .928 r
F P
0 g
s
.46917 .49908 m .48212 .50579 L .4895 .50141 L p .742 .842 .926 r
F P
0 g
s
.28745 .56963 m .30949 .56741 L .31385 .55677 L p .724 .853 .943 r
F P
0 g
s
.33549 .55514 m .31385 .55677 L .30949 .56741 L p .73 .853 .939 r
F P
0 g
s
.68295 .37598 m .66886 .39864 L .68041 .40128 L p .822 .801 .832 r
F P
0 g
s
.68041 .40128 m .69575 .37922 L .68295 .37598 L p .822 .801 .832 r
F P
0 g
s
.55995 .46141 m .55737 .4771 L .56606 .47564 L p .767 .81 .887 r
F P
0 g
s
.56606 .47564 m .57043 .45934 L .55995 .46141 L p .767 .81 .887 r
F P
0 g
s
.4895 .50141 m .47807 .49359 L .46917 .49908 L p .742 .842 .926 r
F P
0 g
s
.47807 .49359 m .4895 .50141 L .49727 .49728 L p .743 .838 .923 r
F P
0 g
s
.21766 .58744 m .24002 .58565 L .24309 .57301 L p .696 .839 .952 r
F P
0 g
s
.26532 .57152 m .24309 .57301 L .24002 .58565 L p .705 .843 .948 r
F P
0 g
s
.74193 .30726 m .7265 .33188 L .74044 .33765 L p .829 .789 .815 r
F P
0 g
s
.74044 .33765 m .75698 .31407 L .74193 .30726 L p .829 .789 .815 r
F P
0 g
s
.44579 .51678 m .42872 .51363 L .42113 .52087 L p .744 .856 .932 r
F P
0 g
s
.42872 .51363 m .44579 .51678 L .45298 .51071 L p .744 .855 .931 r
F P
0 g
s
.63196 .41756 m .62081 .43759 L .63112 .43814 L p .803 .808 .855 r
F P
0 g
s
.63112 .43814 m .64374 .41828 L .63196 .41756 L p .803 .808 .855 r
F P
0 g
s
.41439 .52817 m .39512 .52707 L .38846 .53536 L p .741 .855 .933 r
F P
0 g
s
.39512 .52707 m .41439 .52817 L .42113 .52087 L p .742 .857 .934 r
F P
0 g
s
.65642 .39679 m .64374 .41828 L .65481 .41974 L p .813 .803 .842 r
F P
0 g
s
.65481 .41974 m .66886 .39864 L .65642 .39679 L p .813 .803 .842 r
F P
0 g
s
.54935 .46397 m .54858 .47893 L .55737 .4771 L p .763 .811 .891 r
F P
0 g
s
.55737 .4771 m .55995 .46141 L .54935 .46397 L p .763 .811 .891 r
F P
0 g
s
.59862 .43841 m .59074 .45674 L .60043 .45621 L p .789 .809 .868 r
F P
0 g
s
.60043 .45621 m .60995 .43767 L .59862 .43841 L p .789 .809 .868 r
F P
0 g
s
.49727 .49728 m .48743 .48834 L .47807 .49359 L p .743 .838 .923 r
F P
0 g
s
.48743 .48834 m .49727 .49728 L .50535 .49343 L p .744 .833 .919 r
F P
0 g
s
.75738 .28204 m .74193 .30726 L .75698 .31407 L p .828 .782 .809 r
F P
0 g
s
.75698 .31407 m .77354 .28997 L .75738 .28204 L p .828 .782 .809 r
F P
0 g
s
.31385 .55677 m .33549 .55514 L .34095 .54517 L p .731 .857 .941 r
F P
0 g
s
.36198 .54438 m .34095 .54517 L .33549 .55514 L p .734 .854 .937 r
F P
0 g
s
.53871 .46702 m .53976 .48114 L .54858 .47893 L p .76 .813 .895 r
F P
0 g
s
.54858 .47893 m .54935 .46397 L .53871 .46702 L p .76 .813 .895 r
F P
0 g
s
.50535 .49343 m .49718 .48338 L .48743 .48834 L p .744 .833 .919 r
F P
0 g
s
.49718 .48338 m .50535 .49343 L .5137 .48986 L p .746 .829 .915 r
F P
0 g
s
.69706 .35197 m .68295 .37598 L .69575 .37922 L p .824 .791 .821 r
F P
0 g
s
.69575 .37922 m .71111 .35596 L .69706 .35197 L p .824 .791 .821 r
F P
0 g
s
.52809 .47051 m .53096 .4837 L .53976 .48114 L p .756 .816 .9 r
F P
0 g
s
.53976 .48114 m .53871 .46702 L .52809 .47051 L p .756 .816 .9 r
F P
0 g
s
.5137 .48986 m .50725 .47873 L .49718 .48338 L p .746 .829 .915 r
F P
0 g
s
.50725 .47873 m .5137 .48986 L .52225 .48662 L p .749 .824 .91 r
F P
0 g
s
.19525 .5888 m .21766 .58744 L .22077 .57411 L p .687 .836 .955 r
F P
0 g
s
.24309 .57301 m .22077 .57411 L .21766 .58744 L p .696 .839 .952 r
F P
0 g
s
.38846 .53536 m .36822 .5352 L .36198 .54438 L p .738 .855 .935 r
F P
0 g
s
.36822 .5352 m .38846 .53536 L .39512 .52707 L p .738 .857 .936 r
F P
0 g
s
.26532 .57152 m .28745 .56963 L .29208 .55823 L p .716 .851 .946 r
F P
0 g
s
.31385 .55677 m .29208 .55823 L .28745 .56963 L p .724 .853 .943 r
F P
0 g
s
.45298 .51071 m .43711 .5065 L .42872 .51363 L p .744 .855 .931 r
F P
0 g
s
.43711 .5065 m .45298 .51071 L .46078 .5048 L p .745 .854 .93 r
F P
0 g
s
.51758 .47443 m .52225 .48662 L .53096 .4837 L p .752 .82 .905 r
F P
0 g
s
.53096 .4837 m .52809 .47051 L .51758 .47443 L p .752 .82 .905 r
F P
0 g
s
.52225 .48662 m .51758 .47443 L .50725 .47873 L p .749 .824 .91 r
F P
0 g
s
.34095 .54517 m .36198 .54438 L .36822 .5352 L p .735 .858 .938 r
F P
0 g
s
.77283 .2559 m .75738 .28204 L .77354 .28997 L p .828 .775 .802 r
F P
0 g
s
.77354 .28997 m .79009 .26501 L .77283 .2559 L p .828 .775 .802 r
F P
0 g
s
.58689 .43983 m .58072 .45778 L .59074 .45674 L p .785 .807 .87 r
F P
0 g
s
.59074 .45674 m .59862 .43841 L .58689 .43983 L p .785 .807 .87 r
F P
0 g
s
.61953 .41764 m .60995 .43767 L .62081 .43759 L p .799 .802 .854 r
F P
0 g
s
.62081 .43759 m .63196 .41756 L .61953 .41764 L p .799 .802 .854 r
F P
0 g
s
.42113 .52087 m .4028 .51879 L .39512 .52707 L p .742 .857 .934 r
F P
0 g
s
.4028 .51879 m .42113 .52087 L .42872 .51363 L p .743 .858 .934 r
F P
0 g
s
.66914 .37362 m .65642 .39679 L .66886 .39864 L p .817 .791 .828 r
F P
0 g
s
.66886 .39864 m .68295 .37598 L .66914 .37362 L p .817 .791 .828 r
F P
0 g
s
.78826 .22852 m .77283 .2559 L .79009 .26501 L p .83 .768 .793 r
F P
0 g
s
.79009 .26501 m .8066 .23887 L .78826 .22852 L p .83 .768 .793 r
F P
0 g
s
.71121 .32701 m .69706 .35197 L .71111 .35596 L p .824 .783 .813 r
F P
0 g
s
.71111 .35596 m .7265 .33188 L .71121 .32701 L p .824 .783 .813 r
F P
0 g
s
.46078 .5048 m .44624 .4995 L .43711 .5065 L p .745 .854 .93 r
F P
0 g
s
.44624 .4995 m .46078 .5048 L .46917 .49908 L p .746 .852 .929 r
F P
0 g
s
.64316 .39582 m .63196 .41756 L .64374 .41828 L p .809 .795 .84 r
F P
0 g
s
.64374 .41828 m .65642 .39679 L .64316 .39582 L p .809 .795 .84 r
F P
0 g
s
.1728 .58971 m .19525 .5888 L .19838 .57482 L p .676 .831 .958 r
F P
0 g
s
.22077 .57411 m .19838 .57482 L .19525 .5888 L p .687 .836 .955 r
F P
0 g
s
.57484 .44193 m .57043 .45934 L .58072 .45778 L p .782 .806 .872 r
F P
0 g
s
.58072 .45778 m .58689 .43983 L .57484 .44193 L p .782 .806 .872 r
F P
0 g
s
.80366 .19992 m .78826 .22852 L .8066 .23887 L p .831 .761 .784 r
F P
0 g
s
.8066 .23887 m .82308 .21166 L .80366 .19992 L p .831 .761 .784 r
F P
0 g
s
.24309 .57301 m .26532 .57152 L .27019 .55939 L p .707 .848 .95 r
F P
0 g
s
.29208 .55823 m .27019 .55939 L .26532 .57152 L p .716 .851 .946 r
F P
0 g
s
.29208 .55823 m .31385 .55677 L .31977 .54598 L p .725 .859 .944 r
F P
0 g
s
.34095 .54517 m .31977 .54598 L .31385 .55677 L p .731 .857 .941 r
F P
0 g
s
.81902 .17038 m .80366 .19992 L .82308 .21166 L p .825 .749 .781 r
F P
0 g
s
.82308 .21166 m .83957 .1843 L .81902 .17038 L p .825 .749 .781 r
F P
0 g
s
.46917 .49908 m .45605 .49266 L .44624 .4995 L p .746 .852 .929 r
F P
0 g
s
.45605 .49266 m .46917 .49908 L .47807 .49359 L p .748 .849 .926 r
F P
0 g
s
.83425 .13833 m .81902 .17038 L .83957 .1843 L p .77 .697 .782 r
F P
0 g
s
.83957 .1843 m .85632 .16048 L .83425 .13833 L p .77 .697 .782 r
F P
0 g
s
.60655 .41856 m .59862 .43841 L .60995 .43767 L p .796 .799 .854 r
F P
0 g
s
.60995 .43767 m .61953 .41764 L .60655 .41856 L p .796 .799 .854 r
F P
0 g
s
.39512 .52707 m .37566 .52599 L .36822 .5352 L p .738 .857 .936 r
F P
0 g
s
.37566 .52599 m .39512 .52707 L .4028 .51879 L p .739 .86 .937 r
F P
0 g
s
.72539 .30138 m .71121 .32701 L .7265 .33188 L p .822 .775 .808 r
F P
0 g
s
.7265 .33188 m .74193 .30726 L .72539 .30138 L p .822 .775 .808 r
F P
0 g
s
.56256 .44472 m .55995 .46141 L .57043 .45934 L p .779 .807 .875 r
F P
0 g
s
.57043 .45934 m .57484 .44193 L .56256 .44472 L p .779 .807 .875 r
F P
0 g
s
.15028 .59041 m .1728 .58971 L .17591 .5751 L p .668 .822 .957 r
F P
0 g
s
.19838 .57482 m .17591 .5751 L .1728 .58971 L p .676 .831 .958 r
F P
0 g
s
.42872 .51363 m .41146 .51057 L .4028 .51879 L p .743 .858 .934 r
F P
0 g
s
.41146 .51057 m .42872 .51363 L .43711 .5065 L p .744 .859 .933 r
F P
0 g
s
.68188 .34896 m .66914 .37362 L .68295 .37598 L p .819 .78 .816 r
F P
0 g
s
.68295 .37598 m .69706 .35197 L .68188 .34896 L p .819 .78 .816 r
F P
0 g
s
.31977 .54598 m .34095 .54517 L .34781 .53512 L p .731 .862 .942 r
F P
0 g
s
.36822 .5352 m .34781 .53512 L .34095 .54517 L p .735 .858 .938 r
F P
0 g
s
.34781 .53512 m .36822 .5352 L .37566 .52599 L p .735 .862 .94 r
F P
0 g
s
.47807 .49359 m .46648 .48601 L .45605 .49266 L p .748 .849 .926 r
F P
0 g
s
.46648 .48601 m .47807 .49359 L .48743 .48834 L p .751 .845 .921 r
F P
0 g
s
.55013 .44817 m .54935 .46397 L .55995 .46141 L p .776 .809 .879 r
F P
0 g
s
.55995 .46141 m .56256 .44472 L .55013 .44817 L p .776 .809 .879 r
F P
0 g
s
.62916 .39582 m .61953 .41764 L .63196 .41756 L p .805 .79 .838 r
F P
0 g
s
.63196 .41756 m .64316 .39582 L .62916 .39582 L p .805 .79 .838 r
F P
0 g
s
.7396 .27504 m .72539 .30138 L .74193 .30726 L p .82 .767 .802 r
F P
0 g
s
.74193 .30726 m .75738 .28204 L .7396 .27504 L p .82 .767 .802 r
F P
0 g
s
.6544 .37228 m .64316 .39582 L .65642 .39679 L p .813 .783 .825 r
F P
0 g
s
.65642 .39679 m .66914 .37362 L .6544 .37228 L p .813 .783 .825 r
F P
0 g
s
.12755 .59277 m .15028 .59041 L .15338 .57481 L p .675 .769 .921 r
F P
0 g
s
.17591 .5751 m .15338 .57481 L .15028 .59041 L p .668 .822 .957 r
F P
0 g
s
.22077 .57411 m .24309 .57301 L .24818 .5602 L p .698 .845 .953 r
F P
0 g
s
.27019 .55939 m .24818 .5602 L .24309 .57301 L p .707 .848 .95 r
F P
0 g
s
.48743 .48834 m .47746 .47957 L .46648 .48601 L p .751 .845 .921 r
F P
0 g
s
.47746 .47957 m .48743 .48834 L .49718 .48338 L p .754 .84 .916 r
F P
0 g
s
.59311 .42037 m .58689 .43983 L .59862 .43841 L p .794 .797 .855 r
F P
0 g
s
.59862 .43841 m .60655 .41856 L .59311 .42037 L p .794 .797 .855 r
F P
0 g
s
.53764 .45223 m .53871 .46702 L .54935 .46397 L p .773 .813 .884 r
F P
0 g
s
.54935 .46397 m .55013 .44817 L .53764 .45223 L p .773 .813 .884 r
F P
0 g
s
.43711 .5065 m .42106 .50242 L .41146 .51057 L p .744 .859 .933 r
F P
0 g
s
.42106 .50242 m .43711 .5065 L .44624 .4995 L p .746 .859 .932 r
F P
0 g
s
.49718 .48338 m .4889 .47338 L .47746 .47957 L p .754 .84 .916 r
F P
0 g
s
.4889 .47338 m .49718 .48338 L .50725 .47873 L p .758 .834 .91 r
F P
0 g
s
.27019 .55939 m .29208 .55823 L .29842 .5467 L p .717 .858 .949 r
F P
0 g
s
.31977 .54598 m .29842 .5467 L .29208 .55823 L p .725 .859 .944 r
F P
0 g
s
.69467 .32319 m .68188 .34896 L .69706 .35197 L p .818 .77 .808 r
F P
0 g
s
.69706 .35197 m .71121 .32701 L .69467 .32319 L p .818 .77 .808 r
F P
0 g
s
.52519 .45685 m .52809 .47051 L .53871 .46702 L p .769 .817 .89 r
F P
0 g
s
.53871 .46702 m .53764 .45223 L .52519 .45685 L p .769 .817 .89 r
F P
0 g
s
.4028 .51879 m .38428 .51679 L .37566 .52599 L p .739 .86 .937 r
F P
0 g
s
.38428 .51679 m .4028 .51879 L .41146 .51057 L p .74 .863 .937 r
F P
0 g
s
.75382 .24772 m .7396 .27504 L .75738 .28204 L p .82 .759 .795 r
F P
0 g
s
.75738 .28204 m .77283 .2559 L .75382 .24772 L p .82 .759 .795 r
F P
0 g
s
.50725 .47873 m .50073 .4675 L .4889 .47338 L p .758 .834 .91 r
F P
0 g
s
.50073 .4675 m .50725 .47873 L .51758 .47443 L p .762 .828 .904 r
F P
0 g
s
.51285 .46196 m .51758 .47443 L .52809 .47051 L p .766 .823 .897 r
F P
0 g
s
.52809 .47051 m .52519 .45685 L .51285 .46196 L p .766 .823 .897 r
F P
0 g
s
.51758 .47443 m .51285 .46196 L .50073 .4675 L p .762 .828 .904 r
F P
0 g
s
.15338 .57481 m .13092 .57262 L .12755 .59277 L p .675 .769 .921 r
F P
0 g
s
.57929 .4231 m .57484 .44193 L .58689 .43983 L p .792 .798 .857 r
F P
0 g
s
.58689 .43983 m .59311 .42037 L .57929 .4231 L p .792 .798 .857 r
F P
0 g
s
.61453 .39688 m .60655 .41856 L .61953 .41764 L p .803 .786 .837 r
F P
0 g
s
.61953 .41764 m .62916 .39582 L .61453 .39688 L p .803 .786 .837 r
F P
0 g
s
.76802 .21911 m .75382 .24772 L .77283 .2559 L p .821 .751 .786 r
F P
0 g
s
.77283 .2559 m .78826 .22852 L .76802 .21911 L p .821 .751 .786 r
F P
0 g
s
.44624 .4995 m .43152 .49437 L .42106 .50242 L p .746 .859 .932 r
F P
0 g
s
.43152 .49437 m .44624 .4995 L .45605 .49266 L p .749 .857 .929 r
F P
0 g
s
.19838 .57482 m .22077 .57411 L .22606 .56064 L p .688 .842 .957 r
F P
0 g
s
.24818 .5602 m .22606 .56064 L .22077 .57411 L p .698 .845 .953 r
F P
0 g
s
.66567 .3471 m .6544 .37228 L .66914 .37362 L p .814 .77 .812 r
F P
0 g
s
.66914 .37362 m .68188 .34896 L .66567 .3471 L p .814 .77 .812 r
F P
0 g
s
.29842 .5467 m .31977 .54598 L .32723 .53513 L p .726 .865 .947 r
F P
0 g
s
.34781 .53512 m .32723 .53513 L .31977 .54598 L p .731 .862 .942 r
F P
0 g
s
.37566 .52599 m .35603 .52504 L .34781 .53512 L p .735 .862 .94 r
F P
0 g
s
.35603 .52504 m .37566 .52599 L .38428 .51679 L p .736 .866 .941 r
F P
0 g
s
.70748 .29658 m .69467 .32319 L .71121 .32701 L p .816 .761 .802 r
F P
0 g
s
.71121 .32701 m .72539 .30138 L .70748 .29658 L p .816 .761 .802 r
F P
0 g
s
.63884 .37209 m .62916 .39582 L .64316 .39582 L p .809 .776 .822 r
F P
0 g
s
.64316 .39582 m .6544 .37228 L .63884 .37209 L p .809 .776 .822 r
F P
0 g
s
.32723 .53513 m .34781 .53512 L .35603 .52504 L p .732 .868 .945 r
F P
0 g
s
.78221 .18929 m .76802 .21911 L .78826 .22852 L p .822 .744 .777 r
F P
0 g
s
.78826 .22852 m .80366 .19992 L .78221 .18929 L p .822 .744 .777 r
F P
0 g
s
.56519 .42673 m .56256 .44472 L .57484 .44193 L p .79 .8 .86 r
F P
0 g
s
.57484 .44193 m .57929 .4231 L .56519 .42673 L p .79 .8 .86 r
F P
0 g
s
.41146 .51057 m .39402 .50763 L .38428 .51679 L p .74 .863 .937 r
F P
0 g
s
.39402 .50763 m .41146 .51057 L .42106 .50242 L p .742 .864 .937 r
F P
0 g
s
.24818 .5602 m .27019 .55939 L .27693 .54718 L p .708 .855 .952 r
F P
0 g
s
.29842 .5467 m .27693 .54718 L .27019 .55939 L p .717 .858 .949 r
F P
0 g
s
.45605 .49266 m .44277 .48641 L .43152 .49437 L p .749 .857 .929 r
F P
0 g
s
.44277 .48641 m .45605 .49266 L .46648 .48601 L p .753 .854 .925 r
F P
0 g
s
.79641 .15924 m .78221 .18929 L .80366 .19992 L p .827 .744 .773 r
F P
0 g
s
.80366 .19992 m .81902 .17038 L .79641 .15924 L p .827 .744 .773 r
F P
0 g
s
.59937 .3991 m .59311 .42037 L .60655 .41856 L p .801 .785 .838 r
F P
0 g
s
.60655 .41856 m .61453 .39688 L .59937 .3991 L p .801 .785 .838 r
F P
0 g
s
.72032 .26914 m .70748 .29658 L .72539 .30138 L p .813 .753 .796 r
F P
0 g
s
.72539 .30138 m .7396 .27504 L .72032 .26914 L p .813 .753 .796 r
F P
0 g
s
.81087 .13291 m .79641 .15924 L .81902 .17038 L p .869 .786 .767 r
F P
0 g
s
.81902 .17038 m .83425 .13833 L .81087 .13291 L p .869 .786 .767 r
F P
0 g
s
.17591 .5751 m .19838 .57482 L .20384 .56073 L p .678 .84 .961 r
F P
0 g
s
.22606 .56064 m .20384 .56073 L .19838 .57482 L p .688 .842 .957 r
F P
0 g
s
.55092 .43124 m .55013 .44817 L .56256 .44472 L p .788 .804 .865 r
F P
0 g
s
.56256 .44472 m .56519 .42673 L .55092 .43124 L p .788 .804 .865 r
F P
0 g
s
.67698 .32061 m .66567 .3471 L .68188 .34896 L p .813 .76 .803 r
F P
0 g
s
.68188 .34896 m .69467 .32319 L .67698 .32061 L p .813 .76 .803 r
F P
0 g
s
.46648 .48601 m .45475 .47858 L .44277 .48641 L p .753 .854 .925 r
F P
0 g
s
.45475 .47858 m .46648 .48601 L .47746 .47957 L p .758 .85 .919 r
F P
0 g
s
.62255 .37322 m .61453 .39688 L .62916 .39582 L p .807 .773 .821 r
F P
0 g
s
.62916 .39582 m .63884 .37209 L .62255 .37322 L p .807 .773 .821 r
F P
0 g
s
.53657 .43654 m .53764 .45223 L .55013 .44817 L p .786 .809 .871 r
F P
0 g
s
.55013 .44817 m .55092 .43124 L .53657 .43654 L p .786 .809 .871 r
F P
0 g
s
.64854 .34658 m .63884 .37209 L .6544 .37228 L p .81 .764 .809 r
F P
0 g
s
.6544 .37228 m .66567 .3471 L .64854 .34658 L p .81 .764 .809 r
F P
0 g
s
.38428 .51679 m .36556 .51499 L .35603 .52504 L p .736 .866 .941 r
F P
0 g
s
.36556 .51499 m .38428 .51679 L .39402 .50763 L p .737 .87 .942 r
F P
0 g
s
.42106 .50242 m .40482 .49853 L .39402 .50763 L p .742 .864 .937 r
F P
0 g
s
.40482 .49853 m .42106 .50242 L .43152 .49437 L p .746 .865 .935 r
F P
0 g
s
.27693 .54718 m .29842 .5467 L .30647 .53513 L p .718 .865 .951 r
F P
0 g
s
.32723 .53513 m .30647 .53513 L .29842 .5467 L p .726 .865 .947 r
F P
0 g
s
.47746 .47957 m .46736 .47088 L .45475 .47858 L p .758 .85 .919 r
F P
0 g
s
.46736 .47088 m .47746 .47957 L .4889 .47338 L p .764 .844 .912 r
F P
0 g
s
.73318 .24063 m .72032 .26914 L .7396 .27504 L p .812 .743 .788 r
F P
0 g
s
.7396 .27504 m .75382 .24772 L .73318 .24063 L p .812 .743 .788 r
F P
0 g
s
.58377 .40252 m .57929 .4231 L .59311 .42037 L p .8 .787 .84 r
F P
0 g
s
.59311 .42037 m .59937 .3991 L .58377 .40252 L p .8 .787 .84 r
F P
0 g
s
.52225 .44252 m .52519 .45685 L .53764 .45223 L p .783 .816 .878 r
F P
0 g
s
.53764 .45223 m .53657 .43654 L .52225 .44252 L p .783 .816 .878 r
F P
0 g
s
.22606 .56064 m .24818 .5602 L .25531 .54733 L p .698 .852 .956 r
F P
0 g
s
.27693 .54718 m .25531 .54733 L .24818 .5602 L p .708 .855 .952 r
F P
0 g
s
.15338 .57481 m .17591 .5751 L .1815 .56049 L p .663 .841 .968 r
F P
0 g
s
.20384 .56073 m .1815 .56049 L .17591 .5751 L p .678 .84 .961 r
F P
0 g
s
.4889 .47338 m .48052 .46335 L .46736 .47088 L p .764 .844 .912 r
F P
0 g
s
.48052 .46335 m .4889 .47338 L .50073 .4675 L p .77 .837 .903 r
F P
0 g
s
.68831 .2931 m .67698 .32061 L .69467 .32319 L p .81 .75 .796 r
F P
0 g
s
.69467 .32319 m .70748 .29658 L .68831 .2931 L p .81 .75 .796 r
F P
0 g
s
.35603 .52504 m .3362 .52428 L .32723 .53513 L p .732 .868 .945 r
F P
0 g
s
.3362 .52428 m .35603 .52504 L .36556 .51499 L p .732 .873 .947 r
F P
0 g
s
.50806 .44907 m .51285 .46196 L .52519 .45685 L p .78 .823 .886 r
F P
0 g
s
.52519 .45685 m .52225 .44252 L .50806 .44907 L p .78 .823 .886 r
F P
0 g
s
.30647 .53513 m .32723 .53513 L .3362 .52428 L p .726 .872 .95 r
F P
0 g
s
.50073 .4675 m .49412 .45605 L .48052 .46335 L p .77 .837 .903 r
F P
0 g
s
.49412 .45605 m .50073 .4675 L .51285 .46196 L p .775 .83 .895 r
F P
0 g
s
.51285 .46196 m .50806 .44907 L .49412 .45605 L p .775 .83 .895 r
F P
0 g
s
.74602 .21075 m .73318 .24063 L .75382 .24772 L p .811 .734 .779 r
F P
0 g
s
.75382 .24772 m .76802 .21911 L .74602 .21075 L p .811 .734 .779 r
F P
0 g
s
.43152 .49437 m .41661 .48946 L .40482 .49853 L p .746 .865 .935 r
F P
0 g
s
.41661 .48946 m .43152 .49437 L .44277 .48641 L p .751 .863 .931 r
F P
0 g
s
.56784 .40715 m .56519 .42673 L .57929 .4231 L p .8 .79 .843 r
F P
0 g
s
.57929 .4231 m .58377 .40252 L .56784 .40715 L p .8 .79 .843 r
F P
0 g
s
.60566 .37581 m .59937 .3991 L .61453 .39688 L p .806 .772 .821 r
F P
0 g
s
.61453 .39688 m .62255 .37322 L .60566 .37581 L p .806 .772 .821 r
F P
0 g
s
.65827 .31954 m .64854 .34658 L .66567 .3471 L p .809 .752 .799 r
F P
0 g
s
.66567 .3471 m .67698 .32061 L .65827 .31954 L p .809 .752 .799 r
F P
0 g
s
.39402 .50763 m .37637 .50498 L .36556 .51499 L p .737 .87 .942 r
F P
0 g
s
.37637 .50498 m .39402 .50763 L .40482 .49853 L p .74 .873 .942 r
F P
0 g
s
.13092 .57262 m .15338 .57481 L .15905 .56006 L p .609 .871 .991 r
F P
0 g
s
.1815 .56049 m .15905 .56006 L .15338 .57481 L p .663 .841 .968 r
F P
0 g
s
.75885 .17955 m .74602 .21075 L .76802 .21911 L p .81 .725 .771 r
F P
0 g
s
.76802 .21911 m .78221 .18929 L .75885 .17955 L p .81 .725 .771 r
F P
0 g
s
.6306 .34763 m .62255 .37322 L .63884 .37209 L p .809 .76 .807 r
F P
0 g
s
.63884 .37209 m .64854 .34658 L .6306 .34763 L p .809 .76 .807 r
F P
0 g
s
.69967 .26459 m .68831 .2931 L .70748 .29658 L p .807 .74 .79 r
F P
0 g
s
.70748 .29658 m .72032 .26914 L .69967 .26459 L p .807 .74 .79 r
F P
0 g
s
.20384 .56073 m .22606 .56064 L .23354 .54715 L p .689 .85 .96 r
F P
0 g
s
.25531 .54733 m .23354 .54715 L .22606 .56064 L p .698 .852 .956 r
F P
0 g
s
.25531 .54733 m .27693 .54718 L .28554 .53497 L p .708 .863 .956 r
F P
0 g
s
.30647 .53513 m .28554 .53497 L .27693 .54718 L p .718 .865 .951 r
F P
0 g
s
.44277 .48641 m .42932 .48043 L .41661 .48946 L p .751 .863 .931 r
F P
0 g
s
.42932 .48043 m .44277 .48641 L .45475 .47858 L p .757 .861 .926 r
F P
0 g
s
.55171 .41294 m .55092 .43124 L .56519 .42673 L p .8 .796 .848 r
F P
0 g
s
.56519 .42673 m .56784 .40715 L .55171 .41294 L p .8 .796 .848 r
F P
0 g
s
.77166 .14731 m .75885 .17955 L .78221 .18929 L p .803 .715 .767 r
F P
0 g
s
.78221 .18929 m .79641 .15924 L .77166 .14731 L p .803 .715 .767 r
F P
0 g
s
.15905 .56006 m .1364 .56055 L .13092 .57262 L p .609 .871 .991 r
F P
0 g
s
.36556 .51499 m .34664 .51347 L .3362 .52428 L p .732 .873 .947 r
F P
0 g
s
.34664 .51347 m .36556 .51499 L .37637 .50498 L p .733 .879 .948 r
F P
0 g
s
.58827 .37998 m .58377 .40252 L .59937 .3991 L p .807 .775 .823 r
F P
0 g
s
.59937 .3991 m .60566 .37581 L .58827 .37998 L p .807 .775 .823 r
F P
0 g
s
.78435 .11228 m .77166 .14731 L .79641 .15924 L p .748 .668 .772 r
F P
0 g
s
.79641 .15924 m .81087 .13291 L .78435 .11228 L p .748 .668 .772 r
F P
0 g
s
.71105 .23487 m .69967 .26459 L .72032 .26914 L p .804 .73 .782 r
F P
0 g
s
.72032 .26914 m .73318 .24063 L .71105 .23487 L p .804 .73 .782 r
F P
0 g
s
.66803 .29124 m .65827 .31954 L .67698 .32061 L p .806 .741 .792 r
F P
0 g
s
.67698 .32061 m .68831 .2931 L .66803 .29124 L p .806 .741 .792 r
F P
0 g
s
.28554 .53497 m .30647 .53513 L .31618 .5236 L p .717 .874 .955 r
F P
0 g
s
.3362 .52428 m .31618 .5236 L .30647 .53513 L p .726 .872 .95 r
F P
0 g
s
.53548 .41976 m .53657 .43654 L .55092 .43124 L p .8 .804 .855 r
F P
0 g
s
.55092 .43124 m .55171 .41294 L .53548 .41976 L p .8 .804 .855 r
F P
0 g
s
.45475 .47858 m .44286 .47139 L .42932 .48043 L p .757 .861 .926 r
F P
0 g
s
.44286 .47139 m .45475 .47858 L .46736 .47088 L p .765 .856 .918 r
F P
0 g
s
.40482 .49853 m .38837 .495 L .37637 .50498 L p .74 .873 .942 r
F P
0 g
s
.38837 .495 m .40482 .49853 L .41661 .48946 L p .744 .874 .94 r
F P
0 g
s
.31618 .5236 m .3362 .52428 L .34664 .51347 L p .725 .88 .952 r
F P
0 g
s
.61198 .3505 m .60566 .37581 L .62255 .37322 L p .809 .759 .807 r
F P
0 g
s
.62255 .37322 m .6306 .34763 L .61198 .3505 L p .809 .759 .807 r
F P
0 g
s
.63867 .32031 m .6306 .34763 L .64854 .34658 L p .808 .748 .796 r
F P
0 g
s
.64854 .34658 m .65827 .31954 L .63867 .32031 L p .808 .748 .796 r
F P
0 g
s
.51927 .42743 m .52225 .44252 L .53657 .43654 L p .798 .813 .864 r
F P
0 g
s
.53657 .43654 m .53548 .41976 L .51927 .42743 L p .798 .813 .864 r
F P
0 g
s
.46736 .47088 m .45713 .46236 L .44286 .47139 L p .765 .856 .918 r
F P
0 g
s
.45713 .46236 m .46736 .47088 L .48052 .46335 L p .774 .849 .908 r
F P
0 g
s
.1815 .56049 m .20384 .56073 L .21164 .54666 L p .679 .847 .963 r
F P
0 g
s
.23354 .54715 m .21164 .54666 L .20384 .56073 L p .689 .85 .96 r
F P
0 g
s
.72241 .20371 m .71105 .23487 L .73318 .24063 L p .802 .719 .773 r
F P
0 g
s
.73318 .24063 m .74602 .21075 L .72241 .20371 L p .802 .719 .773 r
F P
0 g
s
.57052 .38577 m .56784 .40715 L .58377 .40252 L p .809 .78 .826 r
F P
0 g
s
.58377 .40252 m .58827 .37998 L .57052 .38577 L p .809 .78 .826 r
F P
0 g
s
.50321 .43573 m .50806 .44907 L .52225 .44252 L p .794 .822 .874 r
F P
0 g
s
.52225 .44252 m .51927 .42743 L .50321 .43573 L p .794 .822 .874 r
F P
0 g
s
.48052 .46335 m .47202 .45335 L .45713 .46236 L p .774 .849 .908 r
F P
0 g
s
.47202 .45335 m .48052 .46335 L .49412 .45605 L p .782 .841 .897 r
F P
0 g
s
.23354 .54715 m .25531 .54733 L .26445 .53452 L p .698 .86 .96 r
F P
0 g
s
.28554 .53497 m .26445 .53452 L .25531 .54733 L p .708 .863 .956 r
F P
0 g
s
.6778 .26171 m .66803 .29124 L .68831 .2931 L p .802 .73 .784 r
F P
0 g
s
.68831 .2931 m .69967 .26459 L .6778 .26171 L p .802 .73 .784 r
F P
0 g
s
.48742 .44442 m .49412 .45605 L .50806 .44907 L p .789 .832 .885 r
F P
0 g
s
.50806 .44907 m .50321 .43573 L .48742 .44442 L p .789 .832 .885 r
F P
0 g
s
.49412 .45605 m .48742 .44442 L .47202 .45335 L p .782 .841 .897 r
F P
0 g
s
.41661 .48946 m .4015 .48501 L .38837 .495 L p .744 .874 .94 r
F P
0 g
s
.4015 .48501 m .41661 .48946 L .42932 .48043 L p .751 .875 .936 r
F P
0 g
s
.37637 .50498 m .3585 .50272 L .34664 .51347 L p .733 .879 .948 r
F P
0 g
s
.3585 .50272 m .37637 .50498 L .38837 .495 L p .735 .884 .948 r
F P
0 g
s
.73377 .17127 m .72241 .20371 L .74602 .21075 L p .802 .711 .764 r
F P
0 g
s
.74602 .21075 m .75885 .17955 L .73377 .17127 L p .802 .711 .764 r
F P
0 g
s
.5928 .35542 m .58827 .37998 L .60566 .37581 L p .812 .763 .807 r
F P
0 g
s
.60566 .37581 m .61198 .3505 L .5928 .35542 L p .812 .763 .807 r
F P
0 g
s
.64676 .29143 m .63867 .32031 L .65827 .31954 L p .805 .736 .788 r
F P
0 g
s
.65827 .31954 m .66803 .29124 L .64676 .29143 L p .805 .736 .788 r
F P
0 g
s
.55251 .39313 m .55171 .41294 L .56784 .40715 L p .811 .788 .831 r
F P
0 g
s
.56784 .40715 m .57052 .38577 L .55251 .39313 L p .811 .788 .831 r
F P
0 g
s
.15905 .56006 m .1815 .56049 L .1896 .54588 L p .671 .842 .965 r
F P
0 g
s
.21164 .54666 m .1896 .54588 L .1815 .56049 L p .679 .847 .963 r
F P
0 g
s
.61832 .32327 m .61198 .3505 L .6306 .34763 L p .809 .747 .794 r
F P
0 g
s
.6306 .34763 m .63867 .32031 L .61832 .32327 L p .809 .747 .794 r
F P
0 g
s
.26445 .53452 m .28554 .53497 L .29597 .52284 L p .707 .872 .959 r
F P
0 g
s
.31618 .5236 m .29597 .52284 L .28554 .53497 L p .717 .874 .955 r
F P
0 g
s
.74515 .1386 m .73377 .17127 L .75885 .17955 L p .805 .709 .759 r
F P
0 g
s
.75885 .17955 m .77166 .14731 L .74515 .1386 L p .805 .709 .759 r
F P
0 g
s
.68759 .23078 m .6778 .26171 L .69967 .26459 L p .798 .718 .776 r
F P
0 g
s
.69967 .26459 m .71105 .23487 L .68759 .23078 L p .798 .718 .776 r
F P
0 g
s
.34664 .51347 m .32752 .51215 L .31618 .5236 L p .725 .88 .952 r
F P
0 g
s
.32752 .51215 m .34664 .51347 L .3585 .50272 L p .726 .887 .955 r
F P
0 g
s
.42932 .48043 m .41568 .47494 L .4015 .48501 L p .751 .875 .936 r
F P
0 g
s
.41568 .47494 m .42932 .48043 L .44286 .47139 L p .761 .873 .929 r
F P
0 g
s
.29597 .52284 m .31618 .5236 L .32752 .51215 L p .716 .883 .958 r
F P
0 g
s
.75676 .11006 m .74515 .1386 L .77166 .14731 L p .847 .745 .751 r
F P
0 g
s
.77166 .14731 m .78435 .11228 L .75676 .11006 L p .847 .745 .751 r
F P
0 g
s
.53438 .40185 m .53548 .41976 L .55171 .41294 L p .813 .799 .839 r
F P
0 g
s
.55171 .41294 m .55251 .39313 L .53438 .40185 L p .813 .799 .839 r
F P
0 g
s
.21164 .54666 m .23354 .54715 L .2432 .53376 L p .688 .858 .964 r
F P
0 g
s
.26445 .53452 m .2432 .53376 L .23354 .54715 L p .698 .86 .96 r
F P
0 g
s
.38837 .495 m .37171 .49198 L .3585 .50272 L p .735 .884 .948 r
F P
0 g
s
.37171 .49198 m .38837 .495 L .4015 .48501 L p .74 .888 .947 r
F P
0 g
s
.57321 .36252 m .57052 .38577 L .58827 .37998 L p .816 .77 .81 r
F P
0 g
s
.58827 .37998 m .5928 .35542 L .57321 .36252 L p .816 .77 .81 r
F P
0 g
s
.65486 .26101 m .64676 .29143 L .66803 .29124 L p .8 .723 .779 r
F P
0 g
s
.66803 .29124 m .6778 .26171 L .65486 .26101 L p .8 .723 .779 r
F P
0 g
s
.69736 .19826 m .68759 .23078 L .71105 .23487 L p .794 .706 .767 r
F P
0 g
s
.71105 .23487 m .72241 .20371 L .69736 .19826 L p .794 .706 .767 r
F P
0 g
s
.44286 .47139 m .43079 .46474 L .41568 .47494 L p .761 .873 .929 r
F P
0 g
s
.43079 .46474 m .44286 .47139 L .45713 .46236 L p .772 .868 .919 r
F P
0 g
s
.51627 .41164 m .51927 .42743 L .53548 .41976 L p .813 .811 .849 r
F P
0 g
s
.53548 .41976 m .53438 .40185 L .51627 .41164 L p .813 .811 .849 r
F P
0 g
s
.1364 .56055 m .15905 .56006 L .16744 .54474 L p .681 .813 .946 r
F P
0 g
s
.1896 .54588 m .16744 .54474 L .15905 .56006 L p .671 .842 .965 r
F P
0 g
s
.62467 .29418 m .61832 .32327 L .63867 .32031 L p .807 .734 .784 r
F P
0 g
s
.63867 .32031 m .64676 .29143 L .62467 .29418 L p .807 .734 .784 r
F P
0 g
s
.59735 .32883 m .5928 .35542 L .61198 .3505 L p .814 .751 .794 r
F P
0 g
s
.61198 .3505 m .61832 .32327 L .59735 .32883 L p .814 .751 .794 r
F P
0 g
s
.45713 .46236 m .44674 .45432 L .43079 .46474 L p .772 .868 .919 r
F P
0 g
s
.44674 .45432 m .45713 .46236 L .47202 .45335 L p .784 .86 .906 r
F P
0 g
s
.4983 .42211 m .50321 .43573 L .51927 .42743 L p .81 .824 .861 r
F P
0 g
s
.51927 .42743 m .51627 .41164 L .4983 .42211 L p .81 .824 .861 r
F P
0 g
s
.70713 .16431 m .69736 .19826 L .72241 .20371 L p .791 .695 .759 r
F P
0 g
s
.72241 .20371 m .73377 .17127 L .70713 .16431 L p .791 .695 .759 r
F P
0 g
s
.2432 .53376 m .26445 .53452 L .27558 .52185 L p .696 .87 .964 r
F P
0 g
s
.29597 .52284 m .27558 .52185 L .26445 .53452 L p .707 .872 .959 r
F P
0 g
s
.47202 .45335 m .4634 .44368 L .44674 .45432 L p .784 .86 .906 r
F P
0 g
s
.4634 .44368 m .47202 .45335 L .48742 .44442 L p .795 .85 .892 r
F P
0 g
s
.48063 .43289 m .48742 .44442 L .50321 .43573 L p .804 .838 .876 r
F P
0 g
s
.50321 .43573 m .4983 .42211 L .48063 .43289 L p .804 .838 .876 r
F P
0 g
s
.55332 .37175 m .55251 .39313 L .57052 .38577 L p .822 .781 .814 r
F P
0 g
s
.57052 .38577 m .57321 .36252 L .55332 .37175 L p .822 .781 .814 r
F P
0 g
s
.66297 .22887 m .65486 .26101 L .6778 .26171 L p .794 .709 .77 r
F P
0 g
s
.6778 .26171 m .68759 .23078 L .66297 .22887 L p .794 .709 .77 r
F P
0 g
s
.3585 .50272 m .34042 .50079 L .32752 .51215 L p .726 .887 .955 r
F P
0 g
s
.34042 .50079 m .3585 .50272 L .37171 .49198 L p .727 .895 .955 r
F P
0 g
s
.48742 .44442 m .48063 .43289 L .4634 .44368 L p .795 .85 .892 r
F P
0 g
s
.4015 .48501 m .38619 .48119 L .37171 .49198 L p .74 .888 .947 r
F P
0 g
s
.38619 .48119 m .4015 .48501 L .41568 .47494 L p .749 .89 .943 r
F P
0 g
s
.1896 .54588 m .21164 .54666 L .22179 .53273 L p .678 .857 .968 r
F P
0 g
s
.2432 .53376 m .22179 .53273 L .21164 .54666 L p .688 .858 .964 r
F P
0 g
s
.71688 .12925 m .70713 .16431 L .73377 .17127 L p .781 .683 .756 r
F P
0 g
s
.73377 .17127 m .74515 .1386 L .71688 .12925 L p .781 .683 .756 r
F P
0 g
s
.27558 .52185 m .29597 .52284 L .30818 .51085 L p .705 .882 .963 r
F P
0 g
s
.32752 .51215 m .30818 .51085 L .29597 .52284 L p .716 .883 .958 r
F P
0 g
s
.30818 .51085 m .32752 .51215 L .34042 .50079 L p .715 .892 .961 r
F P
0 g
s
.16744 .54474 m .14522 .54241 L .1364 .56055 L p .681 .813 .946 r
F P
0 g
s
.63103 .26313 m .62467 .29418 L .64676 .29143 L p .802 .72 .775 r
F P
0 g
s
.64676 .29143 m .65486 .26101 L .63103 .26313 L p .802 .72 .775 r
F P
0 g
s
.57591 .33729 m .57321 .36252 L .5928 .35542 L p .821 .76 .795 r
F P
0 g
s
.5928 .35542 m .59735 .32883 L .57591 .33729 L p .821 .76 .795 r
F P
0 g
s
.53328 .38286 m .53438 .40185 L .55251 .39313 L p .827 .796 .822 r
F P
0 g
s
.55251 .39313 m .55332 .37175 L .53328 .38286 L p .827 .796 .822 r
F P
0 g
s
.60191 .30012 m .59735 .32883 L .61832 .32327 L p .813 .739 .782 r
F P
0 g
s
.61832 .32327 m .62467 .29418 L .60191 .30012 L p .813 .739 .782 r
F P
0 g
s
.67106 .19491 m .66297 .22887 L .68759 .23078 L p .789 .695 .761 r
F P
0 g
s
.68759 .23078 m .69736 .19826 L .67106 .19491 L p .789 .695 .761 r
F P
0 g
s
.72653 .09094 m .71688 .12925 L .74515 .1386 L p .722 .639 .764 r
F P
0 g
s
.74515 .1386 m .75676 .11006 L .72653 .09094 L p .722 .639 .764 r
F P
0 g
s
.41568 .47494 m .40183 .47022 L .38619 .48119 L p .749 .89 .943 r
F P
0 g
s
.40183 .47022 m .41568 .47494 L .43079 .46474 L p .761 .89 .935 r
F P
0 g
s
.37171 .49198 m .35483 .48945 L .34042 .50079 L p .727 .895 .955 r
F P
0 g
s
.35483 .48945 m .37171 .49198 L .38619 .48119 L p .732 .902 .954 r
F P
0 g
s
.51323 .39534 m .51627 .41164 L .53438 .40185 L p .83 .812 .834 r
F P
0 g
s
.53438 .40185 m .53328 .38286 L .51323 .39534 L p .83 .812 .834 r
F P
0 g
s
.67914 .15945 m .67106 .19491 L .69736 .19826 L p .784 .683 .752 r
F P
0 g
s
.69736 .19826 m .70713 .16431 L .67914 .15945 L p .784 .683 .752 r
F P
0 g
s
.16744 .54474 m .1896 .54588 L .20021 .53149 L p .665 .857 .973 r
F P
0 g
s
.22179 .53273 m .20021 .53149 L .1896 .54588 L p .678 .857 .968 r
F P
0 g
s
.63738 .22988 m .63103 .26313 L .65486 .26101 L p .795 .704 .764 r
F P
0 g
s
.65486 .26101 m .66297 .22887 L .63738 .22988 L p .795 .704 .764 r
F P
0 g
s
.22179 .53273 m .2432 .53376 L .25501 .52056 L p .685 .868 .968 r
F P
0 g
s
.27558 .52185 m .25501 .52056 L .2432 .53376 L p .696 .87 .964 r
F P
0 g
s
.55413 .34873 m .55332 .37175 L .57321 .36252 L p .831 .775 .798 r
F P
0 g
s
.57321 .36252 m .57591 .33729 L .55413 .34873 L p .831 .775 .798 r
F P
0 g
s
.43079 .46474 m .41855 .45892 L .40183 .47022 L p .761 .89 .935 r
F P
0 g
s
.41855 .45892 m .43079 .46474 L .44674 .45432 L p .777 .886 .924 r
F P
0 g
s
.60646 .26897 m .60191 .30012 L .62467 .29418 L p .809 .723 .771 r
F P
0 g
s
.62467 .29418 m .63103 .26313 L .60646 .26897 L p .809 .723 .771 r
F P
0 g
s
.49333 .40854 m .4983 .42211 L .51627 .41164 L p .828 .83 .849 r
F P
0 g
s
.51627 .41164 m .51323 .39534 L .49333 .40854 L p .828 .83 .849 r
F P
0 g
s
.57862 .30985 m .57591 .33729 L .59735 .32883 L p .824 .749 .781 r
F P
0 g
s
.59735 .32883 m .60191 .30012 L .57862 .30985 L p .824 .749 .781 r
F P
0 g
s
.68724 .12378 m .67914 .15945 L .70713 .16431 L p .784 .678 .747 r
F P
0 g
s
.70713 .16431 m .71688 .12925 L .68724 .12378 L p .784 .678 .747 r
F P
0 g
s
.34042 .50079 m .32213 .49899 L .30818 .51085 L p .715 .892 .961 r
F P
0 g
s
.32213 .49899 m .34042 .50079 L .35483 .48945 L p .715 .902 .962 r
F P
0 g
s
.44674 .45432 m .4362 .44714 L .41855 .45892 L p .777 .886 .924 r
F P
0 g
s
.4362 .44714 m .44674 .45432 L .4634 .44368 L p .794 .878 .908 r
F P
0 g
s
.25501 .52056 m .27558 .52185 L .28866 .50937 L p .693 .88 .968 r
F P
0 g
s
.30818 .51085 m .28866 .50937 L .27558 .52185 L p .705 .882 .963 r
F P
0 g
s
.64371 .19435 m .63738 .22988 L .66297 .22887 L p .786 .686 .754 r
F P
0 g
s
.66297 .22887 m .67106 .19491 L .64371 .19435 L p .786 .686 .754 r
F P
0 g
s
.47375 .42183 m .48063 .43289 L .4983 .42211 L p .822 .849 .868 r
F P
0 g
s
.4983 .42211 m .49333 .40854 L .47375 .42183 L p .822 .849 .868 r
F P
0 g
s
.4634 .44368 m .45465 .43477 L .4362 .44714 L p .794 .878 .908 r
F P
0 g
s
.45465 .43477 m .4634 .44368 L .48063 .43289 L p .81 .865 .889 r
F P
0 g
s
.28866 .50937 m .30818 .51085 L .32213 .49899 L p .702 .892 .966 r
F P
0 g
s
.48063 .43289 m .47375 .42183 L .45465 .43477 L p .81 .865 .889 r
F P
0 g
s
.69554 .09305 m .68724 .12378 L .71688 .12925 L p .825 .709 .736 r
F P
0 g
s
.71688 .12925 m .72653 .09094 L .69554 .09305 L p .825 .709 .736 r
F P
0 g
s
.38619 .48119 m .37065 .47803 L .35483 .48945 L p .732 .902 .954 r
F P
0 g
s
.37065 .47803 m .38619 .48119 L .40183 .47022 L p .741 .907 .951 r
F P
0 g
s
.53216 .36281 m .53328 .38286 L .55332 .37175 L p .841 .793 .805 r
F P
0 g
s
.55332 .37175 m .55413 .34873 L .53216 .36281 L p .841 .793 .805 r
F P
0 g
s
.14522 .54241 m .16744 .54474 L .17847 .5301 L p .626 .869 .988 r
F P
0 g
s
.20021 .53149 m .17847 .5301 L .16744 .54474 L p .665 .857 .973 r
F P
0 g
s
.61101 .23496 m .60646 .26897 L .63103 .26313 L p .801 .704 .759 r
F P
0 g
s
.63103 .26313 m .63738 .22988 L .61101 .23496 L p .801 .704 .759 r
F P
0 g
s
.65003 .15687 m .64371 .19435 L .67106 .19491 L p .777 .67 .746 r
F P
0 g
s
.67106 .19491 m .67914 .15945 L .65003 .15687 L p .777 .67 .746 r
F P
0 g
s
.20021 .53149 m .22179 .53273 L .23426 .51905 L p .675 .867 .972 r
F P
0 g
s
.25501 .52056 m .23426 .51905 L .22179 .53273 L p .685 .868 .968 r
F P
0 g
s
.55495 .32375 m .55413 .34873 L .57591 .33729 L p .839 .766 .782 r
F P
0 g
s
.57591 .33729 m .57862 .30985 L .55495 .32375 L p .839 .766 .782 r
F P
0 g
s
.58133 .27963 m .57862 .30985 L .60191 .30012 L p .823 .734 .767 r
F P
0 g
s
.60191 .30012 m .60646 .26897 L .58133 .27963 L p .823 .734 .767 r
F P
0 g
s
.51015 .37873 m .51323 .39534 L .53328 .38286 L p .848 .816 .818 r
F P
0 g
s
.53328 .38286 m .53216 .36281 L .51015 .37873 L p .848 .816 .818 r
F P
0 g
s
.40183 .47022 m .38778 .46634 L .37065 .47803 L p .741 .907 .951 r
F P
0 g
s
.38778 .46634 m .40183 .47022 L .41855 .45892 L p .757 .91 .943 r
F P
0 g
s
.65632 .11799 m .65003 .15687 L .67914 .15945 L p .762 .654 .744 r
F P
0 g
s
.67914 .15945 m .68724 .12378 L .65632 .11799 L p .762 .654 .744 r
F P
0 g
s
.35483 .48945 m .33772 .48721 L .32213 .49899 L p .715 .902 .962 r
F P
0 g
s
.33772 .48721 m .35483 .48945 L .37065 .47803 L p .718 .911 .962 r
F P
0 g
s
.61553 .19786 m .61101 .23496 L .63738 .22988 L p .79 .683 .747 r
F P
0 g
s
.63738 .22988 m .64371 .19435 L .61553 .19786 L p .79 .683 .747 r
F P
0 g
s
.17847 .5301 m .15652 .52907 L .14522 .54241 L p .626 .869 .988 r
F P
0 g
s
.23426 .51905 m .25501 .52056 L .26893 .50765 L p .681 .878 .972 r
F P
0 g
s
.28866 .50937 m .26893 .50765 L .25501 .52056 L p .693 .88 .968 r
F P
0 g
s
.66253 .0749 m .65632 .11799 L .68724 .12378 L p .69 .605 .756 r
F P
0 g
s
.68724 .12378 m .69554 .09305 L .66253 .0749 L p .69 .605 .756 r
F P
0 g
s
.48829 .39538 m .49333 .40854 L .51323 .39534 L p .849 .84 .837 r
F P
0 g
s
.51323 .39534 m .51015 .37873 L .48829 .39538 L p .849 .84 .837 r
F P
0 g
s
.41855 .45892 m .4061 .45414 L .38778 .46634 L p .757 .91 .943 r
F P
0 g
s
.4061 .45414 m .41855 .45892 L .4362 .44714 L p .778 .909 .93 r
F P
0 g
s
.58402 .24581 m .58133 .27963 L .60646 .26897 L p .816 .714 .752 r
F P
0 g
s
.60646 .26897 m .61101 .23496 L .58402 .24581 L p .816 .714 .752 r
F P
0 g
s
.32213 .49899 m .30362 .49711 L .28866 .50937 L p .702 .892 .966 r
F P
0 g
s
.30362 .49711 m .32213 .49899 L .33772 .48721 L p .7 .903 .968 r
F P
0 g
s
.53103 .34153 m .53216 .36281 L .55413 .34873 L p .855 .79 .787 r
F P
0 g
s
.55413 .34873 m .55495 .32375 L .53103 .34153 L p .855 .79 .787 r
F P
0 g
s
.62002 .15809 m .61553 .19786 L .64371 .19435 L p .777 .663 .738 r
F P
0 g
s
.64371 .19435 m .65003 .15687 L .62002 .15809 L p .777 .663 .738 r
F P
0 g
s
.26893 .50765 m .28866 .50937 L .30362 .49711 L p .688 .89 .972 r
F P
0 g
s
.17847 .5301 m .20021 .53149 L .21332 .51738 L p .666 .865 .975 r
F P
0 g
s
.23426 .51905 m .21332 .51738 L .20021 .53149 L p .675 .867 .972 r
F P
0 g
s
.55576 .29611 m .55495 .32375 L .57862 .30985 L p .843 .754 .765 r
F P
0 g
s
.57862 .30985 m .58133 .27963 L .55576 .29611 L p .843 .754 .765 r
F P
0 g
s
.46675 .41169 m .47375 .42183 L .49333 .40854 L p .841 .865 .861 r
F P
0 g
s
.49333 .40854 m .48829 .39538 L .46675 .41169 L p .841 .865 .861 r
F P
0 g
s
.4362 .44714 m .42547 .44111 L .4061 .45414 L p .778 .909 .93 r
F P
0 g
s
.42547 .44111 m .4362 .44714 L .45465 .43477 L p .802 .902 .912 r
F P
0 g
s
.62451 .11745 m .62002 .15809 L .65003 .15687 L p .769 .65 .732 r
F P
0 g
s
.65003 .15687 m .65632 .11799 L .62451 .11745 L p .769 .65 .732 r
F P
0 g
s
.37065 .47803 m .35488 .47536 L .33772 .48721 L p .718 .911 .962 r
F P
0 g
s
.35488 .47536 m .37065 .47803 L .38778 .46634 L p .727 .92 .958 r
F P
0 g
s
.44575 .427 m .45465 .43477 L .47375 .42183 L p .825 .887 .887 r
F P
0 g
s
.47375 .42183 m .46675 .41169 L .44575 .427 L p .825 .887 .887 r
F P
0 g
s
.45465 .43477 m .44575 .427 L .42547 .44111 L p .802 .902 .912 r
F P
0 g
s
.5867 .20762 m .58402 .24581 L .61101 .23496 L p .803 .688 .739 r
F P
0 g
s
.61101 .23496 m .61553 .19786 L .5867 .20762 L p .803 .688 .739 r
F P
0 g
s
.62912 .08311 m .62451 .11745 L .65632 .11799 L p .807 .673 .716 r
F P
0 g
s
.65632 .11799 m .66253 .0749 L .62912 .08311 L p .807 .673 .716 r
F P
0 g
s
.50704 .36193 m .51015 .37873 L .53216 .36281 L p .867 .819 .799 r
F P
0 g
s
.53216 .36281 m .53103 .34153 L .50704 .36193 L p .867 .819 .799 r
F P
0 g
s
.58934 .16486 m .5867 .20762 L .61553 .19786 L p .783 .661 .728 r
F P
0 g
s
.61553 .19786 m .62002 .15809 L .58934 .16486 L p .783 .661 .728 r
F P
0 g
s
.21332 .51738 m .23426 .51905 L .24901 .50573 L p .669 .877 .976 r
F P
0 g
s
.26893 .50765 m .24901 .50573 L .23426 .51905 L p .681 .878 .972 r
F P
0 g
s
.55658 .26461 m .55576 .29611 L .58133 .27963 L p .842 .735 .746 r
F P
0 g
s
.58133 .27963 m .58402 .24581 L .55658 .26461 L p .842 .735 .746 r
F P
0 g
s
.5299 .31852 m .53103 .34153 L .55495 .32375 L p .867 .783 .765 r
F P
0 g
s
.55495 .32375 m .55576 .29611 L .5299 .31852 L p .867 .783 .765 r
F P
0 g
s
.33772 .48721 m .3204 .48501 L .30362 .49711 L p .7 .903 .968 r
F P
0 g
s
.3204 .48501 m .33772 .48721 L .35488 .47536 L p .7 .915 .968 r
F P
0 g
s
.52653 .22406 m .52551 .16631 L .49071 .2911 L p .953 .752 .594 r
F P
0 g
s
.49071 .2911 m .49416 .29688 L .52653 .22406 L p .953 .752 .594 r
F P
0 g
s
.49746 .31125 m .49416 .29688 L .47453 .33497 L p .977 .91 .671 r
F P
0 g
s
.47453 .33497 m .46144 .36036 L p .46967 .34914 L .977 .91 .671 r
F P
0 g
s
.49746 .31125 m .47453 .33497 L .46967 .34914 L .977 .91 .671 r
F
.44493 .39137 m .47263 .36266 L p .44361 .38556 L .891 .987 .797 r
F P
0 g
s
.47263 .36266 m .46715 .35749 L .43728 .39055 L p .891 .987 .797 r
F P
0 g
s
.46715 .35749 m .48897 .32421 L p .46197 .35967 L .977 .91 .671 r
F P
0 g
s
.48631 .32646 m .46144 .36036 L .48897 .32421 L .977 .91 .671 r
F
.4654 .35269 m .49416 .29688 L p .47439 .33913 L .944 .909 .527 r
F P
0 g
s
.49416 .29688 m .48035 .32266 L .47639 .33486 L .944 .909 .527 r
F
.48035 .32266 m .47167 .33885 L .47632 .33491 L F
.48035 .32266 m .47632 .33491 L .47639 .33486 L F
.49071 .2911 m .4957 .2732 L p .49439 .27989 L .95 .711 .541 r
F P
0 g
s
.49071 .2911 m .47167 .33885 L p .48035 .32266 L .944 .909 .527 r
F P
0 g
s
.49416 .29688 m .49071 .2911 L p .48035 .32266 L .944 .909 .527 r
F P
0 g
s
.50593 .24335 m .50437 .24948 L .4957 .2732 L .95 .711 .541 r
F
.50437 .24948 m .48678 .31871 L .49439 .27989 L F
.50437 .24948 m .49439 .27989 L .4957 .2732 L F
.48678 .31871 m .49071 .2911 L p .49439 .27989 L F P
0 g
s
.43669 .42068 m .44575 .427 L .46675 .41169 L p .838 .914 .887 r
F P
0 g
s
.46675 .41169 m .45963 .40286 L .43669 .42068 L p .838 .914 .887 r
F P
0 g
s
.45237 .39584 m .45963 .40286 L .48316 .38297 L p .883 .912 .842 r
F P
0 g
s
.48316 .38297 m .47795 .37178 L .45237 .39584 L p .883 .912 .842 r
F P
0 g
s
.42744 .41606 m .43669 .42068 L .45963 .40286 L p .844 .946 .886 r
F P
0 g
s
.45963 .40286 m .45237 .39584 L .42744 .41606 L p .844 .946 .886 r
F P
0 g
s
.44493 .39137 m .45237 .39584 L .47795 .37178 L p .9 .945 .828 r
F P
0 g
s
.47795 .37178 m .47263 .36266 L .44493 .39137 L p .9 .945 .828 r
F P
0 g
s
.46715 .35749 m .47263 .36266 L .5007 .32789 L p .951 .892 .734 r
F P
0 g
s
.5007 .32789 m .49746 .31125 L .46715 .35749 L p .951 .892 .734 r
F P
0 g
s
.48678 .31871 m .44832 .43237 L p .48111 .32308 L 0 0 .051 r
F P
0 g
s
.49071 .2911 m .48804 .30984 L p .48111 .32308 L 0 0 .051 r
F P
0 g
s
.48804 .30984 m .48678 .31871 L p .48111 .32308 L 0 0 .051 r
F P
0 g
s
.46144 .36036 m .46167 .36025 L p .46197 .35967 L .977 .91 .671 r
F P
0 g
s
.46167 .36025 m .46715 .35749 L p .46197 .35967 L .977 .91 .671 r
F P
0 g
s
.48897 .32421 m .49746 .31125 L p .48631 .32646 L .977 .91 .671 r
F P
0 g
s
.47439 .33913 m .47147 .34537 L .4654 .35269 L .944 .909 .527 r
F
.44776 .37896 m .46715 .35749 L p .45336 .37102 L .671 .925 .622 r
F P
0 g
s
.46144 .36036 m .42937 .39455 L p .45336 .37102 L .671 .925 .622 r
F P
0 g
s
.46715 .35749 m .46144 .36036 L p .45336 .37102 L .671 .925 .622 r
F P
0 g
s
.47147 .34537 m .46929 .35001 L .4644 .35538 L .944 .909 .527 r
F
.46929 .35001 m .4553 .37992 L .46361 .3575 L F
.46929 .35001 m .46361 .3575 L .4644 .35538 L F
.47147 .34537 m .4644 .35538 L .4654 .35269 L F
.42937 .39455 m .43728 .39055 L .44776 .37896 L p .671 .925 .622 r
F P
0 g
s
.45336 .37102 m .42937 .39455 L .44776 .37896 L .671 .925 .622 r
F
.47167 .33885 m .4553 .37992 L p .47639 .33486 L .944 .909 .527 r
F P
0 g
s
.4553 .37992 m .46144 .36036 L .4654 .35269 L p .944 .909 .527 r
F P
0 g
s
.43728 .39055 m .4401 .39085 L p .44361 .38556 L .891 .987 .797 r
F P
0 g
s
.4401 .39085 m .44493 .39137 L p .44361 .38556 L .891 .987 .797 r
F P
0 g
s
.4957 .2732 m .52551 .16631 L p .50593 .24335 L .95 .711 .541 r
F P
0 g
s
.52551 .16631 m .52475 .05273 L .48678 .31871 L p .95 .711 .541 r
F P
0 g
s
.52475 .05273 m .52551 .16631 L .55893 .13014 L p .576 .464 .69 r
F P
0 g
s
.55893 .13014 m .55971 .08291 L .52475 .05273 L p .576 .464 .69 r
F P
0 g
s
.15652 .52907 m .17847 .5301 L .1922 .51551 L p .67 .853 .97 r
F P
0 g
s
.21332 .51738 m .1922 .51551 L .17847 .5301 L p .666 .865 .975 r
F P
0 g
s
.38778 .46634 m .37349 .4632 L .35488 .47536 L p .727 .92 .958 r
F P
0 g
s
.37349 .4632 m .38778 .46634 L .4061 .45414 L p .744 .928 .951 r
F P
0 g
s
.59194 .11818 m .58934 .16486 L .62002 .15809 L p .753 .631 .725 r
F P
0 g
s
.62002 .15809 m .62451 .11745 L .59194 .11818 L p .753 .631 .725 r
F P
0 g
s
.48316 .38297 m .48829 .39538 L .51015 .37873 L p .871 .852 .821 r
F P
0 g
s
.51015 .37873 m .50704 .36193 L .48316 .38297 L p .871 .852 .821 r
F P
0 g
s
.24901 .50573 m .26893 .50765 L .28491 .49505 L p .674 .889 .976 r
F P
0 g
s
.30362 .49711 m .28491 .49505 L .26893 .50765 L p .688 .89 .972 r
F P
0 g
s
.59445 .06387 m .59194 .11818 L .62451 .11745 L p .647 .558 .74 r
F P
0 g
s
.62451 .11745 m .62912 .08311 L .59445 .06387 L p .647 .558 .74 r
F P
0 g
s
.28491 .49505 m .30362 .49711 L .3204 .48501 L p .683 .902 .974 r
F P
0 g
s
.59194 .11818 m .59445 .06387 L .55971 .08291 L p .791 .63 .681 r
F P
0 g
s
.55738 .22751 m .55658 .26461 L .58402 .24581 L p .832 .708 .728 r
F P
0 g
s
.58402 .24581 m .5867 .20762 L .55738 .22751 L p .832 .708 .728 r
F P
0 g
s
.4061 .45414 m .39343 .45037 L .37349 .4632 L p .744 .928 .951 r
F P
0 g
s
.39343 .45037 m .4061 .45414 L .42547 .44111 L p .77 .932 .937 r
F P
0 g
s
.45963 .40286 m .46675 .41169 L .48829 .39538 L p .862 .886 .853 r
F P
0 g
s
.48829 .39538 m .48316 .38297 L .45963 .40286 L p .862 .886 .853 r
F P
0 g
s
.55817 .18281 m .55738 .22751 L .5867 .20762 L p .81 .673 .713 r
F P
0 g
s
.5867 .20762 m .58934 .16486 L .55817 .18281 L p .81 .673 .713 r
F P
0 g
s
.55971 .08291 m .55893 .13014 L .59194 .11818 L p .791 .63 .681 r
F P
0 g
s
.58934 .16486 m .59194 .11818 L .55893 .13014 L p .777 .634 .703 r
F P
0 g
s
.50389 .34495 m .50704 .36193 L .53103 .34153 L p .888 .82 .775 r
F P
0 g
s
.53103 .34153 m .5299 .31852 L .50389 .34495 L p .888 .82 .775 r
F P
0 g
s
.52877 .2928 m .5299 .31852 L .55576 .29611 L p .876 .769 .74 r
F P
0 g
s
.55576 .29611 m .55658 .26461 L .52877 .2928 L p .876 .769 .74 r
F P
0 g
s
.55893 .13014 m .55817 .18281 L .58934 .16486 L p .777 .634 .703 r
F P
0 g
s
.42547 .44111 m .41455 .43637 L .39343 .45037 L p .77 .932 .937 r
F P
0 g
s
.41455 .43637 m .42547 .44111 L .44575 .427 L p .804 .929 .916 r
F P
0 g
s
.35488 .47536 m .33889 .47292 L .3204 .48501 L p .7 .915 .968 r
F P
0 g
s
.33889 .47292 m .35488 .47536 L .37349 .4632 L p .705 .927 .965 r
F P
0 g
s
.1922 .51551 m .21332 .51738 L .22888 .50367 L p .657 .875 .98 r
F P
0 g
s
.24901 .50573 m .22888 .50367 L .21332 .51738 L p .669 .877 .976 r
F P
0 g
s
.1922 .51551 m .17092 .51302 L .15652 .52907 L p .67 .853 .97 r
F P
0 g
s
.44575 .427 m .43669 .42068 L .41455 .43637 L p .804 .929 .916 r
F P
0 g
s
.3204 .48501 m .30285 .48272 L .28491 .49505 L p .683 .902 .974 r
F P
0 g
s
.30285 .48272 m .3204 .48501 L .33889 .47292 L p .679 .915 .974 r
F P
0 g
s
.22888 .50367 m .24901 .50573 L .26598 .49281 L p .66 .887 .98 r
F P
0 g
s
.28491 .49505 m .26598 .49281 L .24901 .50573 L p .674 .889 .976 r
F P
0 g
s
.52764 .2626 m .52877 .2928 L .55658 .26461 L p .879 .747 .713 r
F P
0 g
s
.55658 .26461 m .55738 .22751 L .52764 .2626 L p .879 .747 .713 r
F P
0 g
s
.47795 .37178 m .48316 .38297 L .50704 .36193 L p .896 .865 .801 r
F P
0 g
s
.50704 .36193 m .50389 .34495 L .47795 .37178 L p .896 .865 .801 r
F P
0 g
s
.26598 .49281 m .28491 .49505 L .30285 .48272 L p .666 .9 .979 r
F P
0 g
s
.55817 .18281 m .55893 .13014 L .52551 .16631 L p .829 .663 .677 r
F P
0 g
s
.37349 .4632 m .35898 .46056 L .33889 .47292 L p .705 .927 .965 r
F P
0 g
s
.35898 .46056 m .37349 .4632 L .39343 .45037 L p .72 .94 .957 r
F P
0 g
s
.5007 .32789 m .50389 .34495 L .5299 .31852 L p .908 .815 .744 r
F P
0 g
s
.5299 .31852 m .52877 .2928 L .5007 .32789 L p .908 .815 .744 r
F P
0 g
s
.52653 .22406 m .52764 .2626 L .55738 .22751 L p .87 .716 .688 r
F P
0 g
s
.55738 .22751 m .55817 .18281 L .52653 .22406 L p .87 .716 .688 r
F P
0 g
s
.17092 .51302 m .1922 .51551 L .20855 .50148 L p .636 .872 .986 r
F P
0 g
s
.22888 .50367 m .20855 .50148 L .1922 .51551 L p .657 .875 .98 r
F P
0 g
s
.52551 .16631 m .52653 .22406 L .55817 .18281 L p .829 .663 .677 r
F P
0 g
s
.39343 .45037 m .38055 .44746 L .35898 .46056 L p .72 .94 .957 r
F P
0 g
s
.38055 .44746 m .39343 .45037 L .41455 .43637 L p .748 .952 .943 r
F P
0 g
s
.33889 .47292 m .32267 .47053 L .30285 .48272 L p .679 .915 .974 r
F P
0 g
s
.32267 .47053 m .33889 .47292 L .35898 .46056 L p .678 .929 .97 r
F P
0 g
s
.41455 .43637 m .40342 .43294 L .38055 .44746 L p .748 .952 .943 r
F P
0 g
s
.40342 .43294 m .41455 .43637 L .43669 .42068 L p .793 .957 .92 r
F P
0 g
s
.20855 .50148 m .22888 .50367 L .24683 .49049 L p .645 .886 .984 r
F P
0 g
s
.26598 .49281 m .24683 .49049 L .22888 .50367 L p .66 .887 .98 r
F P
0 g
s
.43669 .42068 m .42744 .41606 L .40342 .43294 L p .793 .957 .92 r
F P
0 g
s
.30285 .48272 m .28509 .4803 L .26598 .49281 L p .666 .9 .979 r
F P
0 g
s
.28509 .4803 m .30285 .48272 L .32267 .47053 L p .656 .912 .979 r
F P
0 g
s
.49746 .31125 m .5007 .32789 L .52877 .2928 L p .927 .804 .704 r
F P
0 g
s
.52877 .2928 m .52764 .2626 L .49746 .31125 L p .927 .804 .704 r
F P
0 g
s
.24683 .49049 m .26598 .49281 L .28509 .4803 L p .65 .897 .983 r
F P
0 g
s
.47263 .36266 m .47795 .37178 L .50389 .34495 L p .923 .877 .773 r
F P
0 g
s
.50389 .34495 m .5007 .32789 L .47263 .36266 L p .923 .877 .773 r
F P
0 g
s
.20855 .50148 m .18801 .49909 L .17092 .51302 L p .636 .872 .986 r
F P
0 g
s
.35898 .46056 m .34424 .4582 L .32267 .47053 L p .678 .929 .97 r
F P
0 g
s
.34424 .4582 m .35898 .46056 L .38055 .44746 L p .684 .944 .961 r
F P
0 g
s
.49416 .29688 m .49746 .31125 L .52764 .2626 L p .944 .784 .653 r
F P
0 g
s
.52764 .2626 m .52653 .22406 L .49416 .29688 L p .944 .784 .653 r
F P
0 g
s
.18801 .49909 m .20855 .50148 L .22746 .48809 L p .628 .884 .988 r
F P
0 g
s
.24683 .49049 m .22746 .48809 L .20855 .50148 L p .645 .886 .984 r
F P
0 g
s
.38055 .44746 m .36743 .44523 L .34424 .4582 L p .684 .944 .961 r
F P
0 g
s
.36743 .44523 m .38055 .44746 L .40342 .43294 L p .706 .962 .944 r
F P
0 g
s
.32267 .47053 m .30623 .46811 L .28509 .4803 L p .656 .912 .979 r
F P
0 g
s
.30623 .46811 m .32267 .47053 L .34424 .4582 L p .646 .925 .974 r
F P
0 g
s
.22746 .48809 m .24683 .49049 L .2671 .47779 L p .638 .893 .985 r
F P
0 g
s
.28509 .4803 m .2671 .47779 L .24683 .49049 L p .65 .897 .983 r
F P
0 g
s
.2671 .47779 m .28509 .4803 L .30623 .46811 L p .632 .908 .983 r
F P
0 g
s
.41798 .41345 m .42744 .41606 L .45237 .39584 L p .83 .981 .881 r
F P
0 g
s
.45237 .39584 m .44493 .39137 L .41798 .41345 L p .83 .981 .881 r
F P
0 g
s
.40342 .43294 m .39208 .43076 L .36743 .44523 L p .706 .962 .944 r
F P
0 g
s
.39208 .43076 m .40342 .43294 L .42744 .41606 L p .754 .978 .918 r
F P
0 g
s
.42744 .41606 m .41798 .41345 L .39208 .43076 L p .754 .978 .918 r
F P
0 g
s
.34424 .4582 m .32928 .456 L .30623 .46811 L p .646 .925 .974 r
F P
0 g
s
.32928 .456 m .34424 .4582 L .36743 .44523 L p .637 .94 .961 r
F P
0 g
s
.22746 .48809 m .20787 .48562 L .18801 .49909 L p .628 .884 .988 r
F P
0 g
s
.30623 .46811 m .28955 .46567 L .2671 .47779 L p .632 .908 .983 r
F P
0 g
s
.28955 .46567 m .30623 .46811 L .32928 .456 L p .615 .918 .977 r
F P
0 g
s
.20787 .48562 m .22746 .48809 L .24888 .47505 L p .646 .88 .984 r
F P
0 g
s
.2671 .47779 m .24888 .47505 L .22746 .48809 L p .638 .893 .985 r
F P
0 g
s
.36743 .44523 m .35409 .44352 L .32928 .456 L p .637 .94 .961 r
F P
0 g
s
.35409 .44352 m .36743 .44523 L .39208 .43076 L p .636 .955 .933 r
F P
0 g
s
.24888 .47505 m .2671 .47779 L .28955 .46567 L p .602 .902 .985 r
F P
0 g
s
.39208 .43076 m .38049 .42975 L .35409 .44352 L p .636 .955 .933 r
F P
0 g
s
.38049 .42975 m .39208 .43076 L .41798 .41345 L p .657 .971 .888 r
F P
0 g
s
.4083 .41311 m .41798 .41345 L .44493 .39137 L p .745 .993 .841 r
F P
0 g
s
.44493 .39137 m .43728 .39055 L .4083 .41311 L p .745 .993 .841 r
F P
0 g
s
.41798 .41345 m .4083 .41311 L .38049 .42975 L p .657 .971 .888 r
F P
0 g
s
.32928 .456 m .31408 .45382 L .28955 .46567 L p .615 .918 .977 r
F P
0 g
s
.31408 .45382 m .32928 .456 L .35409 .44352 L p .58 .925 .957 r
F P
0 g
s
.24888 .47505 m .23049 .47142 L .20787 .48562 L p .646 .88 .984 r
F P
0 g
s
.28955 .46567 m .27264 .46324 L .24888 .47505 L p .602 .902 .985 r
F P
0 g
s
.27264 .46324 m .28955 .46567 L .31408 .45382 L p .601 .91 .981 r
F P
0 g
s
.23049 .47142 m .24888 .47505 L .27264 .46324 L p .517 .883 .977 r
F P
0 g
s
.35409 .44352 m .34051 .44215 L .31408 .45382 L p .58 .925 .957 r
F P
0 g
s
.34051 .44215 m .35409 .44352 L .38049 .42975 L p .544 .925 .91 r
F P
0 g
s
.38049 .42975 m .36868 .4296 L .34051 .44215 L p .544 .925 .91 r
F P
0 g
s
.36868 .4296 m .38049 .42975 L .4083 .41311 L p .465 .887 .796 r
F P
0 g
s
.31408 .45382 m .29867 .45128 L .27264 .46324 L p .601 .91 .981 r
F P
0 g
s
.29867 .45128 m .31408 .45382 L .34051 .44215 L p .497 .895 .942 r
F P
0 g
s
.39836 .41512 m .4083 .41311 L .42417 .40075 L p .462 .856 .659 r
F P
0 g
s
.42824 .39626 m .39836 .41512 L .42417 .40075 L .462 .856 .659 r
F
.42937 .39455 m .39836 .41512 L p .42824 .39626 L F P
0 g
s
.43728 .39055 m .42937 .39455 L p .42824 .39626 L .462 .856 .659 r
F P
0 g
s
.42937 .39455 m .44096 .3822 L p .43017 .39335 L .229 0 .069 r
F P
0 g
s
.39836 .41512 m .42937 .39455 L p .39678 .41423 L 0 0 0 r
F P
0 g
s
.36868 .4296 m .39836 .41512 L p .37925 .42165 L 0 0 0 r
F P
0 g
s
.35665 .42936 m .3633 .42949 L p .37925 .42165 L 0 0 0 r
F P
0 g
s
.3633 .42949 m .36868 .4296 L p .37925 .42165 L 0 0 0 r
F P
0 g
s
.38816 .41944 m .35665 .42936 L p .37959 .42153 L 0 0 0 r
F P
0 g
s
.39836 .41512 m .38816 .41944 L p .37959 .42153 L 0 0 0 r
F P
0 g
s
.38816 .41944 m .3901 .41861 L p .39656 .41438 L 0 0 0 r
F P
0 g
s
.39678 .41423 m .38816 .41944 L .39656 .41438 L 0 0 0 r
F
.3901 .41861 m .39836 .41512 L p .39678 .41423 L F P
0 g
s
.4083 .41311 m .39836 .41512 L .36868 .4296 L p .465 .887 .796 r
F P
0 g
s
.38816 .41944 m .4212 .40263 L p .39643 .41742 L .513 .894 .716 r
F P
0 g
s
.37757 .42868 m .38816 .41944 L p .39643 .41742 L .513 .894 .716 r
F P
0 g
s
.4212 .40263 m .38816 .41944 L p .40764 .40768 L 0 0 0 r
F P
0 g
s
.42937 .39455 m .42447 .39939 L p .40764 .40768 L 0 0 0 r
F P
0 g
s
.42447 .39939 m .4212 .40263 L p .40764 .40768 L 0 0 0 r
F P
0 g
s
.4212 .40263 m .42937 .39455 L p .43017 .39335 L .229 0 .069 r
F P
0 g
s
.44689 .37565 m .4212 .40263 L .44096 .3822 L .229 0 .069 r
F
.42417 .40075 m .43728 .39055 L p .42824 .39626 L .462 .856 .659 r
F P
0 g
s
.4553 .37992 m .4212 .40263 L p .43244 .39082 L .229 0 .069 r
F P
0 g
s
.44096 .3822 m .46144 .36036 L p .44689 .37565 L .229 0 .069 r
F P
0 g
s
.46144 .36036 m .45692 .37475 L p .43244 .39082 L .229 0 .069 r
F P
0 g
s
.45692 .37475 m .4553 .37992 L p .43244 .39082 L .229 0 .069 r
F P
0 g
s
.27264 .46324 m .25545 .46139 L .23049 .47142 L p .517 .883 .977 r
F P
0 g
s
.25545 .46139 m .27264 .46324 L .29867 .45128 L p .661 .897 .98 r
F P
0 g
s
.44832 .43237 m .4553 .37992 L .49071 .2911 L p 0 0 .051 r
F P
0 g
s
.34051 .44215 m .3267 .44108 L .29867 .45128 L p .497 .895 .942 r
F P
0 g
s
.3267 .44108 m .34051 .44215 L .36868 .4296 L p .494 .902 .906 r
F P
0 g
s
.29867 .45128 m .28313 .44683 L .25545 .46139 L p .661 .897 .98 r
F P
0 g
s
.28313 .44683 m .29867 .45128 L .3267 .44108 L p .204 .732 .801 r
F P
0 g
s
.36868 .4296 m .35665 .42936 L .3267 .44108 L p .494 .902 .906 r
F P
0 g
s
.3267 .44108 m .31256 .44169 L .28313 .44683 L p .204 .732 .801 r
F P
0 g
s
.31256 .44169 m .3267 .44108 L .35665 .42936 L p .675 .938 .966 r
F P
0 g
s
.35665 .42936 m .34456 .4256 L .31256 .44169 L p .675 .938 .966 r
F P
0 g
s
.34456 .4256 m .35665 .42936 L .38816 .41944 L p .399 0 0 r
F P
0 g
s
.41297 .40563 m .4212 .40263 L .4553 .37992 L p .68 .346 .402 r
F P
0 g
s
.4212 .40263 m .41297 .40563 L .37757 .42868 L p .513 .894 .716 r
F P
0 g
s
.4553 .37992 m .44832 .43237 L .41297 .40563 L p .68 .346 .402 r
F P
0 g
s
.38816 .41944 m .37757 .42868 L .34456 .4256 L p .399 0 0 r
F P
0 g
s
.25 Mabswid
.04424 .06215 m
.96197 0 L
s
.96197 0 m
1 .39856 L
s
1 .39856 m
0 .45361 L
s
0 .45361 m
.04424 .06215 L
s
.96197 0 m
1 .39856 L
s
.96458 .02735 m
.95778 .0278 L
s
[(0)] .97817 .02644 -1 .06685 Mshowa
.97223 .10757 m
.96543 .10801 L
s
[(0.25)] .98583 .1067 -1 .0643 Mshowa
.98017 .19078 m
.97337 .1912 L
s
[(0.5)] .99377 .18994 -1 .06165 Mshowa
.98841 .27714 m
.98161 .27754 L
s
[(0.75)] 1.00201 .27633 -1 .05891 Mshowa
.99697 .36683 m
.99017 .36721 L
s
[(1)] 1.01058 .36606 -1 .05606 Mshowa
.125 Mabswid
.96609 .04316 m
.96201 .04343 L
s
.96761 .05909 m
.96353 .05936 L
s
.96914 .07514 m
.96506 .0754 L
s
.97068 .0913 m
.9666 .09156 L
s
.9738 .12397 m
.96972 .12423 L
s
.97537 .14049 m
.97129 .14075 L
s
.97696 .15713 m
.97288 .15738 L
s
.97856 .17389 m
.97448 .17415 L
s
.9818 .20779 m
.97772 .20804 L
s
.98343 .22493 m
.97935 .22518 L
s
.98508 .2422 m
.981 .24245 L
s
.98674 .2596 m
.98266 .25985 L
s
.9901 .2948 m
.98602 .29504 L
s
.9918 .3126 m
.98772 .31284 L
s
.99351 .33054 m
.98943 .33077 L
s
.99523 .34861 m
.99115 .34884 L
s
.96308 .01165 m
.959 .01192 L
s
.99872 .38518 m
.99464 .38541 L
s
gsave
1.06175 .18556 -61 -10.37 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 242.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 359}, {301.875, 0}} -> {-0.0563635, -0.0173819, \
0.00381386, 0.00381386}}]
}, Open  ]],

Cell[TextData[{
  "In the lower half sphere, ",
  Cell[BoxData[
      \(TraditionalForm\`z < 0\)]],
  ", the potential rises to meet the boundary condition that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[Phi](a, \[Theta], \[Phi])\), "=", " ", 
              RowBox[{"1", 
                StyleBox["V",
                  FontSlant->"Plain"]}]}], ";"}], " "}], TraditionalForm]]],
  "while in the upper half the potential on the surface of the sphere is \
zero. The convex curvature of the potential in the interior of the sphere \
reflects the positive charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " in the upper half of the sphere. Note the barely discernible Gibbs \
phenomenon near the discontinuities in the potential. "
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 4.3", "Subsubtitle",
  CellTags->"c:32"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Solve the following potential problems in rectangular geometry. Plot the \
solutions using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, 
          y) = \(\[Phi](1, y) = \(\[Phi](x, 0) = 0\)\); \ \[Phi](1, y) = 
        sin\ 2  \[Pi]\ y\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y, z)\) = 10\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, 
          0) = \(\[Phi](x, y, 
            1) = \ \(\[Phi](0, y, 
              z) = \(\[Phi](1, y, z) = \ \(\[Phi](x, 0, z) = 
                0\)\)\)\); \ \[Phi](x, 1, z) = h(x - 1/2)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function. Plot the solution in the ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(\(1/2\)\(\ \)\)\)]],
  " plane."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = \(-x\)\ y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, 
          y) = \(\[Phi](2, y) = \(\[Phi](x, 0) = 0\)\), \ \(\(\[Phi](x, 
          1)\)\(=\)\)\)]],
  "1."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y, z)\) = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, 0) = \(\[Phi](x, y, 1) = 0\); \ \[Phi](
          0, y, z) = \(\[Phi](1, y, z) = z(1 - z)\), \ \ \[Phi](x, 0, 
          z) = \(\[Phi](x, 1, z) = 0\)\)]],
  ". Plot the solution in the ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(\(1/2\)\(\ \)\)\)]],
  " plane."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, 
            y)\) = \(\(cos\)\(\ \)\(n\)\(\ \)\(\[Pi]\)\(\ \)\(x\)\(\ \
\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " an integer,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[Phi]\/\[PartialD]x\) \((0, 
            y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]x\) \((1, 
              y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 
                0)\) = \ \(\(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 
              0\)\)\)\)]],
  ". (What happens for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  "?)"
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, 
            y)\) = \[ExponentialE]\^\(x\  + y\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0, 
          y) = \(\[Phi](1, y) = \(\[Phi](x, 0) = 
            0\)\); \ \(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " For the problem"
}], "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y)\) = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[Phi]\/\[PartialD]x\) \((0, 
            y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]x\) \((1, 
              y)\) = \(\(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 0)\) = 
            0\)\), \ \ \(\[PartialD]\[Phi]\/\[PartialD]y\) \((x, 1)\) = 
        a\ \(h(x - 1/2)\), \)]],
  " "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function, find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " for which a solution exists, and find the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  ". [Hint : For the function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ", choose  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(u = \(u\_o\)(x, y) + \ f(x, y)\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is an arbitrary function that satisfies homogeneous von Neumann \
conditions on all sides except at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y = 1\)\(,\)\(\ \)\)\)]],
  "and that takes account of the charge in the box (  i.e.  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_V\[Del]\^2 
              f \[DifferentialD]x \[DifferentialD]y = 1\)]],
  "),  and where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u\_o = 0\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  " Show, using Gauss's law,  that for Poisson's equation in a square box \
with ",
  StyleBox["periodic",
    FontSlant->"Italic"],
  " boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x + L, 
          y) = \(\[Phi](x, y + L) = \[Phi](x, y)\)\)]],
  ",  a solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\)]],
  " exists ",
  StyleBox["only if ",
    FontSlant->"Italic"],
  " the net charge density in the square is zero: "
}], "Text",
  CellTags->"i:76"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%L\[DifferentialD]x \
\(\[Integral]\_0\%L\[DifferentialD]y\ \(\[Rho](x, y)\)\) = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " For a given charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, y)\)]],
  " find a general form for the solution in terms of an exponential Fourier \
series."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Find the Green's function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  " as a generalized Fourier series  for the potential inside a grounded \
rectangular cube with walls at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, \ x = a, \ y = 0, y = a, \ z = 0, z = L\)]],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " It is sometimes useful to write the Green's function for Poisson's \
equation in a different manner than the eigenmode expansion used in the \
bilinear equation. For the rectangular cube of Exercise (4),  now employ only \
the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " eigenmodes, writing"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], ")"}], "=", 
          RowBox[{\(\[Sum]\+\(m, n = 1\)\%\[Infinity]\), 
            RowBox[{
              RowBox[{\(f\_\(m\ n\)\), "(", 
                RowBox[{"z", ",", " ", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["r",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], ")"}], " ", "sin", 
              " ", \((n\ \[Pi]\ x/a)\), " ", \(sin(m\ \[Pi]\ y/a)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.69)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(m\ n\)\)]],
  " solves the following boundary-value problem:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]z\^2\) 
            f\_\(m\ n\) - \(\[Kappa]\_\(m\ n\)\^2\) f\_\(m\ n\) = 
        sin\ \((n\ \[Pi]\ x\_o/a)\)\ \(sin(m\ \[Pi]\ y\_o/a)\) \(\[Delta](
            z - z\_o)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(m\ n\) = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_\(m\ n\)\^2 = \((\(m\ \[Pi]\)\/a)\)\^2 + \
\((\(n\ \[Pi]\)\/a)\)\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve this boundary-value problem, using the technique discussed in Sec. \
",
  ButtonBox["2.4.4",
    ButtonData:>{"Chapter2.nb", "c:47"},
    ButtonStyle->"Hyperlink"],
  " to show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(f\_\(\(\ \)\(m\ n\)\)\), "(", 
            RowBox[{"z", ",", " ", 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], ")"}], 
          "=", \(\(-4\) 
            sin\ \((n\ \[Pi]\ x\_o/a)\)\ \(sin(
              m\ \[Pi]\ y\_o/
                  a)\)\ sinh\ \((\[Kappa]\_\(m\ n\)\ \(z\_ < \))\)\ \(sinh(\(\
\[Kappa]\_\(m\ n\)\)(L - \(z\_ > \)))\)\/\(\(a\^2\) \(\[Kappa]\_\(m\ n\)\) \
\(sinh(\[Kappa]\_\(m\ n\)\ L)\)\)\)}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.70)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`z\_\(\(<\)\(( > )\)\)\)]],
  " is the lesser (greater) of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\)]],
  ".",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " By carefully taking the limit ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(>>\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`z, z\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z, z\_o >> 0\)]],
  ", show that the Green's function in an infinitely long grounded conducting \
tube of square cross-section is"
}], "Text",
  CellTags->"i:77"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], 
        "=", \(\(-2\) \(\[Sum]\+\(m, n = 1\)\%\[Infinity] 
              sin\ \((n\ \[Pi]\ x/a)\)\ \(sin(
                m\ \[Pi]\ y/a)\)\ sin\ \((n\ \[Pi]\ x\_o/a)\)\ \(sin(
                m\ \[Pi]\ y\_o/
                    a)\)\ \(\(\[ExponentialE]\^\(\(-\[Kappa]\_\(m\ n\)\) | z \
- z\_o | \)\/\(\(a\^2\) \[Kappa]\_\(m\ n\)\)\)\(.\)\)\)\)}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(4.3.71)"],

Cell[TextData[{
  "(Hint: As ",
  Cell[BoxData[
      \(TraditionalForm\`x \[Rule] \[Infinity]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`sinh\ x~\ cosh\ x\ ~\ \(\[ExponentialE]\^x\)/2\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Find the force in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction on a charge ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ", located at position ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o, y\_o, z\_o)\)\)]],
  " in a rectangular box  of length ",
  StyleBox["L",
    FontSlant->"Italic"],
  " with square cross section.  Plot this force (scaled to ",
  Cell[BoxData[
      \(TraditionalForm\`q\^2/\[Epsilon]\_o\ L\^2\)]],
  ") vs. ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < z\_o < L\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y\_o = \(a/2 = x\_o\)\)]],
  ",  for ",
  Cell[BoxData[
      \(TraditionalForm\`a\  = \ L/2\)]],
  ". \n[Hint: This force arises from the image charges in the walls of the \
grounded box. To determine the force, one needs to calculate the electric \
field ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["E",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  "at the position ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["r",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " of the charge. However, one cannot simply evaluate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["E",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "=", 
          RowBox[{
            RowBox[{
              RowBox[{\(q\/\[Epsilon]\_o\), 
                RowBox[{
                  SubscriptBox["\[Del]", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]], 
                  RowBox[{"g", "(", 
                    RowBox[{
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["r",
                            FontSlant->"Plain"], 
                          StyleBox["o",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"]}], ")"}]}]}], "|", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  "  using Eq. ",
  ButtonBox["(4.3.69)",
    ButtonData:>"(4.3.69)",
    ButtonStyle->"Hyperlink"],
  ", since the self-field of the charge is infinite at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". This is manifested in Eq. ",
  ButtonBox["(4.3.69)",
    ButtonData:>"(4.3.69)",
    ButtonStyle->"Hyperlink"],
  " (and in Eq. ",
  ButtonBox["(4.3.71)",
    ButtonData:>"(4.3.71)",
    ButtonStyle->"Hyperlink"],
  " ) by the fact that the series does not converge if ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". (Try it if you like!) One must somehow subtract out this self-field \
term, and determine only the effect of the field due to the images in the \
walls of the tube."
}], "Text"],

Cell[TextData[{
  "One way to do this is to note that for an infinite tube, there is no force \
in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction on the charge due to symmetry in ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". Therefore, we can subtract Eq. ",
  ButtonBox["(4.3.71)",
    ButtonData:>"(4.3.71)",
    ButtonStyle->"Hyperlink"],
  " from Eq. ",
  ButtonBox["(4.3.69)",
    ButtonData:>"(4.3.69)",
    ButtonStyle->"Hyperlink"],
  " to obtain the effect on ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " of  the tube's finite length.  The resulting series  converges when one \
takes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ". ]"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " The following problem relates to the eigenmode expansion of the solution \
to Laplace's equation, Eq. ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:79"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Use Green's theorem to show that, for Dirichlet boundary conditions in a \
2-dimensional domain,\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(n\ m\), \ \[Del]\^2 u)\)\)]],
  "= ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Lambda]\_\(n\ m\)\)(\[Psi]\_\(n\ m\), \ u)\), "-", 
          RowBox[{\(\[Integral]\_S\), 
            RowBox[{"u", " ", 
              RowBox[{
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"], 
                "\[CenterDot]", \(\[Del]\[Psi]\_\(n\ m\)\)}], \(\
\[DifferentialD]l\)}]}]}], TraditionalForm]]],
  ", \n where the surface integral runs over the boundary ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " of the domain,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]l\)]],
  "is a line element of this boundary, and where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(n\ m\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " have the same definitions as in Eq. ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Determine the eigenmode expansion for the solution of Laplace's equation, \
 ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 0\)]],
  ",  using the result of part (a) and Eq. ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ". In particular, show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y)\  = \ 
        u(x, y) + \[Sum]\+\(n\ m\)b\_\(n\ m\)\ \(\(\[Psi]\_\(n\ m\)\)(x, 
                y)\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.72)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(b\_\(n\ m\)\), "=", 
          RowBox[{
            RowBox[{\(\[Integral]\_S\), 
              RowBox[{"u", " ", 
                RowBox[{
                  OverscriptBox[
                    StyleBox["n",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"], 
                  "\[CenterDot]", \(\[Del]\[Psi]\_\(n\ m\)\)}], \(\
\[DifferentialD]l\ /\([\[Lambda]\_\(n\ m\)\ \((\[Psi]\_\(n\ m\), \[Psi]\_\(n\ \
m\))\)]\)\)}]}], " ", "-", 
            " ", \(\(\((\[Psi]\_\(n\ m\), 
                u)\)/\((\[Psi]\_\(n\ m\), \[Psi]\_\(n\ m\))\)\)\(\ \)\)}]}], 
        TraditionalForm]]],
  ". Note that in the surface integral the function ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is uniquely determined by the boundary conditions. Equation ",
  ButtonBox["(4.3.72)",
    ButtonData:>"(4.3.72)",
    ButtonStyle->"Hyperlink"],
  " is equivalent to Eq. ",
  ButtonBox["(4.3.29)",
    ButtonData:>"(4.3.29)",
    ButtonStyle->"Hyperlink"],
  ", but avoids taking derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ". This is an advantage when ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " varies rapidly."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Redo the  Laplace equation problem associated with Fig. ",
  ButtonBox["4.5",
    ButtonData:>"Fig. 4.5",
    ButtonStyle->"Hyperlink"],
  " , taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(b = 1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_o = 1\)]],
  ", and using an eigenmode expansion as given by Eq. ",
  ButtonBox["(4.3.72)",
    ButtonData:>"(4.3.72)",
    ButtonStyle->"Hyperlink"],
  ". Note that on the boundary ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is nonzero only on the right side, in the range ",
  Cell[BoxData[
      \(TraditionalForm\`1/3\  < \ y < 2/3\)]],
  ", so the required surface integral becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(1/3\)\%\(2/3\)\), 
          RowBox[{" ", 
            RowBox[{
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], 
              "\[CenterDot]", \(\[Del]\(\(\[Psi]\_\(n\ m\)\)(1, 
                  y)\)\)}], \(\[DifferentialD]y\)}]}], TraditionalForm]]],
  ".  For ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " use the following function:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\  = \ 
        x\ \(f(y - 1/3, 1 - x, \(-1\)/3)\)\ \(f(2/3 - y, 
            1 - x, \(-1\)/3)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(x, y, z)\  = \ \([tanh(x/y)\  - \ tanh(z/y)\ ]\)/
          2\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`u(x, y)\)]],
  " to convince yourself that it matches the boundary conditions. This \
function is chosen because it is continuous everywhere except on the right \
boundary. Therefore, its generalized Fourier series expansion in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(m\ n\)\)]],
  " has better convergence properties than our previous choice for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ",  Eq. ",
  ButtonBox["(4.3.28)",
    ButtonData:>"(4.3.28)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tYou will have to find the inner product ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Psi]\_\(n\ m\), u)\)\)]],
  " via numerical integration.  Keep ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \ m \[LessEqual] \ 6\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \ n \[LessEqual] \ 6\)]],
  ".  Avoid integrating in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " all the way to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = 1\)\(,\)\)\)]],
  " because of the singularity in ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  "; rather, integrate only up to ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0.9999\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Compare your solution to that found via Eq. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  " (for M=25) by plotting ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](0.9, y)\), Cell[""]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 1/2)\)]],
  "  for both solutions.  Which solution works better? [Answer: Eq. ",
  ButtonBox["(4.3.31)",
    ButtonData:>"(4.3.31)",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that in the limit that an infinite number of terms are kept, Eq. ",
  ButtonBox["(4.3.72)",
    ButtonData:>"(4.3.72)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 
          y)\  = \ \[Sum]\+\(n\ m\)c\_\(n\ m\)\ \(\(\[Psi]\_\(n\ m\)\)(x, 
              y)\)\)]]
}], "Text"],

Cell[TextData[{
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " not on the boundary, where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_\(n\ m\)\), "=", 
          RowBox[{\(\[Integral]\_S\), 
            RowBox[{"u", " ", 
              RowBox[{
                OverscriptBox[
                  StyleBox["n",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"], 
                "\[CenterDot]", \(\[Del]\[Psi]\_\(n\ m\)\)}], \(\
\[DifferentialD]l\ /\([\[Lambda]\_\(n\ m\)\ \((\[Psi]\_\(n\ m\), \[Psi]\_\(n\ \
m\))\)]\)\)}]}]}], TraditionalForm]]],
  ". This is yet another form for the solution to Laplace's equation with \
Dirichlet boundary conditions, valid only in the interior of the domain.  \
Repeat the calculation and plots of part (b) using this series, taking  ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \ m \[LessEqual] \ 40\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1 \[LessEqual] \ n \[LessEqual] \ 40\)]],
  " (the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\(n\ m\)\)]],
  " can be determined analytically). "
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Find the solution to the following potential problems inside a cylinder. \
Write the solution in terms of an eigenmode expansion. Put the equation into \
standard form, if necessary. Plot the solutions."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](r, \[Theta])\) = x\ y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](1, \[Theta]) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\^2\( \[Phi](r, \[Theta], z)\) = 
        z\ sin\[Theta]\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](1, \[Theta], 
          z) = \(\[Phi](r, \[Theta], 0) = \(\[Phi](r, \[Theta], 2) = 
            0\)\)\)]],
  ". Plot in the ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " plane vs. ",
  Cell[BoxData[
      \(TraditionalForm\`y\ and\ z\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\^2\( \[Phi](r, \[Theta], z)\) = \ 1\), ",", " ", 
          
          FormBox[\(\[Phi](1, \[Theta], 
                z) = \(\[Phi](
                  r, \[Theta], \(-1\)) = \(\[Theta](r, \[Theta], 1) = 0\)\)\),
            
            "TraditionalForm"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](2, \[Theta], 
          z) = \(h(z)\)\ \(h(\[Theta])\)\)]],
  " (concentric cylinders, ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\) < \[Theta] < \[Pi]\)]],
  " assumed).  Plot in the ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " plane vs. ",
  Cell[BoxData[
      \(TraditionalForm\`y\ and\ z\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\^2\( \[Phi](r, \[Theta])\) = \ 
        y\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Phi]\/\[PartialD]r\)]],
  Cell[BoxData[
      \(TraditionalForm\`\((1, \[Theta])\) = sin\ \[Theta]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A wedge, shown in Fig. ",
  ButtonBox["4.7",
    ButtonData:>"Fig. 4.7",
    ButtonStyle->"Hyperlink"],
  ", has opening angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". The wedge is filled with uniform charge, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(\[Rho]\)\(/\)\),
              "TraditionalForm"], 
            FormBox[\(\[Epsilon]\_o\),
              "TraditionalForm"]}], "=", 
          RowBox[{"1", " ", 
            RowBox[{
              StyleBox["V",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". The walls of the wedge are grounded, at zero potential.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the eigenmodes for this geometry. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use these eigenmodes to solve for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta])\)]],
  " inside the wedge. Plot the solution using a contour plot for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 65\ \[Degree]\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000^b000`400?l00000o`00003obP3oool0
0<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3o
ool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00I@3oool00`20P800000000000002
00000080P8200`3oool00`20P8000000000000020820P5H0oooo001T0?ooo`030820P00000000000
00D0000000<0P8200?ooo`0000001@0000000`20P800oooo0?ooo`1C0?ooo`00I03oool400000004
0820P03oool0oooo0?ooo`D000000`3oool00`20P800oooo0?ooo`1C0?ooo`00I03oool4000000D0
oooo1000001I0?ooo`00I03oool3000000L0oooo0`00001I0?ooo`00I03oool3000000L0oooo0`00
001I0?ooo`00I03oool00`20P8000000000000070?ooo`<00000F@3oool006D0oooo0`0000060?oo
o`<00000F@3oool006H0oooo00<0P82000000010@4001@3oool3000005T0oooo001Y0?ooo`800000
0`3oool3000005T0oooo001[0?ooo`80000000@0oooo0000000000000000F@3oool006d0oooo1000
001I0?ooo`00I@3oool20820P0L0oooo0`00001I0?ooo`00I03oool01020P8000000000000000006
0?ooo`<00000F@3oool006@0oooo00@0P82000000000000000001P3oool3000005T0oooo001T0?oo
o`040820P00000000000000000H0oooo0P0000000`20P800oooo0?ooo`1G0?ooo`00I@3oool01020
P800000000000030`<030?ooo`050<30`0000000000000000030`<00F@3oool006P0oooo00<0P820
0000000000000`00001L0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?oo
o`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo0005
0?oookd00000203oool000D0oooo_@0000020820P0H0oooo00050?oookl000001P3oool000L0oooo
00<0P8200000000000000P00002e0?ooo`<000001P3oool000P0oooo1@00000^0?ooo`040820P000
0000000000000880oooo0`0000060?ooo`002@3oool00`20P800000000000002000000030820P03o
ool0oooo02X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000;0?ooo`@0000000<0
P8200?ooo`3oool0:@3oool01020P80000000000000000220?ooo`<000001P3oool000/0oooo00<0
P8200000000000000P00000[0?ooo`040820P0000000000000000880oooo0`0000060?ooo`00303o
ool5000002X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000=0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool09P3oool01010@40000000000000000220?ooo`<00000
1P3oool000l0oooo100000000`20P800oooo0?ooo`0U0?ooo`<00000P`3oool3000000H0oooo000?
0?ooo`030820P00000000000008000009`3oool300000880oooo0`0000070?ooo`00403oool50000
02H0oooo0`0000220?ooo`<000001`3oool00140oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0R0?ooo`<00000PP3oool3000000L0oooo000C0?ooo`@0000000<0P8200?ooo`3oool0
8@3oool300000880oooo0`0000070?ooo`004`3oool00`20P80000000000000200000280oooo1000
00220?ooo`<000001`3oool001@0oooo1@00000Q0?ooo`@00000PP3oool3000000L0oooo000E0?oo
o`D00000803oool3000008<0oooo0`0000070?ooo`005P3oool00`20P80000000000000200000003
0<30`03oool0oooo01/0oooo100000230?ooo`<000001`3oool001L0oooo00<0P820000000000000
0P00002T0?ooo`<000001`3oool001P0oooo1@00002S0?ooo`<000001`3oool001T0oooo1@00002R
0?ooo`<000001`3oool001X0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2M0?oo
o`040820P00000000000000000L0oooo000K0?ooo`030820P0000000000000800000W`3oool40000
00L0oooo000L0?ooo`D00000WP3oool3000000P0oooo000M0?ooo`D00000W@3oool3000000P0oooo
000N0?ooo`030820P000000000000080000000<0`<300?ooo`3oool09P3oool40820P0030<30`03o
ool0oooo00D0oooo0`20P81S0?ooo`040820P00000000000000000P0oooo000O0?ooo`030820P000
00000000008000009P3oool2000000050820P03oool0oooo0?ooo`20P8000P0000050?ooo`@00000
HP3oool4000000P0oooo000P0?ooo`D000004@3oool00`000000P8200?ooo`0?0?ooo`040820P000
00000000000000H0oooo0P0000030?ooo`D00000HP3oool4000000P0oooo000Q0?ooo`D000003`3o
ool4000000l0oooo00<0P820000000000000203oool010000000P8200?ooo`3oool5000000030820
P03oool0oooo05l0oooo100000080?ooo`008P3oool00`20P800000000000002000000030<30`03o
ool0oooo00X0oooo100000000`20P800oooo0?ooo`0<0?ooo`040820P00000000000000000T0oooo
00D000000820P03oool000000410@0020?ooo`80P820H@3oool3000000030820P03oool0oooo00H0
oooo000S0?ooo`030820P00000000000008000002`3oool01@20P8000000000000000000P82000l0
oooo100000090?ooo`040820P00000000000000006D0oooo00D0P82000000000000000000820P008
0?ooo`00903oool5000000X0oooo00D0P82000000000000000000820P00?0?ooo`@000002@3oool0
1020P800000000000000001U0?ooo`050820P0000000000000000020P800203oool002D0oooo1@00
00090?ooo`@00000403oool4000000X0oooo0`00001U0?ooo`050820P0000000000000000020P800
203oool002H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`040?ooo`@0000000<0
P8200?ooo`3oool03P3oool4000000X0oooo00@0P820000000000000@410I03oool01@20P8000000
000000000000P82000P0oooo000W0?ooo`030820P00000000000008000001@3oool400000180oooo
1000000;0?ooo`<00000I03oool01@20P8000000000000000000P82000P0oooo000X0?ooo`D00000
0`3oool4000001@0oooo1000000:0?ooo`@00000H`3oool4000000T0oooo000Y0?ooo`D0000000<0
oooo0820P00000000P0000000`20P800oooo0?ooo`0B0?ooo`@000002P3oool4000006<0oooo1000
00090?ooo`00:P3oool00`20P800000000000006000001D0oooo00D0@41000000000000000000<30
`0090?ooo`0300000020P800000000800000HP3oool4000000T0oooo000[0?ooo`030820P0000000
000000@000005`3oool3000000030820P03oool0oooo00L0oooo00<000000?ooo`0000000`00001Q
0?ooo`<000002P3oool002`0oooo1@00000I0?ooo`<00000203oool2000000030?ooo`20P8000000
00800000H03oool4000000X0oooo000/0?ooo`H000006@3oool3000000L0oooo0P0000000`3oool0
P82000000002000000030820P03oool0oooo05d0oooo0`00000;0?ooo`00;P3oool00`20P8000000
00000002000000030<30`03oool0oooo01H0oooo00@0P820000000000000P820103oool00`10@400
P8200?ooo`020?ooo`<0000000<0@4100?ooo`3oool0G@3oool3000000/0oooo000_0?ooo`030820
P00000000000008000006`3oool5000006L0oooo1000000;0?ooo`00<03oool5000008H0oooo0`00
000<0?ooo`00<@3oool5000008D0oooo0`00000<0?ooo`00<P3oool5000008@0oooo0`00000<0?oo
o`00<`3oool01@10@4000000000000000000@4100880oooo00@0P8200000000000000000303oool0
03@0oooo1@0000210?ooo`<0000000<0P8200?ooo`3oool02P3oool003D0oooo1@0000200?ooo`<0
000000<0P8200?ooo`3oool02P3oool003H0oooo1@00001o0?ooo`<0000000<0P8200?ooo`3oool0
2P3oool003L0oooo00D0@41000000000000000000410@01m0?ooo`050820P0000000000000000030
`<00303oool003P0oooo1@00001l0?ooo`040820P00000000000000000d0oooo000i0?ooo`D00000
N`3oool01020P800000000000000000=0?ooo`00>P3oool5000007X0oooo1000000=0?ooo`00>`3o
ool01@10@4000000000000000000@41007T0oooo0`00000>0?ooo`00?03oool5000007P0oooo0`00
000>0?ooo`00?@3oool5000007H0oooo1000000>0?ooo`00?P3oool5000007D0oooo0`00000?0?oo
o`00?`3oool01@10@4000000000000000000@41007<0oooo00@0P82000000000000000003`3oool0
0400oooo1@00001b0?ooo`<00000403oool00440oooo1@00001a0?ooo`<00000403oool00480oooo
1@00001_0?ooo`@00000403oool004<0oooo00<0@4100000000000000P0000000`30`<00oooo0?oo
o`1[0?ooo`<0000000<0P8200?ooo`3oool03P3oool004@0oooo1@00001/0?ooo`050820P0000000
000000000020P800403oool004D0oooo1@00001[0?ooo`040820P0000000000000000140oooo0016
0?ooo`D00000JP3oool01020P800000000000000000A0?ooo`00A`3oool00`20P800000000000002
000000030<30`03oool0oooo06H0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`00B03oool00`20
P800000000000002000006P0oooo0`00000B0?ooo`00B@3oool5000006H0oooo1000000B0?ooo`00
BP3oool5000006D0oooo0`00000C0?ooo`00B`3oool00`20P800000000000002000000030<30`03o
ool0oooo0600oooo00@0P82000000000000000004`3oool004`0oooo00<0P8200000000000000P00
001R0?ooo`<00000503oool004d0oooo1@00001P0?ooo`@00000503oool004h0oooo1@00001O0?oo
o`@00000503oool003T0oooo1020P8060?ooo`80P8202P3oool00`20P80000000000000200000003
0<30`03oool0oooo05X0oooo00D0P82000000000000000000820P00D0?ooo`00>03oool7000000<0
oooo1@0000090?ooo`030820P0000000000000800000G03oool4000001D0oooo000g0?ooo`030820
P0000000000000D0000000<0P8200?ooo`0000001P0000090?ooo`D00000F`3oool4000001D0oooo
000g0?ooo`@0000000@0P8200?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo00P0oooo
1@00001I0?ooo`@000005P3oool003L0oooo100000050?ooo`@000003`3oool5000005P0oooo1000
000F0?ooo`00=`3oool3000000L0oooo0`00000@0?ooo`050410@0000000000000000010@400EP3o
ool4000001L0oooo000g0?ooo`<000001`3oool300000140oooo1@00001D0?ooo`@00000603oool0
03L0oooo00<0P8200000000000001`3oool300000180oooo1@00001C0?ooo`@00000603oool003P0
oooo0`0000060?ooo`<000004`3oool500000540oooo00D0P82000000000000000000820P00H0?oo
o`00>@3oool00`20P80000000410@0050?ooo`<00000503oool01@10@4000000000000000000@410
0500oooo00D0@41000000000000000000<30`00H0?ooo`00?03oool2000000<0oooo0`00000E0?oo
o`D00000C`3oool4000001T0oooo000n0?ooo`80000000@0oooo00000000000000005P3oool50000
04d0oooo1000000J0?ooo`00@03oool4000001L0oooo1@00001<0?ooo`@000006P3oool003P0oooo
0P20P8070?ooo`<00000603oool01@10@4000000000000000000@41004T0oooo0P20P803000001/0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000I0?ooo`D00000B03oool4000001`0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000J0?ooo`D00000AP3oool01@20P800
0000000000000000P82001`0oooo000g0?ooo`040820P00000000000000000H0oooo0P0000000`20
P800oooo0?ooo`0I0?ooo`D00000A@3oool01@20P8000000000000000000P82001`0oooo000h0?oo
o`040820P000000000000<30`0<0oooo00D0`<3000000000000000000<30`00L0?ooo`050410@000
0000000000000010@400A03oool4000001d0oooo000k0?ooo`030820P0000000000000<00000803o
ool500000480oooo1000000N0?ooo`00HP3oool500000440oooo0`00000O0?ooo`00H`3oool50000
03l0oooo1000000O0?ooo`00I03oool01@10@4000000000000000000@41003d0oooo00@0P8200000
000000000000803oool006D0oooo1@00000k0?ooo`050820P0000000000000000020P800803oool0
06H0oooo1@00000j0?ooo`040820P0000000000000000240oooo001W0?ooo`D00000>@3oool40000
0240oooo001X0?ooo`050410@0000000000000000010@400=`3oool01020P800000000000000000R
0?ooo`00J@3oool5000003H0oooo0`00000S0?ooo`00JP3oool5000003@0oooo0`00000T0?ooo`00
J`3oool5000003<0oooo0`00000T0?ooo`00K03oool01@10@4000000000000000000@4100300oooo
00D0P82000000000000000000820P00T0?ooo`00K@3oool5000002l0oooo1000000U0?ooo`00KP3o
ool5000002d0oooo1000000V0?ooo`00K`3oool5000002/0oooo1000000W0?ooo`00L03oool40000
00030820P03oool0oooo02P0oooo1000000W0?ooo`00L03oool00`30`<0000000000000200000003
0820P03oool0oooo02D0oooo00D0`<3000000000000000000410@00X0?ooo`00LP3oool5000002H0
oooo1000000Y0?ooo`00L`3oool5000002D0oooo1000000Y0?ooo`00M03oool4000000030820P03o
ool0oooo0240oooo1000000Z0?ooo`00M03oool00`30`<00000000000002000000030820P03oool0
oooo01h0oooo00D0P82000000000000000000820P00[0?ooo`00MP3oool5000001l0oooo0`000000
0`20P800oooo0?ooo`0Z0?ooo`00M`3oool5000001d0oooo00D0P82000000000000000000820P00/
0?ooo`00N03oool4000000030820P03oool0oooo01X0oooo1000000]0?ooo`00N03oool00`30`<00
000000000002000000030820P03oool0oooo01P0oooo00@0P820000000000000P820;P3oool007X0
oooo1@00000H0?ooo`@00000;`3oool007/0oooo1@00000F0?ooo`@00000<03oool007`0oooo1000
00000`20P800oooo0?ooo`0B0?ooo`050820P0000000000000000020P800<03oool007`0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0@0?ooo`050820P0000000000000000020P800
<@3oool007h0oooo1@00000@0?ooo`@00000<`3oool007l0oooo1@00000>0?ooo`@00000=03oool0
0800oooo1@00000<0?ooo`030820P0000000000000800000=03oool00800oooo00<0`<3000000000
00000P0000000`10@400oooo0?ooo`090?ooo`050410@0000000000000000030`<00=03oool00880
oooo1@0000090?ooo`@00000=P3oool008<0oooo1@0000070?ooo`@00000=`3oool008@0oooo1@00
00050?ooo`@00000>03oool008D0oooo00D0@41000000000000000000410@0030?ooo`050410@000
0000000000000030`<00>03oool008H0oooo1@0000000`3oool0000000000002000003X0oooo0027
0?ooo`T00000>P3oool008P0oooo1`00000k0?ooo`00R@3oool01@10@4000000000000000000@410
03`0oooo002:0?ooo`800000?P3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{67.5625, 62.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.7 Exercise (8)", "Caption",
  CellTags->"Fig. 4.7"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " A wedge, shown in Fig. ",
  ButtonBox["4.8",
    ButtonData:>"Fig. 4.8",
    ButtonStyle->"Hyperlink"],
  ", has opening angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " and radii ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`b < a\)]],
  ". The edges of the wedge have constant potentials as shown. Find the \
solution to Laplace's equation using separation of variables rather than \
eigenmodes. (Hint: You will still need to determine radial eigenfunctions, \
and the correct radial inner product with respect to which these functions \
are orthogonal.)"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<l0002Ab000`400?l00000o`00003ooooooooo
oooooooooooo?oooool00?ooooooooooooooooooocoooooo003oooooooooooooooooooloooooo`00
oooooooooooooooooooo?oooool00?ooooooooooooooooooocoooooo003ooooooooooooooooooolo
ooooo`00oooooooooooooooooooo?oooool00?ooooooooooooooooooocoooooo003ooooooooooooo
ooooooloooooo`00oooooooooooooooooooo?oooool00?ooooooooooooooooooocoooooo003ooooo
ooooooooooooooloooooo`00oooooooooooooooooooo?oooool00?ooooooooooooooooooocoooooo
003oooooooooooooooooooloooooo`004ooooooo0?ooool0ooooo`3ooolG0?oooaGooooo000Coooo
ool0ooooo`3ooooo0?oooaL0oooo5Oooool001?oooooo`3ooooo0?ooool0oooo5`3ooolEooooo`00
4ooooooo0?ooool0ooooo`3ooolG0?oooaGooooo000Cooooool0ooooo`3ooooo0?oooaL0oooo5Ooo
ool001?oooooo`3ooooo0?oooa80oooo1000003o0?ooo`40oooo5Oooool001?oooooo`3ooooo0?oo
oa80oooo1000003o0?ooo`40oooo5Oooool001?oooooo`3ooooo0?oooa80oooo1000003o0?ooo`40
oooo5Oooool001?oooooo`3ooooo0?oooa80oooo1000003o0?ooo`40oooo5Oooool001?oooooo`3o
oooo0?oooa80oooo1000003o0?ooo`40oooo5Oooool001?oooooo`3ooooo0?oooa<0oooo1@00003n
0?oooaGooooo000Cooooool0ooooo`3ooolC0?ooo`D00000oP3ooolEooooo`004ooooooo0?ooool0
oooo4`3oool500000?h0oooo5Oooool001?oooooo`3ooooo0?oooa<0oooo1@00003n0?oooaGooooo
000Cooooool0ooooo`3ooolC0?ooo`D00000oP3ooolEooooo`004ooooooo0?ooool0oooo503oool5
00000?d0oooo5Oooool001?oooooo`3ooooo0?oooa@0oooo1@00003m0?oooaGooooo000Cooooool0
ooooo`3ooolD0?ooo`D00000o@3ooolEooooo`004ooooooo0?ooool0oooo4@3oool;000004@0oooo
2000002^0?oooaGooooo000Cooooool0ooooo`3oool>0?ooo`D0000000<0oooo0000000000000`00
00020?ooo`@00000?`3oool3000000H0oooo1000002[0?oooaGooooo000Cooooool0ooooo`3oool=
0?ooo`D000000`3oool4000000<0oooo1@00000l0?ooo`<000002P3oool200000:X0oooo5Oooool0
01?oooooo`3ooooo0?ooo``0oooo1P0000030?ooo`D00000103oool4000003T0oooo1000000<0?oo
o`800000Z@3ooolEooooo`004ooooooo0?ooool0oooo303oool6000000<0oooo1@0000040?ooo`@0
0000>@3oool4000000`0oooo0P00002Y0?oooaGooooo000Cooooool0ooooo`3oool<0?ooo`D00000
103oool5000000D0oooo1@00000f0?ooo`@000003@3oool300000:P0oooo5Oooool001?oooooo`3o
oooo0?ooo`/0oooo1P0000040?ooo`D000001@3oool6000003D0oooo1000000>0?ooo`800000Z03o
oolEooooo`004ooooooo0?ooool0oooo2`3oool6000000@0oooo1@0000060?ooo`H000003`3ooolN
000000H0oooo1000000?0?ooo`@00000YP3ooolEooooo`004ooooooo0?ooool0oooo2`3oool60000
00D0oooo100000060?ooo`H000003`3ooolN000000H0oooo1000000?0?ooo`@00000YP3ooolEoooo
o`004ooooooo0?ooool0oooo2`3oool6000000D0oooo100000070?ooo`D000003`3ooolN000000D0
oooo1@00000?0?ooo`D00000Y@3ooolEooooo`004ooooooo0?ooool0oooo2`3oool6000000D0oooo
100000070?ooo`D000003`3ooolN000000D0oooo1@00000?0?ooo`D00000Y@3ooolEooooo`004ooo
oooo0?ooool0oooo2`3oool6000000D0oooo1@0000060?ooo`H00000<@3oool300000180oooo1000
002U0?oooaGooooo000Cooooool0ooooo`3oool;0?ooo`H000001@3oool5000000H0oooo1P00000a
0?ooo`<000004P3oool400000:D0oooo5Oooool001?oooooo`3ooooo0?ooo`/0oooo1P0000070?oo
o`<000001P3oool600000300oooo1000000B0?ooo`@00000Y@3ooolEooooo`004ooooooo0?ooool0
oooo303oool6000000H0oooo0`0000060?ooo`H00000<03oool400000180oooo1@00002T0?oooaGo
oooo000Cooooool0ooooo`3oool<0?ooo`H000001P3oool3000000L0oooo1@00000`0?ooo`@00000
4P3oool500000:@0oooo5Oooool001?oooooo`3ooooo0?ooo``0oooo1P0000060?ooo`@000001P3o
ool500000300oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo303oool6
000000H0oooo100000060?ooo`D00000<03oool400000180oooo1@00002T0?oooaGooooo000Coooo
ool0ooooo`3oool=0?ooo`H000001@3oool4000000H0oooo1@00000`0?ooo`@000004P3oool50000
0:@0oooo5Oooool001?oooooo`3ooooo0?ooo`h0oooo1@0000060?ooo`<000001@3oool600000300
oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo3P3oool6000000D0oooo
0`0000050?ooo`H000003P3ooolN000000@0oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooo
oooo0?ooool0oooo3`3oool6000000@0oooo0`0000050?ooo`D000003`3ooolN000000@0oooo1000
000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo4P3oool4000000<0oooo0`000004
0?ooo`D00000403ooolN000000@0oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?oo
ool0oooo4P3oool4000000<0oooo0`0000040?ooo`D00000403ooolN000000@0oooo1000000B0?oo
o`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo4`3oool500000080oooo100000000`3oool0
000000000003000003<0oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo
5P3oool;000003H0oooo1000000B0?ooo`D00000Y03ooolEooooo`004ooooooo0?ooool0oooo6P3o
ool4000003X0oooo0`00000B0?ooo`@00000Y@3ooolEooooo`004ooooooo0?ooool0oooo6P3oool4
000003X0oooo1@00000?0?ooo`D00000Y@3ooolEooooo`004ooooooo0?ooool0oooo6`3oool30000
03X0oooo1@00000?0?ooo`D00000Y@3ooolEooooo`004ooooooo0?ooool0oooo6`3oool3000003X0
oooo1@00000?0?ooo`D00000Y@3ooolEooooo`004ooooooo0?ooool0oooo6`3oool3000003/0oooo
1000000?0?ooo`@00000YP3ooolEooooo`004ooooooo0?ooool0oooo6`3oool4000003X0oooo1000
000?0?ooo`@00000YP3ooolEooooo`004ooooooo0?ooool0oooo6`3oool4000003/0oooo1000000=
0?ooo`<00000Z03ooolEooooo`004ooooooo0?ooool0oooo6`3oool4000003/0oooo1000000=0?oo
o`<00000Z03ooolEooooo`004ooooooo0?ooool0oooo703oool3000003`0oooo1000000;0?ooo`<0
0000Z@3ooolEooooo`004ooooooo0?ooool0oooo703oool3000003h0oooo0`0000080?ooo`@00000
ZP3ooolEooooo`004ooooooo0?ooool0oooo703oool3000003h0oooo0`0000080?ooo`@00000ZP3o
oolEooooo`004ooooooo0?ooool0oooo703oool3000003l0oooo0`0000060?ooo`@00000Z`3ooolE
ooooo`004ooooooo0?ooool0oooo703oool400000400oooo2000002^0?oooaGooooo000Cooooool0
ooooo`3ooooo0?oooaL0oooo5Oooool001?oooooo`3ooooo0?ooool0oooo5`3ooolEooooo`004ooo
oooo0?ooool0ooooo`3ooolG0?oooaGooooo000Cooooool0ooooo`3ooooo0?oooaL0oooo5Oooool0
01?oooooo`3ooooo0?ooool0oooo5`3ooolEooooo`004ooooooo0?ooool0ooooo`3ooolG0?oooaGo
oooo000Cooooool0ooooo`3ooooo0?oooaL0oooo5Oooool001?oooooo`3ooooo0?ooool0oooo5`3o
oolEooooo`004ooooooo0?ooool0ooooo`3ooolG0?oooaGooooo000Cooooool0ooooo`3ooooo0?oo
oaL0oooo5Oooool001?oooooo`3ooooo0?ooool0oooo5`3ooolEooooo`004ooooooo0?ooool0oooo
o`3ooolG0?oooaGooooo000Cooooool0ooooo`3ooooo0?oooaL0oooo5Oooool001?oooooo`3ooon?
0?ooool00000O@00000:0?oooaGooooo000Cooooool0ooooS`3ooooo000007d000002P3ooolEoooo
o`004ooooooo0?ooohl0ooooo`00001m00000080oooo100000040?oooaGooooo000Cooooool0oooo
S`3ooooo000007d000000P3oool4000000@0oooo5Oooool001?oooooo`3ooon?0?ooool00000O@00
00020?ooo`@00000103ooolEooooo`004ooooooo0?ooohl0oooo1@00003o0?ooogX0oooo10000004
0?oooaGooooo000Cooooool0ooooS`3oool500000?l0ooooNP3oool4000000@0oooo5Oooool001?o
ooooo`3ooon?0?ooo`D00000o`3ooomj0?ooo`@00000103ooolEooooo`004ooooooo0?ooohh0oooo
1@00003o0?ooog/0oooo100000040?oooaGooooo000Cooooool0ooooSP3oool500000?l0ooooN`3o
ool4000000@0oooo5Oooool001?oooooo`3ooon>0?ooo`D00000o`3ooomk0?ooo`@00000103ooolE
ooooo`004ooooooo0?ooohh0oooo1@00003o0?ooog/0oooo100000040?oooaGooooo000Cooooool0
ooooSP3oool500000?l0ooooN`3oool4000000@0oooo5Oooool001?oooooo`3ooon>0?ooo`D00000
o`3ooomk0?ooo`@00000103ooolEooooo`004ooooooo0?ooohh0oooo1@00003o0?ooog/0oooo1000
00040?oooaGooooo000Cooooool0ooooSP3oool500000?l0ooooN`3oool4000000@0oooo5Oooool0
01?oooooo`3ooon>0?ooo`D00000o`3ooomk0?ooo`@00000103ooolEooooo`004ooooooo0?ooohd0
oooo1P00003o0?ooog/0oooo100000040?oooaGooooo000Cooooool0ooooS@3oool500000?l0oooo
O03oool4000000@0oooo5Oooool001?oooooo`3ooon=0?ooo`D00000o`3oooml0?ooo`@00000103o
oolEooooo`004ooooooo0?ooohd0oooo1@00003o0?ooog`0oooo100000040?oooaGooooo000Coooo
ool0ooooS@3oool500000?l0ooooO03oool4000000@0oooo5Oooool001?oooooo`3ooon<0?ooo`H0
0000o`3ooomj0?ooo`D000001@3ooolEooooo`004ooooooo0?oooaH0oooo1@00001a0?ooo`@00000
o`3oooml0?ooo`D000001@3ooolEooooo`004ooooooo0?oooaH0oooo1@00001a0?ooo`@00000o`3o
ooml0?ooo`D000001@3ooolEooooo`004ooooooo0?oooaH0oooo1@00001a0?ooo`@00000o`3oooml
0?ooo`D000001@3ooolEooooo`004ooooooo0?oooaH0oooo1@00001_0?ooo`H00000o`3oooml0?oo
o`D000001@3ooolEooooo`004ooooooo0?oooaL0oooo1@00001^0?ooo`D00000o`3ooomm0?ooo`D0
00001@3ooolEooooo`004ooooooo0?oooaL0oooo1@00001^0?ooo`D00000o`3ooomm0?ooo`D00000
1@3ooolEooooo`004ooooooo0?oooaL0oooo1@00001^0?ooo`D00000o`3ooomm0?ooo`D000001@3o
oolEooooo`004ooooooo0?oooaL0oooo1@00001]0?ooo`H00000o`3ooomm0?ooo`D000001@3ooolE
ooooo`004ooooooo0?oooaL0oooo1@00001]0?ooo`H00000o`3ooomm0?ooo`D000001@3ooolEoooo
o`004ooooooo0?oooaL0oooo1@00001]0?ooo`D00000o`3ooomn0?ooo`D000001@3ooolEooooo`00
4ooooooo0?oooaP0oooo1@00001[0?ooo`H00000o`3ooomn0?ooo`D000001@3ooolEooooo`004ooo
oooo0?oooaP0oooo1@00001[0?ooo`H00000o`3ooomn0?ooo`D000001@3ooolEooooo`004ooooooo
0?oooaP0oooo1@00001[0?ooo`H00000o`3ooomn0?ooo`D000001@3ooolEooooo`004ooooooo0?oo
oaD0oooo300000130?ooo`T000006`3oool500000?l0ooooO`3oool5000000D0oooo5Oooool001?o
ooooo`3ooolB0?ooo`D0000000<0oooo0000000000000`0000020?ooo`@00000?`3oool4000000H0
oooo0`00000H0?ooo`H00000o`3ooomo0?ooo`D000001@3ooolEooooo`004ooooooo0?oooa40oooo
1@0000030?ooo`@00000103oool4000003`0oooo0`00000:0?ooo`8000005`3oool600000?l0oooo
O`3oool5000000D0oooo5Oooool001?oooooo`3oool@0?ooo`H000000`3oool5000000@0oooo1@00
000i0?ooo`<00000303oool2000001H0oooo1@00003o0?oooh00oooo1@0000050?oooaGooooo000C
ooooool0oooo403oool6000000<0oooo1@0000040?ooo`D00000>@3oool3000000`0oooo0P00000F
0?ooo`D00000o`3ooon00?ooo`D000001@3ooolEooooo`004ooooooo0?oooa00oooo1@0000040?oo
o`D000001@3oool5000003H0oooo1000000=0?ooo`@000004`3oool600000?l0ooooP03oool50000
00D0oooo5Oooool001?oooooo`3oool?0?ooo`H00000103oool5000000D0oooo1P00000e0?ooo`@0
00003P3oool3000001<0oooo1000003o0?oooh80oooo1@0000050?oooaGooooo000Cooooool0oooo
3`3oool6000000@0oooo1@0000060?ooo`H00000403ooolM000000H0oooo1000000?0?ooo`@00000
403oool600000?l0ooooPP3oool5000000D0oooo5Oooool001?oooooo`3oool?0?ooo`H000001P3o
ool3000000H0oooo1P00000@0?oooad000001P3oool4000000l0oooo1000000@0?ooo`H00000o`3o
oon20?ooo`D000001@3ooolEooooo`004ooooooo0?ooo`l0oooo1P0000060?ooo`<000001`3oool5
00000100oooo7@0000050?ooo`D000003`3oool5000000h0oooo1P00003o0?oooh80oooo1@000006
0?oooaGooooo000Cooooool0oooo3`3oool6000000H0oooo100000060?ooo`H00000<@3oool40000
0140oooo1000000>0?ooo`H00000o`3ooon20?ooo`D000001P3ooolEooooo`004ooooooo0?ooo`l0
oooo1P0000060?ooo`@000001P3oool600000340oooo1000000A0?ooo`@000003P3oool600000?l0
ooooPP3oool5000000H0oooo5Oooool001?oooooo`3oool?0?ooo`H000001P3oool4000000H0oooo
1P00000a0?ooo`@000004@3oool4000000d0oooo1P00003o0?oooh<0oooo1@0000060?oooaGooooo
000Cooooool0oooo3`3oool6000000L0oooo0`0000060?ooo`H00000<03oool500000140oooo1000
000=0?ooo`H00000o`3ooon30?ooo`D000001P3ooolEooooo`004ooooooo0?oooa00oooo1P000006
0?ooo`<000001P3oool600000300oooo1@00000A0?ooo`D000002`3oool600000?l0ooooQ03oool5
000000H0oooo5Oooool001?oooooo`3oool@0?ooo`H000001P3oool3000000P0oooo1000000`0?oo
o`D000004@3oool5000000/0oooo1@00003o0?ooohD0oooo1@0000060?oooaGooooo000Cooooool0
oooo403oool6000000H0oooo1@0000060?ooo`@00000<03oool500000140oooo1@00000:0?ooo`H0
0000o`3ooon50?ooo`D000001P3ooolEooooo`004ooooooo0?oooa00oooo1P0000060?ooo`D00000
1P3oool400000300oooo1@00000A0?ooo`D000002P3oool600000?l0ooooQ@3oool5000000H0oooo
5Oooool001?oooooo`3ooolA0?ooo`H000001@3oool5000000H0oooo1000000`0?ooo`D000004@3o
ool5000000X0oooo1000003o0?ooohL0oooo1@0000060?oooaGooooo000Cooooool0oooo4P3oool5
000000H0oooo100000040?ooo`H00000<03oool500000140oooo1@0000070?ooo`H00000o`3ooon8
0?ooo`D000001P3ooolEooooo`004ooooooo0?oooa80oooo1P0000050?ooo`@00000103oool60000
00l0oooo7@0000040?ooo`D000004@3oool5000000H0oooo1`00003o0?ooohP0oooo1@0000060?oo
oaGooooo000Cooooool0oooo503oool5000000@0oooo100000040?ooo`D00000403ooolM000000@0
oooo1@00000A0?ooo`D000001P3oool600000?l0ooooR03oool5000000L0oooo5Oooool001?ooooo
o`3ooolF0?ooo`D000000P3oool4000000<0oooo1@00000A0?oooad00000103oool500000140oooo
1@0000050?ooo`H00000o`3ooon90?ooo`D000001`3ooolEooooo`004ooooooo0?oooaH0oooo1@00
00020?ooo`@000000`3oool500000140oooo7@0000040?ooo`D000004@3oool5000000D0oooo1P00
003o0?ooohT0oooo1@0000070?oooaGooooo000Cooooool0oooo5`3oool500000080oooo10000000
0`3oool0000000000003000003<0oooo1@00000A0?ooo`D00000103oool600000?l0ooooRP3oool5
000000L0oooo5Oooool001?oooooo`3ooolK0?ooo`X00000=P3oool500000140oooo1@0000030?oo
o`L00000o`3ooon:0?ooo`D000001`3ooolEooooo`004ooooooo0?oooah0oooo1000000j0?ooo`@0
00004@3oool4000000@0oooo1P00003o0?oooh/0oooo1@0000070?oooaGooooo000Cooooool0oooo
7P3oool4000003X0oooo1@00000?0?ooo`D000000P3oool600000?l0ooooS@3oool5000000L0oooo
5Oooool001?oooooo`3ooolO0?ooo`<00000>P3oool5000000l0oooo1@0000000`3oool000000000
000400000?l0ooooSP3oool5000000L0oooo5Oooool001?oooooo`3ooolO0?ooo`<00000>`3oool4
000000l0oooo100000000`3oool000000000000500000?l0ooooSP3oool5000000L0oooo5Oooool0
01?oooooo`3ooolO0?ooo`<00000>`3oool4000000l0oooo100000000`3oool00000000000050000
0?l0ooooSP3oool5000000L0oooo5Oooool001?oooooo`3ooolO0?ooo`@00000>P3oool4000000l0
oooo2`00003o0?ooohl0oooo1@0000070?oooaGooooo000Cooooool0oooo7`3oool4000003/0oooo
1000000=0?ooo`@0000000<0oooo0000000000001000003o0?oooi00oooo1@0000070?oooaGooooo
000Cooooool0oooo7`3oool4000003/0oooo1000000=0?ooo`X00000o`3ooon@0?ooo`D00000203o
oolEooooo`004ooooooo0?ooob40oooo0P00000m0?ooo`<000002`3oool900000?l0ooooTP3oool5
000000P0oooo5Oooool001?oooooo`3ooolQ0?ooo`800000?P3oool3000000T0oooo2P00003o0?oo
oi80oooo1@0000080?oooaGooooo000Cooooool0oooo8@3oool2000003h0oooo0`0000090?ooo`X0
0000o`3ooonB0?ooo`D00000203ooolEooooo`004ooooooo0?ooob40oooo0P00000o0?ooo`@00000
1P3oool:00000?l0ooooT`3oool5000000P0oooo5Oooool001?oooooo`3ooolQ0?ooo`<00000@03o
oolA00000?l0ooooU03oool5000000P0oooo5Oooool001?oooooo`3ooom/0?ooo`P00000o`3ooonE
0?ooo`D00000203ooolEooooo`004ooooooo0?ooofX0oooo2@00003o0?oooiH0oooo1@0000080?oo
oaGooooo000Cooooool0ooooJ03oool800000?l0ooooV03oool6000000P0oooo5Oooool001?ooooo
o`3ooomX0?ooo`P00000o`3ooonH0?ooo`H00000203ooolEooooo`004oooooob0?ooo`800000LP3o
ool800000?l0ooooV@3oool4000000X0oooo5Oooool001?oooooo`3ooomV0?ooo`P00000o`3ooonJ
0?ooo`@000002P3ooolEooooo`004ooooooo0?ooof@0oooo2000003o0?oooi`0oooo1000000:0?oo
oaGooooo000Coooooo00oooo00<000000?ooo`3oool0KP3oool800000?l0ooooWP3oool4000000X0
oooo5Oooool001?oooooo`3ooomQ0?ooo`P00000o`3ooonO0?ooo`@000002P3ooolEooooo`004ooo
oooo0?ooof00oooo2000003o0?oooil0oooo1000000;0?oooaGooooo000Cooooool0ooooH03oool8
00000?l0ooooW`3oool4000000/0oooo5Oooool001?oooookP3oool3000006/0oooo2@00003o0?oo
oj40oooo1000000;0?oooaGooooo000Cooooonh0oooo1P00001V0?ooo`T00000o`3ooonS0?ooo`@0
00002`3ooolEooooo`004oooooo]0?ooo`T00000H`3oool800000?l0ooooY@3oool4000000/0oooo
5Oooool001?oooooj`3oool=000005h0oooo2@00003o0?ooojL0oooo1000000;0?oooaGooooo000C
ooooon/0oooo4000001I0?ooo`P00000o`3ooonZ0?ooo`@000002`3ooolEooooo`004oooooo[0?oo
oa000000F@3oool800000?l0ooooZP3oool4000000/0oooo5Oooool001?ooooojP3oool600000080
oooo2`00001E0?ooo`T00000o`3ooonY0?ooo`D00000303ooolEooooo`004ooooooY0?ooo`H00000
1P3oool;000004l0oooo2P00003o0?oooj/0oooo1@00000<0?oooaGooooo000CooooonT0oooo1P00
00080?ooo`/00000BP3oool:00000?l0oooo[P3oool5000000`0oooo5Oooool001?oooooj03oool6
000000`0oooo2`0000130?ooo``00000o`3ooon`0?ooo`D00000303ooolEooooo`004ooooooW0?oo
o`H000003P3oool@000003T0oooo3P00003o0?oook80oooo1@00000<0?oooaGooooo000CooooonL0
oooo1P00000>0?oooa000000>@3oool>00000?l0oooo/P3oool5000000`0oooo5Oooool001?ooooo
i`3oool600000100oooo4`00000`0?oooa800000o`3ooonb0?ooo`D00000303ooolEooooo`004ooo
oooU0?ooo`H000005@3ooolE000002L0oooo4@00003o0?oookH0oooo1@00000=0?oooaGooooo000C
ooooon@0oooo1P00000J0?oooa`000004`3ooolF00000?l0oooo^P3oool5000000d0oooo5Oooool0
01?oooooi03oool600000200oooo?000003o0?oookd0oooo1@00000=0?oooaGooooo000Cooooon<0
oooo1P00000V0?oooc800000o`3oooo20?ooo`D000003@3ooolEooooo`004ooooooS0?ooo`H00000
9P3ooolb00000?l0oooo`P3oool5000000d0oooo5Oooool001?ooooohP3oool7000002/0oooo:@00
003o0?ooolH0oooo1@00000=0?oooaGooooo000Cooooon80oooo1P00000f0?oooaH00000o`3oooo?
0?ooo`D000003@3ooolEooooo`004ooooooQ0?ooo`H00000@@3oool00`000000oooo0?ooo`3o0?oo
omL0oooo1@00000>0?oooaGooooo000Coooooml0oooo2000003o0?ooool0oooo703oool5000000h0
oooo5Oooool001?ooooog`3oool600000?l0ooooo`3ooolN0?ooo`D000003P3ooolEooooo`004ooo
oooN0?ooo`H00000o`3ooooo0?oooah0oooo1P00000>0?oooaGooooo000Cooooomh0oooo1P00003o
0?ooool0oooo7P3oool6000000h0oooo5Oooool001?ooooog@3oool700000?l0ooooo`3ooolN0?oo
o`H000003P3ooolEooooo`004ooooooM0?ooo`H00000o`3ooooo0?oooal0oooo1@00000?0?oooaGo
oooo000Cooooom`0oooo1P00003o0?ooool0oooo803oool5000000l0oooo5Oooool001?ooooof`3o
ool700000?l0ooooo`3ooolO0?ooo`H000003`3ooolEooooo`004ooooooK0?ooo`H00000o`3ooooo
0?ooob00oooo1P00000?0?oooaGooooo000Cooooom/0oooo1P00003o0?ooool0oooo803oool60000
00l0oooo5Oooool001?ooooofP3oool500000?l0ooooo`3ooolR0?ooo`@000004@3ooolEooooo`00
4ooooooH0?ooo`L00000o`3ooooo0?ooob80oooo1000000A0?oooaGooooo000CooooomP0oooo1P00
003o0?ooool0oooo8@3oool600000140oooo5Oooool001?oooooe`3oool600000?l0ooooo`3ooolR
0?ooo`D000004P3ooolEooooo`004ooooooG0?ooo`H00000o`3ooooo0?ooob80oooo1@00000B0?oo
oaGooooo000CooooomL0oooo1P00003o0?ooool0oooo8P3oool500000180oooo5Oooool001?ooooo
eP3oool600000?l0ooooo`3ooolR0?ooo`H000004P3ooolEooooo`004ooooooE0?ooo`H00000o`3o
oooo0?ooob<0oooo1P00000B0?oooaGooooo000CooooomD0oooo1P00003o0?ooool0oooo8`3oool5
000001<0oooo5Oooool001?oooooe03oool600000?l0ooooo`3ooolT0?ooo`D000004`3ooolEoooo
o`004ooooooB0?ooo`H00000o`3ooooo0?ooobD0oooo1P00000C0?oooaGooooo000Cooooom80oooo
1P00003o0?ooool0oooo9@3oool5000001@0oooo5Oooool001?ooooodP3oool600000?l0ooooo`3o
oolU0?ooo`D00000503ooolEooooo`004ooooooA0?ooo`H00000o`3ooooo0?ooobH0oooo1@00000D
0?oooaGooooo000Cooooom00oooo1P00003o0?ooool0oooo9`3oool5000001@0oooo5Oooool001?o
ooood03oool600000?l0ooooo`3ooolV0?ooo`H00000503ooolEooooo`004oooooo?0?ooo`H00000
o`3ooooo0?ooobL0oooo1@00000E0?oooaGooooo000Cooooolh0oooo1P00003o0?ooool0oooo:03o
ool5000001D0oooo5Oooool001?ooooocP3oool600000?l0ooooo`3ooolX0?ooo`D000005@3ooolE
ooooo`004oooooo>0?ooo`H00000o`3ooooo0?ooobL0oooo1P00000E0?oooaGooooo000Coooool`0
oooo1P00003o0?ooool0oooo:@3oool4000001L0oooo5Oooool001?ooooob`3oool600000?l0oooo
o`3ooolZ0?ooo`@000005`3ooolEooooo`004oooooo;0?ooo`H00000o`3ooooo0?ooobX0oooo1000
000G0?oooaGooooo000CooooolX0oooo1P00003o0?ooool0oooo:@3oool6000001L0oooo5Oooool0
01?ooooobP3oool600000?l0ooooo`3ooolY0?ooo`H000005`3ooolEooooo`004oooooo90?ooo`H0
0000o`3ooooo0?ooobX0oooo1@00000H0?oooaGooooo000CooooolT0oooo1P00003o0?ooool0oooo
:P3oool5000001P0oooo5Oooool001?ooooob03oool600000?l0ooooo`3ooolZ0?ooo`H00000603o
oolEooooo`004oooooo60?ooo`H00000o`3ooooo0?ooob`0oooo1@00000I0?oooaGooooo000Coooo
olH0oooo1P00003o0?ooool0oooo;03oool5000001T0oooo5Oooool001?oooooa@3oool600000?l0
ooooo`3oool/0?ooo`H000006@3ooolEooooo`004oooooo50?ooo`H00000o`3ooooo0?ooob`0oooo
1P00000I0?oooaGooooo000Coooool@0oooo1P00003o0?ooool0oooo;@3oool5000001X0oooo5Ooo
ool001?oooooa03oool600000?l0ooooo`3oool]0?ooo`D000006P3ooolEooooo`004oooooo30?oo
o`H00000o`3ooooo0?ooobd0oooo1P00000J0?oooaGooooo000Coooool80oooo1P00003o0?ooool0
oooo;P3oool5000001/0oooo5Oooool001?ooooo`P3oool600000?l0ooooo`3oool^0?ooo`D00000
6`3ooolEooooo`004oooooo20?ooo`H00000o`3ooooo0?ooobh0oooo1@00000K0?oooaGooooo000C
oooool40oooo1@00003o0?ooool0oooo;`3oool6000001/0oooo5Oooool001?ooooo_`3oool60000
0?l0ooooo`3oool`0?ooo`@000007@3ooolEooooo`004ooooono0?ooo`H00000o`3ooooo0?oooc00
oooo1000000M0?oooaGooooo000Coooookh0oooo1P00003o0?ooool0oooo<03oool5000001d0oooo
5Oooool001?ooooo_@3oool600000?l0ooooo`3ooola0?ooo`D000007@3ooolEooooo`004ooooonm
0?ooo`H00000o`3ooooo0?oooc40oooo1@00000M0?oooaGooooo000Coooookd0oooo1P00003o0?oo
ool0oooo<@3oool4000001h0oooo5Oooool001?ooooo_03oool600000?l0ooooo`3oool`0?ooo`H0
00007P3ooolEooooo`004ooooonk0?ooo`H00000o`3ooooo0?oooc40oooo1P00000N0?oooaGooooo
000Coooook/0oooo1P00003o0?ooool0oooo<@3oool5000001l0oooo5Oooool001?ooooo^@3oool6
00000?l0ooooo`3ooolb0?ooo`H000007`3ooolEooooo`004ooooonh0?ooo`H00000o`3ooooo0?oo
oc<0oooo1P00000O0?oooaGooooo000CoooookP0oooo1P00003o0?ooool0oooo<`3oool6000001l0
oooo5Oooool001?ooooo^03oool600000?l0ooooo`3ooolc0?ooo`D00000803ooolEooooo`004ooo
oong0?ooo`H00000o`3ooooo0?oooc<0oooo1P00000P0?oooaGooooo000CoooookH0oooo1P00003o
0?ooool0oooo=03oool600000200oooo5Oooool001?ooooo]P3oool600000?l0ooooo`3ooold0?oo
o`D000008@3ooolEooooo`004ooooone0?ooo`H00000o`3ooooo0?oooc@0oooo1P00000Q0?oooaGo
oooo000CoooookD0oooo1P00003o0?ooool0oooo=03oool600000240oooo5Oooool001?ooooo/`3o
ool600000?l0ooooo`3ooolf0?ooo`H000008@3ooolEooooo`004ooooonc0?ooo`H00000o`3ooooo
0?ooocH0oooo1@00000R0?oooaGooooo000Coooook80oooo1P00003o0?ooool0oooo=P3oool60000
0280oooo5Oooool001?ooooo/@3oool600000?l0ooooo`3ooolg0?ooo`H000008P3ooolEooooo`00
4ooooona0?ooo`H00000o`3ooooo0?ooocD0oooo1P00000T0?oooaGooooo000Coooook40oooo1P00
003o0?ooool0oooo=@3oool6000002@0oooo5Oooool001?ooooo/03oool600000?l0ooooo`3ooolf
0?ooo`H00000903ooolEooooo`004ooooon_0?ooo`H00000o`3ooooo0?ooocH0oooo1P00000U0?oo
oaGooooo000Cooooojl0oooo1P00003o0?ooool0oooo=P3oool6000002D0oooo5Oooool001?ooooo
[P3oool500000?l0ooooo`3ooolg0?ooo`H000009P3ooolEooooo`004ooooon/0?ooo`H00000o`3o
oooo0?ooocP0oooo1P00000V0?oooaGooooo000Coooooj`0oooo1P00003o0?ooool0oooo>03oool6
000002H0oooo5Oooool001?ooooo[03oool600000?l0ooooo`3ooolh0?ooo`D000009`3ooolEoooo
o`004ooooon[0?ooo`H00000o`3ooooo0?ooocP0oooo1P00000W0?oooaGooooo000CooooojX0oooo
1P00003o0?ooool0oooo>@3oool6000002L0oooo5Oooool001?oooooQP3oool9000001/0oooo1P00
003o0?ooool0oooo>03oool6000002P0oooo5Oooool001?oooooQ03oool5000000H0oooo0P00000H
0?ooo`H00000o`3ooooo0?ooocT0oooo1P00000X0?oooaGooooo000Coooooh80oooo1000000:0?oo
o`<000005@3oool600000?l0ooooo`3ooolh0?ooo`H00000:P3ooolEooooo`004ooooon20?ooo`@0
00002P3oool3000001D0oooo1P00003o0?ooool0oooo>03oool6000002X0oooo5Oooool001?ooooo
P03oool5000000`0oooo1000000C0?ooo`H00000o`3ooooo0?ooocP0oooo1P00000Z0?oooaGooooo
000Cooooogl0oooo1@00000>0?ooo`@00000403oool600000?l0ooooo`3oooli0?ooo`H00000:`3o
oolEooooo`004oooool<0?ooo`D00000KP3oool5000000h0oooo1000000?0?ooo`H00000o`3ooooo
0?ooocX0oooo1P00000[0?oooaGooooo000Cooooo``0oooo1@00001]0?ooo`D00000403oool40000
00h0oooo1P00003o0?ooool0oooo>P3oool5000002`0oooo5Oooool001?ooooo303oool5000006d0
oooo1@00000@0?ooo`@000003@3oool600000?l0ooooo`3ooolj0?ooo`H00000;03ooolEooooo`00
4oooool<0?ooo`D00000K@3oool500000100oooo1000000=0?ooo`H00000o`3ooooo0?ooocX0oooo
1P00000/0?oooaGooooo000Cooooo``0oooo1@00001/0?ooo`H00000403oool5000000`0oooo1@00
003o0?ooool0oooo>`3oool6000002`0oooo5Oooool001?ooooo3@3oool5000006/0oooo1@00000A
0?ooo`D000002`3oool600000?l0ooooo`3ooolj0?ooo`H00000;@3ooolEooooo`004oooool=0?oo
o`D00000J`3oool500000140oooo1@00000:0?ooo`H00000o`3ooooo0?oooc/0oooo1P00000]0?oo
oaGooooo000Cooooo`d0oooo1@00001[0?ooo`D000004@3oool5000000X0oooo1000003o0?ooool0
oooo?03oool6000002h0oooo5Oooool001?ooooo3@3oool5000006/0oooo1@00000A0?ooo`D00000
203oool600000?l0ooooo`3oooll0?ooo`H00000;P3ooolEooooo`004oooool=0?ooo`D00000J`3o
ool500000140oooo1@0000080?ooo`H00000o`3ooooo0?oooc`0oooo1P00000^0?oooaGooooo000C
ooooo`d0oooo1@00001[0?ooo`D000004@3oool5000000L0oooo1P00003o0?ooool0oooo?03oool5
00000300oooo5Oooool001?ooooo3P3oool5000006X0oooo1@00000@0?ooo`H000001`3oool50000
0?l0ooooo`3ooolm0?ooo`D00000<03ooolEooooo`004oooool>0?ooo`D00000J`3oool400000100
oooo1@0000070?ooo`H00000o`3ooooo0?ooocd0oooo1000000a0?oooaGooooo000Cooooo`/0oooo
3000001?0?ooo`030000003oool0oooo01D0oooo1000000@0?ooo`D000001P3oool600000?l0oooo
o`3oooll0?ooo`H00000<@3ooolEooooo`004oooool80?ooo`D0000000<0oooo0000000000000`00
00020?ooo`@00000C@3oool3000001H0oooo1000000>0?ooo`H000001P3oool500000?l0ooooo`3o
ooll0?ooo`H00000<P3ooolEooooo`004oooool70?ooo`D000000`3oool4000000@0oooo1000001:
0?ooo`@000005P3oool4000000h0oooo1@0000060?ooo`H00000o`3ooooo0?oooc`0oooo1P00000b
0?oooaGooooo000Cooooo`L0oooo1@0000030?ooo`@00000103oool4000004X0oooo1000000F0?oo
o`@000003P3oool5000000H0oooo1P00003o0?ooool0oooo?03oool600000380oooo5Oooool001?o
oooo1P3oool6000000<0oooo1@0000040?ooo`D00000B03oool4000001L0oooo1000000<0?ooo`D0
00001P3oool500000?l0ooooo`3ooolm0?ooo`H00000<`3ooolEooooo`004oooool60?ooo`D00000
103oool5000000D0oooo1@0000160?ooo`H00000603oool3000000X0oooo100000080?ooo`@00000
o`3ooooo0?oooch0oooo1P00000c0?oooaGooooo000Cooooo`D0oooo1P0000040?ooo`D000001@3o
ool6000004D0oooo1P00000I0?ooo`<000001P3oool5000000P0oooo1P00003o0?ooool0oooo?@3o
ool6000003@0oooo5Oooool001?ooooo1@3oool6000000@0oooo1@0000060?ooo`H000004@3ooolM
000001D0oooo2000000K0?ooo`T000002@3oool600000?l0ooooo`3oooln0?ooo`H00000=03ooolE
ooooo`004oooool50?ooo`H000001P3oool3000000H0oooo1P00000A0?oooad000005@3oool40000
0080oooo0P00000]0?ooo`D00000o`3ooooo0?oooch0oooo1P00000e0?oooaGooooo000Cooooo`D0
oooo1P0000060?ooo`<000001P3oool600000140oooo7@00000E0?ooo`@000000P3oool2000002d0
oooo1@00003o0?ooool0oooo?P3oool6000003D0oooo5Oooool001?ooooo1@3oool6000000H0oooo
0`0000070?ooo`D000004@3ooolM000001<0oooo1P0000020?ooo`800000;03oool600000?l0oooo
o`3oooln0?ooo`H00000=@3ooolEooooo`004oooool50?ooo`H000001P3oool4000000H0oooo1P00
00100?ooo`D000000`3oool3000002X0oooo1P00003o0?ooool0oooo?@3oool6000003L0oooo5Ooo
ool001?ooooo1@3oool6000000H0oooo100000060?ooo`H00000@03oool5000000@0oooo0P00000Z
0?ooo`D00000o`3ooooo0?oooch0oooo1@00000h0?oooaGooooo000Cooooo`D0oooo1P0000070?oo
o`<000001P3oool6000003l0oooo1@0000050?ooo`800000:@3oool600000?l0ooooo`3ooolm0?oo
o`H00000>03ooolEooooo`004oooool60?ooo`H000001P3oool3000000H0oooo1P00000o0?ooo`D0
00001P3oool2000002H0oooo1P00003o0?ooool0oooo?`3oool5000003T0oooo5Oooool001?ooooo
1P3oool6000000H0oooo0`0000060?ooo`H00000?`3oool5000000H0oooo0P00000V0?ooo`H00000
o`3ooooo0?ooocl0oooo1@00000i0?oooaGooooo000Cooooo`H0oooo1P0000060?ooo`<00000203o
ool4000003h0oooo1P0000060?ooo`8000009P3oool500000?l0ooooo`3ooolo0?ooo`H00000>@3o
oolEooooo`004oooool60?ooo`H000001P3oool5000000H0oooo1000000n0?ooo`D000001`3oool2
000002D0oooo1P00003o0?ooool0oooo?`3oool5000003X0oooo5Oooool001?ooooo1`3oool60000
00D0oooo1@0000060?ooo`@00000?@3oool6000000P0oooo0`00000R0?ooo`H00000o`3ooooo0?oo
ocl0oooo1P00000j0?oooaGooooo000Cooooo`P0oooo1@0000060?ooo`@00000103oool6000003d0
oooo1@0000090?ooo`<000008P3oool500000?l0ooooo`3ooom00?ooo`D00000>`3ooolEooooo`00
4oooool80?ooo`H000001@3oool4000000@0oooo1P00000@0?oooad00000403oool5000000T0oooo
0`00000Q0?ooo`H00000o`3ooooo0?ooocl0oooo1P00000k0?oooaGooooo000Cooooo`X0oooo1@00
00040?ooo`@00000103oool500000140oooo7@00000?0?ooo`@00000303oool3000001l0oooo1P00
003o0?ooool0oooo@03oool4000003d0oooo5Oooool001?ooooo2P3oool5000000@0oooo10000004
0?ooo`D000004@3ooolM000000l0oooo1000000<0?ooo`<000007`3oool600000?l0ooooo`3ooom0
0?ooo`@00000?@3ooolEooooo`004oooool<0?ooo`D000000P3oool4000000<0oooo1@00000B0?oo
oad000003`3oool4000000`0oooo0`00000O0?ooo`@00000o`3ooooo0?oood00oooo1@00000n0?oo
oaGooooo000Cooooo`d0oooo1@0000020?ooo`@0000000<0oooo0000000000000`00000n0?ooo`D0
0000303oool4000001`0oooo1P00003o0?ooool0oooo@03oool5000003h0oooo5Oooool001?ooooo
4@3oool:00000440oooo1000000?0?ooo`8000006`3oool600000?l0ooooo`3ooom00?ooo`D00000
?`3ooolEooooo`004ooooolD0?ooo`@00000@P3oool6000000l0oooo0P00000K0?ooo`D00000o`3o
oooo0?oood40oooo1@00000o0?oooaGooooo000Coooooa@0oooo100000120?ooo`D000004@3oool2
000001T0oooo1P00003o0?ooool0oooo@03oool500000400oooo5Oooool001?ooooo503oool40000
0480oooo1@00000A0?ooo`8000006@3oool600000?l0ooooo`3ooom00?ooo`D00000@03ooolEoooo
o`004ooooolE0?ooo`<00000@@3oool600000140oooo0P00000H0?ooo`H00000o`3ooooo0?oood40
oooo1@0000100?oooaGooooo000CoooooaD0oooo0`0000110?ooo`D000004P3oool2000001P0oooo
1@00003o0?ooool0oooo@@3oool500000440oooo5Oooool001?ooooo5@3oool400000400oooo1@00
000C0?ooo`8000005P3oool600000?l0ooooo`3ooom00?ooo`H00000@@3ooolEooooo`004ooooolE
0?ooo`@00000?`3oool6000001<0oooo0P00000D0?ooo`H00000o`3ooooo0?oood80oooo10000013
0?oooaGooooo000CoooooaD0oooo1000000o0?ooo`D00000503oool2000001@0oooo1@00003o0?oo
ool0oooo@@3oool5000004@0oooo5Oooool001?ooooo5@3oool4000003l0oooo1@00000D0?ooo`80
0000503oool500000?l0ooooo`3ooom10?ooo`D00000A03ooolEooooo`004ooooolG0?ooo`800000
?P3oool6000001@0oooo0`00000B0?ooo`H00000o`3ooooo0?oood00oooo1P0000140?oooaGooooo
000CoooooaL0oooo0P00000n0?ooo`H00000503oool300000140oooo1P00003o0?ooool0oooo@@3o
ool5000004D0oooo5Oooool001?ooooo5`3oool2000003d0oooo1`00000D0?ooo`H000003P3oool5
00000?l0ooooo`3ooom10?ooo`H00000A@3ooolEooooo`004ooooolG0?ooo`<00000>@3oool>0000
00`0oooo2`00000<0?ooo`H00000o`3ooooo0?oood00oooo1P0000160?oooaGooooo000Coooooh<0
oooo1P00003o0?ooool0oooo@@3oool5000004L0oooo5Oooool001?oooooP`3oool600000?l0oooo
o`3ooom10?ooo`D00000A`3ooolEooooo`004ooooon30?ooo`@00000o`3ooooo0?oood80oooo1P00
00170?oooaGooooo000Coooooh80oooo1@00003o0?ooool0oooo@@3oool5000004T0oooo5Oooool0
01?oooooP03oool600000?l0ooooo`3ooom20?ooo`@00000BP3ooolEooooo`004ooooon00?ooo`D0
0000o`3ooooo0?oood40oooo1P00001:0?oooaGooooo000Cooooogl0oooo1P00003o0?ooool0oooo
@@3oool5000004/0oooo5Oooool001?oooooOP3oool600000?l0ooooo`3ooom10?ooo`H00000B`3o
oolEooooo`004ooooomn0?ooo`H00000o`3ooooo0?oood40oooo1P00001;0?oooaGooooo000Coooo
ogh0oooo1@00003o0?ooool0oooo@@3oool6000004`0oooo5Oooool001?oooooO@3oool600000?l0
ooooo`3ooom10?ooo`D00000C@3ooolEooooo`004oooooml0?ooo`H00000o`3ooooo0?oood40oooo
1P00001=0?oooaGooooo000Cooooog`0oooo1000003o0?ooool0oooo@P3oool6000004h0oooo5Ooo
ool001?oooooNP3oool600000?l0ooooo`3ooom20?ooo`H00000CP3ooolEooooo`004ooooomj0?oo
o`H00000o`3ooooo0?oood80oooo1P00001>0?oooaGooooo000CooooogT0oooo1P00003o0?ooool0
oooo@@3oool600000500oooo5Oooool001?oooooN@3oool500000?l0ooooo`3ooom10?ooo`H00000
D@3ooolEooooo`004ooooomh0?ooo`H00000o`3ooooo0?oood40oooo1P00001A0?oooaGooooo000C
ooooogL0oooo1P00003o0?ooool0oooo@@3oool600000580oooo5Oooool001?oooooM`3oool50000
0?l0ooooo`3ooom10?ooo`H00000D`3ooolEooooo`004ooooomg0?ooo`D00000o`3ooooo0?oood40
oooo1P00001C0?oooaGooooo000CooooogH0oooo1P00003o0?ooool0oooo@@3oool6000005<0oooo
5Oooool001?oooooM03oool600000?l0ooooo`3ooom20?ooo`H00000E03ooolEooooo`004ooooomd
0?ooo`D00000o`3ooooo0?oood40oooo2000001D0?oooaGooooo000Cooooog<0oooo1P00003o0?oo
ool0oooo@@3oool6000005H0oooo5Oooool001?oooooLP3oool600000?l0ooooo`3ooom10?ooo`H0
0000E`3ooolEooooo`004ooooomb0?ooo`D00000o`3ooooo0?oood40oooo1`00001G0?oooaGooooo
000Cooooog80oooo1@00003o0?ooool0oooo@@3oool7000005L0oooo5Oooool001?oooooL@3oool6
00000?l0ooooo`3ooom00?ooo`L00000F03ooolEooooo`004ooooom`0?ooo`H00000o`3ooooo0?oo
od40oooo1P00001I0?oooaGooooo000Cooooog00oooo1000003o0?ooool0oooo@P3oool6000005X0
oooo5Oooool001?oooooK`3oool500000?l0ooooo`3ooom10?ooo`D00000G03ooolEooooo`004ooo
oom_0?ooo`@00000o`3ooooo0?oood00oooo1`00001L0?oooaGooooo000Cooooofl0oooo1000003o
0?ooool0oooo@03oool7000005`0oooo5Oooool001?oooooK@3oool500000?l0ooooo`3ooom10?oo
o`H00000G@3ooolEooooo`004ooooom/0?ooo`H00000o`3ooooo0?oood00oooo1P00001N0?oooaGo
oooo000Cooooof`0oooo1@00003o0?ooool0oooo@03oool6000005l0oooo5Oooool001?oooooJ`3o
ool500000?l0ooooo`3ooom10?ooo`H00000G`3ooolEooooo`004ooooomZ0?ooo`H00000o`3ooooo
0?oood00oooo1P00001P0?oooaGooooo000CooooofX0oooo1P00003o0?ooool0oooo@03oool60000
0600oooo5Oooool001?oooooJP3oool500000?l0ooooo`3ooom00?ooo`H00000H@3ooolEooooo`00
4ooooomY0?ooo`@00000o`3ooooo0?oood00oooo1P00001S0?oooaGooooo000CooooofL0oooo1P00
003o0?ooool0oooo@03oool6000006<0oooo5Oooool001?oooooI`3oool500000?l0ooooo`3ooom0
0?ooo`H00000I03ooolEooooo`004ooooomV0?ooo`D00000o`3ooooo0?oood00oooo1P00001U0?oo
oaGooooo000CooooofD0oooo1P00003o0?ooool0oooo?`3oool6000006H0oooo5Oooool001?ooooo
I@3oool600000?l0ooooo`3ooolo0?ooo`H00000IP3ooolEooooo`004ooooomU0?ooo`D00000o`3o
oooo0?oood00oooo1P00001V0?oooaGooooo000Cooooof@0oooo1@00003o0?ooool0oooo@03oool6
000006L0oooo5Oooool001?oooooH`3oool600000?l0ooooo`3oooln0?ooo`H00000J@3ooolEoooo
o`004ooooomS0?ooo`@00000o`3ooooo0?oood00oooo1@00001Z0?oooaGooooo000Cooooof40oooo
1@00003o0?ooool0oooo@03oool6000006X0oooo5Oooool001?oooooH@3oool500000?l0ooooo`3o
oom00?ooo`H00000JP3ooolEooooo`004ooooomP0?ooo`H00000o`3ooooo0?ooocl0oooo1P00001[
0?oooaGooooo000Cooooof00oooo1@00003o0?ooool0oooo?`3oool6000006`0oooo5Oooool001?o
ooooG`3oool600000?l0ooooo`3ooolo0?ooo`D00000K@3ooolEooooo`004ooooomN0?ooo`H00000
o`3ooooo0?ooocl0oooo1P00001]0?oooaGooooo000Coooooeh0oooo1@00003o0?ooool0oooo?`3o
ool5000006l0oooo5Oooool001?oooooGP3oool500000?l0ooooo`3ooolo0?ooo`D00000K`3ooolE
ooooo`004ooooomM0?ooo`H00000o`3ooooo0?ooocd0oooo1P00001`0?oooaGooooo000Coooooe`0
oooo1@00003o0?ooool0oooo?`3oool500000740oooo5Oooool001?oooooG03oool400000?l0oooo
o`3ooolo0?ooo`H00000L@3ooolEooooo`004ooooomJ0?ooo`H00000o`3ooooo0?oooch0oooo1P00
001b0?oooaGooooo000CoooooeT0oooo1P00003o0?ooool0oooo?P3oool6000007<0oooo5Oooool0
01?oooooF@3oool500000?l0ooooo`3oooln0?ooo`L00000L`3ooolEooooo`004ooooomI0?ooo`D0
0000o`3ooooo0?oooch0oooo1`00001c0?oooaGooooo000CoooooeP0oooo1P00003o0?ooool0oooo
?03oool8000007@0oooo5Oooool001?oooooE`3oool600000?l0ooooo`3oooll0?ooo`L00000MP3o
oolEooooo`004ooooomG0?ooo`D00000o`3ooooo0?oooc`0oooo1`00001g0?oooaGooooo000Coooo
oeH0oooo1P00003o0?ooool0oooo>`3oool7000007P0oooo5Oooool001?oooooE03oool600000?l0
ooooo`3oooll0?ooo`L00000N@3ooolEooooo`004ooooomD0?ooo`H00000o`3ooooo0?oooc`0oooo
1`00001i0?oooaGooooo000Coooooe@0oooo1@00003o0?ooool0oooo>`3oool8000007X0oooo5Ooo
ool001?oooooD`3oool600000?l0ooooo`3ooolj0?ooo`L00000O03ooolEooooo`004ooooomB0?oo
o`H00000o`3ooooo0?ooocX0oooo1`00001m0?oooaGooooo000Coooooe80oooo1@00003o0?ooool0
oooo>P3oool7000007h0oooo5Oooool001?oooooD@3oool600000?l0ooooo`3oooli0?ooo`L00000
O`3ooolEooooo`004ooooomA0?ooo`H00000o`3ooooo0?ooocT0oooo1`00001o0?oooaGooooo000C
oooooe00oooo1P00003o0?ooool0oooo>P3oool600000800oooo5Oooool001?oooooD03oool40000
0?l0ooooo`3ooolk0?ooo`D00000PP3ooolEooooo`004ooooom>0?ooo`H00000o`3ooooo0?ooocT0
oooo1P0000230?oooaGooooo000Cooooodd0oooo1P00003o0?ooool0oooo>@3oool7000008<0oooo
5Oooool001?oooooC@3oool500000?l0ooooo`3oooli0?ooo`L00000Q03ooolEooooo`004ooooom=
0?ooo`D00000o`3ooooo0?ooocT0oooo1`0000240?oooaGooooo000Coooood`0oooo1P00003o0?oo
ool0oooo>03oool7000008D0oooo5Oooool001?oooooB`3oool600000?l0ooooo`3ooolh0?ooo`L0
0000QP3ooolEooooo`004ooooom;0?ooo`D00000o`3ooooo0?ooocL0oooo200000270?oooaGooooo
000CooooodX0oooo1P00003o0?ooool0oooo=P3oool7000008T0oooo5Oooool001?oooooB@3oool5
00000?l0ooooo`3ooolg0?ooo`L00000RP3ooolEooooo`004ooooom90?ooo`@00000o`3ooooo0?oo
ocL0oooo1`00002;0?oooaGooooo000CooooodT0oooo1000003o0?ooool0oooo=`3oool7000008/0
oooo5Oooool001?oooooA`3oool600000?l0ooooo`3ooolf0?ooo`L00000S03ooolEooooo`004ooo
oom60?ooo`H00000o`3ooooo0?ooocD0oooo2000002=0?oooaGooooo000CooooodH0oooo1@00003o
0?ooool0oooo=@3oool7000008l0oooo5Oooool001?oooooA@3oool600000?l0ooooo`3ooold0?oo
o`L00000T03ooolEooooo`004ooooom40?ooo`H00000o`3ooooo0?oooc@0oooo1`00002A0?oooaGo
oooo000Coooood@0oooo1P00003o0?ooool0oooo=03oool700000940oooo5Oooool001?oooooA03o
ool500000?l0ooooo`3ooole0?ooo`H00000TP3ooolEooooo`004ooooom30?ooo`H00000o`3ooooo
0?oooc@0oooo1P00002C0?oooaGooooo000Coooood40oooo1P00003o0?ooool0oooo=03oool60000
09D0oooo5Oooool001?ooooo@@3oool500000?l0ooooo`3ooold0?ooo`H00000UP3ooolEooooo`00
4ooooom00?ooo`H00000o`3ooooo0?oooc80oooo1`00002G0?oooaGooooo000Coooood00oooo1P00
003o0?ooool0oooo<P3oool7000009L0oooo5Oooool001?ooooo?`3oool600000?l0ooooo`3ooolb
0?ooo`L00000V03ooolEooooo`004ooooolo0?ooo`D00000o`3ooooo0?oooc80oooo1`00002I0?oo
oaGooooo000Coooooch0oooo1P00003o0?ooool0oooo<03oool6000009`0oooo5Oooool001?ooooo
?@3oool600000?l0ooooo`3oool`0?ooo`H00000W@3ooolEooooo`004ooooolm0?ooo`@00000o`3o
oooo0?oooc40oooo1P00002N0?oooaGooooo000Coooooc/0oooo1P00003o0?ooool0oooo<03oool6
000009l0oooo5Oooool001?ooooo>`3oool600000?l0ooooo`3oool`0?ooo`H00000W`3ooolEoooo
o`004ooooolj0?ooo`H00000o`3ooooo0?oooc00oooo1P00002P0?oooaGooooo000CooooocX0oooo
1@00003o0?ooool0oooo;`3oool600000:80oooo5Oooool001?ooooo>@3oool600000?l0ooooo`3o
ool]0?ooo`L00000X`3ooolEooooo`004oooooli0?ooo`D00000o`3ooooo0?ooobd0oooo1`00002T
0?oooaGooooo000CooooocP0oooo1@00003o0?ooool0oooo;@3oool700000:D0oooo5Oooool001?o
oooo>03oool500000?l0ooooo`3oool]0?ooo`L00000Y@3ooolEooooo`004ooooolg0?ooo`H00000
o`3ooooo0?ooob/0oooo1P00002X0?oooaGooooo000CooooocL0oooo1000003o0?ooool0oooo;03o
ool600000:T0oooo5Oooool001?ooooo=@3oool500000?l0ooooo`3oool/0?ooo`H00000ZP3ooolE
ooooo`004ooooold0?ooo`H00000o`3ooooo0?ooob/0oooo1P00002[0?oooaGooooo000Coooooc@0
oooo1@00003o0?ooool0oooo:`3oool600000:`0oooo5Oooool001?ooooo=03oool500000?l0oooo
o`3oool[0?ooo`H00000[03ooolEooooo`004ooooolc0?ooo`D00000o`3ooooo0?ooob/0oooo1@00
002^0?oooaGooooo000Coooooc80oooo1P00003o0?ooool0oooo:03oool700000:l0oooo5Oooool0
01?ooooo<P3oool500000?l0ooooo`3ooolX0?ooo`L00000/03ooolEooooo`004ooooola0?ooo`@0
0000o`3ooooo0?ooobT0oooo1`00002a0?oooaGooooo000Coooooc00oooo1@00003o0?ooool0oooo
:03oool600000;<0oooo5Oooool001?ooooo<03oool400000?l0ooooo`3ooolW0?ooo`H00000]@3o
oolEooooo`004oooool`0?ooo`@00000o`3ooooo0?ooobL0oooo1P00002e0?oooaGooooo000Coooo
obh0oooo1@00003o0?ooool0oooo9`3oool600000;H0oooo5Oooool001?ooooo;@3oool600000?l0
ooooo`3ooolU0?ooo`L00000]`3ooolEooooo`004oooool]0?ooo`D00000o`3ooooo0?ooobD0oooo
1`00002h0?oooaGooooo000Cooooob`0oooo1@00003o0?ooool0oooo8`3oool900000;T0oooo5Ooo
ool001?ooooo:`3oool600000?l0ooooo`3ooolR0?ooo`L00000_03ooolEooooo`004oooool[0?oo
o`H00000o`3ooooo0?ooob80oooo1`00002l0?oooaGooooo000Cooooob/0oooo1@00003o0?ooool0
oooo8P3oool700000;d0oooo5Oooool001?ooooo:P3oool400000?l0ooooo`3ooolR0?ooo`L00000
_`3ooolEooooo`004ooooolX0?ooo`H00000o`3ooooo0?ooob00oooo1`0000310?oooaGooooo000C
ooooobP0oooo1@00003o0?ooool0oooo803oool700000<80oooo5Oooool001?ooooo9`3oool50000
0?l0ooooo`3ooolO0?ooo`L00000a03ooolEooooo`004ooooolW0?ooo`D00000o`3ooooo0?oooal0
oooo1`0000340?oooaGooooo000CooooobH0oooo1P00003o0?ooool0oooo7P3oool700000<D0oooo
5Oooool001?ooooo9P3oool500000?l0ooooo`3ooolL0?ooo`T00000aP3ooolEooooo`004ooooolU
0?ooo`D00000o`3ooooo0?oooa`0oooo1`0000390?oooaGooooo000Cooooob@0oooo1P00003o0?oo
ool0oooo6`3oool700000<X0oooo5Oooool001?ooooo903oool400000?l0ooooo`3ooolJ0?ooo`P0
0000c03ooolEooooo`004ooooolR0?ooo`D00000o`3ooooo0?oooaX0oooo1`00003>0?oooaGooooo
000Cooooob80oooo1@00003o0?ooool0oooo6P3oool700000<h0oooo5Oooool001?ooooo8@3oool6
00000?l0ooooo`3ooolH0?ooo`P00000c`3ooolEooooo`004ooooolQ0?ooo`D00000o`3ooooo0?oo
oaP0oooo1`00003A0?oooaGooooo000Cooooob00oooo1@00003o0?ooool0oooo5`3oool800000=80
oooo5Oooool001?ooooo8P3oool300000?l0ooooo`3ooolE0?ooo`L00000e@3ooolEooooo`004ooo
oolQ0?ooo`<00000o`3ooooo0?oooaD0oooo1`00003F0?oooaGooooo000Cooooob40oooo0`00003o
0?ooool0oooo5@3oool700000=H0oooo5Oooool001?ooooo803oool500000?l0ooooo`3ooolB0?oo
o`P00000e`3ooolEooooo`004ooooolO0?ooo`P00000o`3ooooo0?ooo`h0oooo1`00003J0?oooaGo
oooo000Cooooob40oooo2@00003o0?ooool0oooo2@3oool800000=/0oooo5Oooool001?ooooo8P3o
ool:00000?l0ooooo`3oool50?ooo`P00000g@3ooolEooooo`004ooooolU0?ooo`P00000o`3ooooo
0?ooo`80oooo2@00003N0?oooaGooooo000CooooobD0oooo2000003o0?ooool0oooo0P3oool90000
0=h0oooo5Oooool001?ooooo9`3oool900000?l0ooooo03oool800000>40oooo5Oooool001?ooooo
:P3oool800000?l0oooon03oool900000>80oooo5Oooool001?ooooo:`3oool800000?l0oooom03o
ool:00000>@0oooo5Oooool001?ooooo;@3oool800000?l0ooool@3oool800000>L0oooo5Oooool0
01?ooooo<03oool800000?l0ooook03oool900000>P0oooo5Oooool001?ooooo<03oool800000?l0
ooook03oool900000>P0oooo5Oooool001?ooooo<@3oool900000?l0ooooi`3oool:00000>X0oooo
5Oooool001?ooooo<`3oool800000?l0ooooi03oool900000>d0oooo5Oooool001?ooooo=@3oool9
00000?l0oooog`3oool900000>l0oooo5Oooool001?ooooo>03oool800000?l0oooof`3oool:0000
0?00oooo5Oooool001?ooooo>@3oool800000?l0oooof03oool:00000?80oooo5Oooool001?ooooo
>`3oool900000?l0ooood`3oool900000?D0oooo5Oooool001?ooooo>`3oool900000?l0ooood`3o
ool900000?D0oooo5Oooool001?ooooo?P3oool800000?l0oooocP3oool;00000?H0oooo5Oooool0
01?ooooo?`3oool:00000?l0oooob@3oool<00000?L0oooo5Oooool001?ooooo@@3oool900000?l0
ooooa`3oool=00000?L0oooo5Oooool001?oooooA03oool800000?l0oooo`P3oool@00000?L0oooo
5Oooool001?oooooAP3oool800000?l0oooo_P3oool;000000<0oooo1@00003f0?oooaGooooo000C
ooooodH0oooo2000003o0?oookh0oooo2`0000030?ooo`D00000mP3ooolEooooo`004ooooom70?oo
o`X00000o`3oooni0?ooo`X000001P3oool500000?H0oooo5Oooool001?oooooBP3oool900000?l0
oooo]03oool;000000P0oooo1@00003f0?oooaGooooo000CooooodX0oooo3000003o0?ooojh0oooo
3@0000090?ooo`D00000mP3ooolEooooo`004ooooom<0?ooo`d00000o`3ooonX0?ooo`d00000303o
ool500000?H0oooo5Oooool001?oooooCP3oool>00000?l0ooooX`3oool=000000l0oooo1@00003e
0?oooaGooooo000Cooooodh0oooo3P00003o0?oooj<0oooo3@00000?0?ooo`D00000m@3ooolEoooo
o`004ooooomA0?ooo`d00000o`3ooonO0?ooo`d000004@3oool500000?D0oooo5Oooool001?ooooo
D`3oool=00000?l0ooooVP3oool<00000180oooo300000150?ooo`P00000Y03ooolEooooo`004ooo
oomG0?ooo``00000o`3ooonE0?ooo``000004@3oool5000000030?ooo`000000000000<000000`3o
ool300000400oooo100000060?ooo`<00000XP3ooolEooooo`004ooooomI0?ooo``00000o`3ooon?
0?ooo`d000004`3oool5000000@0oooo0`0000040?ooo`@00000?@3oool4000000T0oooo0`00002P
0?oooaGooooo000Coooooe`0oooo2`00003o0?oooh/0oooo3@00000D0?ooo`H00000103oool40000
00@0oooo1@00000j0?ooo`<00000303oool3000009l0oooo5Oooool001?oooooGP3oool<00000?l0
ooooQ@3oool<000001P0oooo1@0000050?ooo`@000001@3oool5000003P0oooo0`00000=0?ooo`@0
0000WP3ooolEooooo`004ooooomN0?ooo``00000o`3ooon50?ooo``00000603oool5000000D0oooo
100000050?ooo`D00000>03oool3000000d0oooo1000002N0?oooaGooooo000Cooooof00oooo3@00
003o0?oooh00oooo3000000I0?ooo`H000001@3oool4000000D0oooo1P00000g0?ooo`<000003`3o
ool2000009h0oooo5Oooool001?oooooH`3oool=00000?l0ooooN`3oool<000001/0oooo1P000005
0?ooo`@000001P3oool600000140oooo7P0000060?ooo`<00000403oool3000009d0oooo5Oooool0
01?oooooI@3oool=00000?l0ooooM@3oool=000001h0oooo1P0000060?ooo`<000001P3oool60000
0140oooo7P0000060?ooo`<00000403oool3000009d0oooo5Oooool001?oooooI`3oool=00000?l0
ooooL@3oool<00000240oooo1P0000060?ooo`<000001`3oool500000140oooo7P0000040?ooo`D0
0000403oool4000009`0oooo5Oooool001?oooooJ`3oool<00000?l0ooooJ`3oool<000002@0oooo
1P0000060?ooo`D000001@3oool600000380oooo1000000B0?ooo`<00000W03ooolEooooo`004ooo
oom[0?ooo``00000o`3ooom[0?ooo``00000903oool6000000H0oooo1@0000050?ooo`H00000<P3o
ool400000180oooo0`00002L0?oooaGooooo000Cooooofd0oooo3@00003o0?ooofD0oooo3@00000V
0?ooo`H000001P3oool5000000D0oooo1P00000b0?ooo`@000004P3oool3000009`0oooo5Oooool0
01?oooooL03oool>00000?l0ooooG@3oool>000002T0oooo1P0000070?ooo`@000001@3oool60000
0340oooo1@00000B0?ooo`<00000W03ooolEooooo`004ooooomb0?oooa000000o`3ooomG0?ooo`d0
0000;@3oool6000000H0oooo100000050?ooo`H00000<@3oool500000180oooo1000002K0?oooaGo
oooo000Cooooog@0oooo4@00003o0?oooe00oooo3`00000_0?ooo`H000001P3oool4000000L0oooo
1000000a0?ooo`D000004P3oool4000009/0oooo5Oooool001?oooooN@3oool@00000?l0ooooB@3o
ool>000003<0oooo1P0000060?ooo`D000001P3oool400000340oooo1@00000B0?ooo`@00000V`3o
oolEooooo`004ooooomi0?oooa000000o`3ooom90?ooo`h00000<`3oool6000000H0oooo1@000006
0?ooo`@00000<@3oool500000180oooo1000002K0?oooaGooooo000Cooooogd0oooo3`00003o0?oo
od80oooo3P00000h0?ooo`H000001@3oool5000000H0oooo1000000a0?ooo`D000004P3oool40000
09/0oooo5Oooool001?oooooP03oool?00000?l0oooo?03oool?000003/0oooo1@0000060?ooo`@0
0000103oool600000340oooo1@00000B0?ooo`@00000V`3ooolEooooo`004ooooon30?ooo`l00000
o`3ooole0?ooo`l00000?`3oool6000000D0oooo100000040?ooo`H00000403ooolN000000<0oooo
1@00000B0?ooo`@00000V`3ooolEooooo`004ooooon60?oooa000000o`3oool]0?oooa000000A03o
ool6000000<0oooo100000040?ooo`D000004@3ooolN000000<0oooo1@00000B0?ooo`@00000V`3o
oolEooooo`004ooooon:0?ooo`l00000o`3ooolX0?ooo`h00000BP3oool500000080oooo10000003
0?ooo`D000004P3ooolN000000<0oooo1@00000B0?ooo`@00000V`3ooolEooooo`004ooooon=0?oo
oa000000o`3ooolQ0?ooo`h00000CP3oool500000080oooo100000000`3oool00000000000030000
03@0oooo1@00000B0?ooo`@00000V`3ooolEooooo`004ooooon=0?oooa000000o`3ooolQ0?ooo`h0
0000CP3oool500000080oooo100000000`3oool0000000000003000003@0oooo1@00000B0?ooo`@0
0000V`3ooolEooooo`004ooooonA0?ooo`l00000o`3ooolJ0?ooo`h00000EP3oool:000003L0oooo
1@00000B0?ooo`@00000V`3ooolEooooo`004ooooonE0?ooo`l00000o`3ooolB0?ooo`l00000G03o
ool4000003/0oooo1000000B0?ooo`<00000W03ooolEooooo`004ooooonG0?oooa400000o`3oool:
0?oooa000000G`3oool4000003/0oooo1@00000@0?ooo`@00000W03ooolEooooo`004ooooonK0?oo
oa400000o`3oool10?oooa800000I03oool2000003/0oooo1@00000@0?ooo`@00000W03ooolEoooo
o`004ooooonN0?oooa<00000m@3ooolD000006P0oooo0P00000m0?ooo`<00000403oool3000009d0
oooo5Oooool001?oooooWP3ooolC00000?D0oooo5000001X0?ooo`800000?@3oool300000100oooo
0`00002M0?oooaGooooo000Coooooj80oooo5000003[0?oooaH00000J`3oool3000003`0oooo0`00
000@0?ooo`<00000W@3ooolEooooo`004ooooonV0?oooaD00000h@3ooolF00000700oooo0`00000m
0?ooo`<000003@3oool4000009h0oooo5Oooool001?oooooZ`3ooolC00000=X0oooo5@00001e0?oo
o`<00000?@3oool3000000d0oooo1000002N0?oooaGooooo000Coooook00oooo4`00003@0?oooa@0
0000O03oool2000003h0oooo0`00000;0?ooo`@00000W`3ooolEooooo`004ooooone0?oooa<00000
a@3ooolE00000840oooo0P00000o0?ooo`@00000203oool400000:00oooo5Oooool001?ooooo]@3o
oolC00000<D0oooo5@0000210?ooo`800000?`3oool4000000P0oooo1000002P0?oooaGooooo000C
oooookT0oooo4`00002l0?oooaH00000Q@3oool200000400oooo100000060?ooo`<00000XP3ooolE
ooooo`004ooooonm0?oooa@00000/03ooolH000008X0oooo0`0000120?ooo`P00000Y03ooolEoooo
o`004oooooo20?oooaT00000WP3ooolK00000?l0ooooP@3ooolEooooo`004oooooo60?oooah00000
SP3ooolL00000?l0ooooQ`3ooolEooooo`004oooooo;0?ooob800000OP3ooolN00000?l0ooooS03o
oolEooooo`004oooooo@0?ooobH00000K03ooolP00000?l0ooooT`3ooolEooooo`004oooooo@0?oo
obH00000K03ooolP00000?l0ooooT`3ooolEooooo`004ooooooJ0?ooobH00000F`3ooolO00000?l0
ooooV`3ooolEooooo`004ooooooS0?oooc<00000;P3oool_00000?l0ooooXP3ooolEooooo`004ooo
ooo[0?oooh400000o`3ooonY0?oooaGooooo000CooooooD0ooooKP00003o0?oook80oooo5Oooool0
01?ooooooP3ooomN00000?l0oooo^@3ooolEooooo`004oooooon0?oooeh00000o`3oooni0?oooaGo
oooo000Cooooool0oooo5`3oool^00000?l0ooood@3ooolEooooo`004ooooooo0?ooool0ooooo`3o
oolG0?oooaGooooo003oooooooooooooooooooloooooo`00oooooooooooooooooooo?oooool00?oo
ooooooooooooooooocoooooo003oooooooooooooooooooloooooo`00oooooooooooooooooooo?ooo
ool00?ooooooooooooooooooocoooooo003oooooooooooooooooooloooooo`00oooooooooooooooo
oooo?oooool00?ooooooooooooooooooocoooooo003oooooooooooooooooooloooooo`00oooooooo
oooooooooooo?oooool00?ooooooooooooooooooocoooooo003oooooooooooooooooooloooooo`00
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{234.188, 164.938},
  ImageMargins->{{0, 0}, {0, 17.625}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.8 Exercise (9)", "Caption",
  CellTags->"Fig. 4.8"],

Cell[TextData[{
  "Plot the solution using ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Alpha]\  = \ 135\ \[Degree]\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b = 1/10\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(V\_o\), "=", 
          RowBox[{"1", " ", 
            StyleBox["V",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Answer: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](r, \[Theta])\), "=", 
          
          FormBox[\(\[Sum]\+\(n = 1\)\%\[Infinity] A\_n\ \(sin(\(\(n\ \[Pi]\)\
\/\(log(b/a)\)\) \(log(r/a)\))\) 
                sinh[\(\(n\ \[Pi]\)\/\(log(b/a)\)\) \[Theta]]\),
            "TraditionalForm"]}], TraditionalForm]]],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Find the solution to the following potential problems inside a sphere. \
Write the solution in terms of an eigenmode expansion. Convert inhomogeneous \
boundary conditions, if any, to a source term. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\^2\( \[CapitalPsi](r, \[Theta], \[Phi])\) = 
            x\ y\ z\), ",", 
          FormBox[\(\[CapitalPsi](1, \[Theta], \[Phi]) = 0\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\^2\( \[CapitalPsi](r, \[Theta], \[Phi])\) = 1\), ",",
           
          
          FormBox[\(\[CapitalPsi](
                1, \[Theta], \[Phi]) = \(sin\^2\) \[Theta]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]\^2\( \[CapitalPsi](
                r, \[Theta], \[Phi])\) = \(cos(\ \[Theta])\)/r\), ",", 
          RowBox[{
            RowBox[{
              FormBox[\(\(\[CapitalPsi](1, \[Theta], \[Phi]) = 0\)\(,\)\),
                "TraditionalForm"], \(\[CapitalPsi](2, \[Theta], \[Phi])\)}], 
            "=", "0"}]}], TraditionalForm]]],
  " (concentric spheres)."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[CapitalPsi](r, \[Theta], \[Phi])\) = 
        1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\[CapitalPsi]\/\[PartialD]r\) \((1, \
\[Theta], \[Phi])\) = a\ \(sin\^2\) \[Theta]\ \(cos\^2\) \[Phi]\)]],
  ". Find the value of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " for which a solution exists, and find the solution."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " A hemispherical shell of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " has a flat base, forming half of a sphere. This half sphere is filled \
with a uniform charge density, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(\[Rho]\)\(/\)\),
              "TraditionalForm"], 
            FormBox[\(\[Epsilon]\_o\),
              "TraditionalForm"]}], "=", 
          RowBox[{"10", " ", 
            RowBox[{
              StyleBox["V",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". The surface of the half sphere, including the base, is grounded. Find \
the potential inside the shell, and plot it. What and where  is the maximum \
of the potential?"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " In a plasma the potential due to a charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " satisfies the linearized Poisson-Boltzmann equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = \[Phi]/\[Lambda]\^2 - \[Rho]/\
\[Epsilon]\_o\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " is the Debye length of the plasma.  A spherical charge of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", uniform charge density, and total charge ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " is placed in the plasma. Find the potential, assuming that it vanishes at \
infinity. [Hint: Solve the radial boundary value problem directly in terms of \
homogeneous solutions, using boundary conditions that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi]\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`r \[Rule] \ \[Infinity]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E\_r\  = \(\(-\[PartialD]\[Phi]\)/\[PartialD]r = \ 
          Q/\((4\ \[Pi]\ \[Epsilon]\_o\ a\^2)\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = \ a\)]],
  ". ]"
}], "Text",
  CellTags->"i:80"],

Cell[TextData[{
  StyleBox["(13)(a)",
    FontWeight->"Bold"],
  " Repeat the analysis of the Green's function in Exercise (5), but for the \
inside of a spherical conducting shell of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". Now  write"
}], "Text",
  CellTags->"i:81"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"g", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], ")"}], "=", 
          RowBox[{\(\[Sum]\+\(l = 0\)\%\[Infinity]\), 
            RowBox[{\(\[Sum]\+\(m = \(-l\)\)\%\(\(l\)\(\ \)\)\), 
              RowBox[{\(\(Y\_\(l, \ m\)\)(\[Theta], \[Phi])\), " ", 
                RowBox[{\(f\_\(l\ m\)\), "(", 
                  RowBox[{"r", ",", 
                    StyleBox[" ",
                      FontSlant->"Italic"], 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["o",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"]}], ")"}], " "}]}]}]}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.73)"],

Cell[TextData[{
  "and find an ODE boundary-value problem for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_\(l\ m\)\), "(", 
          RowBox[{"r", ",", " ", 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  ". Solve this boundary-value problem to show that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(f\_\(\(\ \)\(l\ m\)\)\), "(", 
            RowBox[{"r", ",", " ", 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], ")"}], 
          "=", \(\(-\ \(\(Y\_\(l\ m\)\^*\)(\[Theta]\_o, \[Phi]\_o)\)\) 
            1\/\(2  l\  + \ 1\)\ \((r\_ < \%l\/r\_ > \%\(l + 1\) - \(\(r\_ < \
\%l\) r\_ > \%l\)\/a\^\(2  l + 1\))\)\)}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(4.3.74)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\_\(\(<\)\(( > )\)\)\)]],
  " is the lesser (greater) of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o\)]],
  ".  Hint: In spherical coordinates the \[Delta] function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "-", 
            StyleBox[
              SubscriptBox[
                StyleBox["r",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Delta]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              StyleBox[
                SubscriptBox[
                  StyleBox["r",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          
          StyleBox[\(\(\[Delta](
                r - r\_o)\) \(\[Delta](\[Theta] - \[Theta]\_o)\) \(\[Delta](\
\[Phi] - \[Phi]\_o)\)/\((\(r\^2\) sin\[Theta])\)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(4.3.75)"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \ \[Infinity]\)]],
  ", Eqs. ",
  ButtonBox["(4.3.73)",
    ButtonData:>"(4.3.73)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.3.74)",
    ButtonData:>"(4.3.74)",
    ButtonStyle->"Hyperlink"],
  " can be used to represent the potential at point ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " due to an arbitrary charge density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          StyleBox[
            SubscriptBox[
              StyleBox["r",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], ")"}], TraditionalForm]]],
  " in free space. Assume that this charge density is concentrated near the \
origin; that is, it is completely contained inside an imaginary sphere \
centered at the origin and of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". (See Fig. ",
  ButtonBox["4.9",
    ButtonData:>"Fig. 4.9",
    ButtonStyle->"Hyperlink"],
  ".) Then, using the Green's function, show that the electrostatic potential \
at locations far from this charge density is given by "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], 
          "=", \(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \
\(-l\)\)\%l\(\( 1\/\(2\ l\  + \ 
                      1\)\) \(\[Rho]\_\(l\ m\)\) \(\(\(Y\_\(l, \ 
                          m\)\)(\[Theta], \[Phi])\)\/\(\[Epsilon]\_o\ r\^\(l \
+ 1\)\)\)\(\ \)\)\)\)}], TraditionalForm]]],
  ",  provided that ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`r > R\)]]]], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->{"i:84", "(4.3.76)"}],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\_\(l\ m\)\), "=", 
          RowBox[{"\[Integral]", 
            RowBox[{\(\[DifferentialD]\^3 r\_o\), 
              RowBox[{"\[Rho]", "(", 
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ")"}], 
              " ", \(r\_o\%\(\(\ \)\(l\)\)\), \(\(Y\_\(l, \ 
                    m\)\%\(\(\ \)\(*\)\)\)(\[Theta]\_o, \[Phi]\_o)\)}]}]}], 
        TraditionalForm]]],
  " is the ",
  StyleBox["multipole moment",
    FontSlant->"Italic"],
  " of the charge distribution. Equation ",
  ButtonBox["(4.3.76)",
    ButtonData:>"(4.3.76)",
    ButtonStyle->"Hyperlink"],
  " is called a ",
  StyleBox["multipole expansion of the potential",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:82"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:H000222000`400?l00000o`00003ooooooooo
oooooi[ooooo003oooooooooooooV_ooool00?oooooooooooonJooooo`00oooooooooooooi[ooooo
003oooooooooooooV_ooool00?oooooooooooonJooooo`00oooooooooooooi[ooooo003ooooooooo
ooooV_ooool00?oooooooooooonJooooo`00oooooooooooooi[ooooo003oooooooooooooV_ooool0
0?oooooooooooonJooooo`00oooooooooooooi[ooooo000@ooooool0ooooo`3ooomi0?oooa7ooooo
000@ooooool0ooooo`3ooomi0?oooa7ooooo000@oooool40oooo2@00000@0?ooo`030820P0000000
000000L0000000<0P8200?ooo`3oool0o`3ooonA0?oooa7ooooo000@oooool40oooo2@00000@0?oo
o`030820P0000000000000L0000000<0P8200?ooo`3oool0o`3ooonA0?oooa7ooooo000@oooool40
oooo2@00000@0?ooo`030820P0000000000000L0000000<0P8200?ooo`3oool0o`3ooonA0?oooa7o
oooo000@ooooojT0oooo1020P80300000140oooo2@20P80@0?ooo`030<30`020P800P82000L0P820
4@3oool4000000050410@020P800P8200820P030`<00o`3ooomj0?oooa7ooooo000@ooooojH0oooo
2P0000140?ooo`X00000o`3ooomj0?oooa7ooooo000@ooooojH0oooo2P0000140?ooo`X00000o`3o
oomj0?oooa7ooooo000@ooooojL0oooo0`0000030820P4`0oooo1@20P83o0?ooogX0oooo4Oooool0
013oooooo`3ooooo0?ooogT0oooo4Oooool0013oooooo`3oool?0?ooo`@00000o`3ooomV0?oooa7o
oooo000@oooooiD0oooo00<000000820P03oool0MP3oool400000?l0ooooIP3ooolAooooo`004?oo
oon@0?ooo`<0P8201000001f0?ooo`P000000P20P83o0?ooof40oooo4Oooool0013oooooS@3oool:
000007P0oooo00<0P8200000000000001@00003o0?ooof40oooo4Oooool0013oooooSP3oool60000
07h0oooo00<0P8200000000000000P00003o0?ooof40oooo4Oooool0013oooooSP3oool500000880
oooo00<000000820P03oool0o`3ooomP0?oooa7ooooo000@ooooohl0oooo00<0P8200?ooo`3oool0
J@3ooolB0820P?l0ooooJ`3ooolAooooo`004?oooooi0?ooo`030820P0000000000001<00000o`3o
oomY0?oooa7ooooo000@ooooooP0oooo6@00003o0?ooofL0oooo4Oooool0013ooooom03oool20820
P0L000003P1fMWH00`0k>c/0000000000004000000030410@020P800oooo0180oooo00<0P8200<30
`03oool0o`3ooom>0?oooa7ooooo000@ooooogd0oooo00<000000?ooo`3oool0L`3oool600000003
07IfMP3/k>`0k>c/0180k>c/200000000`20P800oooo0?ooo`0=0?ooo`@00000o`3ooom>0?oooa7o
oooo000@ooooogX0oooo00<0P8200000000000000P00001c0?ooo`030820P0000000000000800000
603/k>`00`1fMWH0000000000006000000d0oooo1`00003o0?oood`0oooo4Oooool0013oooooN@3o
ool6000007<0oooo100000000`1fMWH0k>c/0>c/k00I0>c/k0P000003@3oool700000?l0ooooBP3o
oolAooooo`004?oooome0?ooo`80P8201@0000000`20P800`<300?ooo`1b0?ooo`050820P0000000
00000000001fMWH07@3/k>`307IfMPD000000P20P80;0?ooo`030<30`020P800000000@0000000<0
P8200?ooo`3oool0o`3ooom60?oooa7ooooo000@ooooogH0oooo1@00001f0?ooo`<000008P3/k>`0
0`1fMWH0000000000004000000030820P03oool0oooo00/0oooo1000003o0?ooodT0oooo4Oooool0
013oooooMP3oool4000007H0oooo0`00000U0>c/k0L000003@3oool300000?l0ooooB@3ooolAoooo
o`004?oooomf0?ooo`030<30`020P800oooo07H0oooo00@0`<30000000000000>c/k9P3/k>`00`2a
/K40MWIf00000004000000030820P03oool0oooo0?l0ooooE@3ooolAooooo`004?ooooo_0?ooo`<0
000000<0MWIf0>c/k03/k>`0:03/k>`500000?l0ooooEP3ooolAooooo`004?ooooo_0?ooo`<00000
:`3/k>`00`1fMWH000000000000400000?l0ooooE03ooolAooooo`004?ooooo_0?ooo`<00000;@3/
k>`600000?l0ooooD`3ooolAooooo`004?ooooo^0?ooo`<0000000<0MWIf0>c/k03/k>`0;03/k>`0
0`2a/K4000000000000300000080P820o`3ooom@0?oooa7ooooo000@ooooonh0oooo0`00000a0>c/
k0H0000000<0P8200?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooocL0oooo4Oooool0013o
ooooIP3oool2000006D0oooo1@00000L0?ooo`<00000<`3/k>`6000001<0oooo00@0P82000000000
0000P820o`3ooolg0?oooa7ooooo000@ooooof<0oooo0P20P803000000030<30`03oool0oooo02D0
oooo1020P80g0?ooo`030410@0000000P82000@0oooo00<0P82000000020P800603oool300000003
07IfMP3/k>`0k>c/0340k>c/00<0/K6a07IfMP000000100000000`20P800oooo0?ooo`0?0?ooo`04
0410@0000000000000000080P820o`3ooole0?oooa7ooooo000@ooooof80oooo1P0000000`20P800
oooo0?ooo`0U0?ooo`@00000=P3oool3000000L0oooo0P0000000`20P800oooo0?ooo`0D0?ooo`<0
0000=`3/k>`600000140oooo1P00003o0?oooc@0oooo4Oooool0013oooooH@3oool6000002T0oooo
1000000O0?ooo`030820P03oool0oooo01@0oooo0P0000090?ooo`8000005P3oool3000003P0k>c/
1`00000@0?ooo`H00000o`3ooolc0?oooa7ooooo000@ooooof00oooo1P00000Z0?ooo`@000007`3o
ool2000001@0oooo0`00000:0?ooo`8000001`3oool00`000000oooo0?ooo`0;0?ooo`<00000>@3/
k>`6000000030820P03oool0oooo00h0oooo00<0P8200000000000000`00003o0?oooc80oooo4Ooo
ool0013oooooGP3oool00`20P80000000000000200000080P820:`3oool01@20P800000000000000
0000P82001`0oooo00<0P82000000010@4005@3oool3000000X0oooo00@0@410000000000000P820
1P3oool00`20P800@4100?ooo`0:0?ooo`<00000>P3/k>`00`1fMWH0>c/k00000004000000030820
P03oool0oooo00h0oooo00@0P820000000000000P820o`3ooolb0?oooa7ooooo000@ooooof00oooo
0P00000_0?ooo`@000006`3oool3000001H0oooo0`00000:0?ooo`040820P00000000000000000L0
oooo00<0P8200000003oool02@3oool3000003`0k>c/1`00003o0?ooodD0oooo4Oooool0013ooooo
T@3oool4000001X0oooo00<0P8200000000000005`3oool3000000/0oooo0`0000000`20P800oooo
0?ooo`050?ooo`800000203oool30000000307IfMP3/k>`0k>c/03/0k>c/1`00003o0?oood@0oooo
4Oooool0013oooooT@3oool4000001X0oooo0P00000H0?ooo`@000002P3oool01020P80000000000
0010@4080?ooo`0300000010@400oooo00H0oooo0`0000000`1fMWH0k>c/0>c/k00m0>c/k00303/k
>`000000000000<0000000<0P8200<30`03oool0o`3ooom00?oooa7ooooo000@oooooi80oooo1000
000H0?ooo`8000006P3oool3000000/0oooo0`0000090?ooo`8000001P3oool30000000307IfMP3/
k>`0k>c/03l0k>c/1P00003o0?oood40oooo4Oooool0013oooooTP3oool4000001L0oooo0`00000J
0?ooo`@000002P3oool4000000P0oooo0`0000050?ooo`<0000000<0MWIf0>c/k03/k>`0@03/k>`7
00000?l0oooo?`3ooolAooooo`004?oooonB0?ooo`@000005`3oool2000000030820P03oool0oooo
01P0oooo1000000;0?ooo`<00000203oool00`20P8000000000000040?ooo`050820P00000000000
0000001fMWH0@P3/k>`00`1fMWH0000000000004000000030820P03oool0oooo0?l0oooo?03ooolA
ooooo`004?oooonB0?ooo`@0000000D0oooo0820P020P800P8200410@0030820P00300000020P800
P82000/0oooo0`0000000`20P800oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool03@3oool0
1010@400000000000020P80:0?ooo`<00000203oool01020P80000000000000000030?ooo`050820
P000000000000000001fMWH0A03/k>`00`1fMWH0000000000004000000030820P03oool0oooo0?l0
oooo>P3ooolAooooo`004?oooonC0?ooo`<0000000@0P82000000000000000001P3oool2000000X0
oooo0`00000:0?ooo`<000003`3oool01020P800000000000000000:0?ooo`<000002@3oool30000
00040820P03oool0oooo0820P0<0000000<0MWIf0>c/k03/k>`0A03/k>`00`1fMWH0000000000004
000000030820P03oool0oooo0?l0oooo>03ooolAooooo`004?oooonC0?ooo`H00000203oool20000
00P0oooo00@0P82000000000000000002P3oool300000100oooo0`0000000`20P800oooo0?ooo`07
0?ooo`<000002@3oool3000000040820P03oool0oooo0820P0<0000000<0MWIf0>c/k03/k>`0A@3/
k>`8000001@0oooo0P00003o0?ooob<0oooo4Oooool0013oooooD03oool200000440oooo1P000008
0?ooo`030820P0000000000000L0oooo00@0P82000000000000000002P3oool300000140oooo0`00
00090?ooo`<000002@3oool400000080oooo00D0P820000000000000000007IfMP190>c/k00307If
MP000000000000@000004P3oool01020P800000000000000003o0?ooob80oooo4Oooool0013ooooo
CP3oool00`20P800@4100000000200000400oooo1@0000090?ooo`040<30`000000000000410@0H0
oooo1000000;0?ooo`<000004@3oool01020P800000000000020P8070?ooo`8000002P3oool01020
P80000000000000000020?ooo`040820P00000000000000004/0k>c/0P1fMWH5000000030820P03o
ool0oooo00h0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`3o0?oooah0oooo4Ooo
ool0013oooooC@3oool6000000030820P03oool0oooo03d0oooo00<0P8200000000000000P00000:
0?ooo`<000001P3oool3000000`0oooo0`00000B0?ooo`040820P000000000000820P0D0oooo0P00
00000`20P800oooo0?ooo`090?ooo`<000000P3oool01020P800000000000000001>0>c/k00307If
MP000000000000@000003`3oool6000000030820P03oool0oooo0?l0oooo703ooolAooooo`004?oo
oom=0?ooo`H00000@03oool00`20P800000000000002000000/0oooo0`0000050?ooo`<00000303o
ool3000000030820P03oool0oooo0140oooo0P0000040?ooo`<00000303oool4000000030?ooo`20
P800000000800000C`3/k>`8000000l0oooo100000000`20P800oooo0?ooo`3o0?oooa`0oooo4Ooo
ool0013oooooC03oool01010@40000000000000000020820P440oooo00<0P8200000000000000P00
000;0?ooo`<0000000D0P8200?ooo`3oool0oooo0820P003000000`0oooo00@0P820000000000000
@410503oool00`30`<00P8200820P0030820P0h0oooo100000000`3oool0P8200000000200000540
k>c/00<0>c/k0000000000001@0000020820P0`0oooo00D0@41000000000000000000820P03o0?oo
oad0oooo4Oooool0013oooooBP3oool5000000030820P03oool0oooo0440oooo00<0P82000000000
00000P00000;0?ooo`@000000`3oool4000000`0oooo00@0P8200000000000000000:03oool40000
00030?ooo`20P800000000800000D`3/k>`:000000/0oooo1000003o0?oooad0oooo4Oooool0013o
ooooB`3oool4000004D0oooo1000000;0?ooo`@000000`3oool4000000d0oooo0`00000X0?ooo`@0
000000<0oooo0820P00000000P00001F0>c/k0T0000000<0P8200?ooo`3oool0203oool00`000000
oooo0?ooo`3o0?oooa`0oooo4Oooool0013oooooB`3oool3000004H0oooo1000000<0?ooo`@00000
0P3oool4000000d0oooo1000000W0?ooo`@0000000<0oooo0820P00000000P00001H0>c/k0P00000
o`3ooolY0?oooa7ooooo000@oooood`0oooo00<0`<300?ooo`3oool0A@3oool4000000`0oooo1000
00020?ooo`@000003@3oool4000000030820P03oool0oooo02@0oooo100000000`3oool0P8200000
0002000005X0k>c/0P1fMWH4000000030820P03oool0oooo0?l0oooo9P3ooolAooooo`004?oooonE
0?ooo`@000002`3oool400000080oooo1000000>0?ooo`D000009@3oool4000000030?ooo`20P800
000000800000G@3/k>`400000?l0oooo:03ooolAooooo`004?oooonE0?ooo`@000002`3oool40000
0080oooo1000000>0?ooo`<0000000<0oooo0000003oool0903oool4000000030?ooo`20P8000000
00800000GP3/k>`400000?l0oooo9`3ooolAooooo`004?oooonE0?ooo`050820P000000000000000
0020P8002P3oool400000080oooo1000000>0?ooo`030820P000000000000080P82000<0@4100?oo
o`3oool08P3oool3000000030820P03oool0P82000<00000GP3/k>`01@1fMWH00000000000000000
P8200?l0oooo9P3ooolAooooo`004?oooonF0?ooo`040820P00000000000000000X0oooo10000002
0?ooo`@000003`3oool3000000030?ooo`20P800oooo0280oooo100000020?ooo`040820P0000000
0000000005l0k>c/1000003o0?ooobH0oooo4Oooool0013oooooUP3oool01020P800000000000000
00090?ooo`@00000103oool3000000l0oooo0`0000000`3oool0P820000000030?ooo`80000000<0
P8200?ooo`3oool06P3oool400000080oooo00@0P8200000000000000000G`3/k>`0101fMWH00000
00000000003o0?ooobH0oooo4Oooool0013oooooU`3oool3000000030820P03oool0oooo00H0oooo
100000040?ooo`<000003`3oool4000000040?ooo`00000000000?ooo`@00000703oool300000004
0820P03oool0oooo0820P0<00000G`3/k>`01@1fMWH00000000000000000P8200?l0oooo9@3ooolA
ooooo`004?oooonH0?ooo`80P82000<000000820P03oool01@3oool3000000030820P03oool0oooo
00<0oooo1000000>0?ooo`@000000P3oool00`20P800000000000003000001`0oooo0`0000001020
P800oooo0?ooo`20P80300000600k>c/0`0000000`10@400oooo0?ooo`3o0?ooob<0oooo4Oooool0
013oooooVP3oool01020P800000000000020P8030?ooo`<0000000<0P8200?ooo`3oool0103oool0
1020P800000000000000000:0?ooo`P0000000@0P8200?ooo`3oool0P8201000000K0?ooo`040820
P00000000000000000<0oooo00@0P8200000000000000000H@3/k>`3000001@0oooo00<000000?oo
o`3oool0o`3oool>0?oooa7ooooo000@oooooid0oooo1P0000080?ooo`040820P000000000000000
00h0oooo100000001020P800oooo0?ooo`3oool3000000030820P03oool0oooo01T0oooo00@0P820
00000000000000000`3oool01020P800000000000000001Q0>c/k0@000004P3oool300000?l0oooo
3`3ooolAooooo`004?ooooll0?ooo`040820P000000000000820P6`0oooo0`0000000`30`<00oooo
0?ooo`0b0?ooo`030410@0000000P82000@0oooo00@0P8200000000000000000HP3/k>`300000140
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3o0?ooo`/0oooo4Oooool0013ooooo
>`3oool4000006d0oooo0`0000000`20P800oooo0?ooo`0b0?ooo`8000001@3oool01@20P8000000
000000000000MWIf0640k>c/0`00000C0?ooo`@0000000<0P8200?ooo`3oool0o`3oool:0?oooa7o
oooo000@oooooc/0oooo0`0000000`20P800oooo0?ooo`1/0?ooo`80000000<0P8200?ooo`3oool0
<@3oool2000000H0oooo00D0P820000000000000000007IfMP1Q0>c/k0@000004P3oool01@20P800
0000000000000000P8200?l0oooo303ooolAooooo`004?oooolj0?ooo`050820P000000000000000
0020P800KP3oool300000380oooo0P0000000`20P800oooo0?ooo`040?ooo`050820P00000000000
0000001fMWH0HP3/k>`3000001<0oooo1000003o0?ooo``0oooo4Oooool0013ooooo>@3oool01@20
P8000000000000000000P8200700oooo00<0P82000000020P800<03oool00`30`<0000000820P007
0?ooo`050820P000000000000000001fMWH0HP3/k>`3000001@0oooo100000000`20P800oooo0?oo
o`3o0?ooo`P0oooo4Oooool0013ooooo>03oool4000007<0oooo0P00000`0?ooo`030000003oool0
oooo00L0oooo00D0P820000000000000000007IfMP1R0>c/k0@00000503oool300000?l0oooo2`3o
oolAooooo`004?oooolg0?ooo`@00000M03oool00`20P80000000000000^0?ooo`0300000020P800
oooo00P0oooo00D0P820000000000000000007IfMP1R0>c/k00407IfMP0000000000000001D0oooo
00<000000?ooo`3oool0o`3oool:0?oooa7ooooo000@ooooocP0oooo0`00001e0?ooo`<00000;03o
ool00`000000oooo0?ooo`090?ooo`050820P000000000000000001fMWH0HP3/k>`0101fMWH00000
00000000003o0?ooob80oooo4Oooool0013ooooo>@3oool00`20P800`<300?ooo`1e0?ooo`030820
P0000000@41003L0oooo00D0P820000000000000000007IfMP1R0>c/k00507IfMP00000000000000
0030`<00o`3ooolQ0?oooa7ooooo000@oooook<0oooo0P00000f0?ooo`050820P000000000000000
001fMWH0H`3/k>`3000000030820P03oool0oooo0?l0oooo7`3ooolAooooo`004?oooonc0?ooo`03
0820P03oool0oooo03H0oooo0`0000000`1fMWH0k>c/0>c/k01Q0>c/k0<0000000<0P8200?ooo`3o
ool0o`3ooolO0?oooa7ooooo000@ooooon`0oooo0`0000000`0k>c/0k>c/0>c/k01Q0>c/k0<00000
00<0P8200?ooo`3oool0o`3ooolO0?oooa7ooooo000@ooooon`0oooo1000001S0>c/k0<0000000<0
P8200?ooo`3oool0o`3ooolO0?oooa7ooooo000@ooooon`0oooo1000001S0>c/k0<0000000<0P820
0?ooo`3oool0o`3ooolO0?oooa7ooooo000@ooooon`0oooo1000000Q0>c/k0030000001fMWH0k>c/
03l0k>c/0`0000000`20P800oooo0?ooo`3o0?oooal0oooo4Oooool0013oooook@3oool3000001l0
k>c/00@0/K6a000000000000MWIf@03/k>`3000000030820P03oool0oooo0?l0oooo7`3ooolAoooo
o`004?ooooo]0?ooo`<000007`3/k>`30000000307IfMP3/k>`0k>c/03h0k>c/0`0000000`20P800
oooo0?ooo`3o0?oooal0oooo4Oooool0013oooook@3oool3000001h0k>c/100000110>c/k0<00000
00<0P8200?ooo`3oool0o`3ooolO0?oooa7ooooo000@ooooond0oooo0`00000L0>c/k00307IfMP00
0000000000<00000@@3/k>`3000000030820P03oool0oooo01d0oooo0P20P8000`000000@4100?oo
o`3l0?oooa7ooooo000@ooooob`0oooo0P00002o0?ooo`<000006`3/k>`00`1fMWH0000000000004
00000440k>c/0`0000000`20P800oooo0?ooo`0N0?ooo`<00000o@3ooolAooooo`004?ooool/0?oo
o`<0000000<0P8200?ooo`3oool0^`3oool4000001X0k>c/1`0000110>c/k0<0000000<0P8200?oo
o`3oool07P3oool400000?`0oooo4Oooool0013ooooo:`3oool400000;h0oooo1000000I0>c/k0P0
0000@@3/k>`3000000030820P03oool0oooo01l0oooo1000003k0?oooa7ooooo000@ooooobX0oooo
1000002o0?ooo`@00000603/k>`900000440k>c/0`0000000`20P800oooo0?ooo`0P0?ooo`050410
@0000000000000000030`<00n@3ooolAooooo`004?oooolY0?ooo`@00000`@3oool3000001L0k>c/
00<0MWIf0000000000001P0000110>c/k00507IfMP000000000000000020P8008P3oool01@20P800
0000000000000000P8200?T0oooo4Oooool0013ooooo:03oool01@20P8000000000000000000P820
0<40oooo0`00000G0>c/k0T00000@@3/k>`0101fMWH0000000000000000T0?ooo`@00000n@3ooolA
ooooo`004?oooolX0?ooo`<0000000<0P8200?ooo`3oool0`03oool30000000307IfMP3/k>`0k>c/
0180k>c/00<0MWIf000000000000200000110>c/k00407IfMP0000000000000002D0oooo0P000000
0`10@400P8200?ooo`3g0?oooa7ooooo000@ooooobL0oooo100000330?ooo`@000004`3/k>`<0000
0440k>c/00@0MWIf0000000000000000o`3ooolR0?oooa7ooooo000@ooooobP0oooo00<0P8200000
003oool0``3oool400000180k>c/00<0MWIf0000000000002P0000110>c/k00407IfMP0000000000
00000?l0oooo8P3ooolAooooo`004?ooooo^0?ooo`@000004P3/k>`=00000440k>c/00@0MWIf0000
000000000000o`3ooolR0?oooa7ooooo000@ooooonh0oooo1000000@0>c/k00307IfMP0000000000
00/0000000<0MWIf0>c/k03/k>`0?`3/k>`300000?l0oooo8`3ooolAooooo`004?ooooo_0?ooo`<0
00003`3/k>`00`1fMWH000000000000<00000480k>c/0`00003o0?ooob<0oooo4Oooool0013ooooo
k`3oool30000000307IfMP3/k>`0k>c/00`0k>c/3`0000110>c/k0@00000o`3ooolS0?oooa7ooooo
000@ooooonl0oooo0`0000000`1fMWH0k>c/0>c/k0090>c/k080MWIf400000110>c/k0<0000000<0
P8200?ooo`3oool0o`3ooolQ0?oooa7ooooo000@ooooonl0oooo00@0P820000000000000MWIf2P3/
k>`00`1fMWH000000000000@00000400k>c/1000003o0?ooob@0oooo4Oooool0013oooook`3oool0
1020P80000000000001fMWH:0>c/k1<00000@03/k>`400000?l0oooo903ooolAooooo`004?ooooo_
0?ooo`040820P0000000000007IfMPT0k>c/500000100>c/k0<00000o`3ooolU0?oooa7ooooo000@
ooooonl0oooo00@0P82000000000000000001`3/k>`00`1fMWH000000000000B0000000307IfMP3/
k>`0k>c/03d0k>c/1000003o0?ooobD0oooo4Oooool0013oooool03oool3000000H0k>c/00<0MWIf
0000000000004`0000000`1fMWH0k>c/0>c/k00m0>c/k0<0000000<0P8200?ooo`3oool0o`3ooolS
0?oooa7ooooo000@oooooo00oooo0`0000060>c/k1H0000000<0MWIf0>c/k03/k>`0?03/k>`01@1f
MWH00000000000000000P8200?l0oooo9@3ooolAooooo`004?ooooo`0?ooo`<000001P3/k>`F0000
000307IfMP3/k>`0k>c/03`0k>c/00@0MWIf0000000000000000o`3ooolV0?oooa7ooooo000@oooo
oo00oooo0`0000001@1fMWH0k>c/0>c/k03/k>`0MWIf01L0000000<0MWIf0>c/k03/k>`0?03/k>`0
100k>c/0000000000000000c0?ooo`80P82000<000000?ooo`3oool0k@3ooolAooooo`004?oooolM
0?ooo`800000d@3oool4000000@0k>c/5`0000000`1fMWH0k>c/0>c/k00k0>c/k0D00000=03oool3
00000>h0oooo4Oooool0013ooooo7@3oool400000=00oooo0`0000050>c/k1H00000?P3/k>`40000
03D0oooo1000003]0?oooa7ooooo000@oooooa`0oooo100000000`20P800oooo0?ooo`3>0?ooo`<0
000000<0MWIf0>c/k03/k>`00P3/k>`00`2a/K4000000000000C000003d0k>c/1000000g0?ooo`@0
0000k03ooolAooooo`004?oooolK0?ooo`@00000dP3oool4000000H0k>c/5000000l0>c/k00407If
MP0000000000000003P0oooo00D0P82000000000000000000820P03[0?oooa7ooooo000@oooooaX0
oooo00<0P8200000000000000P00003B0?ooo`@00000203/k>`B000003`0k>c/00@0MWIf00000000
00000000>@3oool400000>/0oooo4Oooool0013ooooo6P3oool01@20P8000000000000000000P820
0=80oooo100000080>c/k00307IfMP000000000000l00000?03/k>`3000000030820P03oool0oooo
03L0oooo1000003[0?oooa7ooooo000@oooooaX0oooo100000000`30`<00oooo0?ooo`3A0?ooo`@0
0000203/k>`207IfMPl00000>`3/k>`01@1fMWH00000000000000000`<3003X0oooo0P0000000`10
@400P8200?ooo`3Y0?oooa7ooooo000@oooooaX0oooo1000003D0?ooo`@000002@3/k>`@000003X0
k>c/1@00003o0?ooobX0oooo4Oooool0013ooooo6@3oool400000=D0oooo100000090>c/k0<00000
0P3/k>`00`1fMWH0000000000007000003/0k>c/1000003o0?ooob/0oooo4Oooool0013ooooolP3o
ool01@30`<000000000000000000MWIf00L0k>c/100000040>c/k0<0MWIf1@00000i0>c/k0030;6a
/@000000000000800000o`3oool/0?oooa7ooooo000@oooooo<0oooo0`0000000`1fMWH0k>c/0>c/
k0040>c/k00507IfMP00000000000000001fMWH02@3/k>`00`1fMWH000000000000i0>c/k00507If
MP000000000000000020P800o`3oool/0?oooa7ooooo000@oooooo<0oooo0`0000000`1fMWH0k>c/
0>c/k0040>c/k00507IfMP00000000000000001fMWH0A@3/k>`400000?l0oooo;@3ooolAooooo`00
4?oooooc0?ooo`@000001P3/k>`4000004D0k>c/1@00003o0?ooobd0oooo4Oooool0013ooooom03o
ool3000000H0k>c/0`0000000`1fMWH0k>c/0>c/k0120>c/k0@0000000<0P8200?ooo`3oool0o`3o
ool/0?oooa7ooooo000@oooooo@0oooo0`0000050>c/k0@00000A03/k>`0101fMWH0000000000000
003o0?oooc00oooo4Oooool0013ooooom03oool4000000@0k>c/0`0000150>c/k0@00000o`3oool`
0?oooa7ooooo000@ooooooD0oooo0`0000030>c/k0<0000000<0MWIf0>c/k03/k>`0@@3/k>`01P1f
MWH00000000000000000P8200<30`?l0oooo<03ooolAooooo`004?oooooe0?ooo`@0000000<0k>c/
0000000000000P0000140>c/k0<00000o`3ooolc0?oooa7ooooo000@ooooooD0oooo100000001@3/
k>`00000000000000000MWIf04<0k>c/1000003o0?oooc<0oooo4Oooool0013ooooomP3oool30000
000507IfMP00000000000000001fMWH0@P3/k>`01@1fMWH00000000000000000P8200?l0oooo<`3o
oolAooooo`004?ooooof0?ooo`<0000000@0>c/k0000000000000000@P3/k>`01@1fMWH000000000
00000000P8200?l0oooo=03ooolAooooo`004?ooooof0?ooo`030820P0000000000000<00000@P3/
k>`400000500oooo00<0P8200000003oool0hP3ooolAooooo`004?ooooof0?ooo`030820P0000000
000000<00000@@3/k>`00`1fMWH0000000000002000004l0oooo1000003R0?oooa7ooooo000@oooo
oa40oooo00@0P82000000010@400P820h@3oool00`20P80000000000000200000440k>c/00D0MWIf
00000000000000000410@01A0?ooo`<0000000<0`<300?ooo`3oool0g`3ooolAooooo`004?ooool@
0?ooo`D00000hP3oool400000400k>c/1@00001B0?ooo`040820P000000000000820P>40oooo4Ooo
ool0013ooooo403oool400000>80oooo00<0P8200000000000000P00000n0>c/k00307IfMP000000
000000<00000D`3oool01020P800000000000020P83Q0?oooa7ooooo000@ooooo`l0oooo00D0P820
00000000000000000820P0390?ooo`@0000000<0P8200?ooo`3oool04P3oool00`20P80000000000
0002000003h0k>c/100000000`20P800oooo0?ooo`1B0?ooo`040820P0000000000000000>40oooo
4Oooool0013ooooo3`3oool01@20P8000000000000000000`<300<H0oooo00@0`<30000000000000
`<300`3oool01030`<00P82000000030`<0A0?ooo`H00000>`3/k>`00`1fMWH00000000000020000
00030820P03oool0oooo05@0oooo0`0000000`20P800oooo0?ooo`3N0?oooa7ooooo000@ooooo`l0
oooo100000370?ooo`<000001`3oool2000000l0oooo2000000i0>c/k0D00000F@3oool300000>00
oooo4Oooool0013ooooo3`3oool400000<L0oooo0P0000080?ooo`030820P0000000000000h0oooo
2000000h0>c/k0@0000000<0P8200?ooo`3oool0F03oool400000=l0oooo4Oooool0013ooooo3`3o
ool300000<L0oooo0`0000090?ooo`<000003@3oool3000000030?ooo`20P80000000080000000<0
MWIf0>c/k03/k>`0<`3/k>`6000005`0oooo0`00003O0?oooa7ooooo000@ooooo`h0oooo10000037
0?ooo`<000002@3oool01020P800000000000010@40;0?ooo`<0000000<0P8200?ooo`30`<000`00
00000`0k>c/0k>c/0>c/k00a0>c/k00307IfMP00000000000080000000<0@4100820P03oool0o`3o
oolo0?oooa7ooooo000@ooooo`l0oooo00<0P8200000003oool0a`3oool3000000X0oooo0`00000:
0?ooo`@000000`3oool400000340k>c/00<0MWIf0000000000001000003o0?oood80oooo4Oooool0
013ooooof@3oool3000000/0oooo0`0000090?ooo`<0000000<0P8200?ooo`3oool00P3oool40000
02l0k>c/1P00003o0?oood@0oooo4Oooool0013ooooof@3oool4000000X0oooo00@0P82000000000
0000P8201`3oool01@20P8000000000000000000`<3000@0oooo00<0P8200000000000000P00000[
0>c/k0030;6a/@1fMWH0000000@0000000<0@4100?ooo`3oool0o`3ooom30?oooa7ooooo000@oooo
omX0oooo0`00000;0?ooo`<000001`3oool4000000H0oooo1@00000Y0>c/k0L00000o`3ooom70?oo
oa7ooooo000@ooooomX0oooo0`0000000`20P800oooo0?ooo`080?ooo`<0000000<0P8200?ooo`3o
ool0103oool3000000P0oooo1000000X0>c/k0H0000000<0P8200?ooo`3oool0o`3ooom60?oooa7o
oooo000@ooooomX0oooo0`0000000`20P800oooo0?ooo`080?ooo`040820P000000000000820P0D0
oooo100000080?ooo`D000009P3/k>`600000?l0ooooBP3ooolAooooo`004?ooooo70?ooo`<00000
00<0P8200?ooo`3oool03@3oool01030`<00000000000010@40:0?ooo`040820P000000000000820
P0@0oooo00@0P82000000000000000002@3oool00`30`<00P820000000030000000307IfMP2a/K40
k>c/01h0k>c/00<0MWIf000000000000100000000`20P800oooo0?ooo`3o0?ooodX0oooo4Oooool0
013ooooob03oool300000100oooo0`00000:0?ooo`040820P000000000000820P0@0oooo0`00000=
0?ooo`H000006`3/k>`800000?l0ooooC`3ooolAooooo`004?ooooo80?ooo`<000004@3oool30000
00T0oooo00@0P820000000000000P8200`3oool01020P800000000000000000>0?ooo`L000005`3/
k>`9000000030820P03oool0oooo0?l0ooooC@3ooolAooooo`004?ooooo80?ooo`040410@0000000
00000<30`140oooo00@0@410000000000000P8201`3oool01020P800000000000030`<030?ooo`04
0410@000000000000410@0h0oooo00<0`<300820P020P8001@00000707IfMPL0k>c/1@1fMWH80000
00030410@020P800P8200?l0ooooD@3ooolAooooo`004?ooooo80?ooo`040820P000000000000820
P180oooo0`0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000@0oooo0`0000000`20
P800oooo0?ooo`0@0?oooah00000o`3ooomE0?oooa7ooooo000@ooooolP0oooo00@0P82000000000
0000P8204`3oool3000000H0oooo0P0000040?ooo`@000005@3ooolI000000030820P03oool0oooo
0?l0ooooE@3ooolAooooo`004?ooooo80?ooo`040820P00000000000000001D0oooo0P0000040?oo
o`8000001@3oool4000001H0oooo00<0P8200000000000004P00003o0?oooe/0oooo4Oooool0013o
oooob@3oool3000000030820P03oool0oooo01<0oooo1P20P8050?ooo`@000007P3oool00`30`<00
P8200820P0060820P?l0ooooH03ooolAooooo`004?ooooo90?ooo`@000007`3oool400000:X0oooo
0`00003J0?oooa7ooooo000@ooooolX0oooo0`00000O0?ooo`@00000ZP3oool400000=T0oooo4Ooo
ool0013ooooo203oool01020P800000000000000002n0?ooo`@000007@3oool01@30`<0000000000
00000000P8200:/0oooo0`00003I0?oooa7ooooo000@ooooo`P0oooo1000002n0?ooo`D00000703o
ool01020P800000000000000002/0?ooo`<00000f@3ooolAooooo`004?ooool80?ooo`<00000`03o
ool4000000030820P03oool0oooo01T0oooo1000002/0?ooo`@00000f03ooolAooooo`004?ooool8
0?ooo`<00000`03oool3000000030?ooo`20P800oooo01X0oooo0`00002^0?ooo`<00000f03ooolA
ooooo`004?ooool70?ooo`040820P0000000000000000<00oooo00H0@410000000000000P8200410
@020P80I0?ooo`<0000000<0P8200?ooo`3oool0[03oool300000=P0oooo4Oooool0013ooooo1`3o
ool300000<40oooo00H0P82000000000000000000?ooo`00000H0?ooo`@00000[`3oool400000=L0
oooo4Oooool0013ooooo1`3oool300000<40oooo00D0P82000000000000000000?ooo`02000000<0
oooo0P00000B0?ooo`<00000/03oool01020P800000000000000003G0?oooa7ooooo000@ooooo`L0
oooo0`0000310?ooo`090820P0000000000000000020P800oooo00000020P800oooo00@00000403o
ool01020P800000000000000002`0?ooo`040820P0000000000000000=L0oooo4Oooool0013ooooo
1P3oool3000000030820P03oool0oooo0;l0oooo00D0P82000000000000000000820P0020?ooo`03
0410@0000000000000<00000403oool01010@400000000000010@43o0?oooh`0oooo4Oooool0013o
oooob03oool8000000<0oooo1@00000@0?ooo`<0000000<0P8200?ooo`3oool0o`3ooon:0?oooa7o
oooo000@oooool/0oooo00<0P8200000000000000P0000040?ooo`<00000403oool400000?l0oooo
S@3ooolAooooo`004?oooooV0?ooo`050820P0000000000000000020P800o`3ooon=0?oooa7ooooo
000@ooooonH0oooo1000003o0?ooohh0oooo4Oooool0013oooooi@3oool400000?l0ooooS`3ooolA
ooooo`004?oooooU0?ooo`@00000o`3ooon?0?oooa7ooooo000@ooooon@0oooo00D0P82000000000
000000000820P03o0?ooohl0oooo4Oooool0013oooooi03oool400000?l0ooooT03ooolAooooo`00
4?oooooT0?ooo`@00000o`3ooon@0?oooa7ooooo000@ooooon<0oooo00@0P8200000000000000000
o`3ooonA0?oooa7ooooo000@ooooon<0oooo0`00003o0?oooi80oooo4Oooool0013ooooohP3oool4
00000?l0ooooTP3ooolAooooo`004?oooooR0?ooo`<00000o`3ooonC0?oooa7ooooo000@ooooon40
oooo00@0P820000000000000@410o`3ooonC0?oooa7ooooo000@ooooon40oooo0`0000000`20P800
oooo0?ooo`2i0?ooo`@00000d`3ooolAooooo`004?oooooQ0?ooo`<0000000<0P8200?ooo`3oool0
^@3oool400000=<0oooo4Oooool0013ooooo0`3oool30820P=X0oooo1000002l0?ooo`040410@000
0000000000000=<0oooo4Oooool0013ooooo0`3oool300000=T0oooo1000002m0?ooo`040820P000
0000000000000=<0oooo4Oooool0013ooooo0`3oool300000=T0oooo1000002m0?ooo`040820P000
0000000000000=<0oooo4Oooool0013ooooo0P3oool3000000030820P03oool0oooo0=H0oooo1000
002n0?ooo`050820P0000000000000000020P800dP3ooolAooooo`004?ooool20?ooo`<0000000<0
P8200?ooo`3oool0e@3oool01@30`<000000000000000000@4100;h0oooo00D0P820000000000000
00000820P03B0?oooa7ooooo000@ooooo`80oooo0`0000000`20P800oooo0?ooo`3E0?ooo`050820
P0000000000000000020P800_`3oool3000000030820P03oool0oooo0=00oooo4Oooool0013ooooo
0P3oool3000000030820P03oool0oooo0=D0oooo100000300?ooo`<0000000<0P8200?ooo`3oool0
d03ooolAooooo`004?ooool00`3oool0`<3000000002000000030820P03oool0oooo0=@0oooo00D0
P82000000000000000000820P0300?ooo`<0000000<0P8200?ooo`3oool0d03ooolAooooo`004?oo
ool00`3oool0P8200000000200000=L0oooo1000003o0?oooiP0oooo4Oooool0013ooooo00<0oooo
0820P00000000P00003F0?ooo`@00000o`3ooonI0?oooa7ooooo000@ooooom/0oooo1000003o0?oo
oiT0oooo4Oooool0013ooooofP3oool01030`<00000000000000000?0?ooo`80P82000<0@4100000
00000000100000020820P?l0ooooP03ooolAooooo`004?oooooJ0?ooo`040820P000000000000820
P0d0oooo00<0P8200000000000000P0000050?ooo`@0000000<0P8200?ooo`3oool0o`3oooml0?oo
oa7ooooo000@ooooomX0oooo0`0000000`20P800oooo0?ooo`0;0?ooo`@00000203oool400000?l0
ooooO@3ooolAooooo`004?oooooJ0?ooo`<0000000<0P8200?ooo`3oool02P3oool4000000X0oooo
1000003o0?ooog`0oooo4Oooool0013ooooof@3oool4000000`0oooo1000000<0?ooo`050410@000
0000000000000010@400o`3ooomj0?oooa7ooooo000@ooooomP0oooo1000000<0?ooo`030820P000
00000000008000003@3oool500000?l0ooooN@3ooolAooooo`004?oooooH0?ooo`@00000303oool0
1020P800000000000000000?0?ooo`D00000o`3ooomh0?oooa7ooooo000@ooooomL0oooo1000000=
0?ooo`040410@0000000000000000100oooo1@00003o0?ooogL0oooo4Oooool0013oooooeP3oool0
1@20P8000000000000000000P82000d0oooo1000000A0?ooo`@0000000<0P8200?ooo`3oool0o`3o
oomd0?oooa7ooooo000@ooooomH0oooo00D0P82000000000000000000820P00=0?ooo`@000004@3o
ool500000?l0ooooMP3ooolAooooo`004?oooooF0?ooo`@000003P3oool400000140oooo00<0P820
0000000000000P00003o0?ooogH0oooo4Oooool0013oooooe@3oool01@20P8000000000000000000
P82000h0oooo1000000A0?ooo`030<30`0000000000000<00000o`3ooome0?oooa7ooooo000@oooo
omD0oooo1000000?0?ooo`@000004P3oool600000?l0ooooM03ooolAooooo`004?oooooD0?ooo`@0
0000403oool500000180oooo1@00003o0?ooog@0oooo4Oooool0013oooood`3oool01@20P8000000
000000000000P8200100oooo00<0@4100000000000000P00000B0?ooo`D0000000<0P8200?ooo`3o
ool0W03oool300000=40oooo4Oooool0013ooooo00@0oooo0000000000000000c`3oool400000140
oooo00<0P8200000000000000P00000C0?ooo`@0000000<0P8200?ooo`3oool0W03oool300000=40
oooo4Oooool0013ooooo00@0oooo0000000000000000cP3oool01@20P8000000000000000000P820
0140oooo00<0P8200000000000000`00000B0?ooo`@0000000<0P8200?ooo`3oool0W03oool30000
0=40oooo4Oooool0013ooooo00@0oooo0000000000000000cP3oool01@20P8000000000000000000
P8200140oooo00<0P8200000000000000`00000B0?ooo`D00000WP3oool300000=40oooo4Oooool0
013ooooo00@0oooo0000000000000000d03oool20820P1<0oooo1@0000000`20P800oooo0?ooo`0?
0?ooo`030820P0000000000000800000W`3oool300000=00oooo4Oooool0013ooooo0`00003W0?oo
o`D000004P3oool4000009l0oooo0`00003@0?oooa7ooooo000@ooooo`<00000c`3oool00`000000
oooo0?ooo`020?ooo`8000004@3oool5000000030820P03oool0oooo00l0oooo1000002O0?ooo`<0
0000d03ooolAooooo`004?ooool300000<`0oooo00D0`<3000000000000000000820P0020?ooo`05
0410@0000000000000000010@400403oool01@10@4000000000000000000@4100140oooo1000002O
0?ooo`<00000d03ooolAooooo`004?ooool300000</0oooo1@0000030?ooo`030820P00000000000
00<000003`3oool00`20P80000000000000200000140oooo1000002O0?ooo`<00000d03ooolAoooo
o`004?ooool300000<X0oooo1@0000060?ooo`D0000000<0P8200?ooo`3oool0303oool500000100
oooo1000003o0?ooog<0oooo4Oooool0013ooooo0`0000380?ooo`030820P0000000000000<00000
203oool5000000l0oooo1000000@0?ooo`<0000000<0P8200?ooo`3oool0o`3oooma0?oooa7ooooo
000@ooooolT0oooo0P20P804000000030<30`03oool0oooo00P0oooo00<0P8200000000000000P00
00020820P0d0oooo00D0P82000000000000000000<30`00=0?ooo`050820P0000000000000000020
P800o`3ooomc0?oooa7ooooo000@ooooolP0oooo00<0P8200000000000000P00000?0?ooo`D00000
00<0P8200?ooo`3oool02`3oool01020P800000000000000000=0?ooo`@00000o`3ooomd0?oooa7o
oooo000@ooooolP0oooo1000000A0?ooo`D000003P3oool4000000`0oooo0`00003o0?ooogD0oooo
4Oooool0013oooooaP3oool5000001<0oooo1P00000=0?ooo`@000002P3oool300000?l0ooooMP3o
oolAooooo`004?ooooo40?ooo`030820P000000000000080000000<0P8200?ooo`3oool04`3oool0
0`20P800000000000002000000030410@03oool0oooo00/0oooo00@0P82000000000000000000P20
P8050?ooo`050820P0000000000000000020P800X@3oool30820P=40oooo4Oooool0013ooooo``3o
ool5000001T0oooo00<0P8200000000000000`00000>0?ooo`/00000X`3oool300000=40oooo4Ooo
ool0013ooooo`@3oool00`20P800000000000003000001/0oooo1P00000?0?ooo`H0000000<0P820
0?ooo`3oool0X`3oool300000=40oooo4Oooool0013ooooo_`3oool20820P0<0000000<0@4100?oo
o`3oool0703oool00`20P800@41000000002000000030410@020P800oooo0;P0oooo0`00003A0?oo
oa7ooooo000@oooookh0oooo1@00000R0?ooo`H00000^03oool300000=40oooo4Oooool0013ooooo
_@3oool5000002@0oooo1@0000000`20P800oooo0?ooo`2e0?ooo`<00000d@3ooolAooooo`004?oo
oonl0?ooo`D0000000<0P8200?ooo`3oool0903oool500000;H0oooo0`00003A0?oooa7ooooo000@
oooookX0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0V0?ooo`030<30`0000000
000000<0000000<0P8200?ooo`3oool0/P3oool300000=40oooo4Oooool0013ooooo^@3oool40000
00030820P03oool0oooo02/0oooo1@00002c0?ooo`<00000d@3ooolAooooo`004?oooong0?ooo`H0
0000;P3oool00`20P80000000000000300000;80oooo0`00003A0?oooa7ooooo000@oooookD0oooo
00<0P8200410@00000000P0000000`10@400oooo0?ooo`0_0?ooo`80P820100000000`20P800oooo
0?ooo`3o0?oooh<0oooo4Oooool0013ooooo]03oool5000003H0oooo1@00003o0?oooh@0oooo4Ooo
ool0013ooooo00@0oooo0000000000000000[`3oool5000003L0oooo00<0P8200000000000000`00
003o0?oooh<0oooo4Oooool0013ooooo00<0oooo0000000000000P00002]0?ooo`D00000>P3oool5
000000030820P03oool0oooo0?l0ooooO`3ooolAooooo`004?ooool00`3oool00000000000020000
0:X0oooo00<0`<300820P00000000`0000000`20P800oooo0?ooo`0j0?ooo`030410@00000000000
0080000000<0P8200?ooo`3oool0o`3ooomn0?oooa7ooooo000@ooooo`030?ooo`00000000000080
0000ZP3oool4000000030820P03oool0oooo03h0oooo1@0000000`20P800oooo0?ooo`3o0?ooog`0
oooo4Oooool0013ooooo00<0oooo0000000000000P00002X0?ooo`H00000@P3oool500000?l0oooo
OP3ooolAooooo`004?ooool00`3oool0P82000000002000000030<30`03oool0oooo0:<0oooo00<0
P8200000000000000P0000000`20P800oooo0?ooo`130?ooo`030820P00000000000008000000P20
P83o0?ooog/0oooo4Oooool0013ooooo00<0oooo0820P00000000P0000000`20P800oooo0?ooo`2R
0?ooo`D0000000<0P8200?ooo`3oool0AP3oool5000000030820P03oool0oooo0?l0ooooN03ooolA
ooooo`004?ooool00`3oool0P82000000002000000030820P03oool0oooo0:00oooo00<0P8200000
000000000`00001;0?ooo`D00000o`3ooomj0?oooa7ooooo000@ooooo`80oooo0`0000000`20P800
oooo0?ooo`2P0?ooo`D00000C@3oool600000?l0ooooN03ooolAooooo`004?ooool20?ooo`<0P820
00<0`<300?ooo`3oool0W@3oool20820P0@0000000<0`<300?ooo`3oool0C@3oool00`20P8000000
00000003000000030<30`03oool0oooo0?l0ooooM03ooolAooooo`004?oooonT0?ooo`030820P000
0000000000800000E03oool00`20P80000000000000300000?l0ooooM@3ooolAooooo`004?oooonS
0?ooo`D0000000<0P8200?ooo`3oool0D`3oool600000?l0ooooM03ooolAooooo`004?oooonQ0?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0EP3oool20820P0<0000000<0@4100820
P03oool0o`3oooma0?oooa7ooooo000@oooooj00oooo1@00001L0?ooo`030820P0000000000000<0
0000o`3oooma0?oooa7ooooo000@oooooih0oooo1P00001N0?ooo`H00000V03oool01020P8000000
00000000003C0?oooa7ooooo000@oooooid0oooo00<0P8200000000000000`00001Q0?ooo`D00000
U`3oool01020P800000000000000003C0?oooa7ooooo000@oooooi/0oooo00<0P820000000000000
0`0000000`30`<00oooo0?ooo`1P0?ooo`030<30`0000000000000<0000000<0P8200?ooo`3oool0
T`3oool01010@400000000000020P83C0?oooa7ooooo000@oooooiX0oooo00<0P820000000000000
0P00001X0?ooo`D00000U03oool300000=@0oooo4Oooool0013oooooV@3oool5000006X0oooo1@00
002C0?ooo`<00000e03ooolAooooo`004?oooonH0?ooo`D0000000<0P8200?ooo`3oool0J03oool0
0`20P80000000000000300000980oooo0`00003D0?oooa7ooooo000@oooooiH0oooo00<0@4100000
000000000P0000000`20P800oooo0?ooo`1/0?ooo`030820P000000000000080000000<0@4100?oo
o`3oool0SP3oool300000=@0oooo4Oooool0013oooooU03oool600000740oooo00<0P82000000000
00000`00002>0?ooo`@00000e03ooolAooooo`004?oooonC0?ooo`030820P0000000000000<00000
M03oool5000008d0oooo0`00003E0?oooa7ooooo000@oooooi40oooo00<0P8200000000000000P00
00000`10@400oooo0?ooo`1e0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0R@3o
ool30820P=D0oooo4Oooool0013oooooT03oool5000007/0oooo1@00003o0?ooof<0oooo4Oooool0
013oooooS`3oool5000007d0oooo1@0000000`20P800oooo0?ooo`3o0?oooel0oooo4Oooool0013o
oooo1@3oool3000008H0oooo1@0000000`20P800oooo0?ooo`1l0?ooo`D00000o`3ooomQ0?oooa7o
oooo000@ooooo`D0oooo00@0@410000000000000P820P`3oool00`10@40000000000000200000003
0820P03oool0oooo07l0oooo00<0P8200000000000000P0000000`20P800`<300?ooo`3o0?oooed0
oooo4Oooool0013ooooo1@3oool01020P800000000000020P8210?ooo`D0000000<0P8200?ooo`3o
ool0P`3oool500000?l0ooooGP3ooolAooooo`004?ooool50?ooo`040820P000000000000820P800
oooo1P0000270?ooo`030820P0000000000000800000o`3ooomM0?oooa7ooooo000@ooooo`D0oooo
00@0`<300000000000000000OP3oool00`20P800000000000002000000030410@03oool0oooo08P0
oooo00<0P8200000000000000`0000000`30`<00oooo0?ooo`3o0?oooeP0oooo4Oooool0013ooooo
1P3oool3000007d0oooo1P00002=0?ooo`030820P0000000000000800000o`3ooomJ0?oooa7ooooo
000@ooooo`H0oooo0`00001k0?ooo`030820P0000000000000<00000T03oool600000?l0ooooF03o
oolAooooo`004?ooool60?ooo`@00000NP3oool500000980oooo1@0000000`20P800oooo0?ooo`3o
0?oooeD0oooo4Oooool0013ooooo1`3oool3000007L0oooo00<0`<300000000000000`0000000`20
P800oooo0?ooo`2C0?ooo`040410@0000000000000000080P820o`3ooomE0?oooa7ooooo000@oooo
oh00oooo1@00002I0?ooo`H00000o`3ooomD0?oooa7ooooo000@ooooogl0oooo1@0000000`20P800
oooo0?ooo`2I0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomA0?oooa7ooooo000@ooooogd0oooo
00<0@4100000000000000P0000000`20P800oooo0?ooo`2K0?ooo`030<30`0000000000000<00000
00<0P8200?ooo`3oool0o`3ooom?0?oooa7ooooo000@ooooog/0oooo1P0000000`20P800oooo0?oo
o`2O0?ooo`D00000o`3ooom@0?oooa7ooooo000@ooooogX0oooo00<0P8200000000000000`00002T
0?ooo`D00000LP3oool300000=T0oooo4Oooool0013oooooNP3oool500000:D0oooo00<0P8200000
000000000`00001a0?ooo`<00000f@3ooolAooooo`004?oooomg0?ooo`030820P0000000000000<0
000000<0`<300?ooo`3oool0YP3oool00`20P800000000000002000000030820P03oool0oooo06`0
oooo00@0P8200000000000000000f@3ooolAooooo`004?oooomf0?ooo`D00000[@3oool5000006d0
oooo0`00003J0?oooa7ooooo000@ooooogD0oooo1@0000000`20P800oooo0?ooo`2/0?ooo`D00000
K03oool300000=X0oooo4Oooool0013oooooL`3oool00`10@400000000000002000000030820P03o
ool0oooo0:l0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`1W0?ooo`040<30`000
000000000410@=X0oooo4Oooool0013oooooL@3oool600000;D0oooo1@00001X0?ooo`030820P000
000000000=/0oooo4Oooool0013oooooL03oool600000;L0oooo1@0000000`20P800oooo0?ooo`1T
0?ooo`<00000f`3ooolAooooo`004?oooom_0?ooo`030820P0000000000000<00000^@3oool50000
06H0oooo0`00003K0?oooa7ooooo000@ooooofd0oooo00<0P8200000000000000`0000000`30`<00
oooo0?ooo`2i0?ooo`030<30`00000000000008000000P20P81R0?ooo`<0P820g03ooolAooooo`00
4?oooom/0?ooo`D00000`03oool5000000030820P03oool0oooo0?l0oooo?`3ooolAooooo`004?oo
oom[0?ooo`D00000`P3oool00`20P80000000000000200000?l0oooo@@3ooolAooooo`004?ooool<
0?ooo`<00000FP3oool6000000030820P03oool0oooo0<40oooo1P00003o0?ooocl0oooo4Oooool0
013ooooo303oool01010@400000000000020P81G0?ooo`030820P010@400000000<0000000<0P820
0?ooo`3oool0a03oool20820P0<0000000<0@4100?ooo`3oool0o`3oooll0?oooa7ooooo000@oooo
o``0oooo00@0P8200000000000000000EP3oool600000<X0oooo00<0P8200000000000000`00003o
0?oooc`0oooo4Oooool0013ooooo3@3oool3000005D0oooo00<0P8200000000000000`00003<0?oo
o`H00000o`3ooolk0?oooa7ooooo000@ooooo`d0oooo00@0P8200000000000000000DP3oool00`20
P800000000000002000000030410@03oool0oooo0<h0oooo00H0@41000000000000000000410@020
P83o0?ooocT0oooo4Oooool0013ooooo3P3oool4000004l0oooo00<0P8200000000000000`00000B
0?ooo`/0000000<0P8200?ooo`3oool01@3oool00`20P800000000000004000000030820P03oool0
oooo0:@0oooo1P00003o0?ooocP0oooo4Oooool0013ooooo3P3oool4000004l0oooo1@00000D0?oo
o`030820P0000000000000D000002P3oool00`20P80000000000000300000:X0oooo100000000`20
P800oooo0?ooo`3o0?ooocD0oooo4Oooool0013ooooo3`3oool4000004`0oooo1P0000000`20P800
oooo0?ooo`0C0?ooo`H0000000<0P8200?ooo`3oool0203oool500000:`0oooo1@00003o0?ooocH0
oooo4Oooool0013ooooo3`3oool01010@40000000820P020P81:0?ooo`030820P0000000000000<0
000000<0P8200?ooo`3oool05P3oool5000000030820P03oool0oooo00P0oooo1000002]0?ooo`03
0<30`020P800000000<0000000<0P8200?ooo`3oool0o`3ooolb0?oooa7ooooo000@oooooe`0oooo
1@0000000`20P800oooo0?ooo`0I0?ooo`@0000000<0P8200?ooo`3oool01`3oool500000;00oooo
1@00003o0?oooc<0oooo4Oooool0013oooooFP3oool00`20P800000000000004000001`0oooo1000
00000`20P800oooo0?ooo`070?ooo`@0000000<0P8200?ooo`3oool0[P3oool00`20P80000000000
000300000?l0oooo<P3ooolAooooo`004?oooomI0?ooo`030820P000000000000080000000<0P820
0?ooo`3oool0703oool4000000030410@03oool0oooo00H0oooo1@0000000`30`<00oooo0?ooo`2`
0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0o`3oool^0?oooa7ooooo000@oooo
oeL0oooo1P0000000`20P800oooo0?ooo`0M0?ooo`030820P0000000000000800000203oool50000
0;D0oooo1@0000190?ooo`030820P0000000oooo0>80oooo4Oooool0013oooooEP3oool00`20P800
00000000000300000240oooo00<0P8200000000000000P0000070?ooo`H00000]P3oool5000004P0
oooo0`0000000`20P800oooo0?ooo`3O0?oooa7ooooo000@oooooeD0oooo1P00000R0?ooo`030820
P0000000000000<000001P3oool500000;P0oooo1@0000000`20P800oooo0?ooo`140?ooo`<00000
00<0P8200?ooo`3oool0g`3ooolAooooo`004?oooom10?ooo`030410@020P800oooo00l0oooo00<0
P8200000000000000`0000000`20P800oooo0?ooo`0R0?ooo`D000001@3oool00`30`<0000000000
000300000;T0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`120?ooo`@00000hP3o
oolAooooo`004?oooom00?ooo`D000003@3oool5000002L0oooo1@0000050?ooo`030820P0000000
000000800000_03oool5000000030820P03oool0oooo03l0oooo1000003S0?oooa7ooooo000@oooo
ocl0oooo1P0000000`20P800oooo0?ooo`080?ooo`H0000000<0P8200?ooo`3oool09@3oool60000
00@0oooo1@00002m0?ooo`D00000@@3oool400000><0oooo4Oooool0013ooooo?P3oool00`20P800
000000000005000000030820P03oool0oooo00H0oooo00<0@4100000000000000P0000000`20P800
oooo0?ooo`0X0?ooo`D00000103oool4000000030820P03oool0oooo0;`0oooo00<0`<3000000000
00000P0000020820P3d0oooo1000003T0?oooa7ooooo000@oooooch0oooo2P0000050?ooo`H00000
00<0P8200?ooo`3oool0:@3oool5000000030820P03oool0oooo00D0000000<0P8200?ooo`3oool0
_P3oool5000000030820P03oool0oooo03X0oooo0`0000000`20P800oooo0?ooo`3R0?oooa7ooooo
000@ooooocd0oooo2`0000001@20P800oooo0?ooo`3oool0P82000D00000;P3oool<00000<80oooo
00<0P8200000000000000P00000k0?ooo`050820P0000000000000000020P800i03ooolAooooo`00
4?ooooll0?ooo`d000000P3oool6000002l0oooo3`0000300?ooo`H00000>`3oool2000000030820
P03oool0oooo0>80oooo4Oooool0013ooooo>`3oool00`20P80000000000000;000000030820P000
0000000000<0000000<0`<300?ooo`3oool0;P3oool01@20P8000000000000000000@41000H0oooo
00<0P8200410@00000000P0000000`20P800oooo0?ooo`2m0?ooo`80P820100000000`30`<00oooo
0?ooo`3o0?oooal0oooo4Oooool0013ooooo603oool200000200oooo00<0P8200000000000004000
000d0?ooo`@00000203oool500000<00oooo00<0P8200000000000000`00003o0?ooob00oooo4Ooo
ool0013ooooo5`3oool300000200oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`0b
0?ooo`@000002@3oool500000<00oooo1P00003o0?oooal0oooo4Oooool0013ooooo5`3oool30000
00030820P03oool0oooo01d0oooo4P00000e0?ooo`D000002@3oool4000000030820P03oool0oooo
0;l0oooo100000000`20P800oooo0?ooo`3o0?oooa`0oooo4Oooool0013ooooo5`3oool01020P800
000000000010@40M0?ooo`030820P000000000000140000000<0@4100?ooo`3oool0<P3oool00`20
P800000000000002000000T0oooo00D0@41000000000000000000410@0320?ooo`030410@0000000
00000080000000<0P8200?ooo`3oool0o`3ooolJ0?oooa7ooooo000@oooooaP0oooo0`00000M0?oo
oaD00000=03oool00`20P800000000000002000000T0oooo00<0P8200000000000000P0000340?oo
o`D00000o`3ooolK0?oooa7ooooo000@oooooaP0oooo1000000K0?oooaL00000=03oool5000000P0
oooo00<0P8200000000000000P0000350?ooo`D00000o`3ooolJ0?oooa7ooooo000@oooooaT0oooo
0`0000000`20P800oooo0?ooo`0G0?ooo`030820P0000000000001D0000000<0P8200?ooo`3oool0
<@3oool5000000P0oooo00<0P8200000000000000P0000350?ooo`030<30`020P800000000<00000
00<0P8200?ooo`3oool0o`3ooolF0?oooa7ooooo000@oooooaX0oooo1000000H0?oooaT00000<`3o
ool6000000L0oooo00<0P8200000000000000P0000380?ooo`D00000o`3ooolG0?oooa7ooooo000@
oooooaX0oooo1000000G0?oooaX00000=03oool5000000L0oooo00D0P82000000000000000000820
P0390?ooo`D00000o`3ooolF0?oooa7ooooo000@oooooaX0oooo00<0P8200000003oool05`3ooolK
000003@0oooo1@0000070?ooo`@0000000<0P8200?ooo`3oool0b03oool500000?l0oooo5@3ooolA
ooooo`004?oooolc0?ooo`030<30`0000000000001T0000000<0P8200?ooo`3oool0<@3oool50000
00060820P03oool0oooo0?ooo`30`<00P820100000000`20P800oooo0?ooo`3:0?ooo`030820P000
000000000080000000<0@4100?ooo`3oool0o`3ooolA0?oooa7ooooo000@oooooc<0oooo70000000
0`20P800oooo0?ooo`0_0?ooo`030820P0000000000000d00000d03oool500000?l0oooo4P3ooolA
ooooo`004?oooolb0?oooad0000000<0P8200?ooo`3oool0;P3oool?00000=<0oooo1@0000000`20
P800oooo0?ooo`0M0?ooo`030820P03oool0oooo0>d0oooo4Oooool0013ooooo<@3oool00`20P800
00000000000H00000080P820o`3ooolF0?ooo`030820P010@40000000080000000<0P8200?ooo`3o
ool06P3oool01@20P8000000000000000000P8200>d0oooo4Oooool0013ooooo<03ooolG00000?l0
oooo7`3oool6000001X0oooo1000003^0?oooa7ooooo000@oooooc00oooo5000003o0?ooob<0oooo
1@0000000`20P800oooo0?ooo`0F0?ooo`030820P0000000000000800000kP3ooolAooooo`004?oo
ool_0?ooo`030820P0000000000000l00000o`3ooolW0?ooo`030820P0000000000000800000603o
ool01020P800000000000000003_0?oooa7ooooo000@ooooobh0oooo00<0P8200000000000003000
00020820P?l0oooo:P3oool00`20P800000000000003000000030<30`03oool0oooo01<0oooo0`00
00000`20P800oooo0?ooo`0F0?ooo`050820P0000000000000000030`<00dP3ooolAooooo`004?oo
ool^0?ooo``0000000<0P8200?ooo`3oool0o`3oool_0?ooo`@00000503oool4000001X0oooo0`00
00000`20P800oooo0?ooo`3@0?oooa7ooooo000@ooooobd0oooo2P00003o0?ooocD0oooo00<0P820
0000000000000`00000B0?ooo`<000006`3oool3000000030820P03oool0oooo0=00oooo4Oooool0
013ooooo;03oool01010@400000000000010@4040820P?l0oooo>@3oool20820P0@0000000<0`<30
0?ooo`3oool03@3oool20820P0030000003oool0oooo01X0oooo00@0P820000000000000@410dP3o
oolAooooo`004?ooool/0?ooo`800000o`3ooom10?ooo`030820P0000000000000<00000;P3oool3
00000=80oooo4Oooool0013ooooo:`3oool00`000000oooo0?ooo`3o0?oood80oooo1P00000]0?oo
o`<00000dP3ooolAooooo`004?oooolU0?ooo`800000o`3ooom;0?ooo`@0000000<0P8200?ooo`3o
ool0:P3oool400000=40oooo4Oooool0013ooooo8`3oool01@20P8000000000000000000P8200?l0
ooooB`3oool00`10@400000000000002000000030820P03oool0oooo02T0oooo0`0000000`20P800
oooo0?ooo`3>0?oooa7ooooo000@ooooob@0oooo100000000`20P800oooo0?ooo`3o0?ooodX0oooo
1@00000Z0?ooo`@00000d03ooolAooooo`004?oooolU0?ooo`040820P000000000000820P?l0oooo
C@3oool5000002X0oooo0`00003@0?oooa7ooooo000@ooooobH0oooo0`0000000`20P800oooo0?oo
o`3o0?ooodX0oooo00<0`<300820P00000000`0000000`20P800oooo0?ooo`0V0?ooo`<0000000<0
P8200?ooo`3oool0c@3ooolAooooo`004?oooolW0?ooo`@00000o`3ooom>0?ooo`D0000000<0P820
0?ooo`3oool0903oool400000<l0oooo4Oooool0013ooooo:03oool300000?l0ooooC`3oool50000
02H0oooo00<0P8200000000000000P00003>0?oooa7ooooo000@ooooobP0oooo00@0P82000000000
00000000o`3ooom?0?ooo`D000009@3oool01@20P800000000000020P80000000<h0oooo4Oooool0
013ooooo:03oool00`30`<00P8200820P03o0?oooe40oooo00<0P8200000000000000P0000000`10
@400oooo0?ooo`0Q0?ooo`070<30`000000000000410@020P80000000820P03<0?oooa7ooooo000@
ooooool0ooooOP3oool00`20P800000000000002000002<0oooo0`0000020?ooo`030000003oool0
oooo0<X0oooo4Oooool0013oooooo`3ooomo0?ooo`D000008P3oool300000080oooo00D000000820
P03oool0oooo0820P00200000<H0oooo4Oooool0013oooooo`3ooomi0?ooo`8000001@3oool50000
00030820P03oool0oooo01h0oooo100000020?ooo`030000003oool0oooo00@00000a@3ooolAoooo
o`004?oooooo0?ooogL0oooo00D0P82000000000000000000820P0050?ooo`030<30`00000000000
0080000000<0P8200?ooo`3oool07@3oool400000080oooo00<0`<30000000000000100000350?oo
oa7ooooo000@ooooool0ooooM`3oool4000000P0oooo1@0000000`20P800oooo0?ooo`0G0?ooo`T0
00000`3oool500000<D0oooo4Oooool0013oooooo`3ooomf0?ooo`050820P0000000000000000020
P8002P3oool4000001d0oooo1@0000040?ooo`<00000aP3ooolAooooo`004?oooooo0?ooogD0oooo
00<0P8200000000000000P00000;0?ooo`030<30`00000000000008000000P20P83/0?oooa7ooooo
000@ooooool0ooooM03oool5000000l0oooo100000000`20P800oooo0?ooo`3Y0?oooa7ooooo000@
ooooool0ooooM03oool400000100oooo00<0P8200000000000000P00003[0?oooa7ooooo000@oooo
ool0ooooL`3oool00`20P80000000000000200000140oooo1P00003Y0?oooa7ooooo000@ooooool0
ooooM@3oool20820P1@0oooo00D0P82000000000000000000410@03X0?oooa7ooooo000@ooooocD0
oooo00<000000820P03oool0o`3ooomD0?ooo`030820P0000000000000<00000iP3ooolAooooo`00
4?oooold0?ooo`<00000o`3ooomG0?ooo`D00000i@3ooolAooooo`004?oooolc0?ooo`030<30`000
000000000080000000<0P8200?ooo`3oool0o`3ooomD0?ooo`060410@0000000000000000010@400
P820h`3ooolAooooo`004?oooole0?ooo`@00000o`3ooomH0?ooo`D00000hP3ooolAooooo`004?oo
oolf0?ooo`@00000o`3ooomH0?ooo`@0000000<0P8200?ooo`3oool0g`3ooolAooooo`004?oooolf
0?ooo`050820P0000000000000000020P800o`3ooomH0?ooo`D00000h03ooolAooooo`004?oooolf
0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0o`3ooomF0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0g03ooolAooooo`004?oooolh0?ooo`<00000o`3ooomK0?oo
o`D00000g@3ooolAooooo`004?ooooli0?ooo`0300000020P800oooo0?l0ooooF`3oool500000=`0
oooo4Oooool0013oooooo`3ooonH0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0
f03ooolAooooo`004?oooooo0?ooofP0oooo00<000000?ooo`3oool0;`3oool00`20P80000000000
000200000=T0oooo4Oooool0013oooooo`3ooomW0?ooo`<00000<@3oool500000=P0oooo4Oooool0
013oooooo`3ooomV0?ooo`D00000<@3oool5000000030820P03oool0oooo0=@0oooo4Oooool0013o
ooooo`3ooomU0?ooo`050410@0000000000000000020P800<`3oool00`30`<000000000000020000
00030820P03oool0oooo0=<0oooo4Oooool0013oooooo`3ooomT0?ooo`@0000000<0P8200?ooo`3o
ool0=03oool600000=<0oooo4Oooool0013oooooo`3ooomS0?ooo`D00000>@3oool4000000030820
P03oool0oooo0=00oooo4Oooool0013oooooo`3ooomR0?ooo`D00000>P3oool00`20P80000000000
000200000=80oooo4Oooool0013oooooo`3ooomQ0?ooo`050<30`0000000000000000010@400?03o
ool20820P0@0000000<0`<300?ooo`3oool0c@3ooolAooooo`004?oooooo0?ooof<0oooo0P000010
0?ooo`@00000c`3ooolAooooo`004?oooom70?ooo`0300000020P800oooo0?l0ooooF`3oool00`20
P80000000000000300000<d0oooo4Oooool0013oooooA@3oool01@30`<000000000000000000P820
0?l0ooooG@3oool00`20P800000000000002000000030<30`03oool0oooo0<T0oooo4Oooool0013o
ooooAP3oool600000?l0ooooG03oool00`20P80000000000000300000<X0oooo4Oooool0013ooooo
A`3oool5000000030820P03oool0oooo0?l0ooooF`3oool500000<T0oooo4Oooool0013oooooB03o
ool500000?l0ooooGP3oool4000000030820P03oool0oooo0<H0oooo4Oooool0013oooooB@3oool0
0`20P800000000000002000000030820P03oool0oooo0?l0ooooF`3oool00`20P800000000000002
000000030820P03oool0oooo0<@0oooo4Oooool0013oooooB`3oool300000?l0ooooH03oool50000
0<D0oooo4Oooool0013oooooC03oool00`000000oooo0?ooo`3o0?ooof00oooo1@0000340?oooa7o
oooo000@ooooool0ooooE@3oool20820P5T0oooo00<0P8200000000000000P0000000`20P800oooo
0?ooo`300?oooa7ooooo000@ooooool0ooooE03oool3000005/0oooo1@0000310?oooa7ooooo000@
ooooool0ooooD`3oool4000000030820P03oool0oooo05T0oooo00<0P8200000000000000P000030
0?oooa7ooooo000@ooooool0ooooDP3oool5000005d0oooo1@00002o0?oooa7ooooo000@ooooool0
ooooD03oool01020P80000000000000000020820P5l0oooo00<0P8200410@00000000P0000000`10
@400oooo0?ooo`2k0?oooa7ooooo000@ooooool0ooooC`3oool4000000030820P03oool0oooo0640
oooo1@00002l0?oooa7ooooo000@ooooool0ooooCP3oool5000006D0oooo1@0000000`20P800oooo
0?ooo`2h0?oooa7ooooo000@ooooool0ooooC`3oool00`000000P8200820P01X0?ooo`050410@000
0000000000000020P800^@3ooolAooooo`004?oooomK0?ooo`800000o`3ooomN0?ooo`H00000]`3o
oolAooooo`004?oooomJ0?ooo`040820P000000000000820P?l0ooooG`3oool4000000030820P03o
ool0oooo0;@0oooo4Oooool0013oooooFP3oool500000?l0ooooGP3oool00`20P800000000000002
00000;H0oooo4Oooool0013oooooF`3oool00`20P800000000000003000000030820P03oool0oooo
0?l0ooooFP3oool20820P0@0000000<0`<300?ooo`3oool0/@3ooolAooooo`004?oooomM0?ooo`03
0820P0000000000000@00000o`3ooomM0?ooo`@00000/`3ooolAooooo`004?oooomM0?ooo`030820
P0000000000000@00000o`3ooomM0?ooo`030820P0000000000000<00000/@3ooolAooooo`004?oo
oomO0?ooo`80P8200P00003o0?ooof00oooo00<0P8200000000000000P0000000`30`<00oooo0?oo
o`2]0?oooa7ooooo000@ooooool0oooo@03oool00`000000P8200?ooo`210?ooo`030820P0000000
000000<00000[P3ooolAooooo`004?oooooo0?oooch0oooo00@0P820000000000000P820Q03oool5
00000:d0oooo4Oooool0013oooooo`3ooolm0?ooo`D00000Q@3oool500000:`0oooo4Oooool0013o
ooooo`3ooolj0?ooo`030<30`020P800000000@0000000<0P8200?ooo`3oool0Q03oool00`20P800
000000000002000000030820P03oool0oooo0:P0oooo4Oooool0013oooooo`3ooolj0?ooo`D00000
R`3oool500000:T0oooo4Oooool0013oooooo`3ooolh0?ooo`H0000000<0P8200?ooo`3oool0RP3o
ool500000:P0oooo4Oooool0013oooooo`3oooli0?ooo`@00000S`3oool00`20P800000000000002
00000:L0oooo4Oooool0013oooooL@3oool200000080P820``3oool20820P980oooo00<0P8200000
000000000P0000000`20P800`<300?ooo`2S0?oooa7ooooo000@ooooog00oooo1P0000000`20P800
oooo0?ooo`3o0?oooeH0oooo00<0P8200000000000000P00002T0?oooa7ooooo000@ooooog00oooo
2@00003o0?oooeL0oooo1@00002S0?oooa7ooooo000@ooooog80oooo00<0P8200410@00000001@00
00000`20P800oooo0?ooo`3o0?oooe@0oooo0P20P803000000030410@03oool0oooo09l0oooo4Ooo
ool0013oooooMP3oool400000?l0ooooF@3oool00`20P80000000000000200000:00oooo4Oooool0
013oooooM`3oool300000?l0ooooFP3oool6000009h0oooo4Oooool0013oooooo`3ooolY0?ooo`03
0000003oool0oooo0:X0oooo100000000`20P800oooo0?ooo`2K0?oooa7ooooo000@ooooool0oooo
9@3oool20820P0@00000Z`3oool00`30`<0000000000000200000080P820V`3ooolAooooo`004?oo
oooo0?ooob<0oooo2000002^0?ooo`@0000000<0P8200?ooo`3oool0V03ooolAooooo`004?oooooo
0?ooob40oooo200000000`20P800oooo0?ooo`2^0?ooo`@00000VP3ooolAooooo`004?oooon80?oo
o`030<30`020P800P82009D0oooo00<0P8200000000000000P0000020820P;80oooo00<0`<300820
P00000000`0000000`20P800oooo0?ooo`2E0?oooa7ooooo000@ooooohP0oooo00<0P82000000000
00000P00002D0?ooo`<00000^03oool4000000030820P03oool0oooo09@0oooo4Oooool0013ooooo
R03oool7000000030820P03oool0oooo0?l0ooooB`3oool00`20P800000000000003000009D0oooo
4Oooool0013oooooR03oool:00000?l0ooooC@3oool5000009@0oooo4Oooool0013oooooRP3oool2
0820P0030410@0000000000000<00000o`3ooom>0?ooo`060820P0000000000000000010@400P820
TP3ooolAooooo`004?oooon?0?ooo`800000O@3oool300000=00oooo1@00002A0?oooa7ooooo000@
ooooool0oooo303oool700000=00oooo1@00002@0?oooa7ooooo000@ooooool0oooo2@3oool:0000
0=40oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2<0?oooa7ooooo000@oooooj40
oooo00<0P8200000000000000P00001R0?ooo`030820P0000000000000@00000eP3oool5000008d0
oooo4Oooool0013oooooX@3oool00`20P800000000000006000005h0oooo00@0P820000000000000
P820fP3oool5000008`0oooo4Oooool0013oooooX@3oool:00000?l0oooo?@3oool00`20P8000000
00000002000008/0oooo4Oooool0013oooooX@3oool30820P0030410@0000000000000@00000@`3o
ool50820P0D00000l03oool00`20P800000000000002000000030820P030`<00oooo08L0oooo4Ooo
ool0013oooooZ03oool00`20P80000000?ooo`130?ooo`X00000lP3oool00`20P800000000000002
000008P0oooo4Oooool0013oooooZ@3oool00`000000oooo0?ooo`0?0?ooo`T0000000<0P8200?oo
o`3oool0:03oool900000?<0oooo1@0000270?oooa7ooooo000@oooookX0oooo00<0`<3000000000
00001`0000000`20P800oooo0?ooo`0=0?ooo`X000004@3oool90820P?@0oooo0P20P80400000003
0<30`03oool0oooo0880oooo4Oooool0013ooooo^P3oool00`20P800000000000007000000030820
P03oool0oooo00h0oooo2@00003o0?oooa40oooo00<0P8200000000000000P0000240?oooa7ooooo
000@oooookd0oooo00<0P820000000000000100000000`20P800oooo0?ooo`0>0?ooo`T00000o`3o
oolB0?ooo`D00000P`3ooolAooooo`004?oooooo0?oooo80oooo100000000`20P800oooo0?ooo`1o
0?oooa7ooooo000@ooooool0ooool`3oool01@10@4000000000000000000P8200800oooo4Oooool0
013oooooo`3ooooe0?ooo`D00000OP3ooolAooooo`004?oooooo0?ooooH0oooo100000000`20P800
oooo0?ooo`1k0?oooa7ooooo000@ooooool0oooomP3oool00`20P800000000000002000007d0oooo
4Oooool0013oooooo`3ooooh0?ooo`030820P000000000000080000000<0`<300?ooo`3oool0N03o
oolAooooo`004?oooooo0?ooooX0oooo1000001j0?oooa7ooooo000@ooooool0oooon`3oool50000
07P0oooo4Oooool0013oooooo`3ooool0?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool0M03ooolAooooo`004?oooooo0?ooooh0oooo1@00001e0?oooa7ooooo000@ooooool0ooooo`3o
ool5000007@0oooo4Oooool0013oooooo`3ooooo0?ooo`40oooo100000000`20P800oooo0?ooo`1a
0?oooa7ooooo000@ooooool0ooooo`3oool20?ooo`030<30`000000000000080000000<0P8200?oo
o`3oool0K`3ooolAooooo`004?oooooo0?ooool0oooo103oool500000700oooo4Oooool0013ooooo
o`3ooooo0?ooo`D0oooo00<0P8200000000000000P00000A0?ooo`800000G03ooolAooooo`004?oo
oooo0?ooool0oooo1P3oool00`20P800000000000002000000030820P03oool0oooo00T0oooo00<0
`<300820P00000000`0000000`20P800oooo0?ooo`1I0?oooa7ooooo000@ooooool0ooooo`3oool9
0?ooo`@000002P3oool7000005/0oooo4Oooool0013oooooo`3ooooo0?ooo`T0oooo00<0P8200000
000000000P0000080?ooo`P0000000<0P8200?ooo`3oool0F03ooolAooooo`004?oooooo0?ooool0
oooo2P3oool5000000H0oooo2@0000000`20P800oooo0?ooo`1H0?oooa7ooooo000@ooooool0oooo
o`3oool<0?ooo`050410@0000000000000000010@4000P3oool00`30`<0000000000000900000003
0820P03oool0oooo05L0oooo4Oooool0013oooooo`3ooooo0?ooo`d0oooo1@0000000`3oool0P820
0000000;000005T0oooo4Oooool0013oooooo`3ooooo0?ooo`l0oooo4P00001H0?oooa7ooooo000@
ooooool0ooooo`3oool@0?ooo`030410@0000000000000l0000000<0`<300?ooo`3oool0E03ooolA
ooooo`004?oooooo0?ooool0oooo4@3ooolB000005H0oooo4Oooool0013oooooo`3ooooo0?oooa00
oooo00<0P8200000000000004000001F0?oooa7ooooo000@ooooool0ooooo`3oool@0?ooo`030820
P0000000000001400000E@3ooolAooooo`004?oooooo0?ooool0oooo403ooolE000000030<30`03o
ool0oooo0540oooo4Oooool0013oooooo`3ooooo0?ooo`l0oooo5P0000000`20P800oooo0?ooo`0B
0?ooo`040820P00000000000000003/0oooo4Oooool0013oooooo`3ooooo0?ooo`l0oooo5`00000D
0?ooo`040820P00000000000000001P0oooo00<000000?ooo`3oool0803ooolAooooo`004?oooooo
0?ooool0oooo3P3ooolH000001@0oooo00@0P82000000000000000005`3oool2000000030820P03o
ool0oooo0180oooo00<0P8200?ooo`3oool02P3ooolAooooo`004?oooooo0?ooool0oooo3P3ooolI
000001<0oooo00@0P82000000000000000005@3oool01030`<00000000000020P80E0?ooo`030<30
`0000000P82000X0oooo4Oooool0013oooooo`3ooooo0?ooo`d0oooo6`00000C0?ooo`<0000000<0
P8200?ooo`3oool04P3oool2000001T0oooo0P0000090?oooa7ooooo000@ooooool0ooooo`3oool=
0?oooa`000004P3oool3000000030820P03oool0oooo0140oooo0P00000K0?ooo`0300000020P800
oooo00L0oooo4Oooool0013oooooo`3ooooo0?ooo``0oooo00<0P8200000000000006P0000000`30
`<00oooo0?ooo`0?0?ooo`<0000000<0P8200?ooo`3oool0403oool2000000030820P03oool0oooo
01X0oooo00<000000820P03oool01P3ooolAooooo`004?oooooo0?ooool0oooo3`3ooolK00000140
oooo0`0000000`20P800oooo0?ooo`0?0?ooo`030820P0000000000001d0oooo00<0P82000000000
00001P3ooolAooooo`004?oooooo0?ooool0oooo4@3ooolJ00000140oooo0`00000A0?ooo`<00000
7@3oool01020P800000000000020P8050?oooa7ooooo000@ooooool0ooooo`3ooolC0?ooo`030820
P0000000000001D000004@3oool300000140oooo0P00000O0?ooo`80000000<0P8200?ooo`3oool0
0`3ooolAooooo`004?oooooo0?ooool0oooo5`3oool20820P1<0000000<0`<300?ooo`3oool02@3o
ool20820P00300000020P8000000008000000P20P8000`000000P8200820P00;0?ooo`<00000203o
ool3000000030820P03oool0oooo0140oooo0`0000050?oooa7ooooo000@ooooool0ooooo`3ooolK
0?ooo`030820P0000000000000h0000000<0P8200?ooo`3oool0203oool3000000<0oooo0P000003
0?ooo`030820P0000000000000X0oooo0P0000090?ooo`040820P00000000000000001@0oooo0`00
00040?oooa7ooooo000@ooooool0ooooo`3ooolN0?ooo`l000002P3oool3000000<0oooo0`000003
0?ooo`<00000203oool3000000T0oooo00@0P8200000000000000000503oool3000000@0oooo4Ooo
ool0013oooooo`3ooooo0?ooob00oooo0P20P8000`10@400000000000008000000030820P03oool0
oooo00D0oooo00@0P8200000000000000000103oool3000000@0oooo0`0000000`20P800oooo0?oo
o`030?ooo`040820P00000000000000000T0oooo00D0`<3000000000000000000<30`00C0?ooo`@0
00000`3ooolAooooo`004?oooooo0?ooool0oooo9@3oool9000000L0oooo100000040?ooo`<00000
1@3oool4000000@0oooo1000000:0?ooo`<0000000<0P8200?ooo`3oool04P3oool3000000<0oooo
4Oooool0013oooooo`3ooooo0?ooobL0oooo200000060?ooo`<000001P3oool2000000D0oooo00@0
P8200000000000000000103oool3000000030820P03oool0oooo00P0oooo0`0000000`20P800oooo
0?ooo`0B0?ooo`<000000`3ooolAooooo`004?oooooo0?ooool0oooo:P3oool6000000@0oooo1000
00060?ooo`<00000103oool01@20P8000000000000000000P82000<0oooo0`0000000`20P800oooo
0?ooo`080?ooo`@00000503oool400000080oooo4Oooool0013oooooo`3ooooo0?ooob`0oooo00D0
`<300820P020P80000000<30`0030?ooo`@000001P3oool3000000D0oooo0`0000001010@400oooo
0?ooo`30`<03000000030820P03oool0oooo00T0oooo0`0000000`20P800oooo0?ooo`0A0?ooo`@0
00000P3ooolAooooo`004?oooooo0?ooool0oooo=03oool4000000H0oooo00<0P820000000000000
1@3oool400000080oooo00D0P82000000000000000000820P00;0?ooo`@000004`3oool400000080
oooo4Oooool0013oooooo`3ooooo0?ooocD0oooo100000050?ooo`030820P0000000000000D0oooo
100000020?ooo`050820P0000000000000000020P800303oool3000001<0oooo100000020?oooa7o
oooo000@ooooool0ooooo`3ooole0?ooo`@000001@3oool01020P800000000000020P8050?ooo`@0
000000<0oooo0820P00000000P0000000`20P800oooo0?ooo`0:0?ooo`@000004P3oool400000080
oooo4Oooool0013oooooo`3ooooo0?ooocD0oooo100000050?ooo`040820P00000000000000000D0
oooo100000000`3oool0P82000000002000000030820P03oool0oooo00X0oooo100000000`20P800
oooo0?ooo`0?0?ooo`@000000P3ooolAooooo`004?oooooo0?ooool0oooo=P3oool4000000D0oooo
0`0000050?ooo`@0000000<0oooo0820P00000000P0000000`20P800oooo0?ooo`0;0?ooo`@00000
4@3oool400000080oooo4Oooool0013oooooo`3ooooo0?ooocH0oooo100000050?ooo`<000001@3o
ool4000000030?ooo`20P80000000080000000<0P8200?ooo`3oool02`3oool3000000030820P03o
ool0oooo00l0oooo100000020?oooa7ooooo000@ooooool0ooooo`3ooolf0?ooo`050820P0000000
000000000030`<00103oool3000000D0oooo100000000`3oool0P82000000002000000030820P03o
ool0oooo00/0oooo00H0@410000000000000P82000000020P80?0?ooo`<0000000<0P8200?ooo`3o
ool04Oooool0013oooooo`3ooooo0?ooocL0oooo00@0P820000000000000P8201@3oool200000003
0820P03oool0oooo0080oooo0`0000020?ooo`050820P0000000000000000020P8003@3oool01P20
P800000000000020P800oooo000000h0oooo100000030?oooa7ooooo000@ooooool0ooooo`3ooolh
0?ooo`<000001@3oool2000000030820P03oool0oooo0080oooo0`0000030?ooo`<0000000<0P820
0?ooo`3oool02`3oool01@20P800000000000020P800oooo008000000`3oool2000000P0oooo1000
00030?oooa7ooooo000@ooooool0ooooo`3ooolh0?ooo`80P8200P0000001020P800oooo0?ooo`3o
ool2000000040820P03oool0oooo0?ooo`<0000000@0@4100?ooo`3oool0oooo0`0000000`10@400
oooo0?ooo`0;0?ooo`040820P0000000000000000080oooo00<0P8200410@020P800100000070?oo
o`<00000103ooolAooooo`004?oooooo0?ooool0oooo>P3oool01020P80000000000000000020?oo
o`80000000@0P8200?ooo`3oool0P8200`0000040?ooo`@000003@3oool01020P800000000000000
00030?ooo`030820P0000000000000<000001`3oool3000000@0oooo4Oooool0013oooooo`3ooooo
0?oooc`0oooo0`0000020?ooo`80000000<0oooo0000000000000P0000060?ooo`<000002@3oool0
0`20P800000000000006000000<0oooo1@0000060?ooo`<000001@3ooolAooooo`004?oooooo0?oo
ool0oooo?P3oool7000000030820P03oool0oooo00H0oooo0`00000=0?ooo`030820P00000000000
00800000103oool3000000L0oooo0`0000050?oooa7ooooo000@ooooool0ooooo`3ooom10?ooo`80
0000303oool2000000030820P03oool0oooo01`0oooo00@0`<30000000000000`<301@3ooolAoooo
o`004?oooooo0?ooool0oooo@P3oool00`000000oooo0?ooo`0:0?ooo`<000007P3oool00`20P800
0000000000060?oooa7ooooo000@ooooool0ooooo`3ooom20?ooo`030000003oool0oooo00/0oooo
0P00000N0?ooo`8000001`3ooolAooooo`004?oooooo0?ooool0oooo@P3oool2000000`0oooo0`00
000L0?ooo`800000203ooolAooooo`004?oooooo0?ooool0oooo@P3oool2000000`0oooo00@0`<30
000000000000`<306P3oool00`20P80000000<30`0080?oooa7ooooo000@ooooool0ooooo`3ooom2
0?ooo`030820P0000000oooo00`0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`8000002P3ooolA
ooooo`004?oooooo0?ooool0oooo@P3oool00`20P80000000?ooo`0=0?ooo`800000603oool00`20
P80000000?ooo`0:0?oooa7ooooo000@ooooool0ooooo`3ooom20?ooo`030820P0000000P82000h0
oooo00<0@41000000020P8005P3oool00`30`<00oooo0?ooo`0:0?oooa7ooooo000@ooooool0oooo
o`3ooomD0?ooo`<000008P3ooolAooooo`004?oooooo0?ooool0ooooE@3oool2000000030820P03o
ool0oooo01l0oooo4Oooool0013oooooo`3ooooo0?oooeH0oooo00<000000?ooo`3oool0803ooolA
ooooo`004?oooooo0?ooool0ooooN@3ooolAooooo`004?oooooo0?ooool0ooooN@3ooolAooooo`00
oooooooooooooi[ooooo003oooooooooooooV_ooool00?oooooooooooonJooooo`00oooooooooooo
oi[ooooo003oooooooooooooV_ooool00?oooooooooooonJooooo`00oooooooooooooi[ooooo003o
ooooooooooooV_ooool00?oooooooooooonJooooo`00oooooooooooooi[ooooo003ooooooooooooo
V_ooool00?oooooooooooonJooooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{221.5, 173.5},
  ImageMargins->{{0, 0}, {0, 0.75}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 4.9 geometry assumed for the multipole expansion of Eq. ",
  ButtonBox["(4.3.76)",
    ButtonData:>"(4.3.76)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Caption",
  CellTags->"Fig. 4.9"],

Cell[TextData[{
  StyleBox["(14)(a)",
    FontWeight->"Bold"],
  " The multipole moment ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_00\)]],
  "is called the monopole moment of the charge distribution. It is \
proportional to the total charge ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  ". The potential produced by the monopole moment is simply that given by \
Coulombs law, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = Q/4  \[Pi]\ \(\[Epsilon]\_o\) r\)]],
  "  . The moment ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(1\ m\)\)]],
  " is called a dipole moment, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(2\ m\)\)]],
  " is called a quadrupole moment. Plot contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, z)\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - z\)]],
  " plane, assuming that"
}], "Text"],

Cell[TextData[{
  "\t(i) only ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(1\ 0\)\)]],
  " is nonzero.  "
}], "Text"],

Cell[TextData[{
  "\t(ii) only ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(2\ 0\)\)]],
  " is nonzero."
}], "Text"],

Cell[TextData[{
  StyleBox["  (b)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(1\ 0\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(2\ 0\)\)]],
  " can be written in Cartesian coordinates as"
}], "Text"],

Cell[TextData[{
  "\t\t  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\_\(1\ 0\)\), "=", 
          RowBox[{\(\@\(3\/\(4\ \[Pi]\)\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{\(z\_o\), " ", 
                RowBox[{"\[Rho]", "(", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], 
                  ")"}], \(\[DifferentialD]\^3 r\_o\)}]}]}]}], 
        TraditionalForm]]],
  ",\n  \t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\_\(2\ 0\)\), "=", 
          RowBox[{\(\@\(5\/\(16\ \[Pi]\)\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{\((2  z\_o\^2 - x\_o\^2 - y\_o\^2)\), " ", 
                RowBox[{"\[Rho]", "(", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], 
                  ")"}], \(\[DifferentialD]\^3 r\_o\)}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["  (c)",
    FontWeight->"Bold"],
  " Evaluate the monopole, dipole, and quadrupole moments of two charges \
located on the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " axis; one at ",
  Cell[BoxData[
      \(TraditionalForm\`\(+z\_o\)\)]],
  " with charge ",
  Cell[BoxData[
      \(TraditionalForm\`\(+q\)\)]],
  " and one at ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\_o\)\)]],
  " with charge ",
  Cell[BoxData[
      \(TraditionalForm\`\(-q\)\)]],
  ". \nPlot the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](z)\)]],
  " along the z axis arising  from the dipole and quadrupole terms for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < z < 10\ z\_o\)]],
  ", and compare it to a plot of the exact potential ",
  Cell[BoxData[
      \(TraditionalForm\`q/\[Epsilon]\_o\ \((\(\(1\)\(/\)\) | 
            z - z\_o | \(\(-1\)\(/\)\) | z + z\_o | )\)\)]],
  ". Where does the multipole expansion work?",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A uniform density ellipsoid  of total  charge  ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  "  has a surface determined by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^2/a\^2 + y\^2/b\^2 + z\^2/c\^2 = 1\)]],
  ". Find the quadrupole moments of this charge distribution, and show that"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(\(2\)\(\ \)\(0\)\(\ \)\) = \(\@\(1\/\(80\ \
\[Pi]\)\)\) 
          Q\ \((2  c\^2 - a\^2 - 
              b\^2)\), \[IndentingNewLine]\[Rho]\_\(\(2\)\(\ \)\(1\)\(\ \)\) \
= 0, \[IndentingNewLine]\[Rho]\_\(2\ 2\)\  = \@\(3\/\(160\ \[Pi]\)\)\ Q\ \
\(\((a\^2 - b\^2)\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " A second form of multipole expansion is useful when we want to know the \
potential at a point near the origin due to  charge density that is \
concentrated far from the origin, ",
  StyleBox["outside",
    FontSlant->"Italic"],
  " an imaginary sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". (See Fig. ",
  ButtonBox["4.10",
    ButtonData:>"Fig. 4.10",
    ButtonStyle->"Hyperlink"],
  ") For such a charge density, use the Green's function to show that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[Phi]", "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], 
            "=", \(\[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \
\(-l\)\)\%l\( 1\/\(2\ l\  + \ 
                        1\)\) \(\[Rho]\&_\_\(l\ m\)\) \(\(\(Y\_\(l, \ 
                            m\)\)(\[Theta], \[Phi])\)\/\(\(\[Epsilon]\_o\)\(\ \
\)\)\) r\^l\)\)}], ","}], TraditionalForm]]],
  " provided that ",
  Cell[BoxData[
      \(TraditionalForm\`r < R\)]],
  ","
}], "NE4",
  CellTags->{"i:83", "(4.3.77)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho]\&_\_\(l\ m\)\), "=", 
          RowBox[{"\[Integral]", 
            RowBox[{\(\[DifferentialD]\^3 r\_o\), 
              RowBox[{"\[Rho]", "(", 
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ")"}], 
              " ", \(\(\(Y\_\(l, \ 
                      m\)\%\(\(\ \)\(*\)\)\)(\[Theta]\_o, \[Phi]\_o)\)/
                r\_o\%\(\(\ \)\(l + 1\)\)\)}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;@0002:R000`400?l00000o`00003ooooooooo
ooooom;ooooo003oooooooooooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;ooooo
003oooooooooooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;ooooo003ooooooooo
ooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;ooooo003oooooooooooood_ooool0
0?oooooooooooooBooooo`00ooooooooooooom;ooooo003oooooooooooood_ooool0017oooooo`3o
oooo0?ooojl0oooo4_ooool0017ooooo^P3oool900000100oooo2P00003o0?ooom40oooo4_ooool0
017ooooo^P3oool900000100oooo2P00003o0?ooom40oooo4_ooool0017oooooY`3oool300000100
oooo2@00000@0?ooo`T00000403oool00`20P80000000000000200000?l0oooo_@3ooolBooooo`00
4OoooonP0?ooo`040<30`020P800P8200410@0H00000@P3oool00`10@40000000000000600000003
0820P03oool0oooo0?l0oooo]P3ooolBooooo`004OoooonP0?ooo`030820P0000000000000L00000
@P3oool:00000?l0oooo^03ooolBooooo`004OoooonQ0?ooo`H00000B@3oool00`20P80000000000
000200000?l0oooo^@3ooolBooooo`004OoooonQ0?ooo`<0P820D03oool00`20P800oooo0?ooo`3o
0?oookL0oooo4_ooool0017oooooo`3oool60?ooo`<0000000<0P8200?ooo`3oool0o`3ooonS0?oo
oa;ooooo000Aoooooi00oooo00<000000820P03oool0LP3oool3000000030820P03oool0oooo0?l0
ooooX`3ooolBooooo`004Ooooon;0?ooo`030<30`020P800P82000@00000LP3oool7000000030410
@020P800P8200?l0ooooX03ooolBooooo`004Ooooon80?ooo`030820P0000000000000L00000M03o
ool800000?l0ooooX03ooolBooooo`004Ooooon90?ooo`H00000NP3oool500000?l0ooooX03ooolB
ooooo`004Ooooon90?ooo`030820P0000000@4100080P820O@3oool00`30`<00P8200?ooo`3o0?oo
oj00oooo4_ooool0017oooooo`3ooooo0?ooojl0oooo4_ooool0017oooooo`3ooooo0?ooojl0oooo
4_ooool0017oooooo`3ooooo0?ooojl0oooo4_ooool0017oooooo`3ooolN0?ooo`030000003oool0
oooo0?l0ooooSP3ooolBooooo`004Ooooomh0?ooo`030820P0000000oooo0:40oooo1000003o0?oo
ohh0oooo4_ooool0017oooooM@3oool00`20P80000000000000300000:00oooo0P20P80500000080
P820o`3ooon:0?oooa;ooooo000Aooooog<0oooo1P00002U0?ooo`L00000o`3ooon90?oooa;ooooo
000Aooooog40oooo1`00002X0?ooo`D00000o`3ooon90?oooa;ooooo000Aooooog80oooo0`000000
0`10@400P8200?ooo`2X0?ooo`050<30`020P800000000000020P800o`3ooon90?oooa;ooooo000A
ooooog80oooo00<0P8200000003oool0o`3ooooo0?ooocX0oooo4_ooool0017oooooo`3ooooo0?oo
ojl0oooo4_ooool0017oooooo`3ooooo0?ooojl0oooo4_ooool0017oooooo`3ooooo0?ooojl0oooo
4_ooool0017oooooo`3ooooo0?ooojl0oooo4_ooool0017oooooo`3ooold0?ooo`030<30`03oool0
oooo0?l0ooooN03ooolBooooo`004OoooomS0?ooo`030000003oool0oooo0<d0oooo0`00003o0?oo
ogP0oooo4_ooool0017oooooH@3oool300000<l0oooo0`0000000`20P800oooo0?ooo`3o0?ooogD0
oooo4_ooool0017oooooG`3oool00`20P80000000000000300000<d0oooo00<0P8200410@0000000
0`0000000`20P800oooo0?ooo`3o0?ooog<0oooo4_ooool0017oooooG@3oool00`20P80000000000
0003000000030820P03oool0oooo0<h0oooo1P00003o0?ooog@0oooo4_ooool0017oooooG@3oool6
00000=<0oooo1@00003o0?ooog<0oooo4_ooool0017oooooF`3oool600000=H0oooo1000003o0?oo
og<0oooo4_ooool0017oooooG03oool01020P800000000000020P82F0?ooo`040<30`020P800P820
0<30`3h0oooo0P20P83o0?ooog@0oooo4_ooool0017ooooomP3oool01020P800000000000020P80F
0?ooo`030000003oool0oooo0?l0ooooV`3ooolBooooo`004Oooooof0?ooo`040820P00000000000
0820P1D0oooo0P0000000`20P800oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooQP3ooolB
ooooo`004Oooooof0?ooo`040820P000000000000820P1@0oooo00<0@41000000020P8005@3oool0
0`20P800@4100?ooo`3o0?ooohD0oooo4_ooool0017ooooom`3oool3000001<0oooo0P00000H0?oo
o`030820P0000000oooo0?l0ooooQ03ooolBooooo`004Oooooog0?ooo`<000004P3oool200000003
0820P03oool0oooo01L0oooo0P00003o0?oooh@0oooo4_ooool0017ooooom`3oool300000140oooo
00<0P8200000000000006`3oool00`000000@4100?ooo`3o0?oooh80oooo4_ooool0017ooooom`3o
ool300000140oooo0P00000M0?ooo`800000o`3ooon20?oooa;ooooo000AooooooP0oooo0`00000?
0?ooo`<000007@3oool3000001/0oooo00<000000?ooo`3oool0o`3ooomS0?oooa;ooooo000Aoooo
odd0oooo00<0@41000000020P800YP3oool20820P0<000000P20P80<0?ooo`030820P00000000000
00P0oooo0`20P80C0?ooo`040820P000000000000<30`1P0oooo00H0P82000000000000000000820
P030`<3o0?ooof80oooo4_ooool0017oooooB`3oool500000:@0oooo0`0000001P3oool000000000
00000000oooo0820P080000000<0P8200?ooo`3oool01`3oool3000000P0oooo0`0000000`20P800
oooo0?ooo`0@0?ooo`040820P000000000000820P1T0oooo1@00003o0?ooof80oooo4_ooool0017o
ooooBP3oool00`20P80000000000000400000:80oooo0`0000030?ooo`8000000`3oool2000000T0
oooo0P0000000`20P800oooo0?ooo`060?ooo`040820P000000000000820P1<0oooo0`00000J0?oo
o`H00000o`3ooomP0?oooa;ooooo000AooooodX0oooo00<0@4100000000000000P0000000`20P800
oooo0?ooo`2P0?ooo`040820P000000000000820P0<0oooo0`0000030?ooo`040410@00000000000
0<30`0D0oooo00@0P820000000000000P820203oool01020P800000000000020P80C0?ooo`<00000
00<0P8200?ooo`3oool0603oool00`20P800000000000002000000030<30`03oool0oooo0?l0oooo
G@3ooolBooooo`004Ooooom90?ooo`@0000000<0P8200?ooo`3oool0X@3oool4000000@0oooo0`00
00030?ooo`040820P00000000000000000D0oooo0`0000000`20P800oooo0?ooo`070?ooo`<00000
4`3oool4000001`0oooo1000003o0?oooel0oooo4_ooool0017oooooA`3oool00`20P80000000000
000300000:@0oooo100000040?ooo`<00000103oool4000000@0oooo0`0000000`20P800oooo0?oo
o`070?ooo`<00000503oool3000001`0oooo00@0P8200000000000000000o`3ooomO0?oooa;ooooo
000AooooodP0oooo0`0000000`20P800oooo0?ooo`2R0?ooo`040<30`00000000000000000D0oooo
00@0P820000000000000`<30103oool3000000040820P03oool0oooo0?ooo`<000002P3oool30000
00030820P03oool0oooo0140oooo0`0000000`20P800oooo0?ooo`0K0?ooo`030820P030`<00oooo
0?l0ooooGP3ooolBooooo`004Ooooom90?ooo`030000003oool0oooo0:@0oooo00@0P82000000000
000000001@3oool01020P800000000000020P8050?ooo`<000000`3oool3000000/0oooo0`00000C
0?ooo`@00000o`3ooomn0?oooa;ooooo000Aoooooo00oooo00@0P82000000000000000001@3oool0
1020P800000000000020P8050?ooo`<0000000<0P8200?ooo`0000000`00000;0?ooo`@000004P3o
ool400000?l0ooooOP3ooolBooooo`004Oooooo`0?ooo`050<30`0000000000000000020P8001@3o
ool2000000030820P03oool0oooo00<0oooo0`0000000`20P800oooo00000003000000/0oooo00@0
P82000000000000000004P3oool400000?l0ooooOP3ooolBooooo`004Ooooooa0?ooo`@000001@3o
ool2000000030820P03oool0oooo00<0oooo00D0P82000000000000000000?ooo`04000000`0oooo
0`0000000`20P800oooo0?ooo`0?0?ooo`@00000o`3ooomn0?oooa;ooooo000Aoooooo40oooo1000
00050?ooo`<000001@3oool01@20P8000000000000000000oooo00@00000303oool3000000030820
P03oool0oooo00l0oooo1000003o0?ooogh0oooo4_ooool0017oooool@3oool01@20P80000000000
00000000P82000@0oooo00<0P8200000000000001@3oool01@20P8000000000000000000oooo00@0
0000303oool01@10@4000000000000000000P8200100oooo1000003o0?ooogh0oooo4_ooool0017o
oooolP3oool4000000D0oooo0P0000050?ooo`050820P000000000000000003oool01000000<0?oo
o`050820P000000000000820P0000000403oool400000?l0ooooOP3ooolBooooo`004Oooooob0?oo
o`@000001@3oool2000000D0oooo00D0P82000000000000000000?ooo`04000000`0oooo00@0P820
000000000000P8200P00000?0?ooo`@00000o`3ooomn0?oooa;ooooo000Aoooooo<0oooo00@0@410
000000000000P820103oool00`20P80000000820P0040?ooo`050820P000000000000410@03oool0
1000000=0?ooo`<0000000<0oooo0820P020P8003@3oool01020P800000000000000000/0?ooo`03
0820P03oool0oooo0?l0ooooD03ooolBooooo`004Ooooood0?ooo`<000001@3oool2000000@0oooo
00@0P820000000000000P8200P3oool3000000d0oooo0`0000020?ooo`040000003oool0oooo0?oo
o`<000001`3oool4000002/0oooo0`00003o0?oooe40oooo4_ooool0017ooooo>`3oool200000;L0
oooo100000040?ooo`800000103oool3000000030820P03oool0oooo00<000003@3oool400000005
0?ooo`20P80000000?ooo`20P8000`0000000`20P800oooo0?ooo`040?ooo`<00000:`3oool50000
0?l0ooooD03ooolBooooo`004Oooooli0?ooo`050820P0000000000000000020P800^03oool01010
@400000000000030`<020?ooo`8000000`3oool01020P800000000000020P8030?ooo`<0000000<0
P8200?ooo`3oool02P3oool400000080oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`040?ooo`<00000;03oool01@20P8000000000000000000@4100?l0ooooC`3ooolBooooo`004Ooo
ooli0?ooo`<00000_03oool3000000050?ooo`20P800000000000020P8000`0000050?ooo`040820
P000000000000820P0P0oooo00<0P8200000000000001P0000030?ooo`@0000000<0P8200?ooo`3o
ool00`3oool01020P800000000000020P80]0?ooo`040820P0000000000000000?l0ooooC`3ooolB
ooooo`004Ooooolh0?ooo`040820P0000000000000000;d0oooo00<0P8200000000000001@000007
0?ooo`040820P000000000000820P0`0oooo1@0000030?ooo`040820P00000000000000000H0oooo
00@0P820000000000000P820;P3oool400000?l0ooooCP3ooolBooooo`004Ooooolg0?ooo`050820
P0000000000000000030`<00`03oool00`20P80000000000000:0?ooo`80000000<0@4100?ooo`3o
ool0703oool00`10@40000000820P00`0?ooo`@0000000<0`<300?ooo`3oool0o`3ooom:0?oooa;o
oooo000AooooocH0oooo100000330?ooo`8000002P3oool3000001h0oooo0P00000b0?ooo`<00000
o`3ooom=0?oooa;ooooo000AooooocD0oooo00@0P8200000000000000000a03oool2000000/0oooo
0P00000M0?ooo`800000<`3oool00`20P80000000?ooo`3o0?ooodd0oooo4_ooool0017ooooo=P3o
ool00`20P80000000410@0340?ooo`80000000<0P8200?ooo`3oool0203oool00`20P80000000000
000K0?ooo`80000000<0`<300?ooo`3oool0o`3ooon10?oooa;ooooo000Aooooood0oooo0P000000
0`20P800oooo0?ooo`090?ooo`030820P0000000000001T0oooo00<0P8200000003oool0o`3ooon4
0?oooa;ooooo000Aooooooh0oooo00<000000820P03oool02P3oool00`20P80000000000000I0?oo
o`030000003oool0oooo0?l0ooooQ03ooolBooooo`004Oooooon0?ooo`0300000020P800oooo00/0
oooo00<0P82000000010@4005P3oool20820P0030<30`03oool0oooo0?l0ooooQ03ooolBooooo`00
4Oooooon0?ooo`8000003P3oool200000?l0ooooWP3ooolBooooo`004Ooooooo0?ooo`l0oooo00<0
P820000000000000o`3ooonM0?oooa;ooooo000Aooooool0oooo403oool00`20P80000000<30`03o
0?oooi`0oooo4_ooool0017oooooo`3ooooo0?ooojl0oooo4_ooool0017oooooo`3ooooo0?ooojl0
oooo4_ooool0017oooooo`3oool90?ooo`030410@03oool0oooo0?l0ooooX`3ooolBooooo`004Ooo
oooo0?ooo`T0oooo00<000000?ooo`3oool0H03oool200000?l0oooo@@3ooolBooooo`004Ooooooo
0?ooo`P0oooo0P00001Q0?ooo`<0000000<0P8200?ooo`3oool0o`3oooln0?oooa;ooooo000Aoooo
obX0oooo0P0000000`10@400P8200?ooo`3F0?ooo`040<30`000000000000410@640oooo00@0P820
000000000000@410o`3ooom00?oooa;ooooo000AooooobT0oooo00@0P8200000000000000000f03o
ool3000000030820P03oool0oooo0600oooo1000003o0?ooocl0oooo4_ooool0017ooooo:@3oool3
000000030820P03oool0oooo0=@0oooo1@0000000`20P800oooo0?ooo`1Q0?ooo`@00000o`3oooln
0?oooa;ooooo000AooooobP0oooo00D0P82000000000000000000<30`03E0?ooo`030410@0000000
000000<0000000<0P8200?ooo`3oool0HP3oool3000000030820P03oool0oooo0?l0oooo>`3ooolB
ooooo`004OoooolW0?ooo`@00000eP3oool7000000030820P03oool0oooo0680oooo00@0P8200000
000000000000o`3ooolm0?oooa;ooooo000AooooobH0oooo00@0P8200000000000000000e`3oool7
000000030820P03oool0oooo06<0oooo1000003o0?oooc`0oooo4_ooool0017ooooo9P3oool01010
@400000000000020P83E0?ooo`030<30`0000000000000H0000000<0P8200?ooo`3oool0H`3oool2
0820P0030<30`03oool0oooo0?l0oooo>`3ooolBooooo`004OoooolW0?ooo`800000eP3oool90000
0?l0ooooYP3ooolBooooo`004Oooooon0?ooo`X00000o`3ooonV0?oooa;ooooo000Aoooooo`0oooo
00<0`<300000000000002@00003o0?ooojH0oooo4_ooool0017oooooo03oool<00000?l0ooooYP3o
oolBooooo`004Ooooook0?ooo`d00000o`3ooonV0?oooa;ooooo000AooooooT0oooo00<0`<300000
000000003000003o0?ooojH0oooo4_ooool0017ooooon@3oool?00000?l0ooooYP3ooolBooooo`00
4Ooooooh0?oooa000000o`3ooonV0?oooa;ooooo000AooooooH0oooo00<0@4100000000000003P00
003o0?ooojL0oooo4_ooool0017ooooom@3ooolB00000?l0ooooY`3ooolBooooo`004Ooooood0?oo
oa<00000o`3ooonW0?oooa;ooooo000Aoooooo<0oooo00<0P8200000000000004@00003o0?ooojL0
oooo4_ooool0017ooooolP3oool00`20P80000000000000B00000780oooo00<0`<300820P03oool0
o`3ooolb0?oooa;ooooo000Aoooooo40oooo5P00001a0?ooo`<00000o`3ooolc0?oooa;ooooo000A
oooooa`0oooo0P00003C0?oooaH00000LP3oool300000?l0oooo<P3ooolBooooo`004OoooolK0?oo
o`030820P0000000000000800000d03oool00`10@40000000000000C000000030820P03oool0oooo
0700oooo00@0@410000000000000@410o`3ooola0?oooa;ooooo000Aoooooa/0oooo1000003A0?oo
o`030820P0000000000001<00000L`3oool01020P800000000000000003o0?oooc40oooo4_ooool0
017ooooo6P3oool400000=<0oooo5@00001d0?ooo`@00000o`3oool`0?oooa;ooooo000AoooooaT0
oooo00D0P82000000000000000000410@03D0?ooo`030820P0000000000001400000M@3oool40000
0?l0oooo;`3ooolBooooo`004OoooolI0?ooo`@0000000<0P8200?ooo`3oool0d`3oool00`20P800
00000000000@000007H0oooo0`0000000`20P800oooo0?ooo`3o0?ooob`0oooo4_ooool0017ooooo
6@3oool400000=P0oooo4@00001f0?ooo`800000o`3oool`0?oooa;ooooo000AoooooaP0oooo00D0
P82000000000000000000820P03I0?ooo`030410@0000000000000d00000o`3ooonX0?oooa;ooooo
000AooooooP0oooo3P00003o0?ooojP0oooo4_ooool0017ooooom`3oool>000000030820P03oool0
oooo0?l0ooooYP3ooolBooooo`004Oooooof0?ooo`070<30`0000000000000000020P800oooo0820
P008000000030820P03oool0oooo0?l0ooooYP3ooolBooooo`004Oooooof0?ooo`040820P0000000
0000000000L0oooo100000000`20P800oooo0?ooo`3o0?ooojH0oooo4_ooool0017ooooomP3oool3
000000030820P03oool0oooo00L0oooo0P0000000`20P800oooo0?ooo`3o0?ooojH0oooo4_ooool0
017ooooom@3oool01@20P8000000000000000000`<300?l0oooo]03ooolBooooo`004Ooooooe0?oo
o`@00000o`3ooone0?oooa;ooooo000AooooooD0oooo0`00003o0?oookH0oooo4_ooool0017ooooo
m03oool400000?l0oooo]P3ooolBooooo`004Ooooooc0?ooo`040820P0000000000000000?l0oooo
]`3ooolBooooo`004Ooooooc0?ooo`040820P0000000000000000?l0oooo]`3ooolBooooo`004Ooo
oooc0?ooo`<0000000<0P8200?ooo`3oool0o`3ooone0?oooa;ooooo000Aoooooll0oooo0`00000P
0?ooo`@00000S`3oool00`000000oooo0?ooo`3o0?ooobH0oooo4_ooool0017oooooc`3oool40000
01l0oooo1000002=0?ooo`@00000o`3ooolW0?oooa;ooooo000Aoooooa00oooo00@0`<3000000000
0000P820_03oool3000001h0oooo1000002?0?ooo`<0000000<0P8200?ooo`3oool0o`3ooolT0?oo
oa;ooooo000Aoooooa00oooo1000002l0?ooo`<000007@3oool01020P800000000000000002A0?oo
o`<00000o`3ooolV0?oooa;ooooo000Aoooooa00oooo0`0000000`20P800oooo0?ooo`2k0?ooo`<0
0000703oool01020P800000000000000002A0?ooo`<00000o`3ooolV0?oooa;ooooo000Aooooo`l0
oooo1000002n0?ooo`<00000703oool3000000030820P03oool0oooo08l0oooo00@0@41000000000
0000P820o`3ooolU0?oooa;ooooo000Aooooo`l0oooo0`00002o0?ooo`<0000000<0P8200?ooo`3o
ool0603oool400000980oooo00@0P8200000000000000000o`3ooolU0?oooa;ooooo000Aooooo`h0
oooo1000002o0?ooo`040820P000000000000820P1X0oooo1000002C0?ooo`<00000o`3ooolU0?oo
oa;ooooo000Aooooo`h0oooo0`0000000`20P800oooo0?ooo`2m0?ooo`040820P000000000000000
01T0oooo1000002D0?ooo`040820P0000000000000000?l0oooo903ooolBooooo`004Oooool=0?oo
o`040820P0000000000000000<40oooo0`00000H0?ooo`@00000o`3ooonm0?oooa;ooooo000Aoooo
o`d0oooo00@0P8200000000000000000`@3oool4000001L0oooo1000003o0?oookd0oooo4_ooool0
017ooooo3`3oool00`20P800`<300?ooo`300?ooo`@0000000<0P8200?ooo`3oool04`3oool01@30
`<000000000000000000P8200?l0oooo_@3ooolBooooo`004OoooooC0?ooo`@0000000<0P8200?oo
o`3oool04P3oool01@20P8000000000000000000P8200?l0oooo_@3ooolBooooo`004OoooooC0?oo
o`<0000000<0oooo0820P03oool04`3oool400000?l0oooo_P3ooolBooooo`004OoooooC0?ooo`06
0820P000000000000820P010@400P8204P3oool01@20P8000000000000000000P8200?l0oooo_P3o
oolBooooo`004OoooooD0?ooo`<0000000<0oooo0000003oool04@3oool400000?l0oooo_`3ooolB
ooooo`004OoooooD0?ooo`<0000000<0oooo0000000000000`3oool2000000/0oooo1000003o0?oo
ol00oooo4_ooool0017oooooe03oool3000000050820P03oool0P8200410@020P800100000090?oo
o`050<30`0000000000000000020P800o`3oooo00?oooa;ooooo000Aooooom@0oooo0`0000001020
P800oooo0?ooo`20P805000000T0oooo00@0P8200000000000000000o`3oooo10?oooa;ooooo000A
ooooom00oooo200000030?ooo`D000002@3oool3000000030820P03oool0oooo0?l0oooo_`3ooolB
ooooo`004OoooooD0?ooo`@0P820103oool30820P0T0oooo00D0P82000000000000000000<30`03o
0?oool40oooo4_ooool0017oooooj03oool400000?l0oooo`P3ooolBooooo`004OoooooW0?ooo`@0
0000o`3oooo30?oooa;ooooo000AooooonH0oooo00D0`<3000000000000000000820P03o0?oool<0
oooo4_ooool0017oooooiP3oool01020P800000000000000002R0?ooo`040820P000000000000820
P?l0oooo7P3ooolBooooo`004OoooooV0?ooo`<0000000<0P8200?ooo`3oool0X03oool01020P800
000000000000003o0?oooah0oooo4_ooool0017ooooo203oool300000=X0oooo00D0P82000000000
000000000<30`02S0?ooo`<00000o`3ooolN0?oooa;ooooo000Aooooo`L0oooo00@0P82000000000
00000000fP3oool400000:@0oooo0`00003o0?oooah0oooo4_ooool0017ooooo1`3oool01020P800
000000000020P83J0?ooo`<00000Y@3oool400000?l0oooo7@3ooolBooooo`004Oooool70?ooo`04
0820P000000000000820P=T0oooo1000002V0?ooo`<00000o`3ooolM0?oooa;ooooo000Aooooo`L0
oooo0`0000000`20P800oooo0?ooo`3F0?ooo`040820P0000000000000000:L0oooo0`00003o0?oo
oad0oooo4_ooool0017ooooo1`3oool300000=T0oooo00@0P8200000000000000000Y`3oool40000
0?l0oooo703ooolBooooo`004Oooool70?ooo`<00000f@3oool3000000030820P03oool0oooo0:H0
oooo0`00003o0?oooa`0oooo4_ooool0017ooooo1P3oool400000=P0oooo1000003o0?ooolP0oooo
4_ooool0017ooooo1P3oool300000=T0oooo1000003o0?ooolP0oooo4_ooool0017oooooh@3oool4
00000?l0oooob@3ooolBooooo`004OoooooP0?ooo`040820P0000000000000000?l0oooobP3ooolB
ooooo`004OoooooP0?ooo`040820P0000000000000000?l0oooobP3ooolBooooo`004OoooooP0?oo
o`<0000000<0P8200?ooo`3oool0o`3oooo80?oooa;ooooo000Aoooooml0oooo1000003o0?oool/0
oooo4_ooool0017ooooog`3oool400000?l0oooob`3ooolBooooo`004OoooooN0?ooo`@00000o`3o
ooo<0?oooa;ooooo000Aooooomd0oooo00@0P8200000000000000000o`3oooo=0?oooa;ooooo000A
ooooomd0oooo00@0P8200000000000000000o`3oooo=0?oooa;ooooo000Aooooomd0oooo0`000000
0`20P800oooo0?ooo`3o0?oool/0oooo4_ooool0017ooooog@3oool3000000030<30`03oool0oooo
0?l0oooob`3ooolBooooo`004OoooooL0?ooo`@00000o`3oooo>0?oooa;ooooo000Aooooom`0oooo
1000003o0?ooolh0oooo4_ooool0017ooooof`3oool400000;<0oooo0`20P8000`30`<00oooo0?oo
o`3o0?oooaH0oooo4_ooool0017ooooofP3oool01020P800000000000000002d0?ooo`<0000000<0
P8200?ooo`3oool0o`3ooolF0?oooa;ooooo000AooooomX0oooo00@0P8200000000000000000]03o
ool3000000030820P03oool0oooo0?l0oooo5P3ooolBooooo`004Oooool30?ooo`<00000e03oool3
000000030820P03oool0oooo0;80oooo00@0P820000000000000P820o`3ooolH0?oooa;ooooo000A
ooooo`<0oooo0`00003C0?ooo`@00000]@3oool01020P800000000000020P83o0?oooaP0oooo4_oo
ool0017ooooo0P3oool300000=@0oooo1000002e0?ooo`040820P0000000000000000?l0oooo603o
oolBooooo`004Oooool20?ooo`<00000d`3oool400000;H0oooo00@0P8200000000000000000o`3o
oolH0?oooa;ooooo000Aooooo`80oooo0`00003B0?ooo`040820P0000000000000000;P0oooo0`00
003o0?oooaP0oooo4_ooool0017ooooo0P3oool300000=80oooo00@0P8200000000000000000^03o
ool300000?l0oooo603ooolBooooo`004Oooool00`3oool0`<300000000200000=80oooo0`000000
0`20P800oooo0?ooo`2f0?ooo`<00000o`3ooolH0?oooa;ooooo000Aooooo`050?ooo`20P8000000
00000020P800d@3oool400000?l0ooooe03ooolBooooo`004Oooool01@3oool0P820000000000000
P8200=40oooo1000003o0?ooom@0oooo4_ooool0017oooooe@3oool4000000h0oooo1P20P83o0?oo
ol40oooo4_ooool0017oooooe03oool01020P800000000000000000=0?ooo`/00000o`3ooonn0?oo
oa;ooooo000Aooooom@0oooo00@0P82000000000000000002`3oool00`20P8000000000000020000
00@0oooo00<0P8200000000000000P00003o0?oookd0oooo4_ooool0017oooooe03oool01010@400
000000000020P80:0?ooo`050820P0000000000000000030`<00203oool01@20P800000000000000
0000`<300?l0oooo^P3ooolBooooo`004OoooooD0?ooo`<0000000<0P8200?ooo`3oool01`3oool4
000000/0oooo00<0P8200000000000000P00003o0?oookT0oooo4_ooool0017oooood`3oool40000
00X0oooo1000000<0?ooo`D00000o`3ooonh0?oooa;ooooo000Aooooom80oooo00D0P82000000000
000000000820P0090?ooo`050820P0000000000000000020P8003@3oool01@20P800000000000000
0000@4100?l0oooo]`3ooolBooooo`004OoooooB0?ooo`@000002P3oool01020P800000000000000
000?0?ooo`030820P0000000000000800000o`3ooonf0?oooa;ooooo000Aooooom40oooo00@0P820
00000000000000002`3oool4000000l0oooo00<0P8200000000000000P00003o0?oookH0oooo4_oo
ool0017oooood@3oool01010@400000000000010@40;0?ooo`@00000403oool5000000030<30`03o
ool0oooo0?l0oooo/P3ooolBooooo`004OoooooA0?ooo`<0000000<0P8200?ooo`3oool02@3oool4
00000140oooo100000000`20P800oooo0?ooo`3o0?oook80oooo4_ooool0017oooood03oool40000
00`0oooo1000000A0?ooo`D00000o`3ooond0?oooa;ooooo000Aoooooll0oooo00D0P82000000000
000000000820P00<0?ooo`@000004P3oool4000000030820P03oool0oooo0?l0oooo/@3ooolBoooo
o`004Oooooo?0?ooo`@000003@3oool500000140oooo00<0P8200000000000000P00003o0?oook<0
oooo4_ooool0017ooooocP3oool01020P800000000000000000>0?ooo`D000004@3oool00`20P800
000000000003000009T0oooo0`00003o0?oooaH0oooo4_ooool0017ooooo00@0oooo0820P020P800
P820bP3oool01010@400000000000010@40>0?ooo`030820P00000000000008000004@3oool00`30
`<00000000000003000009T0oooo0`00003o0?oooaH0oooo4_ooool0017ooooo00@0oooo00000000
00000000bP3oool3000000030820P03oool0oooo00`0oooo00<0P8200000000000000`00000A0?oo
o`D00000V@3oool300000?l0oooo5P3ooolBooooo`004Oooool0103oool000000000000000390?oo
o`@000003`3oool00`20P80000000000000300000140oooo1@0000000`20P800oooo0?ooo`2F0?oo
o`<00000o`3ooolF0?oooa;ooooo000Aooooo`040?ooo`000000000000000<P0oooo00D0P8200000
0000000000000820P00@0?ooo`D0000000<0`<300?ooo`3oool03P3oool00`20P800000000000002
000000030820P03oool0oooo09H0oooo00@0P820000000000000P820o`3ooolE0?oooa;ooooo000A
ooooo`<00000b@3oool400000180oooo100000000`20P800oooo0?ooo`0?0?ooo`@0000000<0P820
0?ooo`3oool0UP3oool01020P800000000000020P83o0?oooaD0oooo4_ooool0017ooooo0`000038
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool03P3oool500000140oooo1000
00000`20P800oooo0?ooo`2F0?ooo`040820P000000000000820P?l0oooo5@3ooolBooooo`004Ooo
ool300000<D0oooo00D0`<3000000000000000000820P0030?ooo`050820P0000000000000000030
`<003P3oool01@10@4000000000000000000P8200100oooo100000000`20P800oooo0?ooo`2F0?oo
o`040820P000000000000820P?l0oooo5@3ooolBooooo`004Oooool300000<@0oooo1@0000030?oo
o`H000003P3oool00`20P80000000000000200000100oooo100000000`20P800oooo0?ooo`2F0?oo
o`040820P000000000000820P?l0oooo5@3ooolBooooo`004Oooool300000<<0oooo1@0000050?oo
o`L000003@3oool5000000l0oooo100000000`20P800oooo0?ooo`3o0?ooojl0oooo4_ooool0017o
oooo0`20P8310?ooo`060820P0000000000000000010@400P8201`3oool00`30`<00000000000003
000000030410@03oool0oooo00/0oooo00D0P82000000000000000000<30`00>0?ooo`@00000o`3o
oonb0?oooa;ooooo000Aoooool80oooo00<0P8200000000000000`00000;0?ooo`L00000303oool0
1020P800000000000000000=0?ooo`D00000o`3ooonb0?oooa;ooooo000Aoooool80oooo1000000>
0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool02P3oool4000000`0oooo1000003o
0?oook<0oooo4_ooool0017ooooo_`3oool00`30`<00P82000000002000000030820P030`<00oooo
00h0oooo00<0P8200000000000000`0000020820P0/0oooo00D0P82000000000000000000<30`009
0?ooo`040<30`000000000000410@?l0oooo]03ooolBooooo`004Ooooono0?ooo`@00000503oool0
0`20P800000000000003000000030820P03oool0oooo00T0oooo00@0P82000000000000000002@3o
ool3000000030820P03oool0oooo0?l0oooo/P3ooolBooooo`004Ooooonm0?ooo`D0000000<0P820
0?ooo`3oool04`3oool6000000d0oooo1@0000040?ooo`@00000W@3oool300000?l0oooo5P3ooolB
ooooo`004Ooooonk0?ooo`030820P010@40000000080000000<0P8200?ooo`3oool05P3oool00`20
P800@41000000004000000030<30`03oool0oooo00T0oooo00<0`<300820P020P8001P0000020820
P9h0oooo0`00003o0?oooaH0oooo4_ooool0017ooooo^P3oool5000001`0oooo1P00002d0?ooo`<0
0000o`3ooolF0?oooa;ooooo000AoooookT0oooo1@00000N0?ooo`L00000/P3oool300000?l0oooo
5P3ooolBooooo`004Ooooonf0?ooo`80P820100000000`30`<00oooo0?ooo`0N0?ooo`030<30`000
0000000000<0000000<0@4100?ooo`3oool0[`3oool300000?l0oooo5P3ooolBooooo`004Ooooone
0?ooo`030820P0000000000000<00000903oool700000:l0oooo0`00003o0?oooaH0oooo4_ooool0
017ooooo]@3oool4000000030820P03oool0oooo02@0oooo00<0P8200000000000000`0000000`20
P800oooo0?ooo`2/0?ooo`<00000o`3ooolF0?oooa;ooooo000Aoooook80oooo00<0`<3000000000
00000P0000020820P2P0oooo00<0P8200000000000000`0000020820P:`0oooo0`00003o0?oooaH0
oooo4_ooool0017ooooo/@3oool5000002d0oooo00<0P8200000000000000`0000000`20P800oooo
0?ooo`2Y0?ooo`<00000o`3ooolF0?oooa;ooooo000Aoooook00oooo1@00000_0?ooo`H00000o`3o
ooo40?oooa;ooooo000Aooooojh0oooo00H0P82000000000000000000410@020P80a0?ooo`030820
P010@400000000@0000000<0`<300?ooo`3oool0o`3ooono0?oooa;ooooo000Aooooo`040?ooo`00
0000000000000:P0oooo00<0P8200000000000000`00000e0?ooo`H00000o`3oooo10?oooa;ooooo
000Aooooo`050?ooo`000000000000000020P800Y`3oool5000003L0oooo1`00003o0?oookl0oooo
4_ooool0017ooooo00D0oooo00000000000000000820P02T0?ooo`030<30`020P800000000<00000
00<0`<300?ooo`3oool0=`3oool00`30`<00000000000004000000030<30`03oool0oooo0?l0oooo
^`3ooolBooooo`004Oooool01@3oool00000000000000000P8200:@0oooo1000000n0?ooo`L00000
o`3ooonl0?oooa;ooooo000Aooooo`050?ooo`000000000000000020P800XP3oool5000000030820
P03oool0oooo03d0oooo00<0P8200000000000001000003o0?oook/0oooo4_ooool0017ooooo00D0
oooo0820P000000000000410@02P0?ooo`030820P010@40000000080000000<0P8200?ooo`3oool0
@03oool00`20P800000000000003000000030410@020P800oooo0?l0oooo^03ooolBooooo`004Ooo
ool00`3oool0P82000000002000009l0oooo1@0000000`20P800oooo0?ooo`140?ooo`H00000o`3o
oonh0?oooa;ooooo000Aooooo`030?ooo`20P800000000800000WP3oool5000004P0oooo00<0P820
0000000000000`0000000`20P800oooo0?ooo`3o0?oookD0oooo4_ooool0017ooooo0P3oool30000
09`0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`180?ooo`80P8201@0000000`20
P800oooo0?ooo`3o0?oook<0oooo4_ooool0017oooooX03oool5000004h0oooo00<0P82000000000
00000`0000000`20P800oooo0?ooo`3o0?oook80oooo4_ooool0017oooooW`3oool4000000030820
P03oool0oooo04h0oooo1`00003o0?oook<0oooo4_ooool0017oooooW@3oool00`20P80000000000
0003000005<0oooo1P00003o0?oook80oooo4_ooool0017oooooV`3oool20820P0<0000000<0@410
0?ooo`3oool0D`3oool00`30`<00000000000003000000030410@020P800oooo0?l0oooo[`3ooolB
ooooo`004OoooonJ0?ooo`030820P0000000000000<00000F@3oool600000?l0oooo[`3ooolBoooo
o`004OoooonI0?ooo`D00000F`3oool00`20P800000000000003000000030820P03oool0oooo0900
oooo00@0P820000000000000P820o`3ooolH0?oooa;ooooo000AoooooiL0oooo00<0P82000000000
00000P0000000`20P800`<300?ooo`1L0?ooo`030820P0000000000000<0000000<0P8200?ooo`3o
ool0SP3oool01020P800000000000020P83o0?oooaP0oooo4_ooool0017oooooUP3oool500000640
oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`2=0?ooo`<00000o`3ooolI0?oooa;o
oooo000AoooooiD0oooo1@00001T0?ooo`H00000SP3oool300000?l0oooo6@3ooolBooooo`004Ooo
oonC0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0I03oool00`10@40000000000
0003000000030<30`03oool0oooo08X0oooo0`00003o0?oooaT0oooo4_ooool0017oooooT@3oool0
0`20P800000000000003000006X0oooo1P00002;0?ooo`<00000o`3ooolI0?oooa;ooooo000Aoooo
oi40oooo1@00001/0?ooo`H00000RP3oool300000?l0oooo6@3ooolBooooo`004Ooooon>0?ooo`03
0<30`0000000000000<0000000<0`<300?ooo`3oool0J`3oool00`30`<00P8200000000300000003
0410@03oool0oooo08H0oooo0`0000000`20P800oooo0?ooo`3o0?oooaL0oooo4_ooool0017ooooo
S@3oool5000007<0oooo1P0000260?ooo`<00000o`3ooolJ0?oooa;ooooo000Aoooooh`0oooo1@00
00000`20P800oooo0?ooo`1a0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3o
oonP0?oooa;ooooo000AooooohX0oooo00<0P8200410@00000000P0000000`20P800oooo0?ooo`1e
0?ooo`030820P00000000000008000000P20P83o0?oooj00oooo4_ooool0017ooooo103oool01020
P800000000000020P8210?ooo`D0000000<0P8200?ooo`3oool0M`3oool00`20P800000000000003
000000030820P03oool0oooo0?l0ooooW@3ooolBooooo`004Oooool40?ooo`040820P00000000000
00000800oooo1@00001m0?ooo`D00000o`3ooonO0?oooa;ooooo000Aooooo`D0oooo0`00001m0?oo
o`030<30`020P800000000<0000000<0P8200?ooo`3oool0O@3oool00`10@4000000000000030000
00030<30`03oool0oooo0?l0ooooVP3ooolBooooo`004Oooool50?ooo`<00000O@3oool5000008<0
oooo1@00003o0?oooi`0oooo4_ooool0017ooooo1@3oool4000007X0oooo1@0000000`20P800oooo
0?ooo`230?ooo`H00000o`3ooonJ0?oooa;ooooo000Aooooo`H0oooo0`00001h0?ooo`030<30`000
0000000000<0000000<0P8200?ooo`3oool0Q03oool00`30`<00P82000000003000000030410@03o
ool0oooo0?l0ooooU`3ooolBooooo`004Oooool60?ooo`<00000M`3oool5000000030820P03oool0
oooo08T0oooo1P00003o0?oooiL0oooo4_ooool0017ooooo1P3oool4000007D0oooo1P00002<0?oo
o`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3ooonD0?oooa;ooooo000Aooooo`L0
oooo0`00001c0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0SP3oool00`20P800
00000000000200000080P820o`3ooonD0?oooa;ooooo000Aooooog/0oooo00<0P820000000000000
0`00002C0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3ooonA0?oooa;ooooo
000Aooooog/0oooo1@00002F0?ooo`D00000o`3ooonC0?oooa;ooooo000AooooogP0oooo00<0`<30
0000000000000`0000000`30`<00oooo0?ooo`2F0?ooo`030410@0000000000000<0000000<0`<30
0?ooo`3oool0o`3ooon>0?oooa;ooooo000AooooogL0oooo1P00002L0?ooo`D00000o`3ooon@0?oo
oa;ooooo000AooooogH0oooo1@0000000`20P800oooo0?ooo`2L0?ooo`H00000K@3oool300000?l0
oooo7P3ooolBooooo`004Ooooomd0?ooo`030820P010@4000000008000000P20P82O0?ooo`030<30
`020P800000000<0000000<0@4100?ooo`3oool0JP3oool300000?l0oooo7P3ooolBooooo`004Ooo
oomc0?ooo`D0000000<0P8200?ooo`3oool0XP3oool6000006T0oooo00@0P8200000000000000000
o`3ooolN0?oooa;ooooo000Aooooog80oooo1@00002V0?ooo`030820P0000000000000@00000J03o
ool01020P800000000000020P83o0?oooah0oooo4_ooool0017oooooK`3oool00`30`<00P8200000
0003000000030820P03oool0oooo0:L0oooo00<0P8200000000000000P0000000`10@400P8200?oo
o`1U0?ooo`040820P000000000000820P?l0oooo7P3ooolBooooo`004Ooooom_0?ooo`D00000[03o
ool00`20P800000000000004000006D0oooo0`00003o0?oooal0oooo4_ooool0017oooooK@3oool6
00000:l0oooo1@0000000`20P800oooo0?ooo`1R0?ooo`800000o`3ooolP0?oooa;ooooo000Aoooo
of`0oooo00<0@4100000000000000P0000000`20P800oooo0?ooo`2_0?ooo`030820P00000000000
00<0000000<0P8200?ooo`3oool0G`3oool300000?l0oooo803ooolBooooo`004OoooomZ0?ooo`D0
000000<0P8200?ooo`3oool0/`3oool5000000030820P03oool0oooo05d0oooo0`00003o0?ooob40
oooo4_ooool0017oooooJ@3oool00`20P80000000000000300000;L0oooo1P00003o0?oooh80oooo
4_ooool0017oooooI`3oool00`20P800000000000002000000030410@03oool0oooo0;P0oooo00<0
P8200000000000000`0000000`30`<00oooo0?ooo`3o0?ooogh0oooo4_ooool0017ooooo2`3oool3
000005P0oooo1P00002m0?ooo`H00000o`3ooomo0?oooa;ooooo000Aooooo`/0oooo1000001F0?oo
o`D00000`03oool600000?l0ooooOP3ooolBooooo`004Oooool<0?ooo`<0000000<0P8200?ooo`3o
ool0D@3oool00`10@400000000000002000000030820P030`<00oooo0<00oooo00<0P82000000000
00000P0000000`10@400P8200?ooo`3o0?ooog/0oooo4_ooool0017ooooo3@3oool300000580oooo
1@0000360?ooo`H00000o`3ooomk0?oooa;ooooo000Aooooo`d0oooo0`0000000`20P800oooo0?oo
o`1=0?ooo`030820P0000000000000<00000b03oool5000000030820P03oool0oooo0?l0ooooN03o
oolBooooo`004Oooool=0?ooo`040820P000000000000410@4d0oooo0P20P803000000030410@020
P800oooo00l0oooo2`20P8080?ooo`H0P82000<0`<300?ooo`3oool0WP3oool00`20P80000000000
0003000000030820P03oool0oooo0?l0ooooMP3ooolBooooo`004Oooool=0?ooo`040820P0000000
0000000004`0oooo00<0P8200000000000000`00000C0?ooo`P000002P3oool500000:@0oooo1@00
00000`20P800oooo0?ooo`3o0?ooogD0oooo4_ooool0017ooooo3P3oool4000004X0oooo1P00000E
0?ooo`H000002P3oool500000:H0oooo1P00003o0?ooogH0oooo4_ooool0017ooooo3P3oool01020
P80000000410@020P8180?ooo`030820P0000000000000<0000000<0`<300?ooo`3oool05@3oool5
000000X0oooo100000000`20P800oooo0?ooo`2U0?ooo`030820P0000000000000<0000000<0`<30
0?ooo`3oool0o`3ooomb0?oooa;ooooo000AoooooeT0oooo1@00000J0?ooo`030820P00000000000
008000002@3oool5000000030820P03oool0oooo0:L0oooo1P00003o0?ooog<0oooo4_ooool0017o
ooooE`3oool00`20P800000000000003000000030820P03oool0oooo01P0oooo00<0P82000000000
00000P0000090?ooo`D00000Z`3oool600000?l0ooooLP3ooolBooooo`004OoooomF0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool06P3oool00`20P800000000000002000000030820
P03oool0oooo00D0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`2Z0?ooo`030820
P000000000000080000000<0@4100820P03oool0o`3ooom_0?oooa;ooooo000Aoooooe@0oooo00<0
P8200000000000000`0000000`20P800oooo0?ooo`0L0?ooo`D000001`3oool00`20P80000000000
000200000:l0oooo1P0000160?ooo`030000003oool0oooo0?l0oooo9P3ooolBooooo`004OoooomD
0?ooo`D00000803oool5000000L0oooo1@00002`0?ooo`D0000000<0P8200?ooo`3oool0@P3oool4
00000?l0oooo9P3ooolBooooo`004Oooooln0?ooo`030<30`03oool0oooo0100oooo00<0`<300000
000000000`0000000`20P800oooo0?ooo`0O0?ooo`030820P000000000000080000000<0P8200?oo
o`3oool0103oool400000;80oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`0o0?oo
o`050820P0000000000000000020P800o`3ooolV0?oooa;ooooo000Aoooooch0oooo00<0P8200000
000000003`3oool6000002@0oooo100000000`20P800oooo0?ooo`030?ooo`D00000]03oool50000
00030820P03oool0oooo03h0oooo1000003o0?ooobL0oooo4_ooool0017ooooo?P3oool4000000d0
oooo1@0000000`20P800oooo0?ooo`0S0?ooo`@0000000<0P8200?ooo`3oool00`3oool400000003
0820P03oool0oooo0;<0oooo1P00000n0?ooo`040820P0000000000000000?l0oooo:03ooolBoooo
o`004Oooooll0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool01`3oool00`10@400
00000000000200000080P8209P3oool00`20P800000000000002000000@0oooo1@0000000`30`<00
oooo0?ooo`2d0?ooo`030820P0000000000000<0000000<0`<300?ooo`3oool0>P3oool01010@400
000000000010@43o0?ooobP0oooo4_ooool0017ooooo?03oool8000000030820P03oool0oooo00D0
oooo1@0000000`20P800oooo0?ooo`0W0?ooo`@00000103oool500000;T0oooo1P00000k0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooolV0?oooa;ooooo000Aoooooc/0oooo00<0P820000000000000
1`0000050?ooo`030820P0000000000000@00000:P3oool500000080oooo1P00002j0?ooo`H00000
>P3oool300000?l0oooo:@3ooolBooooo`004Ooooolj0?ooo`030820P0000000000000T0000000@0
P8200?ooo`20P800P820100000000`20P800oooo0?ooo`0Z0?ooo`030820P0000000000000T00000
0`20P82i0?ooo`030820P000000000000080000000<0@4100820P03oool0=P3oool01020P800@410
00000000003o0?ooobT0oooo4_ooool0017ooooo>P3oool=000000030820P0000000000000<00000
;P3oool00`20P800000000000002000000H0oooo1@0000000`20P800oooo0?ooo`2g0?ooo`H00000
o`3ooomS0?oooa;ooooo000AooooocT0oooo4`00000`0?ooo`D000001`3oool400000;X0oooo1@00
00000`20P800oooo0?ooo`3o0?ooof00oooo4_ooool0017ooooo5P3oool00`20P80000000000000O
0?ooo`030820P0000000000000l0000000<0`<300?ooo`3oool0;`3oool5000000L0oooo00<0`<30
0000000000000P0000000`20P800oooo0?ooo`2g0?ooo`030820P0000000000000<0000000<0P820
0?ooo`3oool0o`3ooomN0?oooa;ooooo000AoooooaH0oooo0`0000000`20P800oooo0?ooo`0L0?oo
oa400000<`3oool5000000030820P03oool0oooo00H0oooo100000000`20P800oooo0?ooo`2h0?oo
o`D0000000<0P8200?ooo`3oool0o`3ooomM0?oooa;ooooo000AoooooaH0oooo00@0P82000000000
0000P8207@3ooolC000003<0oooo100000000`20P800oooo0?ooo`060?ooo`@0000000<0P8200?oo
o`3oool0^@3oool600000?l0ooooGP3ooolBooooo`004OoooolF0?ooo`040820P000000000000000
01`0oooo500000000`20P800oooo0?ooo`0`0?ooo`@0000000<0P8200?ooo`3oool01`3oool40000
0;`0oooo00<0P8200000000000000`00003o0?oooed0oooo4_ooool0017ooooo5`3oool300000003
0820P03oool0oooo01P0oooo00<0`<300000000000004P0000000`10@400oooo0?ooo`0`0?ooo`05
0820P0000000000000000010@4002@3oool400000;d0oooo00<0P8200000000000000P0000000`10
@400P8200?ooo`3o0?oooeX0oooo4_ooool0017ooooo603oool3000001X0oooo5P00000c0?ooo`@0
00002@3oool400000;l0oooo00<0P8200000000000000`00003o0?oooeX0oooo4_ooool0017ooooo
603oool4000001T0oooo5`00000b0?ooo`@000002@3oool400000<00oooo1@0000000`20P800oooo
0?ooo`3o0?oooeL0oooo4_ooool0017ooooo6@3oool4000001H0oooo00<0P8200000000000005P00
000b0?ooo`030410@0000000000000800000203oool3000000030410@03oool0oooo0;l0oooo00<0
P8200410@00000000`0000000`20P800oooo0?ooo`3o0?oooeD0oooo4_ooool0017ooooo6@3oool0
0`20P80000000?ooo`0F0?ooo`030820P0000000000001L00000<P3oool00`20P800000000000002
000000L0oooo100000000`20P800oooo0?ooo`310?ooo`H00000o`3ooomF0?oooa;ooooo000Aoooo
oc80oooo00<0P8200000000000006000000a0?ooo`030820P0000000000000<000001@3oool50000
0<D0oooo1P00003o0?oooeD0oooo4_ooool0017ooooo<@3oool00`20P80000000000000I00000300
oooo00<0P8200410@0000000100000040820P0@0000000<0P8200?ooo`3oool0a@3oool00`30`<00
000000000003000000030820P03oool0oooo0?l0ooooD@3ooolBooooo`004Oooool`0?oooad00000
;P3oool00`20P80000000000000<00000<`0oooo1P00000M0?ooo`030820P03oool0oooo0?l0oooo
<P3ooolBooooo`004Oooool`0?oooa/00000o`3oool>0?ooo`D00000703oool300000?l0oooo<P3o
oolBooooo`004Oooool_0?ooo`030410@000000000000180000000<0@4100820P020P8000P20P83o
0?oooa00oooo00<0`<300000000000000`0000000`20P800oooo0?ooo`0G0?ooo`@0000000<0`<30
0?ooo`3oool0o`3oool_0?oooa;ooooo000Aooooobl0oooo4P0000000`20P800oooo0?ooo`3o0?oo
oaP0oooo1@00000G0?ooo`D00000o`3ooolb0?oooa;ooooo000Aooooobh0oooo400000000`20P800
oooo0?ooo`3o0?oooa/0oooo00<0P8200000000000000`00000F0?ooo`@00000o`3ooolc0?oooa;o
oooo000Aooooob`0oooo00<0`<30000000000000300000020820P?l0oooo803oool20820P0@00000
00<0P8200?ooo`3oool04@3oool01020P800000000000000003o0?oooc@0oooo4_ooool0017ooooo
;03oool00`20P800000000000009000000030820P03oool0oooo0?l0oooo903oool00`20P8000000
0000000300000180oooo0`0000000`20P800oooo0?ooo`3o0?oooc80oooo4_ooool0017ooooo;03o
ool9000000030820P03oool0oooo0?l0oooo:03oool600000140oooo0`00003o0?ooocD0oooo4_oo
ool0017ooooo:P3oool01020P80000000000000000040820P0030<30`03oool0oooo0?l0oooo;@3o
ool00`10@400000000000002000000030820P03oool0oooo00`0oooo00<0P8200410@0000000o`3o
oolf0?oooa;ooooo000AooooobX0oooo0P0000000`20P800oooo0?ooo`3o0?oooc@0oooo1P00003o
0?ooodH0oooo4_ooool0017ooooo:@3oool00`20P800oooo0?ooo`3o0?ooocT0oooo1@00003o0?oo
odD0oooo4_ooool0017ooooo8P3oool01020P800@41000000000003o0?ooocl0oooo00<0`<300000
000000000`0000000`20P800oooo0?ooo`3o0?oood40oooo4_ooool0017ooooo8`3oool300000003
0820P03oool0oooo0?l0oooo?`3oool500000?l0oooo@P3ooolBooooo`004OoooolS0?ooo`@00000
o`3ooom10?ooo`030820P0000000000000<00000o`3ooom10?oooa;ooooo000Aooooob@0oooo00@0
P820000000000000P820o`3ooom10?ooo`80P820100000000`20P800oooo0?ooo`3o0?ooocd0oooo
4_ooool0017ooooo9@3oool400000?l0oooo@P3oool00`20P80000000000000300000?l0oooo?P3o
oolBooooo`004OoooolV0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom00?ooo`H00000o`3ooolm
0?oooa;ooooo000AooooobH0oooo00@0`<30000000000000@410o`3ooom40?ooo`030410@0000000
00000080000000<0P8200?ooo`3oool0@P3oool20820P0030410@020P800P82000@0P820k@3ooolB
ooooo`004OoooolW0?ooo`80000000<0P8200?ooo`3oool0o`3ooom30?ooo`H00000@P3oool00`20
P8000000000000060?ooo`0300000020P800oooo0>/0oooo4_ooool0017oooooo`3oooma0?ooo`D0
0000@@3oool3000000L0oooo0P00003[0?oooa;ooooo000Aooooool0ooooL@3oool00`30`<000000
00000003000000030<30`03oool0oooo03`0oooo00<0P820000000000000203oool01030`<000000
00000030`<3Y0?oooa;ooooo000Aooooool0ooooK03oool2000000030820P03oool0oooo00<0oooo
1@00000m0?ooo`<000002@3oool300000>T0oooo4_ooool0017oooooo`3ooom[0?ooo`040820P000
00000000000000D0oooo00<0P8200000000000000`00000l0?ooo`<000002P3oool300000>P0oooo
4_ooool0017oooooo`3ooom[0?ooo`<0000000<0P8200?ooo`3oool0103oool20820P0<0000000<0
@4100820P03oool0>@3oool3000000X0oooo00@0P820000000000000P820i`3ooolBooooo`004Ooo
oooo0?ooofX0oooo100000090?ooo`030820P0000000000000<00000>@3oool4000000X0oooo0`00
003W0?oooa;ooooo000Aooooool0ooooJ@3oool4000000/0oooo1@0000000`20P800oooo0?ooo`0f
0?ooo`@000002P3oool01020P800000000000020P83V0?oooa;ooooo000Aooooool0ooooJ03oool0
1@10@4000000000000000000P82000d0oooo00<0@4100000000000000P0000000`20P800oooo0?oo
o`0e0?ooo`<0000000<0`<300?ooo`3oool01`3oool01020P800000000000010@43V0?oooa;ooooo
000Aooooool0ooooJ03oool3000000030820P03oool0oooo00d0oooo1@0000000`20P800oooo0?oo
o`0d0?ooo`<0000000<0P8200?ooo`3oool0203oool300000>H0oooo4_ooool0017oooooo`3ooomW
0?ooo`@0000000<0P8200?ooo`3oool03`3oool5000002<0oooo00@0P820000000000000P8203P3o
ool01020P800000000000020P80:0?ooo`<00000iP3ooolBooooo`004Ooooooo0?ooofP0oooo00<0
`<300820P020P8004P3oool00`30`<00000000000003000000030<30`03oool0oooo01l0oooo00@0
`<3000000000000000003`3oool3000000X0oooo0`00003V0?oooa;ooooo000Aoooooc<0oooo0P00
003o0?oood/0oooo1@00000Q0?ooo`<00000403oool3000000T0oooo0`00003V0?oooa;ooooo000A
oooooc80oooo00@0P820000000000000P820o`3ooom:0?ooo`030820P0000000000000<00000803o
ool300000140oooo0`0000080?ooo`<00000iP3ooolBooooo`004Ooooolb0?ooo`050410@0000000
000000000020P800o`3ooom:0?ooo`80P8200`0000000`10@400P8200?ooo`0N0?ooo`<00000403o
ool01030`<00000000000010@4070?ooo`80000000<0P8200?ooo`3oool0i03ooolBooooo`004Ooo
oolc0?ooo`@00000o`3ooom<0?ooo`030820P0000000000000<000007P3oool300000180oooo0`00
00050?ooo`030820P000000000000>L0oooo4_ooool0017ooooo=03oool400000?l0ooooC03oool5
000000030820P03oool0oooo01/0oooo1000000B0?ooo`030820P0000000000000@0oooo0P00003X
0?oooa;ooooo000AooooocD0oooo0`0000000`10@400oooo0?ooo`3o0?oood/0oooo00<0@4100000
000000000P0000000`20P800oooo0?ooo`0J0?ooo`<0000000<0`<300?ooo`3oool04@3oool50820
P0030<30`03oool0oooo0>L0oooo4_ooool0017ooooo=@3oool00`20P80000000000000200000?l0
ooooC@3oool6000001/0oooo0`0000000`20P800oooo0?ooo`3o0?ooo`40oooo4_ooool0017ooooo
=P3oool300000?l0ooooD03oool5000001X0oooo00@0P820000000000000P820o`3oool30?oooa;o
oooo000AooooocL0oooo00<0P8200<30`03oool0o`3ooom?0?ooo`030<30`0000000000000<00000
00<0P8200?ooo`3oool05P3oool01020P800000000000000003o0?ooo`<0oooo4_ooool0017ooooo
o`3ooon<0?ooo`D000005`3oool00`20P80000000000000200000?l0oooo0P3ooolBooooo`004Ooo
oooo0?oooe`0oooo00<000000?ooo`3oool0;P3oool5000001L0oooo1@00003o0?ooo`40oooo4_oo
ool0017oooooo`3ooomJ0?ooo`050820P0000000000000000020P800;P3oool00`30`<00P8200000
0003000000030820P03oool0oooo01<0oooo0`0000000`3oool000000<30`03o0?oooa;ooooo000A
ooooool0ooooF@3oool00`20P80000000000000200000380oooo1@00000E0?ooo`<0000000<0oooo
0000003oool0oP3ooolBooooo`004Ooooooo0?oooeT0oooo1000000c0?ooo`030820P00000000000
00<00000503oool3000000030?ooo`20P800oooo0?h0oooo4_ooool0017oooooo`3ooomG0?ooo`03
0820P000000000000080000000<0`<300?ooo`3oool0<`3oool00`20P80000000000000200000003
0820P03oool0oooo0100oooo0`0000001P20P800`<3000000020P800oooo0820P080000000<0P820
0?ooo`3oool0mP3ooolBooooo`004Ooooooo0?oooeH0oooo1@00000h0?ooo`030820P00000000000
00<000004@3oool400000080oooo1P00003h0?oooa;ooooo000Aooooool0ooooE@3oool00`20P800
000000000002000003/0oooo1@00000@0?ooo`@000000`3oool500000?P0oooo4_ooool0017ooooo
o`3ooomF0?ooo`040820P000000000000<30`3`0oooo00<0@4100000000000000P0000000`20P800
oooo0?ooo`080?ooo`@0P820100000001020P800oooo0?ooo`30`<03000000030820P03oool0oooo
0?H0oooo4_ooool0017oooooA03oool00`20P80000000?ooo`3o0?oooe40oooo1@00003o0?oooa80
oooo4_ooool0017oooooA03oool300000?l0ooooDP3oool500000?l0oooo4@3ooolBooooo`004Ooo
oom30?ooo`060820P0000000000000000010@400P820o`3ooom@0?ooo`030<30`020P800000000<0
000000<0P8200?ooo`3oool0o`3oool=0?oooa;ooooo000Aoooood@0oooo00<0P820000000000000
0`00003o0?oooe80oooo1@00003o0?ooo`h0oooo4_ooool0017oooooA@3oool5000000030820P03o
ool0oooo0?l0ooooC`3oool00`20P80000000000000300000?l0oooo3@3ooolBooooo`004Ooooom7
0?ooo`050410@0000000000000000020P800o`3ooomB0?ooo`030820P000000000000080000000<0
P8200?ooo`3oool0o`3oool90?oooa;ooooo000AooooodP0oooo0`00003o0?oooeD0oooo1@00003o
0?ooo`X0oooo4_ooool0017oooooB@3oool00`000000P8200?ooo`3o0?oooeD0oooo1@00003o0?oo
o`T0oooo4_ooool0017oooooo`3ooom90?ooo`030<30`020P800oooo05H0oooo00<0P82000000000
00000P0000000`20P800oooo0?ooo`3o0?ooo`D0oooo4_ooool0017oooooo`3ooom90?ooo`800000
F@3oool500000?l0oooo1P3ooolBooooo`004Ooooooo0?ooodL0oooo1@00001I0?ooo`D00000o`3o
ool50?oooa;ooooo000Aooooool0ooooAP3oool00`20P800000000000002000005/0oooo1@00003o
0?ooo`@0oooo4_ooool0017oooooo`3ooom50?ooo`050820P0000000000000000020P800G@3oool0
0`20P800000000000002000000030820P03oool0oooo0?l0oooo4_ooool0017oooooo`3ooom30?oo
o`030820P0000000000000800000H@3oool500000?l0oooo0@3ooolBooooo`004Ooooooo0?oood<0
oooo1000001S0?ooo`D00000o`3ooolBooooo`004Ooooooo0?oood<0oooo00@0P82000000020P800
`<30I03oool00`20P800000000000002000000030820P03oool0oooo0?/0oooo4_ooool0017ooooo
F03oool200000?l0ooooD`3oool500000?`0oooo4_ooool0017oooooE`3oool01020P80000000000
0020P83o0?oooe<0oooo1@00003k0?oooa;ooooo000AoooooeL0oooo00<0P8200000000000000P00
00000`20P800`<300?ooo`3o0?oooe00oooo00<0P8200000000000000P0000000`20P800oooo0?oo
o`3g0?oooa;ooooo000AoooooeT0oooo1P00003o0?oooe80oooo1@00003h0?oooa;ooooo000Aoooo
oeX0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`3o0?ooodl0oooo1@00003g0?oo
oa;ooooo000AoooooeX0oooo00<0`<300820P00000000`0000000`30`<00oooo0?ooo`3o0?oooe00
oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3c0?oooa;ooooo000Aoooooed0oooo
00<0P820000000000000o`3ooomE0?ooo`D00000m03ooolBooooo`004Ooooooo0?ooocD0oooo0P00
001o0?ooo`D00000l`3ooolBooooo`004Ooooooo0?oooc80oooo0P20P803000000030<30`03oool0
oooo07d0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`3_0?oooa;ooooo000Aoooo
ool0oooo<@3oool00`20P800000000000003000000030820P03oool0oooo07l0oooo1@00003`0?oo
oa;ooooo000Aooooool0oooo<03oool6000008@0oooo1@00003_0?oooa;ooooo000Aooooool0oooo
;P3oool00`20P800000000000003000000030<30`03oool0oooo08@0oooo00<0P820000000000000
0P0000000`20P800`<300?ooo`3[0?oooa;ooooo000Aooooool0oooo;P3oool01020P80000000000
0000002;0?ooo`D00000k03ooolBooooo`004Ooooom]0?ooo`800000_P3oool00`20P80000000000
002=0?ooo`D00000j`3ooolBooooo`004Ooooom/0?ooo`030<30`000000000000080000000<0P820
0<30`03oool0o`3ooom;0?ooo`030820P000000000000080000000<0@4100?ooo`3oool0i`3ooolB
ooooo`004Ooooom/0?ooo`030820P0000000000000H00000o`3ooom<0?ooo`030820P00000000000
00800000j03ooolBooooo`004Ooooom^0?ooo`P00000o`3ooom<0?ooo`D0000000<0P8200?ooo`3o
ool0i03ooolBooooo`004Ooooom_0?ooo`030<30`020P800P82000<0000000<0@4100?ooo`3oool0
o`3ooom;0?ooo`030820P010@40000000080000000<0P8200?ooo`3oool0h`3ooolBooooo`004Ooo
oomc0?ooo`80000000<0P8200?ooo`3oool0o`3ooom=0?ooo`D0000000<0P8200?ooo`3oool0h@3o
oolBooooo`004Ooooooo0?oooah0oooo00<0P8200000003oool0Y@3oool5000003`0oooo3P00002I
0?oooa;ooooo000Aooooool0oooo6`3oool20820P0@00000YP3oool00`30`<000000000000020000
00030820P030`<00oooo03@0oooo00<0P8200410@00000004@0000020820P0030<30`03oool0oooo
0980oooo4_ooool0017oooooo`3ooolI0?ooo`P00000Z03oool5000003<0oooo6`00002B0?oooa;o
oooo000Aooooool0oooo5`3oool800000:/0oooo00<0P8200000000000000P00000`0?ooo`P00000
00<0MWIf0>c/k03/k>`02P3/k>`900000940oooo4_ooool0017oooooQ03oool20820P940oooo1000
00020820P:d0oooo00<0P8200000000000000P0000000`10@400oooo0?ooo`0[0?ooo`030410@000
0000000000<0000000<0>c/k07IfMP3/k>`03`3/k>`00`2a/K40MWIf07IfMP06000000030410@020
P800P82008`0oooo4_ooool0017oooooQ03oool4000000030820P03oool0oooo08`0oooo00<0P820
000000000000/P3oool00`20P800000000000002000002/0oooo1@00000I0>c/k0L0000000<0P820
0?ooo`3oool0R@3ooolBooooo`004Ooooon30?ooo`P00000o`3ooom30?ooo`D0000000<0P8200?oo
o`3oool09`3oool40000000307IfMP3/k>`0k>c/01P0k>c/00<0MWIf0000000000001@00002:0?oo
oa;ooooo000Aoooooh<0oooo0P20P8000`10@40000000000000500000?l0oooo@P3oool00`20P800
@41000000002000000030820P03oool0oooo02D0oooo00D0P820000000000000000007IfMP0N0>c/
k080MWIf100000000`10@400oooo0?ooo`260?oooa;ooooo000AooooohP0oooo1@00003o0?oood@0
oooo1@0000000`20P800oooo0?ooo`0S0?ooo`<000008`3/k>`00`1fMWH0000000000003000008H0
oooo4_ooool0017oooooRP3oool2000007T0oooo0`0000390?ooo`D00000903oool01020P8000000
00000000000T0>c/k0H00000Q@3ooolBooooo`004Ooooooo0?ooo`<0P8201P0000000`20P800oooo
0?ooo`370?ooo`030<30`000000000000080000000<0P8200<30`03oool0803oool01010@4000000
0000002a/K4V0>c/k00303/k>`000000000000<0000000<0P8200?ooo`3oool0P03ooolBooooo`00
4Ooooooo0?ooo`T0000000<0P8200?ooo`3oool0b@3oool500000240oooo0`00000Y0>c/k0H00000
P@3ooolBooooo`004OoooonL0?ooo`@0000000<0P8200?ooo`3oool0G03oool00`20P80000000000
0003000000030820P03oool0oooo0<d0oooo00<0P8200000000000000P00000O0?ooo`@00000:P3/
k>`600000800oooo4_ooool0017oooooV`3oool00`20P800000000000006000000030820P03oool0
oooo05P0oooo00@0`<300820P020P800`<30d`3oool00`20P800000000000002000000030410@03o
ool0oooo01/0oooo0`00000/0>c/k00307IfMP000000000000<0000000<0@4100?ooo`3oool0O03o
oolBooooo`004OoooonK0?ooo`X00000AP3oool500000>P0oooo00<0P8200000000000000P00000K
0?ooo`@00000;`3/k>`6000007`0oooo4_ooool0017oooooW`3oool600000440oooo2P00003Y0?oo
o`D0000000<0P8200?ooo`3oool05`3oool300000340k>c/1@0000000`20P800oooo0?ooo`1i0?oo
oa;ooooo000Aoooooj<0oooo00<0@4100?ooo`3oool03`3oool90820P2P0oooo00<0@41000000000
00001`00003Z0?ooo`030820P010@40000000080000000<0P8200?ooo`3oool05@3oool01030`<00
000000000000000b0>c/k00307IfMP0k>c/00000008000000P20P81i0?oooa;ooooo000AoooookD0
oooo2@00000?0?ooo`X000003`3oool00`20P80000000000000700000>`0oooo1@0000000`20P800
oooo0?ooo`0C0?ooo`040820P0000000000007IfMS@0k>c/1@0000000`20P800oooo0?ooo`1f0?oo
oa;ooooo000Aoooook@0oooo2P00000?0?ooo`X00000o`3oool70?ooo`D000005@3oool01020P800
00000000001fMWHf0>c/k0D00000M`3ooolBooooo`004Ooooond0?ooo`<0P8201`00000@0?ooo`T0
0000o`3oool80?ooo`030<30`000000000000080000000<0P8200?ooo`3oool04@3oool01020P800
00000000001fMWHf0>c/k0030;6a/@1fMWH0000000<0000000<0`<300?ooo`3oool0L`3ooolBoooo
o`004Ooooooo0?ooon40oooo1@00000B0?ooo`040820P0000000000007IfMST0k>c/1@00001d0?oo
oa;ooooo000Aooooool0oooohP3oool00`20P80000000000000200000140oooo00@0P82000000000
0000MWIf>P3/k>`5000007<0oooo4_ooool0017oooooo`3ooooS0?ooo`030820P000000000000080
000000<0P8200?ooo`3oool03@3oool3000000030;6a/@3/k>`0k>c/03T0k>c/00<0MWIf03/k>`00
00000P0000000`20P800oooo0?ooo`1_0?oooa;ooooo000Aooooool0ooooi@3oool00`20P8000000
00000002000000h0oooo0`00000n0>c/k0D00000L03ooolBooooo`004Ooooooo0?ooonH0oooo1@00
000=0?ooo`<00000@03/k>`4000006l0oooo4_ooool0017oooooo`3ooooW0?ooo`030820P010@400
00000080000000<0P8200?ooo`3oool02@3oool300000400k>c/00<0/K6a0000000000000P000000
0`20P800`<300?ooo`1[0?oooa;ooooo000Aooooool0ooooj@3oool5000000X0oooo0`0000130>c/
k0H00000JP3ooolBooooo`004Ooooooo0?ooonX0oooo1@0000090?ooo`<00000@`3/k>`00`1fMWH0
000000000003000000030820P03oool0oooo06L0oooo4_ooool0017oooooo`3oooo[0?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool01@3oool3000004D0k>c/00<0MWIf000000000000
0`0000000`20P800oooo0?ooo`1U0?oooa;ooooo000Aooooool0ooook@3oool5000000H0oooo0`00
00170>c/k0H00000IP3ooolBooooo`004Ooooooo0?ooonh0oooo00<0P8200000000000000P000004
0?ooo`<00000BP3/k>`5000006D0oooo4_ooool0017oooooo`3oooo_0?ooo`80P8200`0000000`20
P800oooo0?ooo`03000004X0k>c/00<0/K6a07IfMP0000000`0000000`10@400oooo0?ooo`1Q0?oo
oa;ooooo000Aooooool0ooool@3oool00`20P800000000000002000000040?ooo`00000000000000
04d0k>c/00<0MWIf0000000000000`0000000`20P800oooo0?ooo`1N0?oooa;ooooo000Aooooool0
oooolP3oool8000004l0k>c/1`00001N0?oooa;ooooo000Aooooool0oooom03oool00`10@4000000
00000003000000d0k>c/00@0/K6a000000000000/K6a?`3/k>`00`1fMWH000000000000400000080
P820F`3ooolBooooo`004Ooooooo0?ooooD0oooo1@00000<0>c/k0@0000000<0MWIf0>c/k03/k>`0
@03/k>`8000005T0oooo4_ooool0017oooooo`3oooog0?ooo`@0000000<0MWIf0>c/k03/k>`01`3/
k>`6000004@0k>c/1`0000000`20P800oooo0?ooo`1E0?oooa;ooooo000Aooooool0oooom`3oool5
0000000307IfMP3/k>`0k>c/00D0k>c/00<0>c/k0000000000001@0000140>c/k0030;6a/@1fMWH0
000000@00000E`3ooolBooooo`004Ooooooo0?ooooL0oooo1`0000000`1fMWH0k>c/0>c/k0020>c/
k0X00000A`3/k>`4000005H0oooo4_ooool0017oooooo`3oooog0?ooo`<0000000<0k>c/00000000
00000P0000030>c/k0/0000000<0MWIf0>c/k03/k>`0A03/k>`4000005H0oooo4_ooool0017ooooo
o`3oooog0?ooo`<0000000<0k>c/0;6a/@1fMWH00`0000000`1fMWH0>c/k0000000:0000000303/k
>`3/k>`0k>c/04D0k>c/1000001E0?oooa;ooooo000Aooooool0oooom`3oool3000000@0k>c/4@00
00170>c/k0<0000000<0P8200?ooo`3oool0DP3ooolBooooo`004Ooooooo0?ooooL0oooo0`000004
0>c/k00307IfMP000000000000h00000A`3/k>`3000000030820P03oool0oooo0580oooo4_ooool0
017oooooo`3oooog0?ooo`<000001@3/k>`A000004H0k>c/00@0MWIf0000000000000000E03ooolB
ooooo`004Ooooooo0?ooooL0oooo0`0000040>c/k00307IfMP000000000000l0000000<0>c/k0>c/
k03/k>`0@`3/k>`01@2a/K400000000000000000P82005<0oooo4_ooool0017oooooo`3oooog0?oo
o`<00000103/k>`C000004H0k>c/1000001C0?oooa;ooooo000Aooooool0oooom`3oool3000000@0
k>c/500000160>c/k0@00000DP3ooolBooooo`004Ooooooo0?ooooL0oooo0`0000030>c/k1H00000
A@3/k>`0101fMWH0000000000000001B0?oooa;ooooo000Aooooool0oooom`3oool4000000030>c/
k0000000000001D0000000<0MWIf0>c/k03/k>`0@`3/k>`300000580oooo4_ooool0017oooooo`3o
oooh0?ooo`<0000000<0k>c/0000000000005@0000000`1fMWH0k>c/0>c/k0130>c/k0<00000DP3o
oolBooooo`004Ooooooo0?ooooP0oooo0`0000000`0k>c/000000000000F000004D0k>c/00@0MWIf
000000000000P820D@3ooolBooooo`004Ooooooo0?ooooP0oooo7@0000140>c/k00407IfMP000000
00000820P540oooo4_ooool0017oooooo`3ooooh0?oooah00000@`3/k>`0101fMWH0000000000020
P81A0?oooa;ooooo000Aooooool0oooon03oool300000080MWIf6@0000000`2a/K40k>c/0>c/k011
0>c/k0<00000D@3ooolBooooo`004Ooooooo0?ooooP0oooo0`0000040>c/k1P00000@`3/k>`30000
0540oooo4_ooool0017oooooo`3ooooh0?ooo`<000001P3/k>`00`1fMWH000000000000C000004<0
k>c/0`00001A0?oooa;ooooo000Aooooool0oooon03oool3000000T0k>c/00<0/K6a07IfMP1fMWH0
4@0000000`1fMWH0k>c/0>c/k00o0>c/k00407IfMP000000000000000500oooo4_ooool0017ooooo
o`3ooooh0?ooo`<000003P3/k>`@00000480k>c/0`00001@0?oooa;ooooo000Aooooool0oooon03o
ool300000100k>c/3P0000000`1fMWH0k>c/0>c/k00o0>c/k0<00000D03ooolBooooo`004Ooooooo
0?ooooP0oooo00@0P820000000000000MWIf4@3/k>`00`2a/K40MWIf07IfMP0:00000440k>c/0`00
001@0?oooa;ooooo000Aooooool0oooon03oool01020P80000000000001fMWHF0>c/k0T00000@03/
k>`300000500oooo4_ooool0017oooooo`3ooooh0?ooo`040820P0000000000007IfMQP0k>c/2000
000o0>c/k0<00000D03ooolBooooo`004Ooooooo0?ooooP0oooo00@0P820000000000000MWIf6`3/
k>`207IfMP0403/k>`000000000007IfMSh0k>c/0`00001@0?oooa;ooooo000Aooooool0oooon03o
ool01020P80000000000001fMWHP0>c/k0030000003/k>`0k>c/03`0k>c/0`00001@0?oooa;ooooo
000Aooooool0oooon03oool01020P80000000000001fMWIO0>c/k0<00000D03ooolBooooo`004Ooo
oooo0?ooooP0oooo00@0P820000000000000MWIfG`3/k>`300000500oooo4_ooool0017oooooo`3o
oooh0?ooo`040820P00000000000000005l0k>c/0`00001@0?oooa;ooooo000Aooooool0oooon@3o
ool3000005l0k>c/0`00001@0?oooa;ooooo000Aooooool0oooon@3oool3000005l0k>c/0`00001@
0?oooa;ooooo000Aooooool0oooon@3oool3000005l0k>c/0`00001@0?oooa;ooooo000Aooooool0
oooon@3oool3000005h0k>c/0`00001A0?oooa;ooooo000Aooooool0oooon@3oool30000000307If
MP3/k>`0k>c/05/0k>c/0`00001A0?oooa;ooooo000Aooooool0oooonP3oool3000005d0k>c/0`00
001A0?oooa;ooooo000Aooooool0oooonP3oool3000005d0k>c/0`00001A0?oooa;ooooo000Aoooo
ool0oooonP3oool3000005`0k>c/00@0/K6a0000000000000000D@3ooolBooooo`004Ooooooo0?oo
ooX0oooo0`00001L0>c/k00407IfMP00000000000820P540oooo4_ooool0017oooooo`3ooooj0?oo
o`<00000G03/k>`0101fMWH0000000000020P81A0?oooa;ooooo000Aooooool0oooonP3oool01020
P800000000000000001K0>c/k00403/k>`00000000000820P540oooo4_ooool0017oooooo`3ooook
0?ooo`<00000F`3/k>`300000580oooo4_ooool0017oooooo`3ooook0?ooo`<00000F`3/k>`30000
0580oooo4_ooool0017oooooo`3ooook0?ooo`<00000FP3/k>`3000000030820P03oool0oooo0500
oooo4_ooool0017oooooo`3ooook0?ooo`<00000FP3/k>`3000005<0oooo4_ooool0017oooooo`3o
oook0?ooo`040820P0000000000007IfMUP0k>c/1000001C0?oooa;ooooo000Aooooool0oooon`3o
ool01020P80000000000001fMWIG0>c/k0040;6a/@0000000000000005@0oooo4_ooool0017ooooo
o`3ooook0?ooo`040820P0000000000007IfMUL0k>c/00@0MWIf0000000000000000E03ooolBoooo
o`004Ooooooo0?oooo/0oooo00@0P820000000000000MWIfE`3/k>`0101fMWH0000000000020P81D
0?oooa;ooooo000Aooooool0oooon`3oool01030`<00000000000000001G0>c/k0<0000000<0P820
0?ooo`3oool0DP3ooolBooooo`004Ooooooo0?oooo`0oooo0`00001F0>c/k0@00000E@3ooolBoooo
o`004Ooooooo0?oooo`0oooo0`00001F0>c/k0<00000EP3ooolBooooo`004Ooooooo0?oooo`0oooo
00@0P8200000000000000000E03/k>`3000000030820P03oool0oooo05@0oooo4_ooool0017ooooo
o`3oooom0?ooo`<00000D`3/k>`0101fMWH0000000000000001G0?oooa;ooooo000Aooooool0oooo
o@3oool3000005<0k>c/00@0MWIf000000000000P820E`3ooolBooooo`004Ooooooo0?ooood0oooo
00@0P8200000000000000000DP3/k>`0100k>c/0000000000030`<1G0?oooa;ooooo000Aooooool0
oooooP3oool300000540k>c/1000001H0?oooa;ooooo000Aooooool0oooooP3oool300000500k>c/
1000001I0?oooa;ooooo000Aooooool0oooooP3oool01010@40000000000001fMWI>0>c/k0040;6a
/@0000000000000003/0oooo1@20P80J0?oooa;ooooo000Aooooool0oooooP3oool01020P8000000
0000001fMWI>0>c/k0<0000000<0P8200?ooo`3oool0=`3oool00`20P8000000000000040?ooo`80
0000603ooolBooooo`004Ooooooo0?ooooh0oooo00@0P820000000000000MWIfC@3/k>`400000003
0820P0000000000000800000=@3oool2000000H0oooo0P00000G0?oooa;ooooo000Aooooool0oooo
oP3oool01030`<00000000000000001<0>c/k0@0000000<0P8200?ooo`0000000`00000N0?ooo`03
0820P03oool0oooo01<0oooo0P0000000`20P800oooo0?ooo`050?ooo`030820P0000000P82001D0
oooo4_ooool0017oooooo`3ooooo0?ooo`<00000B`3/k>`00`1fMWH000000000000200000080oooo
1000000M0?ooo`030820P0000000000001<0oooo0`0000090?ooo`030820P0000000000000H0oooo
00<0P8200?ooo`3oool02`3ooolBooooo`004Ooooooo0?ooool0oooo0`00001;0>c/k0@000000`3o
ool4000001d0oooo0P00000D0?ooo`<000002@3oool01020P800000000000020P8050?ooo`030820
P0000000oooo00/0oooo4_ooool0017oooooo`3ooooo0?ooo`040820P00000000000000004T0k>c/
00D0MWIf00000000000000000820P0040?ooo`@000006P3oool00`20P80000000410@00E0?ooo`<0
00002P3oool3000000H0oooo00<0P82000000030`<002P3ooolBooooo`004Ooooooo0?ooool0oooo
0@3oool3000004P0k>c/1@0000050?ooo`@000006@3oool00`20P80000000000000F0?ooo`<00000
2`3oool3000000L0oooo00<000000?ooo`3oool0203ooolBooooo`004Ooooooo0?ooool0oooo0@3o
ool3000004L0k>c/00<0MWIf0000000000000P0000060?ooo`@000006@3oool2000001L0oooo1000
000:0?ooo`<000001`3oool00`20P80000000?ooo`080?oooa;ooooo000Aooooool0ooooo`3oool1
0?ooo`040820P00000000000000004D0k>c/00D0MWIf00000000000000000410@0070?ooo`050820
P0000000000000000030`<005`3oool00`20P80000000820P00G0?ooo`040820P000000000000000
00/0oooo0`0000060?ooo`040<30`000000000000<30`0L0oooo4_ooool0017oooooo`3ooooo0?oo
o`80oooo0`0000140>c/k0D000002@3oool3000000030820P03oool0oooo01@0oooo0`00000I0?oo
o`@000002P3oool3000000030820P03oool0oooo00@0oooo0`0000070?oooa;ooooo000Aooooool0
ooooo`3oool20?ooo`<0000000<0MWIf0>c/k03/k>`0@03/k>`00`1fMWH0000000000002000000X0
oooo0`0000000`20P800oooo0?ooo`0D0?ooo`80000000<0P8200?ooo`3oool05`3oool4000000X0
oooo00@0P820000000000000P8201`3oool2000000L0oooo4_ooool0017oooooo`3ooooo0?ooo`80
oooo00@0P820000000000000MWIf@P3/k>`4000000/0oooo0`0000001020P800oooo0?ooo`3oool6
000000`0oooo00@0P820000000000000P8201`3oool300000100oooo0`00000:0?ooo`040820P000
000000000820P0L0oooo0`0000060?oooa;ooooo000Aooooool0ooooo`3oool20?ooo`040820P000
0000000007IfMT00k>c/00<0MWIf0000000000000P0000000`30`<00oooo0?ooo`090?ooo`030410
@000000000000080P8200P0000000`20P800oooo0?ooo`020?ooo`040820P010@400P8200820P0T0
oooo00@0P820000000000000`<301`3oool01020P800000000000000000?0?ooo`040820P0000000
00000820P0T0oooo00@0P820000000000000P8201`3oool01020P800000000000020P8050?oooa;o
oooo000Aooooool0ooooo`3oool20?ooo`040820P00000000000000003l0k>c/00<0MWIf00000000
00000P00000=0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool01@3oool200000003
0820P03oool0oooo00H0oooo0`0000090?ooo`<00000403oool3000000T0oooo00@0P82000000000
0000P820203oool3000000D0oooo4_ooool0017oooooo`3ooooo0?ooo`<0oooo0`00000o0>c/k0@0
00003P3oool00`20P800000000000003000000030820P03oool0oooo00H0oooo0P0000080?ooo`<0
00002@3oool300000140oooo0`0000080?ooo`040820P000000000000820P0P0oooo0`0000000`20
P800oooo0?ooo`020?oooa;ooooo000Aooooool0ooooo`3oool30?ooo`<0000000<0MWIf0>c/k03/
k>`0>@3/k>`00`2a/K40000000000003000000030<30`03oool0oooo00`0oooo00<0P82000000000
00000`0000090?ooo`040820P000000000000820P0D0oooo100000090?ooo`040820P00000000000
0820P140oooo00@0@410000000000000P8201P3oool00`20P8000000000000090?ooo`040410@000
000000000820P0@0oooo4_ooool0017oooooo`3ooooo0?ooo`@0oooo0`00000k0>c/k0D000004@3o
ool5000000X0oooo0`0000050?ooo`<000002P3oool01020P800000000000020P80B0?ooo`<00000
00<0P8200?ooo`3oool00`3oool2000000X0oooo00@0P820000000000000P820103ooolBooooo`00
4Ooooooo0?ooool0oooo103oool4000003T0k>c/100000000`20P800oooo0?ooo`0@0?ooo`D00000
2P3oool01020P800000000000020P8040?ooo`<000002P3oool01020P800000000000000000D0?oo
o`800000103oool2000000/0oooo00@0P8200000000000000000103ooolBooooo`004Ooooooo0?oo
ool0oooo1@3oool3000000030;6a/@3/k>`0k>c/03@0k>c/00<0MWIf0000000000000P0000000`20
P800oooo0?ooo`0A0?ooo`D000002P3oool01020P800000000000010@4030?ooo`040820P0000000
0000000000/0oooo0`0000000`20P800oooo0?ooo`0B0?ooo`030<30`020P800P82000<0P820303o
ool01020P80000000000000000040?oooa;ooooo000Aooooool0ooooo`3oool50?ooo`040820P000
0000000007IfMSD0k>c/1@00000E0?ooo`D000002P3oool01020P80000000000000000030?ooo`@0
00002`3oool4000002H0oooo00@0P8200000000000000000103ooolBooooo`004Ooooooo0?ooool0
oooo1@3oool01020P800000000000000000c0>c/k00307IfMP000000000000<000005`3oool40000
00X0oooo00@0P82000000000000000000`3oool4000000`0oooo0`00000V0?ooo`040820P0000000
0000000000@0oooo4_ooool0017oooooo`3ooooo0?ooo`H0oooo1000000a0>c/k00507IfMP000000
000000000010@4006@3oool4000000/0oooo100000020?ooo`@00000303oool4000002D0oooo00@0
P8200000000000000000103ooolBooooo`004Ooooooo0?ooool0oooo1`3oool4000002h0k>c/00<0
MWIf0000000000000P00000K0?ooo`@000002`3oool400000080oooo1000000<0?ooo`@0000000<0
P8200?ooo`3oool08P3oool01020P80000000000000000040?oooa;ooooo000Aooooool0ooooo`3o
ool70?ooo`@00000;@3/k>`5000001d0oooo0`0000000`20P800oooo0?ooo`080?ooo`@000000P3o
ool4000000d0oooo1000000T0?ooo`040820P00000000000000000@0oooo4_ooool0017oooooo`3o
oooo0?ooo`P0oooo00@0@410000000000000MWIf:@3/k>`00`1fMWH0>c/k00000003000000030820
P030`<00oooo01`0oooo0`0000000`20P800oooo0?ooo`080?ooo`@000000P3oool4000000d0oooo
0`0000020820P2<0oooo00@0P8200000000000000000103ooolBooooo`004Ooooooo0?ooool0oooo
2@3oool4000002H0k>c/00<0MWIf0000000000000`0000000`20P800oooo0?ooo`0N0?ooo`040820
P00000000000000000X0oooo100000020?ooo`@000003@3oool01020P800000000000020P8020000
0280oooo00@0P820000000000000P820103ooolBooooo`004Ooooooo0?ooool0oooo2@3oool50000
02@0k>c/1`00000R0?ooo`<000002P3oool400000080oooo1000000=0?ooo`060820P00000000000
0820P03oool000008P3oool3000000030820P03oool0oooo0080oooo4_ooool0017oooooo`3ooooo
0?ooo`X0oooo00D0P820000000000000000003/k>`0O0>c/k080MWIf00<0>c/k0000000000000`00
00000`20P800oooo0?ooo`0R0?ooo`040820P000000000000820P0P0oooo00@0P820000000000000
0000103oool3000000d0oooo00L0P820000000000000@4100?ooo`20P800@4100080oooo00@0@410
000000000000`<306`3oool3000000030<30`03oool0oooo0080oooo4_ooool0017oooooo`3ooooo
0?ooo`/0oooo00<0P8200000000000000`00000L0>c/k0P00000:03oool3000000L0oooo0`000000
0`20P800oooo0?ooo`020?ooo`@00000303oool01020P80000000000000000020?ooo`030820P000
0000000000<0000000<0P8200?ooo`3oool06@3oool3000000D0oooo4_ooool0017oooooo`3ooooo
0?ooo``0oooo1`00000G0>c/k0T0000000<0P8200?ooo`3oool0:03oool3000000H0oooo0`000005
0?ooo`@00000303oool01020P80000000000000000030?ooo`D0000000<0P8200?ooo`3oool06@3o
ool3000000D0oooo4_ooool0017oooooo`3ooooo0?ooo`d0oooo2000000307IfMPX0k>c/101fMWH0
0`0k>c/0000000000007000000030820P03oool0oooo02`0oooo0P20P8001010@400P8200820P020
P802000000030410@020P800oooo00H0oooo0`0000090?ooo`<0P82000<0@4100000000000000P00
00030?ooo`050820P0000000000000000030`<006P3oool3000000H0oooo4_ooool0017oooooo`3o
oooo0?oooa00oooo7@0000000`20P800oooo0?ooo`100?ooo`030820P0000000000003<0oooo0P00
00070?oooa;ooooo000Aooooool0ooooo`3ooolA0?ooo`030820P0000000000001L00000A@3oool0
1020P800000000000020P80a0?ooo`80000000<0P8200?ooo`3oool01@3ooolBooooo`004Ooooooo
0?ooool0oooo503oool30820P0030410@0000000000000T000001020P8190?ooo`040<30`0000000
00000820P300oooo00@0`<30000000000000`<301`3ooolBooooo`004Ooooooo0?ooool0ooooL@3o
ool300000300oooo0P0000090?oooa;ooooo000Aooooool0ooooo`3ooomb0?ooo`800000<03oool0
0`000000oooo0?ooo`080?oooa;ooooo000Aooooool0ooooo`3ooomc0?ooo`800000;@3oool00`20
P80000000<30`00:0?oooa;ooooo000Aooooool0ooooo`3ooomc0?ooo`030820P0000000000002/0
oooo00<0P8200000003oool02`3ooolBooooo`004Ooooooo0?ooool0ooooM03oool2000000030820
P03oool0oooo02P0oooo00<0P8200?ooo`3oool02`3ooolBooooo`004Ooooooo0?ooool0ooooM@3o
ool00`20P80000000820P00g0?oooa;ooooo000Aooooool0ooooo`3ooomf0?ooo`030820P0000000
000003H0oooo4_ooool0017oooooo`3ooooo0?ooogL0oooo00<000000?ooo`3oool0=@3ooolBoooo
o`004Ooooooo0?ooool0oooo[`3ooolBooooo`004Ooooooo0?ooool0oooo[`3ooolBooooo`00oooo
ooooooooom;ooooo003oooooooooooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;o
oooo003oooooooooooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;ooooo003ooooo
ooooooood_ooool00?oooooooooooooBooooo`00ooooooooooooom;ooooo003oooooooooooood_oo
ool00?oooooooooooooBooooo`00ooooooooooooom;ooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{240.125, 184.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 4.10  geometry assumed for the multipole expansion of Eq. ",
  ButtonBox["(4.3.77)",
    ButtonData:>"(4.3.77)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Caption",
  CellTags->"Fig. 4.10"],

Cell[TextData[{
  StyleBox["(17) ",
    FontWeight->"Bold"],
  "Find the electrostatic potential near the origin due to a hemispherical \
shell of charge, total charge ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  ", and radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ".  The shell is oriented above the origin of coordinates, with its origin \
coincident with the origin of coordinates, and its axis of symmetry along the \
",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis. Keep terms up to and including the quadrupole moments, and write \
the resulting potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in terms of Cartesian coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(18)(a)",
    FontWeight->"Bold"],
  " Consider an object of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " moving in gravitational free fall around a fixed mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " . At a given instant, the mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is located a distance ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o\)]],
  " along the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "axis of a coordinate system whose origin is located near (or within) the \
object. Using the fact that the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_G\)]],
  "also satisfies Poisson's equation,"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi]\_G = 4\ \[Pi]\ G\ \[Rho]\)]],
  ", "
}], "NE4",
  CellTags->{"i:110", "(4.3.78)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is the ",
  StyleBox["mass",
    FontSlant->"Italic"],
  " density and ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " is the gravitational constant, find a multipole expansion of the \
gravitational potential due to the mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " that is valid near the origin within the object. Keep terms in the \
expansion up to and including the quadrupole terms, and show that  the force \
in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction on a mass element ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\)]],
  " of the object,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\_z = \(-\[DifferentialD]m\) \
\[PartialD]\[Phi]\_G/\[PartialD]z\)]],
  ",  equals"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]F\_z = \[DifferentialD]m\ \(G(
            2\ \(\@\(\[Pi]/3\)\) \[Rho]\&_\_10 + 
              4\ \@\(\[Pi]/5\)\ \(\[Rho]\&_\_20\) z)\)\)]],
  " . "
}], "NE4",
  CellTags->"(4.3.79)"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " If one assumes that the mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is a point mass, then using Eq. ",
  ButtonBox["(4.3.79)",
    ButtonData:>"(4.3.79)",
    ButtonStyle->"Hyperlink"],
  ", show that the total force in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction on the object, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            FormBox["F",
              "TraditionalForm"], "z"], 
          "=", \(\[Integral]\[DifferentialD]F\_z\)}], TraditionalForm]]],
  ", is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`F\_z = G\ M\ m/r\_o\^2\)]],
  ", "
}], "Text"],

Cell[TextData[{
  StyleBox["provided that the coordinate system used to determine the \
multipole moments has its origin located at the center of mass of the object. \
",
    FontSlant->"Italic"],
  "The center of mass position ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["R",
            FontWeight->"Bold",
            FontSlant->"Plain"], "cm"], TraditionalForm]]],
  " is defined as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["R",
              FontWeight->"Bold",
              FontSlant->"Plain"], "cm"], "=", 
          RowBox[{\(1\/m\), 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{\(\[DifferentialD]m\_i\), 
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}]}]}]}], TraditionalForm]]],
  ", where the sum runs over all the mass elements ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]m\_i\)]],
  " of the object, each located at position ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "i"], TraditionalForm]]],
  ". [Hint: You will need to use Eq. ",
  ButtonBox["(4.3.75)",
    ButtonData:>"(4.3.75)",
    ButtonStyle->"Hyperlink"],
  " to help determine the multipole moments of the point mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".] "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " The object in question has a spatial extent in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction that runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\_1\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`z\_1\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z\_1\), " ", 
          RowBox[{"<<", " ", 
            StyleBox[\(r\_o\),
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  ". Using Eq. ",
  ButtonBox["(4.3.79)",
    ButtonData:>"(4.3.79)",
    ButtonStyle->"Hyperlink"],
  ", show that the acceleration of the point at ",
  Cell[BoxData[
      \(TraditionalForm\`\(+z\_1\)\)]],
  " relative to that at ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\_1\)\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`a\_t = 4  M\ G\ z\_1/r\_o\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  " This relative acceleration is called ",
  StyleBox["tidal acceleration",
    FontSlant->"Italic"],
  " .  [Hint: Equation ",
  ButtonBox["(4.3.75)",
    ButtonData:>"(4.3.75)",
    ButtonStyle->"Hyperlink"],
  " will be needed to help determine the multipole moments of the point mass \
",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".]"
}], "Text",
  CellTags->"i:85"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Determine the tidal acceleration caused by the moon, calculated for the \
two points on the earth nearest and farthest from the moon. Treat the moon as \
a point mass."
}], "Text"],

Cell[TextData[{
  StyleBox["(e) ",
    FontWeight->"Bold"],
  "Determine the tidal acceleration due to the sun, in the same manner as was \
used for the moon in part (d). "
}], "Text"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  " A neutron star has a mass ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2\ M\_sun\)]],
  ", but a radius of only around ",
  Cell[BoxData[
      \(TraditionalForm\`10\ km\)]],
  " . A rocket ship approaches the star in free fall, to a distance ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(r\_o\)\(=\)\),
            "TraditionalForm"], "3000", " ", "km"}], TraditionalForm]]],
  ".  Using Eq. ",
  ButtonBox["(4.3.79)",
    ButtonData:>"(4.3.79)",
    ButtonStyle->"Hyperlink"],
  ", calculate the tension force  (the tidal force) in a man floating inside \
the ship. Assume for simplicity that the mass distribution of the man is a \
uniform cylinder of total mass ",
  Cell[BoxData[
      \(TraditionalForm\`m = 70\ kg\)]],
  " and length ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[TextData[StyleBox["",
              FontSlant->"Italic"]]], "L"}], "=", 
          RowBox[{"2", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", oriented with the cylinder axis pointing toward the star, and treat the \
star as a point mass. The tension force is defined here as the force between \
the halves of the man nearest and furthest from the star as they are pulled \
toward and away from the star by the tidal acceleration. Evaluate the tension \
force in pounds.  (1 pound = 4.45 newtons.) [This problem is inspired by the \
science fiction novel ",
  StyleBox["Neutron Star",
    FontSlant->"Italic"],
  ", by ",
  ButtonBox["Larry Niven (1968)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ". Answer: ",
  Cell[BoxData[
      \(TraditionalForm\`T = M\ m\ G\ \(\(L/r\_o\^3\)\(\ \)\)\)]],
  ".]"
}], "Text",
  CellTags->"i:86"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " A deformable incompressible body, in the presence of another gravitating \
body (both bodies at fixed positions) will deform until it is in equilibrium, \
in such a way that its volume remains unchanged. The equilibrium shape of the \
deformable body can be determined using the fact that, in equilibrium, the \
gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_G\)]],
  " at the surface of the body is independent of position along the surface \
(i.e., the surface of the body is an equipotential). Take, for example, the \
earth-moon system. The earth will deform, attempting to come to equilibrium \
with the moon's gravitational attraction. (Actually, the earth's oceans \
deform. The rigidity of the solid part suppresses the response to the weak  \
lunar tidal acceleration.) This is the basic effect responsible for the \
earth's tides. "
}], "Text",
  CellTags->"i:87"],

Cell[TextData[{
  "\t Assuming that the earth is a deformable incompressible body of uniform \
mass density, that the moon is located a distance ",
  Cell[BoxData[
      \(TraditionalForm\`r\_o\)]],
  " from the earth along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(\ \)\)\)]],
  "axis of a coordinate system used to calculate the deformation (see Fig. ",
  ButtonBox["4.11",
    ButtonData:>"Fig. 4.11",
    ButtonStyle->"Hyperlink"],
  "), that the moon can be treated as a point mass,  and that the resulting \
deformation is small and in equilibrium with the moon's attraction, show that \
the height ",
  Cell[BoxData[
      \(TraditionalForm\`h(\[Theta])\)]],
  " of the deformation of the earth's surface is"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`h(\[Theta]) = \(\@\(\(5  \[Pi]\)\/4\)\) \(M\_m\/M\_e\
\) \(R\^4\/r\_o\^3\) \(\(Y\_\(2, \ 0\)\)(\[Theta])\)\)]],
  ","
}], "NE4",
  CellTags->"(4.3.80)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`M\_e\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " are the mass and radius of the earth respectively, and ",
  Cell[BoxData[
      \(TraditionalForm\`M\_m\)]],
  " is the mass of the moon. For the parameters of the earth-moon system, \
plot this deformation vs ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ", to show that the deformation is largest on the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis of our coordinate system at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ", stretching the earth along the earth-moon axis by an amount equal to \
roughly 0.5 meter at each end. "
}], "Text"],

Cell[TextData[{
  "[Hint: Remember to allow for the effect of the deformation on the earth on \
its own gravitational potential, using the multipole expansion of Eq. ",
  ButtonBox["(4.3.76)",
    ButtonData:>"(4.3.76)",
    ButtonStyle->"Hyperlink"],
  ". Keep only up to quadrupole terms in the expansions. Along these lines, \
the results given in Exercise (15) may be useful. The total gravitational \
potential evaluated at the earth's (deformed) surface ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\)]],
  " will be of the form"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_tot = \(\(-G\)\ M\_e\)\/\(r(\[Theta])\) - \
\[Alpha]\ \(\(Y\_\(2\ , 0\)\)(\[Theta])\) - \ \[Beta]\ \(\(Y\_\(2, \ 
                  0\)\)(\[Theta])\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where small deformation is assumed,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a constant proportional to the mass of the earth, and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  " is a constant proportional to the mass of the moon. The ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "-term is caused by the gravitational potential of the deformed earth, and \
the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\)]],
  "-term is caused by the moon. The surface of the earth is deformed so as to \
be described by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`r(\[Theta])\  = \ 
        R\  + \ \(\(h\_o\)\(\ \)\(\(Y\_\(2\ 0\)\)(\[Theta])\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(h\_o\), 
          RowBox[{"<<", " ", 
            StyleBox["R",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  "  is a constant to be determined by making sure that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_tot\)]],
  " is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  ".  But be careful: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is also proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`h\_o\)]],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " arises from the distortion of the earth. ]"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004?0003Gb000`400?l00000o`00003oo`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@
0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00g`3oool3000000030<30`03oool0oooo02X0oooo
003N0?ooo`040820P00000000000000002d0oooo003N0?ooo`040820P00000000000000002d0oooo
003N0?ooo`<00000;P3oool00=d0oooo00@0P820000000000000P820;P3oool00=d0oooo0`00000_
0?ooo`00g03oool300000300oooo003K0?ooo`040<30`000000000000410@300oooo003K0?ooo`<0
000000<0P8200?ooo`3oool0;P3oool00=/0oooo0`00000a0?ooo`00fP3oool400000340oooo003I
0?ooo`040820P000000000000820P380oooo003I0?ooo`<00000<`3oool00=P0oooo0`0000000`20
P800oooo0?ooo`0a0?ooo`00f03oool3000000030820P03oool0oooo0340oooo003G0?ooo`040410
@00000000000000003@0oooo003G0?ooo`<00000=@3oool00=H0oooo1000000e0?ooo`00e@3oool0
1020P800000000000000000f0?ooo`00e@3oool3000003L0oooo003D0?ooo`040820P00000000000
000003L0oooo003D0?ooo`040820P000000000000820P3L0oooo003D0?ooo`<00000>03oool00=<0
oooo0`00000i0?ooo`00dP3oool4000003T0oooo003A0?ooo`040820P00000000000000003X0oooo
003A0?ooo`<0000000<0P8200?ooo`3oool0>03oool00=00oooo00D0P82000000000000000000820
P00j0?ooo`00d03oool01020P800000000000000000k0?ooo`00d03oool3000000030820P03oool0
oooo03T0oooo003?0?ooo`<00000?@3oool00<h0oooo1000000m0?ooo`00c@3oool01020P8000000
00000000000n0?ooo`00c@3oool3000000030820P03oool0oooo03`0oooo003<0?ooo`050820P000
0000000000000020P800?P3oool00<`0oooo00@0P8200000000000000000?`3oool00<`0oooo0`00
00000`20P800oooo0?ooo`0m0?ooo`00b`3oool400000400oooo003;0?ooo`<00000@@3oool00<X0
oooo100000110?ooo`00b@3oool01020P800000000000010@4120?ooo`00b@3oool3000000030820
P03oool0oooo0400oooo00390?ooo`<00000@`3oool00<P0oooo0`0000000`20P800oooo0?ooo`11
0?ooo`00a`3oool4000004@0oooo00370?ooo`<00000A@3oool00;X0oooo00<0P820000000000000
0P0000070?ooo`@00000A@3oool00;X0oooo00<0P8200000000000001@0000001010@400P8200?oo
o`20P803000000030820P03oool0oooo04<0oooo002j0?ooo`l00000AP3oool00;X0oooo3`000016
0?ooo`00^P3oool>000000030820P030`<00oooo04@0oooo002j0?oooa000000A@3oool00;X0oooo
4P0000130?ooo`00^@3ooolC000000030820P03oool0oooo0400oooo002i0?oooa@0000000<0P820
0?ooo`3oool0?`3oool00;T0oooo5P0000100?ooo`00^@3ooolF00000400oooo001c0?ooo`030<30
`020P800P8200180P82000<0`<300?ooo`3oool0;@3oool00`20P80000000000000E000000030<30
`03oool0oooo03`0oooo001`0?oooa`00000;03ooolH000003l0oooo001]0?ooob80000000<0P820
0?ooo`3oool09P3ooolG00000400oooo001Y0?ooobX000009@3ooolF00000440oooo001T0?ooo`03
0<30`020P800P82000X000000`20P80D0?ooo`<0P8202P0000020820P240oooo500000000`10@400
oooo0?ooo`100?ooo`00H`3oool;00000240oooo2P00000N0?ooo`030820P0000000000001800000
@`3oool00640oooo00<0P8200000000000001P00000X0?ooo`P0000000<0P8200?ooo`3oool06P3o
ool00`20P80000000000000@000004D0oooo001M0?ooo`030<30`020P800000000H000000P20P800
0`30`<00oooo0?ooo`0X0?ooo`030<30`020P800P82000L0000000<0P8200<30`03oool05`3oool0
0`20P80000000000000?000000030<30`03oool0oooo04<0oooo001M0?ooo`L00000<`3oool00`20
P800000000000005000001P0oooo00<0P8200000000000003P0000170?ooo`00F`3oool7000003P0
oooo1`00000F0?ooo`030820P0000000000000d00000B03oool005X0oooo1`00000j0?ooo`L00000
5@3oool>000000030820P03oool0oooo04L0oooo001G0?ooo`80P8201@0000000`20P800oooo0?oo
o`0l0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool0403oool=000000030820P03o
ool0oooo01P0oooo0`20P80G0?ooo`80P82000<0`<300?ooo`3oool04@3oool005H0oooo1`000012
0?ooo`L000004@3oool<000001/0oooo00<0P8200000003oool06P3oool00`000000oooo0?ooo`0A
0?ooo`00E03oool7000004H0oooo1`00000?0?ooo`/0000000<0P8200?ooo`3oool06@3oool00`00
0000oooo0?ooo`0J0?ooo`030820P0000000oooo0140oooo001C0?ooo`L0000000<0P8200?ooo`3o
ool0A@3oool7000000030820P03oool0oooo00/0oooo2`00000K0?ooo`0300000020P800oooo01`0
oooo0P00000A0?ooo`00D@3oool00`20P800000000000002000000030410@020P800P82004X0oooo
0P20P8000`10@40000000000000200000080P8202P3oool:000000030820P03oool0oooo01T0oooo
0P0000000`30`<00oooo0?ooo`0K0?ooo`040820P000000000000<30`0l0oooo001?0?ooo`030820
P0000000000000<00000DP3oool5000000030820P03oool0oooo00L0oooo2@00000L0?ooo`030820
P000000000000200oooo00<000000820P03oool03P3oool004l0oooo1@00001D0?ooo`D000002@3o
ool8000000030820P03oool0oooo01X0oooo0P00000Q0?ooo`8000003`3oool004`0oooo00<0P820
0000000000000`0000000`20P800`<300?ooo`1D0?ooo`030820P0000000000000<0000000<0P820
0?ooo`3oool0103oool600000080P8202@3oool3000000L0oooo100000000`20P800oooo0?ooo`02
0?ooo`030820P0000000P82000X0oooo00<0P82000000010@4000`20P8000`10@400P8200?ooo`0>
0?ooo`030820P0000000P82000h0oooo001<0?ooo`D00000FP3oool5000000D0oooo1P00000=0?oo
o`<000001P3oool3000000040820P03oool000000820P080oooo0P00000:0?ooo`<00000103oool0
0`20P80000000000000?0?ooo`8000003P3oool004/0oooo00<0P8200000000000000P00001L0?oo
o`@0000000<0P8200?ooo`3oool00P3oool5000000030820P03oool0oooo00/0oooo0`0000060?oo
o`<0000000D0P8200?ooo`3oool000000?ooo`03000000T0oooo00<0P8200000000000001P3oool2
000000030820P03oool0oooo00`0oooo0`00000=0?ooo`00B`3oool4000005h0oooo100000040?oo
o`D000003P3oool3000000H0oooo0`0000001020P800oooo0?ooo`20P804000000T0oooo0`000007
0?ooo`8000003P3oool3000000d0oooo00190?ooo`050820P0000000000000000020P800G`3oool0
0`20P800000000000002000000030820P03oool0oooo0080000000<0@4100?ooo`3oool03`3oool2
000000030820P03oool0oooo00<0oooo00@0P8200000000000000000103oool2000000030820P03o
ool0oooo00L0oooo0`0000070?ooo`040820P000000000000820P0`0oooo00<0P820000000000000
3@3oool004P0oooo00@0P8200000000000000000H`3oool5000000030?ooo`00000000000180oooo
0`0000060?ooo`<000000`3oool3000000030820P03oool0oooo00L0oooo0`0000080?ooo`<00000
303oool01020P800000000000020P80<0?ooo`00A`3oool4000000030820P03oool0oooo0680oooo
1P00000C0?ooo`<000001P3oool3000000<0oooo0`0000000`20P800oooo0?ooo`070?ooo`<00000
203oool4000000/0oooo00@0P820000000000000P820303oool004D0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`1S0?ooo`030<30`020P800000000<0000000<0P8200?ooo`3oool0
403oool01020P800000000000020P8060?ooo`<000000P3oool3000000030820P03oool0oooo00L0
oooo0`0000080?ooo`040820P00000000000000000/0oooo00@0P820000000000000P820303oool0
04@0oooo00<0P8200000000000000P00001Z0?ooo`@0000000<0P8200?ooo`3oool03`3oool01020
P80000000000000000060?ooo`<000000P3oool3000000030820P03oool0oooo00L0oooo0`000008
0?ooo`050820P0000000000000000020P8002P3oool01020P800000000000020P80<0?ooo`00A03o
ool4000000030820P03oool0oooo06P0oooo00<0P8200000000000000P00000A0?ooo`040820P000
00000000000000H0oooo0`0000020?ooo`<0000000<0P8200?ooo`3oool01`3oool4000000L0oooo
00D0P82000000000000000000820P00:0?ooo`040820P000000000000820P0`0oooo00130?ooo`D0
0000K03oool500000140oooo100000060?ooo`<0000000D0oooo00000000000000000820P0090?oo
o`@00000203oool4000000X0oooo00@0P820000000000000P820303oool00440oooo00@0`<300000
0000000000000P20P81^0?ooo`80P8200`0000000`30`<00oooo0?ooo`0=0?ooo`<000000P20P805
0?ooo`<0000000D0oooo00000000000000000820P0090?ooo`@00000203oool4000000X0oooo00@0
P820000000000000P820303oool00440oooo0`0000000`20P800oooo0?ooo`1`0?ooo`040820P000
0000000000000100oooo0`0000000`3oool000000?ooo`030?ooo`<0000000D0P820000000000000
00000820P0090?ooo`@00000203oool4000000X0oooo00@0P820000000000000P820303oool00440
oooo0`0000000`20P800oooo0?ooo`1a0?ooo`@000003`3oool3000000030?ooo`000000oooo00<0
oooo00D0P820000000000000P8200?ooo`02000000030820P03oool0oooo00L0oooo00<0P8200000
000000003P0000090?ooo`030820P0000000000000d0oooo000o0?ooo`050820P000000000000000
0020P800M03oool01@20P8000000000000000000P82000h0oooo0`0000020?ooo`050820P03oool0
oooo0?ooo`20P8000P0000001@20P800oooo000000000000@41000T0oooo00D0P820000000000000
00000410@0080820P0@000002@3oool00`10@40000000000000=0?ooo`00?P3oool4000007P0oooo
1000000>0?ooo`<000000P3oool010000000oooo0?ooo`20P802000000030820P03oool000000080
00002@3oool01@20P8000000000000000000P82000P0oooo100000090?ooo`<000003@3oool003d0
oooo00D0P82000000000000000000820P01h0?ooo`050820P0000000000000000020P8003@3oool3
000000<0oooo1@0000000`20P800oooo0?ooo`02000000X0oooo0`0000000`20P800oooo0?ooo`06
0?ooo`@000002@3oool2000000h0oooo000m0?ooo`@00000NP3oool4000000d0oooo0`0000050?oo
o`<000000`3oool2000000X0oooo100000090?ooo`<000002@3oool2000000h0oooo000j0?ooo`80
P820100000000`20P800oooo0?ooo`1i0?ooo`@0000000<0P8200?ooo`3oool02@3oool01010@400
000000000020P80;0?ooo`8000002@3oool01020P80000000000000000090?ooo`<00000203oool2
000000l0oooo000j0?ooo`D00000>03oool:000000030820P03oool0oooo03T0oooo1@00000:0?oo
o`040820P00000000000000000/0oooo00<0P8200000003oool02@3oool3000000T0oooo0`000007
0?ooo`80000000<0P8200?ooo`3oool03@3oool003T0oooo00<0P8200000000000000P00000i0?oo
o`X0000000<0P8200?ooo`3oool0>P3oool4000000X0oooo00@0P8200000000000000000303oool2
000000X0oooo0`0000080?ooo`<000001`3oool200000100oooo000i0?ooo`@0000000<0P8200?oo
o`3oool09P3oool00`000000oooo0?ooo`0>0?ooo`X00000403oool5000002P0oooo00D0P8200000
0000000000000820P00:0?ooo`<0000000<0P8200?ooo`3oool02@3oool2000000030820P03oool0
oooo00L0oooo0`0000080?ooo`<000001P3oool300000100oooo000h0?ooo`030820P00000000000
0080000000<0`<300?ooo`3oool08@3oool30820P0<0000000<0P8200?ooo`3oool03@3oool:0820
P100oooo2P00000S0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool01`3oool30000
00030820P03oool0oooo00X0oooo00<0P8200410@03oool02@3oool00`10@4000000000000070?oo
o`80000000<0P8200?ooo`3oool00`3oool00`30`<0000000820P00A0?ooo`00=`3oool500000240
oooo00<0P8200000000000002000000Y0?ooo`X000009@3oool4000000T0oooo0`0000000`20P800
oooo0?ooo`0;0?ooo`030820P0000000oooo00T0oooo0`0000060?ooo`8000001P3oool00`000000
oooo0?ooo`0A0?ooo`00=`3oool400000280oooo00<0P8200000000000002000000]0?ooo`D00000
00<0P8200?ooo`3oool08`3oool5000000P0oooo1000000>0?ooo`8000002P3oool2000000030820
P03oool0oooo0080oooo0P0000000`20P800oooo0?ooo`030?ooo`0300000020P800oooo0180oooo
000f0?ooo`040410@00000000000000002@0oooo0`0000001010@400P8200820P030`<1L0?ooo`05
0820P0000000000000000010@4001@3oool30820P0<00000403oool00`20P800oooo0?ooo`080?oo
o`030820P010@400P8200080P82000<000000820P020P8001@3oool00`20P800oooo0?ooo`0C0?oo
o`00=@3oool4000000030820P03oool0oooo08H0oooo00@0P8200000000000000000B@3oool003D0
oooo100000290?ooo`030820P0000000000000800000B03oool003@0oooo1000001c0?ooo`030000
0020P800oooo01D0oooo1@0000170?ooo`00<`3oool4000000030820P03oool0oooo0180oooo0`20
P81K0?ooo`@000000P20P8000`30`<00oooo0?ooo`0A0?ooo`D00000AP3oool00380oooo00D0P820
00000000000000000820P00D0?ooo`@00000FP3oool00`20P800000000000006000001<0oooo00D0
P82000000000000000000820P0150?ooo`00<P3oool4000000030820P03oool0oooo0100oooo1P00
00000`20P800oooo0?ooo`1J0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool03`3o
ool01@20P8000000000000000000P82004D0oooo000a0?ooo`050820P0000000000000000020P800
3`3oool20820P0L0000000<0P8200<30`03oool0G@3oool20820P0<0000000<0P8200?ooo`3oool0
403oool01020P80000000000000000150?ooo`00<@3oool400000100oooo1P0000000`20P800oooo
0?ooo`1S0?ooo`800000503oool4000004@0oooo000`0?ooo`@000004@3oool5000005/0oooo00<0
P8200?ooo`3oool0803oool4000004<0oooo000_0?ooo`030820P00000000000008000004P3oool2
000000030820P03oool0oooo05T0oooo00<000000820P03oool08P3oool3000004<0oooo000_0?oo
o`040410@000000000000410@1<0oooo00<0P8200?ooo`3oool0FP3oool00`20P80000000820P00S
0?ooo`040410@000000000000820P480oooo000^0?ooo`@0000000<0P8200?ooo`3oool0K@3oool3
000000030820P03oool0oooo0240oooo00@0P8200000000000000000@P3oool002h0oooo1000001_
0?ooo`050820P0000000000000000020P800903oool300000480oooo000]0?ooo`@00000L03oool0
1@10@4000000000000000000P82002D0oooo0`0000000`20P800oooo0?ooo`0n0?ooo`00;03oool4
00000700oooo1@00000M0?ooo`030000003oool0oooo00L0oooo0`0000100?ooo`00;03oool40000
06l0oooo1P00000L0?ooo`@000001`3oool4000003l0oooo000[0?ooo`050820P000000000000000
0020P800KP3oool00`20P800000000000004000001/0oooo1@0000000`20P800oooo0?ooo`040?oo
o`040820P00000000000000003l0oooo000[0?ooo`050410@0000000000000000030`<001@3oool0
0`20P800@4100000001U0?ooo`030820P0000000000000D00000703oool00`20P800@41000000002
000000030820P03oool0oooo00<0oooo00D0`<3000000000000000000820P00n0?ooo`00:`3oool4
000000D0oooo1@00001R0?ooo`X000007P3oool6000000@0oooo1000000n0?ooo`00:`3oool30000
00D0oooo1@00001R0?ooo`030820P0000000000000P000007`3oool5000000030820P03oool0oooo
0080oooo0`00000n0?ooo`00:P3oool4000000@0oooo1@00001S0?ooo`/00000803oool5000000@0
oooo1000000m0?ooo`00:@3oool01@20P8000000000000000000P8200080oooo00<0P82000000000
00000P0000000`20P800`<300?ooo`1Q0?ooo`030820P0000000000000T000008@3oool01020P800
000000000030`<050?ooo`<0000000<0P8200?ooo`3oool0>P3oool002T0oooo100000020?ooo`03
0820P0000000000000800000I03oool=000002X0oooo1000000l0?ooo`00:03oool01020P8000000
0000000000040?ooo`<00000I@3oool=000002/0oooo1000000k0?ooo`00:03oool01010@4000000
00000010@4050?ooo`030820P030`<00oooo06<0oooo00<0@4100000000000002`00000[0?ooo`05
0410@0000000000000000030`<00>P3oool002P0oooo0`0000000`20P800oooo0?ooo`1X0?ooo`l0
0000:`3oool01@20P8000000000000000000P82003X0oooo000X0?ooo`<00000JP3oool@000002`0
oooo0`0000000`20P800oooo0?ooo`0h0?ooo`009`3oool4000006T0oooo4000000]0?ooo`@00000
>P3oool002H0oooo00@0P8200000000000000000J@3oool00`10@40000000000000>000002h0oooo
0`0000000`20P800oooo0?ooo`0g0?ooo`009P3oool3000006T0oooo4P00000_0?ooo`<00000>@3o
ool002D0oooo1000001X0?oooa<00000;`3oool4000003P0oooo000U0?ooo`<0000000<0@4100?oo
o`3oool0I@3oool00`20P80000000000000A000002l0oooo00D0P82000000000000000000<30`00g
0?ooo`00903oool01@20P8000000000000000000P82006H0oooo00<0P8200000000000004P00000`
0?ooo`<0000000<0P8200?ooo`3oool0=@3oool002@0oooo00@0P8200000000000000000I`3ooolE
00000300oooo1000000g0?ooo`00903oool4000006H0oooo5P00000`0?ooo`040820P00000000000
000003L0oooo000R0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0HP3oool00`30
`<0000000000000E00000340oooo100000000`20P800oooo0?ooo`0c0?ooo`008@3oool6000006D0
oooo6000000a0?ooo`H00000=03oool00200oooo00<0P8200000000000000`00001V0?ooo`030820
P0000000000001D00000<P3oool5000000030820P03oool0oooo0340oooo000P0?ooo`030410@000
000000000080000000<0P8200?ooo`3oool0IP3oool00`20P80000000000000C00000380oooo00<0
P8200000000000000P0000000`10@400oooo0?ooo`0a0?ooo`007`3oool6000006X0oooo00<0P820
0000000000004P00000c0?ooo`@0000000<0P8200?ooo`3oool0<@3oool001l0oooo1P00001/0?oo
oa800000=03oool4000003@0oooo000N0?ooo`H0000000<0P8200?ooo`3oool0J`3ooolA000003@0
oooo00@0P8200000000000000000=03oool001d0oooo00<0`<300820P0000000100000000`20P800
oooo0?ooo`1/0?ooo`030<30`020P800000000d00000=03oool01@20P8000000000000000000`<30
03<0oooo000P0?ooo`050820P0000000000000000020P800K`3oool?000003@0oooo00D0P8200000
0000000000000820P00c0?ooo`00803oool01020P800000000000000001`0?ooo`@000000P3oool9
000003D0oooo0`0000000`20P800oooo0?ooo`0a0?ooo`00803oool01010@400000000000000001_
0?ooo`050820P0000000000000000020P8000`3oool30820P0030410@0000000000000800000=@3o
ool4000003<0oooo000P0?ooo`<00000L03oool01020P80000000000000000120?ooo`<00000<`3o
ool00200oooo0`00001`0?ooo`@00000@P3oool3000003<0oooo000O0?ooo`@00000L03oool40000
0480oooo1000000b0?ooo`007`3oool3000000030820P03oool0oooo04H0oooo0P20P80600000003
0410@020P800P82000L0oooo00H0P82000000000000000000410@020P80?0?ooo`@00000A03oool3
00000380oooo000O0?ooo`<00000C03oool5000000X0oooo1000000@0?ooo`@00000A@3oool30000
0380oooo000N0?ooo`@00000C@3oool4000000T0oooo1@00000@0?ooo`@00000A@3oool400000340
oooo000N0?ooo`<00000CP3oool4000000T0oooo1000000A0?ooo`<00000A`3oool300000340oooo
000M0?ooo`040<30`00000000000000004h0oooo00D0P82000000000000000000820P0070?ooo`05
0820P0000000000000000020P800403oool4000004L0oooo0`0000000`30`<00oooo0?ooo`030?oo
o`030820P0000000oooo02P0oooo000M0?ooo`040820P000000000000820P4h0oooo00D0P8200000
0000000000000820P0070?ooo`@00000403oool01@20P8000000000000000000P82004L0oooo00@0
P820000000000000P8200`3oool00`20P800000000000002000002P0oooo000M0?ooo`040820P000
000000000820P4h0oooo00D0P82000000000000000000820P0060?ooo`030820P000000000000080
0000403oool01@20P8000000000000000000P82004L0oooo00@0P820000000000000P820103oool4
000002P0oooo000D0?ooo`030820P0000000@41000H0oooo00@0@410000000000000P820C`3oool4
000000H0oooo00D0P82000000000000000000820P00@0?ooo`040410@00000000000000004P0oooo
00@0P820000000000000@4101@3oool4000002L0oooo000D0?ooo`<000001P3oool300000500oooo
100000060?ooo`@000004@3oool4000004T0oooo0`0000060?ooo`@000009P3oool001<0oooo0`00
00000`20P800oooo0?ooo`040?ooo`<00000D03oool5000000D0oooo1000000@0?ooo`@00000BP3o
ool3000000H0oooo1000000V0?ooo`004`3oool3000000030820P03oool0oooo00@0oooo0`00001A
0?ooo`@00000103oool500000100oooo1000001:0?ooo`@000001@3oool01@20P800000000000000
0000P82002D0oooo000B0?ooo`040820P00000000000000000H0oooo0`0000000`20P800oooo0?oo
o`1?0?ooo`@00000103oool400000100oooo1000001<0?ooo`<000001@3oool01@30`<0000000000
00000000@41002D0oooo000B0?ooo`<000001`3oool3000005<0oooo2`00000@0?ooo`<00000C@3o
ool3000000H0oooo1000000U0?ooo`004P3oool3000000H0oooo1000001C0?ooo`@000001@3oool4
000000d0oooo00@0P8200000000000000000C@3oool4000002h0oooo000A0?ooo`<000001`3oool3
000005@0oooo100000070?ooo`050820P010@400000000000020P8002P3oool01010@40000000000
0010@41>0?ooo`<00000;P3oool00100oooo100000070?ooo`<00000E@3oool3000000030820P03o
ool0oooo00H0oooo0`00000:0?ooo`<0000000<0P8200?ooo`3oool0C03oool3000002h0oooo000J
0?ooo`@00000E@3oool3000000030820P03oool0oooo00H0oooo100000090?ooo`<00000C`3oool4
000002d0oooo000J0?ooo`<0000000<0P8200?ooo`3oool0D`3oool3000000030820P03oool0oooo
00L0oooo0`0000080?ooo`@00000C`3oool01020P800000000000000000]0?ooo`006P3oool30000
00030820P03oool0oooo05<0oooo00@0@41000000000000000002@3oool4000000H0oooo00D0P820
00000000000000000820P01?0?ooo`040820P00000000000000002d0oooo000J0?ooo`<0000000<0
P8200?ooo`3oool0D`3oool01020P80000000000000000090?ooo`@000001P3oool400000500oooo
00@0P8200000000000000000;@3oool001T0oooo00D0P82000000000000000000820P01E0?ooo`04
0820P00000000000000000T0oooo100000050?ooo`@00000D@3oool01@20P8000000000000000000
P82002`0oooo000I0?ooo`040820P00000000000000005H0oooo00<0`<300000000000000P000008
0?ooo`<0000000<0P8200?ooo`3oool00`3oool3000000030410@03oool0oooo0500oooo0`000000
0`20P800oooo0?ooo`0Z0?ooo`006@3oool01020P800000000000000001G0?ooo`@000001`3oool4
000000D0oooo00D0P82000000000000000000820P01B0?ooo`<0000000<0P8200?ooo`3oool0:P3o
ool001T0oooo00@0P8200000000000000000E`3oool4000000H0oooo00@0P8200000000000000000
1P3oool01@20P8000000000000000000P8200580oooo0`0000000`20P800oooo0?ooo`0Z0?ooo`00
6@3oool01020P800000000000000001F0?ooo`030820P0000000000000<00000103oool400000003
0820P03oool0oooo00@0oooo1000001C0?ooo`<0000000<0P8200?ooo`3oool0:P3oool001T0oooo
0`0000000`20P800oooo0?ooo`1B0?ooo`h0P8202@3oool3000000030820P03oool0oooo0540oooo
00@0P8200000000000000000;03oool001T0oooo0`00001[0?ooo`@00000E@3oool3000002`0oooo
000I0?ooo`<00000J`3oool4000005D0oooo0`00000/0?ooo`006@3oool3000006X0oooo1000001F
0?ooo`<00000303oool00`000000P8200?ooo`0M0?ooo`006@3oool3000006T0oooo00D0`<300000
0000000000000820P01F0?ooo`<0000000<0P8200?ooo`3oool01`3oool01020P800000000000010
@40N0?ooo`00603oool4000006T0oooo00@0P8200000000000000000F03oool3000000X0oooo0`00
000N0?ooo`00603oool3000006X0oooo00@0P820000000000000P820F03oool3000000X0oooo0`00
000N0?ooo`002P3oool01020P800000000000000000:0?ooo`<00000JP3oool3000000030820P03o
ool0oooo05H0oooo0`00000:0?ooo`<0000000<0P8200?ooo`3oool06`3oool000X0oooo0`00000;
0?ooo`<00000J@3oool4000005T0oooo0`00000;0?ooo`<000007@3oool000X0oooo0`00000;0?oo
o`<00000J@3oool4000000@0oooo00<000000?ooo`3oool0DP3oool3000000/0oooo0`00000M0?oo
o`002P3oool3000000/0oooo0`00001X0?ooo`@00000103oool400000580oooo0`00000;0?ooo`<0
00007@3oool000T0oooo0`0000000`20P800oooo0?ooo`080?ooo`040820P000000000000820P6P0
oooo0`0000001@20P800oooo0?ooo`3oool0P82000D000000P20P81@0?ooo`<000002P3oool01020
P800000000000000000L0?ooo`002@3oool3000000/0oooo0`00001X0?ooo`@000001P3oool00`20
P800000000000004000000030820P03oool0oooo04`0oooo0`00000Z0?ooo`00203oool4000000/0
oooo0`00001X0?ooo`@00000203oool6000004h0oooo0`00000Z0?ooo`00203oool3000000030820
P03oool0oooo00T0oooo0`00001W0?ooo`050820P0000000000000000020P8002P3oool00`20P800
000000000003000000030820P03oool0oooo04T0oooo0`00000Z0?ooo`00203oool3000000030820
P03oool0oooo00T0oooo0`00001W0?ooo`040820P00000000000000000d0oooo1@0000000`20P800
oooo0?ooo`180?ooo`<00000:P3oool001L0oooo0`00001W0?ooo`@000003P3oool00`20P8000000
00000003000004T0oooo0`00000Z0?ooo`005`3oool3000006L0oooo1000000?0?ooo`H00000B03o
ool3000002X0oooo000G0?ooo`<00000IP3oool400000140oooo00<0P8200000000000000`000000
0`20P800oooo0?ooo`140?ooo`040410@000000000000<30`2T0oooo000F0?ooo`040820P0000000
00000820P6D0oooo1000000D0?ooo`030820P0000000000000<00000A@3oool01020P80000000000
0020P80Y0?ooo`005P3oool01020P800000000000020P81U0?ooo`@000005P3oool5000004@0oooo
00@0P820000000000000P820:@3oool001H0oooo00@0P820000000000000P820I03oool01030`<00
000000000000000H0?ooo`@0000000<0`<300?ooo`3oool0@@3oool01020P800000000000020P80Y
0?ooo`005P3oool01020P800000000000020P81T0?ooo`040820P00000000000000001P0oooo00<0
P8200000000000000P0000130?ooo`040820P000000000000820P2T0oooo000F0?ooo`040820P000
000000000820P6@0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`D00000@P3oool01020P8000000
00000020P80Y0?ooo`005P3oool01020P800000000000020P80i0?ooo`030820P000000000000080
00009P3oool3000000030820P03oool0oooo01P0oooo100000120?ooo`040820P000000000000820
P2T0oooo000F0?ooo`040820P000000000000820P3L0oooo00<0P8200000000000000P0000030820
P00300000020P800oooo0240oooo00@0P82000000000000000006`3oool00`20P800000000000002
00000440oooo00@0P820000000000000P820:@3oool001H0oooo00@0P820000000000000P820=`3o
ool3000000L0oooo00<000000?ooo`3oool07`3oool4000001d0oooo0`0000000`20P800oooo0?oo
o`0n0?ooo`040820P000000000000820P2T0oooo000F0?ooo`040820P000000000000820P3H0oooo
100000080?ooo`030000003oool0oooo01d0oooo1000000N0?ooo`<0000000<0P8200?ooo`3oool0
?P3oool01020P800000000000020P80Y0?ooo`005P3oool01020P800000000000020P80f0?ooo`<0
000000<0P8200?ooo`3oool01`3oool00`20P800oooo0?ooo`0L0?ooo`@000007P3oool01020P800
00000000000000100?ooo`040820P000000000000820P2T0oooo000F0?ooo`040820P00000000000
0820P3H0oooo0`0000000`20P800oooo0?ooo`0U0?ooo`@00000803oool3000000030820P03oool0
oooo03d0oooo00@0P820000000000000P820303oool3000001X0oooo000F0?ooo`040820P0000000
00000820P3H0oooo0`0000000`20P800oooo0?ooo`0U0?ooo`<0000000<0P8200?ooo`3oool07`3o
ool300000400oooo0`00000<0?ooo`<000006P3oool001H0oooo0`00000g0?ooo`<0000000<0P820
0?ooo`3oool0903oool01@20P8000000000000000000P8200280oooo0`00000o0?ooo`<00000303o
ool3000001X0oooo00060?ooo`@0P820303oool3000003L0oooo00@0P82000000000000000000P20
P8000`10@400P8200820P00Q0?ooo`050410@0000000000000000030`<008P3oool3000000030820
P03oool0oooo03`0oooo0`00000<0?ooo`<000006P3oool000H0oooo1000000<0?ooo`<00000>03o
ool3000000<0oooo0`0000000`20P800oooo0?ooo`0M0?ooo`@000008`3oool01020P80000000000
0000000n0?ooo`<000003@3oool3000001T0oooo00060?ooo`@00000303oool3000003T0oooo0`00
00040?ooo`<000007P3oool3000002@0oooo00D0P82000000000000000000820P00m0?ooo`<00000
3@3oool3000001T0oooo00060?ooo`@00000303oool3000003T0oooo0`0000050?ooo`<00000703o
ool4000002D0oooo0`0000000`20P800oooo0?ooo`0k0?ooo`<000003@3oool3000001T0oooo0006
0?ooo`<000003@3oool3000001@0oooo2@20P8050?ooo`030820P03oool0oooo00@0oooo2`20P806
0?ooo`030410@0000000000000@0oooo00@0`<30000000000000@4106P3oool01@20P80000000000
00000000P82002D0oooo0`0000000`10@400oooo0?ooo`0k0?ooo`<000003@3oool3000001T0oooo
00060?ooo`<000003@3oool3000001H0oooo00@0P8200000000000000000203oool2000000L0oooo
00<0P820000000000000100000090?ooo`80000000<0P8200?ooo`3oool00P3oool4000001T0oooo
1000000W0?ooo`<00000?@3oool3000000d0oooo0`00000I0?ooo`001P3oool3000000d0oooo0`00
000G0?ooo`80000000<0P8200?ooo`3oool01P3oool2000000P0oooo1@00000;0?ooo`8000001@3o
ool3000001P0oooo1000000X0?ooo`@00000?03oool3000000d0oooo0`00000I0?ooo`001P3oool3
000000d0oooo0`00000H0?ooo`0300000020P800oooo00H0oooo0`0000000`10@400oooo0?ooo`06
0?ooo`@00000303oool00`10@400P8200?ooo`030?ooo`<00000603oool20820P00300000010@400
oooo02P0oooo0`00000l0?ooo`<00000:@3oool000H0oooo0`00000=0?ooo`<00000603oool20000
00L0oooo100000080?ooo`@000003@3oool300000080oooo0P00000I0?ooo`<0000000<0P8200?oo
o`3oool09`3oool3000003`0oooo0`00000Y0?ooo`001P3oool3000000d0oooo0`00000I0?ooo`03
0000003oool0oooo00D0oooo1@0000080?ooo`@000003`3oool3000000030820P03oool0oooo01L0
oooo0`0000000`20P800oooo0?ooo`0W0?ooo`<00000?03oool3000000`0oooo1000000I0?ooo`00
5P3oool3000001T0oooo00<000000?ooo`3oool01@3oool6000000L0oooo1000000/0?ooo`<00000
00<0P8200?ooo`3oool09`3oool3000003`0oooo0`00000<0?ooo`@000006@3oool001H0oooo0`00
000I0?ooo`030410@020P800oooo00@0oooo00H0`<3000000000000000000410@020P802000000H0
oooo100000000`30`<00oooo0?ooo`0Y0?ooo`<0000000<0P8200?ooo`3oool09`3oool01020P800
000000000020P80k0?ooo`<00000303oool4000001T0oooo000F0?ooo`<000006@3oool00`20P800
00000?ooo`040?ooo`050820P0000000000000000020P8000P3oool00`000000P8200?ooo`050?oo
o`<0000000<0P8200?ooo`3oool0:@3oool3000000030820P03oool0oooo02P0oooo0`00000k0?oo
o`<00000303oool4000001T0oooo000F0?ooo`<000006@3oool00`20P80000000?ooo`040?ooo`05
0820P0000000000000000020P8000P3oool2000000H0oooo0`0000000`20P800oooo0?ooo`0Y0?oo
o`<0000000<0P8200?ooo`3oool0:03oool3000003/0oooo0`00000<0?ooo`@000006@3oool001H0
oooo00@0P820000000000000P820603oool00`30`<0000000820P0040?ooo`050820P00000000000
00000020P8000`3oool00`10@400P8200?ooo`040?ooo`040410@000000000000410@2/0oooo0`00
00000`20P800oooo0?ooo`0X0?ooo`<00000>P3oool01030`<00000000000010@40<0?ooo`<00000
00<0P8200?ooo`3oool05`3oool001H0oooo00@0P820000000000000P8206@3oool2000000@0oooo
00D0P82000000000000000000820P0040?ooo`800000103oool01020P800000000000000000[0?oo
o`<0000000<0P8200?ooo`3oool0:03oool3000003X0oooo00@0P820000000000000P820303oool3
000001X0oooo000F0?ooo`040820P000000000000820P1T0oooo0P0000040?ooo`@000001@3oool2
000000050820P03oool0oooo0?ooo`20P8000`00000[0?ooo`<0000000<0P8200?ooo`3oool0:03o
ool3000003X0oooo00@0P820000000000000P820303oool3000001X0oooo000F0?ooo`040820P000
000000000820P1T0oooo0`0000030?ooo`@000001P3oool00`000000P8200?ooo`020?ooo`040820
P00000000000000002/0oooo0`0000000`20P800oooo0?ooo`0X0?ooo`<00000>P3oool01020P800
000000000020P80<0?ooo`<000006P3oool001H0oooo00@0P820000000000000P8206P3oool20000
00<0oooo100000070?ooo`0300000020P800oooo0080oooo1000000Z0?ooo`<0000000<0P8200?oo
o`3oool0:03oool3000003X0oooo00@0P820000000000000P820303oool3000001X0oooo000F0?oo
o`040820P000000000000820P1X0oooo0P0000030?ooo`@000001`3oool00`20P80000000?ooo`02
0?ooo`@00000:P3oool3000000030820P03oool0oooo02P0oooo0`00000j0?ooo`040820P0000000
00000820P2T0oooo000F0?ooo`040820P000000000000820P1/0oooo00@000000820P03oool0oooo
100000080?ooo`8000000P3oool5000002T0oooo0`0000000`20P800oooo0?ooo`0X0?ooo`<00000
>P3oool01020P800000000000020P80Y0?ooo`005P3oool01020P800000000000020P80K0?ooo`03
00000020P800oooo00@000002P3oool2000000030<30`03oool0000000<00000:@3oool300000003
0820P03oool0oooo02P0oooo0`00000j0?ooo`040820P000000000000820P2T0oooo000F0?ooo`04
0820P000000000000820P1/0oooo00<000000820P03oool01000000;0?ooo`0300000020P800oooo
00@00000:@3oool3000000030820P03oool0oooo02P0oooo0`00000j0?ooo`040820P00000000000
0820P2T0oooo000F0?ooo`040820P000000000000820P1`0oooo00<000000?ooo`0000000`00000<
0?ooo`030000003oool0oooo00@00000:03oool3000000030820P03oool0oooo02P0oooo0`00000j
0?ooo`040820P000000000000820P2T0oooo000F0?ooo`040820P000000000000820P1`0oooo00<0
00000?ooo`0000000`00000<0?ooo`030820P0000000oooo00@00000:03oool3000000030820P03o
ool0oooo02P0oooo0`00000j0?ooo`040820P000000000000820P2T0oooo000F0?ooo`040<30`000
000000000410@1`0oooo00<000000820P00000000P0000000`20P800oooo0?ooo`0:0?ooo`030<30
`0000000000000@00000:03oool3000000030820P03oool0oooo02L0oooo00@0P820000000000000
0000>P3oool01020P800000000000020P80Y0?ooo`001`3oool01020P800000000000000000<0?oo
o`<00000703oool00`20P800000000000002000000l0oooo1@0000000`20P800oooo0?ooo`0U0?oo
o`<0000000<0P8200?ooo`3oool09`3oool3000003/0oooo0`00000Z0?ooo`001`3oool01020P800
000000000000000<0?ooo`<00000703oool00`20P800000000000002000000l0oooo1@0000000`20
P800oooo0?ooo`0U0?ooo`<0000000<0P8200?ooo`3oool09`3oool3000003/0oooo0`00000Z0?oo
o`00203oool3000000030820P03oool0oooo00T0oooo0`00000L0?ooo`030820P000000000000080
0000403oool5000002L0oooo0`0000000`20P800oooo0?ooo`0V0?ooo`@00000>`3oool3000002X0
oooo00080?ooo`<0000000<0P8200?ooo`3oool02@3oool3000001T0oooo0`20P80500000100oooo
00<0`<300000000000000`0000020820P2@0oooo0`0000000`20P800oooo0?ooo`0V0?ooo`<00000
303oool50820P0030<30`03oool0oooo02P0oooo0`00000Z0?ooo`00203oool3000000030820P03o
ool0oooo00T0oooo0`00001M0?ooo`<0000000<0P8200?ooo`3oool09P3oool3000000/0oooo0P00
00001020P800oooo0?ooo`3oool2000002T0oooo0`00000Z0?ooo`00203oool4000000/0oooo0`00
001M0?ooo`<0000000<0P8200?ooo`3oool09@3oool4000000X0oooo00<0P820000000000000103o
ool00`20P80000000000000X0?ooo`<00000:P3oool000T0oooo0`00000;0?ooo`<00000G@3oool3
000000030820P03oool0oooo02@0oooo00D0`<3000000000000000000820P0090?ooo`030820P000
0000000000H0oooo00<0P82000000010@4009`3oool3000002X0oooo00090?ooo`<00000303oool3
000005`0oooo0`0000000`20P800oooo0?ooo`0T0?ooo`@0000000<0P8200?ooo`3oool01`3oool3
000000L0oooo0`00000U0?ooo`@00000:P3oool000T0oooo1000000;0?ooo`<00000G03oool30000
00030820P03oool0oooo02@0oooo1000000:0?ooo`<00000203oool3000002@0oooo0`00000[0?oo
o`002P3oool3000000/0oooo0`00001L0?ooo`<0000000<0P8200?ooo`3oool08`3oool4000000/0
oooo0`0000080?ooo`<00000903oool3000000/0oooo0`00000M0?ooo`00603oool3000005`0oooo
0`0000000`20P800oooo0?ooo`0R0?ooo`050820P0000000000000000020P8002`3oool3000000P0
oooo00@0@41000000000000000008`3oool3000000X0oooo00@0P82000000000000000007@3oool0
01P0oooo0`00001L0?ooo`<0000000<0P8200?ooo`3oool08P3oool4000000`0oooo0`0000080?oo
o`040820P00000000000000002<0oooo0`00000:0?ooo`<000007P3oool001P0oooo0`00001L0?oo
o`<0000000<0P8200?ooo`3oool08@3oool01020P800000000000000000=0?ooo`<00000203oool0
1@20P8000000000000000000P8200280oooo0`00000:0?ooo`<000007P3oool001P0oooo0`000000
0`20P800oooo0?ooo`1I0?ooo`<0000000<0P8200?ooo`3oool08@3oool01010@400000000000010
@40=0?ooo`@000001`3oool01@30`<000000000000000000@4100240oooo00@0P820000000000000
00002@3oool01030`<00000000000000000N0?ooo`006@3oool3000005/0oooo0`0000000`20P800
oooo0?ooo`0Q0?ooo`<0000000<0P8200?ooo`3oool02`3oool4000000P0oooo1000000Q0?ooo`<0
00002P3oool01020P800000000000020P80N0?ooo`006@3oool3000005/0oooo0`0000000`20P800
oooo0?ooo`0P0?ooo`@000003P3oool4000000P0oooo1000000Q0?ooo`<000002P3oool01020P800
000000000020P80N0?ooo`006@3oool3000005/0oooo0`0000000`20P800oooo0?ooo`0P0?ooo`@0
00003P3oool4000000P0oooo1000000Q0?ooo`<000002P3oool01020P800000000000020P80N0?oo
o`006@3oool3000005/0oooo0`0000000`20P800oooo0?ooo`0N0?ooo`030820P000000000000080
0000403oool@00000200oooo0`00000:0?ooo`<000007`3oool001T0oooo1000001J0?ooo`<00000
00<0P8200?ooo`3oool07@3oool00`20P80000000000000200000140oooo0`0000000`20P800oooo
0?ooo`060?ooo`@000007`3oool4000002`0oooo000I0?ooo`040820P00000000000000005X0oooo
0`0000000`20P800oooo0?ooo`0M0?ooo`@0000000<0P8200?ooo`3oool03`3oool3000000030820
P03oool0oooo00H0oooo1000000O0?ooo`<0000000<0P8200?ooo`3oool0:P3oool001T0oooo00@0
P8200000000000000000FP3oool3000000030820P03oool0oooo01/0oooo00<0P820000000000000
0P0000000`20P800oooo0?ooo`0@0?ooo`040820P000000000000410@0P0oooo00@0P82000000000
000000007`3oool3000000030820P03oool0oooo02X0oooo000I0?ooo`040820P000000000000000
05X0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`030820P0000000000000800000503oool01020
P80000000000000000090?ooo`<000007`3oool3000000030820P03oool0oooo02X0oooo000I0?oo
o`040820P00000000000000005X0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`@000005P3oool3
000000T0oooo0`00000O0?ooo`<0000000<0P8200?ooo`3oool0:P3oool001T0oooo00D0P8200000
0000000000000820P01I0?ooo`<0000000<0P8200?ooo`3oool06@3oool4000000030820P03oool0
oooo01@0oooo0`0000090?ooo`<000007`3oool3000000030820P03oool0oooo02X0oooo000A0?oo
o`030820P030`<00oooo00H0oooo0`0000000`20P800oooo0?ooo`1G0?ooo`<0000000<0P8200?oo
o`3oool05`3oool00`20P800000000000002000000030820P03oool0oooo01H0oooo0`0000080?oo
o`<000007P3oool01@20P8000000000000000000`<3002`0oooo000?0?ooo`<0000000<0P8200?oo
o`3oool01@3oool3000000030820P03oool0oooo05L0oooo0`0000000`20P800oooo0?ooo`0E0?oo
o`H000006`3oool3000000L0oooo0`00000N0?ooo`040820P00000000000000002d0oooo000?0?oo
o`@000001`3oool3000000030820P03oool0oooo05L0oooo0`0000000`20P800oooo0?ooo`0D0?oo
o`H0000000<0P8200?ooo`3oool06@3oool00`20P8000000000000070?ooo`8000007`3oool01020
P800000000000000000]0?ooo`003`3oool4000000L0oooo1000001I0?ooo`<0000000<0P8200?oo
o`3oool04P3oool00`20P800000000000005000001d0oooo0`0000060?ooo`8000007`3oool40000
02d0oooo000@0?ooo`@000001`3oool3000005T0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`03
0820P0000000000000@000000P20P80O0?ooo`030820P0000000@41000<0oooo00@0P82000000000
0000`<307`3oool3000002h0oooo000A0?ooo`@000001P3oool3000005T0oooo0`0000000`20P800
oooo0?ooo`0>0?ooo`P0000000<0P8200?ooo`3oool08@3oool00`20P80000000000000200000280
oooo0`00000^0?ooo`004@3oool4000000H0oooo1000001H0?ooo`<0000000<0P8200?ooo`3oool0
2`3oool00`20P800000000000007000004/0oooo1000000^0?ooo`004P3oool4000000H0oooo0`00
001H0?ooo`<0000000<0P8200?ooo`3oool01@3oool30820P0030410@0000000000000H000000P20
P81=0?ooo`<00000;`3oool00180oooo00D0P82000000000000000000820P0050?ooo`@00000E`3o
ool3000000030820P03oool0000000l0000000<0P8200?ooo`3oool0CP3oool3000002l0oooo000B
0?ooo`030820P0000000000000P0oooo0`00001G0?ooo`<0000000<0P8200?ooo`0000003@00001B
0?ooo`@000001@3oool00`20P80000000?ooo`0W0?ooo`007@3oool3000005L0oooo0`0000000`20
P800oooo00000009000005H0oooo0`0000060?ooo`@000009P3oool001d0oooo0`0000000`30`<00
oooo0?ooo`1D0?ooo`<0000000<0P8200?ooo`20P8001P20P81H0?ooo`040<30`000000000000000
00D0oooo00D0P82000000000000000000820P00V0?ooo`007@3oool01020P800000000000020P81F
0?ooo`<0000000<0P8200?ooo`3oool0GP3oool01020P800000000000020P8050?ooo`@000009`3o
ool001d0oooo00@0P820000000000000P820EP3oool3000000030820P03oool0oooo05h0oooo00@0
P820000000000000P820103oool4000002P0oooo000M0?ooo`040820P000000000000410@5H0oooo
0`0000000`20P800oooo0?ooo`1N0?ooo`040410@000000000000820P0<0oooo00D0`<3000000000
000000000820P00X0?ooo`007P3oool3000005H0oooo0`0000000`20P800oooo0?ooo`1N0?ooo`<0
0000103oool3000000030820P03oool0oooo02L0oooo000N0?ooo`<00000EP3oool3000000030820
P03oool0oooo05h0oooo0`0000030?ooo`@0000000<0P8200?ooo`3oool09`3oool001h0oooo1000
001E0?ooo`<0000000<0P8200?ooo`3oool0G@3oool4000000@0oooo0`00000Z0?ooo`007`3oool3
000005D0oooo0`0000000`20P800oooo0?ooo`1M0?ooo`<000001P3oool20820P2X0oooo000O0?oo
o`<00000E@3oool3000000030820P03oool0oooo05d0oooo0`00000b0?ooo`007`3oool4000005@0
oooo0`0000000`20P800oooo0?ooo`1L0?ooo`@00000<P3oool00200oooo0`00001D0?ooo`<00000
00<0P8200?ooo`3oool0G03oool3000003<0oooo000P0?ooo`@00000D`3oool3000000030820P03o
ool0oooo05/0oooo1000000c0?ooo`007@3oool01020P80000000?ooo`20P803000005<0oooo0`00
00000`20P800oooo0?ooo`1K0?ooo`@00000<`3oool001`0oooo0`0000000`3oool0P82000000002
000005<0oooo0`0000000`20P800oooo0?ooo`1K0?ooo`<0000000<0P8200?ooo`3oool0<@3oool0
01d0oooo0`0000001@10@4000000000000000000P8200580oooo0`0000000`20P800oooo0?ooo`1J
0?ooo`050<30`0000000000000000020P800<`3oool001d0oooo00<0P82000000000000010000000
0`20P800oooo0?ooo`1@0?ooo`<0000000<0P8200?ooo`3oool0FP3oool01020P800000000000000
000d0?ooo`007P3oool6000000030820P03oool0oooo0500oooo0`0000000`20P800oooo0?ooo`1J
0?ooo`040820P00000000000000003@0oooo000O0?ooo`H00000DP3oool3000000030820P03oool0
oooo05X0oooo1000000d0?ooo`007`3oool00`20P80000000000000300000580oooo0`0000000`20
P800oooo0?ooo`1J0?ooo`<0000000<0P8200?ooo`3oool0<P3oool00200oooo00<0P82000000000
00000`00001A0?ooo`<0000000<0P8200?ooo`3oool0F@3oool4000003D0oooo000P0?ooo`030820
P0000000000000<00000D@3oool3000000030820P03oool0oooo05T0oooo1000000e0?ooo`008@3o
ool20820P0@00000D03oool3000000030820P03oool0oooo05P0oooo1@0000000`20P800oooo0?oo
o`0b0?ooo`00903oool300000500oooo0`0000000`20P800oooo0?ooo`1G0?ooo`030820P0000000
000000800000=P3oool002@0oooo1000001?0?ooo`<0000000<0P8200?ooo`3oool0E`3oool40000
03L0oooo000T0?ooo`040820P00000000000000004l0oooo0`0000000`20P800oooo0?ooo`1F0?oo
o`@0000000<0P8200?ooo`3oool0=@3oool002@0oooo00D0`<3000000000000000000820P01>0?oo
o`<0000000<0P8200?ooo`3oool0E03oool00`20P800000000000003000000030820P03oool0oooo
03D0oooo000U0?ooo`@00000CP3oool3000000030820P03oool0oooo05D0oooo1@00000h0?ooo`00
9@3oool4000004h0oooo0`0000000`20P800oooo0?ooo`1F0?ooo`@00000>03oool002H0oooo0`00
00000`20P800oooo0?ooo`1;0?ooo`<0000000<0P8200?ooo`3oool0E@3oool01020P80000000000
0000000i0?ooo`009`3oool3000004d0oooo0`0000000`20P800oooo0?ooo`1E0?ooo`<00000>P3o
ool002L0oooo1000001<0?ooo`<0000000<0P8200?ooo`3oool0E03oool4000003X0oooo000X0?oo
o`<00000C03oool3000000030820P03oool0oooo05@0oooo0`0000000`20P800oooo0?ooo`0h0?oo
o`00:03oool3000000060820P03oool0oooo0820P0000000P820AP3oool3000000030820P03oool0
oooo05<0oooo00D0P82000000000000000000820P00j0?ooo`00:03oool01@20P800000000000000
0000oooo00D0000000<0P8200?ooo`3oool0@P3oool3000000030820P03oool0oooo05<0oooo1000
000k0?ooo`00:03oool01020P80000000000000000020?ooo`D00000A03oool3000000030820P03o
ool0oooo05<0oooo0`00000l0?ooo`00:@3oool400000080oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`100?ooo`<0000000<0P8200?ooo`3oool0DP3oool3000000030820P03oool0
oooo03X0oooo000Z0?ooo`@000000`3oool500000440oooo0`0000000`20P800oooo0?ooo`1B0?oo
o`<00000?@3oool002X0oooo100000040?ooo`@0000000<0P8200?ooo`3oool0?P3oool300000003
0820P03oool0oooo04P0oooo00<000000?ooo`3oool01P3oool3000003h0oooo000[0?ooo`<00000
103oool01@20P8000000000000000000P8200400oooo0`0000000`20P800oooo0?ooo`170?ooo`<0
00001`3oool3000003h0oooo000[0?ooo`040410@00000000000000000D0oooo0P20P8110?ooo`<0
000000<0P8200?ooo`3oool0A@3oool00`10@400000000000002000000030820P03oool0oooo00<0
oooo0`0000000`20P800oooo0?ooo`0l0?ooo`00:`3oool01@20P8000000000000000000P82004L0
oooo0`0000000`20P800oooo0?ooo`140?ooo`D000001P3oool01020P800000000000000000o0?oo
o`00;03oool3000000030820P03oool0oooo04D0oooo0`0000000`20P800oooo0?ooo`120?ooo`H0
00001`3oool01020P800000000000000000o0?ooo`00;03oool01@20P8000000000000000000P820
04H0oooo0`0000000`20P800oooo0?ooo`110?ooo`030820P000000000000080000000<0P8200?oo
o`3oool01@3oool01020P80000000000000000100?ooo`00;@3oool4000004H0oooo0`0000000`20
P800oooo0?ooo`110?ooo`040820P00000000000000000T0oooo0`0000110?ooo`00;@3oool50000
04D0oooo0`0000000`20P800oooo0?ooo`120?ooo`8000002@3oool400000440oooo000^0?ooo`@0
0000A@3oool3000000030820P03oool0oooo04d0oooo0`0000120?ooo`00;P3oool01@20P8000000
000000000000@4100140oooo00<0P8200?ooo`3oool0<03oool3000000030820P03oool0oooo04`0
oooo00@0@410000000000000@410@P3oool002l0oooo00@0P8200000000000000000403oool40000
0300oooo0`0000000`20P800oooo0?ooo`1<0?ooo`<0000000<0P8200?ooo`3oool0@03oool002l0
oooo00<0P8200000000000000P00000?0?ooo`D00000;`3oool3000000030820P03oool0oooo04/0
oooo100000130?ooo`00<03oool4000000h0oooo1`00000^0?ooo`<0000000<0P8200?ooo`3oool0
B`3oool4000004<0oooo000a0?ooo`@0000000<0P8200?ooo`3oool0303oool00`10@40000000000
0004000000030820P03oool0oooo02T0oooo0`0000000`20P800oooo0?ooo`0a0?ooo`80P82000<0
`<300?ooo`3oool04`3oool01@20P8000000000000000000P82004@0oooo000b0?ooo`@000004@3o
ool5000002/0oooo0`0000000`20P800oooo0?ooo`0_0?ooo`050820P0000000000000000020P800
5@3oool4000004D0oooo000b0?ooo`@0000000<0P8200?ooo`3oool03`3oool01020P80000000000
0020P80[0?ooo`<0000000<0P8200?ooo`3oool0;P3oool6000001@0oooo00D0P820000000000000
00000820P0150?ooo`00<P3oool01@30`<000000000000000000@4100180oooo0P20P8000`30`<00
oooo0?ooo`0Y0?ooo`<0000000<0P8200?ooo`3oool0:P3oool20820P0030410@0000000000000@0
000000<0P8200?ooo`3oool04@3oool00`20P800@41000000002000000030<30`03oool0oooo04<0
oooo000c0?ooo`D00000?`3oool3000000030820P03oool0oooo02X0oooo1`00000F0?ooo`D00000
AP3oool003@0oooo1000000o0?ooo`<0000000<0P8200?ooo`3oool0:`3oool4000000030820P03o
ool0oooo01@0oooo1@0000170?ooo`00=@3oool4000003h0oooo0`0000000`20P800oooo0?ooo`0[
0?ooo`800000603oool00`20P800000000000002000004P0oooo000e0?ooo`050820P00000000000
00000010@4008@3oool2000000030410@020P800P82001L0oooo0`0000000`20P800oooo0?ooo`15
0?ooo`050410@0000000000000000020P800B03oool003H0oooo00@0P8200000000000000000803o
ool00`20P800000000000005000001D0oooo0`0000000`20P800oooo0?ooo`140?ooo`@0000000<0
P8200?ooo`3oool0A`3oool003H0oooo00<0P8200000000000000P00000O0?ooo`030820P0000000
000000L0000000<0P8200?ooo`3oool0403oool3000000030820P03oool0oooo01P0oooo0P000000
0`20P800oooo0?ooo`0W0?ooo`@00000BP3oool003L0oooo00<0P8200000000000000P0000000`20
P800oooo0?ooo`0N0?ooo`80P8201@0000000`20P800oooo0?ooo`0@0?ooo`<0000000<0P8200?oo
o`3oool04@3oool40820P0H000009`3oool00`20P800000000000002000004/0oooo000i0?ooo`@0
0000903oool00`20P80000000000000C0?ooo`<0000000<0P8200?ooo`3oool04@3oool:000002H0
oooo00<0P8200000000000000P00001<0?ooo`00>@3oool4000000030820P03oool0oooo03@0oooo
2P0000000`20P800oooo0?ooo`0>0?ooo`L00000:03oool01@20P8000000000000000000P82004`0
oooo000i0?ooo`030820P0000000000000800000=P3oool:000000030820P03oool0oooo00h0oooo
1000000[0?ooo`@00000C@3oool003X0oooo1@0000000`20P800oooo0?ooo`0b0?ooo`X0000000<0
P8200?ooo`3oool0>`3oool00`20P800000000000002000000030820P03oool0oooo04/0oooo000k
0?ooo`H00000=P3oool3000000030820P03oool0oooo03h0oooo1@00001?0?ooo`00?@3oool40000
00030820P03oool0oooo03<0oooo0`0000000`20P800oooo0?ooo`0m0?ooo`030820P00000000000
00800000D03oool003d0oooo00<0`<300000000000000P00000e0?ooo`<0000000<0P8200?ooo`3o
ool0?@3oool01@10@4000000000000000000`<300500oooo000o0?ooo`@00000=03oool300000003
0820P03oool0oooo03`0oooo1000001B0?ooo`00@03oool4000003<0oooo0`0000000`20P800oooo
0?ooo`0k0?ooo`D00000DP3oool00400oooo100000000`20P800oooo0?ooo`0`0?ooo`<0000000<0
P8200?ooo`3oool0>P3oool00`20P800000000000002000005<0oooo00110?ooo`050410@0000000
000000000020P800<@3oool3000000030820P03oool0oooo03T0oooo00D0P8200000000000000000
0410@01D0?ooo`00@P3oool500000300oooo0`0000000`20P800oooo0?ooo`0h0?ooo`D00000E@3o
ool004<0oooo1@00000_0?ooo`<0000000<0P8200?ooo`3oool0=`3oool5000005H0oooo00140?oo
o`@0000000<0P8200?ooo`3oool0;03oool3000000030820P03oool0oooo03H0oooo00<0P8200000
000000000P00001G0?ooo`00A03oool00`30`<00000000000002000000030820P03oool0oooo02/0
oooo0`0000000`20P800oooo0?ooo`0e0?ooo`030820P000000000000080000000<0`<300?ooo`3o
ool0E@3oool004H0oooo1@00000/0?ooo`<0000000<0P8200?ooo`3oool0<`3oool00`20P8000000
00000003000005T0oooo00170?ooo`@0000000<0P8200?ooo`3oool0:@3oool3000000030820P03o
ool0oooo03<0oooo1@00001J0?ooo`00B03oool01@30`<000000000000000000P82002X0oooo0`00
00000`20P800oooo0?ooo`0a0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0F@3o
ool004X0oooo1000000Y0?ooo`<0000000<0P8200?ooo`3oool0<03oool5000005d0oooo001;0?oo
o`@00000:03oool3000000030820P03oool0oooo0300oooo1000001N0?ooo`00B`3oool00`20P800
000000000002000002L0oooo0`0000000`20P800oooo0?ooo`0_0?ooo`@0000000<0P8200?ooo`3o
ool0G03oool004`0oooo1@0000000`20P800oooo0?ooo`0S0?ooo`<0000000<0P8200?ooo`3oool0
;@3oool00`20P800000000000003000005l0oooo001=0?ooo`H0000000<0P8200?ooo`3oool08@3o
ool3000000030820P03oool0oooo02`0oooo1P00001P0?ooo`00C`3oool5000002<0oooo0`000000
0`20P800oooo0?ooo`0[0?ooo`D00000HP3oool004l0oooo00<0`<300820P00000000`0000000`20
P800`<300?ooo`0O0?ooo`<0000000<0P8200?ooo`3oool0:03oool00`30`<00P820000000040000
00030<30`03oool0oooo0600oooo001B0?ooo`L000007P3oool3000000030820P03oool0oooo02H0
oooo1`00001U0?ooo`00D`3oool7000001d0oooo0`0000000`20P800oooo0?ooo`0U0?ooo`L00000
00<0P8200?ooo`3oool0H`3oool005@0oooo1`00000L0?ooo`<0000000<0P8200?ooo`3oool0903o
ool7000006L0oooo001E0?ooo`80P8201P0000000`20P800oooo0?ooo`0G0?ooo`<0000000<0P820
0?ooo`3oool08@3oool00`30`<0000000000000400000080P820J03oool005P0oooo1`00000H0?oo
o`<0000000<0P8200?ooo`3oool0803oool7000006/0oooo001J0?ooo`L000005P3oool300000003
0820P03oool0oooo01h0oooo1`00001]0?ooo`00F`3oool20820P0D000000P20P80C0?ooo`<00000
00<0P8200?ooo`3oool06P3oool00`30`<00P8200820P006000000030820P03oool0oooo06`0oooo
001M0?ooo`030820P0000000000000H000004@3oool3000000030820P03oool0oooo01T0oooo2000
00000`20P800oooo0?ooo`1^0?ooo`00G`3oool9000000l0oooo0`0000000`20P800oooo0?ooo`0G
0?ooo`T00000LP3oool00640oooo2@00000=0?ooo`<0000000<0P8200?ooo`3oool05@3oool90000
07@0oooo001S0?ooo`030820P010@400000000L000001020P8060?ooo`<0000000<0P8200?ooo`3o
ool03`3oool30820P0P000000P20P81f0?ooo`00I`3oool=000000<0oooo0`0000000`20P800oooo
0?ooo`0;0?ooo`d00000NP3oool006P0oooo00<0P820000000000000:000001l0?ooo`00K03oool0
0`20P80000000000000P000000030820P03oool0oooo07d0oooo001`0?ooo`<0P82000<0@4100000
000000004P0000001@10@400P8200820P020P800`<300880oooo001g0?ooo`<0000000D0P8200?oo
o`3oool0oooo0820P02@0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0
000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3o
ool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool0
07L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980
oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?oo
o`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?oo
o`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820
P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`000000
0`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo01d0oooo1@00001`0?oo
o`00M`3oool3000000030820P03oool0oooo01`0oooo0P0000030?ooo`030820P0000000000006h0
oooo001g0?ooo`<0000000<0P8200?ooo`3oool06`3oool2000000030820P03oool0oooo00<0oooo
00<000000820P03oool0K03oool007L0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`030410@000
0000000000L0oooo00<0@41000000020P800J`3oool007L0oooo0`0000000`20P800oooo0?ooo`0J
0?ooo`<000001`3oool01020P800000000000000001Z0?ooo`00M`3oool3000000030820P03oool0
oooo01X0oooo0`0000080?ooo`<00000JP3oool007L0oooo0`0000000`20P800oooo0?ooo`0J0?oo
o`<00000203oool3000000030820P03oool0oooo06L0oooo001g0?ooo`<0000000<0P8200?ooo`3o
ool06P3oool3000000T0oooo0`00001Y0?ooo`00M`3oool3000000030820P03oool0oooo01X0oooo
0`0000000`20P800oooo0?ooo`070?ooo`<00000J03oool007L0oooo0`0000000`20P800oooo0?oo
o`0J0?ooo`040820P000000000000820P0T0oooo0`00001X0?ooo`00M`3oool3000000030820P03o
ool0oooo01X0oooo00@0P820000000000000@4102@3oool01020P800000000000000001W0?ooo`00
M`3oool3000000030820P03oool0oooo01/0oooo0`00000:0?ooo`<00000I`3oool007L0oooo0`00
00000`20P800oooo0?ooo`0L0?ooo`<000002@3oool3000006L0oooo001g0?ooo`<0000000<0P820
0?ooo`3oool02`3oool3000000h0oooo0`0000090?ooo`<00000I`3oool007L0oooo0`0000000`20
P800oooo0?ooo`0;0?ooo`040410@000000000000820P0h0oooo00@0@410000000000000P8201`3o
ool3000006L0oooo001g0?ooo`<0000000<0P8200?ooo`3oool02`3oool01020P800000000000000
000?0?ooo`<000001`3oool2000006P0oooo001g0?ooo`<0000000<0P8200?ooo`3oool02`3oool0
1020P800000000000000000@0?ooo`<000001@3oool3000006P0oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0303oool3000000030820P03oool0oooo00l0oooo00<0P82000000020P8000P20P802
000000030820P03oool0oooo06L0oooo001g0?ooo`<0000000<0P8200?ooo`3oool0303oool30000
00030820P03oool0oooo0800oooo001g0?ooo`<0000000<0P8200?ooo`3oool0303oool400000880
oooo001g0?ooo`<0000000<0P8200?ooo`3oool03@3oool300000880oooo001g0?ooo`<0000000<0
P8200?ooo`3oool03@3oool400000840oooo001g0?ooo`<0000000<0P8200?ooo`3oool03@3oool5
00000800oooo001g0?ooo`<0000000<0P8200?ooo`3oool03P3oool400000800oooo001g0?ooo`<0
000000<0P8200?ooo`3oool03P3oool300000080P820O`3oool007L0oooo0`0000000`20P800oooo
0?ooo`0?0?ooo`@00000O`3oool007L0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`<0000000<0
P8200000003oool0O@3oool007L0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`<0000000@0oooo
000000000000oooo0P00001j0?ooo`00M`3oool3000000030820P03oool0oooo00l0oooo0`000000
0`30`<00P82000000004000007T0oooo001g0?ooo`<0000000<0P8200?ooo`3oool02`3oool00`20
P800000000000004000000030820P03oool0oooo00@00000N@3oool007L0oooo0`0000000`20P800
oooo0?ooo`0?0?ooo`<0000000@0P8200?ooo`3oool0oooo0P00001j0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo
0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P820
0?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool300000003
0820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`00
00000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo0980oooo001g0?oo
o`<0000000<0P8200?ooo`3oool0TP3oool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00
M`3oool3000000030820P03oool0oooo0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3o
ool007L0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`00M`3oool3000000030820P03oool0oooo
0980oooo001g0?ooo`<0000000<0P8200?ooo`3oool0TP3oool00740oooo0`20P80=000000030820
P03oool0oooo08/0oooo001]0?oooaL00000R`3oool006`0oooo00<0P8200000000000005P000000
0`20P800oooo0?ooo`270?ooo`00K03oool00`30`<0000000000000F000000030820P03oool0oooo
08L0oooo001]0?oooaP00000RP3oool006d0oooo6000002:0?ooo`00KP3ooolG000008X0oooo001^
0?oooaH0000000<0P8200?ooo`3oool0R03oool006l0oooo5@00002;0?ooo`00K`3ooolE000008/0
oooo001_0?oooa@00000S03oool006l0oooo00<0P8200000000000004@00002<0?ooo`00L03ooolB
000008d0oooo001`0?oooa800000S@3oool00700oooo00<0P8200000000000003P0000000`10@400
oooo0?ooo`2;0?ooo`00L@3oool@000000030820P03oool0oooo08/0oooo001a0?oooa000000SP3o
ool00780oooo3`00002>0?ooo`00LP3oool>000000030820P03oool0oooo08`0oooo001c0?ooo`d0
0000S`3oool007<0oooo3@00002?0?ooo`00L`3oool00`10@40000000000000900000900oooo001c
0?ooo`030820P0000000000000P0000000<0P8200?ooo`3oool0SP3oool007<0oooo00<0P8200000
00000000200000000`20P800oooo0?ooo`2>0?ooo`00M03oool:000000030820P03oool0oooo08h0
oooo001d0?ooo`X00000T@3oool007D0oooo2000002B0?ooo`00M@3oool800000980oooo001e0?oo
o`030820P0000000000000@0000000<0P8200?ooo`3oool0T03oool007H0oooo1P00002C0?ooo`00
MP3oool00`20P800000000000002000009@0oooo001f0?ooo`030820P0000000000000800000U03o
ool007H0oooo00D0`<3000000000000000000410@0130?ooo`040<30`020P800P8200820P0L0oooo
0`20P8070?ooo`<0P820>@3oool007L0oooo0`0000000`20P800oooo0?ooo`110?ooo`040820P000
00000000000000L0oooo0`0000070?ooo`@00000>03oool007L0oooo0`0000000`20P800oooo0?oo
o`120?ooo`<0000000<0P8200?ooo`3oool0103oool01020P800000000000020P8060?ooo`<00000
00<0oooo0820P03oool0=P3oool007P0oooo0P0000150?ooo`<0000000<0P8200?ooo`3oool0103o
ool01020P800000000000020P8060?ooo`<0000000<0oooo0820P03oool0=P3oool007P0oooo0P00
00150?ooo`<0000000<0P8200?ooo`3oool0103oool01020P800000000000020P8060?ooo`<00000
00@0P8200?ooo`000000P820=@3oool00<00oooo0`0000070?ooo`<000001`3oool3000003P0oooo
001d0?ooo`L00000A@3oool3000000L0oooo0`0000070?ooo`<00000>03oool006l0oooo00<0P820
000000000000300000000`10@400P8200?ooo`0o0?ooo`@000001P3oool3000000030820P03oool0
oooo00@0oooo00@0@410000000000000`<30=`3oool006d0oooo500000000`20P800oooo0?ooo`0m
0?ooo`<000001`3oool3000000H0oooo00@0P820000000000000P820=`3oool006`0oooo00<0P820
0000000000001@0000070?ooo`L00000?`3oool4000000H0oooo100000050?ooo`040820P0000000
00000820P3L0oooo001/0?ooo`D000003@3oool6000003d0oooo100000000`20P800oooo0?ooo`03
0?ooo`@000001@3oool01020P800000000000020P80g0?ooo`00J@3oool00`20P800000000000003
000000030820P03oool0oooo00`0oooo00<0`<300820P0000000100000000`30`<00oooo0?ooo`0j
0?ooo`<0000000<0P8200?ooo`3oool0103oool4000000D0oooo0`00000g0?ooo`00J03oool00`20
P800000000000003000001<0oooo1@00000l0?ooo`<0000000<0P8200000003oool0103oool30000
00030?ooo`20P800oooo00<0oooo0`00000g0?ooo`00J03oool00`20P800000000000002000001D0
oooo1000000F0?ooo`T000001@3oool00`000000oooo0?ooo`040?ooo`/000001P3oool300000003
0820P0000000oooo00@0oooo0`0000000`3oool0P8200?ooo`030?ooo`@00000=P3oool006L0oooo
00<0P8200000000000000P00000H0?ooo`<0000000<0P8200?ooo`3oool0503oool01030`<000000
00000010@4080?ooo`8000001`3oool00`30`<00000000000003000000030820P03oool0oooo00H0
oooo00D0P820000000000000P8200?ooo`020820P0<0oooo00H0P82000000000000000000<30`000
00040?ooo`<00000=P3oool006L0oooo1000000J0?ooo`<0000000<0P8200?ooo`3oool05@3oool0
0`000000P8200?ooo`060?ooo`040820P000000000000820P0P0oooo100000090?ooo`040820P000
000000000820P0<0oooo00@0P8200?ooo`3oool0P8200`0000020?ooo`040000003oool0oooo0?oo
o`<00000=P3oool006H0oooo1000000K0?ooo`<0000000<0P8200?ooo`3oool05@3oool00`000000
P8200?ooo`060?ooo`040820P00000000000000000P0oooo100000090?ooo`040820P00000000000
000000<0oooo00@0P8200?ooo`3oool0P8200`0000030?ooo`0300000020P800oooo00<00000=P3o
ool006D0oooo1@00000K0?ooo`040820P00000000000000001L0oooo0P0000070?ooo`040820P000
00000000000000P0oooo100000070?ooo`H00000103oool6000000@0oooo1@00000f0?ooo`00I@3o
ool3000000030410@03oool0oooo01X0oooo00@0`<300000000000000000603oool00`000000oooo
0?ooo`050?ooo`030820P000000000000080000000<0P8200?ooo`3oool01@3oool4000000T0oooo
0`20P8060?ooo`<0P8201P3oool30820P3L0oooo001U0?ooo`<0000000<0P8200?ooo`3oool06`3o
ool3000001P0oooo00<000000?ooo`3oool01@3oool00`20P800000000000004000000H0oooo1000
001E0?ooo`00I03oool01020P800000000000000000O0?ooo`<000005`3oool00`20P80000000?oo
o`050?ooo`<0000000@0P8200?ooo`00000000001P3oool4000000030820P03oool0oooo0580oooo
001T0?ooo`040820P00000000000000001l0oooo0`00000G0?ooo`030820P0000000oooo00D0oooo
0`0000001@20P800oooo0?ooo`000000@41000H0oooo0`0000000`20P800oooo0?ooo`1B0?ooo`00
I03oool01020P800000000000000000O0?ooo`<000005`3oool00`20P80000000?ooo`050?ooo`<0
000000D0P8200?ooo`3oool0oooo000000060?ooo`<0000000<0P8200?ooo`3oool0DP3oool006@0
oooo00@0P8200000000000000000803oool3000001L0oooo0P0000050?ooo`<0000000H0P8200?oo
o`3oool0oooo0820P00000050?ooo`040820P00000000000000005@0oooo001T0?ooo`<000008@3o
ool3000001L0oooo0P0000050?ooo`<0000000<0P8200?ooo`3oool00P3oool2000000@0oooo00@0
P8200000000000000000E03oool006@0oooo0`00000Q0?ooo`<000005`3oool2000000040820P03o
ool0oooo0?ooo`@000001@3oool00`20P80000000820P0030?ooo`040820P00000000000000005@0
oooo001T0?ooo`@00000803oool3000001P0oooo0P0000030?ooo`@000001`3oool00`000000oooo
0?ooo`020?ooo`@00000D`3oool006@0oooo00@0P82000000000000000007`3oool3000001T0oooo
0P0000030?ooo`@000001`3oool2000000<0oooo1000001C0?ooo`00I03oool01020P80000000000
0000000O0?ooo`<000006@3oool00`20P80000000<30`0020?ooo`@000001`3oool00`30`<000000
0820P0020?ooo`@0000000<0P8200?ooo`3oool0D03oool006@0oooo00D0P8200000000000000000
0820P00N0?ooo`<000006P3oool00`000000P8200?ooo`04000000X0oooo0P0000020?ooo`@00000
DP3oool006D0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`@000006P3oool00`000000P8200?oo
o`04000000X0oooo0P0000000`20P800oooo0000000300000580oooo001U0?ooo`<0000000<0P820
0?ooo`3oool06`3oool3000001/0oooo00<000000820P03oool01000000;0?ooo`0300000020P800
oooo00@00000DP3oool006D0oooo1000000L0?ooo`040<30`00000000000000001`0oooo00<00000
0?ooo`0000000`00000<0?ooo`030410@020P800oooo00@00000D@3oool006H0oooo1000000K0?oo
o`<0000000<0P8200?ooo`3oool06P3oool00`000000oooo00000003000000`0oooo00<0P8200000
000000001000001A0?ooo`00IP3oool5000001X0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`D0
00003P3oool600000540oooo001W0?ooo`D00000603oool4000001d0oooo00<0P820000000000000
0P00000?0?ooo`D0000000<0P8200?ooo`3oool0CP3oool006P0oooo00D0@4100000000000000000
0<30`00E0?ooo`80P8200`00000N0?ooo`030820P00000000000008000003`3oool00`20P8000000
00000002000000030410@03oool0oooo04h0oooo001X0?ooo`030820P0000000000000<000004`3o
ool5000001l0oooo1@00000@0?ooo`030820P0000000000000<00000C`3oool006T0oooo1P00000A
0?ooo`D0000000<0P8200?ooo`3oool06P3oool800000140oooo1`00001=0?ooo`00J@3oool20820
P0D0000000<0P8200?ooo`3oool02`3oool00`20P800000000000003000000030820P030`<00oooo
08P0oooo001/0?ooo`030820P0000000000000D000001`3oool7000008d0oooo001]0?oooa@00000
00<0P8200?ooo`3oool0R`3oool006l0oooo4P00002>0?ooo`00K`3oool00`30`<00P8200820P002
0820P0L000001020P82@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3o
ool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3o
ool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3o
ool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3o
ool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00o`3oool@0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{90.5, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 4.11 Tidal effect in the earth-moon system (greatly \
exaggerated for clarity).\
\>", "Caption",
  CellTags->"Fig. 4.11"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4 The Wave and Heat Equations in Two and Three Dimensions", "Subtitle",
  CellTags->"c:33"],

Cell["", "Text"],

Cell[TextData[{
  "In a uniform medium, the wave and heat equations in one dimension have the \
form ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 
            z/\[PartialD]t\^2 = \(c\^2\) \[PartialD]\^2 
              z/\[PartialD]x\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T/\[PartialD]t = \[Chi] \[PartialD]\^2 
              T/\[PartialD]x\^2\)]],
  " respectively. In multiple spatial dimensions,  the obvious generalization \
of these equations is "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[PartialD]\^2 z/\[PartialD]t\^2\), "=", 
        RowBox[{\(c\^2\), 
          RowBox[{\(\[Del]\^2\), 
            RowBox[{"z", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}]}], TraditionalForm]]]], "NE5",
  CellTags->{"i:88", "(4.4.1)"}],

Cell["and ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]T/\[PartialD]t\), "=", 
          RowBox[{"\[Chi]", 
            RowBox[{\(\[Del]\^2\), 
              RowBox[{"T", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ","
}], "NE5",
  CellTags->{"i:89", "(4.4.2)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  " is the Laplacian operator. This generalization allows the evolution of \
disturbances without any distinction between different spatial directions: \
the equations are ",
  Cell[BoxData[
      FormBox[
        StyleBox["isotropic",
          FontSlant->"Italic"], TraditionalForm]]],
  " in space.  "
}], "Text"],

Cell[TextData[{
  "\tAs in the solution of Poisson's equation, we now consider solutions of \
the heat and wave equations within some specified volume ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ", which has a surface ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". Boundary conditions of either Dirichlet, ",
  "von Neumann",
  ", or mixed form are specified on this surface. Initial conditions must \
also be provided throughout the volume. As in the one-dimensional case, two \
initial conditions (on ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z/\[PartialD]t\)]],
  " ) are required for the wave equation, but only one initial condition \
specifying  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox[\(t = 0\),
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is required for the heat equation. "
}], "Text"],

Cell[TextData[{
  "\tGeneral solutions for these equations can be found. The form of the \
solutions is a generalized Fourier series of eigenmodes of the Laplacian \
operator, just as for the one-dimensional case discussed in Sec. ",
  ButtonBox["4.2",
    ButtonData:>"c:14",
    ButtonStyle->"Hyperlink"],
  ".  However, for most boundary  conditions, the eigenmodes cannot be \
determined analytically.  Analytically tractable solutions can be obtained \
only for those special geometries in which the eigenmodes are separable. \
(Numerical solutions can be found using methods to be discussed in Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  ".) In the following sections we consider several analytically-tractable \
examples. "
}], "Text"],

Cell[CellGroupData[{

Cell["4.4.1 Oscillations of a circular drumhead", "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{

Cell["General solution ", "Section",
  CellTags->"c:36"],

Cell[TextData[{
  "Consider a drum consisting of a 2D membrane stretched tightly over a \
circular ring in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane, of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". The membrane is free to vibrate in the transverse (",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ") direction, with an amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], t)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " are polar coordinates in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane. These vibrations satisfy the wave equation ",
  ButtonBox["(4.4.1)",
    ButtonData:>"(4.4.1)",
    ButtonStyle->"Hyperlink"],
  ". The wave propagation speed is ",
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(T/\[Sigma]\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is the tension force per unit length applied to the edge of the membrane, \
and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " is the mass per unit area of the membrane. Since the membrane is fixed to \
the ring at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ", the boundary condition on ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(a, \[Theta], t) = 0\)]],
  "."
}], "NE5",
  CellTags->"(4.4.3)"],

Cell["The initial conditions are", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`z(r, \[Theta], 0) = \(z\_o\)(
        r, \[Theta]), \[IndentingNewLine]\(\[PartialD]z\/\[PartialD]t\) \((r, \
\[Theta], 0)\) = \(v\_o\)(r, \[Theta])\)]]], "NE5",
  CellTags->"(4.4.4)"],

Cell[TextData[{
  "for some initial transverse displacement and velocity, ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  " respectively."
}], "Text"],

Cell[TextData[{
  "\tTo solve for the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", we use a generalized Fourier series:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], 
          t)\  = \ \[Sum]\+\[Alpha]\(\( c\_\[Alpha]\)(
              t)\)\ \(\(\[Psi]\_\[Alpha]\)(r, \[Theta])\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.5)"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(r, \[Theta])\)]],
  " are chosen to be eigenmodes of the Laplacian operator",
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\(\( \[Psi]\_\[Alpha]\)(
            r, \[Theta])\) = \(\[Lambda]\_\[Alpha]\) \(\(\[Psi]\_\[Alpha]\)(
            r, \[Theta])\)\)]],
  ","
}], "NE5",
  CellTags->"(4.4.6)"],

Cell[TextData[{
  "with boundary conditions identical to those on ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(a, \[Theta])\  = \ 0\)]],
  "."
}], "NE5",
  CellTags->"(4.4.7)"],

Cell["\<\
From our study of Poisson's equation, we already know the form of \
these eigenmodes:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\[Alpha]\)(
          r, \[Theta])\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\ \
\(\(J\_m\)(\(j\_\(m, \ n\)\) r/a)\)\)]],
  ","
}], "NE5",
  CellTags->"(4.4.8)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is any integer, ",
  Cell[BoxData[
      \(TraditionalForm\`J\_m\)]],
  " is a Bessel function, and ",
  Cell[BoxData[
      \(TraditionalForm\`j\_\(m, \ n\)\)]],
  " is the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th zero of ",
  Cell[BoxData[
      \(TraditionalForm\`J\_m\)]],
  " . The corresponding eigenvalues are"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_\[Alpha] = \(-\((j\_\(m, \ \
n\)/a)\)\^2\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.9)"],

Cell[TextData[{
  " Also, we know that these eigenmodes are orthogonal with respect to the \
inner product ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), "=", 
          RowBox[{\(\[Integral]\+\(r < a\)\), 
            RowBox[{
              RowBox[{\(f\^*\), "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{"g", "(", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}], 
              RowBox[{\(\[DifferentialD]\^2\), 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". We can therefore extract an ODE for the time evolution of the Fourier \
amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\[Alpha]\)(t)\)]],
  " in the usual manner. Substitution of Eq. ",
  ButtonBox["(4.4.5)",
    ButtonData:>"(4.4.5)",
    ButtonStyle->"Hyperlink"],
  "  into the wave equation, together with Eq. ",
  ButtonBox["(4.4.6)",
    ButtonData:>{"Chapter4.nb", "(4.4.6)"},
    ButtonStyle->"Hyperlink"],
  ", implies that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\[Alpha]\(\( \[Psi]\_\[Alpha]\)(
              r, \[Theta])\) \(\[DifferentialD]\^2\/\[DifferentialD]t\^2\) \(\
\(c\_\[Alpha]\)(
              t)\)\  = \(c\^2\) \(\[Sum]\+\[Alpha]\( \[Lambda]\_\[Alpha]\) \(\
\(c\_\[Alpha]\)(t)\)\ \(\(\[Psi]\_\[Alpha]\)(r, \[Theta])\)\)\)]],
  ". "
}], "NE5",
  CellTags->"(4.4.10)"],

Cell[TextData[{
  "Then an inner product with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\[Alpha]\)]],
  "  yields the harmonic oscillator equation, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]\^2\/\[DifferentialD]t\^2\) \
\(\(c\_\[Alpha]\)(t)\)\  = \(c\^2\) \(\[Lambda]\_\[Alpha]\) \(\(c\_\[Alpha]\)(
            t)\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.11)"],

Cell[TextData[{
  "Using Eq. ",
  ButtonBox["(4.4.9)",
    ButtonData:>"(4.4.9)",
    ButtonStyle->"Hyperlink"],
  "  we find that the  general solution is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_\[Alpha]\)(t) = 
        A\_\[Alpha]\ cos\ \[Omega]\_\[Alpha]\ t\  + \ 
          B\_\[Alpha]\ sin\ \[Omega]\_\[Alpha]\ t\)]],
  ","
}], "NE5",
  CellTags->"(4.4.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\[Alpha]\)]],
  " is the frequency associated with a given eigenmode,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\[Alpha] = \ j\_\(m, \ n\)\ c/a\)]],
  ","
}], "NE5",
  CellTags->"(4.4.13)"],

Cell[TextData[{
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\[Alpha]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\[Alpha]\)]],
  " are constants determined by the initial conditions. To determine ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\[Alpha]\)]],
  ",",
  " we evaluate Eq. ",
  ButtonBox["(4.4.5)",
    ButtonData:>"(4.4.5)",
    ButtonStyle->"Hyperlink"],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ",and using Eq. ",
  ButtonBox["(4.4.5)",
    ButtonData:>"(4.4.5)",
    ButtonStyle->"Hyperlink"],
  "  we find"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], 
          0)\  = \ \(\[Sum]\+\[Alpha] A\_\[Alpha]\ \(\(\[Psi]\_\[Alpha]\)(
                r, \[Theta])\) = \(z\_o\)(r, \[Theta])\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.14)"],

Cell["The usual  inner product argument then yields ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`A\_\[Alpha] = \((\[Psi]\_\[Alpha], 
            z\_o)\)/\((\[Psi]\_\[Alpha], \[Psi]\_\[Alpha])\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.15)"],

Cell[" Similarly, one finds that ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\[Alpha]\)]],
  Cell[BoxData[
      \(TraditionalForm\`B\_\[Alpha] = \((\[Psi]\_\[Alpha], 
            v\_o)\)/\((\[Psi]\_\[Alpha], \[Psi]\_\[Alpha])\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.16)"],

Cell["Thus, the solution takes the form", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], 
          t) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity]\(\[Sum]\+\(n = 1\
\)\%\[Infinity]\((\(A\_\(m\ n\)\) cos\ \(\[Omega]\_\(m\ n\)\) 
                    t\  + \ \(B\_\(m\ n\)\) 
                    sin\ \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)\) 
                    t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) \
\(\(J\_m\)(\(j\_\(m, \ n\)\) r/a)\)\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.17)"],

Cell["\<\
This completes the solution of the problem. One can see that, aside \
from the higher-dimensionality of the eigenmodes, the solution procedure is \
identical to that for the 1-dimensional string.\
\>", "Text"],

Cell[TextData[{
  "\tAlthough the eigenmodes are complex, the coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(m\ n\)\)]],
  "are also complex, so that the series sums to a real quantity.  In \
particular, Eqs. ",
  ButtonBox["(4.4.15)",
    ButtonData:>"(4.4.15)",
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(4.4.16)",
    ButtonData:>"(4.4.16)",
    ButtonStyle->"Hyperlink"],
  " imply that the coefficients satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(\(-m\)\ n\) = \(A\_\(m\ n\)\%*\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(\(-m\)\ n\) = \(B\_\(m\ n\)\%*\)\)]],
  ". Also, Eq. ",
  ButtonBox["(4.4.13)",
    ButtonData:>"(4.4.13)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(\(-m\)\ n\) = \ \[Omega]\_\(m\ n\)\)]],
  ". If we use these results in Eq. ",
  ButtonBox["(4.4.17)",
    ButtonData:>{"Chapter4.nb", "(4.4.17)"},
    ButtonStyle->"Hyperlink"],
  " we can write the solution as a sum only over nonnegative ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "  as "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`z(r, \[Theta], 
        t) = \[Sum]\+\(n = 1\)\%\[Infinity]\((\(A\_\(0\ n\)\) 
                  cos\ \(\[Omega]\_\(0\ n\)\) t\  + \ \(B\_\(0\ n\)\) 
                  sin\ \(\[Omega]\_\(\(0\)\(\ \)\(n\)\(\ \)\)\) 
                  t)\) \(\(J\_0\)(\(j\_\(0, \ n\)\) 
                r/a)\) + \ \[Sum]\+\(m = 1\)\%\[Infinity]\(\[Sum]\+\(n = \
1\)\%\[Infinity]\((\ \([\(A\_\(m\ n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \
\[Theta]\) + \(A\_\(m\ n\)\%*\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[Theta]\)]\) cos\ \(\[Omega]\_\(m\ n\)\) 
                    t\ \[IndentingNewLine]\ \ \ \ \ \ \ \  + \ \([\(B\_\(m\ n\
\)\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\) + \(B\_\(m\ n\)\%*\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[Theta]\)]\) 
                    sin\ \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)\) 
                    t\ )\)\ \(\(\(J\_m\)(\(j\_\(m, \ n\)\) 
                    r/a)\)\(.\)\)\)\)]]], "NE5",
  CellTags->"(4.4.18)"],

Cell[TextData[{
  "The quantities in the square brackets are real; for example, ",
  Cell[BoxData[
      \(TraditionalForm\`\(A\_\(m\ n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \
\[Theta]\) + \(A\_\(m\ n\)\%*\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[Theta]\)\)]],
  "= 2 Re(",
  Cell[BoxData[
      \(TraditionalForm\`\(A\_\(m\ n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ m\ \
\[Theta]\)\)]],
  "). In fact, if we write ",
  Cell[BoxData[
      \(TraditionalForm\`A\_\(m\ n\) = \(\(|\)\(A\_\(m\ n\)\)\(|\)\(\ \)\(\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\_\(m\ n\)\%A\)\)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(m\ n\) = \ \(\(|\)\(B\_\(m\ n\)\)\(|\)\(\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\_\(m\ n\)\%B\)\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(m\ n\)\%A\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(m\ n\)\%B\)]],
  "are the complex phases of the amplitudes, then Eq. ",
  ButtonBox["(4.4.18)",
    ButtonData:>"(4.4.18)",
    ButtonStyle->"Hyperlink"],
  " becomes "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`z(r, \[Theta], 
        t) = \[Sum]\+\(n = 1\)\%\[Infinity]\ \((\(A\_\(0\ n\)\) 
                  cos\ \(\[Omega]\_\(0\ n\)\) t\  + \ \(B\_\(0\ n\)\) 
                  sin\ \(\[Omega]\_\(\(0\)\(\ \)\(n\)\(\ \)\)\) 
                  t)\) \(\(J\_0\)(\(j\_\(0, \ n\)\) 
                r/a)\) + \[IndentingNewLine]\ 
        2 \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\[Sum]\+\(m = 1\)\%\[Infinity]\([\
\(|\)\(A\_\(m\ n\)\)\(|\)\(\(\(cos(\[Theta]\  + \ \[Phi]\_\(m\ n\)\%A)\) 
                        cos\ \(\[Omega]\_\(m\ n\)\) 
                        t\)\(\ \)\(+\)\)\(|\)\(B\_\(m\ n\)\)\(|\)\(\(cos(\
\[Theta]\  + \ \[Phi]\_\(m\ n\)\%B)\) \(sin\[Omega]\_\(m\ n\)\) 
                      t\)]\)\ \ \(\(\(J\_m\)(\(j\_\(m, \ n\)\) 
                      r/a)\)\(\ \)\(.\)\)\)\)\)]]], "NE5",
  CellTags->"(4.4.19)"],

Cell["\<\
This result is manifestly real, and shows directly that the complex \
part of the Fourier amplitudes merely produces a phase shift in the \
\[Theta]-dependence of the Fourier modes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Drumhead Eigenmodes", "Section",
  CellTags->{"i:90", "c:37"}],

Cell[TextData[{
  "\tThe cylindrically symmetric modes of the drumhead correspond to ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ", and have frequencies ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(\[Omega]\_\(0\ n\)\)\(=\)\),
            "TraditionalForm"], " ", 
          FormBox[\(j\_\(0, \ n\)\ c/a\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Unlike the modes of a uniform string, these frequencies are not \
commensurate:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_\(0\ 1\) = 
        2.4048255576957467`  c/a\)\(,\)\(\[Omega]\_\(0\ 2\) = 
        5.520078110286313`  c/a\)\(,\)\(\[Omega]\_\(0\ 3\) = 
        8.653727913113734`  c/a\)\(,\)\(...\)\(\ \)\)\)]]
}], "Text"],

Cell[TextData[{
  "These ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " modes have no \[Theta]-dependence. Like string modes, they are standing \
waves with stationary nodes at specific radial locations. In the lowest-order \
mode, the entire drumhead oscillates up and down, while in higher order modes \
different sections of the drumhead are oscillating 180\[Degree] out of phase \
with the center. One of these modes, the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0, \ n = 3\)]],
  " mode, is shown in Cell ",
  ButtonBox["4.41",
    ButtonData:>"Cell 4.41",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< NumericalMath`;\)\), "\[IndentingNewLine]", 
    \(\(\(j0 = BesselJZeros[0, 3];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][r_, \[Theta]_]\  := \ BesselJ[0, j0[\([3]\)]\ r]\ ;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        ParametricPlot3D[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], 
            Cos[t] \[Psi][r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2\ Pi}, 
          PlotRange \[Rule] {\(-1\), 1}, PlotPoints \[Rule] 25, 
          BoxRatios \[Rule] {1, 1, 1/2}], {t, 0, 
          1.8\ Pi, \  .2\ Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.41"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51721 .66482 m .51694 .65827 L .43899 .65168 L p .609 .14 .116 r
F P
0 g
s
.51694 .65827 m .51721 .66482 L .59289 .66066 L p .519 .068 .12 r
F P
0 g
s
.59289 .66066 m .59527 .65394 L .51694 .65827 L p .519 .068 .12 r
F P
0 g
s
.59527 .65394 m .59289 .66066 L .66526 .64611 L p .395 0 .079 r
F P
0 g
s
.66526 .64611 m .67023 .63881 L .59527 .65394 L p .395 0 .079 r
F P
0 g
s
.44192 .65848 m .43899 .65168 L .36521 .63435 L p .675 .18 .064 r
F P
0 g
s
.43899 .65168 m .44192 .65848 L .51721 .66482 L p .609 .14 .116 r
F P
0 g
s
.5175 .67031 m .51721 .66482 L .44192 .65848 L p .577 .081 .042 r
F P
0 g
s
.51721 .66482 m .5175 .67031 L .59045 .66631 L p .484 .007 .047 r
F P
0 g
s
.59045 .66631 m .59289 .66066 L .51721 .66482 L p .484 .007 .047 r
F P
0 g
s
.59289 .66066 m .59045 .66631 L .66016 .65234 L p .351 0 0 r
F P
0 g
s
.66016 .65234 m .66526 .64611 L .59289 .66066 L p .351 0 0 r
F P
0 g
s
.36521 .63435 m .3707 .64182 L .44192 .65848 L p .675 .18 .064 r
F P
0 g
s
.44492 .66422 m .44192 .65848 L .3707 .64182 L p .639 .117 0 r
F P
0 g
s
.44192 .65848 m .44492 .66422 L .5175 .67031 L p .577 .081 .042 r
F P
0 g
s
.67023 .63881 m .66526 .64611 L .73058 .62161 L p .207 0 0 r
F P
0 g
s
.73058 .62161 m .73799 .61332 L .67023 .63881 L p .207 0 0 r
F P
0 g
s
.3707 .64182 m .36521 .63435 L .29943 .6068 L p .709 .181 0 r
F P
0 g
s
.51779 .67306 m .5175 .67031 L .44492 .66422 L p .423 0 0 r
F P
0 g
s
.5175 .67031 m .51779 .67306 L .58791 .66922 L p .324 0 0 r
F P
0 g
s
.58791 .66922 m .59045 .66631 L .5175 .67031 L p .324 0 0 r
F P
0 g
s
.59045 .66631 m .58791 .66922 L .65488 .65582 L p .164 0 0 r
F P
0 g
s
.65488 .65582 m .66016 .65234 L .59045 .66631 L p .164 0 0 r
F P
0 g
s
.3707 .64182 m .37633 .64822 L .44492 .66422 L p .639 .117 0 r
F P
0 g
s
.44804 .66721 m .44492 .66422 L .37633 .64822 L p .466 0 0 r
F P
0 g
s
.44492 .66422 m .44804 .66721 L .51779 .67306 L p .423 0 0 r
F P
0 g
s
.66526 .64611 m .66016 .65234 L .723 .62884 L p .147 0 0 r
F P
0 g
s
.723 .62884 m .73058 .62161 L .66526 .64611 L p .147 0 0 r
F P
0 g
s
.29943 .6068 m .30731 .61535 L .3707 .64182 L p .709 .181 0 r
F P
0 g
s
.37633 .64822 m .3707 .64182 L .30731 .61535 L p .659 .108 0 r
F P
0 g
s
.5181 .67162 m .51779 .67306 L .44804 .66721 L p .205 .706 .911 r
F P
0 g
s
.51779 .67306 m .5181 .67162 L .58527 .66794 L p .277 .767 .908 r
F P
0 g
s
.58527 .66794 m .58791 .66922 L .51779 .67306 L p .277 .767 .908 r
F P
0 g
s
.58791 .66922 m .58527 .66794 L .64938 .65509 L p .392 .84 .926 r
F P
0 g
s
.64938 .65509 m .65488 .65582 L .58791 .66922 L p .392 .84 .926 r
F P
0 g
s
.37633 .64822 m .38217 .65187 L .44804 .66721 L p .466 0 0 r
F P
0 g
s
.45128 .66601 m .44804 .66721 L .38217 .65187 L p .186 .665 .931 r
F P
0 g
s
.44804 .66721 m .45128 .66601 L .5181 .67162 L p .205 .706 .911 r
F P
0 g
s
.66016 .65234 m .65488 .65582 L .71515 .6333 L p 0 0 0 r
F P
0 g
s
.71515 .6333 m .723 .62884 L .66016 .65234 L p 0 0 0 r
F P
0 g
s
.73799 .61332 m .73058 .62161 L .78507 .58802 L p 0 0 0 r
F P
0 g
s
.78507 .58802 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.51842 .66502 m .5181 .67162 L .45128 .66601 L p .646 .76 .932 r
F P
0 g
s
.5181 .67162 m .51842 .66502 L .58251 .66149 L p .648 .761 .932 r
F P
0 g
s
.58251 .66149 m .58527 .66794 L .5181 .67162 L p .648 .761 .932 r
F P
0 g
s
.30731 .61535 m .31538 .62284 L .37633 .64822 L p .659 .108 0 r
F P
0 g
s
.38217 .65187 m .37633 .64822 L .31538 .62284 L p .433 0 0 r
F P
0 g
s
.58527 .66794 m .58251 .66149 L .64363 .64919 L p .65 .763 .931 r
F P
0 g
s
.64363 .64919 m .64938 .65509 L .58527 .66794 L p .65 .763 .931 r
F P
0 g
s
.30731 .61535 m .29943 .6068 L .24558 .56996 L p .66 .118 0 r
F P
0 g
s
.38217 .65187 m .38824 .65131 L .45128 .66601 L p .186 .665 .931 r
F P
0 g
s
.45467 .65965 m .45128 .66601 L .38824 .65131 L p .645 .758 .931 r
F P
0 g
s
.45128 .66601 m .45467 .65965 L .51842 .66502 L p .646 .76 .932 r
F P
0 g
s
.51875 .65292 m .51842 .66502 L .45467 .65965 L p .714 .672 .808 r
F P
0 g
s
.51842 .66502 m .51875 .65292 L .57964 .64954 L p .689 .651 .807 r
F P
0 g
s
.57964 .64954 m .58251 .66149 L .51842 .66502 L p .689 .651 .807 r
F P
0 g
s
.65488 .65582 m .64938 .65509 L .70698 .63354 L p .527 .906 .949 r
F P
0 g
s
.70698 .63354 m .71515 .6333 L .65488 .65582 L p .527 .906 .949 r
F P
0 g
s
.73058 .62161 m .723 .62884 L .77528 .59666 L p 0 0 0 r
F P
0 g
s
.77528 .59666 m .78507 .58802 L .73058 .62161 L p 0 0 0 r
F P
0 g
s
.58251 .66149 m .57964 .64954 L .63766 .63777 L p .661 .633 .811 r
F P
0 g
s
.63766 .63777 m .64363 .64919 L .58251 .66149 L p .661 .633 .811 r
F P
0 g
s
.45467 .65965 m .4582 .64778 L .51875 .65292 L p .714 .672 .808 r
F P
0 g
s
.5191 .6357 m .51875 .65292 L .4582 .64778 L p .727 .625 .744 r
F P
0 g
s
.51875 .65292 m .5191 .6357 L .57668 .63248 L p .692 .595 .743 r
F P
0 g
s
.57668 .63248 m .57964 .64954 L .51875 .65292 L p .692 .595 .743 r
F P
0 g
s
.31538 .62284 m .32373 .62755 L .38217 .65187 L p .433 0 0 r
F P
0 g
s
.38824 .65131 m .38217 .65187 L .32373 .62755 L p .215 .64 .953 r
F P
0 g
s
.47308 .56247 m .47681 .54034 L .52052 .54431 L p .732 .596 .705 r
F P
0 g
s
.52052 .54431 m .52017 .56669 L .47308 .56247 L p .732 .596 .705 r
F P
0 g
s
.52087 .52563 m .52052 .54431 L .47681 .54034 L p .729 .616 .732 r
F P
0 g
s
.52017 .56669 m .52052 .54431 L .56449 .5417 L p .69 .562 .704 r
F P
0 g
s
.52052 .54431 m .52087 .52563 L .56149 .5232 L p .692 .585 .731 r
F P
0 g
s
.56149 .5232 m .56449 .5417 L .52052 .54431 L p .692 .585 .731 r
F P
0 g
s
.46932 .58632 m .47308 .56247 L .52017 .56669 L p .733 .589 .695 r
F P
0 g
s
.52017 .56669 m .51981 .59077 L .46932 .58632 L p .733 .589 .695 r
F P
0 g
s
.51981 .59077 m .52017 .56669 L .56753 .56392 L p .69 .553 .695 r
F P
0 g
s
.56449 .5417 m .56753 .56392 L .52017 .56669 L p .69 .562 .704 r
F P
0 g
s
.38824 .65131 m .39459 .64557 L .45467 .65965 L p .645 .758 .931 r
F P
0 g
s
.4582 .64778 m .45467 .65965 L .39459 .64557 L p .737 .697 .813 r
F P
0 g
s
.46556 .60976 m .46932 .58632 L .51981 .59077 L p .732 .591 .697 r
F P
0 g
s
.51981 .59077 m .51945 .61444 L .46556 .60976 L p .732 .591 .697 r
F P
0 g
s
.51945 .61444 m .51981 .59077 L .57059 .58784 L p .69 .555 .697 r
F P
0 g
s
.56753 .56392 m .57059 .58784 L .51981 .59077 L p .69 .553 .695 r
F P
0 g
s
.4582 .64778 m .46184 .63079 L .5191 .6357 L p .727 .625 .744 r
F P
0 g
s
.51945 .61444 m .5191 .6357 L .46184 .63079 L p .731 .601 .712 r
F P
0 g
s
.5191 .6357 m .51945 .61444 L .57365 .61136 L p .691 .568 .712 r
F P
0 g
s
.57365 .61136 m .57668 .63248 L .5191 .6357 L p .691 .568 .712 r
F P
0 g
s
.47681 .54034 m .48049 .52193 L .52087 .52563 L p .729 .616 .732 r
F P
0 g
s
.52121 .51235 m .52087 .52563 L .48049 .52193 L p .717 .661 .794 r
F P
0 g
s
.52087 .52563 m .52121 .51235 L .55854 .5101 L p .69 .639 .793 r
F P
0 g
s
.55854 .5101 m .56149 .5232 L .52087 .52563 L p .69 .639 .793 r
F P
0 g
s
.46184 .63079 m .46556 .60976 L .51945 .61444 L p .731 .601 .712 r
F P
0 g
s
.57059 .58784 m .57365 .61136 L .51945 .61444 L p .69 .555 .697 r
F P
0 g
s
.56753 .56392 m .56449 .5417 L .60621 .53264 L p .646 .53 .708 r
F P
0 g
s
.56449 .5417 m .56149 .5232 L .60001 .51474 L p .651 .557 .735 r
F P
0 g
s
.60001 .51474 m .60621 .53264 L .56449 .5417 L p .651 .557 .735 r
F P
0 g
s
.57964 .64954 m .57668 .63248 L .6315 .62123 L p .653 .569 .748 r
F P
0 g
s
.6315 .62123 m .63766 .63777 L .57964 .64954 L p .653 .569 .748 r
F P
0 g
s
.57059 .58784 m .56753 .56392 L .61251 .55428 L p .643 .52 .698 r
F P
0 g
s
.60621 .53264 m .61251 .55428 L .56753 .56392 L p .646 .53 .708 r
F P
0 g
s
.42892 .55145 m .43586 .52998 L .47681 .54034 L p .772 .635 .709 r
F P
0 g
s
.47681 .54034 m .47308 .56247 L .42892 .55145 L p .772 .635 .709 r
F P
0 g
s
.48049 .52193 m .47681 .54034 L .43586 .52998 L p .765 .651 .737 r
F P
0 g
s
.56149 .5232 m .55854 .5101 L .59392 .50226 L p .661 .62 .797 r
F P
0 g
s
.59392 .50226 m .60001 .51474 L .56149 .5232 L p .661 .62 .797 r
F P
0 g
s
.57365 .61136 m .57059 .58784 L .61886 .57766 L p .644 .522 .7 r
F P
0 g
s
.61251 .55428 m .61886 .57766 L .57059 .58784 L p .643 .52 .698 r
F P
0 g
s
.42192 .57467 m .42892 .55145 L .47308 .56247 L p .774 .628 .699 r
F P
0 g
s
.47308 .56247 m .46932 .58632 L .42192 .57467 L p .774 .628 .699 r
F P
0 g
s
.24558 .56996 m .25556 .58002 L .30731 .61535 L p .66 .118 0 r
F P
0 g
s
.31538 .62284 m .30731 .61535 L .25556 .58002 L p .581 .028 0 r
F P
0 g
s
.64938 .65509 m .64363 .64919 L .69846 .62857 L p .652 .763 .931 r
F P
0 g
s
.69846 .62857 m .70698 .63354 L .64938 .65509 L p .652 .763 .931 r
F P
0 g
s
.39459 .64557 m .40118 .63431 L .4582 .64778 L p .737 .697 .813 r
F P
0 g
s
.46184 .63079 m .4582 .64778 L .40118 .63431 L p .762 .659 .749 r
F P
0 g
s
.57668 .63248 m .57365 .61136 L .62521 .60064 L p .647 .537 .715 r
F P
0 g
s
.62521 .60064 m .6315 .62123 L .57668 .63248 L p .647 .537 .715 r
F P
0 g
s
.61886 .57766 m .62521 .60064 L .57365 .61136 L p .644 .522 .7 r
F P
0 g
s
.43586 .52998 m .4427 .51226 L .48049 .52193 L p .765 .651 .737 r
F P
0 g
s
.48411 .50892 m .48049 .52193 L .4427 .51226 L p .742 .688 .799 r
F P
0 g
s
.48049 .52193 m .48411 .50892 L .52121 .51235 L p .717 .661 .794 r
F P
0 g
s
.41491 .59749 m .42192 .57467 L .46932 .58632 L p .774 .63 .702 r
F P
0 g
s
.46932 .58632 m .46556 .60976 L .41491 .59749 L p .774 .63 .702 r
F P
0 g
s
.52155 .50566 m .52121 .51235 L .48411 .50892 L p .637 .763 .939 r
F P
0 g
s
.48767 .50252 m .52155 .50566 L p .50526 .50708 L .637 .763 .939 r
F P
0 g
s
.48411 .50892 m .48767 .50252 L p .50526 .50708 L .637 .763 .939 r
F P
0 g
s
.48767 .50252 m .45601 .49432 L p .45881 .49504 L 0 .426 .697 r
F P
0 g
s
.52155 .50566 m .48767 .50252 L p .49038 .50281 L .142 0 0 r
F P
0 g
s
.52121 .51235 m .52155 .50566 L p .54064 .50741 L .644 .77 .939 r
F P
0 g
s
.49118 .50334 m .52188 .50619 L p .50234 .50409 L .142 0 0 r
F P
0 g
s
.48767 .50252 m .49118 .50334 L p .50234 .50409 L .142 0 0 r
F P
0 g
s
.49118 .50334 m .48767 .50252 L p .45881 .49504 L 0 .426 .697 r
F P
0 g
s
.48767 .50252 m .48411 .50892 L .44941 .49997 L p .631 .755 .937 r
F P
0 g
s
.44941 .49997 m .45601 .49432 L .48767 .50252 L p .631 .755 .937 r
F P
0 g
s
.46253 .49592 m .49118 .50334 L p .47112 .49819 L 0 .426 .697 r
F P
0 g
s
.45601 .49432 m .46253 .49592 L p .47112 .49819 L 0 .426 .697 r
F P
0 g
s
.41924 .48595 m .42854 .48149 L .45601 .49432 L p .627 .747 .934 r
F P
0 g
s
.46253 .49592 m .45601 .49432 L .42854 .48149 L p 0 .439 .803 r
F P
0 g
s
.4377 .48432 m .46253 .49592 L p .44317 .4877 L 0 .439 .803 r
F P
0 g
s
.42854 .48149 m .4377 .48432 L p .44317 .4877 L 0 .439 .803 r
F P
0 g
s
.4377 .48432 m .42854 .48149 L .40703 .46472 L p .042 .468 .881 r
F P
0 g
s
.41833 .46918 m .4377 .48432 L p .42025 .47317 L .042 .468 .881 r
F P
0 g
s
.40703 .46472 m .41833 .46918 L p .42025 .47317 L .042 .468 .881 r
F P
0 g
s
.41833 .46918 m .4058 .45139 L p .41569 .46367 L 0 .062 .606 r
F P
0 g
s
.4377 .48432 m .41833 .46918 L p .43017 .47965 L .639 .106 0 r
F P
0 g
s
.45601 .49432 m .44941 .49997 L .41924 .48595 L p .627 .747 .934 r
F P
0 g
s
.42953 .48089 m .4468 .49436 L p .42812 .47783 L .639 .106 0 r
F P
0 g
s
.41833 .46918 m .42953 .48089 L p .42812 .47783 L .639 .106 0 r
F P
0 g
s
.42953 .48089 m .41833 .46918 L p .41569 .46367 L 0 .062 .606 r
F P
0 g
s
.41843 .46509 m .42953 .48089 L p .41397 .46154 L 0 .062 .606 r
F P
0 g
s
.4058 .45139 m .41843 .46509 L p .41397 .46154 L 0 .062 .606 r
F P
0 g
s
.41843 .46509 m .4144 .44794 L p .42401 .46952 L 0 .023 .595 r
F P
0 g
s
.42953 .48089 m .41843 .46509 L p .43131 .48472 L .659 .223 0 r
F P
0 g
s
.40976 .49709 m .41924 .48595 L .44941 .49997 L p .765 .718 .809 r
F P
0 g
s
.43103 .4853 m .44073 .49909 L p .42433 .47409 L .659 .223 0 r
F P
0 g
s
.41843 .46509 m .43103 .4853 L p .42433 .47409 L .659 .223 0 r
F P
0 g
s
.44073 .49909 m .42953 .48089 L p .43131 .48472 L .659 .223 0 r
F P
0 g
s
.4468 .49436 m .4377 .48432 L p .43017 .47965 L .639 .106 0 r
F P
0 g
s
.4427 .51226 m .44941 .49997 L .48411 .50892 L p .742 .688 .799 r
F P
0 g
s
.44941 .49997 m .4427 .51226 L .40976 .49709 L p .765 .718 .809 r
F P
0 g
s
.45591 .51087 m .4468 .49436 L .42953 .48089 L p .825 .348 0 r
F P
0 g
s
.42953 .48089 m .44073 .49909 L .45591 .51087 L p .825 .348 0 r
F P
0 g
s
.45202 .52228 m .44073 .49909 L .43103 .4853 L p .77 .348 0 r
F P
0 g
s
.43103 .4853 m .42758 .47036 L p .43882 .49834 L 0 0 .496 r
F P
0 g
s
.44371 .51051 m .45202 .52228 L p .43444 .49131 L .77 .348 0 r
F P
0 g
s
.43103 .4853 m .44371 .51051 L p .43444 .49131 L .77 .348 0 r
F P
0 g
s
.46512 .53236 m .45591 .51087 L .44073 .49909 L p .872 .431 .117 r
F P
0 g
s
.44073 .49909 m .45202 .52228 L .46512 .53236 L p .872 .431 .117 r
F P
0 g
s
.46351 .54837 m .45202 .52228 L .44371 .51051 L p .807 .393 0 r
F P
0 g
s
.44371 .51051 m .45658 .53861 L .46351 .54837 L p .807 .393 0 r
F P
0 g
s
.44371 .51051 m .44082 .49779 L p .45382 .53147 L 0 0 .452 r
F P
0 g
s
.45658 .53861 m .44371 .51051 L p .45382 .53147 L 0 0 .452 r
F P
0 g
s
.44371 .51051 m .43103 .4853 L p .43882 .49834 L 0 0 .496 r
F P
0 g
s
.43103 .4853 m .41843 .46509 L p .42401 .46952 L 0 .023 .595 r
F P
0 g
s
.46253 .49592 m .4377 .48432 L p .4507 .49278 L .712 .18 0 r
F P
0 g
s
.469 .5047 m .46253 .49592 L p .4507 .49278 L .712 .18 0 r
F P
0 g
s
.49118 .50334 m .46253 .49592 L p .47585 .50231 L .68 .18 .05 r
F P
0 g
s
.49468 .51133 m .49118 .50334 L p .47585 .50231 L .68 .18 .05 r
F P
0 g
s
.52188 .50619 m .52155 .50566 L p .49038 .50281 L .142 0 0 r
F P
0 g
s
.52155 .50566 m .55565 .5036 L p .54064 .50741 L .644 .77 .939 r
F P
0 g
s
.55565 .5036 m .55854 .5101 L .52121 .51235 L p .644 .77 .939 r
F P
0 g
s
.40118 .63431 m .40797 .61793 L .46184 .63079 L p .762 .659 .749 r
F P
0 g
s
.46556 .60976 m .46184 .63079 L .40797 .61793 L p .77 .639 .717 r
F P
0 g
s
.40797 .61793 m .41491 .59749 L .46556 .60976 L p .77 .639 .717 r
F P
0 g
s
.55854 .5101 m .55565 .5036 L .58793 .49642 L p .653 .774 .938 r
F P
0 g
s
.58793 .49642 m .59392 .50226 L .55854 .5101 L p .653 .774 .938 r
F P
0 g
s
.32373 .62755 m .33242 .62804 L .38824 .65131 L p .215 .64 .953 r
F P
0 g
s
.39459 .64557 m .38824 .65131 L .33242 .62804 L p .644 .756 .93 r
F P
0 g
s
.723 .62884 m .71515 .6333 L .76517 .60251 L p .401 .822 .643 r
F P
0 g
s
.76517 .60251 m .77528 .59666 L .723 .62884 L p .401 .822 .643 r
F P
0 g
s
.64363 .64919 m .63766 .63777 L .68962 .61806 L p .632 .619 .82 r
F P
0 g
s
.68962 .61806 m .69846 .62857 L .64363 .64919 L p .632 .619 .82 r
F P
0 g
s
.61251 .55428 m .60621 .53264 L .64325 .51755 L p .595 .499 .716 r
F P
0 g
s
.60621 .53264 m .60001 .51474 L .63414 .50066 L p .607 .532 .744 r
F P
0 g
s
.63414 .50066 m .64325 .51755 L .60621 .53264 L p .607 .532 .744 r
F P
0 g
s
.60001 .51474 m .59392 .50226 L .6252 .48925 L p .63 .605 .806 r
F P
0 g
s
.6252 .48925 m .63414 .50066 L .60001 .51474 L p .63 .605 .806 r
F P
0 g
s
.61886 .57766 m .61251 .55428 L .6525 .53821 L p .59 .487 .705 r
F P
0 g
s
.64325 .51755 m .6525 .53821 L .61251 .55428 L p .595 .499 .716 r
F P
0 g
s
.52155 .50566 m .52188 .50619 L .55278 .50432 L p .038 0 0 r
F P
0 g
s
.55278 .50432 m .55565 .5036 L .52155 .50566 L p .038 0 0 r
F P
0 g
s
.39028 .53413 m .4001 .51372 L .43586 .52998 L p .812 .68 .718 r
F P
0 g
s
.43586 .52998 m .42892 .55145 L .39028 .53413 L p .812 .68 .718 r
F P
0 g
s
.4427 .51226 m .43586 .52998 L .4001 .51372 L p .8 .693 .747 r
F P
0 g
s
.62521 .60064 m .61886 .57766 L .66186 .56065 L p .591 .49 .708 r
F P
0 g
s
.6525 .53821 m .66186 .56065 L .61886 .57766 L p .59 .487 .705 r
F P
0 g
s
.4001 .51372 m .40976 .49709 L .4427 .51226 L p .8 .693 .747 r
F P
0 g
s
.33242 .62804 m .34148 .62331 L .39459 .64557 L p .644 .756 .93 r
F P
0 g
s
.40118 .63431 m .39459 .64557 L .34148 .62331 L p .758 .726 .822 r
F P
0 g
s
.63766 .63777 m .6315 .62123 L .68051 .60241 L p .61 .546 .757 r
F P
0 g
s
.68051 .60241 m .68962 .61806 L .63766 .63777 L p .61 .546 .757 r
F P
0 g
s
.38036 .55633 m .39028 .53413 L .42892 .55145 L p .816 .675 .707 r
F P
0 g
s
.42892 .55145 m .42192 .57467 L .38036 .55633 L p .816 .675 .707 r
F P
0 g
s
.25556 .58002 m .26576 .589 L .31538 .62284 L p .581 .028 0 r
F P
0 g
s
.32373 .62755 m .31538 .62284 L .26576 .589 L p 0 .25 .683 r
F P
0 g
s
.59392 .50226 m .58793 .49642 L .61642 .4845 L p .662 .777 .934 r
F P
0 g
s
.61642 .4845 m .6252 .48925 L .59392 .50226 L p .662 .777 .934 r
F P
0 g
s
.55565 .5036 m .55278 .50432 L .58201 .49782 L p 0 0 0 r
F P
0 g
s
.59918 .49679 m .60212 .49345 L p .58201 .49782 L .163 0 0 r
F P
0 g
s
.58201 .49782 m .58793 .49642 L .56597 .5013 L p 0 0 0 r
F P
0 g
s
.58793 .49642 m .58201 .49782 L .60777 .48704 L p .382 .841 .781 r
F P
0 g
s
.60777 .48704 m .61642 .4845 L .58793 .49642 L p .382 .841 .781 r
F P
0 g
s
.60212 .49345 m .60777 .48704 L .58201 .49782 L p .163 0 0 r
F P
0 g
s
.56597 .5013 m .55565 .5036 L p .58201 .49782 L 0 0 0 r
F P
0 g
s
.6315 .62123 m .62521 .60064 L .67122 .58272 L p .598 .508 .723 r
F P
0 g
s
.66186 .56065 m .67122 .58272 L .62521 .60064 L p .591 .49 .708 r
F P
0 g
s
.67122 .58272 m .68051 .60241 L .6315 .62123 L p .598 .508 .723 r
F P
0 g
s
.37041 .57817 m .38036 .55633 L .42192 .57467 L p .815 .676 .71 r
F P
0 g
s
.42192 .57467 m .41491 .59749 L .37041 .57817 L p .815 .676 .71 r
F P
0 g
s
.34148 .62331 m .35087 .61304 L .40118 .63431 L p .758 .726 .822 r
F P
0 g
s
.40797 .61793 m .40118 .63431 L .35087 .61304 L p .795 .699 .759 r
F P
0 g
s
.71515 .6333 m .70698 .63354 L .75465 .60409 L p .65 .942 .961 r
F P
0 g
s
.75465 .60409 m .76517 .60251 L .71515 .6333 L p .65 .942 .961 r
F P
0 g
s
.36055 .59763 m .37041 .57817 L .41491 .59749 L p .809 .683 .726 r
F P
0 g
s
.41491 .59749 m .40797 .61793 L .36055 .59763 L p .809 .683 .726 r
F P
0 g
s
.35087 .61304 m .36055 .59763 L .40797 .61793 L p .795 .699 .759 r
F P
0 g
s
.79464 .57831 m .78507 .58802 L .82492 .54667 L p .52 .827 .507 r
F P
0 g
s
.82492 .54667 m .83625 .53514 L .79464 .57831 L p .52 .827 .507 r
F P
0 g
s
.26576 .589 m .27629 .59518 L .32373 .62755 L p 0 .25 .683 r
F P
0 g
s
.33242 .62804 m .32373 .62755 L .27629 .59518 L p .277 .623 .96 r
F P
0 g
s
.52222 .51387 m .52188 .50619 L .49118 .50334 L p .61 .137 .107 r
F P
0 g
s
.52188 .50619 m .52222 .51387 L .54993 .5122 L p .513 .059 .112 r
F P
0 g
s
.54993 .5122 m .55278 .50432 L .52188 .50619 L p .513 .059 .112 r
F P
0 g
s
.64325 .51755 m .63414 .50066 L .6617 .48168 L p .554 .508 .759 r
F P
0 g
s
.63414 .50066 m .6252 .48925 L .65039 .47172 L p .596 .594 .82 r
F P
0 g
s
.65039 .47172 m .6617 .48168 L .63414 .50066 L p .596 .594 .82 r
F P
0 g
s
.6525 .53821 m .64325 .51755 L .67325 .49716 L p .533 .468 .728 r
F P
0 g
s
.6617 .48168 m .67325 .49716 L .64325 .51755 L p .554 .508 .759 r
F P
0 g
s
.55278 .50432 m .54993 .5122 L .57613 .5064 L p .376 0 .067 r
F P
0 g
s
.57613 .5064 m .58201 .49782 L .55278 .50432 L p .376 0 .067 r
F P
0 g
s
.70698 .63354 m .69846 .62857 L .74371 .60044 L p .654 .763 .93 r
F P
0 g
s
.74371 .60044 m .75465 .60409 L .70698 .63354 L p .654 .763 .93 r
F P
0 g
s
.49118 .50334 m .49468 .51133 L .52222 .51387 L p .61 .137 .107 r
F P
0 g
s
.6252 .48925 m .61642 .4845 L .63931 .46848 L p .671 .778 .93 r
F P
0 g
s
.63931 .46848 m .65039 .47172 L .6252 .48925 L p .671 .778 .93 r
F P
0 g
s
.66186 .56065 m .6525 .53821 L .68501 .51647 L p .526 .453 .717 r
F P
0 g
s
.67325 .49716 m .68501 .51647 L .6525 .53821 L p .533 .468 .728 r
F P
0 g
s
.37183 .49236 m .38381 .47721 L .40976 .49709 L p .834 .742 .762 r
F P
0 g
s
.40976 .49709 m .4001 .51372 L .37183 .49236 L p .834 .742 .762 r
F P
0 g
s
.41924 .48595 m .40976 .49709 L .38381 .47721 L p .785 .753 .824 r
F P
0 g
s
.35962 .51135 m .37183 .49236 L .4001 .51372 L p .853 .734 .732 r
F P
0 g
s
.4001 .51372 m .39028 .53413 L .35962 .51135 L p .853 .734 .732 r
F P
0 g
s
.25556 .58002 m .24558 .56996 L .20758 .52532 L p 0 .039 .564 r
F P
0 g
s
.38381 .47721 m .39554 .4676 L .41924 .48595 L p .785 .753 .824 r
F P
0 g
s
.42854 .48149 m .41924 .48595 L .39554 .4676 L p .625 .739 .929 r
F P
0 g
s
.67122 .58272 m .66186 .56065 L .69691 .5376 L p .527 .457 .72 r
F P
0 g
s
.68501 .51647 m .69691 .5376 L .66186 .56065 L p .526 .453 .717 r
F P
0 g
s
.78507 .58802 m .77528 .59666 L .81336 .55711 L p .579 .885 .599 r
F P
0 g
s
.81336 .55711 m .82492 .54667 L .78507 .58802 L p .579 .885 .599 r
F P
0 g
s
.34727 .53216 m .35962 .51135 L .39028 .53413 L p .859 .73 .72 r
F P
0 g
s
.39028 .53413 m .38036 .55633 L .34727 .53216 L p .859 .73 .72 r
F P
0 g
s
.69846 .62857 m .68962 .61806 L .73238 .59122 L p .599 .61 .834 r
F P
0 g
s
.73238 .59122 m .74371 .60044 L .69846 .62857 L p .599 .61 .834 r
F P
0 g
s
.27629 .59518 m .28723 .5971 L .33242 .62804 L p .277 .623 .96 r
F P
0 g
s
.34148 .62331 m .33242 .62804 L .28723 .5971 L p .644 .754 .929 r
F P
0 g
s
.58201 .49782 m .57613 .5064 L .59918 .49679 L p .163 0 0 r
F P
0 g
s
.61642 .4845 m .60777 .48704 L .6284 .47257 L p .619 .959 .87 r
F P
0 g
s
.6284 .47257 m .63931 .46848 L .61642 .4845 L p .619 .959 .87 r
F P
0 g
s
.68051 .60241 m .67122 .58272 L .70886 .5584 L p .538 .479 .737 r
F P
0 g
s
.69691 .5376 m .70886 .5584 L .67122 .58272 L p .527 .457 .72 r
F P
0 g
s
.46253 .49592 m .469 .5047 L .49468 .51133 L p .68 .18 .05 r
F P
0 g
s
.68962 .61806 m .68051 .60241 L .72072 .57683 L p .561 .524 .772 r
F P
0 g
s
.72072 .57683 m .73238 .59122 L .68962 .61806 L p .561 .524 .772 r
F P
0 g
s
.33486 .55265 m .34727 .53216 L .38036 .55633 L p .857 .731 .723 r
F P
0 g
s
.38036 .55633 m .37041 .57817 L .33486 .55265 L p .857 .731 .723 r
F P
0 g
s
.70886 .5584 m .72072 .57683 L .68051 .60241 L p .538 .479 .737 r
F P
0 g
s
.39554 .4676 m .40703 .46472 L .42854 .48149 L p .625 .739 .929 r
F P
0 g
s
.28723 .5971 m .29862 .59377 L .34148 .62331 L p .644 .754 .929 r
F P
0 g
s
.35087 .61304 m .34148 .62331 L .29862 .59377 L p .776 .759 .837 r
F P
0 g
s
.32253 .57078 m .33486 .55265 L .37041 .57817 L p .848 .737 .74 r
F P
0 g
s
.37041 .57817 m .36055 .59763 L .32253 .57078 L p .848 .737 .74 r
F P
0 g
s
.20758 .52532 m .21921 .53728 L .25556 .58002 L p 0 .039 .564 r
F P
0 g
s
.26576 .589 m .25556 .58002 L .21921 .53728 L p 0 .129 .647 r
F P
0 g
s
.52255 .52796 m .52222 .51387 L .49468 .51133 L p .674 .278 .287 r
F P
0 g
s
.52222 .51387 m .52255 .52796 L .54707 .5265 L p .588 .208 .29 r
F P
0 g
s
.54707 .5265 m .54993 .5122 L .52222 .51387 L p .588 .208 .29 r
F P
0 g
s
.29862 .59377 m .31041 .58486 L .35087 .61304 L p .776 .759 .837 r
F P
0 g
s
.36055 .59763 m .35087 .61304 L .31041 .58486 L p .826 .746 .776 r
F P
0 g
s
.31041 .58486 m .32253 .57078 L .36055 .59763 L p .826 .746 .776 r
F P
0 g
s
.54993 .5122 m .54707 .5265 L .57023 .52141 L p .477 .11 .263 r
F P
0 g
s
.57023 .52141 m .57613 .5064 L .54993 .5122 L p .477 .11 .263 r
F P
0 g
s
.77528 .59666 m .76517 .60251 L .80143 .56473 L p .694 .978 .802 r
F P
0 g
s
.80143 .56473 m .81336 .55711 L .77528 .59666 L p .694 .978 .802 r
F P
0 g
s
.49819 .52573 m .49468 .51133 L .469 .5047 L p .748 .329 .253 r
F P
0 g
s
.49468 .51133 m .49819 .52573 L .52255 .52796 L p .674 .278 .287 r
F P
0 g
s
.60777 .48704 m .59918 .49679 L .61758 .48391 L p 0 0 0 r
F P
0 g
s
.61758 .48391 m .6284 .47257 L .60777 .48704 L p 0 0 0 r
F P
0 g
s
.67325 .49716 m .6617 .48168 L .68078 .45881 L p .489 .485 .78 r
F P
0 g
s
.6617 .48168 m .65039 .47172 L .66773 .45065 L p .558 .588 .84 r
F P
0 g
s
.66773 .45065 m .68078 .45881 L .6617 .48168 L p .558 .588 .84 r
F P
0 g
s
.65039 .47172 m .63931 .46848 L .65497 .44927 L p .678 .776 .924 r
F P
0 g
s
.65497 .44927 m .66773 .45065 L .65039 .47172 L p .678 .776 .924 r
F P
0 g
s
.68501 .51647 m .67325 .49716 L .69412 .47255 L p .453 .434 .747 r
F P
0 g
s
.68078 .45881 m .69412 .47255 L .67325 .49716 L p .489 .485 .78 r
F P
0 g
s
.4377 .48432 m .4468 .49436 L .469 .5047 L p .712 .18 0 r
F P
0 g
s
.57613 .5064 m .57023 .52141 L .59057 .51299 L p .313 0 .192 r
F P
0 g
s
.59057 .51299 m .59918 .49679 L .57613 .5064 L p .313 0 .192 r
F P
0 g
s
.35309 .46704 m .36671 .4537 L .38381 .47721 L p .866 .801 .785 r
F P
0 g
s
.38381 .47721 m .37183 .49236 L .35309 .46704 L p .866 .801 .785 r
F P
0 g
s
.39554 .4676 m .38381 .47721 L .36671 .4537 L p .8 .792 .845 r
F P
0 g
s
.36671 .4537 m .38002 .44594 L .39554 .4676 L p .8 .792 .845 r
F P
0 g
s
.40703 .46472 m .39554 .4676 L .38002 .44594 L p .626 .732 .923 r
F P
0 g
s
.63931 .46848 m .6284 .47257 L .64244 .45525 L p .776 .985 .901 r
F P
0 g
s
.64244 .45525 m .65497 .44927 L .63931 .46848 L p .776 .985 .901 r
F P
0 g
s
.47549 .51992 m .469 .5047 L .4468 .49436 L p .809 .359 .17 r
F P
0 g
s
.469 .5047 m .47549 .51992 L .49819 .52573 L p .748 .329 .253 r
F P
0 g
s
.69691 .5376 m .68501 .51647 L .70775 .49018 L p .44 .415 .734 r
F P
0 g
s
.69412 .47255 m .70775 .49018 L .68501 .51647 L p .453 .434 .747 r
F P
0 g
s
.21921 .53728 m .23107 .54814 L .26576 .589 L p 0 .129 .647 r
F P
0 g
s
.27629 .59518 m .26576 .589 L .23107 .54814 L p 0 .351 .822 r
F P
0 g
s
.33917 .48428 m .35309 .46704 L .37183 .49236 L p .893 .801 .751 r
F P
0 g
s
.37183 .49236 m .35962 .51135 L .33917 .48428 L p .893 .801 .751 r
F P
0 g
s
.76517 .60251 m .75465 .60409 L .78906 .56805 L p .736 .941 .951 r
F P
0 g
s
.78906 .56805 m .80143 .56473 L .76517 .60251 L p .736 .941 .951 r
F P
0 g
s
.38002 .44594 m .39303 .44498 L .40703 .46472 L p .626 .732 .923 r
F P
0 g
s
.41833 .46918 m .40703 .46472 L .39303 .44498 L p .197 .49 .901 r
F P
0 g
s
.70886 .5584 m .69691 .5376 L .72157 .50967 L p .443 .419 .737 r
F P
0 g
s
.70775 .49018 m .72157 .50967 L .69691 .5376 L p .44 .415 .734 r
F P
0 g
s
.32505 .5034 m .33917 .48428 L .35962 .51135 L p .902 .8 .738 r
F P
0 g
s
.35962 .51135 m .34727 .53216 L .32505 .5034 L p .902 .8 .738 r
F P
0 g
s
.59918 .49679 m .59057 .51299 L .60677 .50172 L p .04 0 .042 r
F P
0 g
s
.60677 .50172 m .61758 .48391 L .59918 .49679 L p .04 0 .042 r
F P
0 g
s
.6284 .47257 m .61758 .48391 L .63005 .46852 L p .619 .883 .555 r
F P
0 g
s
.63005 .46852 m .64244 .45525 L .6284 .47257 L p .619 .883 .555 r
F P
0 g
s
.75465 .60409 m .74371 .60044 L .77621 .56607 L p .656 .763 .928 r
F P
0 g
s
.77621 .56607 m .78906 .56805 L .75465 .60409 L p .656 .763 .928 r
F P
0 g
s
.23107 .54814 m .2433 .55617 L .27629 .59518 L p 0 .351 .822 r
F P
0 g
s
.28723 .5971 m .27629 .59518 L .2433 .55617 L p .35 .611 .947 r
F P
0 g
s
.72072 .57683 m .70886 .5584 L .73547 .52886 L p .462 .448 .756 r
F P
0 g
s
.72157 .50967 m .73547 .52886 L .70886 .5584 L p .443 .419 .737 r
F P
0 g
s
.52289 .54701 m .52255 .52796 L .49819 .52573 L p .692 .325 .348 r
F P
0 g
s
.52255 .52796 m .52289 .54701 L .54417 .54575 L p .61 .259 .35 r
F P
0 g
s
.54417 .54575 m .54707 .5265 L .52255 .52796 L p .61 .259 .35 r
F P
0 g
s
.4468 .49436 m .45591 .51087 L .47549 .51992 L p .809 .359 .17 r
F P
0 g
s
.31084 .52222 m .32505 .5034 L .34727 .53216 L p .899 .8 .742 r
F P
0 g
s
.34727 .53216 m .33486 .55265 L .31084 .52222 L p .899 .8 .742 r
F P
0 g
s
.54707 .5265 m .54417 .54575 L .56426 .54139 L p .508 .17 .329 r
F P
0 g
s
.56426 .54139 m .57023 .52141 L .54707 .5265 L p .508 .17 .329 r
F P
0 g
s
.39303 .44498 m .4058 .45139 L .41833 .46918 L p .197 .49 .901 r
F P
0 g
s
.50174 .5451 m .49819 .52573 L .47549 .51992 L p .765 .378 .321 r
F P
0 g
s
.49819 .52573 m .50174 .5451 L .52289 .54701 L p .692 .325 .348 r
F P
0 g
s
.74371 .60044 m .73238 .59122 L .76293 .55848 L p .564 .605 .853 r
F P
0 g
s
.76293 .55848 m .77621 .56607 L .74371 .60044 L p .564 .605 .853 r
F P
0 g
s
.73238 .59122 m .72072 .57683 L .7493 .5457 L p .5 .505 .793 r
F P
0 g
s
.73547 .52886 m .7493 .5457 L .72072 .57683 L p .462 .448 .756 r
F P
0 g
s
.7493 .5457 m .76293 .55848 L .73238 .59122 L p .5 .505 .793 r
F P
0 g
s
.29668 .53868 m .31084 .52222 L .33486 .55265 L p .886 .802 .761 r
F P
0 g
s
.33486 .55265 m .32253 .57078 L .29668 .53868 L p .886 .802 .761 r
F P
0 g
s
.83625 .53514 m .82492 .54667 L .84655 .49953 L p .842 .988 .72 r
F P
0 g
s
.84655 .49953 m .85906 .48583 L .83625 .53514 L p .842 .988 .72 r
F P
0 g
s
.68078 .45881 m .66773 .45065 L .6758 .42729 L p .516 .588 .865 r
F P
0 g
s
.66773 .45065 m .65497 .44927 L .66216 .428 L p .684 .772 .918 r
F P
0 g
s
.66216 .428 m .6758 .42729 L .66773 .45065 L p .684 .772 .918 r
F P
0 g
s
.2433 .55617 m .25598 .55989 L .28723 .5971 L p .35 .611 .947 r
F P
0 g
s
.29862 .59377 m .28723 .5971 L .25598 .55989 L p .644 .752 .928 r
F P
0 g
s
.57023 .52141 m .56426 .54139 L .58187 .53417 L p .362 .038 .275 r
F P
0 g
s
.58187 .53417 m .59057 .51299 L .57023 .52141 L p .362 .038 .275 r
F P
0 g
s
.69412 .47255 m .68078 .45881 L .68978 .4334 L p .403 .462 .807 r
F P
0 g
s
.6758 .42729 m .68978 .4334 L .68078 .45881 L p .516 .588 .865 r
F P
0 g
s
.48207 .54011 m .47549 .51992 L .45591 .51087 L p .832 .418 .257 r
F P
0 g
s
.47549 .51992 m .48207 .54011 L .50174 .5451 L p .765 .378 .321 r
F P
0 g
s
.65497 .44927 m .64244 .45525 L .64879 .43612 L p .845 .944 .886 r
F P
0 g
s
.64879 .43612 m .66216 .428 L .65497 .44927 L p .845 .944 .886 r
F P
0 g
s
.28274 .55109 m .29668 .53868 L .32253 .57078 L p .855 .803 .799 r
F P
0 g
s
.32253 .57078 m .31041 .58486 L .28274 .55109 L p .855 .803 .799 r
F P
0 g
s
.25598 .55989 m .26914 .5583 L .29862 .59377 L p .644 .752 .928 r
F P
0 g
s
.31041 .58486 m .29862 .59377 L .26914 .5583 L p .789 .795 .857 r
F P
0 g
s
.35994 .42795 m .37401 .42229 L .38002 .44594 L p .807 .834 .871 r
F P
0 g
s
.38002 .44594 m .36671 .4537 L .35994 .42795 L p .807 .834 .871 r
F P
0 g
s
.39303 .44498 m .38002 .44594 L .37401 .42229 L p .63 .726 .917 r
F P
0 g
s
.70775 .49018 m .69412 .47255 L .70413 .44514 L p .341 .393 .77 r
F P
0 g
s
.68978 .4334 m .70413 .44514 L .69412 .47255 L p .403 .462 .807 r
F P
0 g
s
.61758 .48391 m .60677 .50172 L .61768 .48828 L p 0 0 0 r
F P
0 g
s
.61768 .48828 m .63005 .46852 L .61758 .48391 L p 0 0 0 r
F P
0 g
s
.26914 .5583 m .28274 .55109 L .31041 .58486 L p .789 .795 .857 r
F P
0 g
s
.34551 .43926 m .35994 .42795 L .36671 .4537 L p .889 .872 .814 r
F P
0 g
s
.36671 .4537 m .35309 .46704 L .34551 .43926 L p .889 .872 .814 r
F P
0 g
s
.37401 .42229 m .38772 .42345 L .39303 .44498 L p .63 .726 .917 r
F P
0 g
s
.4058 .45139 m .39303 .44498 L .38772 .42345 L p .327 .505 .88 r
F P
0 g
s
.82492 .54667 m .81336 .55711 L .83382 .51212 L p .85 .996 .765 r
F P
0 g
s
.83382 .51212 m .84655 .49953 L .82492 .54667 L p .85 .996 .765 r
F P
0 g
s
.59057 .51299 m .58187 .53417 L .59585 .52453 L p .121 0 .155 r
F P
0 g
s
.59585 .52453 m .60677 .50172 L .59057 .51299 L p .121 0 .155 r
F P
0 g
s
.64244 .45525 m .63005 .46852 L .6356 .45156 L p .89 .987 .728 r
F P
0 g
s
.6356 .45156 m .64879 .43612 L .64244 .45525 L p .89 .987 .728 r
F P
0 g
s
.21921 .53728 m .20758 .52532 L .18911 .47507 L p 0 .221 .742 r
F P
0 g
s
.33074 .45451 m .34551 .43926 L .35309 .46704 L p .924 .883 .775 r
F P
0 g
s
.35309 .46704 m .33917 .48428 L .33074 .45451 L p .924 .883 .775 r
F P
0 g
s
.72157 .50967 m .70775 .49018 L .7188 .46082 L p .316 .365 .754 r
F P
0 g
s
.70413 .44514 m .7188 .46082 L .70775 .49018 L p .341 .393 .77 r
F P
0 g
s
.45591 .51087 m .46512 .53236 L .48207 .54011 L p .832 .418 .257 r
F P
0 g
s
.38772 .42345 m .40115 .43204 L .4058 .45139 L p .327 .505 .88 r
F P
0 g
s
.41843 .46509 m .4058 .45139 L .40115 .43204 L p 0 .232 .743 r
F P
0 g
s
.52323 .56894 m .52289 .54701 L .50174 .5451 L p .697 .342 .369 r
F P
0 g
s
.52289 .54701 m .52323 .56894 L .54121 .56789 L p .617 .277 .371 r
F P
0 g
s
.54121 .56789 m .54417 .54575 L .52289 .54701 L p .617 .277 .371 r
F P
0 g
s
.3157 .47167 m .33074 .45451 L .33917 .48428 L p .936 .885 .758 r
F P
0 g
s
.33917 .48428 m .32505 .5034 L .3157 .47167 L p .936 .885 .758 r
F P
0 g
s
.54417 .54575 m .54121 .56789 L .55817 .56425 L p .518 .191 .352 r
F P
0 g
s
.55817 .56425 m .56426 .54139 L .54417 .54575 L p .518 .191 .352 r
F P
0 g
s
.73547 .52886 m .72157 .50967 L .73372 .47841 L p .322 .372 .758 r
F P
0 g
s
.7188 .46082 m .73372 .47841 L .72157 .50967 L p .316 .365 .754 r
F P
0 g
s
.50538 .56734 m .50174 .5451 L .48207 .54011 L p .77 .395 .345 r
F P
0 g
s
.50174 .5451 m .50538 .56734 L .52323 .56894 L p .697 .342 .369 r
F P
0 g
s
.81336 .55711 m .80143 .56473 L .82072 .52185 L p .846 .988 .856 r
F P
0 g
s
.82072 .52185 m .83382 .51212 L .81336 .55711 L p .846 .988 .856 r
F P
0 g
s
.18911 .47507 m .20176 .48925 L .21921 .53728 L p 0 .221 .742 r
F P
0 g
s
.23107 .54814 m .21921 .53728 L .20176 .48925 L p .005 .28 .78 r
F P
0 g
s
.63005 .46852 m .61768 .48828 L .62247 .47351 L p .847 .932 .553 r
F P
0 g
s
.62247 .47351 m .6356 .45156 L .63005 .46852 L p .847 .932 .553 r
F P
0 g
s
.60677 .50172 m .59585 .52453 L .60522 .51306 L p 0 0 0 r
F P
0 g
s
.60522 .51306 m .61768 .48828 L .60677 .50172 L p 0 0 0 r
F P
0 g
s
.56426 .54139 m .55817 .56425 L .573 .55825 L p .378 .065 .303 r
F P
0 g
s
.573 .55825 m .58187 .53417 L .56426 .54139 L p .378 .065 .303 r
F P
0 g
s
.68978 .4334 m .6758 .42729 L .6737 .40313 L p .469 .595 .895 r
F P
0 g
s
.6758 .42729 m .66216 .428 L .66008 .40606 L p .688 .767 .912 r
F P
0 g
s
.66008 .40606 m .6737 .40313 L .6758 .42729 L p .688 .767 .912 r
F P
0 g
s
.48877 .56319 m .48207 .54011 L .46512 .53236 L p .838 .437 .287 r
F P
0 g
s
.48207 .54011 m .48877 .56319 L .50538 .56734 L p .77 .395 .345 r
F P
0 g
s
.66216 .428 m .64879 .43612 L .64677 .41644 L p .857 .881 .855 r
F P
0 g
s
.64677 .41644 m .66008 .40606 L .66216 .428 L p .857 .881 .855 r
F P
0 g
s
.40115 .43204 m .4144 .44794 L .41843 .46509 L p 0 .232 .743 r
F P
0 g
s
.30053 .48856 m .3157 .47167 L .32505 .5034 L p .933 .885 .762 r
F P
0 g
s
.32505 .5034 m .31084 .52222 L .30053 .48856 L p .933 .885 .762 r
F P
0 g
s
.7493 .5457 m .73547 .52886 L .74877 .49572 L p .357 .411 .781 r
F P
0 g
s
.73372 .47841 m .74877 .49572 L .73547 .52886 L p .322 .372 .758 r
F P
0 g
s
.80143 .56473 m .78906 .56805 L .80716 .52721 L p .783 .911 .927 r
F P
0 g
s
.80716 .52721 m .82072 .52185 L .80143 .56473 L p .783 .911 .927 r
F P
0 g
s
.70413 .44514 m .68978 .4334 L .68769 .40706 L p .284 .436 .838 r
F P
0 g
s
.6737 .40313 m .68769 .40706 L .68978 .4334 L p .469 .595 .895 r
F P
0 g
s
.20176 .48925 m .21464 .50233 L .23107 .54814 L p .005 .28 .78 r
F P
0 g
s
.2433 .55617 m .23107 .54814 L .21464 .50233 L p .179 .421 .857 r
F P
0 g
s
.36441 .40164 m .37828 .39817 L .37401 .42229 L p .801 .876 .902 r
F P
0 g
s
.37401 .42229 m .35994 .42795 L .36441 .40164 L p .801 .876 .902 r
F P
0 g
s
.38772 .42345 m .37401 .42229 L .37828 .39817 L p .634 .721 .91 r
F P
0 g
s
.37828 .39817 m .39177 .40156 L .38772 .42345 L p .634 .721 .91 r
F P
0 g
s
.40115 .43204 m .38772 .42345 L .39177 .40156 L p .427 .517 .848 r
F P
0 g
s
.64879 .43612 m .6356 .45156 L .63367 .43415 L p .943 .921 .76 r
F P
0 g
s
.63367 .43415 m .64677 .41644 L .64879 .43612 L p .943 .921 .76 r
F P
0 g
s
.58187 .53417 m .573 .55825 L .58474 .55024 L p .149 0 .195 r
F P
0 g
s
.58474 .55024 m .59585 .52453 L .58187 .53417 L p .149 0 .195 r
F P
0 g
s
.76293 .55848 m .7493 .5457 L .76379 .51068 L p .423 .488 .822 r
F P
0 g
s
.74877 .49572 m .76379 .51068 L .7493 .5457 L p .357 .411 .781 r
F P
0 g
s
.78906 .56805 m .77621 .56607 L .79311 .52722 L p .658 .762 .927 r
F P
0 g
s
.79311 .52722 m .80716 .52721 L .78906 .56805 L p .658 .762 .927 r
F P
0 g
s
.35015 .41079 m .36441 .40164 L .35994 .42795 L p .887 .947 .844 r
F P
0 g
s
.35994 .42795 m .34551 .43926 L .35015 .41079 L p .887 .947 .844 r
F P
0 g
s
.28538 .50311 m .30053 .48856 L .31084 .52222 L p .915 .881 .786 r
F P
0 g
s
.31084 .52222 m .29668 .53868 L .28538 .50311 L p .915 .881 .786 r
F P
0 g
s
.4745 .55673 m .46512 .53236 L .45202 .52228 L p .885 .458 .16 r
F P
0 g
s
.46512 .53236 m .4745 .55673 L .48877 .56319 L p .838 .437 .287 r
F P
0 g
s
.7188 .46082 m .70413 .44514 L .70207 .41666 L p .169 .334 .787 r
F P
0 g
s
.68769 .40706 m .70207 .41666 L .70413 .44514 L p .284 .436 .838 r
F P
0 g
s
.39177 .40156 m .40495 .41241 L .40115 .43204 L p .427 .517 .848 r
F P
0 g
s
.4144 .44794 m .40115 .43204 L .40495 .41241 L p .25 .338 .759 r
F P
0 g
s
.77621 .56607 m .76293 .55848 L .77862 .52157 L p .525 .606 .877 r
F P
0 g
s
.76379 .51068 m .77862 .52157 L .76293 .55848 L p .423 .488 .822 r
F P
0 g
s
.77862 .52157 m .79311 .52722 L .77621 .56607 L p .525 .606 .877 r
F P
0 g
s
.61768 .48828 m .60522 .51306 L .60927 .50047 L p .799 .874 .439 r
F P
0 g
s
.60927 .50047 m .62247 .47351 L .61768 .48828 L p .799 .874 .439 r
F P
0 g
s
.21464 .50233 m .22789 .51252 L .2433 .55617 L p .179 .421 .857 r
F P
0 g
s
.25598 .55989 m .2433 .55617 L .22789 .51252 L p .42 .602 .922 r
F P
0 g
s
.27042 .51357 m .28538 .50311 L .29668 .53868 L p .875 .869 .829 r
F P
0 g
s
.29668 .53868 m .28274 .55109 L .27042 .51357 L p .875 .869 .829 r
F P
0 g
s
.6356 .45156 m .62247 .47351 L .62066 .45837 L p .973 .921 .676 r
F P
0 g
s
.62066 .45837 m .63367 .43415 L .6356 .45156 L p .973 .921 .676 r
F P
0 g
s
.4144 .44794 m .42758 .47036 L .43103 .4853 L p 0 .023 .595 r
F P
0 g
s
.33551 .42392 m .35015 .41079 L .34551 .43926 L p .918 .968 .787 r
F P
0 g
s
.34551 .43926 m .33074 .45451 L .33551 .42392 L p .918 .968 .787 r
F P
0 g
s
.59585 .52453 m .58474 .55024 L .59257 .54072 L p 0 0 0 r
F P
0 g
s
.59257 .54072 m .60522 .51306 L .59585 .52453 L p 0 0 0 r
F P
0 g
s
.22789 .51252 m .2416 .51835 L .25598 .55989 L p .42 .602 .922 r
F P
0 g
s
.26914 .5583 m .25598 .55989 L .2416 .51835 L p .645 .751 .926 r
F P
0 g
s
.52359 .59116 m .52323 .56894 L .50538 .56734 L p .697 .34 .367 r
F P
0 g
s
.52323 .56894 m .52359 .59116 L .53817 .59032 L p .616 .275 .369 r
F P
0 g
s
.53817 .59032 m .54121 .56789 L .52323 .56894 L p .616 .275 .369 r
F P
0 g
s
.73372 .47841 m .7188 .46082 L .71683 .43023 L p .122 .292 .764 r
F P
0 g
s
.70207 .41666 m .71683 .43023 L .7188 .46082 L p .169 .334 .787 r
F P
0 g
s
.40495 .41241 m .41791 .43059 L .4144 .44794 L p .25 .338 .759 r
F P
0 g
s
.42758 .47036 m .4144 .44794 L .41791 .43059 L p .131 .214 .684 r
F P
0 g
s
.25579 .5188 m .27042 .51357 L .28274 .55109 L p .793 .834 .883 r
F P
0 g
s
.28274 .55109 m .26914 .5583 L .25579 .5188 L p .793 .834 .883 r
F P
0 g
s
.54121 .56789 m .53817 .59032 L .5519 .58742 L p .517 .189 .35 r
F P
0 g
s
.5519 .58742 m .55817 .56425 L .54121 .56789 L p .517 .189 .35 r
F P
0 g
s
.2416 .51835 m .25579 .5188 L .26914 .5583 L p .645 .751 .926 r
F P
0 g
s
.50911 .58989 m .50538 .56734 L .48877 .56319 L p .769 .393 .342 r
F P
0 g
s
.50538 .56734 m .50911 .58989 L .52359 .59116 L p .697 .34 .367 r
F P
0 g
s
.45202 .52228 m .46351 .54837 L .4745 .55673 L p .885 .458 .16 r
F P
0 g
s
.6737 .40313 m .66008 .40606 L .64855 .38497 L p .689 .76 .906 r
F P
0 g
s
.66008 .40606 m .64677 .41644 L .63625 .39756 L p .844 .818 .824 r
F P
0 g
s
.63625 .39756 m .64855 .38497 L .66008 .40606 L p .844 .818 .824 r
F P
0 g
s
.55817 .56425 m .5519 .58742 L .56391 .58262 L p .376 .062 .3 r
F P
0 g
s
.56391 .58262 m .573 .55825 L .55817 .56425 L p .376 .062 .3 r
F P
0 g
s
.49566 .58657 m .48877 .56319 L .4745 .55673 L p .837 .435 .284 r
F P
0 g
s
.48877 .56319 m .49566 .58657 L .50911 .58989 L p .769 .393 .342 r
F P
0 g
s
.68769 .40706 m .6737 .40313 L .66116 .37985 L p .419 .61 .928 r
F P
0 g
s
.64855 .38497 m .66116 .37985 L .6737 .40313 L p .689 .76 .906 r
F P
0 g
s
.32057 .43899 m .33551 .42392 L .33074 .45451 L p .926 .971 .76 r
F P
0 g
s
.33074 .45451 m .3157 .47167 L .32057 .43899 L p .926 .971 .76 r
F P
0 g
s
.64677 .41644 m .63367 .43415 L .62417 .41748 L p .915 .829 .747 r
F P
0 g
s
.62417 .41748 m .63625 .39756 L .64677 .41644 L p .915 .829 .747 r
F P
0 g
s
.39295 .37528 m .40522 .38084 L .39177 .40156 L p .64 .719 .905 r
F P
0 g
s
.39177 .40156 m .37828 .39817 L .39295 .37528 L p .64 .719 .905 r
F P
0 g
s
.40495 .41241 m .39177 .40156 L .40522 .38084 L p .502 .531 .819 r
F P
0 g
s
.74877 .49572 m .73372 .47841 L .73188 .44574 L p .134 .302 .77 r
F P
0 g
s
.71683 .43023 m .73188 .44574 L .73372 .47841 L p .122 .292 .764 r
F P
0 g
s
.62247 .47351 m .60927 .50047 L .60761 .4876 L p .982 .912 .621 r
F P
0 g
s
.60761 .4876 m .62066 .45837 L .62247 .47351 L p .982 .912 .621 r
F P
0 g
s
.85906 .48583 m .84655 .49953 L .84696 .4493 L p .933 .947 .775 r
F P
0 g
s
.84696 .4493 m .85986 .43317 L .85906 .48583 L p .933 .947 .775 r
F P
0 g
s
.38029 .37661 m .39295 .37528 L .37828 .39817 L p .773 .912 .934 r
F P
0 g
s
.37828 .39817 m .36441 .40164 L .38029 .37661 L p .773 .912 .934 r
F P
0 g
s
.573 .55825 m .56391 .58262 L .57337 .57623 L p .145 0 .19 r
F P
0 g
s
.57337 .57623 m .58474 .55024 L .573 .55825 L p .145 0 .19 r
F P
0 g
s
.60522 .51306 m .59257 .54072 L .5959 .5303 L p .774 .844 .39 r
F P
0 g
s
.5959 .5303 m .60927 .50047 L .60522 .51306 L p .774 .844 .39 r
F P
0 g
s
.70207 .41666 m .68769 .40706 L .67415 .38161 L p .115 .401 .853 r
F P
0 g
s
.66116 .37985 m .67415 .38161 L .68769 .40706 L p .419 .61 .928 r
F P
0 g
s
.40522 .38084 m .41719 .39387 L .40495 .41241 L p .502 .531 .819 r
F P
0 g
s
.41791 .43059 m .40495 .41241 L .41719 .39387 L p .404 .402 .743 r
F P
0 g
s
.41791 .43059 m .43079 .45528 L .42758 .47036 L p .131 .214 .684 r
F P
0 g
s
.44082 .49779 m .42758 .47036 L .43079 .45528 L p .063 .143 .636 r
F P
0 g
s
.42758 .47036 m .44082 .49779 L .44371 .51051 L p 0 0 .496 r
F P
0 g
s
.48412 .58141 m .4745 .55673 L .46351 .54837 L p .884 .455 .155 r
F P
0 g
s
.4745 .55673 m .48412 .58141 L .49566 .58657 L p .837 .435 .284 r
F P
0 g
s
.63367 .43415 m .62066 .45837 L .6122 .44392 L p .947 .826 .693 r
F P
0 g
s
.6122 .44392 m .62417 .41748 L .63367 .43415 L p .947 .826 .693 r
F P
0 g
s
.30546 .45381 m .32057 .43899 L .3157 .47167 L p .924 .97 .767 r
F P
0 g
s
.3157 .47167 m .30053 .48856 L .30546 .45381 L p .924 .97 .767 r
F P
0 g
s
.36725 .38364 m .38029 .37661 L .36441 .40164 L p .815 .997 .851 r
F P
0 g
s
.36441 .40164 m .35015 .41079 L .36725 .38364 L p .815 .997 .851 r
F P
0 g
s
.41719 .39387 m .42895 .41423 L .41791 .43059 L p .404 .402 .743 r
F P
0 g
s
.43079 .45528 m .41791 .43059 L .42895 .41423 L p .345 .324 .692 r
F P
0 g
s
.84655 .49953 m .83382 .51212 L .83386 .46429 L p .921 .942 .797 r
F P
0 g
s
.83386 .46429 m .84696 .4493 L .84655 .49953 L p .921 .942 .797 r
F P
0 g
s
.76379 .51068 m .74877 .49572 L .74709 .461 L p .199 .363 .803 r
F P
0 g
s
.73188 .44574 m .74709 .461 L .74877 .49572 L p .134 .302 .77 r
F P
0 g
s
.71683 .43023 m .70207 .41666 L .68754 .38906 L p 0 .24 .756 r
F P
0 g
s
.67415 .38161 m .68754 .38906 L .70207 .41666 L p .115 .401 .853 r
F P
0 g
s
.58474 .55024 m .57337 .57623 L .57965 .56866 L p 0 0 0 r
F P
0 g
s
.57965 .56866 m .59257 .54072 L .58474 .55024 L p 0 0 0 r
F P
0 g
s
.20176 .48925 m .18911 .47507 L .19318 .42214 L p .212 .339 .776 r
F P
0 g
s
.47527 .57474 m .46351 .54837 L .45658 .53861 L p .803 .388 0 r
F P
0 g
s
.46351 .54837 m .47527 .57474 L .48412 .58141 L p .884 .455 .155 r
F P
0 g
s
.52396 .61084 m .52359 .59116 L .50911 .58989 L p .689 .318 .339 r
F P
0 g
s
.52359 .59116 m .52396 .61084 L .53503 .61021 L p .607 .252 .342 r
F P
0 g
s
.53503 .61021 m .53817 .59032 L .52359 .59116 L p .607 .252 .342 r
F P
0 g
s
.60927 .50047 m .5959 .5303 L .59442 .51968 L p .983 .906 .596 r
F P
0 g
s
.59442 .51968 m .60761 .4876 L .60927 .50047 L p .983 .906 .596 r
F P
0 g
s
.62066 .45837 m .60761 .4876 L .60022 .47534 L p .961 .821 .66 r
F P
0 g
s
.60022 .47534 m .6122 .44392 L .62066 .45837 L p .961 .821 .66 r
F P
0 g
s
.83382 .51212 m .82072 .52185 L .82041 .47636 L p .883 .923 .845 r
F P
0 g
s
.82041 .47636 m .83386 .46429 L .83382 .51212 L p .883 .923 .845 r
F P
0 g
s
.53817 .59032 m .53503 .61021 L .54546 .60803 L p .504 .161 .32 r
F P
0 g
s
.54546 .60803 m .5519 .58742 L .53817 .59032 L p .504 .161 .32 r
F P
0 g
s
.66116 .37985 m .64855 .38497 L .62807 .36629 L p .688 .753 .9 r
F P
0 g
s
.64855 .38497 m .63625 .39756 L .61772 .38087 L p .819 .763 .8 r
F P
0 g
s
.61772 .38087 m .62807 .36629 L .64855 .38497 L p .819 .763 .8 r
F P
0 g
s
.35382 .39468 m .36725 .38364 L .35015 .41079 L p .788 .987 .736 r
F P
0 g
s
.35015 .41079 m .33551 .42392 L .35382 .39468 L p .788 .987 .736 r
F P
0 g
s
.51296 .60988 m .50911 .58989 L .49566 .58657 L p .762 .37 .311 r
F P
0 g
s
.50911 .58989 m .51296 .60988 L .52396 .61084 L p .689 .318 .339 r
F P
0 g
s
.29032 .46627 m .30546 .45381 L .30053 .48856 L p .91 .964 .805 r
F P
0 g
s
.30053 .48856 m .28538 .50311 L .29032 .46627 L p .91 .964 .805 r
F P
0 g
s
.63625 .39756 m .62417 .41748 L .60757 .40278 L p .87 .752 .729 r
F P
0 g
s
.60757 .40278 m .61772 .38087 L .63625 .39756 L p .87 .752 .729 r
F P
0 g
s
.77862 .52157 m .76379 .51068 L .76232 .4739 L p .319 .471 .855 r
F P
0 g
s
.74709 .461 m .76232 .4739 L .76379 .51068 L p .199 .363 .803 r
F P
0 g
s
.43079 .45528 m .44369 .48498 L .44082 .49779 L p .063 .143 .636 r
F P
0 g
s
.45424 .52809 m .44082 .49779 L .44369 .48498 L p .034 .112 .614 r
F P
0 g
s
.44082 .49779 m .45424 .52809 L .45658 .53861 L p 0 0 .452 r
F P
0 g
s
.42895 .41423 m .44059 .4411 L .43079 .45528 L p .345 .324 .692 r
F P
0 g
s
.44369 .48498 m .43079 .45528 L .44059 .4411 L p .311 .28 .662 r
F P
0 g
s
.5519 .58742 m .54546 .60803 L .55455 .60444 L p .355 .027 .263 r
F P
0 g
s
.55455 .60444 m .56391 .58262 L .5519 .58742 L p .355 .027 .263 r
F P
0 g
s
.19318 .42214 m .20604 .43879 L .20176 .48925 L p .212 .339 .776 r
F P
0 g
s
.21464 .50233 m .20176 .48925 L .20604 .43879 L p .249 .375 .796 r
F P
0 g
s
.67415 .38161 m .66116 .37985 L .63871 .35917 L p .369 .634 .956 r
F P
0 g
s
.62807 .36629 m .63871 .35917 L .66116 .37985 L p .688 .753 .9 r
F P
0 g
s
.41731 .35537 m .42742 .36285 L .40522 .38084 L p .648 .718 .899 r
F P
0 g
s
.40522 .38084 m .39295 .37528 L .41731 .35537 L p .648 .718 .899 r
F P
0 g
s
.41719 .39387 m .40522 .38084 L .42742 .36285 L p .561 .547 .796 r
F P
0 g
s
.50275 .6074 m .49566 .58657 L .48412 .58141 L p .829 .409 .244 r
F P
0 g
s
.49566 .58657 m .50275 .6074 L .51296 .60988 L p .762 .37 .311 r
F P
0 g
s
.42742 .36285 m .43726 .3778 L .41719 .39387 L p .561 .547 .796 r
F P
0 g
s
.42895 .41423 m .41719 .39387 L .43726 .3778 L p .506 .448 .726 r
F P
0 g
s
.59257 .54072 m .57965 .56866 L .58227 .56038 L p .777 .848 .396 r
F P
0 g
s
.58227 .56038 m .5959 .5303 L .59257 .54072 L p .777 .848 .396 r
F P
0 g
s
.73188 .44574 m .71683 .43023 L .7013 .40053 L p 0 .17 .707 r
F P
0 g
s
.68754 .38906 m .7013 .40053 L .71683 .43023 L p 0 .24 .756 r
F P
0 g
s
.82072 .52185 m .80716 .52721 L .80652 .484 L p .8 .868 .899 r
F P
0 g
s
.80652 .484 m .82041 .47636 L .82072 .52185 L p .8 .868 .899 r
F P
0 g
s
.62417 .41748 m .6122 .44392 L .59753 .4312 L p .892 .741 .686 r
F P
0 g
s
.59753 .4312 m .60757 .40278 L .62417 .41748 L p .892 .741 .686 r
F P
0 g
s
.79311 .52722 m .77862 .52157 L .77739 .4827 L p .483 .614 .905 r
F P
0 g
s
.76232 .4739 m .77739 .4827 L .77862 .52157 L p .319 .471 .855 r
F P
0 g
s
.45658 .53861 m .46972 .56698 L .47527 .57474 L p .803 .388 0 r
F P
0 g
s
.46972 .56698 m .45658 .53861 L .45424 .52809 L p 0 0 .457 r
F P
0 g
s
.40687 .35478 m .41731 .35537 L .39295 .37528 L p .715 .93 .961 r
F P
0 g
s
.39295 .37528 m .38029 .37661 L .40687 .35478 L p .715 .93 .961 r
F P
0 g
s
.56391 .58262 m .55455 .60444 L .5617 .59966 L p .11 0 .139 r
F P
0 g
s
.5617 .59966 m .57337 .57623 L .56391 .58262 L p .11 0 .139 r
F P
0 g
s
.27533 .47462 m .29032 .46627 L .28538 .50311 L p .871 .939 .861 r
F P
0 g
s
.28538 .50311 m .27042 .51357 L .27533 .47462 L p .871 .939 .861 r
F P
0 g
s
.43726 .3778 m .4469 .40009 L .42895 .41423 L p .506 .448 .726 r
F P
0 g
s
.44059 .4411 m .42895 .41423 L .4469 .40009 L p .474 .393 .685 r
F P
0 g
s
.80716 .52721 m .79311 .52722 L .79216 .48621 L p .659 .761 .925 r
F P
0 g
s
.79216 .48621 m .80652 .484 L .80716 .52721 L p .659 .761 .925 r
F P
0 g
s
.77739 .4827 m .79216 .48621 L .79311 .52722 L p .483 .614 .905 r
F P
0 g
s
.49402 .60354 m .48412 .58141 L .47527 .57474 L p .866 .419 .099 r
F P
0 g
s
.48412 .58141 m .49402 .60354 L .50275 .6074 L p .829 .409 .244 r
F P
0 g
s
.20604 .43879 m .21911 .45429 L .21464 .50233 L p .249 .375 .796 r
F P
0 g
s
.22789 .51252 m .21464 .50233 L .21911 .45429 L p .341 .464 .84 r
F P
0 g
s
.68754 .38906 m .67415 .38161 L .64969 .35896 L p 0 .347 .807 r
F P
0 g
s
.63871 .35917 m .64969 .35896 L .67415 .38161 L p .369 .634 .956 r
F P
0 g
s
.32616 .42041 m .34009 .40767 L .33678 .41297 L p .771 .973 .692 r
F P
0 g
s
.33678 .41297 m .32057 .43899 L p .32616 .42041 L .771 .973 .692 r
F P
0 g
s
.32616 .42041 m .31218 .43078 L .3169 .42689 L p .497 .858 .616 r
F P
0 g
s
.34009 .40767 m .32616 .42041 L .327 .41972 L p 0 0 0 r
F P
0 g
s
.3533 .39551 m .33551 .42392 L p .34009 .40767 L .765 .967 .677 r
F P
0 g
s
.33551 .42392 m .32057 .43899 L .34009 .40767 L p .765 .967 .677 r
F P
0 g
s
.327 .41972 m .36195 .391 L p .34009 .40767 L 0 0 0 r
F P
0 g
s
.38029 .37661 m .36725 .38364 L .39608 .35991 L p .613 .949 .786 r
F P
0 g
s
.36195 .391 m .37355 .38016 L .36789 .38481 L p 0 0 0 r
F P
0 g
s
.36789 .38481 m .34009 .40767 L p .36195 .391 L 0 0 0 r
F P
0 g
s
.35028 .39944 m .36195 .391 L .34893 .4017 L p .497 .858 .616 r
F P
0 g
s
.34893 .4017 m .32616 .42041 L p .35028 .39944 L .497 .858 .616 r
F P
0 g
s
.34009 .40767 m .35382 .39468 L .3533 .39551 L p .765 .967 .677 r
F P
0 g
s
.35382 .39468 m .34009 .40767 L .37355 .38016 L p 0 0 0 r
F P
0 g
s
.35028 .39944 m .33867 .4037 L .35127 .39778 L p .381 .834 .741 r
F P
0 g
s
.36195 .391 m .35028 .39944 L .35676 .39641 L p 0 0 0 r
F P
0 g
s
.35676 .39641 m .4024 .37503 L p .36195 .391 L 0 0 0 r
F P
0 g
s
.4024 .37503 m .41069 .36813 L .393 .37643 L p 0 0 0 r
F P
0 g
s
.393 .37643 m .36195 .391 L p .4024 .37503 L 0 0 0 r
F P
0 g
s
.39413 .37769 m .4024 .37503 L .35861 .39554 L p .381 .834 .741 r
F P
0 g
s
.35861 .39554 m .35028 .39944 L p .39413 .37769 L .381 .834 .741 r
F P
0 g
s
.41069 .36813 m .41892 .35881 L .37355 .38016 L p .007 0 0 r
F P
0 g
s
.37355 .38016 m .36195 .391 L .41069 .36813 L p .007 0 0 r
F P
0 g
s
.45695 .34901 m .46386 .36547 L .43726 .3778 L p .61 .567 .78 r
F P
0 g
s
.43726 .3778 m .42742 .36285 L .45695 .34901 L p .61 .567 .78 r
F P
0 g
s
.46386 .36547 m .45695 .34901 L .49169 .34049 L p .653 .589 .77 r
F P
0 g
s
.41069 .36813 m .4024 .37503 L .46472 .35983 L p .18 0 0 r
F P
0 g
s
.39413 .37769 m .38597 .37489 L .41268 .36837 L p .535 .877 .989 r
F P
0 g
s
.4024 .37503 m .39413 .37769 L .40931 .37399 L p 0 0 0 r
F P
0 g
s
.40931 .37399 m .46062 .36149 L p .4024 .37503 L 0 0 0 r
F P
0 g
s
.46472 .35983 m .46884 .35392 L .41069 .36813 L p .18 0 0 r
F P
0 g
s
.46062 .36149 m .46472 .35983 L .4124 .37259 L p 0 0 0 r
F P
0 g
s
.4124 .37259 m .4024 .37503 L p .46062 .36149 L 0 0 0 r
F P
0 g
s
.49169 .34049 m .49509 .35787 L .46386 .36547 L p .653 .589 .77 r
F P
0 g
s
.56606 .34178 m .56189 .35902 L .52863 .35566 L p .725 .643 .766 r
F P
0 g
s
.52903 .338 m .52863 .35566 L .49509 .35787 L p .69 .614 .766 r
F P
0 g
s
.49509 .35787 m .49169 .34049 L .52903 .338 L p .69 .614 .766 r
F P
0 g
s
.52863 .35566 m .52903 .338 L .56606 .34178 L p .725 .643 .766 r
F P
0 g
s
.46884 .35392 m .46472 .35983 L .53219 .35539 L p .368 0 0 r
F P
0 g
s
.47062 .38925 m .46386 .36547 L .49509 .35787 L p .638 .522 .706 r
F P
0 g
s
.49509 .35787 m .49842 .38258 L .47062 .38925 L p .638 .522 .706 r
F P
0 g
s
.52824 .38064 m .52863 .35566 L .56189 .35902 L p .735 .597 .703 r
F P
0 g
s
.49842 .38258 m .49509 .35787 L .52863 .35566 L p .688 .558 .702 r
F P
0 g
s
.52863 .35566 m .52824 .38064 L .49842 .38258 L p .688 .558 .702 r
F P
0 g
s
.53267 .35674 m .53219 .35539 L .46472 .35983 L p .092 0 0 r
F P
0 g
s
.46472 .35983 m .46062 .36149 L .53267 .35674 L p .092 0 0 r
F P
0 g
s
.46062 .36149 m .45656 .35765 L .48566 .35573 L p .449 .829 .989 r
F P
0 g
s
.53219 .35539 m .53171 .34976 L .46884 .35392 L p .368 0 0 r
F P
0 g
s
.59234 .36766 m .59992 .35148 L .62807 .36629 L p .79 .716 .783 r
F P
0 g
s
.59992 .35148 m .59234 .36766 L .56189 .35902 L p .758 .677 .772 r
F P
0 g
s
.56189 .35902 m .56606 .34178 L .59992 .35148 L p .758 .677 .772 r
F P
0 g
s
.53171 .34976 m .53219 .35539 L .59905 .36214 L p .486 0 0 r
F P
0 g
s
.48566 .35573 m .53315 .35259 L p .46062 .36149 L .449 .829 .989 r
F P
0 g
s
.41268 .36837 m .45656 .35765 L p .39413 .37769 L .535 .877 .989 r
F P
0 g
s
.35127 .39778 m .39413 .37769 L p .35028 .39944 L .381 .834 .741 r
F P
0 g
s
.3169 .42689 m .35028 .39944 L p .32616 .42041 L .497 .858 .616 r
F P
0 g
s
.60761 .4876 m .59442 .51968 L .58814 .50958 L p .966 .818 .646 r
F P
0 g
s
.58814 .50958 m .60022 .47534 L .60761 .4876 L p .966 .818 .646 r
F P
0 g
s
.6122 .44392 m .60022 .47534 L .58751 .46457 L p .902 .733 .663 r
F P
0 g
s
.58751 .46457 m .59753 .4312 L .6122 .44392 L p .902 .733 .663 r
F P
0 g
s
.26064 .47768 m .27533 .47462 L .27042 .51357 L p .785 .871 .911 r
F P
0 g
s
.27042 .51357 m .25579 .5188 L .26064 .47768 L p .785 .871 .911 r
F P
0 g
s
.44059 .4411 m .45223 .47296 L .44369 .48498 L p .311 .28 .662 r
F P
0 g
s
.45673 .51751 m .44369 .48498 L .45223 .47296 L p .297 .262 .649 r
F P
0 g
s
.44369 .48498 m .45673 .51751 L .45424 .52809 L p .034 .112 .614 r
F P
0 g
s
.57337 .57623 m .5617 .59966 L .56641 .59401 L p 0 0 0 r
F P
0 g
s
.56641 .59401 m .57965 .56866 L .57337 .57623 L p 0 0 0 r
F P
0 g
s
.21911 .45429 m .23251 .46686 L .22789 .51252 L p .341 .464 .84 r
F P
0 g
s
.2416 .51835 m .22789 .51252 L .23251 .46686 L p .482 .599 .893 r
F P
0 g
s
.5959 .5303 m .58227 .56038 L .58101 .55197 L p .983 .906 .599 r
F P
0 g
s
.58101 .55197 m .59442 .51968 L .5959 .5303 L p .983 .906 .599 r
F P
0 g
s
.39608 .35991 m .40687 .35478 L .38029 .37661 L p .613 .949 .786 r
F P
0 g
s
.4469 .40009 m .45644 .42887 L .44059 .4411 L p .474 .393 .685 r
F P
0 g
s
.45223 .47296 m .44059 .4411 L .45644 .42887 L p .456 .363 .662 r
F P
0 g
s
.48734 .59855 m .47527 .57474 L .46972 .56698 L p .755 .329 0 r
F P
0 g
s
.47527 .57474 m .48734 .59855 L .49402 .60354 L p .866 .419 .099 r
F P
0 g
s
.62807 .36629 m .61772 .38087 L .59234 .36766 L p .79 .716 .783 r
F P
0 g
s
.61772 .38087 m .60757 .40278 L .58493 .39118 L p .824 .69 .716 r
F P
0 g
s
.58493 .39118 m .59234 .36766 L .61772 .38087 L p .824 .69 .716 r
F P
0 g
s
.74709 .461 m .73188 .44574 L .71538 .41394 L p 0 .188 .72 r
F P
0 g
s
.7013 .40053 m .71538 .41394 L p .70209 .40169 L 0 .17 .707 r
F P
0 g
s
.7013 .40053 m .68754 .38906 L .66103 .36446 L p 0 .107 .596 r
F P
0 g
s
.66103 .36446 m .67272 .37397 L .7013 .40053 L p 0 .107 .596 r
F P
0 g
s
.71538 .41394 m .7013 .40053 L .67272 .37397 L p .5 0 0 r
F P
0 g
s
.68469 .38544 m .71538 .41394 L p .67381 .37499 L .5 0 0 r
F P
0 g
s
.67272 .37397 m .68469 .38544 L p .67381 .37499 L .5 0 0 r
F P
0 g
s
.64969 .35896 m .66103 .36446 L .68754 .38906 L p 0 .347 .807 r
F P
0 g
s
.68469 .38544 m .64157 .36263 L p .6955 .39581 L .631 .069 0 r
F P
0 g
s
.71538 .41394 m .68469 .38544 L p .72854 .42608 L 0 .035 .523 r
F P
0 g
s
.69687 .39665 m .72965 .4271 L p .69082 .39111 L 0 .035 .523 r
F P
0 g
s
.68469 .38544 m .69687 .39665 L p .69082 .39111 L 0 .035 .523 r
F P
0 g
s
.74397 .4379 m .72965 .4271 L .69687 .39665 L p 0 .173 .659 r
F P
0 g
s
.69687 .39665 m .65057 .37223 L p .70224 .40157 L .508 0 0 r
F P
0 g
s
.70911 .40547 m .74397 .4379 L p .70888 .40717 L 0 .173 .659 r
F P
0 g
s
.69687 .39665 m .70911 .40547 L p .70888 .40717 L 0 .173 .659 r
F P
0 g
s
.70911 .40547 m .69687 .39665 L p .70224 .40157 L .508 0 0 r
F P
0 g
s
.71538 .41394 m .73188 .44574 L p .70209 .40169 L 0 .17 .707 r
F P
0 g
s
.65964 .3794 m .70911 .40547 L p .66544 .38067 L .508 0 0 r
F P
0 g
s
.65057 .37223 m .65964 .3794 L p .66544 .38067 L .508 0 0 r
F P
0 g
s
.65964 .3794 m .59905 .36214 L p .65507 .3784 L .234 0 0 r
F P
0 g
s
.70911 .40547 m .65964 .3794 L p .70929 .40413 L 0 .382 .767 r
F P
0 g
s
.66868 .38236 m .72129 .4101 L p .68699 .39302 L 0 .382 .767 r
F P
0 g
s
.65964 .3794 m .66868 .38236 L p .68699 .39302 L 0 .382 .767 r
F P
0 g
s
.66868 .38236 m .65964 .3794 L p .65507 .3784 L .234 0 0 r
F P
0 g
s
.64157 .36263 m .65057 .37223 L .69687 .39665 L p .631 .069 0 r
F P
0 g
s
.63871 .35917 m .62807 .36629 L .59992 .35148 L p .686 .745 .896 r
F P
0 g
s
.65964 .3794 m .65057 .37223 L .59402 .35607 L p .542 0 0 r
F P
0 g
s
.59402 .35607 m .59905 .36214 L .65964 .3794 L p .542 0 0 r
F P
0 g
s
.60407 .36395 m .66868 .38236 L p .62984 .37108 L .234 0 0 r
F P
0 g
s
.59905 .36214 m .60407 .36395 L p .62984 .37108 L .234 0 0 r
F P
0 g
s
.55782 .38359 m .56189 .35902 L .59234 .36766 L p .779 .639 .707 r
F P
0 g
s
.56189 .35902 m .55782 .38359 L .52824 .38064 L p .735 .597 .703 r
F P
0 g
s
.59905 .36214 m .59402 .35607 L .53171 .34976 L p .486 0 0 r
F P
0 g
s
.60407 .36395 m .59905 .36214 L .53219 .35539 L p .208 0 0 r
F P
0 g
s
.53267 .35674 m .60407 .36395 L p .56387 .35916 L .208 0 0 r
F P
0 g
s
.53219 .35539 m .53267 .35674 L p .56387 .35916 L .208 0 0 r
F P
0 g
s
.53267 .35674 m .46062 .36149 L p .51222 .35516 L .449 .829 .989 r
F P
0 g
s
.53315 .35259 m .53267 .35674 L p .51222 .35516 L .449 .829 .989 r
F P
0 g
s
.60407 .36395 m .53267 .35674 L p .5871 .35926 L .388 .776 .989 r
F P
0 g
s
.60771 .34276 m .59992 .35148 L .56606 .34178 L p .682 .738 .893 r
F P
0 g
s
.58904 .34757 m .59402 .35607 L .65057 .37223 L p .632 .089 0 r
F P
0 g
s
.60902 .36027 m .60407 .36395 L p .5871 .35926 L .388 .776 .989 r
F P
0 g
s
.66868 .38236 m .60407 .36395 L p .65658 .37531 L .361 .728 .988 r
F P
0 g
s
.64969 .35896 m .63871 .35917 L .60771 .34276 L p .331 .667 .975 r
F P
0 g
s
.68469 .38544 m .67272 .37397 L .63273 .35276 L p .648 .091 0 r
F P
0 g
s
.59992 .35148 m .60771 .34276 L .63871 .35917 L p .686 .745 .896 r
F P
0 g
s
.63273 .35276 m .64157 .36263 L .68469 .38544 L p .648 .091 0 r
F P
0 g
s
.6776 .37986 m .66868 .38236 L p .65658 .37531 L .361 .728 .988 r
F P
0 g
s
.72129 .4101 m .70911 .40547 L p .70929 .40413 L 0 .382 .767 r
F P
0 g
s
.69687 .39665 m .68469 .38544 L p .6955 .39581 L .631 .069 0 r
F P
0 g
s
.72965 .4271 m .71538 .41394 L p .72854 .42608 L 0 .035 .523 r
F P
0 g
s
.24635 .47499 m .26064 .47768 L .25579 .5188 L p .646 .75 .925 r
F P
0 g
s
.25579 .5188 m .2416 .51835 L .24635 .47499 L p .646 .75 .925 r
F P
0 g
s
.4679 .55863 m .45424 .52809 L .45673 .51751 L p .037 .115 .617 r
F P
0 g
s
.45424 .52809 m .4679 .55863 L .46972 .56698 L p 0 0 .457 r
F P
0 g
s
.23251 .46686 m .24635 .47499 L .2416 .51835 L p .482 .599 .893 r
F P
0 g
s
.4469 .40009 m .43726 .3778 L .46386 .36547 L p .58 .487 .714 r
F P
0 g
s
.60757 .40278 m .59753 .4312 L .57761 .42117 L p .838 .673 .678 r
F P
0 g
s
.57761 .42117 m .58493 .39118 L .60757 .40278 L p .838 .673 .678 r
F P
0 g
s
.44983 .34002 m .45695 .34901 L .42742 .36285 L p .655 .719 .895 r
F P
0 g
s
.42742 .36285 m .41731 .35537 L .44983 .34002 L p .655 .719 .895 r
F P
0 g
s
.52433 .62517 m .52396 .61084 L .51296 .60988 L p .666 .257 .26 r
F P
0 g
s
.52396 .61084 m .52433 .62517 L .5318 .62475 L p .578 .186 .264 r
F P
0 g
s
.5318 .62475 m .53503 .61021 L .52396 .61084 L p .578 .186 .264 r
F P
0 g
s
.46386 .36547 m .47062 .38925 L .4469 .40009 L p .58 .487 .714 r
F P
0 g
s
.45644 .42887 m .4469 .40009 L .47062 .38925 L p .562 .444 .677 r
F P
0 g
s
.53503 .61021 m .5318 .62475 L .53882 .62329 L p .464 .085 .234 r
F P
0 g
s
.53882 .62329 m .54546 .60803 L .53503 .61021 L p .464 .085 .234 r
F P
0 g
s
.51692 .62453 m .51296 .60988 L .50275 .6074 L p .739 .306 .223 r
F P
0 g
s
.51296 .60988 m .51692 .62453 L .52433 .62517 L p .666 .257 .26 r
F P
0 g
s
.57965 .56866 m .56641 .59401 L .56834 .58784 L p .807 .884 .458 r
F P
0 g
s
.56834 .58784 m .58227 .56038 L .57965 .56866 L p .807 .884 .458 r
F P
0 g
s
.32057 .43899 m .30546 .45381 L .32616 .42041 L p .771 .973 .692 r
F P
0 g
s
.60022 .47534 m .58814 .50958 L .57743 .50073 L p .906 .73 .652 r
F P
0 g
s
.57743 .50073 m .58751 .46457 L .60022 .47534 L p .906 .73 .652 r
F P
0 g
s
.54546 .60803 m .53882 .62329 L .54494 .62089 L p .294 0 .158 r
F P
0 g
s
.54494 .62089 m .55455 .60444 L .54546 .60803 L p .294 0 .158 r
F P
0 g
s
.46972 .56698 m .48318 .59275 L .48734 .59855 L p .755 .329 0 r
F P
0 g
s
.48318 .59275 m .46972 .56698 L .4679 .55863 L p 0 0 .512 r
F P
0 g
s
.51005 .62286 m .50275 .6074 L .49402 .60354 L p .797 .333 .133 r
F P
0 g
s
.50275 .6074 m .51005 .62286 L .51692 .62453 L p .739 .306 .223 r
F P
0 g
s
.59753 .4312 m .58751 .46457 L .57031 .4561 L p .844 .664 .658 r
F P
0 g
s
.57031 .4561 m .57761 .42117 L .59753 .4312 L p .844 .664 .658 r
F P
0 g
s
.38495 .36906 m .39608 .35991 L .36725 .38364 L p .45 .813 .547 r
F P
0 g
s
.36725 .38364 m .35382 .39468 L .38495 .36906 L p .45 .813 .547 r
F P
0 g
s
.59442 .51968 m .58101 .55197 L .57589 .54399 L p .965 .818 .648 r
F P
0 g
s
.57589 .54399 m .58814 .50958 L .59442 .51968 L p .965 .818 .648 r
F P
0 g
s
.44248 .33793 m .44983 .34002 L .41731 .35537 L p .626 .92 .977 r
F P
0 g
s
.41731 .35537 m .40687 .35478 L .44248 .33793 L p .626 .92 .977 r
F P
0 g
s
.45644 .42887 m .46595 .4626 L .45223 .47296 L p .456 .363 .662 r
F P
0 g
s
.46397 .50762 m .45223 .47296 L .46595 .4626 L p .449 .351 .652 r
F P
0 g
s
.45223 .47296 m .46397 .50762 L .45673 .51751 L p .297 .262 .649 r
F P
0 g
s
.76232 .4739 m .74709 .461 L .72965 .4271 L p 0 .286 .787 r
F P
0 g
s
.71538 .41394 m .72965 .4271 L .74709 .461 L p 0 .188 .72 r
F P
0 g
s
.47062 .38925 m .4773 .41951 L .45644 .42887 L p .562 .444 .677 r
F P
0 g
s
.46595 .4626 m .45644 .42887 L .4773 .41951 L p .552 .422 .657 r
F P
0 g
s
.55455 .60444 m .54494 .62089 L .54973 .61771 L p .011 0 0 r
F P
0 g
s
.54973 .61771 m .5617 .59966 L .55455 .60444 L p .011 0 0 r
F P
0 g
s
.46997 .55026 m .45673 .51751 L .46397 .50762 L p .299 .264 .651 r
F P
0 g
s
.45673 .51751 m .46997 .55026 L .4679 .55863 L p .037 .115 .617 r
F P
0 g
s
.59234 .36766 m .58493 .39118 L .55782 .38359 L p .779 .639 .707 r
F P
0 g
s
.50418 .62029 m .49402 .60354 L .48734 .59855 L p .801 .311 0 r
F P
0 g
s
.49402 .60354 m .50418 .62029 L .51005 .62286 L p .797 .333 .133 r
F P
0 g
s
.58493 .39118 m .57761 .42117 L .5538 .41463 L p .787 .619 .672 r
F P
0 g
s
.5538 .41463 m .55782 .38359 L .58493 .39118 L p .787 .619 .672 r
F P
0 g
s
.58227 .56038 m .56834 .58784 L .56734 .58159 L p .98 .914 .631 r
F P
0 g
s
.56734 .58159 m .58101 .55197 L .58227 .56038 L p .98 .914 .631 r
F P
0 g
s
.66103 .36446 m .64969 .35896 L .61577 .34094 L p 0 .284 .671 r
F P
0 g
s
.60771 .34276 m .61577 .34094 L .64969 .35896 L p .331 .667 .975 r
F P
0 g
s
.4773 .41951 m .47062 .38925 L .49842 .38258 L p .629 .488 .672 r
F P
0 g
s
.48185 .58654 m .4679 .55863 L .46997 .55026 L p .073 .154 .644 r
F P
0 g
s
.4679 .55863 m .48185 .58654 L .48318 .59275 L p 0 0 .512 r
F P
0 g
s
.5617 .59966 m .54973 .61771 L .55287 .61395 L p 0 0 0 r
F P
0 g
s
.55287 .61395 m .56641 .59401 L .5617 .59966 L p 0 0 0 r
F P
0 g
s
.48818 .33056 m .49169 .34049 L .45695 .34901 L p .662 .722 .893 r
F P
0 g
s
.45695 .34901 m .44983 .34002 L .48818 .33056 L p .662 .722 .893 r
F P
0 g
s
.4997 .61697 m .48734 .59855 L .48318 .59275 L p .615 .174 0 r
F P
0 g
s
.48734 .59855 m .4997 .61697 L .50418 .62029 L p .801 .311 0 r
F P
0 g
s
.31218 .43078 m .32616 .42041 L .30546 .45381 L p .798 .995 .772 r
F P
0 g
s
.30546 .45381 m .29032 .46627 L .31218 .43078 L p .798 .995 .772 r
F P
0 g
s
.58751 .46457 m .57743 .50073 L .56297 .49378 L p .846 .659 .65 r
F P
0 g
s
.56297 .49378 m .57031 .4561 L .58751 .46457 L p .846 .659 .65 r
F P
0 g
s
.57761 .42117 m .57031 .4561 L .5498 .45058 L p .79 .607 .654 r
F P
0 g
s
.5498 .45058 m .5538 .41463 L .57761 .42117 L p .79 .607 .654 r
F P
0 g
s
.43486 .34156 m .44248 .33793 L .40687 .35478 L p 0 0 0 r
F P
0 g
s
.40687 .35478 m .39608 .35991 L .43486 .34156 L p 0 0 0 r
F P
0 g
s
.58814 .50958 m .57589 .54399 L .56721 .53701 L p .905 .73 .654 r
F P
0 g
s
.56721 .53701 m .57743 .50073 L .58814 .50958 L p .905 .73 .654 r
F P
0 g
s
.4773 .41951 m .48395 .4547 L .46595 .4626 L p .552 .422 .657 r
F P
0 g
s
.47553 .49911 m .46595 .4626 L .48395 .4547 L p .548 .413 .649 r
F P
0 g
s
.46595 .4626 m .47553 .49911 L .46397 .50762 L p .449 .351 .652 r
F P
0 g
s
.85986 .43317 m .84696 .4493 L .82426 .3994 L p .916 .856 .767 r
F P
0 g
s
.82426 .3994 m .8366 .38074 L .85986 .43317 L p .916 .856 .767 r
F P
0 g
s
.49842 .38258 m .5017 .41376 L .4773 .41951 L p .629 .488 .672 r
F P
0 g
s
.48395 .4547 m .4773 .41951 L .5017 .41376 L p .624 .471 .654 r
F P
0 g
s
.55782 .38359 m .5538 .41463 L .52785 .41209 L p .737 .572 .669 r
F P
0 g
s
.52785 .41209 m .52824 .38064 L .55782 .38359 L p .737 .572 .669 r
F P
0 g
s
.77739 .4827 m .76232 .4739 L .74397 .4379 L p .178 .45 .878 r
F P
0 g
s
.72965 .4271 m .74397 .4379 L .76232 .4739 L p 0 .286 .787 r
F P
0 g
s
.61577 .34094 m .60771 .34276 L .57035 .33199 L p .319 .71 .98 r
F P
0 g
s
.56606 .34178 m .57035 .33199 L .60771 .34276 L p .682 .738 .893 r
F P
0 g
s
.47587 .54244 m .46397 .50762 L .47553 .49911 L p .45 .353 .653 r
F P
0 g
s
.46397 .50762 m .47587 .54244 L .46997 .55026 L p .299 .264 .651 r
F P
0 g
s
.5017 .41376 m .49842 .38258 L .52824 .38064 L p .685 .53 .669 r
F P
0 g
s
.37355 .38016 m .38495 .36906 L .35382 .39468 L p 0 0 0 r
F P
0 g
s
.56641 .59401 m .55287 .61395 L .55413 .60987 L p .855 .947 .589 r
F P
0 g
s
.55413 .60987 m .56834 .58784 L .56641 .59401 L p .855 .947 .589 r
F P
0 g
s
.58101 .55197 m .56734 .58159 L .56342 .57568 L p .958 .822 .666 r
F P
0 g
s
.56342 .57568 m .57589 .54399 L .58101 .55197 L p .958 .822 .666 r
F P
0 g
s
.57035 .33199 m .56606 .34178 L .52903 .338 L p .676 .731 .892 r
F P
0 g
s
.52824 .38064 m .52785 .41209 L .5017 .41376 L p .685 .53 .669 r
F P
0 g
s
.48456 .32753 m .48818 .33056 L .44983 .34002 L p .518 .881 .98 r
F P
0 g
s
.44983 .34002 m .44248 .33793 L .48456 .32753 L p .518 .881 .98 r
F P
0 g
s
.48318 .59275 m .49694 .61312 L .4997 .61697 L p .615 .174 0 r
F P
0 g
s
.49694 .61312 m .48318 .59275 L .48185 .58654 L p 0 .063 .626 r
F P
0 g
s
.52472 .63172 m .52433 .62517 L .51692 .62453 L p .556 .043 0 r
F P
0 g
s
.52433 .62517 m .52472 .63172 L .52849 .63151 L p .456 0 0 r
F P
0 g
s
.52849 .63151 m .5318 .62475 L .52433 .62517 L p .456 0 0 r
F P
0 g
s
.52944 .3278 m .52903 .338 L .49169 .34049 L p .67 .726 .891 r
F P
0 g
s
.49169 .34049 m .48818 .33056 L .52944 .3278 L p .67 .726 .891 r
F P
0 g
s
.5318 .62475 m .52849 .63151 L .53203 .63078 L p .308 0 0 r
F P
0 g
s
.53203 .63078 m .53882 .62329 L .5318 .62475 L p .308 0 0 r
F P
0 g
s
.5538 .41463 m .5498 .45058 L .52747 .44844 L p .737 .559 .652 r
F P
0 g
s
.52747 .44844 m .52785 .41209 L .5538 .41463 L p .737 .559 .652 r
F P
0 g
s
.52098 .6314 m .51692 .62453 L .51005 .62286 L p .618 .078 0 r
F P
0 g
s
.51692 .62453 m .52098 .6314 L .52472 .63172 L p .556 .043 0 r
F P
0 g
s
.48347 .58032 m .46997 .55026 L .47587 .54244 L p .316 .288 .668 r
F P
0 g
s
.46997 .55026 m .48347 .58032 L .48185 .58654 L p .073 .154 .644 r
F P
0 g
s
.84696 .4493 m .83386 .46429 L .81176 .41688 L p .905 .854 .782 r
F P
0 g
s
.81176 .41688 m .82426 .3994 L .84696 .4493 L p .905 .854 .782 r
F P
0 g
s
.50497 .44985 m .5017 .41376 L .52785 .41209 L p .683 .515 .652 r
F P
0 g
s
.5017 .41376 m .50497 .44985 L .48395 .4547 L p .624 .471 .654 r
F P
0 g
s
.53882 .62329 m .53203 .63078 L .5351 .62958 L p .078 0 0 r
F P
0 g
s
.5351 .62958 m .54494 .62089 L .53882 .62329 L p .078 0 0 r
F P
0 g
s
.57031 .4561 m .56297 .49378 L .54578 .48925 L p .791 .603 .647 r
F P
0 g
s
.54578 .48925 m .5498 .45058 L .57031 .4561 L p .791 .603 .647 r
F P
0 g
s
.51752 .63057 m .51005 .62286 L .50418 .62029 L p .626 .061 0 r
F P
0 g
s
.51005 .62286 m .51752 .63057 L .52098 .6314 L p .618 .078 0 r
F P
0 g
s
.52903 .338 m .52944 .3278 L .57035 .33199 L p .676 .731 .892 r
F P
0 g
s
.61577 .34094 m .62411 .34484 L .66103 .36446 L p 0 .284 .671 r
F P
0 g
s
.67272 .37397 m .66103 .36446 L .62411 .34484 L p .572 0 0 r
F P
0 g
s
.52785 .41209 m .52747 .44844 L .50497 .44985 L p .683 .515 .652 r
F P
0 g
s
.49064 .49263 m .48395 .4547 L .50497 .44985 L p .622 .463 .646 r
F P
0 g
s
.48395 .4547 m .49064 .49263 L .47553 .49911 L p .548 .413 .649 r
F P
0 g
s
.29829 .43699 m .31218 .43078 L .29032 .46627 L p .81 .99 .879 r
F P
0 g
s
.29032 .46627 m .27533 .47462 L .29829 .43699 L p .81 .99 .879 r
F P
0 g
s
.57743 .50073 m .56721 .53701 L .55556 .53154 L p .846 .66 .651 r
F P
0 g
s
.55556 .53154 m .56297 .49378 L .57743 .50073 L p .846 .66 .651 r
F P
0 g
s
.79216 .48621 m .77739 .4827 L .75818 .44455 L p .439 .63 .935 r
F P
0 g
s
.74397 .4379 m .75818 .44455 L .77739 .4827 L p .178 .45 .878 r
F P
0 g
s
.54494 .62089 m .5351 .62958 L .5375 .62798 L p 0 0 0 r
F P
0 g
s
.5375 .62798 m .54973 .61771 L .54494 .62089 L p 0 0 0 r
F P
0 g
s
.56834 .58784 m .55413 .60987 L .55342 .60573 L p .968 .925 .695 r
F P
0 g
s
.55342 .60573 m .56734 .58159 L .56834 .58784 L p .968 .925 .695 r
F P
0 g
s
.51457 .62928 m .50418 .62029 L .4997 .61697 L p .513 0 0 r
F P
0 g
s
.50418 .62029 m .51457 .62928 L .51752 .63057 L p .626 .061 0 r
F P
0 g
s
.48521 .53574 m .47553 .49911 L .49064 .49263 L p .549 .414 .65 r
F P
0 g
s
.47553 .49911 m .48521 .53574 L .47587 .54244 L p .45 .353 .653 r
F P
0 g
s
.49608 .609 m .48185 .58654 L .48347 .58032 L p .15 .238 .701 r
F P
0 g
s
.48185 .58654 m .49608 .609 L .49694 .61312 L p 0 .063 .626 r
F P
0 g
s
.20604 .43879 m .19318 .42214 L .22154 .37026 L p .384 .409 .763 r
F P
0 g
s
.83386 .46429 m .82041 .47636 L .79895 .43138 L p .87 .847 .818 r
F P
0 g
s
.79895 .43138 m .81176 .41688 L .83386 .46429 L p .87 .847 .818 r
F P
0 g
s
.57035 .33199 m .57479 .3291 L .61577 .34094 L p .319 .71 .98 r
F P
0 g
s
.57479 .3291 m .57035 .33199 L .52944 .3278 L p .346 .762 .978 r
F P
0 g
s
.42699 .34921 m .43486 .34156 L .39608 .35991 L p 0 0 0 r
F P
0 g
s
.39608 .35991 m .38495 .36906 L .42699 .34921 L p 0 0 0 r
F P
0 g
s
.57589 .54399 m .56342 .57568 L .55685 .57052 L p .901 .735 .667 r
F P
0 g
s
.55685 .57052 m .56721 .53701 L .57589 .54399 L p .901 .735 .667 r
F P
0 g
s
.62411 .34484 m .61577 .34094 L .57479 .3291 L p .353 0 0 r
F P
0 g
s
.5498 .45058 m .54578 .48925 L .52709 .4875 L p .737 .554 .645 r
F P
0 g
s
.52709 .4875 m .52747 .44844 L .5498 .45058 L p .737 .554 .645 r
F P
0 g
s
.52986 .32449 m .52944 .3278 L .48818 .33056 L p .417 .823 .978 r
F P
0 g
s
.48818 .33056 m .48456 .32753 L .52986 .32449 L p .417 .823 .978 r
F P
0 g
s
.54973 .61771 m .5375 .62798 L .53907 .62611 L p .664 .938 .667 r
F P
0 g
s
.53907 .62611 m .55287 .61395 L .54973 .61771 L p .664 .938 .667 r
F P
0 g
s
.50825 .48865 m .50497 .44985 L .52747 .44844 L p .682 .509 .645 r
F P
0 g
s
.50497 .44985 m .50825 .48865 L .49064 .49263 L p .622 .463 .646 r
F P
0 g
s
.48796 .57453 m .47587 .54244 L .48521 .53574 L p .459 .368 .666 r
F P
0 g
s
.47587 .54244 m .48796 .57453 L .48347 .58032 L p .316 .288 .668 r
F P
0 g
s
.4997 .61697 m .51233 .62761 L .51457 .62928 L p .513 0 0 r
F P
0 g
s
.51233 .62761 m .4997 .61697 L .49694 .61312 L p 0 .184 .704 r
F P
0 g
s
.80652 .484 m .79216 .48621 L .77214 .44586 L p .66 .759 .924 r
F P
0 g
s
.75818 .44455 m .77214 .44586 L .79216 .48621 L p .439 .63 .935 r
F P
0 g
s
.52747 .44844 m .52709 .4875 L .50825 .48865 L p .682 .509 .645 r
F P
0 g
s
.82041 .47636 m .80652 .484 L .78575 .44137 L p .798 .823 .871 r
F P
0 g
s
.78575 .44137 m .79895 .43138 L .82041 .47636 L p .798 .823 .871 r
F P
0 g
s
.48079 .33021 m .48456 .32753 L .44248 .33793 L p 0 0 0 r
F P
0 g
s
.44248 .33793 m .43486 .34156 L .48079 .33021 L p 0 0 0 r
F P
0 g
s
.52944 .3278 m .52986 .32449 L .57479 .3291 L p .346 .762 .978 r
F P
0 g
s
.77214 .44586 m .78575 .44137 L .80652 .484 L p .66 .759 .924 r
F P
0 g
s
.56297 .49378 m .55556 .53154 L .54173 .52798 L p .79 .603 .648 r
F P
0 g
s
.54173 .52798 m .54578 .48925 L .56297 .49378 L p .79 .603 .648 r
F P
0 g
s
.56734 .58159 m .55342 .60573 L .55076 .60183 L p .941 .829 .705 r
F P
0 g
s
.55076 .60183 m .56342 .57568 L .56734 .58159 L p .941 .829 .705 r
F P
0 g
s
.22154 .37026 m .23363 .38944 L .20604 .43879 L p .384 .409 .763 r
F P
0 g
s
.21911 .45429 m .20604 .43879 L .23363 .38944 L p .403 .433 .777 r
F P
0 g
s
.55287 .61395 m .53907 .62611 L .53969 .62407 L p .879 .993 .785 r
F P
0 g
s
.53969 .62407 m .55413 .60987 L .55287 .61395 L p .879 .993 .785 r
F P
0 g
s
.28464 .43786 m .29829 .43699 L .27533 .47462 L p .758 .902 .941 r
F P
0 g
s
.27533 .47462 m .26064 .47768 L .28464 .43786 L p .758 .902 .941 r
F P
0 g
s
.49739 .53063 m .49064 .49263 L .50825 .48865 L p .622 .464 .647 r
F P
0 g
s
.49064 .49263 m .49739 .53063 L .48521 .53574 L p .549 .414 .65 r
F P
0 g
s
.49721 .60489 m .48347 .58032 L .48796 .57453 L p .354 .339 .704 r
F P
0 g
s
.48347 .58032 m .49721 .60489 L .49608 .609 L p .15 .238 .701 r
F P
0 g
s
.51095 .62569 m .49694 .61312 L .49608 .609 L p .075 .311 .793 r
F P
0 g
s
.49694 .61312 m .51095 .62569 L .51233 .62761 L p 0 .184 .704 r
F P
0 g
s
.56721 .53701 m .55685 .57052 L .54804 .56648 L p .843 .665 .662 r
F P
0 g
s
.54804 .56648 m .55556 .53154 L .56721 .53701 L p .843 .665 .662 r
F P
0 g
s
.54578 .48925 m .54173 .52798 L .5267 .5266 L p .737 .555 .646 r
F P
0 g
s
.5267 .5266 m .52709 .4875 L .54578 .48925 L p .737 .555 .646 r
F P
0 g
s
.49505 .56957 m .48521 .53574 L .49739 .53063 L p .554 .426 .661 r
F P
0 g
s
.48521 .53574 m .49505 .56957 L .48796 .57453 L p .459 .368 .666 r
F P
0 g
s
.52511 .62885 m .52472 .63172 L .52098 .6314 L closepath p .334 .763 .972 r
F P
0 g
s
.52511 .62885 m .52849 .63151 L .52472 .63172 L closepath p .392 .813 .971 r
F P
0 g
s
.52511 .62885 m .53203 .63078 L .52849 .63151 L closepath p .478 .864 .976 r
F P
0 g
s
.52511 .62885 m .52098 .6314 L .51752 .63057 L closepath p .313 .722 .977 r
F P
0 g
s
.51156 .52751 m .50825 .48865 L .52709 .4875 L p .683 .509 .646 r
F P
0 g
s
.50825 .48865 m .51156 .52751 L .49739 .53063 L p .622 .464 .647 r
F P
0 g
s
.23363 .38944 m .24588 .40743 L .21911 .45429 L p .403 .433 .777 r
F P
0 g
s
.23251 .46686 m .21911 .45429 L .24588 .40743 L p .452 .495 .813 r
F P
0 g
s
.55413 .60987 m .53969 .62407 L .53931 .62202 L p .922 .923 .795 r
F P
0 g
s
.53931 .62202 m .55342 .60573 L .55413 .60987 L p .922 .923 .795 r
F P
0 g
s
.52511 .62885 m .5351 .62958 L .53203 .63078 L closepath p .576 .904 .98 r
F P
0 g
s
.52511 .62885 m .51752 .63057 L .51457 .62928 L closepath p .326 .69 .98 r
F P
0 g
s
.52709 .4875 m .5267 .5266 L .51156 .52751 L p .683 .509 .646 r
F P
0 g
s
.51054 .62364 m .49608 .609 L .49721 .60489 L p .288 .388 .791 r
F P
0 g
s
.49608 .609 m .51054 .62364 L .51095 .62569 L p .075 .311 .793 r
F P
0 g
s
.62411 .34484 m .63273 .35276 L .67272 .37397 L p .572 0 0 r
F P
0 g
s
.27134 .4329 m .28464 .43786 L .26064 .47768 L p .647 .749 .923 r
F P
0 g
s
.26064 .47768 m .24635 .47499 L .27134 .4329 L p .647 .749 .923 r
F P
0 g
s
.56342 .57568 m .55076 .60183 L .54634 .59843 L p .889 .745 .696 r
F P
0 g
s
.54634 .59843 m .55685 .57052 L .56342 .57568 L p .889 .745 .696 r
F P
0 g
s
.52511 .62885 m .5375 .62798 L .5351 .62958 L closepath p .663 .922 .975 r
F P
0 g
s
.57479 .3291 m .57939 .33193 L .62411 .34484 L p .353 0 0 r
F P
0 g
s
.57939 .33193 m .57479 .3291 L .52986 .32449 L p .318 0 0 r
F P
0 g
s
.52511 .62885 m .51457 .62928 L .51233 .62761 L closepath p .363 .665 .972 r
F P
0 g
s
.50025 .60108 m .48796 .57453 L .49505 .56957 L p .479 .404 .694 r
F P
0 g
s
.48796 .57453 m .50025 .60108 L .49721 .60489 L p .354 .339 .704 r
F P
0 g
s
.24588 .40743 m .25842 .42242 L .23251 .46686 L p .452 .495 .813 r
F P
0 g
s
.24635 .47499 m .23251 .46686 L .25842 .42242 L p .535 .601 .866 r
F P
0 g
s
.5303 .3269 m .52986 .32449 L .48456 .32753 L p .198 0 0 r
F P
0 g
s
.48456 .32753 m .48079 .33021 L .5303 .3269 L p .198 0 0 r
F P
0 g
s
.52511 .62885 m .53907 .62611 L .5375 .62798 L closepath p .727 .915 .958 r
F P
0 g
s
.25842 .42242 m .27134 .4329 L .24635 .47499 L p .535 .601 .866 r
F P
0 g
s
.55556 .53154 m .54804 .56648 L .53762 .56385 L p .789 .609 .658 r
F P
0 g
s
.53762 .56385 m .54173 .52798 L .55556 .53154 L p .789 .609 .658 r
F P
0 g
s
.52511 .62885 m .51233 .62761 L .51095 .62569 L closepath p .411 .646 .954 r
F P
0 g
s
.55342 .60573 m .53931 .62202 L .53796 .62008 L p .899 .836 .774 r
F P
0 g
s
.53796 .62008 m .55076 .60183 L .55342 .60573 L p .899 .836 .774 r
F P
0 g
s
.50424 .56581 m .49739 .53063 L .51156 .52751 L p .625 .474 .657 r
F P
0 g
s
.49739 .53063 m .50424 .56581 L .49505 .56957 L p .554 .426 .661 r
F P
0 g
s
.63273 .35276 m .62411 .34484 L .57939 .33193 L p .59 .028 0 r
F P
0 g
s
.51112 .6216 m .49721 .60489 L .50025 .60108 L p .424 .438 .77 r
F P
0 g
s
.49721 .60489 m .51112 .6216 L .51054 .62364 L p .288 .388 .791 r
F P
0 g
s
.52511 .62885 m .53969 .62407 L .53907 .62611 L closepath p .764 .89 .934 r
F P
0 g
s
.41892 .35881 m .42699 .34921 L .38495 .36906 L p .025 0 0 r
F P
0 g
s
.38495 .36906 m .37355 .38016 L .41892 .35881 L p .025 0 0 r
F P
0 g
s
.52511 .62885 m .51095 .62569 L .51054 .62364 L closepath p .462 .633 .928 r
F P
0 g
s
.52986 .32449 m .5303 .3269 L .57939 .33193 L p .318 0 0 r
F P
0 g
s
.55685 .57052 m .54634 .59843 L .54044 .59578 L p .836 .678 .687 r
F P
0 g
s
.54044 .59578 m .54804 .56648 L .55685 .57052 L p .836 .678 .687 r
F P
0 g
s
.54173 .52798 m .53762 .56385 L .52631 .56284 L p .737 .561 .655 r
F P
0 g
s
.52631 .56284 m .5267 .5266 L .54173 .52798 L p .737 .561 .655 r
F P
0 g
s
.50501 .59781 m .49505 .56957 L .50424 .56581 L p .565 .453 .685 r
F P
0 g
s
.49505 .56957 m .50501 .59781 L .50025 .60108 L p .479 .404 .694 r
F P
0 g
s
.52511 .62885 m .53931 .62202 L .53969 .62407 L closepath p .779 .855 .907 r
F P
0 g
s
.51491 .56351 m .51156 .52751 L .5267 .5266 L p .684 .517 .655 r
F P
0 g
s
.51156 .52751 m .51491 .56351 L .50424 .56581 L p .625 .474 .657 r
F P
0 g
s
.47691 .33691 m .48079 .33021 L .43486 .34156 L p .231 0 0 r
F P
0 g
s
.43486 .34156 m .42699 .34921 L .47691 .33691 L p .231 0 0 r
F P
0 g
s
.52511 .62885 m .51054 .62364 L .51112 .6216 L closepath p .509 .626 .902 r
F P
0 g
s
.5267 .5266 m .52631 .56284 L .51491 .56351 L p .684 .517 .655 r
F P
0 g
s
.55076 .60183 m .53796 .62008 L .53574 .6184 L p .86 .762 .753 r
F P
0 g
s
.53574 .6184 m .54634 .59843 L .55076 .60183 L p .86 .762 .753 r
F P
0 g
s
.51266 .61971 m .50025 .60108 L .50501 .59781 L p .517 .476 .75 r
F P
0 g
s
.50025 .60108 m .51266 .61971 L .51112 .6216 L p .424 .438 .77 r
F P
0 g
s
.52511 .62885 m .53796 .62008 L .53931 .62202 L closepath p .779 .817 .883 r
F P
0 g
s
.52511 .62885 m .51112 .6216 L .51266 .61971 L closepath p .552 .625 .878 r
F P
0 g
s
.52511 .62885 m .53574 .6184 L .53796 .62008 L closepath p .769 .78 .862 r
F P
0 g
s
.52511 .62885 m .53278 .61709 L .53574 .6184 L closepath p .753 .747 .847 r
F P
0 g
s
.52511 .62885 m .52929 .61624 L .53278 .61709 L closepath p .732 .717 .837 r
F P
0 g
s
.52511 .62885 m .52551 .61591 L .52929 .61624 L closepath p .709 .691 .831 r
F P
0 g
s
.52511 .62885 m .52171 .61613 L .52551 .61591 L closepath p .683 .67 .831 r
F P
0 g
s
.52511 .62885 m .51814 .61687 L .52171 .61613 L closepath p .655 .652 .835 r
F P
0 g
s
.52511 .62885 m .51505 .61809 L .51814 .61687 L closepath p .624 .639 .844 r
F P
0 g
s
.52511 .62885 m .51266 .61971 L .51505 .61809 L closepath p .59 .629 .859 r
F P
0 g
s
.54804 .56648 m .54044 .59578 L .53347 .59406 L p .786 .624 .68 r
F P
0 g
s
.53347 .59406 m .53762 .56385 L .54804 .56648 L p .786 .624 .68 r
F P
0 g
s
.51117 .59534 m .50424 .56581 L .51491 .56351 L p .631 .495 .679 r
F P
0 g
s
.50424 .56581 m .51117 .59534 L .50501 .59781 L p .565 .453 .685 r
F P
0 g
s
.54634 .59843 m .53574 .6184 L .53278 .61709 L p .818 .702 .738 r
F P
0 g
s
.53278 .61709 m .54044 .59578 L .54634 .59843 L p .818 .702 .738 r
F P
0 g
s
.50501 .59781 m .51505 .61809 L .51266 .61971 L p .517 .476 .75 r
F P
0 g
s
.51505 .61809 m .50501 .59781 L .51117 .59534 L p .586 .509 .735 r
F P
0 g
s
.53762 .56385 m .53347 .59406 L .52591 .59339 L p .737 .578 .677 r
F P
0 g
s
.52591 .59339 m .52631 .56284 L .53762 .56385 L p .737 .578 .677 r
F P
0 g
s
.5183 .59383 m .51491 .56351 L .52631 .56284 L p .686 .536 .676 r
F P
0 g
s
.51491 .56351 m .5183 .59383 L .51117 .59534 L p .631 .495 .679 r
F P
0 g
s
.51117 .59534 m .51814 .61687 L .51505 .61809 L p .586 .509 .735 r
F P
0 g
s
.52631 .56284 m .52591 .59339 L .5183 .59383 L p .686 .536 .676 r
F P
0 g
s
.54044 .59578 m .53278 .61709 L .52929 .61624 L p .775 .653 .728 r
F P
0 g
s
.52929 .61624 m .53347 .59406 L .54044 .59578 L p .775 .653 .728 r
F P
0 g
s
.75818 .44455 m .74397 .4379 L .70911 .40547 L p .003 .42 .858 r
F P
0 g
s
.5183 .59383 m .52171 .61613 L .51814 .61687 L p .641 .542 .726 r
F P
0 g
s
.51814 .61687 m .51117 .59534 L .5183 .59383 L p .641 .542 .726 r
F P
0 g
s
.53347 .59406 m .52929 .61624 L .52551 .61591 L p .733 .612 .722 r
F P
0 g
s
.52591 .59339 m .52551 .61591 L .52171 .61613 L p .689 .575 .722 r
F P
0 g
s
.52171 .61613 m .5183 .59383 L .52591 .59339 L p .689 .575 .722 r
F P
0 g
s
.52551 .61591 m .52591 .59339 L .53347 .59406 L p .733 .612 .722 r
F P
0 g
s
.57939 .33193 m .58415 .33877 L .63273 .35276 L p .59 .028 0 r
F P
0 g
s
.58415 .33877 m .57939 .33193 L .5303 .3269 L p .527 0 0 r
F P
0 g
s
.53076 .33332 m .5303 .3269 L .48079 .33021 L p .411 0 0 r
F P
0 g
s
.48079 .33021 m .47691 .33691 L .53076 .33332 L p .411 0 0 r
F P
0 g
s
.64157 .36263 m .63273 .35276 L .58415 .33877 L p .644 .108 0 r
F P
0 g
s
.5303 .3269 m .53076 .33332 L .58415 .33877 L p .527 0 0 r
F P
0 g
s
.33867 .4037 m .35028 .39944 L .31218 .43078 L p .645 .968 .845 r
F P
0 g
s
.31218 .43078 m .29829 .43699 L .33867 .4037 L p .645 .968 .845 r
F P
0 g
s
.47291 .34556 m .47691 .33691 L .42699 .34921 L p .293 0 0 r
F P
0 g
s
.42699 .34921 m .41892 .35881 L .47291 .34556 L p .293 0 0 r
F P
0 g
s
.77214 .44586 m .75818 .44455 L .72129 .4101 L p .398 .655 .962 r
F P
0 g
s
.70911 .40547 m .72129 .4101 L .75818 .44455 L p .003 .42 .858 r
F P
0 g
s
.8366 .38074 m .82426 .3994 L .7783 .35381 L p .874 .774 .749 r
F P
0 g
s
.7783 .35381 m .78901 .33274 L .8366 .38074 L p .874 .774 .749 r
F P
0 g
s
.78575 .44137 m .77214 .44586 L .73328 .40934 L p .66 .758 .922 r
F P
0 g
s
.72129 .4101 m .73328 .40934 L .77214 .44586 L p .398 .655 .962 r
F P
0 g
s
.32723 .40254 m .33867 .4037 L .29829 .43699 L p .705 .918 .966 r
F P
0 g
s
.29829 .43699 m .28464 .43786 L .32723 .40254 L p .705 .918 .966 r
F P
0 g
s
.82426 .3994 m .81176 .41688 L .76746 .37366 L p .865 .776 .761 r
F P
0 g
s
.76746 .37366 m .7783 .35381 L .82426 .3994 L p .865 .776 .761 r
F P
0 g
s
.58415 .33877 m .58904 .34757 L .64157 .36263 L p .644 .108 0 r
F P
0 g
s
.58904 .34757 m .58415 .33877 L .53076 .33332 L p .573 .066 .01 r
F P
0 g
s
.53123 .34168 m .53076 .33332 L .47691 .33691 L p .461 0 .017 r
F P
0 g
s
.47691 .33691 m .47291 .34556 L .53123 .34168 L p .461 0 .017 r
F P
0 g
s
.81176 .41688 m .79895 .43138 L .75638 .39047 L p .84 .78 .794 r
F P
0 g
s
.75638 .39047 m .76746 .37366 L .81176 .41688 L p .84 .78 .794 r
F P
0 g
s
.79895 .43138 m .78575 .44137 L .74499 .40269 L p .784 .78 .849 r
F P
0 g
s
.73328 .40934 m .74499 .40269 L .78575 .44137 L p .66 .758 .922 r
F P
0 g
s
.74499 .40269 m .75638 .39047 L .79895 .43138 L p .784 .78 .849 r
F P
0 g
s
.65057 .37223 m .64157 .36263 L .58904 .34757 L p .632 .089 0 r
F P
0 g
s
.53076 .33332 m .53123 .34168 L .58904 .34757 L p .573 .066 .01 r
F P
0 g
s
.23363 .38944 m .22154 .37026 L .27399 .32374 L p .495 .458 .745 r
F P
0 g
s
.31605 .39548 m .32723 .40254 L .28464 .43786 L p .649 .749 .922 r
F P
0 g
s
.28464 .43786 m .27134 .4329 L .31605 .39548 L p .649 .749 .922 r
F P
0 g
s
.46884 .35392 m .47291 .34556 L .41892 .35881 L p .279 0 0 r
F P
0 g
s
.41892 .35881 m .41069 .36813 L .46884 .35392 L p .279 0 0 r
F P
0 g
s
.27399 .32374 m .28424 .34528 L .23363 .38944 L p .495 .458 .745 r
F P
0 g
s
.24588 .40743 m .23363 .38944 L .28424 .34528 L p .505 .475 .757 r
F P
0 g
s
.30518 .38283 m .31605 .39548 L .27134 .4329 L p .58 .608 .845 r
F P
0 g
s
.27134 .4329 m .25842 .42242 L .30518 .38283 L p .58 .608 .845 r
F P
0 g
s
.28424 .34528 m .29459 .36558 L .24588 .40743 L p .505 .475 .757 r
F P
0 g
s
.25842 .42242 m .24588 .40743 L .29459 .36558 L p .532 .521 .789 r
F P
0 g
s
.29459 .36558 m .30518 .38283 L .25842 .42242 L p .532 .521 .789 r
F P
0 g
s
.59402 .35607 m .58904 .34757 L .53123 .34168 L p .563 .049 0 r
F P
0 g
s
.53171 .34976 m .53123 .34168 L .47291 .34556 L p .45 0 0 r
F P
0 g
s
.47291 .34556 m .46884 .35392 L .53171 .34976 L p .45 0 0 r
F P
0 g
s
.53123 .34168 m .53171 .34976 L .59402 .35607 L p .563 .049 0 r
F P
0 g
s
.73328 .40934 m .72129 .4101 L .66868 .38236 L p .368 .687 .98 r
F P
0 g
s
.38597 .37489 m .39413 .37769 L .33867 .4037 L p .627 .91 .983 r
F P
0 g
s
.33867 .4037 m .32723 .40254 L .38597 .37489 L p .627 .91 .983 r
F P
0 g
s
.74499 .40269 m .73328 .40934 L .6776 .37986 L p .659 .756 .921 r
F P
0 g
s
.66868 .38236 m .6776 .37986 L .73328 .40934 L p .368 .687 .98 r
F P
0 g
s
.75638 .39047 m .74499 .40269 L .68632 .37141 L p .764 .742 .833 r
F P
0 g
s
.6776 .37986 m .68632 .37141 L .74499 .40269 L p .659 .756 .921 r
F P
0 g
s
.78901 .33274 m .7783 .35381 L .71123 .31673 L p .827 .708 .734 r
F P
0 g
s
.71123 .31673 m .71927 .29362 L .78901 .33274 L p .827 .708 .734 r
F P
0 g
s
.37798 .36614 m .38597 .37489 L .32723 .40254 L p .651 .749 .921 r
F P
0 g
s
.32723 .40254 m .31605 .39548 L .37798 .36614 L p .651 .749 .921 r
F P
0 g
s
.7783 .35381 m .76746 .37366 L .70311 .33857 L p .822 .713 .745 r
F P
0 g
s
.70311 .33857 m .71123 .31673 L .7783 .35381 L p .822 .713 .745 r
F P
0 g
s
.76746 .37366 m .75638 .39047 L .69483 .35731 L p .805 .724 .775 r
F P
0 g
s
.68632 .37141 m .69483 .35731 L .75638 .39047 L p .764 .742 .833 r
F P
0 g
s
.69483 .35731 m .70311 .33857 L .76746 .37366 L p .805 .724 .775 r
F P
0 g
s
.3702 .35172 m .37798 .36614 L .31605 .39548 L p .619 .62 .83 r
F P
0 g
s
.31605 .39548 m .30518 .38283 L .3702 .35172 L p .619 .62 .83 r
F P
0 g
s
.28424 .34528 m .27399 .32374 L .34782 .287 L p .574 .497 .731 r
F P
0 g
s
.34782 .287 m .35518 .31046 L .28424 .34528 L p .574 .497 .731 r
F P
0 g
s
.29459 .36558 m .28424 .34528 L .35518 .31046 L p .579 .511 .742 r
F P
0 g
s
.36262 .33265 m .3702 .35172 L .30518 .38283 L p .594 .548 .772 r
F P
0 g
s
.30518 .38283 m .29459 .36558 L .36262 .33265 L p .594 .548 .772 r
F P
0 g
s
.35518 .31046 m .36262 .33265 L .29459 .36558 L p .579 .511 .742 r
F P
0 g
s
.45656 .35765 m .46062 .36149 L .39413 .37769 L p .535 .877 .989 r
F P
0 g
s
.68632 .37141 m .6776 .37986 L .60902 .36027 L p .658 .754 .921 r
F P
0 g
s
.60407 .36395 m .60902 .36027 L .6776 .37986 L p .361 .728 .988 r
F P
0 g
s
.45259 .34781 m .45656 .35765 L .38597 .37489 L p .653 .75 .92 r
F P
0 g
s
.38597 .37489 m .37798 .36614 L .45259 .34781 L p .653 .75 .92 r
F P
0 g
s
.69483 .35731 m .68632 .37141 L .61388 .35059 L p .741 .709 .822 r
F P
0 g
s
.60902 .36027 m .61388 .35059 L .68632 .37141 L p .658 .754 .921 r
F P
0 g
s
.70311 .33857 m .69483 .35731 L .61862 .33522 L p .768 .678 .764 r
F P
0 g
s
.61388 .35059 m .61862 .33522 L .69483 .35731 L p .741 .709 .822 r
F P
0 g
s
.44872 .33226 m .45259 .34781 L .37798 .36614 L p .654 .636 .82 r
F P
0 g
s
.37798 .36614 m .3702 .35172 L .44872 .33226 L p .654 .636 .82 r
F P
0 g
s
.53267 .35674 m .53315 .35259 L .60902 .36027 L p .388 .776 .989 r
F P
0 g
s
.71927 .29362 m .71123 .31673 L .62777 .29195 L p .781 .655 .723 r
F P
0 g
s
.62777 .29195 m .63227 .26744 L .71927 .29362 L p .781 .655 .723 r
F P
0 g
s
.71123 .31673 m .70311 .33857 L .62324 .31515 L p .778 .661 .734 r
F P
0 g
s
.61862 .33522 m .62324 .31515 L .70311 .33857 L p .768 .678 .764 r
F P
0 g
s
.62324 .31515 m .62777 .29195 L .71123 .31673 L p .778 .661 .734 r
F P
0 g
s
.44493 .31202 m .44872 .33226 L .3702 .35172 L p .644 .575 .762 r
F P
0 g
s
.3702 .35172 m .36262 .33265 L .44493 .31202 L p .644 .575 .762 r
F P
0 g
s
.61388 .35059 m .60902 .36027 L .53315 .35259 L p .657 .752 .92 r
F P
0 g
s
.44122 .28862 m .44493 .31202 L .36262 .33265 L p .638 .545 .733 r
F P
0 g
s
.36262 .33265 m .35518 .31046 L .44122 .28862 L p .638 .545 .733 r
F P
0 g
s
.35518 .31046 m .34782 .287 L .43754 .26392 L p .635 .534 .722 r
F P
0 g
s
.43754 .26392 m .44122 .28862 L .35518 .31046 L p .635 .534 .722 r
F P
0 g
s
.53362 .34243 m .53315 .35259 L .45656 .35765 L p .655 .751 .92 r
F P
0 g
s
.45656 .35765 m .45259 .34781 L .53362 .34243 L p .655 .751 .92 r
F P
0 g
s
.53315 .35259 m .53362 .34243 L .61388 .35059 L p .657 .752 .92 r
F P
0 g
s
.61862 .33522 m .61388 .35059 L .53362 .34243 L p .714 .68 .816 r
F P
0 g
s
.53407 .32655 m .53362 .34243 L .45259 .34781 L p .686 .656 .815 r
F P
0 g
s
.45259 .34781 m .44872 .33226 L .53407 .32655 L p .686 .656 .815 r
F P
0 g
s
.62324 .31515 m .61862 .33522 L .53407 .32655 L p .729 .639 .758 r
F P
0 g
s
.53362 .34243 m .53407 .32655 L .61862 .33522 L p .714 .68 .816 r
F P
0 g
s
.53452 .30595 m .53407 .32655 L .44872 .33226 L p .689 .605 .757 r
F P
0 g
s
.44872 .33226 m .44493 .31202 L .53452 .30595 L p .689 .605 .757 r
F P
0 g
s
.62777 .29195 m .62324 .31515 L .53452 .30595 L p .734 .618 .729 r
F P
0 g
s
.53407 .32655 m .53452 .30595 L .62324 .31515 L p .729 .639 .758 r
F P
0 g
s
.63227 .26744 m .62777 .29195 L .53495 .2822 L p .735 .61 .718 r
F P
0 g
s
.53452 .30595 m .53495 .2822 L .62777 .29195 L p .734 .618 .729 r
F P
0 g
s
.53495 .2822 m .53539 .25714 L .63227 .26744 L p .735 .61 .718 r
F P
0 g
s
.53495 .2822 m .53452 .30595 L .44493 .31202 L p .688 .58 .728 r
F P
0 g
s
.44493 .31202 m .44122 .28862 L .53495 .2822 L p .688 .58 .728 r
F P
0 g
s
.53539 .25714 m .53495 .2822 L .44122 .28862 L p .688 .571 .718 r
F P
0 g
s
.44122 .28862 m .43754 .26392 L .53539 .25714 L p .688 .571 .718 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000So/9:g00?o0000okbL]onlW;L00onlW;L;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`0001Oo/9:g00?o0000
okbL]onlW;L03_nlW;L:o`0001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[
ooooo`004_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool0K?ooool4o`0000;oXXRh00?o0000ok2B]on`T[L07?n`T[L00ol0003o_9bgokbL]`0HokbL
]`Oo00004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`Co
00001_nRR;P00ol0003o/9:gok2B]`0Lok2B]`03o`000?nlW;Oo_9bg01co_9bg00?o0000olNW^Oo7
YkT00ol0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
1?l0000;oj:8^003o`000?n`T[Oo/9:g01_o/9:g00?o0000okbL]onlW;L07?nlW;L00ol0003oajNi
olNW^@03olNW^@?o00003?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo
000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Mooooo`Co00003onRR;P00ol0003o/9:gok2B]`0Kok2B]`03o`000?nlW;Oo_9bg01_o_9bg00?o
0000olNW^Oo7YkT01oo7YkT3o`0000Wooooo00?o0000ooooooooool0;oooool2o`0002_ooooo000M
ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oooooooooo05Sooooo1?l0000C
oj:8^003o`000?n`T[Oo/9:g01_o/9:g00?o0000okbL]onlW;L06onlW;L00ol0003oajNiolNW^@0:
olNW^@?o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo000Koooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Coooo
o`Co00005onRR;P00ol0003o/9:gok2B]`0Dok2B]`So00000_nlW;L3o`0001So_9bg00?o0000olNW
^Oo7YkT03Oo7YkT3o`0000Cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Xoooo
o`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo0ol0000Loj:8^003
o`000?n`T[Oo/9:g00Co/9:g3ol00007ok2D^P03o`000?nkW[[o^ijj00?o^ijj2_l0000>okbL]`03
o`000?o7YkWoajNi013oajNi0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo02Oo
oooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0C?ooool2o`000003oi9o
^ol0003oXXRh01[oXXRh2Ol0000Fok2D^P03o`000?nkW[[o^ijj00go^ijj2Ol00004okbL]`03o`00
0?o7YkWoajNi01CoajNi0ol0000cooooo`03o`000?oooooooooo02Kooooo000Sooooo`;o00003Ooo
ool00ol0003oooooooooo`19ooooo`;o00001?nBOk/00ol0003oXXRhoj:8^00Doj:8^0Co00000_nS
Rk/00ol0003o/9Bjok2D^P0Jok2D^P03o`000?nkW[[o^ijj01Ko^ijj1ol0000EolNW^@03o`000?o7
YkWo000000;o0000<?ooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Kooooo0_l00006oi9o^`03o`000?nRR;SoXXRh013oXXRh1?l00006
oj>;^`03o`000?n`U;[o/9Bj01[o/9Bj00?o0000ok^N^_nkW[X06_nkW[X00ol0003oajVkolNY^`03
o`0001;oajNi00?o0000olNW^Oo7YkT00_o7YkT2o`0002kooooo0_l0000Wooooo`008oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04?ooooo0_l00008oi9o^`03o`000?nRR;SoXXRh
00coXXRh1?l0000:oj>;^`03o`000?n`U;[o/9Bj01[o/9Bj00?o0000ok^N^_nkW[X06_nkW[X00ol0
003oajVkolNY^`03olNY^`?o00003oo7YkT00ol0003oajNiolNW^@02olNW^@04o`000?oC]K_o0000
o`0002kooooo00?o0000ooooooooool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`10ooooo`;o00002onBOk/00ol0003oXXRhoj:8^008oj:8^0?o00003onSRk/00ol0
003o/9Bjok2D^P0Iok2D^P03o`000?nkW[[o^ijj01[o^ijj00?o0000olNY^oo7ZK/01_o7ZK/3o`00
00coajNi00Go0000olNW^Oo7YkWoajNio`000004om>e^`;o0000;?ooool00ol0003oooooooooo`0T
ooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03kooooo00?o0000oi9o
^onBOk/02onBOk/00ol0003oXXRhoj:8^004oj:8^0Co00004_nSRk/00ol0003o/9Bjok2D^P0Bok2D
^PSo00000onkW[X2o`0001Ko^ijj00?o0000olNY^oo7ZK/02_o7ZK/4o`0000OoajNi0_l00003olNW
^@03o`000?oC]K_odkFk00CodkFk00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Soooo
o`008_ooool2o`0001?ooooo00?o0000ooooooooool0>oooool2o`0000koTWnk00?o0000oj:8^?nR
R;P01?l0000Foj>;^`03o`000?n`U;[o/9Bj00Co/9Bj3_l00007ok2J`@03o`000?njXl;o^Z?200?o
^Z?22Ol0000=ok^N^P03o`000?o7ZK_oajVk00koajVk0ol000001_o7YkWo0000o`000?l0003oajNi
o`0000;oajNi00?o0000om>e^ooC]K/01_oC]K/2o`0002_ooooo00?o0000ooooooooool08_ooool0
02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`;o00004?nBOk/3o`00
01SoXh^k0ol000000on`U;[o0000o`000003o`0001Go/9[100?o0000okZS`_njXl803?njXl89o`00
00Co^ijj00?o0000olNY^oo7ZK/03oo7ZK/5o`0000?oajNi00?o0000olNW^Ol000002_oC]K/2o`00
02Wooooo00?o0000ooooooooool08_ooool002;ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0eooooo`;o00004?nBOk/2o`000003oiB2_Ol0003oXh^k01CoXh^k1?l00002ojBC``03
o`000?n`V/7o/9[101Wo/9[100?o0000okZS`_njXl805OnjXl85o`0000koajVk0ol00005olNY^`?o
000000?oajNio`000?l000003?oC]K/2o`0002Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`008_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03;ooooo0_l0000@oi9o^`;o00000onDP[d00ol0
003oXh^koj>;^`0@oj>;^`?o00001_nTTl<00ol0003o/9[1ok2J`@0Iok2J`@03o`000?njXl;o^Z?2
01Wo^Z?200?o0000olB]`oo4[L<00ol00006olNY^`?o00002oo7ZK/3o`0000kodkFk0_l0000Woooo
o`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`04ooooo`008Oooool3o`0001Oooooo00?o0000ooooooooool0;oooool2o`00
013oTWnk0_l00006oiB2_@03o`000?nSRk_oXh^k00_oXh^k1?l00009ojBC``03o`000?n`V/7o/9[1
01Wo/9[100?o0000okZS`_njXl806OnjXl800ol0003oa:g3olB]``03olB]``Ko00003oo7ZK/4o`00
00kodkFk0_l0000Uooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo01Sooooo0_l0000]oooo
o`;o00004?nBOk/2o`0000SoU8:m00?o0000oj>;^onSRk/01onSRk/4o`0000koY9?300?o0000ok2J
`On`V/406?n`V/400ol0003o^Z?2okZS`P0HokZS`P03o`000?o4[L?oa:g300Coa:g31_l0000?olNY
^`04o`000?oB][ko0000om:f_P;o00003_oC]K/00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:Oooool00ol0003oOWFn
o`00000=oi9o^`?o00002_nDP[d00ol0003oXh^koj>;^`04oj>;^`?o00004_nTTl<00ol0003o/9[1
ok2J`@0Aok2J`@So00000onjXl800ol0003o^Z?2okZS`P0DokZS`P04o`000?o4[L?oa:g3olB]``?o
00001_o4[L<3o`0000_oajVk00Go0000om:f__oB][kod[Jno`000002om:f_P;o00003OoC]K/2o`00
02Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Wooooo`05o`000?mnMKkoOWFnogie__l000002_nBOk/2o`0000koU8:m00?o0000oj>;^onSRk/0
0ol0000EojBC``03o`000?n`V/7o/9[100Co/9[13Ol00007ojnWd003o`000?nf[]3o]Zk@00;o]Zk@
2Ol0000=okZS`PCo00003?o4[L<3o`0000SoajVk00?o0000om:f__oB][h00_oB][h01?l0003od[Jn
om:f__oB][h2o`0000godkFk0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ogie__mnMKh00_mnMKh00ol0003oTWnkoi9o^`06oi9o^`;o00003onDP[d3o`00
01OoY9?30ol000000on`V/7o0000o`000003o`0001Co[jO@00?o0000okJ^d?nf[]002onf[]09o`00
00;o^Z?20ol0000BolB]``?o00001Oo7ZK/00ol0003od[Jnom:f_P02om:f_P03o`000?oB][kod[Jn
00?od[Jn0_l0000=om>e^`03o`000?oooooooooo01kooooo0ol00004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02?ooooo00?o0000ogie__mnMKh01?mnMKh00ol0003oTWnkoi9o^`03oi9o^`;o00003onDP[d2
o`000003oiR<aOl0003oY9?301?oY9?31?l00002ojNRd@03o`000?n_Ym3o[jO@01So[jO@00?o0000
okJ^d?nf[]004onf[]05o`0001Koa:g30ol000000oo7ZK_o0000om:f_P05om:f_P03o`000?oB][ko
d[Jn00Cod[Jn00?o0000om>e^ooC]K/02_oC]K/2o`00027ooooo00?o0000ooooooooool00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`001oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool08Oooool00ol0003oOWFnogie_P05ogie_P04o`000?nBOk_oTWnkoi9o^`;o
00003onDP[d2o`0000CoV8c500?o0000ojBC`onTTl<03OnTTl<4o`0000KoYj;A00?o0000ojnWd?n_
Ym006?n_Ym000ol0003o]Zk@okJ^d00@okJ^d0?o00001?nf[]000ol0003o_KGBokfedP03o`0001Co
a:g30ol00006om:f_P03o`000?oB][kod[Jn00Cod[Jn0_l00009om>e^`04o`000?oOa[ooglJoo`00
027ooooo00?o0000ooooooooool07?ooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?mnMKkoOWFn00KoOWFn00Co0000oi9o^ol0003o00003onDP[d2o`0000KoV8c500?o0000
ojBC`onTTl<02?nTTl<5o`0000_oYj;A00?o0000ojnWd?n_Ym004On_Ym07o`0000oo]Zk@0ol00007
okJ^d003o`000?nm]M;o_KGB00?o_KGB1?l0000AolB]``04o`000?o>^LKo0000o`0000Cod[Jn00?o
0000om:f__oB][h01_oB][h2o`0000KodkFk00?o0000omo6_ooOa[l00_oOa[l00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Ooo
ool00ol0003oOWFnogie_P07ogie_P;o00003onDP[d2o`0000SoV8c500?o0000ojBC`onTTl<01?nT
Tl<4o`00013oYj;A00?o0000ojnWd?n_Ym001?n_Ym0=o`0000KoYl3[00?o0000ojS0jonX`>/01?nX
`>/=o`0000Go]Zk@00?o0000okfed_nm]M802?nm]M83o`0000goa:g300?o0000oljia_o>^LH00_o>
^LH2o`0000?od[Jn00?o0000om:f__oB][h01ooB][h2o`0000CodkFk00?o0000omo6_ooOa[l00ooO
a[l00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01_ooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo01_ooooo00?o
0000ogie__mnMKh01omnMKh00ol0003oPGW1o`00000<oiB2_@?o00002onHS<D00ol0003oY9?3ojBC
``03o`0001;oYj;A0ol000000on_Ym3o0000o`000003o`0001;oYl3[00?o0000ojS0jonX`>/02?nX
`>/3o`0000OoZ<3[1_l0000=okfedP?o00002_o4[L<00ol0003oc[W6oljiaP04oljiaP05o`000?oB
][kod[Jnom:f__l000002_oB][h2o`000003om>e^ol0003oglJo00KoglJo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Jooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Wooooo00?o0000ogie__mnMKh01omnMKh01Ol0003oPGW1oh5i`On1NL7o000000WoU8:m
0_l0000=oiR<a@?o00004OnWX]45o`0000;oYko[00?o0000ojO0jonW`>/04?nW`>/7o`0000OoZ<3[
0ol0000?ojS0j`03o`000?nX`N_oZ<7[00;o00003?nm]M84o`0000Goa:g300?o0000oljia_o>^LH0
1_o>^LH2o`0000;od[Jn00?o0000om:f__oB][h02OoB][h00ol0003oglJoomo6_`07omo6_`03o`00
0?oooooooooo01cooooo00?o0000ooooool000006oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?mnMKkoOWFn00OoOWFn00?o0000oh5i`On1NL400on1
NL400ol0003oU8:moiB2_@04oiB2_@;o00003OnHS<D2o`000003oijNe?l0003oYj;A00coYj;A1Ol0
0008ojNoj`03o`000?nW`>_oYl3[00GoYl3[2_l000000ombe?go0000o`000003og;Do@03o`000?mS
a_goHlKm00;oHlKm3_l00006ojS0j`03o`000?nX`N_oZ<7[00CoZ<7[0ol0000<okfedP?o00000_o4
[L<00ol0003oc[W6oljiaP08oljiaP?o00002ooB][h2o`0000WoglJo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Iooooo`008?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01Gooooo00?o0000ogie__mnMKh01omnMKh00ol0003oPGW1oh5i`@04oh5i`@03o`000?nDP[go
U8:m00;oU8:m0_l0000=oiR<a@;o00001?nNW]@00ol0003oYj;AojNRd@06ojNRd@Co00002onW_n/3
o`0000;oYl3[0ol00002og;Do@_o00001?n`S[<00ol0003o_9RcokbH/`0;o`0000KoHlKm1_l0000:
ojS1j`Co00002onm]M82o`0000goc[W60_l00009om:f_P04o`000?oMa/;ogLK2o`0000WoglJo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Hooooo`007oooool2o`0002Sooooo00?o0000
ooooooooool04oooool00ol0003oOWFnogie_P07ogie_P03o`000?n1NL7oPGW100KoPGW100Co0000
oiB2_Ol0003o00003OnHS<D2o`0000OoWYkD00Co0000ojNRdOnWX]7oYj;A1?l0000:ojNoj`Go0000
0_n8h?d;o`0000;oXhFd00?o0000ok2>/on`S[<01on`S[<3o`0000Oo_9Rc00?o0000olNS]?o7Xk@0
2?l00004of?6o@04o`000?mL^_coG;[lo`0000_oZ<7[0ol00009okfedP03o`000?o3_MGo000000go
c[W60_l00007om:f_P05o`000?oMa/;ogLK2omg6`_l000002OoOa[l00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Oooooo000Oooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool04Oooool00ol0003oOWFnogie_P07ogie_P03o`000?n1NL7oPGW100OoPGW10_l0000=oiR<a@;o
00002OnNW]@3o`0000_oYko[1?l00003ohSPo@Co00000_nLTLL4o`0000OoXhFd00?o0000ok2>/on`
S[<01On`S[<3o`0000Wo_9Rc00?o0000olNS]?o7Xk@00oo7Xk@3o`0000;o`Zg51?l00006oebjo0?o
00002OnX`N/3o`0000Go_KGB00?o0000ol>meOo3_MD00_o3_MD2o`0000_oc[W60_l00005om:f_P03
o`000?oMa/;ogLK200?ogLK200?o0000omo6_ooOa[l01ooOa[l00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Oooooo000Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
3oooool00ol0003oOWFnogie_P07ogie_P03o`000?n1NL7oPGW100OoPGW100?o0000ohR5bOl00000
2onHS<D2o`0000WoWYkD0_l000000onV_n_o0000ojNoj`07ojNoj`Co00000_n8h?d5o`0000CoW977
0_l000000onDO;Ko0000oj>5]008oj>5]003o`000?n`S[?o/8jc00;o/8jc0ol00002ok2>/`03o`00
0?nlV;?o_9Rc00Oo_9Rc00?o0000olNS]?o7Xk@01_o7Xk@3o`0000Gob[O81omL^_`3o`0000WoZ<7[
0ol00002okfedP03o`000?o3_MGo`kgE00Co`kgE0_l00009oljiaP04o`000?o>^LKo0000o`0000?o
d[Jn00?o0000omg6`_oMa/801?oMa/800ol0003oglJoomo6_`07omo6_`03o`000?oooooooooo01_o
oooo0_l0000Hooooo`007oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00gooooo
00?o0000ogie__mnMKh01omnMKh00ol0003oPGW1oh5i`@07oh5i`@05o`000?n8QLWoR8G9ohR5bOl0
00002?nHS<D2o`0000SoWYkD0ol00004ojJoj`03o`000?nW_n_oYko[00;oYko[1?l000000on8h?go
0000o`000003o`000003ohn<bol0003oW97700;oW9770ol00003oiAl]P03o`000?nSQKCoXhFd00So
XhFd1?l00005ok2>/`03o`000?nlV;?o_9Rc00Oo_9Rc00?o0000olNS]?o7Xk@01oo7Xk@01?l0003o
d[2go`000?l00006olZgb0;o00001OmL^_`3o`0000WoZ<7[0_l00009ol>me@;o00002?o>^LH00ol0
003oc[W6oljiaP02o`000003om:f__l0003ogLK200KogLK200?o0000omo6_ooOa[l01ooOa[l00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03?ooool00ol0003oOWFnogie_P06ogie_P03o`000?n1NL7oPGW100Oo
PGW100?o0000ohR5bOn8QLT00_n8QLT00ol0003oV8c5oiR<a@04oiR<a@;o00002?nNW]@2o`0000Oo
Y[o[1?l000000on8h?go0000o`000004o`0000GoShc;00Co0000oibAaol0003o00001onDO;H00ol0
003oXhFdoj>5]005oj>5]0?o00002?n`S[<00ol0003o_9RcokbH/`06okbH/`03o`000?o7XkCoaj>d
00Soaj>d00Co0000om:`]ooB/;Ood[2g0_l00003olZgb003o`000?oA`lcodL?<00?odL?<0_l00003
oebjo0?o00001_nX`N/01?l0003oZ<7[ojS1jol00009ol>me@03o`000?o>^LKoc[W600Koc[W600Co
0000oljia_o>^LKoc[W60_l00008omg6`P03o`000?oOa[ooglJo00OoglJo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Eooooo`007oooool2o`0002gooooo00?o0000ooooooooool02_oo
ool00ol0003oHVS3o`000006ogie_P03o`000?n1NL7oPGW100KoPGW10_l00006ohR5b@04o`000?nH
S<GoV8c5oiR<a@;o00002?nNW]@2o`0000OoY[o[0_l00003oj3Xn`Co000000?oYKOVo`000?n?S</0
1_n?S</2o`0000WoU7bf00?o0000oj>5]?nSQK@00_nSQK@3o`0000;oXhFd00?o0000ok2>/on`S[<0
1_n`S[<00ol0003o_9RcokbH/`06okbH/`03o`000?o7XkCoaj>d00Ooaj>d00?o0000om:`]ooB/;L0
1?oB/;L2o`000003olZgb?l0003odL?<00GodL?<00?o0000ok30i_n``>H00_l00002oebjo0?o0000
0_nX`N/00ol0003oZ<7[ojS1j`03ojS1j`;o00001oo3_MD2o`0000Ooc[W600Ko0000oljia_o>^LKo
0000omO7bol00008omg6`P03o`000?oOa[ooglJo00OoglJo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wo
oooo00Co0000of9X`omRJ<?o00001?mnMKh00ol0003oPGW1oh5i`@06oh5i`@03o`000?n8QLWoR8G9
00KoR8G900Co0000oiR<aOnHS<Go00002?nNW]@2o`0000OoY[o[0_l00003oj3Xn`?o00000onS^>L0
0ol0003oShc;ohn<b`05ohn<b`03o`000?n1L[Wo000000WoU7bf00?o0000oj>5]?l000000_l00004
oj>5]13o00000onlV;<00ol0003oaj>dolNS]007olNS]003o`000?oB/;Ood[2g00Kod[2g0_l00007
om73c003o`000?n``>Ko/<3V00So00002?nX`N/00ol0003o`kgEol>me@06ol>me@;o00001Oo>^LH0
0ol0003oc[W6o`000003omO7b`03o`000?oMa/;ogLK200KogLK200?o0000omo6_ooOa[l01ooOa[l0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool01oooool01Ol0003oHVS3of9X`omRJ<?o000000?oOWFn00?o0000
oh5i`On1NL401_n1NL400ol0003oR8G9ohR5b@07ohR5b@;o00002?nNW]@2o`0000OoY[o[0_l00002
oj3Xn`?o000000?oaNW_o`000?nS^>L00onS^>L00on0Qm7o0000ohn<b`04ohn<b`05o`000?n1L[Wo
PG:ioh5b^Ol000001onDO;H3o`0000CoXhFd0ol000000onQO:co0000ojn7Z`07ojn7Z`03o`000?nl
TZ_o_9:[00?o_9:[1_l00007olNS]003o`000?oB/;Ood[2g00Kod[2g00?o0000omk0^_l000001ooA
`l`2o`0000;o/<;W00Co0000of^LkOm[W>go06740omN[oX00ol0003oZ<7[ojS1j`05ojS1j`;o0000
2?o3_MD2o`0000Coc[W600?o0000omO7booGal/00ooGal/00ol0003ogLK2omg6`P06omg6`P03o`00
0?oOa[ooglJo00KoglJo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Cooooo`007_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00?o0000of9X`omRJ<<00omR
J<<00ol0003oOWFno`000008oh5i`@03o`000?n8QLWoR8G900OoR8G900Co0000oiBKf?nDVmSo0000
1?nNW]@3o`0000OoY[o[0_l00002oj3Xn`;o000000CoHMFmolGYkoo5jNoo00001?nS^>L01?l0003o
P8OAoh27dOl00003ohn<b`03o`000?n1L[WoPG:i00;oPG:i00?o0000oiAl]_nDO;H00_nDO;H3o`00
00;oU7bf00?o0000oj>5]?l000000_l00004oj5l[003o`000?n_Qj_o[hN[00Ko[hN[00?o0000okbB
ZonlTZ/01_nlTZ/00ol0003obIj/olVN[005o`000003olNS]?l0003od[2g00Ood[2g00Go0000omk0
^_oN`;[og/2jo`000005om73c0;o00001?n``^L00ol0003oJic]of^Lk@02o`0000?oGZoj0_l00006
ojS1j`;o00002?o3_MD2o`000004oljia_l0003oelO;o`0000GoelO;00?o0000omg6`_oMa/801_oM
a/800ol0003oglJoomo6_`04omo6_`03o`000?oZflCo000001_ooooo00?o0000ooooool000005?oo
ool001kooooo0ol0000aooooo`;o00001Oooool00ol0003oHVS3of9X``04of9X``03o`000?n1NL7o
PGW100KoPGW100?o0000ohR5bOn8QLT01on8QLT00ol0003oU9_HoiBKf002oiBKf004o`000?nNW]Co
WYkDo`0000SoY[o[0_l00002oj3Xn`;o00000_mQeKd3olGYk`05o`000?nS^>OoXkSWoj>hiol00000
1?n0Qm400ol0003oShc;o`000006oh5b^@Co00001?nDO;H3o`0000OoXGb/00?o0000ojn7Zon_Qj/0
1_n_Qj/00ol0003o_9:[okbBZ`06okbBZ`03o`000?o9WZcobIj/00GobIj/0ol00007om:`]`03o`00
0?oN`;[og/2j00;og/2j00Go0000om73c?oA`lcodL?<o`000002omSAdP05o`000?n``^Oo/<;Wok32
iol000000om[W>d01?l0003o0674o`000?l00002oej_nP;o00001_nX`N/2o`0000So`kgE0_l00002
omO7b`03o`000?oGal_oelO;00?oelO;00?o0000omg6`_oMa/801_oMa/800ol0003oglJoomo6_`02
omo6_`04o`000?oZflCoj]_4o`0001kooooo00?o0000ooooooooool04Oooool001kooooo00?o0000
ooooooooool0<oooool01Ol0003ooooooooooooooooo000000OoHVS300?o0000oh5i`On1NL401?n1
NL42o`0000WoR8G900?o0000oiBKf?nDVmP00onDVmP3o`0000OoY[o[0_l00002oj3Xn`;o00000_mQ
eKd01Oo@omWo0000olGYkoo5jNoo000000CoXkSW00?o0000oh27dOn0Qm400on0Qm400ol0003oPG:i
oh5b^@03oh5b^@?o00001?nDO;H3o`000003ohma[Ol0003oXGb/00OoXGb/00?o0000ojn7Zon_Qj/0
1_n_Qj/00ol0003o_9:[okbBZ`06okbBZ`03o`000?o9WZcobIj/00KobIj/00Co0000omJ/[Ol0003o
00001?oB/;L00ol0003og/2jomk0^P04omk0^P03o`000?oA`lco000000?of=7B00?o0000ok32ion`
`^L00_n``^L01ol0003oJic]of^LkOm[W>go0000oaeVf_l0HL@00_l00002oej_nP;o00001_nX`N/2
o`0000Ko`kgE00Go0000olS7fOl0003oelO;o`000006omO7b`03o`000?oMa/;ogLK200KogLK200Go
0000omo6_ooOa[ooglJoo`000003on[Ka003o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Cooooo
00Co0000oooooooooooo00001_mRJ<<00ol0003oIfk6o`000004oh5i`@03o`000?n8QLWoR8G900Oo
R8G90_l00005oiBKf005o`000?nV_ncoY[o/ojJok?l000001?nV_n/2o`0000;oX>Sk0_l000001?mQ
eKgo0000om3ofOo@omT6o`0000;oXkSW00?o0000oh27dOn0Qm401?n0Qm400ol0003oPG:ioh5b^@03
o`0000;oPG:i00?o0000oiAl]_l000000_l00004ohma[@03o`000?nQO:coXGb/00KoXGb/00?o0000
ojn7Zon_Qj/01_n_Qj/00ol0003o_9:[okbBZ`06okbBZ`03o`000?o9WZcobIj/00KobIj/00Go0000
omJ/[OoF[:goeZb]o`000003om:`]`03o`000?oN`;[og/2j00Gog/2j00?o0000omSAd_oHdM800ooH
dM800ol0003o/<;Wok32i`02ok32i`04o`000?m[W>goJic]o`0000;o7FKJ00Co0000oj4A0?l0003o
00000_mN[oX00ol0003oZ<7[ojS1j`05ojS1j`03o`000?o3_MGo`kgE00;o`kgE00Oo0000olS7fOo8
amWob<OIo`000?oGal_o000000KoelO;00?o0000omg6`_oMa/801_oMa/800ol0003oglJoo`000004
on[Ka003o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool001?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Kooooo0_l00006of9X``05o`000?mWK/Ko
Ifk6ofM^a_l000000_n1NL400ol0003oR8G9ohR5b@07ohR5b@03o`000?nDVmSoU9_H00CoU9_H00?o
0000ojJok?nV_n`00onV_n`01?l0003oY[o[ojJojol00002oj3Xn`Go000000Cod?oIo`000?l0003o
00000_o=h>H3oj:hj0;o00001_n0Qm44o`0000GoPG:i0_l00008ohma[@03o`000?nQO:coXGb/00Ko
XGb/00?o0000ojn7Zon_Qj/01On_Qj/00ol0003o_9:[okbBZ`05okbBZ`03o`000?o9WZcobIj/00Ko
bIj/00?o0000omJ/[OoF[:d00ooF[:d2o`000003om:`]ol0003og/2j00Kog/2j00?o0000omSAd_oH
dM800ooHdM800ol0003o/<;Wok32i`02ok32i`05o`000?m[W>goJic]of^LkOl000000_lMI]X2o`0m
`@04o`1Qa?l0003o0000oej_nP;o00001_nX`N/2o`000003ol>meOl0003ob<OI00Cob<OI00?o0000
omO7bol000001_oGal/00ol0003ogLK2omg6`P06omg6`P03o`000?oZflCoj]_400?oj]_400?o0000
ooooooooool07?ooool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool00_ooool0
01?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Oooooo00?o0000
of9X`omRJ<<01?mRJ<<01ol0003oIfk6ofM^a_mWK/Ko0000oh5i`Ol000002On8QLT00ol0003oU9_H
oiBKf004oiBKf003o`000?nV_ncoY[o/00CoY[o/2?l00002olWl_0;o000000?oho;Ho`000?o=h>H0
0_o=h>H01_l0003oX[SXoj:hj?nR^>SoKHCIo`0000?oP8OA0ol00002ofMV_P03o`000?n1L[WoPG:i
00;oPG:i00?o0000ogUT[ol000002?n?LJd00ol0003oXGb/oj5l[006oj5l[003o`000?n_Qj_o[hN[
00Go[hN[00?o0000okbBZonlTZ/01OnlTZ/00ol0003obIj/olVN[006olVN[003o`000?oF[:goeZb]
00GoeZb]0_l00006omk0^P03o`000?oZe;oo000000Cof=7B00Co0000ok32ion``^Oo/<;W1_l00002
oaeVfP06o`000?l0?L7o02^do`000?l0HLCo00000_mN[oX2o`0000GoZ<7[0_l00007olS7f@03o`00
0?oGal_o000000KoelO;00?o0000omg6`_oMa/801OoMa/800ol0003oj]_4on[Ka004on[Ka003o`00
0?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05o`000?oo
ooooooooooooool000001Oooool2o`0003Oooooo00?o0000of9X`omRJ<<01?mRJ<<00ol0003oIfk6
ofM^aP03ofM^aP03o`000?n8QLWoR8G900OoR8G900?o0000oiBKf?nDVmP01?nDVmP00ol0003oY[o/
ojJok004ojJok004o`000?ndjoOo]>_go`0000;oYOOH00Go0000ol?g[Ol0003obOblo`000003on?b
f005o`000?o=h>KocN3VolgPi_l000000onR^>P2off4f@?o000000?oP8OAo`000?mWI[h00_mWI[h0
1Ol0003oPG:ioh5b^On1L[Wo000000?oNFB_00?o0000ohma[On?LJd01On?LJd00ol0003oXGb/oj5l
[006oj5l[003o`000?n_Qj_o[hN[00Go[hN[00?o0000okbBZonlTZ/01OnlTZ/00ol0003obIj/olVN
[006olVN[003o`000?oF[:goeZb]00GoeZb]00?o0000onBm[ol000001?oN`;X01?l0003oj]Boon[D
_ol00004omSAdPCo00000_n`a>T3ogRHi@;o000000Co7FKJo`000?l0?L7o03g10_l0:k@3o`0000;o
GZoj0_l000000onX`N_o0000o`000003ojS2k0Oob<OI0_l00007omO7b`03o`000?oMa/;ogLK200?o
gLK200?o0000onOJb?l000001OoZfl@00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool001?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo03Kooooo00?o0000of9X`omRJ<<01?mRJ<<00ol0003oIfk6ofM^aP03ofM^aP03
o`000?n8QLWoR8G900GoR8G90_l00006oiBKf003o`000?nV_ncoY[o/00CoY[o/00Co0000okC[mond
joOo00000_nUmmP5o`0000?oho;H00?o0000olgPi_o=h>H00_o=h>H00ol0003oX[SXoj:hj003o`00
0004off4fOl0003oP8OAo`0000GoIfJn00?o0000oh5b^Ol000001?miI:l00ol0003oSg6]ohma[@05
ohma[@03o`000?nQO:coXGb/00KoXGb/00?o0000ojn7Zon_Qj/01On_Qj/00ol0003o_9:[okbBZ`05
okbBZ`03o`000?o9WZcobIj/00GobIj/00?o0000omJ/[OoF[:d01OoF[:d01Ol0003oi;f_onBm[ooT
_Joo000000?og/2j00Go0000on[D_ooZe;ooj]Boo`000002omSAdP03o`000?oKhM[o000000Co/<CY
00Co0000ogRHiOmhV>GoN9SU0_m8KmH01?lMI][o0000o`0m`Ol00002o`0[]003o`000?l0Jm_o0000
00Co00001_nX`^`00ol0003ob<OIolS7f@04olS7f@;o00001ooGal/01Ol0003ogLK2omg6`_oMa/;o
000000;oim[800?o0000on[Ka?oZfl@01?oZfl@00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool001?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo03Gooooo00?o0000of9X`omRJ<<01?mRJ<<00ol0003oIfk6ofM^aP03
ofM^aP03o`000?mcO]3o000000GoR8G900?o0000oiBKf?nDVmP01?nDVmP2o`0000KoY[o/00Co0000
okC[mondjoOo00000_nUmmP4o`000003on_gbOl0003oho;H00;oho;H00Co0000olgPi_o=h>KocN3V
1Ol00004off4f@03o`000?mWI[koIfJn00GoIfJn00?o0000ogUT[omiI:l00omiI:l00ol0003oSg6]
ohma[@05ohma[@03o`000?nQO:coXGb/00CoXGb/5?l00006olVN[003o`000?oF[:goeZb]00GoeZb]
00?o0000onBm[ooT_Jl00_oT_Jl00ol0003og/2jo`000004on[D_`03o`000?oHdM;o000000;ofn7J
00?o0000ok34jOn`a>T00_n`a>T01Ol0003oN9SUogRHiOmhV>Go000000;oB6oF00Co0000o`0m`Ol0
?L7o00000_l0:k@00ol0003o06_Ko`1[f`04ofFWmPKoZ<;/00?o0000olS7fOo8amT01?o8amT2o`00
00OoelO;00?o0000omg6`_l000001?oWf/P00ol0003oj]_4on[Ka003on[Ka003o`000?oooooooooo
01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`004oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=?ooool00ol0003oHVS3of9X``04of9X
``03o`000?mWK/KoIfk600CoIfk600Co0000og=nd?mcO]3o00000on8QLT00ol0003oU9_HoiBKf004
oiBKf003o`000?nV_ncoY[o/00GoY[o/00Co0000okC[mondjoOo00000_nUmmP2o`000005ol?g[Ol0
003ojoO9on_gbOl000000ooSl]P00ol0003ocN3Vo`000002o`0000?oX[SX00?o0000off4fOm]Q=T0
0_m]Q=T00ol0003oIfJnofMV_P05ofMV_P03o`000?miI:ooNFB_00CoNFB_00?o0000ohma[On?LJd0
1On?LJd00ol0003oXGb/o`000003o`0000;oWgRW00?o0000ojj3Y_n^PjH01On^PjH00ol0003o_8nV
okb?YP05okb?YP03o`000?o:VjOo000000;o00000oo9WZ`00ol0003oeZb]omJ/[@05omJ/[@03o`00
0?oT_Jooi;f_00?oi;f_00?o0000on[D_ooZe;l01?oZe;l01Ol0003ofn7Jom_Qf_oKhM[o000000Co
/<CY00Go0000ogRHiOmhV>GoN9SUo`000003odQ_eP;o000000Go03g1o`0[]?l0:kCo032ho`000002
o`1[f`CoIJOf00?o0000ojS2k?nX`^`00onX`^`00ol0003ob<OIolS7f@04olS7f@03o`000?oGal_o
elO;00KoelO;00?o0000onOJb?oWf/P00ooWf/P00ol0003oj]_4on[Ka004on[Ka003o`000?oooooo
oooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`004oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0000eooooo`03o`000?mRJ<?oHVS300CoHVS300?o0000
ofM^a_mWK/H00omWK/H00ol0003oLgk@og=nd002og=nd003o`000?n8QLWo000000KoU9_H00?o0000
ojJok?nV_n`01?nV_n`2o`0000;o]>_g00Go0000ojGgf?nUmmSo0000olGi/@02o`0000?ojoO900?o
0000on?bf?oSl]P00ol00002olgPiP05o`000?nR^>SoX[SXoj:hj?l000001?m]Q=T00oloE/;o0000
ofMV_P04ofMV_P03o`000?mHD[7o000000GoNFB_00?o0000ohma[On?LJd01?n?LJd3o`0000KoWgRW
00?o0000ojj3Y_n^PjH01On^PjH00ol0003o_8nVokb?YP05okb?YP03o`000?o:VjOobY^W00;obY^W
0ol00007omJ/[@03o`000?oT_Jooi;f_00Coi;f_00?o0000on[D_ooZe;l01?oZe;l00ol0003ofn7J
om_QfP02om_QfP05o`000?n`a>Wo/<CYok34jOl000000omhV>D01?l0003oB6oFodQ_e_m8KmH2ob]E
b@;o00000_l0:k@01Ol0<;So0000o`1[fol0Jm_o000000?oIJOf00?o0000ojS2k?nX`^`00onX`^`0
0ol0003ob<OIolS7f@04olS7f@03o`000?oGal_oelO;00GoelO;00?o0000onOJb?oWf/P01?oWf/P0
0ol0003oj]_4on[Ka003on[Ka003o`000?oooooooooo01_ooooo0ol00007ooooo`03o`000?oooooo
oooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000of9X`omRJ<<01?mRJ<<00ol0
003oIfk6ofM^aP04ofM^aP03o`000?mcO]3oLgk@00?oLgk@0_l00005oiBKf003o`000?nV_ncoY[o/
00CoY[o/00Go0000okC[mondjoOo]>_go`000002ojGgf004olcnaOl0003o0000o`0000CojoO90ol0
00001?oSl]So0000olgPi_o=h>H7o`0000?oKHCI00?o0000ocmF`_l000000omWI[h01?l0003oF5:a
oeQB/Ol00005ogUT[`04o`000?n?LJgoSg6]ohma[@?o000000?oSFbXo`000?nON:L01_nON:L00ol0
003o[X>Vojj3YP05ojj3YP03o`000?nlSjKo_8nV00Go_8nV00?o0000olZKYoo:VjL01?o:VjL2o`00
00KoeZb]00?o0000onBm[ooT_Jl00ooT_Jl00ol0003ol]>ao`000004on[D_`;o00001?oKhMX01Ol0
003o/<CYok34jOn`a>Wo000000CoN9SU00Co0000odQ_e_m8KmKo00000_l[ELT01Ol0?L7o0000o`0[
]?l0003o032h00;o000000?o06_Ko`000?mUYoH00_mUYoH00ol0003oZ<;/ojS2k003ojS2k003o`00
0?o8amWob<OI00Cob<OI00?o0000omO7booGal/00ooGal/00ol0003og]SAo`000005onOJb003o`00
0?oZflCoj]_400?oj]_400?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03oeEE
EOmVIVKo000000Kooooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000of9X`omRJ<<01?mR
J<<00ol0003oIfk6ofM^aP03ofM^aP03o`000?mcO]3oLgk@00CoLgk@0_n8VMd00ol0003oU9_HoiBK
f002oiBKf0KoY[o/00Go0000okC[mondjoOo]>_go`000002ojGgf003olcnaOl0003oaOVa00;o0000
0_o[mlT2o`0000?oho;H1?l000000oo>eMkoXKWZoj6ijP02oj6ijP;oDh7Q00?o0000off4fOl00000
0oloE/800ol0003oIfJno`000003oeQB/@03o`000?miI:ooNFB_00CoNFB_0ol00004ohe/Z003o`00
0?nON:OoWgRW00GoWgRW00?o0000ojj3Y_n^PjH01On^PjH00ol0003o_8nVokb?YP05okb?YP03o`00
0?o:VjOobY^W00CobY^W00?o0000omRYZ?l000000_l00003omJ/[@03o`000?oT_Jooi;f_00?oi;f_
00?o0000oo;C/Ol000000ooZe;l00ol0003olN_2o`000004om_QfP03o`000?n`a>Wo000000?o0000
0omhV>D01?l0003oB6oFodQ_e_l00003ob]Eb@03o`000?l0:kCo02^d00;o032h0_l000000ol0Jm_o
0000ofFWmP02ofFWmP03o`000?nX`^coZ<;/00?oZ<;/00?o0000olS7fOo8amT01?o8amT01Ol0003o
elO;omO7booGal_o000000;og]SA00?o0000onOJb?oWf/P01?oWf/P00ol0003oj]_4on[Ka003on[K
a003o`000?oooooooooo01cooooo0ol0000<ooooo`007?ooool00ol0003oooooooooo`0dooooo`03
ocIFa_l0003oHVS300?oHVS300?o0000ofM^a_mWK/H01?mWK/H00ol0003oLgk@og=nd003og=nd005
o`000?n8VMgoR9WMohRIgOl000000_nDVmP6ojJok003o`000?ndjoOo]>_g00;o]>_g0_nUmmP00oo<
o/Go0000olGi/@05o`000004on_gbOl0003oho;Hon?bf0;o00001?o>eMh01Ol0003oXKWZoj6ij_nQ
^N[o000000;oDh7Q0_l00004ocmF`P03o`000?mHD[7oF5:a00?oF5:a00?o0000ogUT[omiI:l00_mi
I:l2o`0000KoSFbX00?o0000oimhYonON:L01OnON:L00ol0003o[X>Vojj3YP05ojj3YP03o`000?nl
SjKo_8nV00Go_8nV00?o0000olZKYoo:VjL01?o:VjL00ol0003of:VXomRYZ002omRYZ0?o00001OoT
_Jl01Ol0003ol]>aoo;C/Oobdk7o000000;oj]Bo00Co0000oo7[`_oajl;o00000_oKhMX3o`0000;o
[lG[0_n4U]d2o`000005ogRHiOl0003oB6oFodQ_e_l000001?l[ELT01?l0003o02^do`000?l0<;P2
o`19b@03o`000?l0Jm_o000000?oIJOf00?o0000ojS2k?nX`^`00onX`^`00ol0003ob<OIolS7f@03
olS7f@;o000000?oelO;o`000?oNf=400ooNf=400ol0003oim[8onOJb003onOJb003o`000?oZflCo
j]_400?oj]_400?o0000ooooooooool06Oooool3o`0000;ooooo00?o0000ooooooooool02_ooool0
01cooooo00?o0000ooooooooool0=?ooool2ocIFaP04o`000?mRJ<?oHVS3o`0000KoIfk600?o0000
og=nd?mcO]001?mcO]000ol0003oR9WMohRIg@02ohRIg@;o00001OnV_n`00ol0003o]>_gokC[m`02
okC[m`;o00000_o<o/D5o`0000?ojoO900Go0000on?bf?l0003ohmo@o`000004olkEgP03o`000?nQ
^N[oXKWZ00;oXKWZ00Co0000oe>1hOmCPN7o00001?loE/800ol0003oF5:aoeQB/@03oeQB/@07o`00
0?miI:ooNFB_ogUT[ol0003oM5bYo`000007ohe/Z003o`000?nON:OoWgRW00CoWgRW00?o0000ojj3
Y_n^PjH01On^PjH00ol0003o_8nVokb?YP05okb?YP03o`000?o:VjOobY^W00?obY^W00?o0000omRY
Z?oHZJP01OoHZJP00ol0003oi;f_onBm[`03onBm[`07o`000?obdk7ol]>aoo;C/Ol0003oj]Boo`00
0003oo7[`P?o000000?of?7Ro`000?n_aN/00_n_aN/5ohBFg@05o`000?m8KmKoB6oFodQ_e_l00000
0ol[ELT01OlOB/?o0000o`0[]?l0003o032h00;o04W900?o0000o`1[fol000000omUYoH00ol0003o
Z<;/ojS2k003ojS2k003o`000?o8amWob<OI00?ob<OI0_l00005omkHd@03o`000?oWf/Soim[800?o
im[800?o0000on[Ka?oZfl@01?oZfl@00ol0003oooooooooo`0Eooooo`?o00001Oooool00ol0003o
ooooooooo`0:ooooo`007?ooool2o`0003Gooooo00Ko0000ocIFa_lfE/Ko0000of9X`ol00005ofM^
aP03o`000?mcO]3oLgk@00CoLgk@00?o0000ohRIgOn8VMd00on8VMd00ol0003oYKo/o`000002o`00
00;oY[o/1?ndjoL00ol0003ocogQo`000004o`0000;okOS200Co0000on_gbOo[mlWojoO90_l00002
on?Od003o`000?o>eMkoc]GN00?oc]GN00Go0000oj6ij_nQ^N[oXKWZo`000002oe>1h@03o`000?lo
E/;o?eK200;o?eK200?o8CJ_o`000?mHD[400omHD[401?l0003oNFB_ogUT[ol00002ogALZ@03o`00
0?n=K:SoSFbX00GoSFbX00?o0000oimhYonON:L01OnON:L00ol0003o[X>Vojj3YP04ojj3YP03o`00
0?nlSjKo_8nV00Co_8nV00?o0000olZKYoo:VjL01?o:VjL00ol0003of:VXomRYZ005omRYZ0;o0000
1?oT_Jl00ol0003ol]>aoo;C/@02oo;C/@03o`000?oajl;olN_200;olN_200Co0000omSah_oHlN;o
00000on_aN/00ol0003oQ9KMohBFg@03ohBFg@05ofMfc_l0003oB6oFodQ_e_l000000ol[ELT01_l0
003o7d[3o`000?l0003o032ho`0000;o04W900?o0000o`1[fol000000omUYoH00ol0003oZ<;/ojS2
k003ojS2k007o`000?o8amWob<OIolS7fOl0003oc=;No`000006omkHd@03o`000?oWf/Soim[800?o
im[800?o0000on[Ka?oZfl@00ooZfl@00ol0003oooooooooo`0Booooo`?o00002?ooool00ol0003o
ooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`05o`000?lfE/Ko=UK6ocIFa_l0
00001_mWK/H00ol0003oLgk@og=nd003og=nd003o`000?n8VMgoR9WM00?oR9WM00?o0000ojFok?nU
_n`00onU_n`5o`000003olomhOl0003o000000;o000000?oaOVao`000?o]n<800_o]n<801Ol0003o
joO9on_gbOo[mlWo000000Cohmo@00?o0000olkEg_o>eMh00_o>eMh01Ol0003oXKWZoj6ij_nQ^N[o
000000?oDh7Q00Co0000ocmF`_loE/;o?eK20_l00005oeQB/@03ogUT[ol0003oM5bY00?oM5bY00?o
0000ohe/Z?n=K:P01?n=K:P00ol0003oWgRWoimhY`05oimhY`03o`000?n^PjKo[X>V00Co[X>V00?o
0000okb?Y_nlSjH01?nlSjH00ol0003obY^WolZKY`04olZKY`03o`000?oHZJSof:VX00Gof:VX00?o
0000onJkZOl000000_oT_Jl00ol0003ol]>aoo;C/@03oo;C/@03o`000?oajl;olN_200;olN_200Co
0000omSah_oHlN;o00000on_aN/00ol0003oQ9KMohBFg@02ohBFg@06o`000?mWM/koIgK>o`000?m8
KmKo00000ol[ELT01_l0003o7d[3oam:`ol0:kCo0000o`0`^0?o04W90ol00003ofFWmP03o`000?nX
`^coZ<;/00?oZ<;/00?o0000olS7fOl000000oo<d]h00ol0003og]SAomkHd@03omkHd@03o`000?oW
f/Soim[800?oim[800?o0000on[Ka?oZfl@00_oZfl@2o`00013ooooo1?l0000;ooooo`03o`000?oo
oooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Gooooo00Go0000ocIFa_lfE/Ko=UK6o`00
0005ofM^aP03o`000?mcO]3oLgk@00CoLgk@00?o0000ohRIgOn8VMd00on8VMd00ol0003oYKo/ojFo
k003ojFok003o`000?o2i_3o`^K`00Co00000_o<o/D3o`0000;okOS200Co0000on_gbOo[mlWojoO9
0_l00004on?Od003o`000?o>eMkoc]GN00;oc]GN00?o0000oj6ij_nQ^NX00_nQ^NX01ol0003oDh7Q
oe>1hOl0>kko0000ocmF`_l000000_lQ=Zl00ol0003oF5:aoeQB/@02oeQB/@03o`000?mdG:WoM5bY
00?oM5bY00?o0000ohe/Z?n=K:P01?n=K:P00ol0003oWgRWoimhY`05oimhY`03o`000?n^PjKo[X>V
00Co[X>V00?o0000okb?Y_nlSjH01?nlSjH00ol0003obY^WolZKY`04olZKY`03o`000?oHZJSof:VX
00Cof:VX00Oo0000onJkZOoV^jWoi[^Yo`000?oT_Joo000000Col]>a0_l00003oo7[`P05o`000?oH
lN;of?7RomSah_l000000on_aN/00ol0003oQ9KMohBFg@02ohBFg@06o`000?mWM/koIgK>ofMfc_m8
KmKo00000ol[ELT01ol0003o7d[3oam:`olOB/?o0000o`0`^?l000000_l0BLT2obech0;o00000omU
YoH01?l0003oZ<;/ojS2k?nX`^`3o`0000Coc=;N00?o0000omkHdOoNf=401?oNf=400ol0003oim[8
onOJb003onOJb006o`000?oZflCoj]_4o`000?o^l/Ko00003Oooool3o`00013ooooo00?o0000oooo
ooooool02Oooool001_ooooo00?o0000ooooooooool0=Oooool01_l0003o=UK6ocIFa_lfE/Ko?eo;
o`0000CoIfk600?o0000og=nd?mcO]000omcO]000ol0003oR9WMohRIg@03ohRIg@03o`000?nU_nco
YKo/00?oYKo/1Ol00002olomh@06o`000?o<o/Go0000o`000?o/n<Co00000_o]n<801_l0003ojoO9
on_gbOl0003ok>;6o`0000Cohmo@00Co0000olkEg_o>eMkoc]GN2?l000000omCPN7o0000o`0k_P02
o`0000;o8CJ_00?o0000oeQB/OmHD[400_mHD[400ol0003oM5bYogALZ@03ogALZ@03o`000?n=K:So
SFbX00CoSFbX00?o0000oimhYonON:L01OnON:L00ol0003o[X>Vojj3YP04ojj3YP03o`000?nlSjKo
_8nV00Co_8nV00?o0000olZKYoo:VjL01?o:VjL00ol0003of:VXomRYZ004omRYZ003o`000?oV^jWo
i[^Y00;oi[^Y00?o0000oo;C/Oobdk400oobdk401?l0003onN^]o`000?oajl82o`0000;of?7R00?o
0000ojo5jon_aN/00_n_aN/00ol0003oQ9KMohBFg@02ohBFg@03o`000?mWM/koIgK>00;oIgK>00Go
0000ob]EbOl[ELWo:eG9o`000004oam:``03o`000?l0<;So000000;o04W90ol]Ln07o`0000;oZ<;/
00?o0000olcBg_o<d]h00oo<d]h00ol0003og]SAomkHd@03omkHd@03o`000?oWf/Soim[800?oim[8
00?o0000on[Ka?l000000_o^l/H00ol0003oooooooooo`08ooooo`?o00004oooool00ol0003ooooo
ooooo`09ooooo`006oooool00ol0003oooooooooo`0eooooo`04o`000?lfE/Ko=UK6ocIFaP;o?eo;
00Co0000ofM^a_mWK/Ko00001_mcO]000ol0003oR9WMohRIg@03ohRIg@04o`000?nU_ncoYKo/ojFo
k0?o00000_o2i_001?l0003ocogQolomhOl00002olcna@03o`000?o/n<Co000000?okOS200?o0000
on_gbOl000000oo/h/H01Ol0003ohmo@on?Od?oSgm3o000000;oc]GN00?o0000olc:f?l000001?nP
^n`2oc9miP05o`000?mCPN7o03^no`0k__l000000olQ=Zl01_l0003oF5:aoeQB/Ol0003oCdNYo`00
00GoM5bY00?o0000ohe/Z?n=K:P01?n=K:P00ol0003oWgRWoimhY`04oimhY`04o`000?n^PjKo[X>V
ojj3YPSo00000_nlSjH00ol0003obY^WolZKY`03olZKY`03o`000?oHZJSof:VX00Gof:VX00?o0000
onJkZOoV^jT00_oV^jT00ol0003ol]>aoo;C/@02oo;C/@03o`000?oijjgonN^]00;o000000?ohobj
o`000?oHlN801?l000000on_aN_o0000ohBFg@03ohBFg@03o`000?mWM/koIgK>00?oIgK>00?oEfC5
o`000?l[ELT00_l[ELT01ol0003o7d[3oam:`olOB/?o8Tg5o`000?l0<;P00_l0BLT00ol0003o;G?P
obech004og2Qk`KoZ<;/00?o0000olcBg_o<d]h00_o<d]h2o`0000Cog]SA00?o0000onOJb?oWf/P0
1?oWf/P01Ol0003ok_;6onkba_o^l/Ko000000Oooooo0ol0000Fooooo`03o`000?oooooooooo00Wo
oooo000Kooooo`;o0000=Oooool00ol0003o=UK6ocIFaP02ocIFaP06o`000?loGl_o?eo;o`000?mW
K/Ko00001OmcO]000ol0003oR9WMohRIg@03ohRIg@03o`000?nU_nco000000;o000000?oYKo/o`00
0?o2i_000_o2i_000ol0003ocogQo`000002olcna@04o`000?o/n<Cok?S4o`0000?okOS20_l00004
oncRaP03o`000?oSgm3ohmo@00;ohmo@0_l00003olc:f003o`000?nP^ncoX;_/00;oX;_/0olbONH0
0ol0003o03^no`000003ob4f[`03o`000?mHD[7o000000;oCdNY00?o0000ogALZOmdG:T00omdG:T0
0ol0003oSFbXohe/Z004ohe/Z004o`000?nON:OoWgRWoimhY`Oo00000on^PZD00ol0003o_8fUokb=
Y@02okb=Y@Ko00000_o:VjL00ol0003of:VXomRYZ004omRYZ003o`000?oV^jWoi[^Y00?oi[^Y0_l0
0002oo;C/@06o`000?oijjgonN^]ooW[[Ol0003ohobj0ol000001?o6o>Ko0000ojg6k?n]a^`3o`00
00?oQ9KM00?o0000ofMfc_mWM/h00_mWM/h01?l0003oEfC5oeMTaOl00002ob]Eb@04o`000?lOB/?o
7d[3oam:``;o8Tg50_l00002o`19b@03o`000?l]Ln3o;G?P00CoL:7_1OnX`^`00ol0003oc=;NolcB
gP03olcBgP;o00001?oNf=400ol0003oim[8onOJb003onOJb005o`000?o^l/Kok_;6onkba_l00000
1?ooool3o`0001Wooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?oo
ool00ol0003o=UK6ocIFaP02ocIFaP05o`000?loGl_o?eo;ocmObol000001_mcO]000ol0003oR9WM
ohRIg@02ohRIg@?o00000onU_n`01Ol0003o`^K`ol;Vl?o2i_3o000000;ocogQ0ol00003oncha005
o`000?o]n<;okOS2ongh`_l000001Oo/h/H00ol0003ohmo@on?Od002on?Od003o`000?o<b]Soc<[H
00?oc<[H00?o0000oj2kk?nP^n`00_nP^n`2oc9miP04o`000?l0>kko0000o`0000?o8CJ_00Go0000
odm7ZOm?AjWoCdNYo`000005ogALZ@03o`000?n=K:SoSFbX00?oSFbX1Ol00003oimfY@03o`000?n^
PZGo[X:U00Co[X:U00?o0000okb=YOnlSJD01?nlSJD01?l0003obYZUolZJYOo:VZD4o`0000Gof:VX
00?o0000onJkZOoV^jT00_oV^jT01_l0003om]:XooKBZ?l0003ol]>ao`0000?onN^]00?o0000on?l
^_l000000_o6o>H01Ol0003o[LK/ojg6k?n]a^co000000;oSYKG0_l000000on4U]go0000ofMfcP03
ofMfcP07o`000?mGI<GoEfC5oeMTaOl0003o:eG9o`000003oam:``07o`000?lRCLGo8Tg5o`0`^?l0
003o04W9o`000002obech005o`000?m`XNooL:7_og2Qkol000001OnX`^`00ol0003oc=;NolcBgP02
olcBgP;o00001?oNf=400ol0003oim[8onOJb002onOJb0;o00000oo^l/H5o`0001cooooo00?o0000
ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?ooool00ol0003o=UK6ocIFaP02ocIF
aP06o`000?loGl_o?eo;ocmObomGM]Oo00001?mcO]000ol0003oR9WMohRIg@04o`0000CoYKo/00Go
0000ol;Vl?o2i_3o`^K`o`000002olomh@;o000000?oj?K>o`000?o/n<@00_o/n<@00ol0003okOS2
ongh`P02o`0000Gok>;600Co0000on?Od?oSgm3ohmo@0_l00006olc:f005o`000?nP^ncoX;_/oj2k
k?l000000_lbONH00ol0003o03^no`000003ob4f[`03o`000?m?AjWoCdNY00;oCdNY00?o0000ogAL
ZOmdG:T00_mdG:T01?l0003oSFbXohe/Z?n=K:P2o`000003ohaYY_l0003oWgJU00GoWgJU00?o0000
ojj2YOn^PZD01?n^PZD00ol0003o_8fUokb=Y@04okb=Y@03o`000?o:VZGobYZU00?obYZU00Co0000
omRXY_l0003o00000ooHZJP00ol0003oi[^YonJkZ@02onJkZ@05o`000?ofdZSom]:XooKBZ?l00000
0ooijjd01_l0003ohobjo`000?l0003oa_cVo`0000?o[LK/00?o0000ohjFeon>U]L00on>U]L00ol0
003oIgK>ofMfcP03ofMfcP03o`000?mGI<GoEfC500;oEfC500?o:eG9o`000?lOB/<00_lOB/<01Ol0
003o8Tg5ob9=aOlRCLGo000000;o04W900Co0000obech?l]Ln3o00000om`XNl00ol0003oZ<;/ojS2
k002ojS2k003o`000?o<d]koc=;N00?oc=;N0_l00004omkHd@06o`000?oWf/Soim[8o`000?o[lLco
00000oo^l/H00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`00
0?oooooooooo03Gooooo00?o0000ocIFa_lfE/H00_lfE/H01?l0003o?eo;ocmOboloGl/2oeMfe`03
o`000?mcO]3oLgk@00Co00000_n8VMd00ol0003oYKo/ojFok003ojFok005o`000?o2i_3o`^K`ol;V
l?l000000_o?oN401?l0003oj?K>onSfc_l00003oncha003o`000?o]n<;o000000;okn;200?o0000
oncRa_o/h/H00_o/h/H01?l0003ohmo@on?Od?l00002omg=b003o`000?o<b]Soc<[H00?oc<[H00?o
0000oj2kk?nP^n`00_nP^n`01_l0003o<WgVo`000?l0>kko00FHo`0000;o8CJ_00?o42BRo`000?m?
AjT00_m?AjT00ol0003oM5bYogALZ@03ogALZ@?o00000on<JJH00ol0003oWgJUoimfY@04oimfY@03
o`000?n^PZGo[X:U00Co[X:U00?o0000okb=YOnlSJD01?nlSJD00ol0003obYZUolZJY@03olZJY@04
o`000?oHZ:Kof:RVomRXYP?o00001OoV^jT01Ol0003om]:XooKBZ?ofdZSo000000;onN^]1?l00000
0oo6o>Ko0000ojg6k002ojg6k003o`000?n>U]OoSYKG00CoSYKG00?o0000ofMfc_mWM/h00_mWM/h0
0ol0003oEfC5oeMTa@04oeMTa@05o`000?lOB/?o7d[3oam:`ol000001?lRCLD00ol0003o04W9o`00
0002obech005o`000?m`XNooL:7_og2Qkol000001OnX`^`00ol0003oc=;NolcBgP02olcBgP03o`00
0?oNf=7o000000?og]SA00?o0000onOJb?l000000_o[lL`01Ol0003ok_;6onkba_o^l/Ko0000023o
oooo00?o0000ooooooooool02Oooool001[ooooo0ol0000eooooo`03o`000?lfE/Ko=UK600;o=UK6
00Co0000ocmOboloGl_o?eo;0omGM]L3o`0000GoR9WM00?o0000ojFok?nU_n`00_nU_n`01Ol0003o
`^K`ol;Vl?o2i_3o000000;ocogQ00Go0000onSfc_oXm/koj?K>o`000002oncha003o`000?o]n<;o
000000?okn;200?o0000oncRa_o/h/H00oo/h/H2o`0000CogLg800?o0000olc:f?o<b]P00oo<b]P0
0ol0003oX;_/oj2kk003o`000008oc9mi_l0003o0000o`05V?lQ=Zoo0000oa0TX_l00004odm7Z@04
o`000?mdG:WoM5bYogALZ@;o00001On<JJH00ol0003oWgJUoimfY@04oimfY@03o`000?n^PZGo[X:U
00Co[X:U00?o0000okb=YOnlSJD00onlSJD00ol0003obYZUolZJY@04olZJY@03o`000?oHZ:Kof:RV
00?of:RV00?o0000onJkZOoV^jT00_oV^jT01?l0003om]:XooKBZ?ofdZP2o`000003ooW[[Ol0003o
f>j=00;o000000?oa_cVo`000?n]a^`00_n]a^`00ol0003oSYKGohjFe`04ohjFe`03o`000?mmO<Oo
000000?oIgK>00?o0000oeMTaOmGI<D01?mGI<D01Ol0003o7d[3oam:`olOB/?o000000Co8Tg500?o
<Uc=o`000?l000000ol]Ln001Ol0003oL:7_og2Qkom`XNoo000000CoZ<;/00?o0000olcBg_o<d]h0
0oo<d]h00ol0003og]SAo`000003omkHd@05o`000?o[lLcojo7<on_ac?l000000oo^l/H00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo
00Go0000ocIFa_lfE/Ko=UK6o`000004ocmOb`?o000000?oEgKGo`000?l000001?n8VMd00ol0003o
YKo/ojFok002ojFok003o`000?o2i_3o`^K`00;o`^K`0ol00004onSfcP03o`000?o/n<Cok?S400;o
00001?o_h/800ol0003ok>;6oncRaP03oncRaP03o`000?oMcLSogLg800CogLg800?o0000olc:f?o<
b]P00oo<b]P2o`0000CoWkg]0_l000001Ol01ISo0000o`000?l@9:;o000000CoCdNY00Ko0000ogAL
ZOmdG:Wo0000og9IY_l00006ohaYYP03o`000?nOMZGoWgJU00?oWgJU00?o0000ojj2YOn^PZD01?n^
PZD00ol0003o_8fUokb=Y@03okb=Y@03o`000?o:VZGobYZU00?obYZU00?o0000omRXY_oHZ:H01?oH
Z:H2o`0000?oi[^Y00Co0000ooKBZ?ofdZSom]:X0_l000000ooijjgo0000o`000005o`000003ojg6
k?l0003oSYKG00GoSYKG00Go0000ogelaommO<OoOGc7o`000002ofMfcP03o`000?mGI<GoEfC500?o
EfC500?o0000oe1M`Ol000000_lOB/<00ol0003o8Tg5ob9=a@02ob9=a@;o<Uc=00Go04W9o`000?l]
Ln3o;G?Po`000004og2Qk`05o`000?nX`^coZ<;/ojS2k?l000001Oo<d]h00ol0003og]SAo`000002
omkHd@;o00000oo[lL`01Ol0003ok_;6onkba_o^l/Ko0000027ooooo00?o0000ooooooooool02?oo
ool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0eooooo`06o`000?lfE/Ko=UK6ocIFa_l0003o?eo;1?l00003oeMf
e`;oNiWT0ol000000on8VMgo0000ojFok003ojFok004o`000?o2i_3o`^K`ol;Vl0;o000000?og_3L
o`000?oXm/h00ooXm/h01?l0003ok?S4oncha?l00006onoR`P03o`000?o/h/Kok>;600;ok>;600?o
0000omg=b?oMcLP01OoMcLP01Ol0003oc<[Holc:f?o<b]So000000;ob<3B1OnO_Nd2o`000005o`05
V?l0003o42BRoa0TX_l000000om?AjT00ol0003oM5bYo`000002og9IYP03o`000?n<JJKoS6VV00Co
S6VV00?o0000oimfYOnOMZD00onOMZD00ol0003o[X:Uojj2Y@04ojj2Y@03o`000?nlSJGo_8fU00?o
_8fU00?o0000olZJYOo:VZD00oo:VZD00ol0003of:RVomRXYP04omRXYP;oikZV00Co0000onJkZOoV
^jWo00000_ofdZP01Ol0003onnVNo`000?l0003of>j=00;o00000on[anh2o`0000KoSYKG00?o0000
ogelaommO<L00ommO<L2o`0000KoEfC500Ko0000oe1M`Om@GL7o0000oam:`ol00004ob9=a@04o`00
0?lbG<go<Uc=o`0000?o;G?P00Go0000og2Qkom`XNooL:7_o`000004ojS2k003o`000?o<d]koc=;N
00?oc=;N00Ko0000omkHdOl0003o0000on;/f?l00003on_ac005o`000?o^l/Kok_;6onkba_l00000
8Oooool00ol0003oooooooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?lfE/Ko=UK600?o0000
0oloGl/01?l0003oEgKGoeMfeomGM]L5og^Ii0?o00000_nU_n`00ol0003o`^K`o`000002o`0000?o
g_3L00Go0000onSfc_oXm/koj?K>o`000003oncha003o`000?o_h/;okn;200Cokn;200Oo0000oncR
a_o/h/Kok>;6o`000?oTcL3o000000OogLg800?o0000olc:f?l000001?o8`=800ol0003oWkg]oinm
k@03oinmk@05o`05V?l0003o42BRoa0TX_l000001?m?AjT00ol0003oLUVVog9IYP02og9IYP03o`00
0?n<JJKoS6VV00?oS6VV00?o0000oimfYOnOMZD01?nOMZD00ol0003o[X:Uojj2Y@03ojj2Y@03o`00
0?nlSJGo_8fU00?o_8fU00?o0000olZJYOo:VZD00oo:VZD00ol0003of:RVomRXYP03omRXYP04o`00
0?oW^ZKoikZVonNjYP;o00000oofdZP01?l0003onnVNo`000?oHkXd2o`0000?oZlO^00Co0000oiRH
dOnHV=7o00001On>U]L00ol0003oOGc7ogela`04ogela`03o`000?mGI<GoEfC500?oEfC500?o0000
oe1M`Om@GL400_m@GL42o`0000Co8Tg500Co0000oc9LcOlbG<go<Uc=0_l000000ol]Ln3o0000og2Q
k`03og2Qk`05o`000?nX`^coZ<;/ojS2k?l000001Oo<d]h01_l0003og]SAo`000?l0003oh^cHo`00
00?ojo7<00Go0000onkba_o^l/Kok_;6o`00000Qooooo`03o`000?oooooooooo00Sooooo0003oooo
o`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eoooo
o`?o000000?o=UK6o`000?loGl/00oloGl/01?l0003oEgKGoeMfeomGM]L5og^Ii003o`000?nU_nco
YKo/00Co00000_o8g^T01Ol0003og_3Lomk`g?oNl=co000000?oj?K>00?o0000oncha?o/n<@00_l0
0006onoR`P04o`000?o/h/Kok>;6o`0000?oi<g000?o0000omg=b?oMcLP01OoMcLP00ol0003ob<3B
olS0dP04olS0dP;o00001?nO_Nd2o`0000;o42BR00Go0000odm7ZOm?AjWoCdNYo`000004og9IYP03
o`000?n<JJKoS6VV00?oS6VV00?o0000oimfYOnOMZD01?nOMZD00ol0003o[X:Uojj2Y@03ojj2Y@03
o`000?nlSJGo_8fU00?o_8fU00?o0000olZJYOo:VZD00oo:VZD00ol0003of:RVomRXYP03omRXYP03
o`000?oW^ZKoikZV00;oikZV00Wo0000ooKBZ?ofdZSom]:Xo`000?okjIko0000omS^SOl000000on[
anh00ol0003oV9SAoiRHd@02oiRHd@05o`000?n>U]OoSYKGohjFeol000001_mmO<L2o`0000GoEfC5
00?o0000oe1M`Om@GL400om@GL400ol0003o8Tg5ob9=a@02ob9=a@04o`000?lbG<go<Uc=oc9Lc@;o
DGSJ00?o0000obech?l000000om`XNl00ol0003oZ<;/ojS2k002ojS2k003o`000?o<d]koc=;N00;o
c=;N0_l000001?oRk=So0000on;/f?l00003on_ac005o`000?o^l/Kok_;6onkba_l000008Oooool0
0ol0003oooooooooo`08ooooo`000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0000cooooo`Go00000_lfE/H01Ol0003o?eo;ocmOboloGl_o000000CoEgKG00?o0000
og^Ii?mkVN@00_mkVN@01Ol0003oYKo/ojFok?nU_nco000000Cob=kY00Go0000omk`g?oNl=cog_3L
o`000003onSfcP03o`000?o/n<Co000000;ok^;300?o0000onoR`_o_h/801?o_h/82o`0000Goi<g0
00?o0000omg=b?oMcLP01?oMcLP00ol0003oeKg3o`000006olS0dP06o`000?nO_NgoWkg]oinmkOl0
1ISo00000_l@9:801_l0003oCdNYodm7ZOl0003oC4>Vo`0000?oLUVV00?o0000ohaYY_n<JJH00on<
JJH00ol0003oWgJUoimfY@04oimfY@03o`000?n^PZGo[X:U00?o[X:U00?o0000okb=YOnlSJD00onl
SJD00ol0003obYZUolZJY@03olZJY@03o`000?oHZ:Kof:RV00;of:RV00?o0000onNjY_oW^ZH00ooW
^ZH01Ol0003om]:XooKBZ?l0003onnVN00?o00000_n[anh2o`0000KoV9SA00?o0000ohjFeol00000
1_mmO<L01?l0003oLfnoog=__ol00004oeMTa@03o`000?m@GL7oD5g100?oD5g100?o0000ob9=aOlR
CLD00_lRCLD01Ol0003o<Uc=oc9LcOlbG<go000000?oDGSJ00?o0000og2Qkom`XNl00_m`XNl01_l0
003oZ<;/ojS2k?nX`^co0000olcBgP?o000000Coc=kVo`000?oRk=Soh^cH0_l00003on_ac005o`00
0?o^l/Kok_;6onkba_l000008Oooool00ol0003oooooooooo`08ooooo`000oooool00ol0003ooooo
ooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0aooooo`;o
00001?ooool01?l0>;go0000ocIFa_l00003ocmOb`03o`000?mGM]OoEgKG00;oEgKG00?o0000og^I
i?mkVN@00_mkVN@01Ol0003oYKo/ojFok?nU_nco000000Cob=kY00Go0000omk`g?oNl=cog_3Lo`00
0003onSfcP03o`000?o/n<Co000000;ok^;300?o0000onoR`_o_h/801?o_h/800ol0003oi<g0onC=
`004onC=`003o`000?oMcLSogLg800?ogLg800Go0000omFm`ooE_L?oeKg3o`000006olS0dP0:o`00
0?nO_Ngo0000o`05V?l007ko0000oa0TX_l0003oCdNYo`0000;oC4>V00?o0000og9IY_mbFJH00_mb
FJH00ol0003oS6VVohaYYP02ohaYYP03o`000?nOMZGoWgJU00CoWgJU00?o0000ojj2YOn^PZD00on^
PZD00ol0003o_8fUokb=Y@02okb=Y@03o`000?o:VZGobYZU00CobYZU00?o0000omRXY_oHZ:H00_oH
Z:H00ol0003oikZVonNjYP02onNjYP06o`000?ogdJGo0000ooKBZ?l0003onnVN0_l00002oj_7kP03
o`000?nHV=7oV9SA00KoV9SA0_l00006ogela`03o`000?mcKkooLfno00;oLfno00Co0000oeMTaOmG
I<Go00001_m@GL400omBGl;o0000ob9=a@02ob9=a@05o`000?lbG<go<Uc=oc9LcOl000001?mAN=X5
o`0000;oZ<;/0ol00004olcNiP05o`000?oRk=Soh^cHon;/f?l000000oo[lL`01Ol0003ok_;6onkb
a_o^l/Ko0000027ooooo00?o0000ooooooooool02?ooool000?ooooo00?o410@ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo0ol00006ooooo`04o`000?l0
>;go0000o`0000?o?eo;00?o0000oeMfeomGM]L00_mGM]L01Ol0003oNiWTog^Ii?mkVNCo000000Co
YKo/00Go0000olSNjOo8g^Wob=kYo`000003omk`g003o`000?oXm/koj?K>00;oj?K>0_l00003onkR
``03o`000?o_h/;okn;200Cokn;200?o0000onC=`?oTcL001OoTcL001Ol0003ogLg8omg=b?oMcLSo
000000GoeKg30_l00005olS0dP;o000000KoX;o_o`000?l007ko0000oa0TX_l00003oda3YP03o`00
0?mbFJKoLUVV00;oLUVV00?o0000ohaYY_n<JJH00on<JJH00ol0003oWgJUoimfY@03oimfY@03o`00
0?n^PZGo[X:U00Oo000000?o_8fUo`000?o:VZD01?o:VZD00ol0003of:RVomRXYP03omRXYP03o`00
0?oW^ZKoikZV00;oikZV00Go0000ooOAYOogdJGo0000oo_YWP03o`000003oj_7k_l0003oV9SA00Ko
V9SA0_l000000on=P/;o0000ogela`04ogela`03o`000?mcKkooLfno00CoLfno00?o0000oeMTaOl0
00001Om@GL401?l0003oDUo2oe9O`_l00002ob9=a@05o`000?lbG<go<Uc=oc9LcOl000001?mAN=X4
og^Mi`?o00000_nX`^`00ol0003oc=kVolcNiP02olcNiP04o`000?oRk=Soh^cHon;/f0;o00000_o[
lL`01Ol0003ok_;6onkba_o^l/Ko000002;ooooo00?o0000ooooooooool01oooool00004oiRHV?oo
ooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`?o0000
2Oooool01?l0003o03Rmo`0h_Ol00003ocmOb`03o`000?mGM]OoEgKG00;oEgKG00Go0000og^Ii?mk
VNCoNiWTo`000003ojFok003o`000?o8g^Wob=kY00;ob=kY00Go0000omk`g?oNl=cog_3Lo`000003
onSfcP;o00001Oo^h/<00ol0003okn;2onoR`P02onoR`P03o`000?oVc;co000000Ooi<g000?o0000
omg=b?l000002?oE_L<01Ol0003ob<3BolS0d_o8`=;o000000;o`kO?0_l000001?l007ko0000oa0T
X_l00004oda3YP05o`000?mbFJKoLUVVog9IY_l000001On<JJH00ol0003oWgJUoimfY@06o`0000?o
[X:U00Co0000okb>YOnlSZGo_8jU1Ol00002olZJY@03o`000?oHZ:Kof:RV00;of:RV00?o0000onNj
Y_oW^ZH00ooW^ZH01Ol0003omm6UooOAYOl0003onnVN00Co00001_nHV=42o`0000CoSH;200Go0000
ogelaommO<OoOGc7o`000008og=__`03o`000?m@GL7oD5g100CoD5g100Oo0000oe9O`_mBGl;oDUo2
o`000?lRCLGo000000?o<Uc=00?o0000oe5hf_mAN=X00_mAN=X00ol0003oNigWog^Mi`02og^Mi`05
o`000?nX`^coZ<;/ojS2k?l000001?o<g^H01?l0003oh^cHon;/f?oRk=P2o`0000;ojo7<00?o0000
onkba_o^l/H00_l0000Rooooo`03o`000?oooooooooo00Oooooo00001?lb<S;o0000oc8b<_o^k^h<
ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`?o00003Oooool2o`0h_@05o`57aol0003o
?eo;ocmObol000000omGM]L00ol0003oNiWTog^Ii002og^Ii005o`000?nU_ncoYKo/ojFok?l00000
1?o8g^T01Ol0003og_3Lomk`g?oNl=co000000;oj?K>00?o0000on[QbOl000001Oo^h/<01Ol0003o
kn;2onoR`_o_h/;o000000?oi/bl00?o0000onC=`?oTcL001OoTcL02o`0000WoeKg300?o0000olS0
d_l000001Oo3]ll01Ol0003o001noa0TX_l879go000000?oC4>V00Go0000og9IY_mbFJKoLUVVo`00
0004ohaYYPCo00000onOMZD00ol0003o[X:Uojj2Y@03ojj2Y@03o`000?nlSZGo_8jU00;o_8jU00Co
0000olZJYOo:VZGobYZU1?l00003omRXYP03o`000?oW^ZKoikZV00;oikZV00Co0000ooOAYOogdJGo
mm6U0_l000001Oo<gg3o0000oj6Jc_nQV/ko000000CoV9SA00?o0000ohf2`_n=P/801On=P/800ol0
003oOGc7o`000009og=__`03o`000?m@GL7oD5g100CoD5g100?o0000oe9O`_mBGl800_mBGl82o`00
00?o<Uc=00?o0000oe5hf_mAN=X00_mAN=X00ol0003oNigWog^Mi`02og^Mi`05o`000?nX`^coZ<;/
ojS2k?l000001?o<g^H02_l0003oh^cHon;/f?oRk=So0000on_ac?l0003ojo7<o`000?o^l/H2o`00
02?ooooo00?o0000ooooooooool01oooool001Wooooo0_l0000Vooooo`?o00004?ooool01ol0003o
03Rmo`0h_Ol1AlOo0000ocmObol000000omGM]L00ol0003oNiWTog^Ii002og^Ii005o`000?nU_nco
YKo/ojFok?l000001?o8g^T01ol0003og_3Lomk`g?oNl=co0000onSfc_l000000_oZhLT00ol0003o
k^;3onkR``03onkR``04o`000?o_h/;okn;2o`0000Coi/bl00?o0000onC=`?oTcL001OoTcL000ol0
003of[^ko`000009omFm``;o00001Oo3]ll00ol0003o001no`000002o`0000?oC4>V00?o0000og9I
Y_mbFJH00_mbFJH4o`000003ohaYY_l0003oWgJU00CoWgJU00?o0000ojj2YOn^PZD00on^PZD00ol0
003o_8jUokb>Y@02okb>Y@03o`000?o:VZGobYZU00?obYZU00Ko0000omRXY_l0003o0000omRXY_l0
0004onNjYP03o`000?ogdJGomm6U00Co00001?nQV/h01?l0003oV9SAo`000?l00008ohf2`P;o0000
2OmcKkl00ol0003oL6Zko`000004oe1M`@03o`000?mBGl;oDUo200CoDUo200?o0000oc9LcOlbG<d0
0_lbG<d01Ol0003oDGSJoe5hf_mAN=[o000000CoNigW00Go0000ojS2k?nX`^coZ<;/o`000004olcN
iP05o`000?oRk=Soh^cHon;/f?l000000_o[lL`3o`000003omOl^?l0003ooooo02;ooooo00?o0000
ooooooooool01oooool001Sooooo00?o0000ooooooooool08oooool3o`0001?ooooo00?o0000o`0h
_Ol0>;d00_l1AlL2o`0000?oEgKG00?o0000og^Ii?mkVN@00_mkVN@01Ol0003oYKo/ojFok?nU_nco
000000Cob=kY00Co0000omk`g?oNl=cog_3L0_l00004on[Qb@03o`000?o^h/?ok^;300?ok^;30_l0
0006onK<_003o`000?oTcL3oi<g000?oi<g000Go0000omZk^ooJ^k_of[^ko`000008omFm``04o`00
0?o</Koo0000o`0000Co`kO?0_l007h00ol0003o21bMo`000003oda3YP05o`000?mbFJKoLUVVog9I
Y_l000001?n<JJH00ol0003oWgJUoimfY@03oimfY@03o`000?n^PZGo[X:U00?o[X:U00?o0000okb>
YOnlSZD00_nlSZD00ol0003obYZUolZJY@03olZJY@04o`000?oHZ:Kof:RVomRXYP;o00000ooW^ZH0
1?l0003omm6UooOAYOogdJD2o`000003olcOL?l0003oXI[>00?oXI[>0_l00009ohf2`P03o`000?n8
Mk[o000000SoLfno00Go0000og1Z^om`J[_oL6Zko`000003oe1M`@03o`000?mBGl;oDUo200CoDUo2
00?oFfW7o`000?lbG<d00_lbG<d01Ol0003oDGSJoe5hf_mAN=[o000000CoNigW00Go0000ojS2k?nX
`^coZ<;/o`000004olcNiP05o`000?oRk=Soh^cHon;/f?l000000oo[lL`00ol0003oeobho`00000T
ooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo023ooooo0ol0000Goooo
o`03o`000?l0>;go000000;o0DO70_l00002oeMfe`03o`000?mkVNCoNiWT00;oNiWT00Go0000ojFo
k?nU_ncoYKo/o`000004olSNj@03o`000?oNl=cog_3L00;o00001OoZhLT00ol0003ok^;3onkR``03
onkR``03o`000?oVc;coi/bl00Koi/bl00Go0000onC=`?oTcL3oi<g0o`000005omZk^`;o00001OoE
_L<00ol0003oc;6oolba_`02olba_`;o00000_o3]ll01Ol0003o001no`000?l879go000000?oC4>V
00?o0000og9IY_mbFJH00_l00004ohaYYP03o`000?nOMZGoWgJU00?oWgJU00?o0000ojj2YOn^PZD0
0on^PZD00ol0003o_8jUokb>Y@02okb>Y@03o`000?o:VZGobYZU00;obYZU00?o0000omRXY_oHZ:H0
0_oHZ:H00ol0003oikZWo`000002onNjYP05o`000?ogdJGomm6Uo`000?okiiP00_l00003oj6JcP;o
000000?oVhRno`000?n=P/801on=P/801Ol0003oR7NjohQg^_n8Mk[o000000KoLfno00?o0000og1Z
^om`J[/00om`J[/01?l0003oD5g1oe1M`Ol00005oe9O`P04o`000?mKJLOoFfW7o`0000;o<Uc=00Go
0000oe5hf_mAN=[oDGSJo`000004og^Mi`05o`000?nX`^coZ<;/ojS2k?l000001?o<g^H01Ol0003o
h^cHon;/f?oRk=So000000;ojo7<0_l000000ooGo;So0000ooooo`0Sooooo`03o`000?oooooooooo
00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Jooooo`03o`000?l0>;go03Rm00;o
0DO70_l]Jm/00ol0003oEgKGo`000004og^Ii005o`000?nU_ncoYKo/ojFok?l000001?o8g^T01Ol0
003og_3Lo`000?oOg]Co000000Goj^7900?o0000onkR`oo^h/<00oo^h/<00ol0003oi/blonK<_006
onK<_005o`000?oTcL3oi<g0onC=`?l000001ooJ^k/00ol0003oeKg3omFm``02omFm``03o`000?o<
/Kooc;6o00Coc;6o0_l000001_o3]loo001no`000?l0003o21bMo`0000;oC4>V00Go0000og9IY_l0
003oLeZWo`000005ohaYYP03o`000?nOMZGoWgJU00;oWgJU00?o0000ojj2YOn^PZD00on^PZD00ol0
003o_8jUokb>Y@02okb>Y@03o`000?o:VZGobYZU00;obYZU00?o0000omRXY_oHZ:H00_oHZ:H01_l0
003oikZWonNjYol0003oikZVo`0000;omm6U00Co0000oo_WV?l0003oXI[>0ol00004oi^8_P03o`00
0?n=P/;oSH;200?oSH;20_l00005ohQg^P03o`000?mcKkooLfno00;oLfno00?o0000og1Z^om`J[/0
1Om`J[/2o`0000KoDUo200Oo0000oe]YaomKJLOoFfW7o`000?lbG<go000000?oDGSJ00?o0000og^M
iomkWNL00_mkWNL01Ol0003oZ<;/ojS2k?nX`^co000000Coc=kV00Ko0000on;/f?oRk=Soh^cHo`00
0?o[lL`2o`000003omOl^?l0003ooooo02Cooooo00?o0000ooooooooool01oooool001Sooooo00?o
0000ooooooooool06_ooool3o`0001gooooo00Co0000o`0h_Ol0>;go00000_l1AlL2obe[f`;o0000
0omkVN@00ol0003oYKo/ojFok002ojFok007o`000?o8g^Wob=kYolSNjOl0003og_3Lo`000002omoN
e003o`000?oZhLWoj^7900Coj^7900Oo0000onkR`oo^h/?ok^;3o`000?oVc;go000000Soi/bl00?o
0000onC=`?l000002OoJ^k/01?l0003oeKg3omFm`ol00009olba_`06o`000?l007ko0000o`000?l8
79go00000om<@jH01Ol0003oLeZWog=JYomcFZOo000000CoS6VV00?o0000oimfYOnOMZD00_nOMZD0
0ol0003o[X:Uojj2Y@02ojj2Y@03o`000?nlSZGo_8jU00?o_8jU00?o0000olZJYOo:VZD00_o:VZD0
1Ol0003of:RVomRXY_oHZ:Ko000000CoikZW00Go0000ooOAYOogdJGo0000oo_WV003o`0000OoVhRn
00?o0000ohf2`_n=P/800_n=P/800ol0003oR7NjohQg^P05ohQg^P05o`000?mcKkooLfnoog=__ol0
00002Om`J[/00ol0003oDUo2oe9O`P04oe9O`P03o`000?mKJLOoFfW700;oFfW70_l00003oe5hfP03
o`000?mkWNOoNigW00;oNigW00Go0000ojS2k?nX`^coZ<;/o`000004olcNiP04o`000?oRk=Soh^cH
on;/f0;o000000?ofOk3o`000?oGo;P00_l0000Tooooo`03o`000?oooooooooo00Oooooo000Hoooo
o`;o00006?ooool3o`00027ooooo00?o0000o`0h_Ol000000_l1AlL3obe[f`;o00000_mkVN@01Ol0
003oYKo/ojFok?nU_nco000000Cob=kY0_l00004omoNe003o`000?oZhLWoj^7900?oj^7900Co0000
onkR`oo^h/?o00000ooVc;d00ol0003oi/blonK<_006onK<_0;o00002_oJ^k/00ol0003oeKg3o`00
000;olba_`05o`000?l007?o21bMo`PLWOl000000_m<@jH01Ol0003oLeZWog=JYomcFZOo000000Co
S6VV00?o0000oimfYOnOMZD00onOMZD01Ol0003o[X:Uojj2YOn^PZGo000000Co_8jU00?o0000olZJ
YOo:VZD00oo:VZD01Ol0003of:RVomRXY_oHZ:Ko000000CoikZW00Ko0000ooOAYOogdJGo0000oo_W
V?l0000:oi^8_P04o`000?n=P/;oSH;2o`0000WoR7Nj00?o0000og=__ol000002_m`J[/00ol0003o
DUo2oe9O`P03oe9O`P03o`000?mKJLOoFfW700CoFfW70_l00002oe5hfP03o`000?mkWNOoNigW00;o
NigW00Go0000ojS2k?nX`^coZ<;/o`000004olcNiP03o`000?oRk=Soh^cH00;o000000CofOk3o`00
0?oGo;So00000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo000Hoooo
o`03o`000?oooooooooo01Cooooo0ol0000Tooooo`06o`000?l0>;go03Rmo`000?l1AlOo00000_l]
Jm/2of^Jk0?o00000onU_n`00ol0003ob=kYolSNj@03o`0000GogmkD00?o0000on[QbOoZhLT00ooZ
hLT01?l0003ok^;3onkR`ol00004onK<_@03o`000?oVc;coi/bl00Goi/bl00?o0000om^j^?l00000
2_oJ^k/00ol0003oc;6oolba_`0:olba_`09o`000?l007?o0000o`PLWOl0003oC4>Vo`000?m<@jKo
000000;oLeZW00?o0000ohaYY_n<JJH00_n<JJH00ol0003oWgJUoimfY@03oimfY@05o`000?n^PZGo
[X:Uojj2YOl000001?nlSZD00ol0003obYZUolZJY@02olZJY@03o`000?oHZ:Kof:RV00;of:RV00?o
0000onNjYooW^ZL00_oW^ZL00oogdJGo0000ooOAY@03o`0000[oVhRn00?o0000ohf2`_l000002_n8
MkX2o`0000[oL6Zk00?o0000og5[_?l000001?mBGl800ol0003oFfW7oe]Ya`04oe]Ya`;oK7cB00?o
0000oe5hf_l000001?mkWNL01Ol0003oZ<;/ojS2k?nX`^co000000Coc=kV00Wo0000on;/f?l0003o
f?cKo`000?oIo/?o0000omOl^?l000000_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Kooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0000Wooooo`04o`000?l0>;go03Rm
o`0000;o0DO70ol]Jm/3of^Jk0Oo00000_o;eN800ol0003ogmkDomoNe003omoNe003o`000?oZhLWo
j^7900Coj^790_l00006onK<_@03o`000?oVc;coi/bl00?oi/bl00Co0000om^j^?oK^[SofkZh0_l0
0008omZk^`04o`000?o?[[Oo0000o`0000Soc;6o00Co0000ol>V_?l0003o00000_l879d01?l0003o
C4>Voda3Y_l00003og=JY`05o`000?n<JJKoS6VVohaYY_l000001OnOMZD01Ol0003o[X:Uojj2YOn^
PZGo000000Co_8jU00?o0000olZJYOo:VZD00_o:VZD00ol0003of:RVomRXYP02omRXYP05o`000?oW
^ZOoikZWonNjYol000000_ogdJD00ol0003onnNHo`00000;oi^8_P;o00002_n8MkX00ol0003oQW>g
o`000009og1Z^`05o`000?maJkcoLF^log5[_?l000000_mBGl800ol0003oFfW7oe]Ya`04oe]Ya`04
o`000?m/O=;oK7cBofaldP;o00001?mkWNL01Ol0003oZ<;/ojS2k?nX`^co000000Coc=kV0_l00000
1?oHo=_o0000omWn`ol00002omOl^005o`000?ooooooooooooooool000008oooool00ol0003ooooo
ooooo`06ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000:oooool00ol0003o03Rmo`00
0002o`57a`04o`000?l]Jm_o;F_Ko`0000;oJi[/1?nU`>d00ol0003obmGRol_EhP03ol_EhP03o`00
0?oOg]CogmkD00?ogmkD00?o0000on[QbOoZhLT00ooZhLT00ol0003oi/bmonK<_@05onK<_@03o`00
0?oVc;coi/bl00;oi/bl00?o0000om^j^?oK^[P01?oK^[P00ol0003of[^komZk^`04omZk^`03o`00
0?o?[[Oocjjg00;ocjjg0ol00005olba_`04o`000?o3Y[co0000o`00L`;o21bM00Co0000oda3Y_m<
@jKo00000omcFZL01Ol0003oS6VVohaYY_n<JJKo000000GoWgJU00Go0000ojj2YOn^PZGo[X:Uo`00
0004okb>Y@03o`000?o:VZGobYZU00;obYZU00Go0000omRXY_oHZ:Kof:RVo`000004onNjY`03o`00
0?ogdJGomm6U00?o00002?nKR;h3o`000003oiQo]ol0003oR7Nj00OoR7Nj0_l00003ohIc]`03o`00
0?m`J[_oL6Zk00GoL6Zk00?o0000og5[_?maJk`00_maJk`01?l0003oDUo2oe9O`_l00006oe]Ya`03
o`000?m/O=;oK7cB00;oK7cB0_l00003og^Mi`05o`000?nX`^coZ<;/ojS2k?l000000oo<g^H2o`00
00;of?cK00Go0000omWn`ol0003oeobho`000005ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool001Oooooo00?o0000ooooooooool03?ooool3o`0002kooooo00Ko0000o`0h
_Ol0>;go0000o`57aol00002obe[f`04o`000?m[V^coJi[/of^Jk0CoYL3]00?o0000ol_Eh_o;eN80
0_o;eN800ol0003ogmkDomoNe003omoNe003o`000?oZhLWoj^7900;oj^790_l00008onK<_@05o`00
0?oVc;coi/blonK<_?l000001ooK^[P00ol0003of[^komZk^`03omZk^`03o`000?o?[[Oocjjg00Go
cjjg0_l00003olba_`03o`000?o3Y[co`jJl00?o000000Go2AfMo`000?m<@jKoC4>Vo`000002og=J
Y`03o`000?n<JJKoS6VV00;oS6VV00?o0000oimfYOnOMZD00_nOMZD01Ol0003o[X:Uojj2YOn^PZGo
000000Co_8jU00?o0000olZJYOo:VZD00_o:VZD01Ol0003of:RVomRXY_oHZ:Ko000000?oikZW00Co
0000ooOAYOogdJGomm6U0ol00006oi^8_P;o00001OnHOkL00ol0003oR7NjohQg^P04ohQg^P03o`00
0?n6LkOoQW>g00?oQW>g00?o0000og1Z^om`J[/01?m`J[/00ol0003oLF^log5[_004og5[_003o`00
0?mBGl;o000000GoFfW700?o0000ofald_m/O=800om/O=82ohJKh0;o000000?oNigWo`000?nX`^`0
0_nX`^`4o`000006olSYkOl0003of?cKo`000?oIo/?o00000_oGo;P00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool001Oooooo0_l0000:ooooo`?o
0000<Oooool01?l02I3o0000o`0h_Ol00002o`57a`04o`000?l]Jm_o;F_Ko`0000;oJi[/00Go0000
ojG0kOnU`>goYL3]o`000004ol_EhP03o`000?oOg]CogmkD00?ogmkD00Go0000on[QbOoZhLWoj^79
o`000002on;=`P03o`000?oVc;goi/bm00Koi/bm00?o0000onK<_?l000002OoK^[P2o`0000;of[^k
00?o0000oln^]oo?[[L02?o?[[L3o`0000?o`jJl00Go0000o`00Lol0003o2AfMo`000002oda3YP04
o`000?mcFZOoLeZWo`0000CoS6VV00?o0000oimfYOnOMZD03_l000000oo:VZGo0000omRXYP03omRX
YP05o`000?oW^ZOoikZWonNjYol000000_ogdJD4o`0000CoVhRn0_l00007oiQo]`03o`000?n8Mk[o
R7Nj00?oR7Nj00?o0000ohIc]on6LkL01On6LkL00ol0003oL6Zkog1Z^`02og1Z^`03o`000?maJkco
LF^l00KoLF^l00?o0000oe]YaomKJLL01?mKJLL00ol0003oK7cBofaldP02ofaldP03o`000?n6Vn3o
QY_P00?oQY_P1Ol00003olSYk@08o`000?oHo=_of?cKo`000?oIo/?o0000omOl^?l00007ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool0
1_ooool3o`0003Gooooo00?o00V@o`000?l000000_l1AlL01?l0003o;F_Kobe[fol00002of^Jk005
o`000?nU`>goYL3]ojG0kOl000001Oo;eN800ol0003ogmkDomoNe002omoNe004o`000?oZhLWoj^79
o`0000Coh/g200?o0000onK<_OoVc;d01_oVc;d2o`0000_ofkZh00?o0000omZk^ol000003?o?[[L0
0ol0003o`jJlo`000002ol>V_004o`00Lol0003o2AfMo`0000;oC4>V00Co0000og=JYomcFZOoLeZW
0_n<JJH5o`0000;oWgVX00Go0000ojn4Yon_Q:Oo[hBWo`000004okb?Y`03o`000?o9VjSobI^X00?o
00000ooHZ:H02?l0003oikZWonNjYooW^ZOo0000ooOAYOl0003onnNI0_l000000onVS[co0000o`00
0002o`0000[oV7ng00?o0000ohQg^_n8MkX00_l00009ohIc]`04o`000?m`J[_oL6Zko`0000WoLF^l
00?o0000oe]YaomKJLL00omKJLL00ol0003oK7cBofaldP03ofaldP03o`000?n6Vn3oQY_P00?oQY_P
00Go0000ojS3kOnX`ngoZ<?]o`000003olSYk@03o`000?oHo=_o000000;ofOk300?o0000omOl^?l0
00002?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`00
0?oooooooooo00?ooooo0ol0000iooooo`05o`09T?l0>;go0000o`57aol000000_l]Jm/01Ol0003o
Ji[/of^Jk?m[V^co000000?oYL3]00?o0000ol_Eh_o;eN800_o;eN800ol0003ogmkDomoNe003omoN
e0;o00001OoRcL800ol0003oi/bmonK<_@06onK<_@03o`000?oK^kWo000000_ofkZh0_l0000<oln^
]`03o`000?o5X[GoaJ:e00Go000000Go2AfMo`000?m<@jKoC4>Vo`000002og=JY`;o00000_n=KJT0
0ol0003oWgVXoimiZ002oimiZ005o`000?n_Q:Oo[hBWojn4Yol000001?nlSjL01_l0003obI^XolVK
Z?o9VjSo0000omNZZ@?o00000ooW^ZL01Ol0003omm6UooOAYOl0003onnNI00Co00003OnHOkL00ol0
003oR7Njo`00000;ohIc]`03o`000?m`J[_o000000WoLF^l00?o0000ogIb`Ol000001?mKJLL00ol0
003oK7cBofaldP03ofaldP03o`000?n6Vn3oQY_P00;oQY_P00Go0000ojS3kOnX`ngoZ<?]o`000003
olSYk@08o`000?oHo=_of?cKo`000?oIo/?o0000omOl^?l0000:ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01Oooool001Kooooo00Co0000oooooooooooooooo0ol0000mooooo`05
o`09T?l0003o0000o`57aol000000_l]Jm/01?l0003oJi[/of^Jk?l00003ojG0k@03o`000?o;eN;o
bmGR00;obmGR00?o0000omoNe?oOg]@00ooOg]@00ol0003oh/g2on;=`P05on;=`P03o`000?oVc;go
i/bm00Coi/bm00Go0000om^k^OoK^kWofk^io`00000:om^j^003o`000?o@[;Co000000;o00002?o?
[[L00ol0003oaJ:eolFR]@04olFR]@;o000000Go2AfMo`000?m<@jKoC4>Vo`000002og=JY`05o`00
0?n=KJWoSFfYohe]ZOl000001?nONJP01Ol0003o[hBWojn4Yon_Q:Oo000000Co_8nW00Go0000olVK
Z?o9VjSobI^Xo`000003omNZZ@;o00000_oW^ZL00ol0003omm6Uo`000002oo_WV@04o`000?nUQkGo
YHNeo`0000goV7ng0_l0000<ohIc]`;o00002OmaJk`01Ol0003oMW;1ogIb`OmfL/7o000000?oFfW7
00?o0000ofald_m/O=800_m/O=800ol0003oQY_PohJKh003ohJKh005o`000?nX`ngoZ<?]ojS3kOl0
00000oo8jNd00ol0003of?cKo`000002omWn``;o00003?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Gooooo000Fooooo`Co0000@Oooool2o`0QY@;o00000_l]Jm/01Ol0003oJi[/
of^Jk?m[V^co000000?oYL3]00?o0000ol_Eh_o;eN800_o;eN801?l0003ogmkDomoNe?oOg]@2o`00
00Soh/g200?o0000onK<_OoVc;d00ooVc;d00ol0003ofk^iom^k^@02om^k^@;o00001ooK^[P00ol0
003od:bdom2/]003om2/]0;o00001_o?[[L00ol0003oaJ:eolFR]@04olFR]@;o00000_l97Id2oda3
YP05o`000?mcFZOo0000ogENZ_l000000_n=KJT00ol0003oWgVXoimiZ002oimiZ005o`000?n_Q:Oo
[hBWojn4Yol000001?nlSjL01Ol0003obI^XolVKZ?o9VjSo000000?oejZY00Wo0000onJlZ_l0003o
ikZWo`000?ogdJGo0000oo_WVOl000001?nUQkD00ol0003oV7ngoiQo]`07oiQo]`?o000000?oUgbd
o`000?n6LkL02_n6LkL00ol0003oQWBho`000008og5[_003o`000?mfL/7oMW;100;oMW;100Co0000
oe]YaomKJLOo00001Om/O=800ol0003oQY_PohJKh003ohJKh005o`000?nX`ngoZ<?]ojS3kOl00000
0oo8jNd01?l0003of?cKo`000?oIo/<2o`0000gooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`05ooooo`005_ooool3o`0004?ooooo0_l08JD01?l0003o;F_Kobe[fol00003of^Jk005
o`000?nU`>goYL3]ojG0kOl000001?o;eN801?l0003ogmkDomoNe?l00002om[=c003o`000?oRcL;o
h/g200Koh/g200Go0000onK<_OoVc;goi/bmo`000007om^k^@03o`000?oK^[SofkZh00CofkZh00?o
0000om2/]?o@[;@01Oo@[;@2o`0000Cocjjg00?o0000olFR]Oo5X[D01Oo5X[D2o`000005o`TMWOl0
003oC4>Voda3Y_l000000_meGZX01Ol0003oSFfYohe]ZOn=KJWo000000?oWgVX00Go0000ojn4Yon_
Q:Oo[hBWo`000004okb?Y`04o`000?o9VjSobI^Xo`0000CoejZY00Co0000onJlZ_oV_:[o00000_og
dJD3o`0000CoYHNe00?o0000oiQo]onHOkL01?nHOkL3o`0000GoUgbd00?o0000ohIc]on6LkL01_n6
LkL2o`0000?oQWBh00?o0000og5[_?maJk`01?maJk`00ol0003oMW;1ogIb`@04ogIb`@03o`000?mK
JLOo000000GoK7cB00?o0000ohJKh?n6Vn000_n6Vn001Ol0003oZ<?]ojS3kOnX`ngo000000?ob>W]
00?o0000omSlfol000000_oIo/<00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01Oooool000cooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oo
oooooooo04;ooooo0_l08JD2o`000005obe[fol0003oJi[/of^Jk?l000000onU`>d00ol0003obmGR
ol_EhP02ol_EhP03o`000?oOg]Co000000Cof/g<00?o0000on;=`_oRcL801OoRcL801?l0003oi/bm
onK<_Ol00009om^k^@;o00000ooK^[P00ol0003od:bdom2/]008om2/]0Co00002?o5X[D2o`000003
o`TMWOl0003oC4>V00;o00000_meGZX01Ol0003oSFfYohe]ZOn=KJWo000000CoWgVX00Co0000ojn4
Yon_Q:Oo00000onlSjL01Ol0003obI^XolVKZ?o9VjSo000000?oejZY00Wo0000onJlZ_oV_:[oi[bZ
o`000?ogdJGo0000oo_WVOl000001OnUQkD00ol0003oV7ngoiQo]`02oiQo]`;o00002?nGO;@00ol0
003oQW>gohIc]`04ohIc]`;o00001On6M;P00ol0003oLF^log5[_004og5[_003o`000?mfL/7oMW;1
00GoMW;10_l00004ofaldP03o`000?n6Vn3oQY_P00?oQY_P00Go0000ojS3kOnX`ngoZ<?]o`000003
olSYk@03o`000?oHo=_o000000;o00004Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Gooooo000>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@Oooool01?l0
003o026Uo`1Id_l0FM82o`0000?oJi[/00Go0000ojG0kOnU`>goYL3]o`000003ol_EhP;o00001_oJ
cL`00ol0003oh/g2on;=`P05on;=`P03o`000?oVc;go000000_ofk^i00Co0000om^j^?oK^[So0000
3Oo@[;@3o`0000OoaJ:e00Ko0000o`TMWOl97Igo0000oe19Zol00003ogENZP04o`000?n=KJWoSFfY
o`0000CoWgVX00Co0000ojn4Yon_Q:Oo00000onlSjL01Ol0003obI^XolVKZ?o9VjSo000000?oejZY
00Go0000onJlZ_oV_:[oi[bZooGBZP02o`000003oo_WVOl0003oYHNe00GoYHNe1?l0000;oiMl]003
o`000?n6LkOoQW>g00;oQW>g00?o0000ohId^?n6M;P01_n6M;P00ol0003oLF^log5[_002og5[_003
o`000?mfL/7oMW;100GoMW;100Co0000ogn1bomoPL_o00000om/O=800ol0003oQY_PohJKh002ohJK
h005o`000?nX`ngoZ<?]ojS3kOl000000oo8jNd00ol0003of?cKo`000002o`0001;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo047ooooo00Go0000o`0QYOl0FM;o05WBo`000003of^Jk005o`000?nU`>go
YL3]ojG0kOl000000_o;eN800ol0003obL_Ko`000007om[=c003o`000?oRcL;oh/g200Goh/g20_l0
000<om^k^@03o`000?oK^[So000000god:bd00?o0000olJP/_o6X;800ol00004olFR]@04oleS0?l9
7Igo2AfMo`0000;oD4V[00Co0000ogENZ_meGZ[o00000_n=KJT00ol0003oWgVXoimiZ002oimiZ004
o`000?n_Q:Oo[hBWo`0000?o_8nW00Go0000olVKZ?o9VjSobI^Xo`000003omNZZ@08o`000?oV_:[o
i[bZo`000?oedZ[o0000oo_WVOl00005ojF7]@?o00003_nGO;@00ol0003oQW>gohIc]`02o`0000[o
QWBh00Co0000og5[_?maJkco00001omfL/400ol0003oOh7;ogn1b`02ogn1b`04o`000?m/O=;oK7cB
o`0000CoQY_P00Go0000ojS3kOnX`ngoZ<?]o`000003olSYk@04o`000?oHo=_o0000o`0001Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooooooo
o`0:ooooo`;o0000@_ooool01?l02I3o026Uo`1Id_l0FM84o`0000?oYL3]00?o0000ol_Eh_l00000
0oo9bm/00ol0003of/g<om[=c004om[=c003o`000?oRcL;oh/g200Goh/g200?o0000omVl_Ol00000
3?oK^kT2o`0000god:bd00?o0000olJP/_o6X;800oo6X;84o`000007olFR]Ol0003o0000oa8WY?l0
003oD4V[o`000002ogENZP04o`000?n=KJWoSFfYo`0000CoWgVX00Co0000ojn4Yon_Q:Oo00000onl
SjL01Ol0003obI^XolVKZ?o9VjSo000000;oejZY00So0000onJlZ_oV_:[oi[bZo`000?oedZ[o0000
oo_WV@Ko00000_nTQK800ol0003oUgbdoiMl]00<oiMl]003o`000?n6LkOo000000coQWBh00?o0000
og5[_?l000001omfL/400ol0003oOh7;ogn1b`04ogn1b`;o00001?n6Vn000ol0003oZ<?]ojS3k@02
ojS3k@05o`000?o8jNgob>W]o`000?oHo=/00_l0000Fooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10
ooooo`04o`09T?l08JGo05WBo`0000;oFIcb1_l00005olW;f`03o`000?oJcLcof/g<00Cof/g<00?o
0000on;=`_oRcL800ooRcL801Ol0003ofKbmomVl_OoI_;go000000_ofk^i00Co0000om2]]Ol0003o
00002_o@[;@00ol0003oaZ2bolJP/P08olJP/P07o`000?o=H`3o0000oa8WY?l0003oD4V[o`000003
ogENZP04o`000?n=KJWoSFfYo`0000?oWgVX00Co0000ojn4Yon_Q:Oo00000onlSjL01?l0003obI^X
olVKZ?l00003omNZZ@04o`000?oV_:[oi[bZo`0000;omM:Z00?on^VQo`000?l000001onTQK800ol0
003oUgbdoiMl]00<oiMl]0;o00003On6M;P2o`0000OoMW;100?o0000ogn1bomoPL/01_moPL/2o`00
00?oQY_P00Go0000ojS3kOnX`ngoZ<?]o`000003olSYk@?o00006?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0@?ooool01?l0003o026Uo`1Id_l00002oeVLlP05o`000?nT`>goY<3]ojC0kOl000001_o9
bm/00ol0003of/g<om[=c004om[=c005o`000?oRcL;oh/g2on;=`_l000001OoI_;d2o`0000Sofk^i
00?o0000om2]]Oo@[KD00_o@[KD2o`0000Sod:bd00?o0000olJP/_o6X;802_o6X;801_l0003o4RNT
oa8WY?l0003oD4V[o`0000;oMEjZ00Go0000ohe]ZOn=KJWo0000oimiZ00=o`0000?oejZY00So0000
onJlZ_oV_:[o0000ooGBZ_l0003on^VQo`0000WoY8Fb00?o0000oiMl]?nGO;@02?nGO;@3o`000003
oiMm]Ol0003oQWBh00[oQWBh0_l000000on9N[co0000ogIb`@05ogIb`@03o`000?moPL_oOh7;00Ko
Oh7;00?o0000oi2Jf_n@V]X00_l000000on6Vn3o0000ojS3k@02ojS3k@04o`000?o8jNgob>W]olSY
k@;o00006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0@?ooool01?l0003o026Uo`1Id_l00002oeVL
lP05o`000?nT`>goY<3]ojC0kOl000001_o9bm/00ol0003of/g<om[=c004om[=c003o`000?oRcL;o
000000SofKbm00?o0000om^k^OoK^kT01OoK^kT00ol0003od:feom2]]@04om2]]@?o00001Oo@[;@0
0ol0003oaZ2bolJP/P0:olJP/P06oleS0?l0003o4RNTo`000?m@BJ_o00000_meGZX00ol0003oSFfY
o`000002o`0000;oXGj]00Co0000ojn9[On_RJgo00000onlTjd00ol0003obIn^olVO[P04o`0000;o
i[bZ00?o0000ooGBZ_l000000_ojjJ400ol0003oY8FbojB5/P07ojB5/P03o`000?nGO;CoUgbd00Ko
Ugbd0_l00005oiMm]@03o`000?n6M;SoQWBh00OoQWBh00?o0000ohUj_?n9N[`00_n9N[`00ol0003o
MW;1ogIb`@02ogIb`@03o`000?moPL_oOh7;00KoOh7;00?o0000oi2Jf_n@V]X00on@V]X3o`0000;o
Z<?]1Ol0000Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool000cooooo
00?oEEEEofIVI_l000004Oooool2o`00047ooooo00Co0000o`0QYOl0FM;o00000_mIW?801Ol0003o
Y<3]ojC0kOnT`>go000000KobL_K00?o0000om[=c?oJcL`01?oJcL`2o`0000WofKbm0_l00004om^k
^@03o`000?o@[KGod:fe00Sod:fe0_l00003om2/]003o`000?o6X;;oaZ2b00_oaZ2b00Go0000oa8W
Y?l0003oD4V[o`000002ogENZP;o000000?oT7>_o`000?nQOZd00_nQOZd01?l0003o[hV]ojn9[Ol0
0003okbC[@04o`000?o9WjkobIn^o`0000;oeZf_00So0000onJlZ_oV_:[o0000ooGBZ_l0003on^VQ
o`0000[oY8Fb00?o0000oiMl]?nGO;@01?nGO;@2o`0000OoUgfe00?o0000ohId^?n6M;P01On6M;P2
o`0000KoRGZl00Co0000ogIb`OmfL/7o00002?moPL/00ol0003oT9[Joi2JfP04oi2JfP03o`000?nW
`ngoYl?]00Co000000?o/O[=o`000?ooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Cooooo000Rooooo`03o`000?oooooooooo03oooooo0_l000001Ol0FM;o0000oeVLl_mI
W?;o000000?oY<3]00?o0000olW;foo9bm/00oo9bm/00ol0003of/g<om[=c004om[=c003o`000?oC
_/Ko000000[ofKbm00Co0000om^k^OoK^kWo00003Oo@[KD3o`0000koaZ2b00WocF<0o`000?lB9jCo
0000oe19ZomeGZ[o0000ogYW/Ol000000_n@Ljl01?l0003oXGj]oj5n[Ol00002ojn9[@05o`000?nl
Tjgo_9>]okbC[Ol000000_o9Wjh00ol0003oeZf_omJ][`02o`000003onJlZ_l0003omM:Z00?o0000
2_nTQK801?l0003oUgbdoiMl]?nGO;@3o`0000[oUgfe00?o0000ohId^?n6M;P00_n6M;P2o`0000So
RGZl00?o0000ogIb`Ol000002?moPL/00ol0003oT9[Joi2JfP04oi2JfP09o`000?nW`ngoYl?]ojO3
kOl0003o_?3co`000?nan/go000001oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`04ooooo`008oooool00ol0003oooooooooo`0oooooo`;o000000Co05WBo`000?mIW?;o00001?nT
`>d00ol0003obL_KolW;f`03olW;f`03o`000?oJcLcof/g<00;of/g<00Go0000om>na_oC_/Kodkk6
o`00000:omVl_@03o`000?oK^kWo000000ood:fe0ol0000<olJP/P;o000000Co4RNTo`000?m@BJ_o
00000omjIk400ol0003oT7>_o`000002oj5n[@04o`000?n_RJgo[hV]o`0000?o_9>]00?o0000olVO
[_l000000ooF[Jl2on>n/P05o`000?oedZ[o0000oo[YXOl000003?nTQK83o`0000goUgfe00Go0000
ohId^?n6M;SoQWBho`00000:ohUj_0;o00002?moPL/00ol0003oT9[Joi2JfP04oi2JfP09o`000?nW
`ngoYl?]ojO3kOl0003o_?3co`000?nan/go0000023ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`04ooooo`009?ooool2o`00043ooooo0ol00002oeVLlP03o`000?nT`>goY<3]00;o
Y<3]00?o0000olW;foo9bm/00oo9bm/01?l0003of/g<om[=c?l00005om>naP;o00002OoI_;d2o`00
00ood:fe00?o0000olJQ/oo6XK<01Ol00007olJP/P;o00000_lB9j@2o`0000?oNVNa00?o0000oi1c
[ol000000_nQOZd01?l0003o[hV]ojn9[Ol00003okbC[@03o`000?o9Wjko000000;oeZf_00So0000
on>n/_oS_[;o0000ooGBZ_l0003on^VQo`0000[oY8Fb0ol0000?oiMm]@04o`000?n6M;So0000o`00
00[oRGZl00?o0000ohn6aOl000001omoPL/00ol0003oT9[Joi2JfP04oi2JfP09o`000?nW`ngoYl?]
ojO3kOl0003o_?3co`000?nan/go000002;ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`04ooooo`009_ooool00ol0003oooooooooo`0oooooo`;o00000_mIW?801Ol0003oY<3]ojC0
kOnT`>go000000KobL_K00?o0000om[=c?l000001ooC_/H00ol0003ofKbmomVl_@06omVl_@03o`00
0?o?[[Wo000000;o00002oo@[KD00ol0003oaZ6colJQ/`06olJQ/`Go000000WoaZ2bo`000?nkU[7o
^iJao`000?lB9jCo0000oeYF]?l000000_mjIk401?l0003oT7>_oi1c[ol00002oj5n[@03o`000?n_
RJgo000000;o_9>]00Co0000olVO[_o9Wjko00000_oF[Jl01ol0003ohkjbon>n/_o`e;Co0000oo[Y
XOl000001_nTQK85o`0000;oY8Fc00?o0000oiMm]OnGOKD03OnGOKD2o`0000[oRGZl0_l00003ohn6
a@03o`000?moPL_oOh7;00?oOh7;00?o0000oi2Jf_n@V]X01?n@V]X02Ol0003oYl?]ojO3kOnW`ngo
0000okc`lol0003o/O[=o`00000Tooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool002Oooooo00?o0000ooooooooool0?oooool2o`0000;oFIcb00Go0000ojC0kOnT`>goY<3]
o`000005olW;f`;o00002OoC_/H00ol0003ofKbmomVl_@04omVl_@03o`000?o?[[Wocjji00?ocjji
0_l00009om2]]@03o`000?o6XK?oaZ6c00_oaZ6c1_l000000olV?;?o0000o`000003ogYW/@03o`00
0?n@Ljoo000000;oXGj]00?o0000ojn9[Ol000000_nlTjd01_l0003obIn^olVO[_l0003oeZf_o`00
00;ohkjb00Ko0000oo3D]?l0003on^VQo`000?nTQK85o`0000OoY8Fc00?o0000oiMm]OnGOKD02_nG
OKD3o`000003oiV2^Ol0003oRGZl00SoRGZl00?o0000ohn6aOn?Q/D01?n?Q/D01Ol0003oOh7;ogn1
bomoPL_o000000KoT9[J00Wo0000ojO3kOnW`ngoYl?]o`000?nll??o0000ok7jcOl000009_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Xooooo`03o`000?oooooooooo
03oooooo0_l000000omIW?;o0000ojC0k@03ojC0k@05o`000?o9bm_obL_KolW;fol000000oo6`]H0
0ol0003odkk6om>naP06om>naP;o00001?oI_;d00ol0003ocjjioln^^@05oln^^@;o00001_o@[KD0
0ol0003oaZ6colJQ/`0=olJQ/`09o`000?nkUk;o^iNbok^G/_l0003o9Sbco`000?mJE[Co000000;o
NVNa00?o0000oi1c[ol000000_nQOZd00ol0003o[hV]o`000002okbC[@08o`000?o9WjkobIn^o`00
0?oF[Joo0000on>n/_l00002oo3D]004ooO//Ol0003o0000o`0000goY8Fc00?o0000oiMm]OnGOKD0
1onGOKD2o`0000GoVH:i00?o0000ohUj_?n9N[`01?n9N[`2o`0000SoShK500?o0000ogn1bol00000
1_n@V]X02Ol0003oYl?]ojO3kOnW`ngo0000okc`lol0003o/O[=o`00000Wooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00oooool002Wooooo0_l00011ooooo`03o`000?mIW?;o0000
00CoY<3]00?o0000olW;fol000001Oo6`]H00ol0003odkk6om>naP07om>naP04o`000?oI_;gofKbm
o`0000[ocjji0ol00003om2]]@03o`000?o6XK?oaZ6c00goaZ6c00?o0000ok^G/_nkUk800_nkUk80
1?l0003o9Sbco`000?l00002ogYW/@03o`000?n@LjooT7>_00;oXGj]0_n_RJd01_l0003o_9>]okbC
[Ol0003obIn^o`0000;oeZf_00Oo0000on>n/_l0003ol=Bdo`000?ogk;7o000000ooY8Fc00?o0000
oiMm]OnGOKD01?nGOKD3o`0000OoVH:i00?o0000ohUj_?n9N[`00on9N[`00ol0003oShK5ohn6a@08
ohn6a@?o00001On@V]X02Ol0003oYl?]ojO3kOnW`ngo0000okc`lol0003o/O[=o`00000Yooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0
?oooool3o`0000;oY<3]0ol00007olK2eP;o00002?oC_/H00ol0003ofKbmo`00000=oln^^@;o0000
00?od:feo`000?o6XK<03_o6XK<00ol0003o^iNbok^G/P02ok^G/P05o`0@X?l0003o0000oeYF]?l0
00000_mjIk400on@Ljoo0000o`00000;o`000005on>n/_l0003ol=Bdo`000?ogk;400_l0000?ojB5
/`03o`000?nGOKGoUgfe00;oUgfe0_l0000;oiV2^@03o`000?n9N[coRGZl00;o00002_n?Q/D01Ol0
003oVIcEoiVLeOnIW=Go000000?oT9[J00Wo0000ojO3kOnW`ngoYl?]o`000?nll??o0000ok7jcOl0
0000:oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000/ooooo`03o`00
0?oooooooooo03oooooo00Co0000odJOmOl0003o00001?nT`Nd8olK2eP03o`000?oC_/Kodkk600Ko
dkk60_l0000?oln^^@?o00003_o6XK<00ol0003o^iNbok^G/P03ok^G/P05o`0@X?lV?;?oFUJdo`00
0?mjIk400_l000001_nFP[co0000ojB:^Ol0003o/9>ho`0000;o^ibh00Ko0000olJW^_l0003odK>l
o`000?oS_[82o`000004ooO//Ol0003o0000o`00013oY8Fc1?l0000=oiV2^@03o`000?n9N[co0000
00[oShK50_l00005oiVLe@03o`000?n@V][o000000?oYl?]00?o0000okc`lol000000_l0000]oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool002gooooo00?o0000oooooooo
ool0@?ooool00ol0003oAYoeojC1k@04ojC1k@;o00001_o6`]H00ol0003odkk6om>naP05om>naP03
o`000?o;//;o000000;o00003?o?[[T00ol0003oaJ>golFS]`04o`0000WoaZ6c00?o0000ok^G/_nk
Uk801?nkUk83o`00000:oeYF]?l0003oQ7Voo`000?nFP[co0000ojB:^Ol0003o/9>ho`0000;o^ibh
00Co0000olJW^_oA/kcodK>l0_l000001?o`e;Co0000o`000?oJlYH2ok2>/P03o`000?nTQK?oY8Fc
00[oY8Fc1?l0000@oiV2^@;o00002On?Q/D2o`0000OoVIcE1?l000000onW`ngo0000o`000002o`00
02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;_ooool2o`00047o
oooo0_l000000om6WoGoY<7]ojC1k@03ojC1k@03o`000?o6`]Koa/;F00Coa/;F0_l00004om>naP03
o`000?o;//;obk;200?obk;20_l00009oln^^@03o`000?o5XkOoaJ>g00GoaJ>g1?l00005olJQ/`03
o`000?nkUk;o^iNb00Go^iNb00Co012PobHl/ol0003o00000_n4NKl02_l0003oUX:lo`000?l0003o
/9>ho`000?nkW;So0000olJW^_l00002om6c_005omc3`?l0003o0000ooO//Ol000000on`S[800ol0
003oY8FcojB5/`05ojB5/`Go00000onURKL00ol0003oVH:ioiV2^@0;oiV2^@?o000000?oW8_1o`00
0?n?Q/D01on?Q/D00ol0003oVIcEoiVLe@05oiVLe@;o00000onW`nh5o`00037ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`00<?ooool00ol0003oooooooooo`10ooooo`03
o`000?m6WoGo000000CoY<7]0_l00006olK2eP04o`000?oC_/Kodkk6o`0000Sobk;20ol00006oln^
^@03o`000?o5XkOoaJ>g00WoaJ>g1?l000000oo6XK?o0000ok^G/P07ok^G/P09o`0@X?m9Hl[o0000
o`000?n4NKoo0000oiJ2_?l0003oY8Zi00;o000000?o^ibho`000?o6YkX00_oA/k`00ooL`l3o0000
onKFaP03o`0000?o/8jb00?o0000ojB5/onTQK<01Ol00009ojF9]`03o`000?nIP[WoVH:i00OoVH:i
0ol00005oib;`@03o`000?n?Q/GoShK500?oShK50_l00007oiVLe@04o`000?nW`nkoYl?^ojO3kPGo
0000=?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000aooooo`03o`00
0?oooooooooo043ooooo0_l000000om6WoGo0000ojC1k@03ojC1k@03o`000?o6`]Koa/;F00Coa/;F
00?o0000om>na_l000002oo;//82o`0000Cocjji00?o0000olFS]oo5XkL03Oo5XkL:o`000003o`0@
X?l0003oBF?:00;o000000CoQ7Voo`000?l0003oY8Zi0_l000001?nkW;So0000o`000?oA/k`2o`00
0003onKFa_l0003o000000So00003_nURKL00ol0003oVH:ioiV2^@05oiV2^@;o00002OnLRl400ol0
003oShK5ohn6a@02o`0000OoVIcE0_l00003ojO3kP04o`000?nVlOKo0000o`0003Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00<_ooool00ol0003oooooooooo`10oooo
o`?o000000?oAYoeo`000?nT`Nd00_nT`Nd00ol0003oa/;FolK2eP04olK2eP03o`000?o;//;obk;2
00cobk;21?l0000AolFS]`03o`000?nkVKKo^iVf00Oo^iVf0_l000001Om9Hl[o0000ohAi_ol0003o
UX:l00Co000000CoaZNjo`000?l0003og<?01?l00005ok2A]P03o`000?nURKOoYHVg00koYHVg00?o
0000oiV2^OnIP[T00_nIP[T3o`0000_oW8_100?o0000ohn6aOl000001onIW=D2o`0000?oYl?^1Ol0
000hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003?ooooo0_l00012
ooooo`;o000000?oAYoeo`000?l000000_nT`Nd2o`0000?oa/;F00?o0000ol:id_o2^M800ol0000=
ol^b`P03o`000?o5XkOoaJ>g00ooaJ>g00?o0000ok^I]_nkVKH02?nkVKH01Ol0003oBF?:odUSb_l0
003oQ7Vo00Oo000000?og<?0o`000?l000000_l00006ok2A]P03o`000?nURKOoYHVg00ooYHVg1?l0
000>oib;`@;o00001onIW=D01?l0003oYl?^ojO3k_nW`nh2o`000003ojKam_l0003o000003_ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003ooooooooo
o`10ooooo`?o000000?oAYoeo`000?l000000_nT`Nd00ol0003oa/;Fo`000006ol:idP?o00002_o;
//800ol0003o`jRool>X_`04o`0000_oaJ>g00?o0000ok^I]_nkVKH02OnkVKH00ol0003oBF?:odUS
bP0;o`0000So/96f00?o0000ojF9]onURKL03OnURKL3o`0000koW8_10ol000000onQW]7o0000oiVL
e@04oiVLe@;o00000onW`nh00ol0003oY_7fo`000002o`0003gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`10ooooo`?o00000_m6WoD0
1?l0003oY<7]o`000?l0000:ol:idP;o00001oo;//800ol0003o`jRool>X_`05ol>X_`Go00001Oo5
XkL00ol0003o^iVfok^I]P0<ok^I]P;o000000?oPZ3Vo`000?l000001_l0000:ok2A]P03o`000?nU
RKOoYHVg00SoYHVg1?l00002ojNA_`03o`000?nLRl7oW8_100WoW8_10ol00005oj6Nd@03o`000?nI
W=GoVIcE00;o00000onW`nh2o`000003ojKam_l0003o000003oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=oooool00ol0003oooooooooo`11ooooo`03ofh00?l0003o
000000;o00000onT`Nh2o`0000Wo`[WB0ol00004ol^b`P03o`000?o3Z;oo`jRo00[o`jRo1?l00000
0oo5XkOo0000ok^I]P0>ok^I]PWo00002on`TKH00ol0003oYHVgojF9]`03ojF9]`Go00001onWTKl0
0ol0003oW8_1oib;`@05oib;`@?o00002?nQW]400ol0003oVIcEo`000003ojO3kP;o000000?oY_7f
o`000?l00000@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000hoooo
o`;o0000A?ooool3ocNSl`03o`000?nT`NkoY<7^00;oY<7^0_l00009ol:idP?o000000?obk;2o`00
0?o3Z;l03oo3Z;l2o`000003ok^I]_l0003o000000;o00002onkVKH7o`0000co/96f00?o0000ojF9
]ol000000ol0000<ojNA_`03o`000?nLRl7oW8_100;oW8_10ol0000;oj6Nd@Co000000CoYl?^o`00
0?nVlOKoY_7f0_l00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool0
03[ooooo00?o0000ooooooooool0@oooool00ol0003o=j?cocNSl`02o`0000?oY<7^0ol00009ol:i
dP03o`000?o3Z;oo`jRo013o`jRo00?o0000okZO__njWkh00onjWkh9o`0000?o^iVf00Co0000ok2A
]_l0003o00001On`TKH;o`00013oYi6o00?o0000oib;`Ol000000_l0000;oj6Nd@?o00000onV`nh5
o`0004Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00>oooool00ol0
003oooooooooo`14ooooo`03ofh00?lgXo?o=j?c00;o00001?nT`Nh2o`0000Oo`[WB00?o0000okbb
d?nl/]000ol0000=ol>X_`03o`000?njWkko^Ynn00co^Ynn3?l00009ok6H_P03o`000?nWTKooYi6o
00koYi6o0ol0000;oj6Nd@?o00000onV`nh6o`0004Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`01ooooo`00??ooool2o`0004Oooooo00?o0000ocNSlol000000_l00003ojC1kP;o
00001?o2^M800ol0003o_;;@okbbd004okbbd0Co00002Oo3Z;l00ol0003o^YnnokZO_P0?okZO_P03
o`000?naV;ko/IRn00oo/IRn00?o0000ojNA_onWTKl02OnWTKl5o`0000;oZJ;?00?o0000oj6NdOnQ
W]401_nQW]43o`0000CoY/?^1Ol0001=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00Oooool003kooooo00?o0000ooooooooool0A_ooool00ol0003o=j?cocNSl`02o`0000?oY<7^
0ol000000oo2^M;o0000okbbd009okbbd0Co00001?o3Z;l00ol0003o^YnnokZO_P0@okZO_P03o`00
0?naV;ko/IRn013o/IRn00?o0000ojNA_onWTKl01?nWTKl4o`0000SoZJ;?00?o0000oj6NdOnQW]40
0_nQW]43o`0000CoY/?^1Ol0001Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0Oooool003oooooo00?o0000ooooooooool0Aoooool2o`000003ocNSlol0003o000000CoY<7^00?o
0000okbbd?nl/]003Onl/]03o`000003ol>X_ol0003o^Ynn017o^Ynn00?o0000ok6H__naV;h04?na
V;h00ol0003oYi6oo`000004o`0000coZJ;?00?o0000oj6NdOl000000_l00004ojK3kPGo0000EOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooo
oooo04Wooooo00Ko0000ocNSlol0003o0000ojC1k_l00003ojG2kPGo00002onl/]02o`000003okZO
__l0003o000000Oo00002?njWkh00ol0003o/IRnok6H_P07ok6H_P_o00004?nYX/l3o`0000GoY/?^
1Ol0001Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo0_l0
001;ooooo`?o00002OnU`^h5o`0000Oo_;;@00?o0000okJ/c_nf[<h02?nf[<hBo`0000Wo/:K>00?o
0000ojVRconYX/l02_nYX/l5o`0000?oY/?^00?o0000ojK3k_l000001?l0001Kooooo`03o`000?oo
oooooooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04_ooooo00?o0000
obnZk_l_Z^h00_l00009ojG2kPGo000000?o_;;@o`000?nf[<h04_nf[<h00ol0003o/:K>ok2VcP0@
ok2VcP03o`000?nYX/ooZJ;?00GoZJ;?1Ol00007ojK3kPGo0000Goooool00ol0003oooooooooo`07
ooooo`7o00000Oooool1ooooo`00A?ooool00ol0003oooooooooo`1>ooooo`;o00000_l_Z^h5o`00
00KoYL;^0_l00004okJ/cP03o`000?nf[<ko]Zc>00co]Zc>00?o0000ok2Vc_n`Y/h04On`Y/h00ol0
003oZJ;?o`000004o`0000OoY/?^1_l0001Tooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo0015ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00_ooool3o`000003
obnZk_l0003o000000?o00000_nU`^h00ol0003oYL;^ojG2kP03ojG2kP[o00001?nf[<h00ol0003o
/:K>ok2VcP07ok2VcPco00001onV`nh6o`0006Wooooo00?o0000ooooooooool01_ooool1o`00007o
oooo0Oooool004Kooooo0_l0001=ooooo`03o`000?oooooooooo00Kooooo1?l000000ol_Z^ko0000
o`00000@ojG2kPko00002_nU`^h01?l0003oY/?^ojK3k_nV`nh6o`0006oooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool004Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0:ooooo`;o00001_ld]>T;o`0000CoYL;^00?o0000ojG2k_nU`^h02?nU`^h>o`0007Gooooo
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Booooo`Go00001_ld]>TEo`0007kooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0M
ooooo`[o0000ROooool00ol0003oooooooooo`04ooooo`7o00000Oooool004_ooooo0_l00018oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool00oooool1o`00007ooooo001=ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`02ooooo`7o
00000Oooool004kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo0;?ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?ooool2o`0004?ooooo00?o
0000ooooooooool0]?ooool01?l0003oooooooooool00001ooooo`00D_ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000000Oooool005?ooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo007o0000001Doooo
o`;o0000?oooool00ol0003oooooooooo`2fooooo`7o00000Oooool1o`000000E_ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo0;Oooooo0_l0000005Oooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2fooooo`?o0000001Hooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0/_ooool4o`0000?ooooo001Iooooo`;o0000>_ooool00ol0003oooooooooo`2^
ooooo`Co00001oooool005_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2Zoooo
o`Co00002oooool005cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Vooooo`Co
00003oooool005gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Rooooo`Co0000
4oooool005kooooo0_l0000eooooo`03o`000?oooooooooo09kooooo1?l0000Gooooo`00H?ooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo09[ooooo1?l0000Kooooo`00HOooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo09Sooooo0ol0000Oooooo`00H_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo09Cooooo1?l0000Rooooo`00Hoooool2o`0002oooooo
00?o0000ooooooooool0T?ooool4o`0002Kooooo001Uooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0S?ooool4o`0002[ooooo001Vooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0R?ooool4o`0002kooooo001Wooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Q?ooool4o`0003;ooooo001Xooooo`;o0000:_ooool00ol0003oooooooooo`20ooooo`Co
0000=_ooool006[ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1looooo`Co0000
>_ooool006_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1hooooo`Co0000?_oo
ool006cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Co0000@_ooool0
06gooooo0_l0000Uooooo`03o`000?oooooooooo073ooooo1?l00016ooooo`00Koooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo06cooooo1?l0001:ooooo`00L?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo06Sooooo1?l0001>ooooo`00LOooool2o`00027ooooo00?o
0000ooooooooool0I?ooool4o`0005;ooooo001cooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0H?ooool4o`0005Kooooo001dooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0G?ooool4o`0005[ooooo001eooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0FOooool3o`0005kooooo001fooooo`;o00007?ooool00ol0003oooooooooo`1Eooooo`Co0000
HOooool007Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Aooooo`Co0000IOoo
ool007Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1=ooooo`Co0000JOooool0
07[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000KOooool007_o
oooo0_l0000Gooooo`03o`000?oooooooooo04Gooooo1?l0001aooooo`00OOooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo047ooooo1?l0001eooooo`00O_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03gooooo1?l0001iooooo`00Ooooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03Wooooo1?l0001mooooo`00P?ooool2o`0001;ooooo00?o0000oooo
ooooool0=Oooool4o`00087ooooo0022ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0<Oooool4o`0008Gooooo0023ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;_ooool4o`0008Wooooo0024ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_oo
ool4o`0008gooooo0025ooooo`;o00003?ooool00ol0003oooooooooo`0Vooooo`Co0000TOooool0
08Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000UOooool008So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000VOooool008Wooooo
0_l00008ooooo`03o`000?oooooooooo01_ooooo0ol0002Mooooo`00Roooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Oooooo1?l0002Pooooo`00S?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo1?l0002Tooooo`00SOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo1?l0002Xooooo`00S_ooool2o`0000?ooooo00?o0000oooooooo
ool02oooool4o`000:cooooo002@ooooo`04o`000?ooooooooooo`0000Wooooo1?l0002`ooooo`00
TOooool00ol0003oooooo`000005ooooo`Co0000]?ooool009;ooooo0_l000000ooooooo0000o`00
0002o`000;Sooooo002Cooooo`;o0000_?ooool00?ooooooD_ooool00?ooooooD_ooool00?oooooo
D_ooool00001\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51722 .66229 m .51694 .65827 L .43899 .65168 L p .517 0 0 r
F P
0 g
s
.51694 .65827 m .51722 .66229 L .59284 .65812 L p .421 0 0 r
F P
0 g
s
.59284 .65812 m .59527 .65394 L .51694 .65827 L p .421 0 0 r
F P
0 g
s
.59527 .65394 m .59284 .65812 L .66515 .64355 L p .274 0 0 r
F P
0 g
s
.66515 .64355 m .67023 .63881 L .59527 .65394 L p .274 0 0 r
F P
0 g
s
.44198 .65594 m .43899 .65168 L .36521 .63435 L p .573 .014 0 r
F P
0 g
s
.43899 .65168 m .44198 .65594 L .51722 .66229 L p .517 0 0 r
F P
0 g
s
.51751 .66542 m .51722 .66229 L .44198 .65594 L p .458 0 0 r
F P
0 g
s
.51722 .66229 m .51751 .66542 L .59035 .66141 L p .36 0 0 r
F P
0 g
s
.59035 .66141 m .59284 .65812 L .51722 .66229 L p .36 0 0 r
F P
0 g
s
.59284 .65812 m .59035 .66141 L .65997 .64742 L p .203 0 0 r
F P
0 g
s
.65997 .64742 m .66515 .64355 L .59284 .65812 L p .203 0 0 r
F P
0 g
s
.36521 .63435 m .37082 .63926 L .44198 .65594 L p .573 .014 0 r
F P
0 g
s
.44504 .65932 m .44198 .65594 L .37082 .63926 L p .505 0 0 r
F P
0 g
s
.44198 .65594 m .44504 .65932 L .51751 .66542 L p .458 0 0 r
F P
0 g
s
.67023 .63881 m .66515 .64355 L .73043 .61904 L p .048 0 0 r
F P
0 g
s
.73043 .61904 m .73799 .61332 L .67023 .63881 L p .048 0 0 r
F P
0 g
s
.51781 .66632 m .51751 .66542 L .44504 .65932 L p .205 0 0 r
F P
0 g
s
.51751 .66542 m .51781 .66632 L .58779 .66247 L p .108 0 0 r
F P
0 g
s
.58779 .66247 m .59035 .66141 L .51751 .66542 L p .108 0 0 r
F P
0 g
s
.37082 .63926 m .36521 .63435 L .29943 .6068 L p .569 0 0 r
F P
0 g
s
.59035 .66141 m .58779 .66247 L .65462 .64904 L p 0 0 0 r
F P
0 g
s
.65462 .64904 m .65997 .64742 L .59035 .66141 L p 0 0 0 r
F P
0 g
s
.37082 .63926 m .37655 .64329 L .44504 .65932 L p .505 0 0 r
F P
0 g
s
.44819 .66046 m .44504 .65932 L .37655 .64329 L p .228 0 0 r
F P
0 g
s
.44504 .65932 m .44819 .66046 L .51781 .66632 L p .205 0 0 r
F P
0 g
s
.66515 .64355 m .65997 .64742 L .72271 .62388 L p 0 0 0 r
F P
0 g
s
.72271 .62388 m .73043 .61904 L .66515 .64355 L p 0 0 0 r
F P
0 g
s
.51812 .66382 m .51781 .66632 L .44819 .66046 L p .367 .774 .983 r
F P
0 g
s
.51781 .66632 m .51812 .66382 L .58513 .66013 L p .422 .821 .982 r
F P
0 g
s
.58513 .66013 m .58779 .66247 L .51781 .66632 L p .422 .821 .982 r
F P
0 g
s
.29943 .6068 m .30748 .61277 L .37082 .63926 L p .569 0 0 r
F P
0 g
s
.37655 .64329 m .37082 .63926 L .30748 .61277 L p .481 0 0 r
F P
0 g
s
.58779 .66247 m .58513 .66013 L .64909 .64726 L p .502 .867 .985 r
F P
0 g
s
.64909 .64726 m .65462 .64904 L .58779 .66247 L p .502 .867 .985 r
F P
0 g
s
.37655 .64329 m .38245 .64508 L .44819 .66046 L p .228 0 0 r
F P
0 g
s
.45145 .65821 m .44819 .66046 L .38245 .64508 L p .345 .733 .985 r
F P
0 g
s
.44819 .66046 m .45145 .65821 L .51812 .66382 L p .367 .774 .983 r
F P
0 g
s
.65997 .64742 m .65462 .64904 L .71477 .62647 L p .294 .781 .716 r
F P
0 g
s
.71477 .62647 m .72271 .62388 L .65997 .64742 L p .294 .781 .716 r
F P
0 g
s
.51844 .65716 m .51812 .66382 L .45145 .65821 L p .648 .758 .93 r
F P
0 g
s
.51812 .66382 m .51844 .65716 L .58238 .65363 L p .65 .759 .93 r
F P
0 g
s
.58238 .65363 m .58513 .66013 L .51812 .66382 L p .65 .759 .93 r
F P
0 g
s
.73799 .61332 m .73043 .61904 L .78487 .58542 L p 0 0 0 r
F P
0 g
s
.78487 .58542 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.30748 .61277 m .31569 .61787 L .37655 .64329 L p .481 0 0 r
F P
0 g
s
.38245 .64508 m .37655 .64329 L .31569 .61787 L p 0 .396 .742 r
F P
0 g
s
.58513 .66013 m .58238 .65363 L .64336 .64129 L p .651 .76 .929 r
F P
0 g
s
.64336 .64129 m .64909 .64726 L .58513 .66013 L p .651 .76 .929 r
F P
0 g
s
.38245 .64508 m .38856 .64347 L .45145 .65821 L p .345 .733 .985 r
F P
0 g
s
.45483 .65178 m .45145 .65821 L .38856 .64347 L p .647 .757 .929 r
F P
0 g
s
.45145 .65821 m .45483 .65178 L .51844 .65716 L p .648 .758 .93 r
F P
0 g
s
.51877 .64606 m .51844 .65716 L .45483 .65178 L p .708 .684 .825 r
F P
0 g
s
.51844 .65716 m .51877 .64606 L .57953 .64268 L p .686 .666 .824 r
F P
0 g
s
.57953 .64268 m .58238 .65363 L .51844 .65716 L p .686 .666 .824 r
F P
0 g
s
.65462 .64904 m .64909 .64726 L .70656 .62564 L p .59 .902 .985 r
F P
0 g
s
.70656 .62564 m .71477 .62647 L .65462 .64904 L p .59 .902 .985 r
F P
0 g
s
.30748 .61277 m .29943 .6068 L .24558 .56996 L p .45 0 0 r
F P
0 g
s
.58238 .65363 m .57953 .64268 L .63743 .63088 L p .662 .651 .828 r
F P
0 g
s
.63743 .63088 m .64336 .64129 L .58238 .65363 L p .662 .651 .828 r
F P
0 g
s
.45483 .65178 m .45833 .64091 L .51877 .64606 L p .708 .684 .825 r
F P
0 g
s
.51911 .63082 m .51877 .64606 L .45833 .64091 L p .724 .64 .764 r
F P
0 g
s
.51877 .64606 m .51911 .63082 L .5766 .62758 L p .692 .613 .764 r
F P
0 g
s
.5766 .62758 m .57953 .64268 L .51877 .64606 L p .692 .613 .764 r
F P
0 g
s
.38856 .64347 m .39489 .63767 L .45483 .65178 L p .647 .757 .929 r
F P
0 g
s
.45833 .64091 m .45483 .65178 L .39489 .63767 L p .729 .706 .829 r
F P
0 g
s
.31569 .61787 m .32414 .62071 L .38245 .64508 L p 0 .396 .742 r
F P
0 g
s
.38856 .64347 m .38245 .64508 L .32414 .62071 L p .355 .7 .984 r
F P
0 g
s
.73043 .61904 m .72271 .62388 L .77491 .59164 L p 0 0 0 r
F P
0 g
s
.77491 .59164 m .78487 .58542 L .73043 .61904 L p 0 0 0 r
F P
0 g
s
.45833 .64091 m .46193 .6259 L .51911 .63082 L p .724 .64 .764 r
F P
0 g
s
.51946 .61228 m .51911 .63082 L .46193 .6259 L p .729 .616 .732 r
F P
0 g
s
.51911 .63082 m .51946 .61228 L .57362 .6092 L p .692 .585 .732 r
F P
0 g
s
.57362 .6092 m .5766 .62758 L .51911 .63082 L p .692 .585 .732 r
F P
0 g
s
.57953 .64268 m .5766 .62758 L .63135 .61632 L p .657 .59 .768 r
F P
0 g
s
.63135 .61632 m .63743 .63088 L .57953 .64268 L p .657 .59 .768 r
F P
0 g
s
.64909 .64726 m .64336 .64129 L .69806 .62061 L p .653 .761 .929 r
F P
0 g
s
.69806 .62061 m .70656 .62564 L .64909 .64726 L p .653 .761 .929 r
F P
0 g
s
.46193 .6259 m .4656 .60759 L .51946 .61228 L p .729 .616 .732 r
F P
0 g
s
.51981 .59177 m .51946 .61228 L .4656 .60759 L p .731 .605 .717 r
F P
0 g
s
.51946 .61228 m .51981 .59177 L .5706 .58884 L p .691 .572 .717 r
F P
0 g
s
.5706 .58884 m .57362 .6092 L .51946 .61228 L p .691 .572 .717 r
F P
0 g
s
.39489 .63767 m .40143 .62741 L .45833 .64091 L p .729 .706 .829 r
F P
0 g
s
.46193 .6259 m .45833 .64091 L .40143 .62741 L p .755 .672 .77 r
F P
0 g
s
.4656 .60759 m .4693 .58732 L .51981 .59177 L p .731 .605 .717 r
F P
0 g
s
.52016 .57089 m .51981 .59177 L .4693 .58732 L p .731 .603 .715 r
F P
0 g
s
.51981 .59177 m .52016 .57089 L .56758 .56812 L p .691 .57 .714 r
F P
0 g
s
.56758 .56812 m .5706 .58884 L .51981 .59177 L p .691 .57 .714 r
F P
0 g
s
.4693 .58732 m .47301 .56667 L .52016 .57089 L p .731 .603 .715 r
F P
0 g
s
.52051 .55135 m .52016 .57089 L .47301 .56667 L p .73 .611 .725 r
F P
0 g
s
.52016 .57089 m .52051 .55135 L .56457 .54874 L p .691 .579 .724 r
F P
0 g
s
.56457 .54874 m .56758 .56812 L .52016 .57089 L p .691 .579 .724 r
F P
0 g
s
.5766 .62758 m .57362 .6092 L .62515 .59847 L p .651 .557 .736 r
F P
0 g
s
.62515 .59847 m .63135 .61632 L .5766 .62758 L p .651 .557 .736 r
F P
0 g
s
.24558 .56996 m .25577 .57741 L .30748 .61277 L p .45 0 0 r
F P
0 g
s
.31569 .61787 m .30748 .61277 L .25577 .57741 L p 0 .203 .638 r
F P
0 g
s
.47301 .56667 m .47671 .54739 L .52051 .55135 L p .73 .611 .725 r
F P
0 g
s
.52086 .53479 m .52051 .55135 L .47671 .54739 L p .726 .631 .752 r
F P
0 g
s
.52051 .55135 m .52086 .53479 L .56159 .53236 L p .692 .603 .752 r
F P
0 g
s
.56159 .53236 m .56457 .54874 L .52051 .55135 L p .692 .603 .752 r
F P
0 g
s
.57362 .6092 m .5706 .58884 L .61889 .57866 L p .648 .542 .72 r
F P
0 g
s
.61889 .57866 m .62515 .59847 L .57362 .6092 L p .648 .542 .72 r
F P
0 g
s
.40143 .62741 m .40814 .61301 L .46193 .6259 L p .755 .672 .77 r
F P
0 g
s
.4656 .60759 m .46193 .6259 L .40814 .61301 L p .765 .652 .737 r
F P
0 g
s
.5706 .58884 m .56758 .56812 L .61262 .55849 L p .648 .54 .718 r
F P
0 g
s
.61262 .55849 m .61889 .57866 L .5706 .58884 L p .648 .54 .718 r
F P
0 g
s
.32414 .62071 m .33287 .62013 L .38856 .64347 L p .355 .7 .984 r
F P
0 g
s
.39489 .63767 m .38856 .64347 L .33287 .62013 L p .646 .755 .928 r
F P
0 g
s
.56758 .56812 m .56457 .54874 L .60639 .5397 L p .65 .55 .728 r
F P
0 g
s
.60639 .5397 m .61262 .55849 L .56758 .56812 L p .65 .55 .728 r
F P
0 g
s
.40814 .61301 m .41498 .59532 L .4656 .60759 L p .765 .652 .737 r
F P
0 g
s
.4693 .58732 m .4656 .60759 L .41498 .59532 L p .769 .642 .722 r
F P
0 g
s
.56457 .54874 m .56159 .53236 L .60022 .52392 L p .655 .578 .756 r
F P
0 g
s
.60022 .52392 m .60639 .5397 L .56457 .54874 L p .655 .578 .756 r
F P
0 g
s
.41498 .59532 m .42189 .57567 L .4693 .58732 L p .769 .642 .722 r
F P
0 g
s
.47301 .56667 m .4693 .58732 L .42189 .57567 L p .77 .641 .719 r
F P
0 g
s
.47671 .54739 m .48037 .53109 L .52086 .53479 L p .726 .631 .752 r
F P
0 g
s
.5212 .5226 m .52086 .53479 L .48037 .53109 L p .712 .674 .812 r
F P
0 g
s
.52086 .53479 m .5212 .5226 L .55865 .52035 L p .688 .655 .811 r
F P
0 g
s
.55865 .52035 m .56159 .53236 L .52086 .53479 L p .688 .655 .811 r
F P
0 g
s
.42189 .57567 m .4288 .55567 L .47301 .56667 L p .77 .641 .719 r
F P
0 g
s
.47671 .54739 m .47301 .56667 L .4288 .55567 L p .767 .647 .73 r
F P
0 g
s
.72271 .62388 m .71477 .62647 L .76468 .5956 L p .546 .928 .833 r
F P
0 g
s
.76468 .5956 m .77491 .59164 L .72271 .62388 L p .546 .928 .833 r
F P
0 g
s
.4288 .55567 m .43567 .53705 L .47671 .54739 L p .767 .647 .73 r
F P
0 g
s
.48037 .53109 m .47671 .54739 L .43567 .53705 L p .758 .664 .757 r
F P
0 g
s
.64336 .64129 m .63743 .63088 L .68928 .61112 L p .637 .639 .836 r
F P
0 g
s
.68928 .61112 m .69806 .62061 L .64336 .64129 L p .637 .639 .836 r
F P
0 g
s
.56159 .53236 m .55865 .52035 L .59413 .51254 L p .663 .638 .815 r
F P
0 g
s
.59413 .51254 m .60022 .52392 L .56159 .53236 L p .663 .638 .815 r
F P
0 g
s
.43567 .53705 m .44247 .52145 L .48037 .53109 L p .758 .664 .757 r
F P
0 g
s
.48398 .51918 m .48037 .53109 L .44247 .52145 L p .734 .698 .816 r
F P
0 g
s
.48037 .53109 m .48398 .51918 L .5212 .5226 L p .712 .674 .812 r
F P
0 g
s
.33287 .62013 m .34191 .61534 L .39489 .63767 L p .646 .755 .928 r
F P
0 g
s
.40143 .62741 m .39489 .63767 L .34191 .61534 L p .746 .732 .838 r
F P
0 g
s
.52154 .51576 m .5212 .5226 L .48398 .51918 L p .641 .761 .936 r
F P
0 g
s
.5212 .5226 m .52154 .51576 L .55574 .5137 L p .647 .766 .936 r
F P
0 g
s
.55574 .5137 m .55865 .52035 L .5212 .5226 L p .647 .766 .936 r
F P
0 g
s
.63743 .63088 m .63135 .61632 L .68028 .59747 L p .618 .57 .778 r
F P
0 g
s
.68028 .59747 m .68928 .61112 L .63743 .63088 L p .618 .57 .778 r
F P
0 g
s
.25577 .57741 m .26614 .58397 L .31569 .61787 L p 0 .203 .638 r
F P
0 g
s
.32414 .62071 m .31569 .61787 L .26614 .58397 L p 0 .442 .852 r
F P
0 g
s
.55865 .52035 m .55574 .5137 L .58812 .50654 L p .654 .77 .934 r
F P
0 g
s
.58812 .50654 m .59413 .51254 L .55865 .52035 L p .654 .77 .934 r
F P
0 g
s
.63135 .61632 m .62515 .59847 L .67113 .58054 L p .606 .532 .745 r
F P
0 g
s
.67113 .58054 m .68028 .59747 L .63135 .61632 L p .606 .532 .745 r
F P
0 g
s
.44247 .52145 m .44917 .51025 L .48398 .51918 L p .734 .698 .816 r
F P
0 g
s
.48755 .51262 m .48398 .51918 L .44917 .51025 L p .636 .755 .934 r
F P
0 g
s
.48398 .51918 m .48755 .51262 L .52154 .51576 L p .641 .761 .936 r
F P
0 g
s
.61889 .57866 m .61262 .55849 L .65267 .54245 L p .599 .511 .726 r
F P
0 g
s
.61262 .55849 m .60639 .5397 L .6435 .52464 L p .603 .523 .737 r
F P
0 g
s
.6435 .52464 m .65267 .54245 L .61262 .55849 L p .603 .523 .737 r
F P
0 g
s
.62515 .59847 m .61889 .57866 L .6619 .56166 L p .6 .514 .729 r
F P
0 g
s
.65267 .54245 m .6619 .56166 L .61889 .57866 L p .599 .511 .726 r
F P
0 g
s
.60639 .5397 m .60022 .52392 L .63444 .50988 L p .615 .556 .765 r
F P
0 g
s
.63444 .50988 m .6435 .52464 L .60639 .5397 L p .615 .556 .765 r
F P
0 g
s
.6619 .56166 m .67113 .58054 L .62515 .59847 L p .6 .514 .729 r
F P
0 g
s
.34191 .61534 m .35123 .60609 L .40143 .62741 L p .746 .732 .838 r
F P
0 g
s
.40814 .61301 m .40143 .62741 L .35123 .60609 L p .784 .708 .78 r
F P
0 g
s
.71477 .62647 m .70656 .62564 L .75411 .59612 L p .669 .916 .976 r
F P
0 g
s
.75411 .59612 m .76468 .5956 L .71477 .62647 L p .669 .916 .976 r
F P
0 g
s
.60022 .52392 m .59413 .51254 L .62552 .49956 L p .636 .626 .823 r
F P
0 g
s
.62552 .49956 m .63444 .50988 L .60022 .52392 L p .636 .626 .823 r
F P
0 g
s
.38031 .55734 m .39011 .53837 L .4288 .55567 L p .808 .685 .729 r
F P
0 g
s
.4288 .55567 m .42189 .57567 L .38031 .55734 L p .808 .685 .729 r
F P
0 g
s
.43567 .53705 m .4288 .55567 L .39011 .53837 L p .803 .69 .739 r
F P
0 g
s
.39011 .53837 m .39983 .52082 L .43567 .53705 L p .803 .69 .739 r
F P
0 g
s
.44247 .52145 m .43567 .53705 L .39983 .52082 L p .79 .702 .768 r
F P
0 g
s
.35123 .60609 m .36079 .59268 L .40814 .61301 L p .784 .708 .78 r
F P
0 g
s
.41498 .59532 m .40814 .61301 L .36079 .59268 L p .8 .693 .747 r
F P
0 g
s
.37051 .57598 m .38031 .55734 L .42189 .57567 L p .807 .686 .731 r
F P
0 g
s
.42189 .57567 m .41498 .59532 L .37051 .57598 L p .807 .686 .731 r
F P
0 g
s
.36079 .59268 m .37051 .57598 L .41498 .59532 L p .8 .693 .747 r
F P
0 g
s
.52188 .51478 m .52154 .51576 L .48755 .51262 L p .103 .644 .847 r
F P
0 g
s
.49109 .51194 m .52188 .51478 L p .50228 .51355 L .103 .644 .847 r
F P
0 g
s
.48755 .51262 m .49109 .51194 L p .50228 .51355 L .103 .644 .847 r
F P
0 g
s
.44917 .51025 m .4558 .50445 L .48755 .51262 L p .636 .755 .934 r
F P
0 g
s
.49109 .51194 m .48755 .51262 L .4558 .50445 L p .083 .601 .882 r
F P
0 g
s
.46236 .50453 m .49109 .51194 L p .47097 .50767 L .083 .601 .882 r
F P
0 g
s
.4558 .50445 m .46236 .50453 L p .47097 .50767 L .083 .601 .882 r
F P
0 g
s
.46236 .50453 m .4558 .50445 L .42823 .49165 L p .128 .582 .923 r
F P
0 g
s
.43747 .49296 m .46236 .50453 L p .44293 .4972 L .128 .582 .923 r
F P
0 g
s
.42823 .49165 m .43747 .49296 L p .44293 .4972 L .128 .582 .923 r
F P
0 g
s
.41805 .47786 m .43747 .49296 L p .41994 .48271 L .214 .572 .94 r
F P
0 g
s
.40665 .47493 m .41805 .47786 L p .41994 .48271 L .214 .572 .94 r
F P
0 g
s
.41805 .47786 m .40548 .4601 L p .41543 .47117 L 0 .238 .75 r
F P
0 g
s
.43747 .49296 m .41805 .47786 L p .42995 .48712 L .435 0 0 r
F P
0 g
s
.43747 .49296 m .42823 .49165 L .40665 .47493 L p .214 .572 .94 r
F P
0 g
s
.42936 .48667 m .44666 .50012 L p .42789 .48551 L .435 0 0 r
F P
0 g
s
.41805 .47786 m .42936 .48667 L p .42789 .48551 L .435 0 0 r
F P
0 g
s
.44666 .50012 m .43747 .49296 L p .42995 .48712 L .435 0 0 r
F P
0 g
s
.4558 .50445 m .44917 .51025 L .4189 .49627 L p .633 .748 .931 r
F P
0 g
s
.4189 .49627 m .42823 .49165 L .4558 .50445 L p .633 .748 .931 r
F P
0 g
s
.45588 .51247 m .44666 .50012 L .42936 .48667 L p .73 .213 0 r
F P
0 g
s
.42936 .48667 m .41824 .47089 L p .43121 .48811 L 0 0 .499 r
F P
0 g
s
.44069 .5007 m .45588 .51247 L p .43637 .49349 L .73 .213 0 r
F P
0 g
s
.42936 .48667 m .44069 .5007 L p .43637 .49349 L .73 .213 0 r
F P
0 g
s
.44069 .5007 m .42936 .48667 L p .43121 .48811 L 0 0 .499 r
F P
0 g
s
.40944 .50632 m .4189 .49627 L .44917 .51025 L p .753 .725 .826 r
F P
0 g
s
.43098 .48691 m .44069 .5007 L p .42419 .47879 L 0 0 .499 r
F P
0 g
s
.41824 .47089 m .43098 .48691 L p .42419 .47879 L 0 0 .499 r
F P
0 g
s
.43098 .48691 m .42753 .47199 L p .43887 .49636 L 0 .037 .606 r
F P
0 g
s
.44069 .5007 m .43098 .48691 L p .4457 .50908 L .643 .206 0 r
F P
0 g
s
.44917 .51025 m .44247 .52145 L .40944 .50632 L p .753 .725 .826 r
F P
0 g
s
.4521 .51872 m .44069 .5007 L p .4457 .50908 L .643 .206 0 r
F P
0 g
s
.46518 .52881 m .45588 .51247 L .44069 .5007 L p .817 .336 0 r
F P
0 g
s
.44069 .5007 m .4521 .51872 L .46518 .52881 L p .817 .336 0 r
F P
0 g
s
.4438 .50694 m .4521 .51872 L p .43442 .49209 L .643 .206 0 r
F P
0 g
s
.43098 .48691 m .4438 .50694 L p .43442 .49209 L .643 .206 0 r
F P
0 g
s
.46236 .50453 m .43747 .49296 L p .45053 .50022 L .575 0 0 r
F P
0 g
s
.43747 .49296 m .44666 .50012 L .4689 .51044 L p .575 0 0 r
F P
0 g
s
.46369 .539 m .4521 .51872 L .4438 .50694 L p .698 .265 0 r
F P
0 g
s
.4438 .50694 m .44092 .49421 L p .454 .5231 L 0 0 .564 r
F P
0 g
s
.4438 .50694 m .45677 .52921 L .46369 .539 L p .698 .265 0 r
F P
0 g
s
.45677 .52921 m .4438 .50694 L p .454 .5231 L 0 0 .564 r
F P
0 g
s
.4438 .50694 m .43098 .48691 L p .43887 .49636 L 0 .037 .606 r
F P
0 g
s
.42936 .48667 m .41805 .47786 L p .41543 .47117 L 0 .238 .75 r
F P
0 g
s
.4689 .51044 m .46236 .50453 L p .45053 .50022 L .575 0 0 r
F P
0 g
s
.49109 .51194 m .46236 .50453 L p .47574 .50973 L .583 .024 0 r
F P
0 g
s
.49462 .51705 m .49109 .51194 L p .47574 .50973 L .583 .024 0 r
F P
0 g
s
.52188 .51478 m .49109 .51194 L p .50398 .51511 L .524 0 0 r
F P
0 g
s
.52154 .51576 m .52188 .51478 L p .53495 .51454 L .191 .719 .843 r
F P
0 g
s
.55285 .51291 m .55574 .5137 L .52154 .51576 L p .191 .719 .843 r
F P
0 g
s
.52221 .5196 m .52188 .51478 L p .50398 .51511 L .524 0 0 r
F P
0 g
s
.52188 .51478 m .55285 .51291 L p .53495 .51454 L .191 .719 .843 r
F P
0 g
s
.39983 .52082 m .40944 .50632 L .44247 .52145 L p .79 .702 .768 r
F P
0 g
s
.55574 .5137 m .55285 .51291 L .58216 .50643 L p .339 .818 .873 r
F P
0 g
s
.58216 .50643 m .58812 .50654 L .55574 .5137 L p .339 .818 .873 r
F P
0 g
s
.59413 .51254 m .58812 .50654 L .61671 .49466 L p .661 .772 .932 r
F P
0 g
s
.61671 .49466 m .62552 .49956 L .59413 .51254 L p .661 .772 .932 r
F P
0 g
s
.79464 .57831 m .78487 .58542 L .82468 .54403 L p .645 .944 .709 r
F P
0 g
s
.82468 .54403 m .83625 .53514 L .79464 .57831 L p .645 .944 .709 r
F P
0 g
s
.26614 .58397 m .2768 .58827 L .32414 .62071 L p 0 .442 .852 r
F P
0 g
s
.33287 .62013 m .32414 .62071 L .2768 .58827 L p .386 .673 .973 r
F P
0 g
s
.70656 .62564 m .69806 .62061 L .74319 .59241 L p .655 .761 .928 r
F P
0 g
s
.74319 .59241 m .75411 .59612 L .70656 .62564 L p .655 .761 .928 r
F P
0 g
s
.58812 .50654 m .58216 .50643 L .60799 .49568 L p .513 .91 .915 r
F P
0 g
s
.60799 .49568 m .61671 .49466 L .58812 .50654 L p .513 .91 .915 r
F P
0 g
s
.69806 .62061 m .68928 .61112 L .73194 .58422 L p .609 .632 .849 r
F P
0 g
s
.73194 .58422 m .74319 .59241 L .69806 .62061 L p .609 .632 .849 r
F P
0 g
s
.2768 .58827 m .2878 .58911 L .33287 .62013 L p .386 .673 .973 r
F P
0 g
s
.34191 .61534 m .33287 .62013 L .2878 .58911 L p .646 .754 .928 r
F P
0 g
s
.65267 .54245 m .6435 .52464 L .67357 .50429 L p .548 .497 .751 r
F P
0 g
s
.6435 .52464 m .63444 .50988 L .66209 .49095 L p .568 .537 .78 r
F P
0 g
s
.66209 .49095 m .67357 .50429 L .6435 .52464 L p .568 .537 .78 r
F P
0 g
s
.52188 .51478 m .52221 .5196 L .54997 .51793 L p .42 0 0 r
F P
0 g
s
.54997 .51793 m .55285 .51291 L .52188 .51478 L p .42 0 0 r
F P
0 g
s
.25577 .57741 m .24558 .56996 L .20758 .52532 L p 0 .242 .742 r
F P
0 g
s
.63444 .50988 m .62552 .49956 L .65079 .48208 L p .606 .618 .837 r
F P
0 g
s
.65079 .48208 m .66209 .49095 L .63444 .50988 L p .606 .618 .837 r
F P
0 g
s
.6619 .56166 m .65267 .54245 L .68522 .52073 L p .541 .482 .74 r
F P
0 g
s
.67357 .50429 m .68522 .52073 L .65267 .54245 L p .548 .497 .751 r
F P
0 g
s
.78487 .58542 m .77491 .59164 L .81292 .55204 L p .682 .971 .775 r
F P
0 g
s
.81292 .55204 m .82468 .54403 L .78487 .58542 L p .682 .971 .775 r
F P
0 g
s
.55285 .51291 m .54997 .51793 L .57622 .51213 L p .26 0 0 r
F P
0 g
s
.57622 .51213 m .58216 .50643 L .55285 .51291 L p .26 0 0 r
F P
0 g
s
.67113 .58054 m .6619 .56166 L .69696 .53862 L p .542 .486 .743 r
F P
0 g
s
.68522 .52073 m .69696 .53862 L .6619 .56166 L p .541 .482 .74 r
F P
0 g
s
.68928 .61112 m .68028 .59747 L .72043 .57185 L p .575 .553 .793 r
F P
0 g
s
.72043 .57185 m .73194 .58422 L .68928 .61112 L p .575 .553 .793 r
F P
0 g
s
.49109 .51194 m .49462 .51705 L .52221 .5196 L p .524 0 0 r
F P
0 g
s
.68028 .59747 m .67113 .58054 L .70873 .55621 L p .553 .508 .759 r
F P
0 g
s
.69696 .53862 m .70873 .55621 L .67113 .58054 L p .542 .486 .743 r
F P
0 g
s
.35941 .51561 m .37149 .4995 L .39983 .52082 L p .839 .74 .755 r
F P
0 g
s
.39983 .52082 m .39011 .53837 L .35941 .51561 L p .839 .74 .755 r
F P
0 g
s
.40944 .50632 m .39983 .52082 L .37149 .4995 L p .819 .747 .784 r
F P
0 g
s
.62552 .49956 m .61671 .49466 L .63967 .47868 L p .668 .773 .928 r
F P
0 g
s
.63967 .47868 m .65079 .48208 L .62552 .49956 L p .668 .773 .928 r
F P
0 g
s
.70873 .55621 m .72043 .57185 L .68028 .59747 L p .553 .508 .759 r
F P
0 g
s
.37149 .4995 m .38341 .48649 L .40944 .50632 L p .819 .747 .784 r
F P
0 g
s
.4189 .49627 m .40944 .50632 L .38341 .48649 L p .769 .755 .84 r
F P
0 g
s
.2878 .58911 m .29916 .58572 L .34191 .61534 L p .646 .754 .928 r
F P
0 g
s
.35123 .60609 m .34191 .61534 L .29916 .58572 L p .761 .76 .852 r
F P
0 g
s
.34721 .53318 m .35941 .51561 L .39011 .53837 L p .846 .737 .743 r
F P
0 g
s
.39011 .53837 m .38031 .55734 L .34721 .53318 L p .846 .737 .743 r
F P
0 g
s
.33498 .55045 m .34721 .53318 L .38031 .55734 L p .845 .738 .746 r
F P
0 g
s
.38031 .55734 m .37051 .57598 L .33498 .55045 L p .845 .738 .746 r
F P
0 g
s
.38341 .48649 m .39512 .47797 L .4189 .49627 L p .769 .755 .84 r
F P
0 g
s
.42823 .49165 m .4189 .49627 L .39512 .47797 L p .631 .742 .927 r
F P
0 g
s
.29916 .58572 m .31086 .57784 L .35123 .60609 L p .761 .76 .852 r
F P
0 g
s
.36079 .59268 m .35123 .60609 L .31086 .57784 L p .811 .751 .797 r
F P
0 g
s
.58216 .50643 m .57622 .51213 L .59931 .50254 L p .011 0 0 r
F P
0 g
s
.59931 .50254 m .60799 .49568 L .58216 .50643 L p .011 0 0 r
F P
0 g
s
.32283 .56579 m .33498 .55045 L .37051 .57598 L p .834 .743 .763 r
F P
0 g
s
.37051 .57598 m .36079 .59268 L .32283 .56579 L p .834 .743 .763 r
F P
0 g
s
.31086 .57784 m .32283 .56579 L .36079 .59268 L p .811 .751 .797 r
F P
0 g
s
.20758 .52532 m .21945 .53464 L .25577 .57741 L p 0 .242 .742 r
F P
0 g
s
.26614 .58397 m .25577 .57741 L .21945 .53464 L p 0 .317 .799 r
F P
0 g
s
.61671 .49466 m .60799 .49568 L .62867 .48124 L p .668 .96 .939 r
F P
0 g
s
.62867 .48124 m .63967 .47868 L .61671 .49466 L p .668 .96 .939 r
F P
0 g
s
.46236 .50453 m .4689 .51044 L .49462 .51705 L p .583 .024 0 r
F P
0 g
s
.77491 .59164 m .76468 .5956 L .80085 .55775 L p .734 .987 .895 r
F P
0 g
s
.80085 .55775 m .81292 .55204 L .77491 .59164 L p .734 .987 .895 r
F P
0 g
s
.39512 .47797 m .40665 .47493 L .42823 .49165 L p .631 .742 .927 r
F P
0 g
s
.52255 .52956 m .52221 .5196 L .49462 .51705 L p .641 .201 .189 r
F P
0 g
s
.52221 .5196 m .52255 .52956 L .54708 .5281 L p .549 .127 .193 r
F P
0 g
s
.54708 .5281 m .54997 .51793 L .52221 .5196 L p .549 .127 .193 r
F P
0 g
s
.54997 .51793 m .54708 .5281 L .57025 .52301 L p .423 .014 .156 r
F P
0 g
s
.57025 .52301 m .57622 .51213 L .54997 .51793 L p .423 .014 .156 r
F P
0 g
s
.49817 .52733 m .49462 .51705 L .4689 .51044 L p .714 .248 .142 r
F P
0 g
s
.49462 .51705 m .49817 .52733 L .52255 .52956 L p .641 .201 .189 r
F P
0 g
s
.21945 .53464 m .23152 .54306 L .26614 .58397 L p 0 .317 .799 r
F P
0 g
s
.2768 .58827 m .26614 .58397 L .23152 .54306 L p .142 .482 .899 r
F P
0 g
s
.76468 .5956 m .75411 .59612 L .78842 .55998 L p .727 .908 .958 r
F P
0 g
s
.78842 .55998 m .80085 .55775 L .76468 .5956 L p .727 .908 .958 r
F P
0 g
s
.60799 .49568 m .59931 .50254 L .61775 .48968 L p 0 0 0 r
F P
0 g
s
.61775 .48968 m .62867 .48124 L .60799 .49568 L p 0 0 0 r
F P
0 g
s
.67357 .50429 m .66209 .49095 L .68122 .46814 L p .512 .521 .802 r
F P
0 g
s
.66209 .49095 m .65079 .48208 L .66819 .46107 L p .575 .614 .854 r
F P
0 g
s
.66819 .46107 m .68122 .46814 L .66209 .49095 L p .575 .614 .854 r
F P
0 g
s
.68522 .52073 m .67357 .50429 L .6945 .47974 L p .479 .472 .772 r
F P
0 g
s
.68122 .46814 m .6945 .47974 L .67357 .50429 L p .512 .521 .802 r
F P
0 g
s
.65079 .48208 m .63967 .47868 L .65539 .45952 L p .674 .771 .924 r
F P
0 g
s
.65539 .45952 m .66819 .46107 L .65079 .48208 L p .674 .771 .924 r
F P
0 g
s
.57622 .51213 m .57025 .52301 L .59061 .5146 L p .233 0 .061 r
F P
0 g
s
.59061 .5146 m .59931 .50254 L .57622 .51213 L p .233 0 .061 r
F P
0 g
s
.69696 .53862 m .68522 .52073 L .70799 .49447 L p .466 .453 .759 r
F P
0 g
s
.6945 .47974 m .70799 .49447 L .68522 .52073 L p .479 .472 .772 r
F P
0 g
s
.47547 .52153 m .4689 .51044 L .44666 .50012 L p .761 .262 .03 r
F P
0 g
s
.4689 .51044 m .47547 .52153 L .49817 .52733 L p .714 .248 .142 r
F P
0 g
s
.3527 .47423 m .36625 .46303 L .38341 .48649 L p .845 .8 .807 r
F P
0 g
s
.38341 .48649 m .37149 .4995 L .3527 .47423 L p .845 .8 .807 r
F P
0 g
s
.39512 .47797 m .38341 .48649 L .36625 .46303 L p .781 .788 .859 r
F P
0 g
s
.75411 .59612 m .74319 .59241 L .7756 .55796 L p .656 .761 .927 r
F P
0 g
s
.7756 .55796 m .78842 .55998 L .75411 .59612 L p .656 .761 .927 r
F P
0 g
s
.33893 .48858 m .3527 .47423 L .37149 .4995 L p .873 .802 .777 r
F P
0 g
s
.37149 .4995 m .35941 .51561 L .33893 .48858 L p .873 .802 .777 r
F P
0 g
s
.36625 .46303 m .37955 .45637 L .39512 .47797 L p .781 .788 .859 r
F P
0 g
s
.40665 .47493 m .39512 .47797 L .37955 .45637 L p .632 .736 .923 r
F P
0 g
s
.63967 .47868 m .62867 .48124 L .64276 .46396 L p .77 .957 .932 r
F P
0 g
s
.64276 .46396 m .65539 .45952 L .63967 .47868 L p .77 .957 .932 r
F P
0 g
s
.70873 .55621 m .69696 .53862 L .72163 .5107 L p .469 .457 .763 r
F P
0 g
s
.70799 .49447 m .72163 .5107 L .69696 .53862 L p .466 .453 .759 r
F P
0 g
s
.23152 .54306 m .24389 .54917 L .2768 .58827 L p .142 .482 .899 r
F P
0 g
s
.2878 .58911 m .2768 .58827 L .24389 .54917 L p .429 .652 .953 r
F P
0 g
s
.32499 .50442 m .33893 .48858 L .35941 .51561 L p .883 .802 .764 r
F P
0 g
s
.35941 .51561 m .34721 .53318 L .32499 .50442 L p .883 .802 .764 r
F P
0 g
s
.72043 .57185 m .70873 .55621 L .73532 .52665 L p .488 .485 .78 r
F P
0 g
s
.72163 .5107 m .73532 .52665 L .70873 .55621 L p .469 .457 .763 r
F P
0 g
s
.74319 .59241 m .73194 .58422 L .76243 .55141 L p .58 .63 .866 r
F P
0 g
s
.76243 .55141 m .7756 .55796 L .74319 .59241 L p .58 .63 .866 r
F P
0 g
s
.37955 .45637 m .39261 .45524 L .40665 .47493 L p .632 .736 .923 r
F P
0 g
s
.41805 .47786 m .40665 .47493 L .39261 .45524 L p .31 .564 .928 r
F P
0 g
s
.73194 .58422 m .72043 .57185 L .74896 .54067 L p .523 .54 .814 r
F P
0 g
s
.73532 .52665 m .74896 .54067 L .72043 .57185 L p .488 .485 .78 r
F P
0 g
s
.74896 .54067 m .76243 .55141 L .73194 .58422 L p .523 .54 .814 r
F P
0 g
s
.52289 .54348 m .52255 .52956 L .49817 .52733 L p .672 .271 .278 r
F P
0 g
s
.52255 .52956 m .52289 .54348 L .54415 .54222 L p .585 .201 .281 r
F P
0 g
s
.54415 .54222 m .54708 .5281 L .52255 .52956 L p .585 .201 .281 r
F P
0 g
s
.59931 .50254 m .59061 .5146 L .60681 .50334 L p 0 0 0 r
F P
0 g
s
.60681 .50334 m .61775 .48968 L .59931 .50254 L p 0 0 0 r
F P
0 g
s
.31098 .52 m .32499 .50442 L .34721 .53318 L p .881 .802 .767 r
F P
0 g
s
.34721 .53318 m .33498 .55045 L .31098 .52 L p .881 .802 .767 r
F P
0 g
s
.24389 .54917 m .25663 .55181 L .2878 .58911 L p .429 .652 .953 r
F P
0 g
s
.29916 .58572 m .2878 .58911 L .25663 .55181 L p .646 .752 .926 r
F P
0 g
s
.54708 .5281 m .54415 .54222 L .56422 .53785 L p .472 .101 .253 r
F P
0 g
s
.56422 .53785 m .57025 .52301 L .54708 .5281 L p .472 .101 .253 r
F P
0 g
s
.62867 .48124 m .61775 .48968 L .63024 .47431 L p .71 .967 .721 r
F P
0 g
s
.63024 .47431 m .64276 .46396 L .62867 .48124 L p .71 .967 .721 r
F P
0 g
s
.50177 .54156 m .49817 .52733 L .47547 .52153 L p .745 .321 .243 r
F P
0 g
s
.49817 .52733 m .50177 .54156 L .52289 .54348 L p .672 .271 .278 r
F P
0 g
s
.44666 .50012 m .45588 .51247 L .47547 .52153 L p .761 .262 .03 r
F P
0 g
s
.29703 .53365 m .31098 .52 L .33498 .55045 L p .866 .802 .786 r
F P
0 g
s
.33498 .55045 m .32283 .56579 L .29703 .53365 L p .866 .802 .786 r
F P
0 g
s
.83625 .53514 m .82468 .54403 L .84629 .49686 L p .853 .997 .815 r
F P
0 g
s
.84629 .49686 m .85906 .48583 L .83625 .53514 L p .853 .997 .815 r
F P
0 g
s
.25663 .55181 m .26976 .55017 L .29916 .58572 L p .646 .752 .926 r
F P
0 g
s
.31086 .57784 m .29916 .58572 L .26976 .55017 L p .77 .79 .87 r
F P
0 g
s
.39261 .45524 m .40548 .4601 L .41805 .47786 L p .31 .564 .928 r
F P
0 g
s
.28326 .54401 m .29703 .53365 L .32283 .56579 L p .834 .801 .82 r
F P
0 g
s
.32283 .56579 m .31086 .57784 L .28326 .54401 L p .834 .801 .82 r
F P
0 g
s
.26976 .55017 m .28326 .54401 L .31086 .57784 L p .77 .79 .87 r
F P
0 g
s
.57025 .52301 m .56422 .53785 L .58181 .53063 L p .306 0 .181 r
F P
0 g
s
.58181 .53063 m .59061 .5146 L .57025 .52301 L p .306 0 .181 r
F P
0 g
s
.48211 .53657 m .47547 .52153 L .45588 .51247 L p .806 .351 .157 r
F P
0 g
s
.47547 .52153 m .48211 .53657 L .50177 .54156 L p .745 .321 .243 r
F P
0 g
s
.68122 .46814 m .66819 .46107 L .6763 .43777 L p .541 .617 .877 r
F P
0 g
s
.66819 .46107 m .65539 .45952 L .6626 .43831 L p .679 .768 .919 r
F P
0 g
s
.6626 .43831 m .6763 .43777 L .66819 .46107 L p .679 .768 .919 r
F P
0 g
s
.6945 .47974 m .68122 .46814 L .69027 .44279 L p .443 .508 .831 r
F P
0 g
s
.6763 .43777 m .69027 .44279 L .68122 .46814 L p .541 .617 .877 r
F P
0 g
s
.82468 .54403 m .81292 .55204 L .83334 .50698 L p .85 .992 .844 r
F P
0 g
s
.83334 .50698 m .84629 .49686 L .82468 .54403 L p .85 .992 .844 r
F P
0 g
s
.61775 .48968 m .60681 .50334 L .61773 .4899 L p 0 0 0 r
F P
0 g
s
.61773 .4899 m .63024 .47431 L .61775 .48968 L p 0 0 0 r
F P
0 g
s
.65539 .45952 m .64276 .46396 L .64913 .44487 L p .817 .917 .905 r
F P
0 g
s
.64913 .44487 m .6626 .43831 L .65539 .45952 L p .817 .917 .905 r
F P
0 g
s
.70799 .49447 m .6945 .47974 L .70453 .45238 L p .386 .444 .799 r
F P
0 g
s
.69027 .44279 m .70453 .45238 L .6945 .47974 L p .443 .508 .831 r
F P
0 g
s
.21945 .53464 m .20758 .52532 L .18911 .47507 L p .094 .353 .822 r
F P
0 g
s
.35946 .43735 m .37351 .43278 L .37955 .45637 L p .785 .823 .882 r
F P
0 g
s
.37955 .45637 m .36625 .46303 L .35946 .43735 L p .785 .823 .882 r
F P
0 g
s
.39261 .45524 m .37955 .45637 L .37351 .43278 L p .635 .731 .917 r
F P
0 g
s
.59061 .5146 m .58181 .53063 L .59578 .52098 L p .029 0 .026 r
F P
0 g
s
.59578 .52098 m .60681 .50334 L .59061 .5146 L p .029 0 .026 r
F P
0 g
s
.34511 .4465 m .35946 .43735 L .36625 .46303 L p .863 .862 .837 r
F P
0 g
s
.36625 .46303 m .3527 .47423 L .34511 .4465 L p .863 .862 .837 r
F P
0 g
s
.40548 .4601 m .41824 .47089 L .42936 .48667 L p 0 .238 .75 r
F P
0 g
s
.45588 .51247 m .46518 .52881 L .48211 .53657 L p .806 .351 .157 r
F P
0 g
s
.37351 .43278 m .38728 .43377 L .39261 .45524 L p .635 .731 .917 r
F P
0 g
s
.40548 .4601 m .39261 .45524 L .38728 .43377 L p .397 .56 .898 r
F P
0 g
s
.72163 .5107 m .70799 .49447 L .71906 .46515 L p .363 .419 .785 r
F P
0 g
s
.70453 .45238 m .71906 .46515 L .70799 .49447 L p .386 .444 .799 r
F P
0 g
s
.33048 .45884 m .34511 .4465 L .3527 .47423 L p .899 .876 .805 r
F P
0 g
s
.3527 .47423 m .33893 .48858 L .33048 .45884 L p .899 .876 .805 r
F P
0 g
s
.64276 .46396 m .63024 .47431 L .6358 .45738 L p .886 .987 .804 r
F P
0 g
s
.6358 .45738 m .64913 .44487 L .64276 .46396 L p .886 .987 .804 r
F P
0 g
s
.52324 .55963 m .52289 .54348 L .50177 .54156 L p .681 .295 .308 r
F P
0 g
s
.52289 .54348 m .52324 .55963 L .54117 .55857 L p .596 .226 .311 r
F P
0 g
s
.54117 .55857 m .54415 .54222 L .52289 .54348 L p .596 .226 .311 r
F P
0 g
s
.81292 .55204 m .80085 .55775 L .82009 .51478 L p .827 .962 .897 r
F P
0 g
s
.82009 .51478 m .83334 .50698 L .81292 .55204 L p .827 .962 .897 r
F P
0 g
s
.54415 .54222 m .54117 .55857 L .55807 .55493 L p .488 .131 .286 r
F P
0 g
s
.55807 .55493 m .56422 .53785 L .54415 .54222 L p .488 .131 .286 r
F P
0 g
s
.50543 .55803 m .50177 .54156 L .48211 .53657 L p .754 .346 .277 r
F P
0 g
s
.50177 .54156 m .50543 .55803 L .52324 .55963 L p .681 .295 .308 r
F P
0 g
s
.18911 .47507 m .20203 .48658 L .21945 .53464 L p .094 .353 .822 r
F P
0 g
s
.23152 .54306 m .21945 .53464 L .20203 .48658 L p .153 .4 .846 r
F P
0 g
s
.38728 .43377 m .40081 .4408 L .40548 .4601 L p .397 .56 .898 r
F P
0 g
s
.41824 .47089 m .40548 .4601 L .40081 .4408 L p .126 .343 .807 r
F P
0 g
s
.73532 .52665 m .72163 .5107 L .73379 .47944 L p .369 .425 .788 r
F P
0 g
s
.71906 .46515 m .73379 .47944 L .72163 .5107 L p .363 .419 .785 r
F P
0 g
s
.31564 .47271 m .33048 .45884 L .33893 .48858 L p .912 .88 .79 r
F P
0 g
s
.33893 .48858 m .32499 .50442 L .31564 .47271 L p .912 .88 .79 r
F P
0 g
s
.56422 .53785 m .55807 .55493 L .57287 .54891 L p .331 0 .221 r
F P
0 g
s
.57287 .54891 m .58181 .53063 L .56422 .53785 L p .331 0 .221 r
F P
0 g
s
.48888 .55386 m .48211 .53657 L .46518 .52881 L p .818 .38 .2 r
F P
0 g
s
.48211 .53657 m .48888 .55386 L .50543 .55803 L p .754 .346 .277 r
F P
0 g
s
.60681 .50334 m .59578 .52098 L .60514 .50949 L p 0 0 0 r
F P
0 g
s
.60514 .50949 m .61773 .4899 L .60681 .50334 L p 0 0 0 r
F P
0 g
s
.80085 .55775 m .78842 .55998 L .80646 .51905 L p .761 .883 .933 r
F P
0 g
s
.80646 .51905 m .82009 .51478 L .80085 .55775 L p .761 .883 .933 r
F P
0 g
s
.74896 .54067 m .73532 .52665 L .74862 .49348 L p .401 .462 .808 r
F P
0 g
s
.73379 .47944 m .74862 .49348 L .73532 .52665 L p .369 .425 .788 r
F P
0 g
s
.63024 .47431 m .61773 .4899 L .62252 .47513 L p .881 .975 .669 r
F P
0 g
s
.62252 .47513 m .6358 .45738 L .63024 .47431 L p .881 .975 .669 r
F P
0 g
s
.30069 .48632 m .31564 .47271 L .32499 .50442 L p .909 .879 .794 r
F P
0 g
s
.32499 .50442 m .31098 .52 L .30069 .48632 L p .909 .879 .794 r
F P
0 g
s
.20203 .48658 m .21513 .49717 L .23152 .54306 L p .153 .4 .846 r
F P
0 g
s
.24389 .54917 m .23152 .54306 L .21513 .49717 L p .291 .506 .892 r
F P
0 g
s
.78842 .55998 m .7756 .55796 L .79244 .51902 L p .658 .76 .926 r
F P
0 g
s
.79244 .51902 m .80646 .51905 L .78842 .55998 L p .658 .76 .926 r
F P
0 g
s
.40081 .4408 m .4142 .45377 L .41824 .47089 L p .126 .343 .807 r
F P
0 g
s
.43098 .48691 m .41824 .47089 L .4142 .45377 L p 0 .156 .693 r
F P
0 g
s
.76243 .55141 m .74896 .54067 L .76342 .5056 L p .461 .531 .843 r
F P
0 g
s
.74862 .49348 m .76342 .5056 L .74896 .54067 L p .401 .462 .808 r
F P
0 g
s
.58181 .53063 m .57287 .54891 L .58458 .54087 L p .068 0 .081 r
F P
0 g
s
.58458 .54087 m .59578 .52098 L .58181 .53063 L p .068 0 .081 r
F P
0 g
s
.69027 .44279 m .6763 .43777 L .67419 .41367 L p .505 .626 .904 r
F P
0 g
s
.6763 .43777 m .6626 .43831 L .66052 .41642 L p .682 .764 .913 r
F P
0 g
s
.66052 .41642 m .67419 .41367 L .6763 .43777 L p .682 .764 .913 r
F P
0 g
s
.7756 .55796 m .76243 .55141 L .77807 .51442 L p .549 .633 .887 r
F P
0 g
s
.77807 .51442 m .79244 .51902 L .7756 .55796 L p .549 .633 .887 r
F P
0 g
s
.6626 .43831 m .64913 .44487 L .64711 .42523 L p .828 .865 .873 r
F P
0 g
s
.64711 .42523 m .66052 .41642 L .6626 .43831 L p .828 .865 .873 r
F P
0 g
s
.76342 .5056 m .77807 .51442 L .76243 .55141 L p .461 .531 .843 r
F P
0 g
s
.47464 .54739 m .46518 .52881 L .4521 .51872 L p .843 .377 .037 r
F P
0 g
s
.46518 .52881 m .47464 .54739 L .48888 .55386 L p .818 .38 .2 r
F P
0 g
s
.28576 .49802 m .30069 .48632 L .31098 .52 L p .889 .873 .815 r
F P
0 g
s
.31098 .52 m .29703 .53365 L .28576 .49802 L p .889 .873 .815 r
F P
0 g
s
.70453 .45238 m .69027 .44279 L .68817 .4165 L p .352 .497 .864 r
F P
0 g
s
.67419 .41367 m .68817 .4165 L .69027 .44279 L p .505 .626 .904 r
F P
0 g
s
.21513 .49717 m .22853 .50543 L .24389 .54917 L p .291 .506 .892 r
F P
0 g
s
.25663 .55181 m .24389 .54917 L .22853 .50543 L p .474 .638 .927 r
F P
0 g
s
.64913 .44487 m .6358 .45738 L .63387 .43999 L p .916 .912 .801 r
F P
0 g
s
.63387 .43999 m .64711 .42523 L .64913 .44487 L p .916 .912 .801 r
F P
0 g
s
.36394 .41109 m .37779 .40872 L .37351 .43278 L p .777 .857 .91 r
F P
0 g
s
.37351 .43278 m .35946 .43735 L .36394 .41109 L p .777 .857 .91 r
F P
0 g
s
.38728 .43377 m .37351 .43278 L .37779 .40872 L p .638 .727 .912 r
F P
0 g
s
.37779 .40872 m .39133 .41193 L .38728 .43377 L p .638 .727 .912 r
F P
0 g
s
.40081 .4408 m .38728 .43377 L .39133 .41193 L p .469 .561 .866 r
F P
0 g
s
.27098 .50641 m .28576 .49802 L .29703 .53365 L p .848 .858 .849 r
F P
0 g
s
.29703 .53365 m .28326 .54401 L .27098 .50641 L p .848 .858 .849 r
F P
0 g
s
.5236 .57592 m .52324 .55963 L .50543 .55803 L p .68 .292 .305 r
F P
0 g
s
.52324 .55963 m .5236 .57592 L .53811 .57508 L p .595 .223 .308 r
F P
0 g
s
.53811 .57508 m .54117 .55857 L .52324 .55963 L p .595 .223 .308 r
F P
0 g
s
.22853 .50543 m .2423 .51017 L .25663 .55181 L p .474 .638 .927 r
F P
0 g
s
.26976 .55017 m .25663 .55181 L .2423 .51017 L p .647 .751 .925 r
F P
0 g
s
.61773 .4899 m .60514 .50949 L .60918 .49689 L p .852 .938 .567 r
F P
0 g
s
.60918 .49689 m .62252 .47513 L .61773 .4899 L p .852 .938 .567 r
F P
0 g
s
.71906 .46515 m .70453 .45238 L .70248 .42394 L p .253 .411 .827 r
F P
0 g
s
.68817 .4165 m .70248 .42394 L .70453 .45238 L p .352 .497 .864 r
F P
0 g
s
.54117 .55857 m .53811 .57508 L .55178 .57215 L p .486 .127 .282 r
F P
0 g
s
.55178 .57215 m .55807 .55493 L .54117 .55857 L p .486 .127 .282 r
F P
0 g
s
.34975 .41808 m .36394 .41109 L .35946 .43735 L p .859 .927 .871 r
F P
0 g
s
.35946 .43735 m .34511 .4465 L .34975 .41808 L p .859 .927 .871 r
F P
0 g
s
.50918 .57464 m .50543 .55803 L .48888 .55386 L p .753 .343 .273 r
F P
0 g
s
.50543 .55803 m .50918 .57464 L .5236 .57592 L p .68 .292 .305 r
F P
0 g
s
.25646 .51058 m .27098 .50641 L .28326 .54401 L p .772 .822 .892 r
F P
0 g
s
.28326 .54401 m .26976 .55017 L .25646 .51058 L p .772 .822 .892 r
F P
0 g
s
.39133 .41193 m .40461 .42121 L .40081 .4408 L p .469 .561 .866 r
F P
0 g
s
.4142 .45377 m .40081 .4408 L .40461 .42121 L p .316 .406 .796 r
F P
0 g
s
.2423 .51017 m .25646 .51058 L .26976 .55017 L p .647 .751 .925 r
F P
0 g
s
.59578 .52098 m .58458 .54087 L .59238 .53133 L p 0 0 0 r
F P
0 g
s
.59238 .53133 m .60514 .50949 L .59578 .52098 L p 0 0 0 r
F P
0 g
s
.4142 .45377 m .42753 .47199 L .43098 .48691 L p 0 .156 .693 r
F P
0 g
s
.4521 .51872 m .46369 .539 L .47464 .54739 L p .843 .377 .037 r
F P
0 g
s
.55807 .55493 m .55178 .57215 L .56373 .56734 L p .328 0 .217 r
F P
0 g
s
.56373 .56734 m .57287 .54891 L .55807 .55493 L p .328 0 .217 r
F P
0 g
s
.6358 .45738 m .62252 .47513 L .6207 .46 L p .956 .924 .731 r
F P
0 g
s
.6207 .46 m .63387 .43999 L .6358 .45738 L p .956 .924 .731 r
F P
0 g
s
.49579 .5713 m .48888 .55386 L .47464 .54739 L p .817 .377 .195 r
F P
0 g
s
.48888 .55386 m .49579 .5713 L .50918 .57464 L p .753 .343 .273 r
F P
0 g
s
.33525 .42828 m .34975 .41808 L .34511 .4465 L p .896 .955 .831 r
F P
0 g
s
.34511 .4465 m .33048 .45884 L .33525 .42828 L p .896 .955 .831 r
F P
0 g
s
.73379 .47944 m .71906 .46515 L .71709 .43459 L p .211 .373 .808 r
F P
0 g
s
.70248 .42394 m .71709 .43459 L .71906 .46515 L p .253 .411 .827 r
F P
0 g
s
.40461 .42121 m .41772 .43643 L .4142 .45377 L p .316 .406 .796 r
F P
0 g
s
.42753 .47199 m .4142 .45377 L .41772 .43643 L p .205 .292 .733 r
F P
0 g
s
.57287 .54891 m .56373 .56734 L .57315 .56092 L p .064 0 .075 r
F P
0 g
s
.57315 .56092 m .58458 .54087 L .57287 .54891 L p .064 0 .075 r
F P
0 g
s
.48431 .56612 m .47464 .54739 L .46369 .539 L p .84 .373 .03 r
F P
0 g
s
.47464 .54739 m .48431 .56612 L .49579 .5713 L p .817 .377 .195 r
F P
0 g
s
.3205 .44003 m .33525 .42828 L .33048 .45884 L p .907 .963 .811 r
F P
0 g
s
.33048 .45884 m .31564 .47271 L .3205 .44003 L p .907 .963 .811 r
F P
0 g
s
.60514 .50949 m .59238 .53133 L .5957 .52088 L p .834 .916 .518 r
F P
0 g
s
.5957 .52088 m .60918 .49689 L .60514 .50949 L p .834 .916 .518 r
F P
0 g
s
.74862 .49348 m .73379 .47944 L .73194 .44679 L p .222 .383 .813 r
F P
0 g
s
.71709 .43459 m .73194 .44679 L .73379 .47944 L p .211 .373 .808 r
F P
0 g
s
.85906 .48583 m .84629 .49686 L .84669 .4466 L p .904 .934 .822 r
F P
0 g
s
.84669 .4466 m .85986 .43317 L .85906 .48583 L p .904 .934 .822 r
F P
0 g
s
.62252 .47513 m .60918 .49689 L .60752 .48401 L p .972 .922 .682 r
F P
0 g
s
.60752 .48401 m .6207 .46 L .62252 .47513 L p .972 .922 .682 r
F P
0 g
s
.67419 .41367 m .66052 .41642 L .64896 .39538 L p .683 .758 .909 r
F P
0 g
s
.66052 .41642 m .64711 .42523 L .63656 .40639 L p .82 .813 .844 r
F P
0 g
s
.63656 .40639 m .64896 .39538 L .66052 .41642 L p .82 .813 .844 r
F P
0 g
s
.68817 .4165 m .67419 .41367 L .66162 .39044 L p .47 .643 .932 r
F P
0 g
s
.64896 .39538 m .66162 .39044 L .67419 .41367 L p .683 .758 .909 r
F P
0 g
s
.42753 .47199 m .44092 .49421 L .4438 .50694 L p 0 .037 .606 r
F P
0 g
s
.64711 .42523 m .63387 .43999 L .62435 .42335 L p .892 .828 .777 r
F P
0 g
s
.62435 .42335 m .63656 .40639 L .64711 .42523 L p .892 .828 .777 r
F P
0 g
s
.41772 .43643 m .43074 .45691 L .42753 .47199 L p .205 .292 .733 r
F P
0 g
s
.44092 .49421 m .42753 .47199 L .43074 .45691 L p .139 .223 .689 r
F P
0 g
s
.58458 .54087 m .57315 .56092 L .5794 .55331 L p 0 0 0 r
F P
0 g
s
.5794 .55331 m .59238 .53133 L .58458 .54087 L p 0 0 0 r
F P
0 g
s
.3925 .38589 m .40483 .39126 L .39133 .41193 L p .643 .725 .908 r
F P
0 g
s
.39133 .41193 m .37779 .40872 L .3925 .38589 L p .643 .725 .908 r
F P
0 g
s
.40461 .42121 m .39133 .41193 L .40483 .39126 L p .527 .566 .838 r
F P
0 g
s
.52396 .59008 m .5236 .57592 L .50918 .57464 L p .667 .261 .265 r
F P
0 g
s
.5236 .57592 m .52396 .59008 L .53497 .58944 L p .58 .19 .268 r
F P
0 g
s
.53497 .58944 m .53811 .57508 L .5236 .57592 L p .58 .19 .268 r
F P
0 g
s
.40483 .39126 m .41689 .40271 L .40461 .42121 L p .527 .566 .838 r
F P
0 g
s
.41772 .43643 m .40461 .42121 L .41689 .40271 L p .439 .449 .772 r
F P
0 g
s
.84629 .49686 m .83334 .50698 L .83336 .45908 L p .891 .926 .838 r
F P
0 g
s
.83336 .45908 m .84669 .4466 L .84629 .49686 L p .891 .926 .838 r
F P
0 g
s
.30561 .45155 m .3205 .44003 L .31564 .47271 L p .905 .961 .816 r
F P
0 g
s
.31564 .47271 m .30069 .48632 L .30561 .45155 L p .905 .961 .816 r
F P
0 g
s
.70248 .42394 m .68817 .4165 L .6746 .3911 L p .234 .488 .893 r
F P
0 g
s
.66162 .39044 m .6746 .3911 L .68817 .4165 L p .47 .643 .932 r
F P
0 g
s
.4755 .55942 m .46369 .539 L .45677 .52921 L p .692 .258 0 r
F P
0 g
s
.46369 .539 m .4755 .55942 L .48431 .56612 L p .84 .373 .03 r
F P
0 g
s
.37986 .38612 m .3925 .38589 L .37779 .40872 L p .754 .885 .938 r
F P
0 g
s
.37779 .40872 m .36394 .41109 L .37986 .38612 L p .754 .885 .938 r
F P
0 g
s
.53811 .57508 m .53497 .58944 L .54533 .58725 L p .465 .088 .239 r
F P
0 g
s
.54533 .58725 m .55178 .57215 L .53811 .57508 L p .465 .088 .239 r
F P
0 g
s
.76342 .5056 m .74862 .49348 L .74694 .45874 L p .281 .436 .839 r
F P
0 g
s
.73194 .44679 m .74694 .45874 L .74862 .49348 L p .222 .383 .813 r
F P
0 g
s
.51303 .58911 m .50918 .57464 L .49579 .5713 L p .741 .31 .228 r
F P
0 g
s
.50918 .57464 m .51303 .58911 L .52396 .59008 L p .667 .261 .265 r
F P
0 g
s
.63387 .43999 m .6207 .46 L .61224 .44556 L p .928 .829 .728 r
F P
0 g
s
.61224 .44556 m .62435 .42335 L .63387 .43999 L p .928 .829 .728 r
F P
0 g
s
.55178 .57215 m .54533 .58725 L .55437 .58363 L p .296 0 .163 r
F P
0 g
s
.55437 .58363 m .56373 .56734 L .55178 .57215 L p .296 0 .163 r
F P
0 g
s
.41689 .40271 m .42877 .4201 L .41772 .43643 L p .439 .449 .772 r
F P
0 g
s
.43074 .45691 m .41772 .43643 L .42877 .4201 L p .382 .373 .725 r
F P
0 g
s
.20203 .48658 m .18911 .47507 L .19318 .42214 L p .295 .42 .818 r
F P
0 g
s
.50289 .58661 m .49579 .5713 L .48431 .56612 L p .8 .338 .138 r
F P
0 g
s
.49579 .5713 m .50289 .58661 L .51303 .58911 L p .741 .31 .228 r
F P
0 g
s
.36688 .39098 m .37986 .38612 L .36394 .41109 L p .809 .978 .897 r
F P
0 g
s
.36394 .41109 m .34975 .41808 L .36688 .39098 L p .809 .978 .897 r
F P
0 g
s
.83334 .50698 m .82009 .51478 L .81976 .4692 L p .851 .902 .871 r
F P
0 g
s
.81976 .4692 m .83336 .45908 L .83334 .50698 L p .851 .902 .871 r
F P
0 g
s
.60918 .49689 m .5957 .52088 L .59422 .51023 L p .977 .919 .659 r
F P
0 g
s
.59422 .51023 m .60752 .48401 L .60918 .49689 L p .977 .919 .659 r
F P
0 g
s
.77807 .51442 m .76342 .5056 L .76194 .46877 L p .383 .527 .877 r
F P
0 g
s
.74694 .45874 m .76194 .46877 L .76342 .5056 L p .281 .436 .839 r
F P
0 g
s
.71709 .43459 m .70248 .42394 L .68791 .39639 L p .061 .362 .832 r
F P
0 g
s
.6746 .3911 m .68791 .39639 L .70248 .42394 L p .234 .488 .893 r
F P
0 g
s
.29069 .46113 m .30561 .45155 L .30069 .48632 L p .886 .949 .844 r
F P
0 g
s
.30069 .48632 m .28576 .49802 L .29069 .46113 L p .886 .949 .844 r
F P
0 g
s
.59238 .53133 m .5794 .55331 L .58201 .545 L p .836 .919 .524 r
F P
0 g
s
.58201 .545 m .5957 .52088 L .59238 .53133 L p .836 .919 .524 r
F P
0 g
s
.43074 .45691 m .44378 .48138 L .44092 .49421 L p .139 .223 .689 r
F P
0 g
s
.45444 .51867 m .44092 .49421 L .44378 .48138 L p .109 .192 .669 r
F P
0 g
s
.44092 .49421 m .45444 .51867 L .45677 .52921 L p 0 0 .564 r
F P
0 g
s
.56373 .56734 m .55437 .58363 L .56147 .57882 L p .013 0 .002 r
F P
0 g
s
.56147 .57882 m .57315 .56092 L .56373 .56734 L p .013 0 .002 r
F P
0 g
s
.6207 .46 m .60752 .48401 L .60014 .47174 L p .945 .826 .697 r
F P
0 g
s
.60014 .47174 m .61224 .44556 L .6207 .46 L p .945 .826 .697 r
F P
0 g
s
.49421 .58272 m .48431 .56612 L .4755 .55942 L p .805 .317 0 r
F P
0 g
s
.48431 .56612 m .49421 .58272 L .50289 .58661 L p .8 .338 .138 r
F P
0 g
s
.82009 .51478 m .80646 .51905 L .8058 .47574 L p .775 .849 .907 r
F P
0 g
s
.8058 .47574 m .81976 .4692 L .82009 .51478 L p .775 .849 .907 r
F P
0 g
s
.19318 .42214 m .20631 .43608 L .20203 .48658 L p .295 .42 .818 r
F P
0 g
s
.21513 .49717 m .20203 .48658 L .20631 .43608 L p .327 .45 .833 r
F P
0 g
s
.45677 .52921 m .46998 .55162 L .4755 .55942 L p .692 .258 0 r
F P
0 g
s
.46998 .55162 m .45677 .52921 L .45444 .51867 L p 0 0 .569 r
F P
0 g
s
.79244 .51902 m .77807 .51442 L .77683 .47547 L p .517 .643 .911 r
F P
0 g
s
.76194 .46877 m .77683 .47547 L .77807 .51442 L p .383 .527 .877 r
F P
0 g
s
.42877 .4201 m .44055 .44274 L .43074 .45691 L p .382 .373 .725 r
F P
0 g
s
.44378 .48138 m .43074 .45691 L .44055 .44274 L p .348 .329 .696 r
F P
0 g
s
.80646 .51905 m .79244 .51902 L .79148 .47792 L p .658 .759 .924 r
F P
0 g
s
.79148 .47792 m .8058 .47574 L .80646 .51905 L p .658 .759 .924 r
F P
0 g
s
.35358 .39907 m .36688 .39098 L .34975 .41808 L p .811 1 .826 r
F P
0 g
s
.34975 .41808 m .33525 .42828 L .35358 .39907 L p .811 1 .826 r
F P
0 g
s
.77683 .47547 m .79148 .47792 L .79244 .51902 L p .517 .643 .911 r
F P
0 g
s
.64896 .39538 m .63656 .40639 L .61798 .38973 L p .801 .765 .82 r
F P
0 g
s
.63656 .40639 m .62435 .42335 L .60773 .40867 L p .854 .758 .756 r
F P
0 g
s
.60773 .40867 m .61798 .38973 L .63656 .40639 L p .854 .758 .756 r
F P
0 g
s
.66162 .39044 m .64896 .39538 L .62842 .37674 L p .683 .752 .904 r
F P
0 g
s
.61798 .38973 m .62842 .37674 L .64896 .39538 L p .801 .765 .82 r
F P
0 g
s
.27589 .46738 m .29069 .46113 L .28576 .49802 L p .843 .917 .884 r
F P
0 g
s
.28576 .49802 m .27098 .50641 L .27589 .46738 L p .843 .917 .884 r
F P
0 g
s
.57315 .56092 m .56147 .57882 L .56615 .57313 L p 0 0 0 r
F P
0 g
s
.56615 .57313 m .5794 .55331 L .57315 .56092 L p 0 0 0 r
F P
0 g
s
.20631 .43608 m .2196 .44907 L .21513 .49717 L p .327 .45 .833 r
F P
0 g
s
.22853 .50543 m .21513 .49717 L .2196 .44907 L p .404 .523 .865 r
F P
0 g
s
.73194 .44679 m .71709 .43459 L .70155 .40492 L p 0 .303 .797 r
F P
0 g
s
.68791 .39639 m .70155 .40492 L .71709 .43459 L p .061 .362 .832 r
F P
0 g
s
.48757 .5777 m .4755 .55942 L .46998 .55162 L p .619 .181 0 r
F P
0 g
s
.4755 .55942 m .48757 .5777 L .49421 .58272 L p .805 .317 0 r
F P
0 g
s
.62435 .42335 m .61224 .44556 L .59757 .43284 L p .879 .748 .714 r
F P
0 g
s
.59757 .43284 m .60773 .40867 L .62435 .42335 L p .879 .748 .714 r
F P
0 g
s
.4271 .37331 m .43701 .38667 L .41689 .40271 L p .577 .577 .816 r
F P
0 g
s
.41689 .40271 m .40483 .39126 L .4271 .37331 L p .577 .577 .816 r
F P
0 g
s
.42877 .4201 m .41689 .40271 L .43701 .38667 L p .525 .483 .752 r
F P
0 g
s
.6746 .3911 m .66162 .39044 L .6391 .36982 L p .439 .668 .959 r
F P
0 g
s
.62842 .37674 m .6391 .36982 L .66162 .39044 L p .683 .752 .904 r
F P
0 g
s
.41694 .36602 m .4271 .37331 L .40483 .39126 L p .649 .724 .903 r
F P
0 g
s
.40483 .39126 m .3925 .38589 L .41694 .36602 L p .649 .724 .903 r
F P
0 g
s
.60752 .48401 m .59422 .51023 L .58796 .50011 L p .951 .824 .683 r
F P
0 g
s
.58796 .50011 m .60014 .47174 L .60752 .48401 L p .951 .824 .683 r
F P
0 g
s
.5957 .52088 m .58201 .545 L .58075 .53654 L p .976 .919 .662 r
F P
0 g
s
.58075 .53654 m .59422 .51023 L .5957 .52088 L p .976 .919 .662 r
F P
0 g
s
.26132 .46937 m .27589 .46738 L .27098 .50641 L p .763 .852 .917 r
F P
0 g
s
.27098 .50641 m .25646 .51058 L .26132 .46937 L p .763 .852 .917 r
F P
0 g
s
.52434 .59988 m .52396 .59008 L .51303 .58911 L p .626 .169 .149 r
F P
0 g
s
.52396 .59008 m .52434 .59988 L .53175 .59945 L p .532 .094 .153 r
F P
0 g
s
.53175 .59945 m .53497 .58944 L .52396 .59008 L p .532 .094 .153 r
F P
0 g
s
.2196 .44907 m .23316 .45969 L .22853 .50543 L p .404 .523 .865 r
F P
0 g
s
.2423 .51017 m .22853 .50543 L .23316 .45969 L p .518 .631 .902 r
F P
0 g
s
.53497 .58944 m .53175 .59945 L .53872 .59799 L p .402 0 .112 r
F P
0 g
s
.53872 .59799 m .54533 .58725 L .53497 .58944 L p .402 0 .112 r
F P
0 g
s
.43701 .38667 m .44676 .40598 L .42877 .4201 L p .525 .483 .752 r
F P
0 g
s
.44055 .44274 m .42877 .4201 L .44676 .40598 L p .493 .427 .711 r
F P
0 g
s
.51698 .59923 m .51303 .58911 L .50289 .58661 L p .697 .214 .097 r
F P
0 g
s
.51303 .58911 m .51698 .59923 L .52434 .59988 L p .626 .169 .149 r
F P
0 g
s
.44378 .48138 m .45692 .50806 L .45444 .51867 L p .109 .192 .669 r
F P
0 g
s
.46816 .54323 m .45444 .51867 L .45692 .50806 L p .113 .195 .672 r
F P
0 g
s
.45444 .51867 m .46816 .54323 L .46998 .55162 L p 0 0 .569 r
F P
0 g
s
.44055 .44274 m .45231 .46935 L .44378 .48138 L p .348 .329 .696 r
F P
0 g
s
.45692 .50806 m .44378 .48138 L .45231 .46935 L p .334 .31 .683 r
F P
0 g
s
.24706 .46672 m .26132 .46937 L .25646 .51058 L p .648 .75 .924 r
F P
0 g
s
.25646 .51058 m .2423 .51017 L .24706 .46672 L p .648 .75 .924 r
F P
0 g
s
.23316 .45969 m .24706 .46672 L .2423 .51017 L p .518 .631 .902 r
F P
0 g
s
.40651 .36434 m .41694 .36602 L .3925 .38589 L p .71 .9 .964 r
F P
0 g
s
.3925 .38589 m .37986 .38612 L .40651 .36434 L p .71 .9 .964 r
F P
0 g
s
.34003 .40872 m .35358 .39907 L .33525 .42828 L p .802 .997 .784 r
F P
0 g
s
.33525 .42828 m .3205 .44003 L .34003 .40872 L p .802 .997 .784 r
F P
0 g
s
.54533 .58725 m .53872 .59799 L .54479 .59557 L p .202 0 .008 r
F P
0 g
s
.54479 .59557 m .55437 .58363 L .54533 .58725 L p .202 0 .008 r
F P
0 g
s
.51016 .59756 m .50289 .58661 L .49421 .58272 L p .737 .221 0 r
F P
0 g
s
.50289 .58661 m .51016 .59756 L .51698 .59923 L p .697 .214 .097 r
F P
0 g
s
.61224 .44556 m .60014 .47174 L .58744 .46096 L p .891 .741 .689 r
F P
0 g
s
.58744 .46096 m .59757 .43284 L .61224 .44556 L p .891 .741 .689 r
F P
0 g
s
.5794 .55331 m .56615 .57313 L .56807 .56693 L p .857 .946 .585 r
F P
0 g
s
.56807 .56693 m .58201 .545 L .5794 .55331 L p .857 .946 .585 r
F P
0 g
s
.68791 .39639 m .6746 .3911 L .65007 .36851 L p .092 .477 .894 r
F P
0 g
s
.6391 .36982 m .65007 .36851 L .6746 .3911 L p .439 .668 .959 r
F P
0 g
s
.46998 .55162 m .48344 .57187 L .48757 .5777 L p .619 .181 0 r
F P
0 g
s
.48344 .57187 m .46998 .55162 L .46816 .54323 L p 0 .058 .622 r
F P
0 g
s
.74694 .45874 m .73194 .44679 L .71544 .41499 L p .004 .318 .807 r
F P
0 g
s
.70155 .40492 m .71544 .41499 L .73194 .44679 L p 0 .303 .797 r
F P
0 g
s
.44676 .40598 m .4564 .43051 L .44055 .44274 L p .493 .427 .711 r
F P
0 g
s
.45231 .46935 m .44055 .44274 L .4564 .43051 L p .476 .397 .688 r
F P
0 g
s
.55437 .58363 m .54479 .59557 L .54954 .59236 L p 0 0 0 r
F P
0 g
s
.54954 .59236 m .56147 .57882 L .55437 .58363 L p 0 0 0 r
F P
0 g
s
.50433 .59496 m .49421 .58272 L .48757 .5777 L p .687 .16 0 r
F P
0 g
s
.49421 .58272 m .50433 .59496 L .51016 .59756 L p .737 .221 0 r
F P
0 g
s
.39577 .36729 m .40651 .36434 L .37986 .38612 L p .676 .976 .888 r
F P
0 g
s
.37986 .38612 m .36688 .39098 L .39577 .36729 L p .676 .976 .888 r
F P
0 g
s
.59422 .51023 m .58075 .53654 L .57565 .52853 L p .951 .825 .684 r
F P
0 g
s
.57565 .52853 m .58796 .50011 L .59422 .51023 L p .951 .825 .684 r
F P
0 g
s
.62842 .37674 m .61798 .38973 L .59253 .37656 L p .777 .724 .803 r
F P
0 g
s
.61798 .38973 m .60773 .40867 L .58504 .39708 L p .814 .7 .74 r
F P
0 g
s
.58504 .39708 m .59253 .37656 L .61798 .38973 L p .814 .7 .74 r
F P
0 g
s
.60014 .47174 m .58796 .50011 L .57727 .49124 L p .895 .738 .679 r
F P
0 g
s
.57727 .49124 m .58744 .46096 L .60014 .47174 L p .895 .738 .679 r
F P
0 g
s
.56147 .57882 m .54954 .59236 L .55266 .58857 L p .574 .843 .495 r
F P
0 g
s
.55266 .58857 m .56615 .57313 L .56147 .57882 L p .574 .843 .495 r
F P
0 g
s
.60773 .40867 m .59757 .43284 L .57763 .42282 L p .83 .684 .702 r
F P
0 g
s
.57763 .42282 m .58504 .39708 L .60773 .40867 L p .83 .684 .702 r
F P
0 g
s
.6391 .36982 m .62842 .37674 L .60017 .36197 L p .681 .746 .901 r
F P
0 g
s
.59253 .37656 m .60017 .36197 L .62842 .37674 L p .777 .724 .803 r
F P
0 g
s
.45231 .46935 m .46414 .49814 L .45692 .50806 L p .334 .31 .683 r
F P
0 g
s
.47023 .53482 m .45692 .50806 L .46414 .49814 L p .336 .312 .684 r
F P
0 g
s
.45692 .50806 m .47023 .53482 L .46816 .54323 L p .113 .195 .672 r
F P
0 g
s
.58201 .545 m .56807 .56693 L .56707 .56063 L p .97 .923 .691 r
F P
0 g
s
.56707 .56063 m .58075 .53654 L .58201 .545 L p .97 .923 .691 r
F P
0 g
s
.3263 .41813 m .34003 .40872 L .3205 .44003 L p .805 .999 .795 r
F P
0 g
s
.3205 .44003 m .30561 .45155 L .3263 .41813 L p .805 .999 .795 r
F P
0 g
s
.48757 .5777 m .4999 .59161 L .50433 .59496 L p .687 .16 0 r
F P
0 g
s
.4999 .59161 m .48757 .5777 L .48344 .57187 L p 0 .007 .553 r
F P
0 g
s
.45672 .35951 m .46368 .37436 L .43701 .38667 L p .619 .591 .801 r
F P
0 g
s
.43701 .38667 m .4271 .37331 L .45672 .35951 L p .619 .591 .801 r
F P
0 g
s
.44676 .40598 m .43701 .38667 L .46368 .37436 L p .59 .514 .737 r
F P
0 g
s
.4564 .43051 m .46602 .45899 L .45231 .46935 L p .476 .397 .688 r
F P
0 g
s
.46414 .49814 m .45231 .46935 L .46602 .45899 L p .468 .383 .677 r
F P
0 g
s
.70155 .40492 m .68791 .39639 L .66135 .37183 L p 0 .287 .759 r
F P
0 g
s
.65007 .36851 m .66135 .37183 L .68791 .39639 L p .092 .477 .894 r
F P
0 g
s
.48212 .56561 m .46816 .54323 L .47023 .53482 L p .15 .235 .697 r
F P
0 g
s
.46816 .54323 m .48212 .56561 L .48344 .57187 L p 0 .058 .622 r
F P
0 g
s
.46368 .37436 m .47052 .39515 L .44676 .40598 L p .59 .514 .737 r
F P
0 g
s
.4564 .43051 m .44676 .40598 L .47052 .39515 L p .573 .471 .7 r
F P
0 g
s
.44957 .35071 m .45672 .35951 L .4271 .37331 L p .655 .725 .9 r
F P
0 g
s
.4271 .37331 m .41694 .36602 L .44957 .35071 L p .655 .725 .9 r
F P
0 g
s
.76194 .46877 m .74694 .45874 L .7295 .42483 L p .11 .399 .853 r
F P
0 g
s
.71544 .41499 m .7295 .42483 L .74694 .45874 L p .004 .318 .807 r
F P
0 g
s
.59757 .43284 m .58744 .46096 L .57026 .45248 L p .837 .674 .681 r
F P
0 g
s
.57026 .45248 m .57763 .42282 L .59757 .43284 L p .837 .674 .681 r
F P
0 g
s
.52472 .60344 m .52434 .59988 L .51698 .59923 L p .425 0 0 r
F P
0 g
s
.52434 .59988 m .52472 .60344 L .52846 .60323 L p .321 0 0 r
F P
0 g
s
.52846 .60323 m .53175 .59945 L .52434 .59988 L p .321 0 0 r
F P
0 g
s
.65007 .36851 m .6391 .36982 L .608 .35345 L p .42 .701 .98 r
F P
0 g
s
.60017 .36197 m .608 .35345 L .6391 .36982 L p .681 .746 .901 r
F P
0 g
s
.56615 .57313 m .55266 .58857 L .55391 .58445 L p .882 .983 .701 r
F P
0 g
s
.55391 .58445 m .56807 .56693 L .56615 .57313 L p .882 .983 .701 r
F P
0 g
s
.53175 .59945 m .52846 .60323 L .53197 .60249 L p .149 0 0 r
F P
0 g
s
.53197 .60249 m .53872 .59799 L .53175 .59945 L p .149 0 0 r
F P
0 g
s
.52101 .60312 m .51698 .59923 L .51016 .59756 L p .47 0 0 r
F P
0 g
s
.51698 .59923 m .52101 .60312 L .52472 .60344 L p .425 0 0 r
F P
0 g
s
.47052 .39515 m .47727 .42115 L .4564 .43051 L p .573 .471 .7 r
F P
0 g
s
.46602 .45899 m .4564 .43051 L .47727 .42115 L p .563 .447 .679 r
F P
0 g
s
.49715 .58774 m .48344 .57187 L .48212 .56561 L p 0 .196 .72 r
F P
0 g
s
.48344 .57187 m .49715 .58774 L .4999 .59161 L p 0 .007 .553 r
F P
0 g
s
.38476 .37348 m .39577 .36729 L .36688 .39098 L p .574 .923 .73 r
F P
0 g
s
.36688 .39098 m .35358 .39907 L .38476 .37348 L p .574 .923 .73 r
F P
0 g
s
.53872 .59799 m .53197 .60249 L .53502 .60128 L p 0 0 0 r
F P
0 g
s
.53502 .60128 m .54479 .59557 L .53872 .59799 L p 0 0 0 r
F P
0 g
s
.51758 .60227 m .51016 .59756 L .50433 .59496 L p .431 0 0 r
F P
0 g
s
.51016 .59756 m .51758 .60227 L .52101 .60312 L p .47 0 0 r
F P
0 g
s
.58796 .50011 m .57565 .52853 L .56701 .52152 L p .895 .739 .68 r
F P
0 g
s
.56701 .52152 m .57727 .49124 L .58796 .50011 L p .895 .739 .68 r
F P
0 g
s
.58075 .53654 m .56707 .56063 L .56318 .55468 L p .942 .827 .702 r
F P
0 g
s
.56318 .55468 m .57565 .52853 L .58075 .53654 L p .942 .827 .702 r
F P
0 g
s
.44222 .34752 m .44957 .35071 L .41694 .36602 L p .647 .897 .983 r
F P
0 g
s
.41694 .36602 m .40651 .36434 L .44222 .34752 L p .647 .897 .983 r
F P
0 g
s
.54479 .59557 m .53502 .60128 L .5374 .59967 L p .446 .848 .659 r
F P
0 g
s
.5374 .59967 m .54954 .59236 L .54479 .59557 L p .446 .848 .659 r
F P
0 g
s
.58744 .46096 m .57727 .49124 L .56286 .48427 L p .84 .67 .672 r
F P
0 g
s
.56286 .48427 m .57026 .45248 L .58744 .46096 L p .84 .67 .672 r
F P
0 g
s
.46602 .45899 m .47567 .48961 L .46414 .49814 L p .468 .383 .677 r
F P
0 g
s
.4761 .52697 m .46414 .49814 L .47567 .48961 L p .469 .385 .679 r
F P
0 g
s
.46414 .49814 m .4761 .52697 L .47023 .53482 L p .336 .312 .684 r
F P
0 g
s
.50433 .59496 m .51465 .60097 L .51758 .60227 L p .431 0 0 r
F P
0 g
s
.51465 .60097 m .50433 .59496 L .4999 .59161 L p 0 .249 .698 r
F P
0 g
s
.31252 .42559 m .3263 .41813 L .30561 .45155 L p .812 .998 .85 r
F P
0 g
s
.30561 .45155 m .29069 .46113 L .31252 .42559 L p .812 .998 .85 r
F P
0 g
s
.59253 .37656 m .58504 .39708 L .55788 .3895 L p .773 .653 .73 r
F P
0 g
s
.58504 .39708 m .57763 .42282 L .55382 .41628 L p .782 .632 .694 r
F P
0 g
s
.55382 .41628 m .55788 .3895 L .58504 .39708 L p .782 .632 .694 r
F P
0 g
s
.60017 .36197 m .59253 .37656 L .562 .36793 L p .75 .688 .793 r
F P
0 g
s
.55788 .3895 m .562 .36793 L .59253 .37656 L p .773 .653 .73 r
F P
0 g
s
.48373 .55936 m .47023 .53482 L .4761 .52697 L p .354 .336 .701 r
F P
0 g
s
.47023 .53482 m .48373 .55936 L .48212 .56561 L p .15 .235 .697 r
F P
0 g
s
.77683 .47547 m .76194 .46877 L .74362 .43272 L p .285 .527 .908 r
F P
0 g
s
.7295 .42483 m .74362 .43272 L .76194 .46877 L p .11 .399 .853 r
F P
0 g
s
.47727 .42115 m .484 .45107 L .46602 .45899 L p .563 .447 .679 r
F P
0 g
s
.47567 .48961 m .46602 .45899 L .484 .45107 L p .559 .437 .671 r
F P
0 g
s
.56807 .56693 m .55391 .58445 L .5532 .58029 L p .949 .925 .748 r
F P
0 g
s
.5532 .58029 m .56707 .56063 L .56807 .56693 L p .949 .925 .748 r
F P
0 g
s
.49501 .36679 m .49837 .3885 L .47052 .39515 L p .643 .545 .728 r
F P
0 g
s
.47052 .39515 m .46368 .37436 L .49501 .36679 L p .643 .545 .728 r
F P
0 g
s
.47727 .42115 m .47052 .39515 L .49837 .3885 L p .635 .509 .693 r
F P
0 g
s
.49158 .351 m .49501 .36679 L .46368 .37436 L p .656 .61 .791 r
F P
0 g
s
.46368 .37436 m .45672 .35951 L .49158 .351 L p .656 .61 .791 r
F P
0 g
s
.71544 .41499 m .70155 .40492 L .67292 .37838 L p 0 .198 .682 r
F P
0 g
s
.66135 .37183 m .67292 .37838 L .70155 .40492 L p 0 .287 .759 r
F P
0 g
s
.54954 .59236 m .5374 .59967 L .53895 .59777 L p .733 .989 .807 r
F P
0 g
s
.53895 .59777 m .55266 .58857 L .54954 .59236 L p .733 .989 .807 r
F P
0 g
s
.57763 .42282 m .57026 .45248 L .54977 .44695 L p .786 .62 .675 r
F P
0 g
s
.54977 .44695 m .55382 .41628 L .57763 .42282 L p .786 .62 .675 r
F P
0 g
s
.4963 .58358 m .48212 .56561 L .48373 .55936 L p .226 .317 .748 r
F P
0 g
s
.48212 .56561 m .4963 .58358 L .49715 .58774 L p 0 .196 .72 r
F P
0 g
s
.51243 .59929 m .4999 .59161 L .49715 .58774 L p 0 .347 .823 r
F P
0 g
s
.4999 .59161 m .51243 .59929 L .51465 .60097 L p 0 .249 .698 r
F P
0 g
s
.85986 .43317 m .84669 .4466 L .824 .39666 L p .889 .851 .8 r
F P
0 g
s
.824 .39666 m .8366 .38074 L .85986 .43317 L p .889 .851 .8 r
F P
0 g
s
.66135 .37183 m .65007 .36851 L .61605 .35053 L p 0 .462 .841 r
F P
0 g
s
.608 .35345 m .61605 .35053 L .65007 .36851 L p .42 .701 .98 r
F P
0 g
s
.608 .35345 m .60017 .36197 L .5662 .35229 L p .677 .74 .898 r
F P
0 g
s
.562 .36793 m .5662 .35229 L .60017 .36197 L p .75 .688 .793 r
F P
0 g
s
.49837 .3885 m .50169 .41541 L .47727 .42115 L p .635 .509 .693 r
F P
0 g
s
.484 .45107 m .47727 .42115 L .50169 .41541 L p .63 .49 .674 r
F P
0 g
s
.48806 .34127 m .49158 .351 L .45672 .35951 L p .662 .727 .898 r
F P
0 g
s
.45672 .35951 m .44957 .35071 L .48806 .34127 L p .662 .727 .898 r
F P
0 g
s
.55266 .58857 m .53895 .59777 L .53956 .59572 L p .867 .981 .847 r
F P
0 g
s
.53956 .59572 m .55391 .58445 L .55266 .58857 L p .867 .981 .847 r
F P
0 g
s
.57727 .49124 m .56701 .52152 L .55541 .51602 L p .839 .671 .673 r
F P
0 g
s
.55541 .51602 m .56286 .48427 L .57727 .49124 L p .839 .671 .673 r
F P
0 g
s
.57565 .52853 m .56318 .55468 L .55665 .54949 L p .889 .743 .694 r
F P
0 g
s
.55665 .54949 m .56701 .52152 L .57565 .52853 L p .889 .743 .694 r
F P
0 g
s
.562 .36793 m .55788 .3895 L .52824 .38656 L p .732 .613 .724 r
F P
0 g
s
.55788 .3895 m .55382 .41628 L .52785 .41374 L p .736 .587 .69 r
F P
0 g
s
.52785 .41374 m .52824 .38656 L .55788 .3895 L p .736 .587 .69 r
F P
0 g
s
.43464 .34897 m .44222 .34752 L .40651 .36434 L p .455 .884 .823 r
F P
0 g
s
.40651 .36434 m .39577 .36729 L .43464 .34897 L p .455 .884 .823 r
F P
0 g
s
.51107 .59735 m .49715 .58774 L .4963 .58358 L p .198 .413 .846 r
F P
0 g
s
.49715 .58774 m .51107 .59735 L .51243 .59929 L p 0 .347 .823 r
F P
0 g
s
.84669 .4466 m .83336 .45908 L .81128 .41161 L p .877 .848 .812 r
F P
0 g
s
.81128 .41161 m .824 .39666 L .84669 .4466 L p .877 .848 .812 r
F P
0 g
s
.57026 .45248 m .56286 .48427 L .54572 .47973 L p .788 .615 .667 r
F P
0 g
s
.54572 .47973 m .54977 .44695 L .57026 .45248 L p .788 .615 .667 r
F P
0 g
s
.79148 .47792 m .77683 .47547 L .75765 .43726 L p .487 .659 .937 r
F P
0 g
s
.74362 .43272 m .75765 .43726 L .77683 .47547 L p .285 .527 .908 r
F P
0 g
s
.36207 .38871 m .37349 .38122 L .36784 .38587 L p .53 .888 .665 r
F P
0 g
s
.36784 .38587 m .34003 .40872 L p .36207 .38871 L .53 .888 .665 r
F P
0 g
s
.35057 .39422 m .36207 .38871 L .3263 .41813 L p .607 .946 .782 r
F P
0 g
s
.36207 .38871 m .35057 .39422 L .35704 .39118 L p 0 0 0 r
F P
0 g
s
.38387 .3742 m .35358 .39907 L p .37349 .38122 L .515 .874 .642 r
F P
0 g
s
.35358 .39907 m .34003 .40872 L .37349 .38122 L p .515 .874 .642 r
F P
0 g
s
.34003 .40872 m .3263 .41813 L .36207 .38871 L p .53 .888 .665 r
F P
0 g
s
.35704 .39118 m .4026 .36977 L p .36207 .38871 L 0 0 0 r
F P
0 g
s
.37349 .38122 m .36207 .38871 L .36322 .38817 L p 0 0 0 r
F P
0 g
s
.36322 .38817 m .41077 .36582 L p .37349 .38122 L 0 0 0 r
F P
0 g
s
.37349 .38122 m .38476 .37348 L .38387 .3742 L p .515 .874 .642 r
F P
0 g
s
.56707 .56063 m .5532 .58029 L .55057 .57635 L p .921 .832 .74 r
F P
0 g
s
.55057 .57635 m .56318 .55468 L .56707 .56063 L p .921 .832 .74 r
F P
0 g
s
.52864 .36458 m .52824 .38656 L .49837 .3885 L p .69 .577 .724 r
F P
0 g
s
.49837 .3885 m .49501 .36679 L .52864 .36458 L p .69 .577 .724 r
F P
0 g
s
.50169 .41541 m .49837 .3885 L .52824 .38656 L p .687 .547 .69 r
F P
0 g
s
.5662 .35229 m .562 .36793 L .52864 .36458 L p .721 .658 .787 r
F P
0 g
s
.52824 .38656 m .52864 .36458 L .562 .36793 L p .732 .613 .724 r
F P
0 g
s
.47567 .48961 m .4854 .52024 L .4761 .52697 L p .469 .385 .679 r
F P
0 g
s
.4882 .55353 m .4761 .52697 L .4854 .52024 L p .479 .402 .692 r
F P
0 g
s
.4761 .52697 m .4882 .55353 L .48373 .55936 L p .354 .336 .701 r
F P
0 g
s
.484 .45107 m .49074 .48311 L .47567 .48961 L p .559 .437 .671 r
F P
0 g
s
.4854 .52024 m .47567 .48961 L .49074 .48311 L p .559 .439 .672 r
F P
0 g
s
.29881 .42968 m .31252 .42559 L .29069 .46113 L p .799 .965 .913 r
F P
0 g
s
.29069 .46113 m .27589 .46738 L .29881 .42968 L p .799 .965 .913 r
F P
0 g
s
.52511 .59947 m .52472 .60344 L .52101 .60312 L closepath p .447 .793 .998 r
F P
0 g
s
.52511 .59947 m .52846 .60323 L .52472 .60344 L closepath p .49 .83 .998 r
F P
0 g
s
.50169 .41541 m .50499 .44622 L .484 .45107 L p .63 .49 .674 r
F P
0 g
s
.49074 .48311 m .484 .45107 L .50499 .44622 L p .627 .483 .666 r
F P
0 g
s
.52511 .59947 m .53197 .60249 L .52846 .60323 L closepath p .549 .863 .996 r
F P
0 g
s
.55382 .41628 m .54977 .44695 L .52747 .44481 L p .737 .574 .672 r
F P
0 g
s
.52747 .44481 m .52785 .41374 L .55382 .41628 L p .737 .574 .672 r
F P
0 g
s
.52511 .59947 m .52101 .60312 L .51758 .60227 L closepath p .425 .757 .995 r
F P
0 g
s
.52904 .34852 m .52864 .36458 L .49501 .36679 L p .69 .632 .786 r
F P
0 g
s
.49501 .36679 m .49158 .351 L .52904 .34852 L p .69 .632 .786 r
F P
0 g
s
.49742 .57944 m .48373 .55936 L .4882 .55353 L p .392 .389 .737 r
F P
0 g
s
.48373 .55936 m .49742 .57944 L .4963 .58358 L p .226 .317 .748 r
F P
0 g
s
.52511 .59947 m .53502 .60128 L .53197 .60249 L closepath p .614 .886 .99 r
F P
0 g
s
.52824 .38656 m .52785 .41374 L .50169 .41541 L p .687 .547 .69 r
F P
0 g
s
.50499 .44622 m .50169 .41541 L .52785 .41374 L p .686 .531 .671 r
F P
0 g
s
.52511 .59947 m .51758 .60227 L .51465 .60097 L closepath p .426 .724 .988 r
F P
0 g
s
.61605 .35053 m .608 .35345 L .57051 .3427 L p .42 .742 .993 r
F P
0 g
s
.5662 .35229 m .57051 .3427 L .608 .35345 L p .677 .74 .898 r
F P
0 g
s
.55391 .58445 m .53956 .59572 L .53919 .59364 L p .892 .909 .83 r
F P
0 g
s
.53919 .59364 m .5532 .58029 L .55391 .58445 L p .892 .909 .83 r
F P
0 g
s
.52511 .59947 m .5374 .59967 L .53502 .60128 L closepath p .672 .893 .977 r
F P
0 g
s
.83336 .45908 m .81976 .4692 L .79833 .42414 L p .842 .838 .841 r
F P
0 g
s
.79833 .42414 m .81128 .41161 L .83336 .45908 L p .842 .838 .841 r
F P
0 g
s
.52864 .36458 m .52904 .34852 L .5662 .35229 L p .721 .658 .787 r
F P
0 g
s
.52511 .59947 m .51465 .60097 L .51243 .59929 L closepath p .444 .697 .974 r
F P
0 g
s
.52785 .41374 m .52747 .44481 L .50499 .44622 L p .686 .531 .671 r
F P
0 g
s
.51066 .59528 m .4963 .58358 L .49742 .57944 L p .353 .454 .825 r
F P
0 g
s
.4963 .58358 m .51066 .59528 L .51107 .59735 L p .198 .413 .846 r
F P
0 g
s
.8058 .47574 m .79148 .47792 L .7715 .43748 L p .659 .758 .923 r
F P
0 g
s
.75765 .43726 m .7715 .43748 L .79148 .47792 L p .487 .659 .937 r
F P
0 g
s
.57051 .3427 m .5662 .35229 L .52904 .34852 L p .673 .735 .897 r
F P
0 g
s
.48443 .33714 m .48806 .34127 L .44957 .35071 L p .572 .873 .994 r
F P
0 g
s
.44957 .35071 m .44222 .34752 L .48443 .33714 L p .572 .873 .994 r
F P
0 g
s
.52511 .59947 m .53895 .59777 L .5374 .59967 L closepath p .717 .885 .958 r
F P
0 g
s
.54977 .44695 m .54572 .47973 L .52708 .47797 L p .737 .568 .664 r
F P
0 g
s
.52708 .47797 m .52747 .44481 L .54977 .44695 L p .737 .568 .664 r
F P
0 g
s
.52511 .59947 m .51243 .59929 L .51107 .59735 L closepath p .473 .676 .954 r
F P
0 g
s
.56286 .48427 m .55541 .51602 L .54165 .51245 L p .787 .616 .668 r
F P
0 g
s
.54165 .51245 m .54572 .47973 L .56286 .48427 L p .787 .616 .668 r
F P
0 g
s
.81976 .4692 m .8058 .47574 L .78507 .43303 L p .775 .813 .883 r
F P
0 g
s
.78507 .43303 m .79833 .42414 L .81976 .4692 L p .775 .813 .883 r
F P
0 g
s
.52945 .33851 m .52904 .34852 L .49158 .351 L p .667 .73 .897 r
F P
0 g
s
.49158 .351 m .48806 .34127 L .52945 .33851 L p .667 .73 .897 r
F P
0 g
s
.56701 .52152 m .55665 .54949 L .5479 .54542 L p .836 .676 .685 r
F P
0 g
s
.5479 .54542 m .55541 .51602 L .56701 .52152 L p .836 .676 .685 r
F P
0 g
s
.5083 .47913 m .50499 .44622 L .52747 .44481 L p .685 .525 .664 r
F P
0 g
s
.50499 .44622 m .5083 .47913 L .49074 .48311 L p .627 .483 .666 r
F P
0 g
s
.20631 .43608 m .19318 .42214 L .22154 .37026 L p .427 .463 .795 r
F P
0 g
s
.7715 .43748 m .78507 .43303 L .8058 .47574 L p .659 .758 .923 r
F P
0 g
s
.7295 .42483 m .71544 .41499 L .68475 .3865 L p 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .71544 .41499 L p .67401 .37932 L 0 .198 .682 r
F P
0 g
s
.69674 .39436 m .7295 .42483 L p .69085 .39172 L 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .69674 .39436 L p .69085 .39172 L 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .64161 .36369 L p .69538 .3936 L .454 0 0 r
F P
0 g
s
.69674 .39436 m .68475 .3865 L p .69538 .3936 L .454 0 0 r
F P
0 g
s
.65048 .36992 m .69674 .39436 L p .64909 .36785 L .454 0 0 r
F P
0 g
s
.64161 .36369 m .65048 .36992 L p .64909 .36785 L .454 0 0 r
F P
0 g
s
.65048 .36992 m .59397 .35376 L p .6517 .37175 L .358 0 0 r
F P
0 g
s
.69674 .39436 m .65048 .36992 L p .70197 .3967 L 0 .279 .665 r
F P
0 g
s
.65941 .37416 m .70881 .40025 L p .66531 .37763 L 0 .279 .665 r
F P
0 g
s
.65048 .36992 m .65941 .37416 L p .66531 .37763 L 0 .279 .665 r
F P
0 g
s
.65941 .37416 m .65048 .36992 L p .6517 .37175 L .358 0 0 r
F P
0 g
s
.59893 .35687 m .65941 .37416 L p .61054 .35892 L .358 0 0 r
F P
0 g
s
.59397 .35376 m .59893 .35687 L p .61054 .35892 L .358 0 0 r
F P
0 g
s
.52904 .34852 m .52945 .33851 L .57051 .3427 L p .673 .735 .897 r
F P
0 g
s
.59893 .35687 m .59397 .35376 L .5317 .34744 L p .323 0 0 r
F P
0 g
s
.53218 .35011 m .59893 .35687 L p .54865 .34982 L .323 0 0 r
F P
0 g
s
.5317 .34744 m .53218 .35011 L p .54865 .34982 L .323 0 0 r
F P
0 g
s
.53218 .35011 m .5317 .34744 L .46888 .3516 L p .204 0 0 r
F P
0 g
s
.46888 .3516 m .46483 .35456 L .53218 .35011 L p .204 0 0 r
F P
0 g
s
.53218 .35011 m .46483 .35456 L p .51927 .35034 L .132 .679 .788 r
F P
0 g
s
.53265 .3493 m .53218 .35011 L p .51927 .35034 L .132 .679 .788 r
F P
0 g
s
.59893 .35687 m .53218 .35011 L p .5898 .35526 L .029 .593 .793 r
F P
0 g
s
.58906 .34863 m .59397 .35376 L .65048 .36992 L p .501 0 0 r
F P
0 g
s
.60388 .35652 m .59893 .35687 L p .5898 .35526 L .029 .593 .793 r
F P
0 g
s
.65941 .37416 m .59893 .35687 L p .65478 .37142 L .009 .549 .841 r
F P
0 g
s
.61605 .35053 m .62435 .35224 L .66135 .37183 L p 0 .462 .841 r
F P
0 g
s
.67292 .37838 m .66135 .37183 L .62435 .35224 L p .37 0 0 r
F P
0 g
s
.67292 .37838 m .68475 .3865 L p .67401 .37932 L 0 .198 .682 r
F P
0 g
s
.68475 .3865 m .67292 .37838 L .63288 .35719 L p .48 0 0 r
F P
0 g
s
.62435 .35224 m .63288 .35719 L .67292 .37838 L p .37 0 0 r
F P
0 g
s
.63288 .35719 m .64161 .36369 L .68475 .3865 L p .48 0 0 r
F P
0 g
s
.66834 .37496 m .65941 .37416 L p .65478 .37142 L .009 .549 .841 r
F P
0 g
s
.70881 .40025 m .69674 .39436 L p .70197 .3967 L 0 .279 .665 r
F P
0 g
s
.56318 .55468 m .55057 .57635 L .54618 .57293 L p .875 .752 .724 r
F P
0 g
s
.54618 .57293 m .55665 .54949 L .56318 .55468 L p .875 .752 .724 r
F P
0 g
s
.49753 .51511 m .49074 .48311 L .5083 .47913 L p .628 .483 .667 r
F P
0 g
s
.49074 .48311 m .49753 .51511 L .4854 .52024 L p .559 .439 .672 r
F P
0 g
s
.52511 .59947 m .53956 .59572 L .53895 .59777 L closepath p .744 .864 .936 r
F P
0 g
s
.49523 .54854 m .4854 .52024 L .49753 .51511 L p .564 .451 .683 r
F P
0 g
s
.4854 .52024 m .49523 .54854 L .4882 .55353 L p .479 .402 .692 r
F P
0 g
s
.52747 .44481 m .52708 .47797 L .5083 .47913 L p .685 .525 .664 r
F P
0 g
s
.5532 .58029 m .53919 .59364 L .53786 .59169 L p .874 .832 .803 r
F P
0 g
s
.53786 .59169 m .55057 .57635 L .5532 .58029 L p .874 .832 .803 r
F P
0 g
s
.52511 .59947 m .51107 .59735 L .51066 .59528 L closepath p .505 .661 .931 r
F P
0 g
s
.50043 .57559 m .4882 .55353 L .49523 .54854 L p .499 .439 .721 r
F P
0 g
s
.4882 .55353 m .50043 .57559 L .49742 .57944 L p .392 .389 .737 r
F P
0 g
s
.28527 .42946 m .29881 .42968 L .27589 .46738 L p .74 .875 .943 r
F P
0 g
s
.27589 .46738 m .26132 .46937 L .28527 .42946 L p .74 .875 .943 r
F P
0 g
s
.51124 .59322 m .49742 .57944 L .50043 .57559 L p .459 .484 .797 r
F P
0 g
s
.49742 .57944 m .51124 .59322 L .51066 .59528 L p .353 .454 .825 r
F P
0 g
s
.52511 .59947 m .53919 .59364 L .53956 .59572 L closepath p .757 .837 .913 r
F P
0 g
s
.52511 .59947 m .51066 .59528 L .51124 .59322 L closepath p .539 .652 .908 r
F P
0 g
s
.22154 .37026 m .23388 .3867 L .20631 .43608 L p .427 .463 .795 r
F P
0 g
s
.2196 .44907 m .20631 .43608 L .23388 .3867 L p .444 .484 .806 r
F P
0 g
s
.54572 .47973 m .54165 .51245 L .52669 .51106 L p .737 .569 .665 r
F P
0 g
s
.52669 .51106 m .52708 .47797 L .54572 .47973 L p .737 .569 .665 r
F P
0 g
s
.51162 .51197 m .5083 .47913 L .52708 .47797 L p .685 .526 .664 r
F P
0 g
s
.5083 .47913 m .51162 .51197 L .49753 .51511 L p .628 .483 .667 r
F P
0 g
s
.42685 .35365 m .43464 .34897 L .39577 .36729 L p 0 0 0 r
F P
0 g
s
.39577 .36729 m .38476 .37348 L .42685 .35365 L p 0 0 0 r
F P
0 g
s
.52511 .59947 m .53786 .59169 L .53919 .59364 L closepath p .758 .807 .892 r
F P
0 g
s
.52511 .59947 m .53565 .58999 L .53786 .59169 L closepath p .751 .777 .874 r
F P
0 g
s
.52511 .59947 m .53271 .58867 L .53565 .58999 L closepath p .739 .749 .86 r
F P
0 g
s
.52511 .59947 m .52925 .58781 L .53271 .58867 L closepath p .722 .724 .851 r
F P
0 g
s
.52511 .59947 m .52551 .58748 L .52925 .58781 L closepath p .703 .702 .846 r
F P
0 g
s
.52511 .59947 m .52174 .5877 L .52551 .58748 L closepath p .681 .684 .846 r
F P
0 g
s
.52511 .59947 m .5182 .58845 L .52174 .5877 L closepath p .657 .669 .85 r
F P
0 g
s
.52511 .59947 m .51514 .58969 L .5182 .58845 L closepath p .631 .658 .858 r
F P
0 g
s
.52511 .59947 m .51276 .59131 L .51514 .58969 L closepath p .602 .651 .871 r
F P
0 g
s
.52511 .59947 m .51124 .59322 L .51276 .59131 L closepath p .572 .649 .888 r
F P
0 g
s
.55541 .51602 m .5479 .54542 L .53754 .54278 L p .786 .622 .678 r
F P
0 g
s
.53754 .54278 m .54165 .51245 L .55541 .51602 L p .786 .622 .678 r
F P
0 g
s
.55057 .57635 m .53786 .59169 L .53565 .58999 L p .842 .766 .779 r
F P
0 g
s
.53565 .58999 m .54618 .57293 L .55057 .57635 L p .842 .766 .779 r
F P
0 g
s
.55665 .54949 m .54618 .57293 L .54032 .57025 L p .827 .689 .711 r
F P
0 g
s
.54032 .57025 m .5479 .54542 L .55665 .54949 L p .827 .689 .711 r
F P
0 g
s
.50043 .57559 m .51276 .59131 L .51124 .59322 L p .459 .484 .797 r
F P
0 g
s
.52708 .47797 m .52669 .51106 L .51162 .51197 L p .685 .526 .664 r
F P
0 g
s
.57051 .3427 m .57494 .33871 L .61605 .35053 L p .42 .742 .993 r
F P
0 g
s
.57494 .33871 m .57051 .3427 L .52945 .33851 L p .447 .787 .998 r
F P
0 g
s
.62435 .35224 m .61605 .35053 L .57494 .33871 L p 0 .46 .751 r
F P
0 g
s
.49523 .54854 m .50516 .57231 L .50043 .57559 L p .499 .439 .721 r
F P
0 g
s
.51276 .59131 m .50043 .57559 L .50516 .57231 L p .537 .511 .775 r
F P
0 g
s
.50437 .54475 m .49753 .51511 L .51162 .51197 L p .63 .494 .677 r
F P
0 g
s
.49753 .51511 m .50437 .54475 L .49523 .54854 L p .564 .451 .683 r
F P
0 g
s
.50516 .57231 m .49523 .54854 L .50437 .54475 L p .576 .48 .709 r
F P
0 g
s
.272 .42454 m .28527 .42946 L .26132 .46937 L p .649 .749 .923 r
F P
0 g
s
.26132 .46937 m .24706 .46672 L .272 .42454 L p .649 .749 .923 r
F P
0 g
s
.23388 .3867 m .24634 .40215 L .2196 .44907 L p .444 .484 .806 r
F P
0 g
s
.23316 .45969 m .2196 .44907 L .24634 .40215 L p .488 .539 .836 r
F P
0 g
s
.52988 .33411 m .52945 .33851 L .48806 .34127 L p .5 .834 .999 r
F P
0 g
s
.48806 .34127 m .48443 .33714 L .52988 .33411 L p .5 .834 .999 r
F P
0 g
s
.50516 .57231 m .51514 .58969 L .51276 .59131 L p .537 .511 .775 r
F P
0 g
s
.48069 .33764 m .48443 .33714 L .44222 .34752 L p .211 .733 .733 r
F P
0 g
s
.44222 .34752 m .43464 .34897 L .48069 .33764 L p .211 .733 .733 r
F P
0 g
s
.54165 .51245 m .53754 .54278 L .5263 .54176 L p .737 .576 .675 r
F P
0 g
s
.5263 .54176 m .52669 .51106 L .54165 .51245 L p .737 .576 .675 r
F P
0 g
s
.24634 .40215 m .25903 .41517 L .23316 .45969 L p .488 .539 .836 r
F P
0 g
s
.24706 .46672 m .23316 .45969 L .25903 .41517 L p .558 .629 .878 r
F P
0 g
s
.25903 .41517 m .272 .42454 L .24706 .46672 L p .558 .629 .878 r
F P
0 g
s
.54618 .57293 m .53565 .58999 L .53271 .58867 L p .806 .712 .762 r
F P
0 g
s
.53271 .58867 m .54032 .57025 L .54618 .57293 L p .806 .712 .762 r
F P
0 g
s
.51498 .54243 m .51162 .51197 L .52669 .51106 L p .686 .534 .675 r
F P
0 g
s
.51162 .51197 m .51498 .54243 L .50437 .54475 L p .63 .494 .677 r
F P
0 g
s
.51127 .56981 m .5182 .58845 L .51514 .58969 L p .597 .537 .759 r
F P
0 g
s
.51514 .58969 m .50516 .57231 L .51127 .56981 L p .597 .537 .759 r
F P
0 g
s
.50437 .54475 m .51127 .56981 L .50516 .57231 L p .576 .48 .709 r
F P
0 g
s
.5479 .54542 m .54032 .57025 L .5334 .56852 L p .781 .637 .702 r
F P
0 g
s
.5334 .56852 m .53754 .54278 L .5479 .54542 L p .781 .637 .702 r
F P
0 g
s
.52945 .33851 m .52988 .33411 L .57494 .33871 L p .447 .787 .998 r
F P
0 g
s
.52669 .51106 m .5263 .54176 L .51498 .54243 L p .686 .534 .675 r
F P
0 g
s
.51127 .56981 m .50437 .54475 L .51498 .54243 L p .636 .517 .701 r
F P
0 g
s
.54032 .57025 m .53271 .58867 L .52925 .58781 L p .768 .667 .751 r
F P
0 g
s
.51835 .56829 m .52174 .5877 L .5182 .58845 L p .646 .565 .749 r
F P
0 g
s
.5182 .58845 m .51127 .56981 L .51835 .56829 L p .646 .565 .749 r
F P
0 g
s
.52925 .58781 m .5334 .56852 L .54032 .57025 L p .768 .667 .751 r
F P
0 g
s
.5334 .56852 m .52925 .58781 L .52551 .58748 L p .73 .628 .745 r
F P
0 g
s
.5259 .56785 m .52551 .58748 L .52174 .5877 L p .69 .595 .745 r
F P
0 g
s
.52174 .5877 m .51835 .56829 L .5259 .56785 L p .69 .595 .745 r
F P
0 g
s
.52551 .58748 m .5259 .56785 L .5334 .56852 L p .73 .628 .745 r
F P
0 g
s
.74362 .43272 m .7295 .42483 L .69674 .39436 L p 0 .344 .804 r
F P
0 g
s
.51498 .54243 m .51835 .56829 L .51127 .56981 L p .636 .517 .701 r
F P
0 g
s
.53754 .54278 m .5334 .56852 L .5259 .56785 L p .735 .593 .698 r
F P
0 g
s
.5259 .56785 m .5263 .54176 L .53754 .54278 L p .735 .593 .698 r
F P
0 g
s
.51835 .56829 m .51498 .54243 L .5263 .54176 L p .688 .554 .698 r
F P
0 g
s
.5263 .54176 m .5259 .56785 L .51835 .56829 L p .688 .554 .698 r
F P
0 g
s
.57494 .33871 m .57952 .33935 L .62435 .35224 L p 0 .46 .751 r
F P
0 g
s
.57952 .33935 m .57494 .33871 L .52988 .33411 L p .093 0 0 r
F P
0 g
s
.41888 .35987 m .42685 .35365 L .38476 .37348 L p 0 0 0 r
F P
0 g
s
.38476 .37348 m .37349 .38122 L .41888 .35987 L p 0 0 0 r
F P
0 g
s
.3263 .41813 m .31252 .42559 L .35057 .39422 L p .607 .946 .782 r
F P
0 g
s
.53032 .33433 m .52988 .33411 L .48443 .33714 L p 0 0 0 r
F P
0 g
s
.48443 .33714 m .48069 .33764 L .53032 .33433 L p 0 0 0 r
F P
0 g
s
.63288 .35719 m .62435 .35224 L .57952 .33935 L p .432 0 0 r
F P
0 g
s
.52988 .33411 m .53032 .33433 L .57952 .33935 L p .093 0 0 r
F P
0 g
s
.47684 .34136 m .48069 .33764 L .43464 .34897 L p .069 0 0 r
F P
0 g
s
.43464 .34897 m .42685 .35365 L .47684 .34136 L p .069 0 0 r
F P
0 g
s
.75765 .43726 m .74362 .43272 L .70881 .40025 L p .172 .529 .922 r
F P
0 g
s
.69674 .39436 m .70881 .40025 L .74362 .43272 L p 0 .344 .804 r
F P
0 g
s
.3391 .39633 m .35057 .39422 L .31252 .42559 L p .69 .972 .92 r
F P
0 g
s
.31252 .42559 m .29881 .42968 L .3391 .39633 L p .69 .972 .92 r
F P
0 g
s
.57952 .33935 m .58423 .34322 L .63288 .35719 L p .432 0 0 r
F P
0 g
s
.58423 .34322 m .57952 .33935 L .53032 .33433 L p .389 0 0 r
F P
0 g
s
.7715 .43748 m .75765 .43726 L .72083 .40275 L p .462 .684 .962 r
F P
0 g
s
.70881 .40025 m .72083 .40275 L .75765 .43726 L p .172 .529 .922 r
F P
0 g
s
.41077 .36582 m .41888 .35987 L .37349 .38122 L p 0 0 0 r
F P
0 g
s
.53077 .33777 m .53032 .33433 L .48069 .33764 L p .27 0 0 r
F P
0 g
s
.48069 .33764 m .47684 .34136 L .53077 .33777 L p .27 0 0 r
F P
0 g
s
.64161 .36369 m .63288 .35719 L .58423 .34322 L p .522 0 0 r
F P
0 g
s
.53032 .33433 m .53077 .33777 L .58423 .34322 L p .389 0 0 r
F P
0 g
s
.47289 .34662 m .47684 .34136 L .42685 .35365 L p .158 0 0 r
F P
0 g
s
.42685 .35365 m .41888 .35987 L .47289 .34662 L p .158 0 0 r
F P
0 g
s
.78507 .43303 m .7715 .43748 L .73273 .40088 L p .659 .756 .922 r
F P
0 g
s
.72083 .40275 m .73273 .40088 L .7715 .43748 L p .462 .684 .962 r
F P
0 g
s
.32776 .39406 m .3391 .39633 L .29881 .42968 L p .701 .888 .966 r
F P
0 g
s
.29881 .42968 m .28527 .42946 L .32776 .39406 L p .701 .888 .966 r
F P
0 g
s
.8366 .38074 m .824 .39666 L .77807 .35105 L p .854 .778 .777 r
F P
0 g
s
.77807 .35105 m .78901 .33274 L .8366 .38074 L p .854 .778 .777 r
F P
0 g
s
.824 .39666 m .81128 .41161 L .76705 .36834 L p .845 .779 .788 r
F P
0 g
s
.76705 .36834 m .77807 .35105 L .824 .39666 L p .845 .779 .788 r
F P
0 g
s
.79833 .42414 m .78507 .43303 L .74441 .39427 L p .765 .778 .863 r
F P
0 g
s
.73273 .40088 m .74441 .39427 L .78507 .43303 L p .659 .756 .922 r
F P
0 g
s
.81128 .41161 m .79833 .42414 L .75585 .38316 L p .819 .78 .816 r
F P
0 g
s
.75585 .38316 m .76705 .36834 L .81128 .41161 L p .819 .78 .816 r
F P
0 g
s
.74441 .39427 m .75585 .38316 L .79833 .42414 L p .765 .778 .863 r
F P
0 g
s
.31661 .38704 m .32776 .39406 L .28527 .42946 L p .65 .749 .922 r
F P
0 g
s
.28527 .42946 m .272 .42454 L .31661 .38704 L p .65 .749 .922 r
F P
0 g
s
.58423 .34322 m .58906 .34863 L .64161 .36369 L p .522 0 0 r
F P
0 g
s
.58906 .34863 m .58423 .34322 L .53077 .33777 L p .468 0 0 r
F P
0 g
s
.4026 .36977 m .41077 .36582 L .3931 .37413 L p 0 0 0 r
F P
0 g
s
.41077 .36582 m .4026 .36977 L .46483 .35456 L p 0 0 0 r
F P
0 g
s
.4026 .36977 m .39444 .37028 L .40958 .36658 L p .304 .798 .829 r
F P
0 g
s
.46483 .35456 m .46888 .3516 L .44785 .35675 L p 0 0 0 r
F P
0 g
s
.44785 .35675 m .41077 .36582 L p .46483 .35456 L 0 0 0 r
F P
0 g
s
.46483 .35456 m .46077 .35405 L .47726 .35296 L p .132 .679 .788 r
F P
0 g
s
.47726 .35296 m .53265 .3493 L p .46483 .35456 L .132 .679 .788 r
F P
0 g
s
.40958 .36658 m .46077 .35405 L p .4026 .36977 L .304 .798 .829 r
F P
0 g
s
.3931 .37413 m .36207 .38871 L p .4026 .36977 L 0 0 0 r
F P
0 g
s
.53123 .34275 m .53077 .33777 L .47684 .34136 L p .35 0 0 r
F P
0 g
s
.47684 .34136 m .47289 .34662 L .53123 .34275 L p .35 0 0 r
F P
0 g
s
.65048 .36992 m .64161 .36369 L .58906 .34863 L p .501 0 0 r
F P
0 g
s
.23388 .3867 m .22154 .37026 L .27399 .32374 L p .518 .497 .772 r
F P
0 g
s
.30569 .3755 m .31661 .38704 L .272 .42454 L p .594 .633 .86 r
F P
0 g
s
.272 .42454 m .25903 .41517 L .30569 .3755 L p .594 .633 .86 r
F P
0 g
s
.27399 .32374 m .28445 .34251 L .23388 .3867 L p .518 .497 .772 r
F P
0 g
s
.24634 .40215 m .23388 .3867 L .28445 .34251 L p .528 .513 .783 r
F P
0 g
s
.53077 .33777 m .53123 .34275 L .58906 .34863 L p .468 0 0 r
F P
0 g
s
.29499 .36025 m .30569 .3755 L .25903 .41517 L p .552 .556 .812 r
F P
0 g
s
.25903 .41517 m .24634 .40215 L .29499 .36025 L p .552 .556 .812 r
F P
0 g
s
.46888 .3516 m .47289 .34662 L .41888 .35987 L p .137 0 0 r
F P
0 g
s
.41888 .35987 m .41077 .36582 L .46888 .3516 L p .137 0 0 r
F P
0 g
s
.28445 .34251 m .29499 .36025 L .24634 .40215 L p .528 .513 .783 r
F P
0 g
s
.72083 .40275 m .70881 .40025 L .65941 .37416 L p .066 .534 .897 r
F P
0 g
s
.39444 .37028 m .4026 .36977 L .35057 .39422 L p .511 .913 .887 r
F P
0 g
s
.35057 .39422 m .3391 .39633 L .39444 .37028 L p .511 .913 .887 r
F P
0 g
s
.59397 .35376 m .58906 .34863 L .53123 .34275 L p .45 0 0 r
F P
0 g
s
.5317 .34744 m .53123 .34275 L .47289 .34662 L p .332 0 0 r
F P
0 g
s
.47289 .34662 m .46888 .3516 L .5317 .34744 L p .332 0 0 r
F P
0 g
s
.73273 .40088 m .72083 .40275 L .66834 .37496 L p .447 .715 .981 r
F P
0 g
s
.65941 .37416 m .66834 .37496 L .72083 .40275 L p .066 .534 .897 r
F P
0 g
s
.53123 .34275 m .5317 .34744 L .59397 .35376 L p .45 0 0 r
F P
0 g
s
.38635 .36637 m .39444 .37028 L .3391 .39633 L p .646 .885 .984 r
F P
0 g
s
.3391 .39633 m .32776 .39406 L .38635 .36637 L p .646 .885 .984 r
F P
0 g
s
.74441 .39427 m .73273 .40088 L .67719 .37134 L p .659 .755 .921 r
F P
0 g
s
.66834 .37496 m .67719 .37134 L .73273 .40088 L p .447 .715 .981 r
F P
0 g
s
.75585 .38316 m .74441 .39427 L .68589 .36293 L p .75 .746 .848 r
F P
0 g
s
.67719 .37134 m .68589 .36293 L .74441 .39427 L p .659 .755 .921 r
F P
0 g
s
.37838 .35765 m .38635 .36637 L .32776 .39406 L p .652 .749 .921 r
F P
0 g
s
.32776 .39406 m .31661 .38704 L .37838 .35765 L p .652 .749 .921 r
F P
0 g
s
.46077 .35405 m .46483 .35456 L .4026 .36977 L p .304 .798 .829 r
F P
0 g
s
.76705 .36834 m .75585 .38316 L .69443 .34995 L p .79 .731 .798 r
F P
0 g
s
.68589 .36293 m .69443 .34995 L .75585 .38316 L p .75 .746 .848 r
F P
0 g
s
.78901 .33274 m .77807 .35105 L .71106 .31395 L p .814 .718 .759 r
F P
0 g
s
.71106 .31395 m .71927 .29362 L .78901 .33274 L p .814 .718 .759 r
F P
0 g
s
.77807 .35105 m .76705 .36834 L .7028 .33321 L p .808 .722 .77 r
F P
0 g
s
.69443 .34995 m .7028 .33321 L .76705 .36834 L p .79 .731 .798 r
F P
0 g
s
.7028 .33321 m .71106 .31395 L .77807 .35105 L p .808 .722 .77 r
F P
0 g
s
.37057 .34435 m .37838 .35765 L .31661 .38704 L p .626 .642 .846 r
F P
0 g
s
.31661 .38704 m .30569 .3755 L .37057 .34435 L p .626 .642 .846 r
F P
0 g
s
.3629 .32728 m .37057 .34435 L .30569 .3755 L p .605 .576 .795 r
F P
0 g
s
.30569 .3755 m .29499 .36025 L .3629 .32728 L p .605 .576 .795 r
F P
0 g
s
.67719 .37134 m .66834 .37496 L .60388 .35652 L p .449 .752 .993 r
F P
0 g
s
.59893 .35687 m .60388 .35652 L .66834 .37496 L p .009 .549 .841 r
F P
0 g
s
.35534 .30767 m .3629 .32728 L .29499 .36025 L p .591 .541 .767 r
F P
0 g
s
.29499 .36025 m .28445 .34251 L .35534 .30767 L p .591 .541 .767 r
F P
0 g
s
.28445 .34251 m .27399 .32374 L .34782 .287 L p .586 .528 .756 r
F P
0 g
s
.34782 .287 m .35534 .30767 L .28445 .34251 L p .586 .528 .756 r
F P
0 g
s
.45675 .34909 m .46077 .35405 L .39444 .37028 L p .582 .865 .995 r
F P
0 g
s
.39444 .37028 m .38635 .36637 L .45675 .34909 L p .582 .865 .995 r
F P
0 g
s
.53218 .35011 m .53265 .3493 L .60388 .35652 L p .029 .593 .793 r
F P
0 g
s
.68589 .36293 m .67719 .37134 L .6088 .35172 L p .658 .753 .92 r
F P
0 g
s
.60388 .35652 m .6088 .35172 L .67719 .37134 L p .449 .752 .993 r
F P
0 g
s
.45279 .33928 m .45675 .34909 L .38635 .36637 L p .654 .75 .92 r
F P
0 g
s
.38635 .36637 m .37838 .35765 L .45279 .33928 L p .654 .75 .92 r
F P
0 g
s
.6088 .35172 m .60388 .35652 L .53265 .3493 L p .474 .792 .999 r
F P
0 g
s
.69443 .34995 m .68589 .36293 L .61364 .34207 L p .73 .717 .838 r
F P
0 g
s
.6088 .35172 m .61364 .34207 L .68589 .36293 L p .658 .753 .92 r
F P
0 g
s
.53313 .34403 m .53265 .3493 L .46077 .35405 L p .521 .832 1 r
F P
0 g
s
.46077 .35405 m .45675 .34909 L .53313 .34403 L p .521 .832 1 r
F P
0 g
s
.4489 .32486 m .45279 .33928 L .37838 .35765 L p .656 .655 .837 r
F P
0 g
s
.37838 .35765 m .37057 .34435 L .4489 .32486 L p .656 .655 .837 r
F P
0 g
s
.7028 .33321 m .69443 .34995 L .61839 .32782 L p .758 .69 .786 r
F P
0 g
s
.61364 .34207 m .61839 .32782 L .69443 .34995 L p .73 .717 .838 r
F P
0 g
s
.53265 .3493 m .53313 .34403 L .6088 .35172 L p .474 .792 .999 r
F P
0 g
s
.71106 .31395 m .7028 .33321 L .62307 .30977 L p .77 .675 .758 r
F P
0 g
s
.61839 .32782 m .62307 .30977 L .7028 .33321 L p .758 .69 .786 r
F P
0 g
s
.71927 .29362 m .71106 .31395 L .62768 .28915 L p .773 .669 .748 r
F P
0 g
s
.62307 .30977 m .62768 .28915 L .71106 .31395 L p .77 .675 .758 r
F P
0 g
s
.44507 .30663 m .4489 .32486 L .37057 .34435 L p .649 .599 .784 r
F P
0 g
s
.37057 .34435 m .3629 .32728 L .44507 .30663 L p .649 .599 .784 r
F P
0 g
s
.61364 .34207 m .6088 .35172 L .53313 .34403 L p .657 .752 .92 r
F P
0 g
s
.62768 .28915 m .63227 .26744 L .71927 .29362 L p .773 .669 .748 r
F P
0 g
s
.53359 .33389 m .53313 .34403 L .45675 .34909 L p .655 .751 .92 r
F P
0 g
s
.45675 .34909 m .45279 .33928 L .53359 .33389 L p .655 .751 .92 r
F P
0 g
s
.4413 .28582 m .44507 .30663 L .3629 .32728 L p .644 .569 .756 r
F P
0 g
s
.3629 .32728 m .35534 .30767 L .4413 .28582 L p .644 .569 .756 r
F P
0 g
s
.43754 .26392 m .4413 .28582 L .35534 .30767 L p .641 .559 .746 r
F P
0 g
s
.35534 .30767 m .34782 .287 L .43754 .26392 L p .641 .559 .746 r
F P
0 g
s
.53313 .34403 m .53359 .33389 L .61364 .34207 L p .657 .752 .92 r
F P
0 g
s
.61839 .32782 m .61364 .34207 L .53359 .33389 L p .708 .692 .833 r
F P
0 g
s
.53405 .31914 m .53359 .33389 L .45279 .33928 L p .683 .672 .832 r
F P
0 g
s
.45279 .33928 m .4489 .32486 L .53405 .31914 L p .683 .672 .832 r
F P
0 g
s
.62307 .30977 m .61839 .32782 L .53405 .31914 L p .724 .655 .78 r
F P
0 g
s
.53359 .33389 m .53405 .31914 L .61839 .32782 L p .708 .692 .833 r
F P
0 g
s
.5345 .30056 m .53405 .31914 L .4489 .32486 L p .688 .625 .78 r
F P
0 g
s
.4489 .32486 m .44507 .30663 L .5345 .30056 L p .688 .625 .78 r
F P
0 g
s
.62768 .28915 m .62307 .30977 L .5345 .30056 L p .73 .635 .752 r
F P
0 g
s
.53405 .31914 m .5345 .30056 L .62307 .30977 L p .724 .655 .78 r
F P
0 g
s
.63227 .26744 m .62768 .28915 L .53494 .2794 L p .732 .628 .742 r
F P
0 g
s
.5345 .30056 m .53494 .2794 L .62768 .28915 L p .73 .635 .752 r
F P
0 g
s
.53494 .2794 m .5345 .30056 L .44507 .30663 L p .689 .6 .752 r
F P
0 g
s
.44507 .30663 m .4413 .28582 L .53494 .2794 L p .689 .6 .752 r
F P
0 g
s
.53494 .2794 m .53539 .25714 L .63227 .26744 L p .732 .628 .742 r
F P
0 g
s
.53539 .25714 m .53494 .2794 L .4413 .28582 L p .689 .592 .742 r
F P
0 g
s
.4413 .28582 m .43754 .26392 L .53539 .25714 L p .689 .592 .742 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000So/9Nm00?o0000ok^P_OnkX;d00onkX;d;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`0001Oo/9Nm00?o0000
ok^P_OnkX;d03_nkX;d:o`0001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[
ooooo`004_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool0K?ooool4o`0000;oY8nn00?o0000ok2G_On`Ukd07?n`Ukd00ol0003o^j2mok^P_@0Hok^P
_@Oo00004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`Co
00001_nTSkh00ol0003o/9Nmok2G_@0Lok2G_@03o`000?nkX;go^j2m01co^j2m00?o0000olF[_oo5
Zkl00ol0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
1?l0000;ojB?_P03o`000?n`Ukgo/9Nm01_o/9Nm00?o0000ok^P_OnkX;d07?nkX;d00ol0003oaJ^o
olF[_`03olF[_`?o00003?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo
000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Mooooo`Co00003onTSkh00ol0003o/9Nmok2G_@0Kok2G_@03o`000?nkX;go^j2m01_o^j2m00?o
0000olF[_oo5Zkl01oo5Zkl3o`0000Wooooo00?o0000ooooooooool0;oooool2o`0002_ooooo000M
ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oooooooooo05Sooooo1?l0000C
ojB?_P03o`000?n`Ukgo/9Nm01Co/9Nm2?l00003ok^P_@;o00006?nkX;d00ol0003oaJ^oolF[_`0:
olF[_`?o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo000Koooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Coooo
o`Co00006?nTSkh00ol0003o/9Nmok2G_@04ok2G_@oo00001on`VL000ol0003o^Z;0okZR`003okZR
`0[o00003_nkX;d00ol0003oaJ^oolF[_`0=olF[_`?o00001?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Sooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Coooool3o`0001[oY8nn0ol000000on`Ukgo0000o`000003o`0001Ko/9W000?o0000okZR`?nj
X/003OnjX/09o`0000Co^j2m00?o0000olF[_oo5Zkl04Oo5Zkl3o`000003ooooool0003ooooo03;o
oooo00?o0000ooooooooool09oooool002?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1<ooooo`;o000000?oUXO1o`000?nTSkh05_nTSkh4o`0000;oY97100?o0000ok2I`?n`VL00
6_n`VL000ol0003o^Z;0okZR`00FokZR`0Go00005_o5Zkl3o`0003?ooooo00?o0000ooooooooool0
9_ooool002?ooooo0_l0000=ooooo`03o`000?oooooooooo04Wooooo0_l00004oiJ7`@03o`000?nT
SkkoY8nn013oY8nn1?l00006ojBA`@03o`000?n`VL3o/9W001[o/9W000?o0000okZR`?njX/006_nj
X/000ol0003oaJc2olF/`P03o`0001;oaJ^o00?o0000olF[_ol000000_l0000`ooooo`03o`000?oo
oooooooo02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2
o`0000KoUXO100?o0000ojB?__nTSkh03?nTSkh4o`0000[oY97100?o0000ok2I`?n`VL006_n`VL00
0ol0003o^Z;0okZR`00JokZR`003o`000?o5[<;oaJc200?oaJc20ol0000?olF[_`03o`000?o5Zkoo
aJ^o00;oaJ^o0_l0000^ooooo`;o00009oooool002?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`13ooooo`;o00002OnFQl400ol0003oY8nnojB?_P08ojB?_P?o00003onTTL400ol0
003o/9W0ok2I`00Iok2I`003o`000?njX/3o^Z;001[o^Z;000?o0000olF/`_o5[<801_o5[<83o`00
00coaJ^o00?o0000olF[_oo5Zkl00_o5Zkl01?l0003od;O2o`000?l0000^ooooo`03o`000?oooooo
oooo02Cooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool2o`00
00_oUXO100?o0000ojB?__nTSkh01?nTSkh4o`0001;oY97100?o0000ok2I`?n`VL004_n`VL08o`00
00?o^Z;00_l0000FokZR`003o`000?o5[<;oaJc200[oaJc21?l00008olF[_`05o`000?o5ZkooaJ^o
olF[_ol000001?o@]l82o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nFQl7oUXO100_oUXO100Co0000ojB?
__nTSkkoY8nn0ol0000FojBA`@03o`000?n`VL3o/9W000Co/9W03_l00007ok2Oa`03o`000?niYlOo
^JO700?o^JO72Ol0000=okZR`003o`000?o5[<;oaJc200koaJc20ol00004olF[_`;o00000oo5Zkl0
0ol0003od;O2om2g`P04om2g`P03o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool0
02;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo0_l0000>oiJ7`@?o00006?nTTL43o`00
0003ok2I`?l0003o000000?o00005On`WlL00ol0003o^JO7okVWa`0<okVWa`Wo00001?njX/000ol0
003oaJc2olF/`P0AolF/`PCo000000GoaJ^oo`000?o5ZkooaJ^oo`000008om2g`P;o0000:oooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03Sooooo0_l0000>oiJ7`@;o000000?oUh[4o`000?nTTL404onTTL45o`0000;oYYW800?o0000ok2O
aon`WlL06On`WlL00ol0003o^JO7okVWa`0EokVWa`Go00004Oo5[<83o`0000;oaJc21?l000000oo5
Zkoo0000om2g`P09om2g`P;o0000:Oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo0_l0000>oiJ7`@;o00001?nGR/@00ol0003o
Y971ojBA`@0=ojBA`@Co00001onVVLP00ol0003o/9o7ok2Oa`0Iok2Oa`03o`000?niYlOo^JO701Wo
^JO700?o0000ol:`bOo2/<T00ol00009olF/`P?o00002?o5[<83o`0000cod;O20_l0000Wooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0boooo
o`;o00003_nFQl42o`0000KoUh[400?o0000ojBA`OnTTL402OnTTL44o`0000coYYW800?o0000ok2O
aon`WlL06?n`WlL00ol0003o^JO7okVWa`0HokVWa`03o`000?o2/<Wo`[3900Co`[391?l00002olF/
`P?o00003?o5[<84o`0000cod;O20_l0000Wooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`008Oooool3o`00
01Oooooo00?o0000ooooooooool0;oooool2o`0000koUXO10_l00008oiN:a003o`000?nTTL7oY971
00CoY9711Ol0000@ojJIb003o`000?n`WlOo/9o700_o/9o73_l00004okVWa`?o00004oniYlL00ol0
003o`[39ol:`b@07ol:`b@Go00003?o5[<800ol0003oc[S5o`000002oljha@03o`000?o@]l;od;O2
00_od;O20_l0000Uooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo01Sooooo0_l0000]oooo
o`;o00003OnFQl43o`0000_oUh[400?o0000ojBA`OnTTL400ol0000CojJIb0?o000000?o/9o7o`00
0?l000002_l0000=ojj/e003o`000?ne/MGo]K7E00Go]K7E3Ol00006okVWa`03o`000?o2/<Wo`[39
00Co`[390ol00005ol:`b@?o00002Oo5[<801?l0003oc[S5oljhaOl00002oljha@;o00003Oo@]l80
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oQ7o5o`00000;oiJ7`@;o00003OnGR/@3o`0001?oYYW8
1?l00002ojNWeP03o`000?n^[=Co[ZcD01So[ZcD00?o0000okFaeOne/MD04_ne/MD6o`0000Co`[39
0ol0000;ol:`b@Co00001Oo5[<801Ol0003oc[S5oljhaOo>^<Go000000?oc[S50_l0000<om2g`P;o
00009?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Oooooo00Go0000ohAoaOn4OlGoQ7o5o`000008oiJ7`@;o00003OnGR/@2o`000003oiZCbol0
003oYYW800ooYYW81?l00006ojNWeP03o`000?n^[=Co[ZcD01So[ZcD00?o0000okFaeOne/MD05one
/MD00ol0003o^[OFo`000003o`00017o`[390ol000000oo5[<;o0000oljha@04oljha@03o`000?o>
^<Goc[S500;oc[S50_l0000<om2g`P;o00008_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`001Ol00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00007Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?n4OlGoQ7o500;oQ7o500?o0000oiJ7`OnFQl401?nFQl42o`0000goUh[4
0_l00004oiZCb`03o`000?nVVLSoYYW800SoYYW81Ol0000;ojNWeP03o`000?n^[=Co[ZcD017o[ZcD
1ol0000HokFae@?o00001?nj]mH4o`00013o`[390_l00005oljha@03o`000?o>^<Goc[S500Coc[S5
00?o0000om2g`_o@]l802oo@]l800ol0003oooooooooo`0Nooooo`?o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?n4OlGoQ7o500CoQ7o500Co0000oiJ7`OnFQl7oUXO10_l0000=oiN:
a0;o00001_nJTl/00ol0003oYYW8ojJIb004ojJIb0Co00004?nWYmH00ol0003o[ZcDojj/e004ojj/
e0go00001_nW`>/00ol0003oZ<3[ojS0j`02ojS0j`Wo00002?ne/MD4o`0000[o^[OF0ol0000>ol:`
b@03o`000?o:^lco000000Coc[S500?o0000oljhaOo>^<D01?o>^<D2o`0000_od;O20_l0000Qoooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ohAoaOn4OlD01On4
OlD01?l0003oUXO1o`000?l0000=oiN:a0;o00002?nJTl/01?l0003oYYW8ojJIb?nVVLP3o`0001;o
YjOF0ol000000on^[=Co0000o`000003o`0001;oYl3[00?o0000ojS0jonX`>/03?nX`>/8o`0000?o
]K7E00?o0000okZge_nj]mH02onj]mH3o`0000[o`[3900?o0000olZkc?o:^l`00_o:^l`2o`0000;o
c[S500?o0000oljhaOo>^<D01Oo>^<D2o`0000Sod;O200Co0000om[7a_oJalKo00008Oooool00ol0
003oooooooooo`0Looooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ohAo
aOn4OlD01_n4OlD2o`0000coUh[40ol0000:oiZCb`?o00004_nWYmH4o`0000;oYko[00?o0000ojO0
jonW`>/04?nW`>/7o`00013oZ<3[0ol00003ojS0j`Co00004?nj]mH4o`0000Go`[3900?o0000olZk
c?o:^l`01Oo:^l`00ol0003oc[S5o`000009oljha@;o00001Oo@]l800ol0003of/O6om[7aP02om[7
aP03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Mooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?l000002_nGR/@2o`00
00_oVY?;0_l000000onPY=So0000ojNWeP0>ojNWePCo00001onW_n/00ol0003oYl3[ojO0j`05ojO0
j`[o00001_n5e?l00ol0003oNL[oogW:o`02ogW:o`So000000CoZ<3[o`000?l0003o00002OnX`>/0
0ol0003oZ<3[ojS0j`04o`0000ko^[OF0ol00002ol:`b@03o`000?o:^lcob[_<00Kob[_<0ol0000:
oljha@03o`000?o@]l;od;O200;od;O200?o0000om[7a_oJalH00ooJalH00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo01_ooooo00?o0000ohAoaOn4OlD01_n4OlD0
1Ol0003oQh?8ohN3b?n7PlSo000000OoUh[40_l0000;oiZCb`;o00001?nPY=P00ol0003oYjOFojNW
eP09ojNWeP?o00002_nW_n/3o`000003ojO0jol0003o000000;o00001_n5e?l<o`0000[oNL[o2_l0
0004ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[0ol0000>okZgeP;o00002oo:^l`2o`0000[oc[S50_l0
00000oo@]l;o0000om[7aP06om[7aP03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?n4OlGo
Q7o500KoQ7o500?o0000ohN3b?n7PlP00on7PlP00ol0003oUh[4oiN:a002oiN:a0;o00002onJTl/2
o`0000OoX:CH00?o0000ojNWe_nWYmH01?nWYmH4o`0000SoYko[1Ol000001?nDgOko0000o`000?l0
0003ohGDo`[o00000olQ[LT4ok2Qb@03o`000?nhZ<Wo^:S900Co^:S91ol00008ogW:o`Co00002onX
`>/4o`0000_o^[OF00?o0000oknnfOl000002oo:^l`2o`0000[oc[S50_l00008om[7aP03o`000?oo
oooooooo01cooooo00?o0000ooooool000006oooool0023ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01On7PlP0
1?l0003oUh[4oiN:a?l0000;oiZCb`;o00002OnPY=P01?l0003oYjOFojNWe_nWYmH3o`0000OoYko[
1Ol00003oiCMoP?o000000CoCLcDo`000?l0003o00001?lQ[LT3ojNLbP03o`000?n`XLWo/:7900Wo
/:7900?o0000okRXbOnhZ<T00onhZ<T3o`0000?o^:S900Co0000okn`bono/<_o00000_l7Ul/7o`00
00?oL/3n0_l0000;ojS0j`Co00001_nj]mH00ol0003o_kkIoknnf@02oknnf@03o`000?o:^lcob[_<
00Oob[_<00Co0000olZkc?l0003o00002?o>^<D00ol0003of<O9o`000008om[7aP03o`000?oooooo
oooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Eooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP2o`00
00_oVY?;0_l0000;oj2Tf0?o00001onW_n/4o`0000GoU=gn2Ol00009ojNLbP03o`000?n`XLWo/:79
00So/:7900?o0000okRXbOnhZ<T00ol00006okRXb@03o`000?no/<_o_k3;00?o_k3;0ol00002ojfm
i@04o`000?n^_^Ko0XcGo`:<e`GoL/3n0ol0000:ojS0j`?o00000_nj]mH00ol0003o_kkIoknnf@04
oknnf@;o00002?o:^l`01?l0003ob[_<olZkc?l00006oljha@05o`000?oHalWof<O9omS7bOl00000
2?oJalH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo000Oooooo`;o0000:?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7
PlP00ol0003oSHk?o`000009oiZCb`;o00002onPY=P2o`0000;oY[o[00?o0000ojNojonW_n/00_nW
_n/3o`0000KoU=gn1Ol000001OnW^NKo0000o`000?nNUlgo000000_oYic:00?o0000ok2QbOn`XLT0
2?n`XLT3o`0000So^:S900?o0000okn`bono/</01ono/</2o`0000Go[[kV00Co0000o`:<eol0003o
00000omb`?h4o`0000WoZ<3[0_l00009oknnf@;o00001oo:^l`00ol0003ob[_<olZkc002o`0000?o
c[S500?o0000omS7bOoHalT00ooHalT00ol0003of/O6om[7aP06om[7aP03o`000?oooooooooo01go
oooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP01Ol0003oSHk?
ohf>con=S/oo000000KoVY?;0_l0000;oj2Tf0;o00001?nV_n/3o`0000SoU=gn0ol00004ojNiiP;o
00001?nNUld00ol0003oYic:ojNLbP07ojNLbPgo000000?o^:S9o`000?l000000ol00004okRXb@03
o`000?no/<_o_k3;00So_k3;00Co0000olJicOl0003o00001On^_^H00ol0003o0XcGo`000003o`00
00;oL/3n1?l00006ojS0j`03o`000?nX`N_o000000Wo_kkI0_l00006olZkc004o`000?o:^lcob[_<
olZkc0;o000000?oc[S5o`000?oHalT01OoHalT00ol0003of/O6om[7aP06om[7aP03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0?ooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP00ol0
003oSHk?ohf>c`03ohf>c`04o`000?nJTl_oVY?;oiZCb`;o00002onPY=P2o`0000CoY[o[0_l00003
ojGRn`03o`000?nDgOkoU=gn00;oU=gn0_l00002ojJii`03o`000?nW^NKoYkWV00;oYkWV00?o0000
oijGcOnNUld01OnNUld00ol0003oYic:ojNLbP03ojNLbP?o00000_nTRkX00ol0003o/9>iok2C^@02
ok2C^@?o00000_n`TkT00ol0003o^ibiok^L^@04ok^L^@Go00002Ono/</00ol0003oa[W=olJic@02
olJic@;o00001_n^_^H2o`000004o`:<eol0003o0000o`0000?oL/3n0ol00002ojS0j`03o`000?nX
`N_oZ<7[00;oZ<7[0_l00008oknnf@03o`000?o:^lcob[_<00?ob[_<00?o0000olZkc?o:^l`00oo:
^l`00ol0003of<O9omS7b@06omS7b@03o`000?oJalKof/O600Kof/O600?o0000ooooooooool06ooo
ool2o`0001Sooooo000Oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool0
0ol0003oQ7o5ohAoa@06ohAoa@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01?n=S/l0
1?l0003oVY?;oiZCbol0000:oj2Tf0?o00001?nV_n/2o`0000GoYN;k0ol00002okGVmP03o`000?nV
^NOoY[WW00;oY[WW00Co0000ojNii_nW^NKo00002?nNUld00ol0003oYic:ojNLbP03o`0000GoY8^j
00?o0000ok2C^Ol000000_l00005ok2C^@03o`000?nkW;Wo^ibi00So^ibi00?o0000olFW^_o5YkX0
0ol00004okn`b`03o`000?o6^Lgoa[W=00Coa[W=00?o0000ojjni_n^_^H00_n^_^H00ol0003o[/3W
ojk0i`07o`0000?oL/3n0_l00007ojS1j`;o00001ono_]T2o`0000Cob[_<00?o0000olZkc?o:^l`0
0_o:^l`2o`0000Sof<O900?o0000om[7a_oJalH01_oJalH00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03?oo
ool00ol0003oQ7o5ohAoa@05ohAoa@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=
S/l2o`0000[oX:CH0_l00005ojJoj`;o00001OnUh_/4o`0000;o]NKf00?o0000ojJiionV^NL00onV
^NL2o`0000[oWYO=0ol00007ojB;^P?o00002?n`TkT00ol0003o^ibiok^L^@08ok^L^@03o`000?o5
Yk[oaJNj00?oaJNj0ol000000ono/<_o0000olJic@06olJic@;o000000?o[[kVo`000?n^`>L00on^
`>L00ol0003oL:_eog2[m@06o`0000?oL[Ok00?o0000ojS1jonX`N/01OnX`N/2o`0000Oo_kkI0_l0
0003olZkc004o`000?o:^lcob[_<o`0000;odLO@00?o0000omS7bOoHalT01_oHalT00ol0003of/O6
om[7aP06om[7aP03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool001oooooo0_l0
000]ooooo`03o`000?oooooooooo00[ooooo00?o0000ofefbol000001On4OlD00ol0003oQh?8ohN3
b006ohN3b003o`000?n=S/ooSHk?00GoSHk?00Co0000oiRRg?nHX]co00001onPY=P2o`0000GoY[o[
0_l00005ojGRn`Co00000onei_H6ojJii`03o`000?nCTm3o000000SoWYO=0_l000000onGPkco0000
ojB;^P04ojB;^P?o00000_nTRkX00ol0003o/9>iok2C^@06ok2C^@03o`000?nkW;Wo^ibi00Oo^ibi
00?o0000olFW^_o5YkX01oo5YkX00ol0003oa[W=olJic@08olJic@03o`000?n^`>Oo[/3W00Co[/3W
00Go0000og2[mOm`ZoGoL:_eoaMji003oa28i@GoL[Ok0_l00006ojS1j`03o`000?no_]Wo_kkI00Ko
_kkI00Co0000olZkc?o:^lcob[_<0_l00004om77d003o`000?oHalWof<O900Kof<O900?o0000om[7
a_oJalH01_oJalH00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000Nooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool01?l0003oKGK;ofefbol00003ohAo
a@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=S/l00ol0003oV:;LoiRRg002oiRR
g003o`000?nPY=SoX:CH00;oX:CH0_l00005ojJoj`;o00001OnUh_/3o`0000;o[OWS0onei_H5ojJi
i`;o00000onCTm000ol0003oWYO=oijGc@02oijGc@?o00001?nGPk`00ol0003oY8^jo`000002o`00
00GoY8^j00?o0000ok2C^On`TkT01_n`TkT00ol0003o^ibiok^L^@07ok^L^@03o`000?o5Yk[oaJNj
00OoaJNj00Co0000om2c_Ol0003o00001oo6^Ld00ol0003ocL?Aojk0i`05ojk0i`06o`000?m`ZoGo
L:_eog2[mOl0003o5g[T0ol@R>D00ol0003oL[Okog:gn`02og:gn`;o00001OnX`N/2o`0000Oo_kkI
0_l000000oo:^lco0000om77d005om77d003o`000?oHalWof<O900Kof<O900?o0000om[7a_oJalH0
1_oJalH00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool01oooool00ol0003oKGK;ofefb`02ofefb`03o`000?n4
OlGo000000SoQh?800?o0000ohf>con=S/l01On=S/l00ol0003oV:;LoiRRg004oiRRg004o`000?nP
Y=SoX:CHo`0000GoY[o[0_l00004ojGRn`Co00000on]nN<4o`0000CoY[WW00?o0000oi>Cd?nCTm00
1?nCTm001?l0003oWYO=o`000?l00006oiN3_0?o00002?nTRkX00ol0003o/9>iok2C^@06ok2C^@03
o`000?nkW;Wo^ibi00Oo^ibi00?o0000olFW^_o5YkX01_o5YkX00ol0003od;>mom2c_@02om2c_@;o
00001?o6^Ld01?l0003ocL?Aolg3dOo=`m42o`0000Co[/3W00Oo0000og2[mOm`ZoGoL:_eo`000?lG
N^CoM00000;o48SU0_l00004og:gn`;o00001OnX`N/2o`0000Oo_kkI0ol00006om77d003o`000?oH
alWof<O900Kof<O900?o0000om[7a_oJalH01OoJalH00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo000Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool0
0ol0003oKGK;ofefb`04ofefb`03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=S/l0
0ol0003oV:;LoiRRg005oiRRg0?o00001OnV_n/00ol0003oYN;kojGRn`02ojGRn`;o000000?oP^WS
oh?OY?l000001?l00002ol7Rl006o`000?nT^NSo0000o`000?nV^NOo00001onCTm02o`0000GoUh>l
0ol000000onGPkco0000ojB;^P06ojB;^Q7o00000onkW;T00ol0003oaJNjolFW^P07olFW^P03o`00
0?o@/kgod;>m00Cod;>m0_l000000oo6^Lgo0000olg3d@05olg3d@03o`000?n^`>Oo[/3W00;o[/3W
00So0000og2[mOm`ZoGoL:_eo`000?lGN^Co0000og@000;o48SU0_l00004og:gn`03o`000?nX`N_o
Z<7[00CoZ<7[0_l00004oknnf@03o`000?o3amco`lOL00;o00001_oAam000ol0003of<O9omS7b@06
omS7b@03o`000?oJalKof/O600?of/O600?o0000on?Ic?l000006oooool00ol0003oooooo`00000D
ooooo`007_ooool3o`00037ooooo0_l00005ooooo`03o`000?m]M/_oKGK;00CoKGK;00?o0000ohN3
b?n7PlP01On7PlP00ol0003oSHk?ohf>c`05ohf>c`03o`000?nHX]coV:;L00GoV:;L00Go0000ojJo
k?nV_ncoY[o/o`000002ojJoj`03o`000?nUh__oYN;k00;oYN;k0_l000000on2jN?oQn>Zoh?OY002
o`0000;oco[U00Co0000ol7Rl?o1h_3o00001?nT^NP00ol0003oTi?@oi>Cd005oi>Cd003o`000?n6
Nl3o000000;oUh>l0ol00005oiN3_003o`000?nTRk[o000000Co00000_nRP[400ol0003o[hb`ojn<
/006ojn</003o`000?nlU[3o_9J`00?o_9J`1_l00007olFW^P03o`000?o@/kgod;>m00Kod;>m00?o
0000olg3dOo=`m401_o=`m400ol0003o[/3Wojk0i`09o`000004o`19`_md003o0000oa28i@;o0000
0omb]o/2o`0000KoZ<7[0_l000000ono_]Wo0000ol?7g003ol?7g0;o00001_oAam000ol0003of<O9
omS7b@06omS7b@05o`000?oJalKof/O6om[7a_l000000_oSfL`00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo017ooooo000Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooo
ooooo`000006ofefb`03o`000?maNlko000000GoQh?800?o0000ohf>con=S/l01On=S/l00ol0003o
V:;LoiRRg005oiRRg003o`000?nV_ncoY[o/00;oY[o/1?l00003ojGRn`?o000000CoQn>Zoh?OY?o?
om?o00000_o?n^D01Ol0003o`N;`ol7Rl?o1h_3o000000CoY;WX00?oQY3Fo`000?nCTm001?nCTm00
0ol0003oQW_0ohIk`003o`0000OoUh>l0ol00007oj:2/@03o`000?n_S;3o[hb`00Ko[hb`00?o0000
okbF/?nlU[001_nlU[000ol0003ob:6aolRQ/@05o`000003olFW^_l0003od;>m00Sod;>m00?o0000
om[2`Ol000001oo=`m42o`0000;o[/;X00Co0000ogRTk_mhY>koN:C^0_lkO>@2o`000005o`19`_l0
003o04NZo`000?l@R>D00_l00003og:gn`;o00001OnX`N/2o`0000Ko`lOL00?o0000om77d?oAam00
1OoAam000ol0003of<O9omS7b@06omS7b@03o`000?oJalKo000000CohmW<00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Aooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0=?ooool01?l0003oooooooooool00005ofefb`05o`000?maNlkoLG_>og5k
c_l000000on7PlP00ol0003oSHk?ohf>c`05ohf>c`03o`000?nHX]coV:;L00GoV:;L00?o0000ojJo
k?nV_n`00_nV_n`00ol0003o/n?gok?Sm`02ok?Sm`?o000000KoVo;8o`000?n7hj[oPmnToloodol0
0002oloji@05o`000?o1h_3o`N;`ol7Rl?l000001?nT^NP01?l0003oQY3FohJ@e_l00003oi>Cd0Co
000000?oQW_0o`000?nGPk`01OnGPk`2o`000003oi9h/ol0003oXX:a00OoXX:a00?o0000ojn</?n_
S;001_n_S;000ol0003o_9J`okbF/006okbF/003o`000?o8XK7ob:6a00Gob:6a0ol00007om2c_@05
o`000?oJ`/7of/;1om[2`Ol000001Oo=`m42o`0000Co[/;X00Co0000ogRTk_mhY>koN:C^0olkO>@6
o`000003oa28iOl0003oL[Ok00?oL[Ok0_l000000onX`N_o0000o`000002ojS1k003o`000?o3amco
`lOL00Co`lOL00?o0000om77d?oAam001OoAam000ol0003of<O9omS7b@06omS7b@03o`000?oSfLco
hmW<00?ohmW<00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`004oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=_ooool2o`0000KoKGK;00?o0000
og5kc_maNlh00_maNlh00ol0003oQh?8o`000007ohf>c`03o`000?nHX]coV:;L00GoV:;L00?o0000
ojJok?nV_n`00_nV_n`00ol0003o/n?gok?Sm`02ok?Sm`03o`000?n`n>_o000000;oVo;800OoQn>Z
o`000?o?om?ocooCo`000?o?n^Go000000Co`N;`00?o0000ojBij?nT^NP00_nT^NP01?l0003oQY3F
ohJ@e_n6T=H4o`0000GoQW_000Co0000oiN3_?nGPkcoUh>l0_l00003oi9h/`03o`000?nRP[7oXX:a
00KoXX:a00?o0000ojn</?n_S;001_n_S;000ol0003o_9J`okbF/006okbF/003o`000?o8XK7ob:6a
00Kob:6a00Co0000omB_/ol0003o00001Oo@/kd00ol0003of/;1om[2`@02om[2`@05o`000?o=`m7o
cL?Aolg3dOl000000_oAd=P01Ol0003o[/;Xojk2j?n^`^So000000?oN:C^00?o0000oc]li?lkO>@0
0_l?G=@4o`000004o`1HcOl0003o0000o`0000;oL[Ok0ol00005ojS1k003o`000?o3amco`lOL00Co
`lOL00?o0000om77d?oAam001OoAam000ol0003of<O9omS7b@05omS7b@03o`000?oSfLcohmW<00?o
hmW<00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`Co000000?o410@oooooooo
ool00_ooool001?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ofefbom]M//00om]M//00ol0003oLG_>og5kcP04og5kcP03o`000?n=S/ooSHk?00Go
SHk?00?o0000oiRRg?nHX]`01OnHX]`00ol0003oY[o/ojJok002ojJok003o`000?nchoOo/n?g00;o
/n?g00?o0000ok3hjol000000_nKl/P01On7hj[ocOo8o`000?o?om?o000000;oco[U00Go0000ol7R
l?o1h_3o`N;`o`000004ojBij003o`000?n6T=KoQY3F00Co00001on6Nl001?l0003oUh>lo`000?l0
0006oi9h/`03o`000?nRP[7oXX:a00KoXX:a00?o0000ojn</?n_S;001On_S;000ol0003o_9J`okbF
/006okbF/003o`000?o8XK7ob:6a00Gob:6a00?o0000omB_/ooD[k<00_oD[k<01Ol0003od;>mom2c
_Oo@/kgo000000Kof/;100?o0000olg3dOl000000ooAd=P00ol0003o[/;Xojk2j002ojk2j005o`00
0?mhY>koN:C^ogRTk_l000000_lkO>@3o`mLe0?o000000?o05S=o`000?l/Qn`00_l00003ogJ_mP03
o`000?nX`NcoZ<7/00?oZ<7/00?o0000ol?7g?o3am`01?o3am`2o`0000KodLO@00?o0000omS7bOoH
alT00ooHalT00ol0003oh=W?o`000005on?Ic003o`000?oooooooooo01_ooooo0_l0000:ooooo`03
o`000?oooooooooo00Cooooo000Cooooo`05o`000?ooooooooooooooool000001Oooool2o`0003Oo
oooo00?o0000ofefbom]M//01?m]M//00ol0003oLG_>og5kcP04og5kcP03ogb9e_l0003oSHk?00Co
SHk?00?o0000oiRRg?nHX]`01?nHX]`2o`0000CoY[o/00Co0000ok?SmonchoOo/n?g0_l000002On`
n>_o0000oi_bb?nKl/SoQn>Zolgob?l0003ocooCo`000002oloji@03o`000?o1h_3o`N;`00;o`N;`
00Co0000ojBij?nT^NSoY;WX1?l00003ohJ@eP03o`000?n6Nl3oQW_000GoQW_00_l00008oi9h/`03
o`000?nRP[7oXX:a00KoXX:a00?o0000ojn</?n_S;001On_S;000ol0003o_9J`okbF/005okbF/003
o`000?o8XK7ob:6a00Kob:6a00?o0000omB_/ooD[k<00ooD[k<2o`000003om2c_Ol0003of/;100Ko
f/;100?o0000om7@f?oAd=P00ooAd=P00ol0003o[/;Xojk2j002ojk2j004o`000?mhY>koN:C^o`00
00?o>gcT0_l?G=@2o`1=c0;o000000Co05S=o`000?l/Qnco;8O/1?mf[oH00ol0003oZ<7/ojS1k003
ojS1k003o`000?o3amco`lOL00?o`lOL00?o0000ol?7g?l000001_oAam001Ol0003of<O9omS7bOoH
alWo000000;oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool001?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo03Kooooo00?o0000ofefbom]M//00om]M//00ol0003oLG_>og5k
cP04og5kcP04o`000?mlRMKoO8WFo`0000?oSHk?00?o0000oiRRg?nHX]`01?nHX]`00ol0003oY[o/
ojJok002ojJok0;o00000onchoL01?l0003o/?S[ok3hjol00002oi_bb003o`000?o=olSo000000;o
cooC3Ol00005ohJ@eP03o`000?m`L/Go000000GoQW_000?o0000ogi]]_l000002?nBN;<00ol0003o
XX:aoj:2/@06oj:2/@03o`000?n_S;3o[hb`00Go[hb`00?o0000okbF/?nlU[001OnlU[000ol0003o
b:6aolRQ/@06olRQ/@03o`000?oD[k?oe:nc00Goe:nc0_l00007om[2`@03o`000?oAd=SodM3H00?o
dM3H00?o0000ojk2j?n^`^P00_n^`^P01Ol0003oN:C^ogRTk_mhY>ko000000;o>gcT00?o0000o`mL
e?l?G=@00_l0CL`2o`000004o`1HcOl0003o;8O/obb7k0CoMZof00?o0000ojS1k?nX`N`00onX`N`0
0ol0003o`lOLol?7g003ol?7g003o`000?o3amco000000KodLO@00?o0000omS7bOl000001?oPfLl0
0ol0003ohmW<on?Ic003on?Ic003o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0=Oooool00ol0003oKGK;ofefb`03ofefb`03o`000?maNlkoLG_>00CoLG_>00?o0000
ogb9e_mlRMH00_mlRMH00ol0003oSHk?ohf>c`06oiRRg003o`000?nV_ncoY[o/00;oY[o/00?o0000
ok?SmonchoL00_nchoL00ol0003o/?S[ok3hj`03oi_bb005olkobol0003ocOo8o`000?o?om<00_l0
00000ooKkMko0000olKKj003olKKj0Ko00001?n6T=H01Ol0003oL7;5og1baOm`L/Go000000?oQW_0
00Go0000ogi]]_mnKKKoOVffo`000007oi9h/`03o`000?nRP[7oXX:a00KoXX:a00Co0000ojn</?n_
S;3o[hb`2Ol00003okbF/003o`000?o8XK7ob:6a00Gob:6a00?o0000omB_/ooD[k<01_oD[k<00ol0
003ohKnfo`000005om[2`@03o`000?oTdlKo000000CodM3H00Co0000ojk2j?n^`^So[/;X1_l00003
oc]li0;o3ecD00?o0000o`1=c?l0CL`00_l000001Ol0F<go0000obb7k?l/Qnco000000?oMZof00?o
0000ojS1k?nX`N`00onX`N`00ol0003o`lOLol?7g003ol?7g003o`000?o3amco000000GodLO@0_l0
0005on3Ic`03o`000?oSfLcohmW<00?ohmW<00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?m]M/_oKGK;00CoKGK;00?o0000og5kc_maNlh01?ma
Nlh00ol0003oO8WFogb9eP03ogb9eP;o00001OnHX]`00ol0003oY[o/ojJok002ojJok003o`000?nc
hoOo/n?g00;o/n?g00?o0000ok3hjon`n>/00onKl/P01?o>ol_o0000olgob?l00002olood`05o`00
0?oKkMkofngNo`000?o6fnP01?l00003oj>jj@;oN8oM00Go0000ohJ@e_n6T=KoQY3Fo`000004og1b
a@03o`000?n6Nl3o000000CoOVff00?o0000oi9h/onBN;<01OnBN;<00ol0003oXX:aoj:2/@04oj:2
/@Ko00001?n_Qj/00ol0003o_9:/okbB[002okbB[0Ko00001Oo8XK400ol0003oe:ncomB_/`05omB_
/`05o`000?oQ_kKohKnfon6o]_l000000ooJ`/401?l0003oi=?6onCCa_l00004om7@f0Co00000_n^
`nT3oh6Pi`?o000000Go>gcTo`000?l?G=Co3ecDo`000002o`1=c0;o000000Go05S=o`000?l/Qnco
;8O/o`000003ogJ_mP03o`000?nX`NcoZ<7/00?oZ<7/00?o0000ol?7g?o3am`00_o3am`01?l0003o
`lOLol?7g?l00003om77d003o`000?oGe]Oo000000Goh=W?00?o0000on?Ic?oSfL`01?oSfL`00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool001?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000=Oooool00ol0003oKGK;ofefb`03ofef
b`03o`000?maNlkoLG_>00CoLG_>00?o0000ogb9e_mlRMH01?mlRMH2ohjQh005o`000?nHX]coV:;L
oiRRg?l000001?nV_n`00ol0003o/n?gok?Sm`02ok?Sm`04o`000?n`n>_o/?S[oi_bb0;o000000Go
c_o;o`000?o=olSo0000olood`02o`0000;ofngN0ol00002olKKj003o`000?nS^^WoXk[Y00;oXk[Y
00Ko0000ogR?gOmhSmgo0000ohJ@e_l00006og1ba@03o`000?mnKKKoOVff00CoOVff00?o0000oi9h
/onBN;<01OnBN;<00ol0003oXX:ao`000003o`0000;oXGf/00?o0000ojn7Zon_Qj/01On_Qj/00ol0
003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00?o00000_o8XK400ol0003oe:ncomB_/`05omB_
/`03o`000?oQ_kKohKnf00;ohKnf00?o0000om[2`Ol000001?oTdlH01_l0003odM3Hom7@f?l0003o
dmgOo`0000Co[/?Y00Co0000oh6Pion1X>OoPJ3W0_mJOmd3o`000004o`mLe?l0003o04g<o`1=c0;o
0E7>00?o0000o`1HcOl000000_l/Qn`01Ol0003oMZofogJ_m_mf[oKo000000GoZ<7/00?o0000ol?7
g?o3am`00_o3am`01_l0003o`lOLol?7g?l0003odLO@o`0000?oemKG00?o0000on3IcooPfLl00ooP
fLl00ol0003ohmW<on?Ic003on?Ic003o`000?oooooooooo01_ooooo0ol00007ooooo`03o`000?oo
oooooooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000ofefbom]M//01?m]M//0
0ol0003oLG_>og5kcP03og5kcP03o`000?mlRMKoO8WF00CoO8WF00Go0000ohjQh?n>XN3oSZ7Po`00
0002oiRRg0GoY[o/1?nchoL3ok3hj`;o000000GocooIo`000?o>ol_o0000olgob002o`000006onGd
e?l0003o0000o`000?oKkMko00000oo6fnP00ol0003oXk[Yoj>jj@02oj>jj@05o`000?mhSmgoN8oM
ogR?gOl000001om`L/D00ol0003oOVffogi]]P04ogi]]P03o`000?nBN;?oTWRc00?oTWRc1?l00006
oj5m[003o`000?n_Qj_o[hN[00Go[hN[00?o0000okbB[?nlTZ`01OnlTZ`00ol0003obIj/olVN[003
olVN[0?o00001_oD[k<00ol0003ohKnfon6o]P04on6o]P03o`000?oTdlKoi=?600?oi=?600?o0000
om7@f?l000000_oCgMl00ol0003o[/?Yojk3j@02ojk3j@05o`000?n1X>OoPJ3Woh6Piol000001?mJ
Omd00ol0003o3ecDo`000002o`1=c0;o0E7>00?o0000o`1HcOl000000_l/Qn`01Ol0003oMZofogJ_
m_mf[oKo000000GoZ<7/00?o0000ol?7g?o3am`00_o3am`01?l0003o`lOLo`000?l00004omOFe`03
o`000?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00?oEEEEofIVI_l000001_ooool001cooooo00?o0000ooooooooool0
=?ooool00om;Jm7o0000ofefb`03ofefb`03o`000?maNlkoLG_>00CoLG_>00?o0000ogb9e_mlRMH0
0omlRMH00ol0003oSZ7PohjQh003ohjQh0?o00000onV_n`4ok?Sm`?o00000oo?omT01_l0003oc_o;
o`000?o=olSo0000onGde0?o00000_oKkMh00ol0003oa]_XolKKj002olKKj005o`000?nS^^WoXk[Y
oj>jjOl000001?mhSmd00om@Il_o0000og1ba@04og1ba@03o`000?mQGkWo000000GoOVff00?o0000
oi9h/onBN;<00ol00002oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01On_Qj/0
0ol0003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_l000000_l00003
omB_/`03o`000?oQ_kKohKnf00CohKnf00?o0000onCCa_oTdlH01?oTdlH01Ol0003odmgOom?MgooC
gMoo000000Co[/?Y00Go0000oh6Pion1X>OoPJ3Wo`000004oeYog@03od1Ydol?G=Co000000;o04g<
00?o0000o`5Ac_l1DLh00ol00002obb7k005o`000?mf[oKoMZofogJ_m_l000001OnX`N`01?l0003o
`lOLol?7g?o3am`2o`000003olK@h_l0003oemKG00CoemKG00?o0000on3IcooPfLl00ooPfLl00ol0
003ohmW<on?Ic003on?Ic003o`000?oooooooooo01cooooo0ol0000<ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;oBf_A00Co0000ofefbom]M/_o00001_maNlh00ol0003oO8WFogb9eP04ogb9
eP03o`000?n>XN3oSZ7P00?oSZ7P00?o0000ojJok?nV_n`01ol00002olcgj@05o`000?o?omWocooI
o`000?o>ol/01Ol000000ooUm=Co0000om_]gP02om_]gP05o`000?o6fnSoa]_XolKKj?l000001?nS
^^T00ol0003oN8oMogR?g@02ogR?g@;oD6O;00Go0000og1baOm`L/GoL7;5o`000002of5O^@03o`00
0?mnKKKoOVff00?oOVff0ol00005oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/0
1On_Qj/00ol0003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_oF[:h0
0_oF[:h2o`000003omB_/ol0003ohKnf00CohKnf00?o0000ongD^_l000001?oTdlH2o`0000CodmgO
00Go0000ojk3jOn^`nWo[/?Yo`000003oh6Pi`03o`000?mJOmgoFWoM00;oFWoM00Co0000od1Ydol?
G=Co00000_l0CL`01?l0003o0E7>oaaVf_lLI]X2o`0000;o;8O/00Go0000ogJ_m_mf[oKoMZofo`00
0005ojS1k005o`000?o3amco0000olK@h_l000000_o6d>800ol0003oemKGomOFe`02omOFe`03o`00
0?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Iooooo`?o0000
0_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`?oBf_A00?o
0000ofefbol000001_maNlh00ol0003oO8WFogb9eP03ogb9eP03o`000?n>XN3oSZ7P00?oSZ7P00?o
0000ojJok?nV_n`00_nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;oc?OY00Co0000oloofOo?omWo
cooI1Ol00003onGde005o`000?oKkMkofngNom_]g_l000000_o6fnP8o`0000?oN8oM00Ko0000oe1W
bom@Il_o0000og1baOl00004of5O^@07o`000?mnKKKoOVffogi]]_l0003oNFF`o`000007oi1b[@03
o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/00ol0003o_9:/okbB[005okbB[003
o`000?o9WZcobIj/00?obIj/00?o0000omJ/[_oF[:h01OoF[:h00ol0003ohKnfon6o]P04on6o]P04
o`000?o]e;[okMBjo`0000;oi=?600?o0000on[YcOl000001?oCgMl01Ol0003o[/?Yojk3jOn^`nWo
000000CoPJ3W00Go0000oeYogOmJOmgoFWoMo`000002od1Yd`04o`000?l0CLco04g<o`0000;o0E7>
0olLI]X2o`000003obb7k?l0003oMZof00;oMZof00?o0000ojS1k?nX`N`00_nX`N`2o`0000?oa]3R
00?o0000olK@h_l000001OoGe]L00ol0003oh=W?on3Ic`03on3Ic`03o`000?oSfLcohmW<00?ohmW<
00?o0000ooooooooool05Oooool3o`0000Gooooo00?o0000ooooooooool02_ooool001cooooo0_l0
000eooooo`05o`000?m;Jm7oBf_Aod][dOl000001_maNlh00ol0003oO8WFogb9eP03ogb9eP03o`00
0?n>XN3oSZ7P00?oSZ7P00?o0000ojJok?nV_n`00_nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;o
c?OY00?o0000oloofOo?omT01?l00002onSfc`05o`000?oUm=CoiOCDonGde?l000000ooKkMh3o`00
0003olSBhOnR^n[oX[_Z00?oX[_Z0_mUSnD00ol0003oN8oMo`000004oe1Wb`03o`000?mQGkWoHEni
00?oHEni00Co0000ogi]]_mnKKKo00000omiIK000ol0003oT7:]oi1b[@04oi1b[@03o`000?nQOJco
XGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/00ol0003o_9:/okbB[004okbB[003o`000?o9WZco
bIj/00CobIj/00?o0000omJ/[_oF[:h01OoF[:h2o`0000CohKnf00Oo0000ongD^_o]e;[okMBjo`00
0?oTdlKo000000;oj^W=00?o0000om?MgooCgMl00_oCgMl01Ol0003o[/?Yojk3jOn^`nWo000000Co
PJ3W00Go0000oeYogOmJOmgoFWoMo`000003od1Yd`;o000000Co04g<o`000?l1DLko0E7>0_lLI]X2
odR6j0?o00000omf[oH01_l0003oZ<7/o`000?l0003oZ<;/o`0000Coa]3R0_l00005omOFe`03o`00
0?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Booooo`?o0000
2?ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`06o`000?m;
Jm7oBf_Aod][dOmCLmGo00001?maNlh00ol0003oO8WFogb9eP04ogb9eP03o`000?n>XN3oSZ7P00?o
SZ7P00Go0000ojJok?nV_ncoY[o/o`000004okgOl@03o`000?o<mnWoc?OY00Ko00000ooXm/l01Ol0
003oiOCDonGde?oUm=Co000000;ofngN0_l00003olSBh@03o`000?nR^n[oX[_Z00;oX[_Z00?o0000
ofF?iOmUSnD00_l00004oe1Wb`03o`000?mQGkWoHEni00?oHEni00?o0000ogi]]_l000001?miIK00
0ol0003oT7:]oi1b[@04oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/0
0ol0003o_9:/okbB[004okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_oF[:h01?oF[:h0
1?l0003oi;f`onBm/?l00002on6o]P03o`000?o]e;[okMBj00?okMBj00?o0000on[YcOoZjLd00_oZ
jLd00ol0003odmgOom?Mg`09o`000003oh6Piol0003oFWoM00;oFWoM00Co0000od1Ydom0JM?o@6WC
0_lfGlh2o`0000;o0E7>00?o0000oaaVf_lLI]X01?m8Q^P5o`0000CoZ<;/00?o0000olK@h_o6d>80
0_o6d>82o`0000GoemKG00?o0000on3IcooPfLl00_oPfLl00ol0003ohmW<on?Ic002on?Ic0;o0000
4?ooool4o`0000_ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0=Ooo
ool01?l0003oBf_Aod][dOm;Jm42oe=ce@05o`000?maNlkoLG_>og5kc_l000001OmlRMH00ol0003o
SZ7PohjQh003ohjQh003o`000?nV_ncoY[o/00;oY[o/00Co0000okgOlOnmgo7o_Moa1?l00002oloo
f@;o000000?oioK@o`000?oXm/l00_oXm/l00ol0003oiOCDonGde004o`000003omcLe_l0003ob=;Q
00?ob=;Q00Go0000oj:kj_nR^n[oX[_Zo`000003ofF?i@03o`000?m@Il_oD6O;00;oD6O;00?o=4Zk
o`000?mQGkT01?mQGkT00ol0003oNFF`ogUU/003ogUU/003o`000?n@LZgoT7:]00CoT7:]00?o0000
oj5m[?nQOJ`01OnQOJ`00ol0003o[hN[ojn7Z`04ojn7Z`03o`000?nlTZco_9:/00Co_9:/00?o0000
olVN[?o9WZ`01?o9WZ`00ol0003oeZb^omJ/[P04omJ/[P07o`000?oT_K3oi;f`onBm/?l0003ohKnf
o`000005ongD^P03o`000?oZjLgoj^W=00;oj^W=0ol000000ooAj^Oo0000ojg4j`02ojg4j`CoRYgP
0ol00002oeYog@05o`000?m0JM?o@6WCod1Ydol000000_lfGlh01?l0CLco0000o`5Ac_l1DLh2oaaV
fP04o`000?m8Q^SoB8KXodR6j0CoO:S_1OnX`^`00ol0003oa]3RolK@hP02olK@hP;o00001OoGe]L0
0ol0003oh=W?on3Ic`03on3Ic`06o`000?oSfLcohmW<o`000?oWkm;o00003Oooool3o`00013ooooo
00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Oooool01?l0003oBf_Aod][
dOm;Jm43oe=ce@03o`000?maNlko000000KoO8WF00?o0000ohjQh?n>XN000on>XN001Ol0003oY[o/
ojJok?nV_nco000000;o_Moa0ol000000oo<mnWo0000oloof@02oloof@04o`000?oWm]3oioK@o`00
00;oj?K?00Go0000onGde?oUm=CoiOCDo`000004omcLeP03o`000?o8d^7ob=;Q00;ob=;Q00?o0000
oj:kj_nR^nX00_nR^nX01Ol0003oIHoUofF?iOlPElko000000?oD6O;0_l00005of5O^@03o`000?mi
IK3oNFF`00CoNFF`00?o0000oi1b[On@LZd00on@LZd00ol0003oXGf/oj5m[003oj5m[0ko00000_nl
TZ`00ol0003obIj/olVN[004olVN[003o`000?oF[:koeZb^00?oeZb^00?o0000onBm/?oT_K000ooT
_K000ol0003okMBjongD^P03ongD^P;o00001?oZjLd01Ol0003odN[Wom7ZiooAj^Oo000000?o[LC[
1On:WN02og62e003o`000?mJOmgo000000?o@6WC00Go0000ocIOc_lfGlko=Uo>o`000002o`5AcP04
o`000?lLI][o76KJo`0000?oB8KX1?mlZ>l5ojS2k003o`000?o6d>;oa]3R00;oa]3R0_l00005omOF
e`03o`000?oPfLooh=W?00;oh=W?00?o0000on?Ic?l000000_oWkm800ol0003oooooooooo`08oooo
o`?o00004oooool00ol0003oooooooooo`09ooooo`006oooool00ol0003oooooooooo`0eooooo`05
o`000?m;Jm7oBf_Aod][dOl000000omCLmD00ol0003oO8WFogb9eP04ogb9eP03o`000?n>XN3oSZ7P
00?oSZ7P00?o0000ojJok?nV_n`00_nV_n`3o`000005okgOlOl0003oc?OYolcgjOl000000_o?omT0
1Ol0003oioK@onOfd?oWm]3o000000;oj?K?00?o0000onGde?oUm=@00_l00005omcLeP05o`000?o8
d^7ob=;QolSBhOl000001?nR^nX02?l0003oIHoUofF?iOl0003o85O>o`000?m@Il_o00000_ldB[/0
1ol0003oHEniof5O^OmQGkWo0000oeUD/_l000001OmiIK000ol0003oT7:]oi1b[@04oi1b[@03o`00
0?nQOJco000000;o00000_nPNjX00ol0003o[hJYojn6Z@04ojn6Z@03o`000?nlTJWo_96Y00;o_96Y
1_l00002olVN[003o`000?oF[:koeZb^00CoeZb^00?o0000onBm/?oT_K000ooT_K000ol0003okMBj
ongD^P03ongD^P;o00000ooZjLd2o`0000;odN[W00Go0000ojg4jon]a>_o[LC[o`000004ohZMh006
o`000?maP]CoLH;Dog62e?mJOmgo00000om0JM<00ol0003o=Uo>ocIOcP02ocIOcP;o000000Co0E7>
o`000?lLI][o00000om8Q^P01Ol0003oO:S_ogbXkomlZ>oo000000CoZ<;/00?o0000olK@h_o6d>80
0oo6d>800ol0003oemKGomOFe`03omOFe`03o`000?oPfLooh=W?00;oh=W?0_l00003onO_dP03o`00
0?oooooooooo00Gooooo0ol0000Fooooo`03o`000?oooooooooo00Wooooo000Kooooo`;o0000=Ooo
ool00ol0003oBf_Aod][d@02od][d@06o`000?mCLmGoDg?Eoe=ceOmWQMgo00001?mlRMH00ol0003o
SZ7PohjQh003ohjQh003o`000?nV_ncoY[o/00?o00000onmgo401Ol0003oc?OYolcgjOl0003ocooI
00;o00000ooWm]001ol0003oj?K?onSfcooXm/oo0000onGde?l000000_oVh<h00ol0003og=cFomcL
eP02omcLeP05o`000?o8d^7ob=;QolSBhOl000001?nR^nX01?l0003oIHoUofF?iOl00002ob1GcP;o
00000oldB[/00ol0003oHEnio`000002oeUD/P03o`000?miIK3oNFF`00?oNFF`00?o0000oi1b[On@
LZd00on@LZd3o`0000GoX7^Z00?o0000ojn6ZOn_QZT01?n_QZT00ol0003o_96YokbAZ@04okbAZ@04
o`000?o9WJ[obIfZolVMZPCo00001OoF[:h00ol0003oi;f`onBm/002onBm/003o`000?oadk;o0000
00?okMBj00Go0000ooC/^oodk;_o0000on[Yc@02o`0000?odN[W00Go0000ojg4jon]a>_o[LC[o`00
0004ohZMh003o`000?maP]CoLH;D00;oLH;D0_l00003od1Yd`04o`000?lfGlko=Uo>ocIOcP;o>6;@
00Go0000o`5Ac_l0003o76KJo`000003odR6j005o`000?mlZ>ooO:S_ogbXkol000001?nX`^`00ol0
003oa]3RolK@hP02olK@hP;o00001OoGe]L01_l0003oh=W?on3Icol0003oi>gFo`0000?oinoB00?o
0000ooooooooool00_ooool3o`0001Wooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000
ooooooooool0=?ooool00ol0003oBf_Aod][d@02od][d@04o`000?mCLmGoDg?Eoe=ce@;oIhGM00Go
0000ogb9e_mlRMKoO8WFo`000005ohjQh0?o000000?oY[o/o`000?nmgo400onmgo400ol0003oc?OY
olcgj@02o`000003on;bf?l0003oioK@00;oioK@00Co0000onSfcooXm/ooj?K?0_l00003onKPcP03
o`000?oLg=Kog=cF00;og=cF00?o0000olSBhOo8d^400_o8d^400ol0003oX[_Zo`000003o`0000;o
IHoU00Co0000ob1Gc_lPElko00000oldB[/00ol0003oHEnio`000003oeUD/P03o`000?miIK3oNFF`
00?oNFF`00?o0000oi1b[Ol000000_l000000on?Kj_o0000oj1kZP05oj1kZP03o`000?n_QZWo[hJY
00Co[hJY00?o0000okbAZOnlTJT01?nlTJT00ol0003obIfZolVMZP03olVMZP04o`000?oGZjco0000
o`0000;oeZb^00?o0000onBm/?oT_K000ooT_K001_l0003olM>boo7C/_l0003okMBjo`0000?om>bk
0_l000000ooRo<go0000om7Zi`02om7Zi`05o`000?n]a>_o[LC[ojg4jol000001?n:WN000ol0003o
LH;Dog62e002og62e0;oHW7<00Co0000od1Ydom0JM?o00000olfGlh01Ol0003o>6;@ocQRd?lhH]3o
000000;o76KJ00Co0000odR6j?m8Q^So00000omlZ>l00ol0003oZ<;/ojS2k002ojS2k003o`000?o6
d>;oa]3R00?oa]3R00?o0000omOFeooGe]L00ooGe]L00ol0003oh=W?o`000002onC]eP04o`000?oW
km;oinoBonO_dPGo00007?ooool00ol0003oooooooooo`09ooooo`006oooool00ol0003ooooooooo
o`0dooooo`03o`000?m;Jm7oBf_A00;oBf_A00Co0000oe=ceOmCLmGoDg?E0omWQMd00ol0003oO8WF
o`000003ohjQh0?o00001?nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;oc?OY00Go0000on;bf?oR
l]Soh_;Ho`000003onOfd005o`000?oXm/ooj?K?onSfcol000001?oVh<h00ol0003og=cFomcLeP02
omcLeP04o`000?o8d^7ob=;QolSBh@?o00000_nQ_>`01Ol0003oCi3]o`000?mUSnGo000000;o85O>
00?o0000ocA:^oldB[/00_ldB[/00ol0003oFEBboeUD/P02oeUD/P03o`000?miIK3oNFF`00?oNFF`
0_l00004ohm_Z`03o`000?nPNj[oX7^Z00CoX7^Z00?o0000ojn6ZOn_QZT01?n_QZT00ol0003o_96Y
okbAZ@03okbAZ@03o`000?o9WJ[obIfZ00CobIfZ00Oo0000omN[[?oGZjcoej^/o`000?oF[:ko0000
00Coi;f`00Oo0000oo7C/_oadk;olM>bo`000?o]e;[o000000?om>bk00Co0000on;lcOoRo<go0000
0_oAj^L01Ol0003o[LC[ojg4jon]a>_o000000CoRYgP00?o0000og62e?maP]@00_maP]@01ol0003o
HW7<of9ac?mRLLco0000od1Ydol000000olfGlh00ol0003o>6;@ocQRd002ocQRd003o`000?lLI][o
000000?oB8KX00Go0000ogbXkomlZ>ooO:S_o`000004ojS2k003o`000?o6d>;oa]3R00;oa]3R0_l0
0004omOFe`;o00000ooTkMH01Ol0003oinoBonO_d_oWkm;o0000023ooooo00?o0000ooooooooool0
2Oooool001[ooooo00?o0000ooooooooool0=Oooool00ol0003oBf_Aod][d@02od][d@05o`000?mC
LmGoDg?Eoe=ceOl000000omWQMd5o`0000;oSZ7P00Go0000ojJok?nV_ncoY[o/o`000003okgOl@04
o`000?o<mnWo0000o`0000Coh_;H00Go0000onOfd?oWm]3oioK@o`000002onSfc`;o00001OoVh<h0
0ol0003og=cFomcLeP02omcLeP?o000000?oalWKo`000?nQ_>`00onQ_>`00ol0003oCi3]odn@k@02
o`000003ob1Gc_l0003o000000?o=4Zk00?o0000oeUD/_mIE;800_mIE;800ol0003oNFF`ogUU/002
ogUU/0;o00001_n?Kj/00ol0003oX7^Zoj1kZP03oj1kZP03o`000?n_QZWo[hJY00Co[hJY00?o0000
okbAZOnlTJT00onlTJT00ol0003obIfZolVMZP03olVMZP03o`000?oGZjcoej^/00?oej^/0_l00004
onBm/003o`000?oadk;olM>b00;olM>b00Co0000ooC/^oodk;_om>bk0_l000000ooRo<go0000om7Z
i`08o`0000?oRYgP00?o0000og62e?maP]@00_maP]@00ol0003oHW7<of9ac002of9ac003od1Ydol0
003o=Uo>00;o=Uo>00?o0000ocQRd?lhH]000_lhH]02odM_eP05oaaVf_l0003oB8KXodR6j?l00000
0omlZ>l00ol0003oZ<;/ojS2k002ojS2k003o`000?o6d>;oa]3R00?oa]3R0_l00002omOFe`03o`00
0?oIi]ko000000?oi>gF00Go0000onO_d_oWkm;oinoBo`00000Pooooo`03o`000?oooooooooo00Wo
oooo000Jooooo`?o0000=Oooool01Ol0003oBf_Aod][dOm;Jm7o000000CoDg?E00?o0000ofN5gOmW
QMd01_l000000on>XN3o0000ojJok003ojJok004o`000?nmgo7o_MoaokgOl@;o000000?oen[Ro`00
0?oRl]P00ooRl]P02Ol0003oioK@onOfd?oWm]3o0000onSfcol0003ojN7:o`000005onKPcP04o`00
0?oLg=Kog=cFomcLeP;o00001?o7bM/00ol0003oXKc/oj6lk002oj6lk008o`000?m?T>go0000o`0l
_ol0003o85O>o`0W/Ol00002ocA:^`;o00001?mIE;801_l0003oNFF`ogUU/?l0003oMf:]o`0000Ko
Sfn[00?o0000oj1kZ_nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJWo_96Y00?o
_96Y00?o0000olVMZ_o9WJX00oo9WJX00ol0003oej^/omN[[003omN[[003o`000?oU_:go000000;o
i;f`00?o0000oo7C/_oadk800ooadk800ol0003om>bkooC/^`02o`000004on;lcOl0003o0000o`00
00;oaOC^00Ko0000ojc5k?n/aNco[<G/o`000?nCWMX2o`000003ohZMh?l0003oLH;D00?oLH;D00?o
0000of9ac?mRLL`00omRLL`01Ol0003o=Uo>ocIOc_lfGlko000000Co>6;@00Co0000odM_e_m7KmKo
00000om8Q^P01Ol0003oO:S_ogbXkomlZ>oo000000CoZ<;/00?o0000olK@h_o6d>800_o6d>801?l0
003oemKGo`000?l00002omWVgP05o`000?oTkMKoi>gFonC]e_l000000ooWkm800ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000
od][dOm;Jm7oBf_Ao`000004oe=ce@?o000000?oIhGMohBQi_n4XNH00on4XNH3o`0000;oY[o/00?o
0000okgOlOl000000_l00003omOZhP03o`000?oRl]Soh_;H00;oh_;H00Ko0000onOfd?oWm]3o0000
onSfcol00003onWQbP03o`000?oVh<koi^3>00;oi^3>00Ko0000omcLe_oLg=Ko0000omS<c_l00005
olO9f`03o`000?nQ_>coXKc/00;oXKc/00Oo0000odn@kOl0003o03boob1Gc_l0003o02Na00;o0000
00?o8cV`o`000?mIE;800omIE;800ol0003oNFF`o`000003ogMR[@03o`000?n?Kj_oSfn[00?oSfn[
00?o0000oj1kZ_nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJWo_96Y00?o_96Y
00?o0000olVMZ_o9WJX00oo9WJX00ol0003oej^/omN[[003omN[[006o`000?oU_:goiKb]o`000?oT
_K3o00001?oadk82o`000003ooC/^ol0003ohOV[00?o00000oo5m>h01Ol0003o[<G/ojc5k?n/aNco
000000CoTigJ00?o0000og62e?maP]@00_maP]@00ol0003oHW7<of9ac004of9ac005o`000?lfGlko
=Uo>ocIOc_l000001?lhH]001?l0003oAfoFodM_e_m7KmH2o`000003odR6j?l0003oO:S_00;oO:S_
00?o0000ojS2k?nX`^`00_nX`^`00ol0003oa]3RolK@hP02olK@hP03o`000?oGe]Oo000000?ofNKN
00Go0000onC]e_oTkMKoi>gFo`000003onO_dP03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0eooooo`06o`000?m;Jm7oBf_Aod][dOl0003oDg?E1?l0
0003ofN5g@03o`000?n4XNKoQ:7V00;oQ:7V00?o0000ojFok?nU_n`01?l00002ol?JjP05o`000?oG
j^;oen[RomOZh_l000000ooRl]P01?l0003oioK@onOfd?oWm]02o`0000CojN7:00?o0000onKPc_oV
h<h00ooVh<h2o`0000?of<c>00?o0000olO9foo7bM/00oo7bM/00ol0003oXKc/oj6lk002oj6lk005
o`000?m?T>go0000o`0l_ol000000_l09k401?l0003o8cV`ob<i/?l00004oeUD/P03o`000?mgHZgo
Mf:]00;oMf:]00?o0000ohm_Zon?Kj/00on?Kj/00ol0003oX7^Zoj1kZP04oj1kZP03o`000?n_QZWo
[hJY00?o[hJY00?o0000okbAZOnlTJT00onlTJT00ol0003obIfZolVMZP03olVMZP03o`000?oGZjco
ej^/00;oej^/00?o0000onFl[OoU_:d00_oU_:d00ol0003olM>boo7C/P03oo7C/P?o00000_oQnJ/2
o`0000?oaOC^00Go0000ojc5k?n/aNco[<G/o`000005oi>MfP03oh>5cOl0003oLH;D00;oLH;D00?o
0000of9ac?mRLL`00omRLL`00ol0003oG6_8o`000002ocIOcP03o`000?lhH]3o>6;@00;o>6;@00Co
0000odM_e_m7KmKoAfoF0_mRQ^000ol0003oB8KXo`000003ogbXk`03o`000?nX`^coZ<;/00;oZ<;/
00Co0000olK@h_o6d>;oa]3R0_l000001OoIi]ko0000omWVg_oIi]ko000000?oi>gF00Go0000onO_
d_oWkm;oinoBo`00000Qooooo`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000
od][dOm;Jm400ol00002oe=ce@03o`000?mWQMgoIhGM00;oIhGM00?o0000ohBQi_n4XNH00_n4XNH0
1Ol0003oYKo/ojFok?nU_nco000000Co`m[Z00Go0000omOZh_oGj^;oen[Ro`000003on;bf005o`00
0?oWm]3oioK@onOfd?l000001OoYhLX00ol0003oi^3>onKPcP03onKPcP03o`000?oHc<kof<c>00?o
f<c>00?o0000olO9foo7bM/00oo7bM/00ol0003oXKc/oj6lk006o`0000;o02Na00Go0000ob<i/?lS
>K3o8cV`o`000002oeUD/P;o00001?mgHZd00ol0003oSfn[ohm_Z`03ohm_Z`03o`000?nPNj[oX7^Z
00CoX7^Z00?o0000ojn6ZOn_QZT00on_QZT00ol0003o_96YokbAZ@02okbAZ@03o`000?o9WJ[obIfZ
00CobIfZ00?o0000omN[[?oGZj`00_oGZj`00ol0003oiKb]onFl[@02onFl[@03o`000?oadk;olM>b
00;olM>b00?o0000ooS/[_l000000_oQnJ/2o`0000?oaOC^00Go0000ojc5k?n/aNco[<G/o`000005
oi>MfP04o`000?n3QLgoPhG=o`0000;oLH;D00?o0000of9ac?mRLL`00omRLL`01_l0003oG6_8oea[
b?l0003o=Uo>o`0000Co>6;@00Go0000odM_e_m7KmKoAfoFo`000003of:6h005o`000?mlZ>ooO:S_
ogbXkol000001?nX`^`01_l0003oa]3Ro`000?l0003oa]WXo`0000;ofNKN00?o0000omWVg_l00000
0ooTkMH01Ol0003oinoBonO_d_oWkm;o0000027ooooo00?o0000ooooooooool02?ooool000?ooooo
00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo
0ol000000om;Jm7o0000oe=ce@02oe=ce@03o`000?mWQMgoIhGM00;oIhGM00?o0000ohBQi_n4XNH0
0_n4XNH01Ol0003oYKo/ojFok?nU_nco000000Co`m[Z00Go0000omOZh_oGj^;oen[Ro`000003on;b
f003o`000?oWm]3oioK@00;o00001_oYhLX00ol0003oi^3>onKPcP02onKPcP03o`000?oHc<kof<c>
00Cof<c>00?o0000olO9foo7bM/00oo7bM/2o`0000CoXKg]0ol000000ol09k7o0000o`000002ob<i
/003o`000?mIE;;o000000;oEDn^00?o0000ogMR[OmgHZd00_mgHZd00ol0003oSfn[ohm_Z`03ohm_
Z`03o`000?nPNj[oX7^Z00?oX7^Z00?o0000ojn6ZOn_QZT01ol000000onlTJWo0000olVMZP04olVM
ZP03o`000?oGZjcoej^/00?oej^/00Oo0000onFl[OoU_:goiKb]o`000?ocdZko000000;olM>b00Co
0000ooS/[_ohk:ko00000_oQnJ/01Ol0003oaOC^olGdk_o5m>ko000000?o[<G/00?o0000oi>Mf_nC
WMX00onCWMX00ol0003oPhG=oh>5c@02oh>5c@;o00001_mRLL`01_l0003oG6_8oea[b?mLJlSo=Uo>
o`0000Co>6;@00Go0000odM_e_m7KmKoAfoFo`000004of:6h0[o00000oo6fNP01_l0003ofNKNomWV
g_l0003ofNKNo`0000?oi>gF00Go0000onO_d_oWkm;oinoBo`00000Qooooo`03o`000?oooooooooo
00Sooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool3o`0003?o
oooo1?l000001?lHF];o0000od][dOl00003oe=ce@03o`000?mWQMgoIhGM00;oIhGM00Go0000ohBQ
i_n4XNKoQ:7Vo`000004ojFok005o`000?o3f^[o`m[Zol?Jj_l000001?oGj^802Ol0003oh_;Hon;b
f?oRl]So0000onOfd?l0003oj>7;o`000006onWQbP07o`000?oVh<koi^3>onKPc_l0003oglg6o`00
0006omS<cP05o`000?o7bM_oalWKolO9fol000000_o4`ML5oj6mk@06o`000?m_003o0000o`0W/Ol0
2I_o00000_lS>K001Ol0003oEDn^oeE?[_mECjko000000CoMf:]00?o0000ohm_Zon?Kj/00on?Kj/0
0ol0003oX7^Zoj1kZP06o`0000?o[hJY00Co0000okbAZ_nlTJ[o_96Z1Ol00002olVMZP03o`000?oG
Zjcoej^/00;oej^/00?o0000onFl[OoU_:d00_oU_:d01ol0003olm:^oo?B[_l0003olM>bo`000?oh
k:h00_l000000ooQnJ_o0000o`000005o`000003ojc5k?l0003oTigJ00CoTigJ00?o0000oh>5cOn3
QLd01?n3QLd00ol0003oHW7<of9ac003of9ac003o`000?mLJlSoG6_800?oG6_80_l00003ocQRd005
o`000?m7KmKoAfoFodM_e_l000001?mRQ^04ohBTj@03o`000?nX`^coZ<;/00;oZ<;/00Go0000olKI
j?o6fNSoa]WXo`000003omWVgP;o00000ooTkMH01Ol0003oinoBonO_d_oWkm;o0000027ooooo00?o
0000ooooooooool02?ooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_lHF]82o`0000?oDg?E00?o
0000ofN5gOmWQMd00_mWQMd01Ol0003oQ:7VohBQi_n4XNKo000000CoYKo/00Go0000ol?Jj_o3f^[o
`m[Zo`000003omOZhP03o`000?oRl]Soh_;H00;oh_;H0_l00003onSQb`03o`000?oYhL[ojN7:00?o
jN7:00Co0000onKPc_oVh<ko00000ooOcLH00ol0003of<c>omS<cP04omS<cP03o`000?o7bM_o0000
00Coa<7G00?o0000oj6mkOnQ_Nd00_nQ_Nd02?l0003o001oo`0W/Ol0003o00VKo`000?lS>K3o0000
1?mECjh01Ol0003oMf:]ogMR[OmgHZgo000000CoSfn[1?l00003oj1kZP03o`000?n_QZWo[hJY00?o
[hJY00?o0000okbAZ_nlTJX00_nlTJX01?l0003obIf[olVMZoo9WJ/4o`0000?oej^/00?o0000onFl
[OoU_:d00_oU_:d01Ol0003olm:^oo?B[_ocdZko000000;on>b^00?o0000on7iZol000000_n[mO00
1?l0003oZlG]oj_5kOn[aNd3o`0000CoTigJ00?o0000oh>5cOn3QLd01On3QLd00ol0003oHW7<of9a
c003of9ac003o`000?mLJlSoG6_800?oG6_80_mNK<T01?l0003o>6;@ocQRd?l00003odM_eP03o`00
0?mRQ^3oHXKP00;oHXKP00Go0000ohBTjOn4Y>WoQ:CYo`000004ojS2k005o`000?o6fNSoa]WXolKI
j?l000001?oIi]h01Ol0003oi>gFonC]e_oTkMKo000000?oinoB00?o0000ooooooooool07oooool0
0ol0003oooooooooo`08ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;_ooool3o`0000Kooooo00?o0000oaQJd_lHF]800_l00002oe=c
e@05o`000?mWQMgoIhGMofN5gOl000001?n4XNH00ol0003oYKo/ojFok002ojFok005o`000?o3f^[o
`m[Zol?Jj_l000000ooGj^801?l0003oh_;Hon;bf?oRl]P2o`0000Coj>7;00?o0000onWQb_oYhLX0
1?oYhLX2o`0000Goglg600?o0000omS<c_oHc<h01?oHc<h00ol0003oa<7GolC1e`04olC1e`;o0000
0onQ_Nd01_l0003o001oo`000?l02I_o0000ob<i/0;o00000omECjh00ol0003oMf:]ogMR[@02ogMR
[@Co000000?oSg2/o`000?nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJ[o_96Z
00;o_96Z00?o0000olVMZoo9WJ/00oo9WJ/00ol0003oeZ^/o`000002omN[[005o`000?oU_:goiKb]
onFl[Ol000001?ocdZh00ol0003on>b^o`000002o`000003oj_el?l0003o000000?oZlG]00Co0000
oi^Ne_nKW]KoVikF0_l000000onCWM[o0000oh>5c@06oh>5c@03o`000?mjN<Go000000?oHW7<00?o
0000oea[b?mLJlP01?mLJlP3oei/b@03o`000?lhH]3o000000?oAfoF00?o0000of:6h?mRQ^000_mR
Q^001Ol0003oQ:CYohBTjOn4Y>Wo000000CoZ<;/00Go0000olKIj?o6fNSoa]WXo`000004omWVgP;o
00000_oTkMH00ol0003oinoBonO_dP02o`0002;ooooo00?o0000ooooooooool01oooool00004oiRH
V?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`?o
00002Oooool00ol0003o65[BoaQJdP02obMVf003o`000?mCLmGo000000?oIhGM00?o0000ohBQi_n4
XNH00_n4XNH00ol0003oYKo/ojFok002ojFok005o`000?o3f^[o`m[Zol?Jj_l000000ooGj^801_l0
003oh_;Hon;bf?l0003ohmo@o`0000Coj>7;00?o0000onWQb_oYhLX01?oYhLX00ol0003oglg6omo=
aP04omo=aP03o`000?oHc<kof<c>00?of<c>00Co0000om6ob?oA_lSo00001_o4`ML01?l0003oXKg]
oj6mkOnQ_Nd2o`0000;o00VK00?o8cV`o`000?l000000omECjh00ol0003oMf:]ogMR[@02ogMR[@03
o`000?n?L:coSg2/00;oSg2/00?o0000oj1kZ_nPNjX00onPNjX00ol0003o[hJYojn6Z@03ojn6Z@03
o`000?nlTJ[o_96Z00;o_96Z00?o0000olVMZoo9WJ/00oo9WJ/00ol0003oeZ^/omJ[[002o`0000Co
iKb]00Co0000oo?B[_ocdZkolm:^0ol000001?oJl97o0000oj_el?l00003oj_5k@;o00001OnKW]H2
o`0000OoPhG=00Go0000ogYhaOmjN<GoNWS5o`000002of9ac003o`000?mLJlSoG6_800?oG6_800?o
0000oei/bOmNK<T00_mNK<T00olhH]3o0000odM_eP03odM_eP05o`000?mRQ^3oHXKPof:6h?l00000
0on4Y>T00ol0003oZ<;/ojS2k002ojS2k005o`000?o6fNSoa]WXolKIj?l000001?oIi]h2o`0000;o
i>gF00Go0000onO_d_l0003of_o@o`00000Rooooo`03o`000?oooooooooo00Oooooo00001?lb<S;o
0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`?o00003Oooool00ol0
003o65[BoaQJdP02obMVf0;o00000omWQMd00ol0003oQ:7VohBQiP02ohBQiP05o`000?nU_ncoYKo/
ojFok?l000001?o3f^X01ol0003oen[RomOZh_oGj^;o0000on;bf?l000000_oSgm000ol0003oj>7;
onSQb`03onSQb`03o`000?oYhL[ojN7:00;ojN7:0_l00007omo=aP05o`000?oHc<kof<c>omS<c_l0
00001?oA_lP00ol0003oa<7GolC1e`04olC1e`03o`000?nQ_NgoXKg]00?o00000_l02I/00ol0003o
6c6[o`000003oeE?[P03o`000?mgHZgoMf:]00;o00001On?L:`00ol0003oX7^Zoj1kZP02oj1kZP03
o`000?n_QZWo[hJY00?o[hJY00?o0000okbAZ_nlTJX00_nlTJX00ol0003obIf[olVMZ`02olVMZ`03
o`000?oFZjcoeZ^/00;oeZ^/0_l00003onFl[@04o`000?ocdZkolm:^oo?B[P?o000000?of_2Ao`00
0?l000000_n[aNd2o`0000KoVikF00?o0000oi69aol000001_n3QLd00ol0003oNWS5ogYha@03ogYh
a@03o`000?mRLLco000000GoG6_800?o0000oei/bOmNK<T00omNK<T2o`0000?oAfoF00Go0000of:6
h?mRQ^3oHXKPo`000003ohBTj@03o`000?nX`^coZ<;/00;oZ<;/00Go0000olKIj?o6fNSoa]WXo`00
0004omWVgP04o`000?oTkMKo0000onC]eP;o000000?of_o@o`000?ooool08_ooool00ol0003ooooo
ooooo`07ooooo`006Oooool2o`0002Kooooo0ol0000@ooooo`03o`000?lHF];o65[B00?o9fKH0_l0
0002ofN5g@03o`000?n4XNKoQ:7V00;oQ:7V00Go0000ojFok?nU_ncoYKo/o`000004ol?JjP04o`00
0?oGj^;oen[RomOZhP;o00001?oSgm000ol0003oj>7;onSQb`02onSQb`05o`000?oYhL[ojN7:onWQ
b_l000000_oRcL<00ol0003oglg6omo=aP05omo=aP03o`000?oHc<ko000000KodKo80_l00005olC1
e`;o00000onR_nh2o`09V`04o`000?lK<J_o6c6[o`0000;oEDn^00Go0000ogMR[Ol0003oN6:]o`00
0005ohm`[003o`000?nPNj[oX7^Z00;oX7^Z00?o0000ojn6ZOn_QZT00_n_QZT00ol0003o_96ZokbA
ZP03okbAZP03o`000?o9WJ_obIf[00;obIf[00?o0000omJ[[?oFZj`00_oFZj`00ol0003oiKf^o`00
0002o`0000?olm:^00Co0000oo[[Z?l0003of_2A0ol000000on[aNgo0000oi^NeP05oi^NeP;o0000
0onARLL00ol0003oPhG=oh>5c@03oh>5c@03o`000?mjN<GoNWS500CoNWS500?o0000oea[b?mLJlP0
1?mLJlP00ol0003oGVc9oei/b@03oei/b@;oIWK>00Co0000odM_e_m7KmKo00000omRQ^001Ol0003o
Q:CYohBTjOn4Y>Wo000000CoZ<;/00Go0000olKIj?o6fNSoa]WXo`000004omWVgP03o`000?oTkMKo
i>gF00;o00000_oJom000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Hoooo
o`03o`000?oooooooooo02?ooooo0ol0000Cooooo`04o`000?lHF];o65[Bo`0000;o9fKH0_m:PN@0
0ol0003oIhGMo`000004ohBQiP05o`000?nU_ncoYKo/ojFok?l000000oo3f^X01?l0003oen[RomOZ
h_oGj^82o`0000Gohmo@00?o0000onSQbooXhL/00_oXhL/01?l0003ojN7:onWQb_l00004on;=``03
o`000?oOcLKoglg600Goglg600?o0000om6ob?oA_lP01ooA_lP01Ol0003oa<7GolC1eoo4`MOo0000
00;o`;WC0_l000000onR_nko0000o`09V`02o`000003oa/aZol0003oEDn^00;oEDn^00Go0000ogQR
[OmhHZgoN6:]o`000004ohm`[003o`000?nPNj[oX7^Z00?oX7^Z00Go0000ojn6ZOn_QZWo[hJYo`00
0004okbAZP03o`000?o9WJ_obIf[00?obIf[00Go0000omJ[[?oFZjcoeZ^/o`000004onFm[P06o`00
0?ocdZkolm:^oo?B[_l0003on^^X0_l00002ojW5kP;o00001_nKW]H00ol0003oTHW7oi69a`04oi69
a`05o`000?n3QLgoPhG=oh>5cOl000001omjN<D00omgLl;o0000oea[b003oea[b003o`000?mNK<Wo
GVc900?oGVc900Oo0000ofIfc_mVM/koIWK>o`000?m7KmKo000000?oHXKP00?o0000ohBTjOn4Y>T0
0_n4Y>T01Ol0003oZ<;/ojS2k?nX`^co000000?oa]WX00?o0000omWVg_oIi]h00_oIi]h01ol0003o
i>gFo`000?oIoMSo0000om[od?l000009?ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0
003oooooooooo`0Pooooo`?o00005oooool00ol0003o65[BoaQJdP03obMVf0;oBX7T0_l00003ohBQ
iP03o`000?nU_ncoYKo/00;oYKo/00Co0000ol?Jj_o3f^[o`m[Z1?l000000ooIfmWo0000on?Od004
on?Od003o`000?oXhL_oj>7;00?oj>7;0_l00006on;=``03o`000?oOcLKoglg600Coglg600?o0000
omJm`Ol000002?oA_lP00ol0003oa<7Go`000005ol2id`;o000000?o00VKo`000?l000000_lK<J/0
1?l0003oEDn^oeE?[_l00003ogQR[@03o`000?n?L:coSg2/00;oSg2/00?o0000oj1kZ_nPNjX00onP
NjX01Ol0003o[hJYojn6ZOn_QZWo000000Co_96Z00?o0000olVMZoo9WJ/00_o9WJ/00ol0003oeZ^/
omJ[[002omJ[[003o`000?oU_JkoiKf^00;oiKf^00Go0000oo?B[_ocdZko0000oo[[Z005o`0000;o
XZ3B00Co0000oi^Ne_nKW]KoVikF0_l00008oi69a`03o`000?n3QLgo000000OoNWS500Co0000ogMc
`_mgLl;o00000omLJlP00ol0003oGVc9oei/b@03oei/b@03o`000?mVM/koIWK>00;oIWK>0_l00003
of:6h003o`000?n4Y>WoQ:CY00;oQ:CY00Go0000ojS2k?nX`^coZ<;/o`000003olKIj003o`000?oI
i]kofNKN00;ofNKN0_l000001OoIoMSo0000o`000?oJom3o000002Cooooo00?o0000ooooooooool0
1oooool001Sooooo00?o0000ooooooooool07Oooool3o`0001[ooooo00Co0000oaQJd_lHF];o0000
0_lWI]P3odZ1i0?o000000?oQ:7Vo`000?nU_n`00onU_n`00ol0003o`m[Zol?JjP02o`0000CofM_I
00?o0000on?Od?oSgm001?oSgm000ol0003oj>7;onSQb`02onSQb`03o`000?oRcL?oh/g300Goh/g3
00?o0000omo=a_oOcLH00ooOcLH01Ol0003oe[g1omJm`OoF_L7o000000SodKo80_l00008ol2id`09
o`000?oAEP3o0000oa/aZol0003oEDn^o`000?mFCjoo000000;oN6:]00?o0000ohm`[?n?L:`00_n?
L:`00ol0003oX7^Zoj1kZP03oj1kZP05o`000?n_QZWo[hJYojn6ZOl000001?nlTJX00ol0003obIf[
olVMZ`02olVMZ`03o`000?oFZjcoeZ^/00;oeZ^/00[o0000onFm[_oU_JkoiKf^o`000?ocdjoo0000
oo?B[_l0003on^^X0ol00005oj:PdP03o`000?nKW]Ko000000[oTHW70_l00007ogYha@03o`000?mg
Ll;oMg?200;oMg?200Co0000oea[b?mLJlSo00001OmNK<T00ol0003oIWK>ofIfcP03ofIfcP;o0000
0_mRQ^000ol0003oQ:CYohBTj@02ohBTj@05o`000?nX`^coZ<;/ojS2k?l000000oo6fNP01?l0003o
fNKNomWVg_oIi]h2o`0000;ofOgH00?o0000om[od?l000009Oooool00ol0003oooooooooo`07oooo
o`006?ooool00ol0003oooooooooo`0Jooooo`?o00007Oooool01?l0003o65[BoaQJd_l00002obMV
f003o`000?m:PNCoBX7T00?oNJ?]1Ol000001_nU_nco0000o`000?l0003oaM;To`0000GofM_I00?o
0000on?Od?oSgm000ooSgm000ol0003oj>7;onSQb`02onSQb`03o`000?oRcL?oh/g300Koh/g300Go
0000omo=a_oOcLKoglg6o`000005omJm`@;o00001_oA_lP01?l0003ob[?4o`000?l00006ol2id`03
o`000?l0093o000000;o6c6[00Co0000oeI?[omFCjoo00000omhHZd00ol0003oSg2/ohm`[002ohm`
[003o`000?nPNj[oX7^Z00;oX7^Z00Go0000ojn6ZOn_QZWo[hJYo`000004okbAZP03o`000?o9WJ_o
bIf[00;obIf[00Go0000omJ[[?oFZjcoeZ^/o`000004onFm[P05o`000?ocdjoolm>_o`000?ojjjP0
0_l00007oj:PdP;o00002OnARLL2o`000003ohao`?l0003oNWS500GoNWS500?o0000ogMc`_mgLl80
1?mgLl82o`0000GoGVc900?o0000ofIfc_mVM/h01?mVM/h2ogJ7e`03o`000?mRQ^3o000000CoQ:CY
00Go0000ojS2k?nX`^coZ<;/o`000003olKIj008o`000?oIi]ko0000o`000?oCm^Go0000omWmf?l0
0002om[od0;o00009?ooool00ol0003oooooooooo`07ooooo`006?ooool2o`0001Sooooo0ol0000Q
ooooo`04o`000?lHF];o65[Bo`0000;o9fKH0om:PN@3ogVSk@CoYL3/0_l00004olGBi003o`000?oI
fmWofM_I00;ofM_I00?o0000on?Od?oSgm000ooSgm001ol0003oj>7;onSQbooXhL_o0000on7=a?l0
00002?oRcL<00ol0003oglg6o`000008omJm`@03o`000?oA_lSodKo800;odKo800?o0000olZca?o:
/l@00_o:/l@2o`0000Go`;WC00Go0000om5F0?lK<J_o6c6[o`000003oeI?[`04o`000?mhHZgoN6:]
o`0000CoSg2/00?o0000oj1kZ_nPNjX03_l000000oo9WJ_o0000omJ[[003omJ[[005o`000?oU_Jko
iKf^onFm[_l000000oocdjl01?l0003on^^Xo`000?l00005oj:PdP;o000000?oWHk3o`000?nARLL0
1onARLL00ol0003oS7o0ohao`002ohao`003o`000?mjN<GoNWS500;oNWS500?o0000ogMc`_mgLl80
1_mgLl800ol0003oGVc9oei/b@03oei/b@03o`000?mVM/koIWK>00?oIWK>00Co0000ogJ7eomfQmOo
MXOG0_l00004ohBTj@05o`000?nX`^coZ<;/ojS2k?l000000oo6fNP2o`0000;odoKU00Ko0000omWm
f?oIoMSo0000om[od?l00002ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_oo
ool001Sooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00Co0000oaQJd_lHF];o00000_lW
I]P01?l0003oBX7TodZ1i?l00003ogVSk@CoYL3/00?o0000olGBi?o5d^@00_o5d^@00ol0003ofM_I
omWKf@02omWKf@03o`000?oSgm3ohmo@00?ohmo@00Co0000onSQbooXhL_o00000ooQcL@00ol0003o
h/g3on;=``06on;=``;o00002OoF_L401?l0003odKo8om6ob?l00007olZca0;o00000oo0^M<4o`00
0005oa`a[?l0003oETn_oeI?[ol000000_mhHZd01?l0003oSg2/ohm`[?n?L:`4o`0000;oXGj]00Go
0000ojn8[?n_R:co[hR/o`000004okbC[003o`000?o9WjgobIn]00?o00000ooFZj`01Ol0003oiKf^
onFm[_oU_Jko000000;olm>_0ol000000ooEjXCoXZ3Boj:PdP02oj:PdP;o00001?nMS/<00ol0003o
THW7oi69a`03oi69a`;o00001_n<Ol001?l0003oNWS5ogYhaOl00008ogMc`P;o00001OmNK<T00ol0
003oIWK>ofIfcP03ofIfcP03o`000?mfQmOoMXOG00;oMXOG1?l000000on4Y>Wo0000ojS2k002ojS2
k003o`000?o6fNSo000000;o00000ooCm^D00ol0003ofOgHo`000002om[od004o`000?oooooooooo
o`0002Cooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool04_ooool3o`00
02Oooooo00Co0000oaQJd_lHF];o00000_lWI]P01?l0003oBX7TodZ1i?l00003ogVSk@03o`000?nU
`>coYL3/00;oYL3/00Go0000olGBi?o5d^CoaM;To`000005omWKf@03o`000?oSgm3ohmo@00?ohmo@
0_l00005on7=a003o`000?oRcL?oh/g300Goh/g300?o0000omRl__l000002OoF_L400ol0003odKo8
o`000009olZca0;o000000Oo`;WCo`000?l0093o002@o`000?lL<Jco000000;oETn_00Go0000ogQR
[OmhHZgoN6:]ohm`[002o`000003oi1c[_l0003oXGj]00?oXGj]00Go0000ojn8[?n_R:co[hR/o`00
0004okbC[006o`000?o9WjgobIn]olVO[Ol0003oeZf_0ol00004onFm[P03o`000?ocdjoolm>_00Co
00000_nRX=82o`0000OoWHk300?o0000oi69aonARLL00_l00008ohao`003o`000?mjN<Go000000So
Mg?200Co0000ogQd`omhM<?o00000omNK<T00ol0003oIWK>ofIfcP03ofIfcP03o`000?mfQmOoMXOG
00?oMXOG00Co0000ohbRhon<X^?oS:;S1ol00002ol;RkP04o`000?oCm^GodoKUo`0000;ofOgH00Co
0000om[od?oJom3o00000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo
000Gooooo`03o`000?oooooooooo00oooooo0ol0000[ooooo`04o`000?lHF];o65[Bo`0000;o9fKH
00Co0000odZ1i?m:PNCo00000_miXnd00ol0003oYL3/ojG0k002ojG0k003o`000?o5d^CoaM;T00;o
aM;T00?o0000omWKfOoIfmT00_oIfmT00ol0003ohmo@on?Od002on?Od0;o00001ooQcL@00ol0003o
h/g3on;=``03on;=``04o`000?oH_;kof;bnomRl_P;o00002?oF_L400ol0003ob[?4olZca00:olZc
a003o`000?nk/]3o^k;@00;o00000_lL<J`01?l0003oETn_oeI?[ol00002ogQR[@05o`000?n@Ljko
T7>^oi1c[_l000001?nQOZd01Ol0003o[hR/ojn8[?n_R:co000000Co_9>/00Go0000olVO[Oo9Wjgo
bIn]o`000003omJ][`;o00000_oU_Jh01Ol0003olm>_oo?C[ol0003onN^Y00;o000000?oXZ3Bo`00
0?l000002OnMS/<00ol0003oTHW7o`00000:ohao`0;o00002?mgLl800ol0003oN7C3ogQd``02ogQd
``04o`000?mNK<WoGVc9o`0000GoIWK>00?o0000ogJ7eomfQmL00_mfQmL00ol0003oS:;SohbRh`03
ohbRh`05o`000?nX`^goZ<;]ojS2kOl000000_o2h^h01ol0003odoKUom?fiOoCm^Go0000omWmf?l0
00000_oJom000ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool001Oooooo00?o0000ooooooooool03?ooool3o`0002kooooo0_l000001OlHF];o0000
obMVf?lWI]So000000;oBX7T00Go0000ogVSkOmiXngoNJ?]o`000003ojG0k003o`000?o5d^CoaM;T
00;oaM;T00?o0000omWKfOoIfmT00_oIfmT01ol0003ohmo@on?Od?oSgm3o0000omg=bOl000001ooQ
cL@00ol0003oh/g3on;=``02on;=``03o`000?oH_;kof;bn00Cof;bn00?o0000omJm`OoF_L401OoF
_L401?l0003ocK2mo`000?l00009olZca008o`000?o2ZL7o`ZW1o`000?l0093o0000oa`a[?l00002
oeI?[`04o`000?mhHZgo0000o`0000CoT7>^00Go0000oj5n[OnQOZgoXGj]o`000003ojn8[003o`00
0?nlTjco_9>/00;o_9>/00Co0000olVO[Oo9Wjgo00001?oF[Jl01ol0003ohkjao`000?oU_Jko0000
oo?C[ol000000_oijjT3o`0000_oWHk30_l0000:ohao`003o`000?n:Nkgo000000OoMg?200?o0000
ogQd`omhM<<01?mhM<<00ol0003oGVc9o`000004ofIfcP03o`000?mfQmOoMXOG00?oMXOG00?o0000
ohbRhon<X^<00_n<X^<01Ol0003oZ<;]ojS2kOnX`^go000000?o`^;^00Co0000om?fiOoCm^Go0000
0_oIoMP01?l0003of_o@om[od?l00006ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool001Oooooo0_l0000:ooooo`?o0000<Oooool2o`0m_@;o00000_lWI]P01?l0003oBX7T
odZ1i?l00003ogVSk@03o`000?nU`>coYL3/00;oYL3/00Go0000olGBi?o5d^CoaM;To`000004omWK
f@04o`000?oSgm3ohmo@o`0000?ogLg900?o0000on7=a?oQcL@01OoQcL@01Ol0003oh/g3on;=`ooR
cL?o000000Oof;bn00?o0000omJm`OoF_L400ooF_L400ol0003ocK2molf`_@02olf`_@?o00001Oo:
/l@00ol0003o`ZW1ol:Y`@03ol:Y`@04o`000?lL<Jco736/o`0000;oETn_00Co0000ogYV/OmjI[7o
00000on@Ljh01Ol0003oXGj]oj5n[OnQOZgo000000?o[hR/00?o0000okbC[?nlTj`00_nlTj`01?l0
003obIn]olVO[Ol00004omJ][`?ohkja00Go0000oo?C[oocdjoo0000ooW[Z@02o`000003ojNC`Ol0
003oWHk300OoWHk30ol000000onJQKco0000ohao`007ohao`0;o00000on:Nkd00ol0003oMg?2ogMc
`P03ogMc`P03o`000?mhM<?oN7C300KoN7C300?o0000ofIfc_mVM/h00omVM/h00ol0003oMXOGogJ7
e`02ogJ7e`03o`000?n<X^?oS:;S00?oS:;S00Go0000ojS2kOnX`^goZ<;]o`000002ol;RkP05o`00
0?oCm^GodoKUom?fiOl000000_oIoMP00ol0003of_o@o`000007ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003Gooooo
0_l0?Kd01OlHF];o0000obMVf?lWI]So000000;oBX7T00Co0000ogVSkOmiXngo00001?nU`>`00ol0
003oaM;TolGBi002olGBi003o`000?oIfmWofM_I00;ofM_I0_l00005omg=b@03o`000?oQcLCohLg4
00GohLg400?o0000on;=`ol000002OoH_;h2o`0000;oe[g100?o0000olf`_Oo=/;d01_o=/;d2o`00
00?ob[?400?o0000ol:Y`Oo2ZL400oo2ZL42o`000003oa`a[?l0003oETn_00;o00000_mjI[401Ol0
003oT7>^oi1c[_n@Ljko000000CoXGj]00Co0000ojn8[?n_R:co00000onlTj`01Ol0003obIn]olVO
[Oo9Wjgo000000?oeZf_00Oo0000on>n/OoS_[7ohkjao`000?ocdjoo000000;onN^Y00Co0000ojNC
`OnWTl7o00001_nMS/<2o`0000GoVXFl00?o0000ohao`?n<Ol001?n<Ol000ol0003oRW^mohYk_@04
ohYk_@05o`000?mgLl;oMg?2ogMc`_l000002OmhM<<00omlO<Oo0000ofIfcP03ofIfcP03o`000?mf
QmOoMXOG00;oMXOG00?o0000ohbRhon<X^<00on<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^
00Co0000om?fiOoCm^Go00000_oIoMP01?l0003of_o@om[od?l00008ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool00oooool3o`0003Wo
oooo0_l0?Kd2o`000005obMVf?l0003oBX7TodZ1i?l000000omiXnd01Ol0003oYL3/ojG0k?nU`>co
000000CoaM;T00Co0000omWKfOoIfmWofM_I0_l00007omg=b@03o`000?oQcLCohLg400GohLg40_l0
000;omRl_P03o`000?oF_L7o000000[ocK2m0_l000000oo:/lCo0000ol:Y`@05ol:Y`@04o`000?lL
<Jco736/o`0000;oFUJc00Co0000ogYV/OmjI[7o00000_n@Ljh00ol0003oXGj]oj5n[@02oj5n[@04
o`000?n_R:co[hR/o`0000?o_9>/00Go0000olVO[Oo9WjgobIn]o`000003omJ][`05o`000?oS_[7o
hkjaon>n/Ooadk<00_l000000ooijjWo0000o`000003ojNC`@04o`000?nMS/?oWHk3oif>``;o0000
1onJQK`00ol0003oS7o0ohao`003ohao`003o`000?n:NkgoRW^m00KoRW^m00?o0000ogMc`_l00000
2OmhM<<01?l0003oO7c7ogalaol00002ofIfcP03o`000?mfQmOoMXOG00;oMXOG00?o0000ohbRhon<
X^<00on<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Go0000om?fiOoCm^GodoKUo`000002
omWmf0?o00002_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Foooo
o`04o`000?ooooooooooooooo`?o0000?Oooool00ol0?Kgo057<o`1Ac002o`0000;oBX7T00Go0000
ogVSkOmiXngoNJ?]o`000004ojG0k005o`000?o5d^CoaM;TolGBi?l000000_oIfmT00ol0003oeLgA
o`000008omg=b@03o`000?oQcLCohLg400CohLg400?o0000omRl__l000002ooH_;h00ol0003ocK2m
olf`_@0;olf`_@03o`000?o2ZL7o`ZW100Go`ZW100Co0000oa`a[?lL<Jco00000_mJE[<01?l0003o
NVJaogYV/Ol00002oi1c[P03o`000?nQOZgoXGj]00;oXGj]00Co0000ojn8[?n_R:co00000onlTj`0
1Ol0003obIn]olVO[Oo9Wjgo000000;oeZf_00[o0000on>n/OoS_[7ohkjao`000?oadk?o0000ooW[
ZOl0003oe^^61?nWTl44o`0000[oVXFl00?o0000ohao`?n<Ol000_l00009ohYk_@;o00002OmhM<<0
0ol0003oO7c7ogala`02ogala`03o`000?mVM/ko000000CoMXOG00?o0000ohbRhon<X^<00on<X^<0
1Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Ko0000om?fiOoCm^GodoKUo`000?oIoMP3o`0000co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`005_ooool4o`00047ooooo
00Go03fmo`1Ac?l0DLco9fKHo`000002odZ1i004o`000?miXngoNJ?]o`0000CoYL3/00?o0000olGB
i?o5d^@00_o5d^@2o`0000?oeLgA00?o0000omg=bOoMcLT01OoMcLT00ol0003ohLg4on7=a003on7=
a004o`000?oH_;kof;bnomRl_P;o00002OoH_;h01?l0003ocZnjo`000?l0000:olf`_@03o`000?o4
YK[oa:Fj00Go000000Oo`ZW1o`000?l0003o9Sbbo`000?mJE[?o000000?oNVJa00Co0000oi1c[_n@
Ljko00000onQOZd00ol0003o[hR/o`000003o`000005okbC[?l0003obIn]olVO[Ol000000ooF[Jl0
1?l0003ohkjaon>n/Ol00002oo7C/`04o`000?oijjWo0000o`0000;oYi?10ol0000=oiZ5_003o`00
0?n<Ol3o000000[oRW^m00?o0000ohYl__l000002?mhM<<00ol0003oO7c7ogala`04ogala`;o0000
1?mfQmL00ol0003oS:;SohbRh`02ohbRh`05o`000?nX`^goZ<;]ojS2kOl000000oo2h^h01?l0003o
doKUom?fiOl00002omWmf0;o00003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo000Fooooo`?o0000@oooool00ol0?Kgo057<o`1Ac002o`000003odZ1i?l0003oNJ?]00;o
NJ?]00Go0000ojG0k?nU`>coYL3/o`000003olGBi0;o00001OoEcM400ol0003ogLg9omg=b@05omg=
b@05o`000?oQcLCohLg4on7=a?l000001_oH_;h2o`0000Kof;bn00?o0000olj_^_o>[kX00_o>[kX2
o`0000OocK2m00?o0000olBU^_o4YKX01_o4YKX01Ol0003o/D80o`000?lV?;;o000000;oFUJc00Go
0000ogYV/OmjI[7o0000oi1c[P07o`000004ok2=/_l0003o_9NbokbG/PGo00000ooF[Jl01ol0003o
hkjaon>n/Ol0003olM>co`000?ohk;001Ol00002ojJ<^P03o`000?nJQKcoVXFl00_oVXFl0_l0000:
ohYk_@05o`000?n:O;koRWbnohYl__l000001_mhM<<00ol0003oO7c7ogala`05ogala`;oQH[@00Co
0000ogJ7eomfQmOo00001On<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Co0000om?fiOoC
m^GodoKU1?l0000?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool000co
oooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00Co03fmo`1Ac?l0
003o97_V0_l00003ogVSk@03o`000?nU`>coYL3/00;oYL3/0ol000000oo5b]ko0000omG=d@05omG=
d@03o`000?oMcLWogLg900GogLg900?o0000on7=a?l000002OoH_;h00ol0003of;bnomRl_P03omRl
_P03o`000?o>[k[ocZnj00CocZnj0_l00005olf`_@03o`000?o4YK[oa:Fj00Soa:Fj00Ko0000obHl
/_lV?;;o0000oeYF/ol00002ogYV/@;o000000?oTgZeo`000?nRQ;<00_nRQ;<01?l0003o/8fbok2=
/_l00003okbG/P03o`000?o7Xk?oaj>c00Co00000_oS_[401_l0003olM>coo7C/ol0003on>b`o`00
00OoYXbj00?o0000oiZ5_?nJQK`01onJQK`3o`000003oiV2^Ol0003oRW^m00OoRW^m0_l00005ohYl
_P03o`000?mhM<?oN7C300;oN7C300?o0000ogalaomlO<L01OmlO<L01ol0003oQH[@ohF:d?n5R]3o
0000ogJ7eol000001?n<X^<00ol0003oZ<;]ojS2k@02ojS2k@04o`000?o2h^ko`^;^o`0000;odoKU
1?l0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`04o`000?l0?Kgo057<o`0000;o97_V
1?l00002ojG0k0?o00001?o5b]h00ol0003oeLgAomG=d@04omG=d@03o`000?oMcLWogLg900GogLg9
0_l0000:omRl_P;o00000_oH_;h00ol0003ocZnjolj_^P07olj_^P;o00000oo=/;d00ol0003oa:Fj
olBU^P08olBU^P0:ok520?l0003o9Sbbo`000?mJE[?o0000ogYV/Ol0003oOg2ho`0000;oTgZe00Co
0000oj:4/onRQ;?o00000_n`SK801Ol0003o_9NbokbG/_nlUk;o000000;oaj>c00?o0000om>`]_oC
/;H00_l000001OoS_[7o0000oo7C/ol0003on>b`00;o00001onVS;X00ol0003oVXFloiZ5_004oiZ5
_0?o00001OnIP[T00ol0003oRW^mohYk_@04ohYk_@03o`000?n:O;koRWbn00GoRWbn00Go0000ogQd
`omhM<?oN7C3o`000007ogala`03o`000?n5R]3oQH[@00?oQH[@0_l00004ohbRh`05o`000?nX`^go
Z<;]ojS2kOl000000_o2h^h01?l0003odoKUom?fiOoCm^D3o`0001;ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo047ooooo0_l000001?l0DLco0000obAki_l00002offVl`?o00000_nU`>d00ol0003oaL[N
olG:gP03olG:gP03o`000?oEcM7oeLgA00CoeLgA00?o0000omg=bOoMcLT01?oMcLT00ol0003oeKk3
o`00000;omRl_P03o`000?oH_;ko000000_ocZnj0ol0000<olBU^P06o`000?lV?;;o9Sbbo`000?mJ
E[?o00000omoL;P00ol0003oTgZeo`000002oj:4/`04o`000?n`SK;o/8fbo`0000?o_9Nb00Co0000
olNS/oo7Xk?o00000_oC/;H01_l0003ogl2io`000?oadk?o0000ooS//0;o00002?nVS;X00ol0003o
VXFloiZ5_002oiZ5_0;o00002?nIP[T00ol0003oRW^mohYk_@02ohYk_@;o00002On:O;h00ol0003o
N7C3o`000007ogala`03o`000?n5R]3oQH[@00CoQH[@00?o0000oiBQgOl000000_l000000on<X^?o
0000ojS2k@02ojS2k@03o`000?o2h^ko`^;^00Ko00005?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00[ooooo0_l00012ooooo`06o`0m
_Ol0003o057<o`000?lTNnKo00000_m]Y_<00ol0003oYL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N
00?oaL[N00?o0000omG=dOoEcM401?oEcM400ol0003ogLg9omg=b@02omg=b@05o`000?oE_/?oeKk3
omFn`ol000002ooH_;h2o`0000gocZnj00?o0000olBU^_o4YKX02_o4YKX01_na@P3o0000obHl/_l0
003oFUJco`0000?oOg2h00?o0000oi=j]Ol000000_nRQ;<01?l0003o/8fbok2=/_l00003okbG/P03
o`000?o7Xk?o000000?odk2f0_oO`;T01_l0003olM>co`000?l0003ofo:Eo`0000WoYXbj1?l0000;
oiV2^@04o`000?n:NkgoRW^mo`0000_oRWbn0_l00007ogala`03o`000?n5R]3oQH[@00CoQH[@00?o
0000oiBQgOnDXMd00onDXMd3o`0000;oZ<;]1?l000001?nko>Go0000o`000?l0000Fooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`10ooooo`06o`0m_Ol0003o057<o`000?lTNnKo00000_m]Y_<00ol0003o
YL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N00?oaL[N00?o0000omG=dOoEcM401?oEcM401?l0003o
gLg9omg=bOl00005omFn``;o00002OoH_;h01?l0003ocZnko`000?l0000;olj_^P03o`000?o5Y;So
aJBh00Go00001_o4YKX01_l0003o9SbbobHl/_l0003oI6>lo`0000;oOg2h00Co0000oi=j]OnCN[Go
00000_nRQ;<00ol0003o/8fbo`000002okbG/P04o`000?o7Xk?oaj>co`0000;odk2f00Ko0000omo0
^OoO`;WojmBmo`000?ohk;02o`0000SoYXbj0ol0000>oiV2^@03o`000?n:Nkgo000000_oRWbn00?o
0000ohf2`_l000001_mlO<L00ol0003oQH[@ohF:d004ohF:d003o`000?nDXMgoU:7M00?oU:7M00Co
0000ojO2kOnW`^goYl;]0ol000000onjj?Go0000ok_li@03o`0001Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo043ooooo00Ko03fmo`000?l0DLco0000obAki_l00002offVl`03o`000?nU`>goYL3]00;o
YL3]00?o0000olG:g_o5b]h00oo5b]h00ol0003oeLgAomG=d@04omG=d@03o`000?oMcLWo000000Oo
eKk300?o0000omRl__oH_;h01OoH_;h00ol0003ocZnkolj_^`02olj_^`;o00002?o>[kX00ol0003o
aJBholFT^006olFT^0Go000000Ooa:Fjo`000?l0003o9Sbbo`000?mTHkco000000?oOg2h00?o0000
oi=j]Ol000000_nRQ;<00ol0003o/8fbo`000002okbG/P06o`000?o7Xk?oaj>co`000?oC/;Ko0000
0_oO`;T00ol0003ojmBmo`000002o`0000CoYXbj1Ol00002ojF:]`03o`000?nIP[WoVH:i00coVH:i
0_l0000:ohYl_P;o00000on=P/800ol0003oO7c7ogala`02ogala`03o`000?n5R]3oQH[@00CoQH[@
00?o0000oiBQgOnDXMd00onDXMd00ol0003oYl;]ojO2k@02ojO2k@05o`000?njj?Go^^Seo`000?nk
o>D00ol0000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool000kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`10ooooo`06o`000?l0DLco057<o`000?lT
NnKo00000_m]Y_<00ol0003oYL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N00;oaL[N00?o0000omG=
dOoEcM401OoEcM42o`0000SoeKk30_l00004omRl_P03o`000?o>[k_ocZnk00GocZnk0ol00005olj_
^P03o`000?o5Y;SoaJBh00_oaJBh1?l000001?liDKoo0000ofAS_?l00002ogm`^003o`000?nCN[Go
000000;oXXBc00?o0000ok2=/_l000000_nlUk800ol0003oaj>co`000002om>`]P04o`000?oO`;Wo
0000on_D_@;o000000?ofo:Eo`000?l000000ol00008ojF:]`03o`000?nIP[WoVH:i00SoVH:i0ol0
00000onIPk[o0000ohYl_P08ohYl_P03o`000?n=P/;oSH;200CoSH;200Co0000ogalaomlO<Oo0000
1_n5R]000ol0003oU:7MoiBQg@03oiBQg@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go
0000ok_li@03o`0001_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00
3?ooool00omEEEGoIVIVo`00000Aooooo`;o0000@Oooool00ol0003o057<o`000002obAkiP04o`00
0?m]Y_?oKJKco`0000CoYL3]00?o0000olG:g_o5b]h00_o5b]h00ol0003oeLgAomG=d@03omG=d@04
o`000?o?`<cocl3<o`0000WoeKk300Go0000omRl__oH_;kof;bno`00000:olj_^`;o00000oo>[kX0
0ol0003oaJBholFT^00<olFT^00;o`000?nkV[Oo03:ho`000?liDKoo0000ofAS_?l0003oOg2ho`00
0?nCN[D03?l000001_oC/;Ko0000o`000?o[e;go0000oo;/_`;o00003OnUR[L00ol0003oVH:ioiV2
^@05oiV2^@?o00001OnIPkX00ol0003oRWbnohYl_P04ohYl_P;o00001on=P/800ol0003oO7c7o`00
0006ohF:d003o`000?nDXMgoU:7M00?oU:7M00?o0000ojO2kOnW`^d00_nW`^d01Ol0003o^^Seok[X
mOl0003o^ocU00?o00007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo
000Rooooo`03o`000?oooooooooo03oooooo00Go0000o`1Ac?l0003o97_Vo`000003offVl`05o`00
0?nU`>goYL3]ojG0kOl000001Oo5b]h01Ol0003oeLgAomG=dOoEcM7o000000Cocl3<00?o0000omFn
`ooE_/<01ooE_/<00ol0003of;bno`00000=olj_^`?o00003oo5Y;P01?l0003o^iZgo`000?l0<[P2
o`000003ofAS_?l0003oOg2h00;o000000KoV8W2o`000?nUT;oo0000ok2H__l00002okZP_P08o`00
0?o4Z/3o0000oljf`ol0003ogl2io`000?o[e;d3o`0000koYHZg00?o0000oiV2^OnIP[T00_nIP[T3
o`0000SoVH>j00?o0000ohYl__n:O;h00on:O;h00ol0003oSH;2ohf2`P07ohf2`P;o00001on5R]00
0ol0003oU:7MoiBQg@02oiBQg@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go0000ok_l
i@03o`0001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`008oooool0
0ol0003oooooooooo`0oooooo`05o`000?l0DLco0000obAki_l000000om]Y_<01Ol0003oYL3]ojG0
kOnU`>go000000GoaL[N00?o0000omG=dOl000001_o?`<`2o`0000SoeKk30_l0000?olj_^`03o`00
0?o5Y;SoaJBh00coaJBh00Oo0000ok^J]onkV[Oo^iZgo`000?l0<[So000000;oI6>l00?o0000ohV2
a_l000000_nHRL82o`000004ok2H__l0003o^Z2nokZP_P;oa:[00_o>]/<2o`000005on_D_Ol0003o
0000on7k/ol000003onUR[L4o`0000coVH>j00?o0000ohYl__n:O;h00_l00009ohf2`P04o`000?nC
SL_oThg;o`0000GoQH[@00?o0000oiBQgOnDXMd00_nDXMd00ol0003oYl;]ojO2k@02ojO2k@05o`00
0?njj?Go^^Seo`000?nko>D00ol0000Pooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool002Cooooo0_l00010ooooo`?o000000?o97_Vo`000?m]Y_<00_m]Y_<01Ol0003oYL3]
ojG0kOnU`>go000000CoaL[N0_l00009olo0c003o`000?oE_/?oeKk300GoeKk300?o0000olba_ol0
00000_l0000<olj_^`03o`000?o4Y;Soa:Bh00?o00002Oo5Y;P00ol0003o^iZgok^J]`02ok^J]`03
o`000?l0<[So>E6o00;o00000_n9P/H03Ol0003oV8W2o`000?l0003o/9Rno`000?njX;ko0000olBZ
`?l0003oc[K3o`000?oGa<L00_l000001?obk;oo0000o`000?l0000=ojF:]`?o00003onIPkX00ol0
003oRWbno`000009ohf2`P;o00001?nCSL/01Ol0003oQH[@ohF:d?n5R]3o000000CoU:7M00?o0000
ojO2kOnW`^d00_nW`^d01Ol0003o^^Seok[XmOl0003o^ocU00?o00008_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo000Vooooo`03o`000?oooooooooo03oooooo0_l00000
0olTNnKo0000offVl`02offVl`06o`000?nU`>goYL3]ojG0kOl0003oaL[N0_l00003ol;2fP03o`00
0?o?`<cocl3<00Kocl3<0_l00004omFn``03o`000?o</Kooc;6o00?oc;6o0_l00009olj_^`03o`00
0?o4Y;Soa:Bh00Coa:Bh1?l00005olFT^003o`000?nkV[Oo^iZg00?o^iZg0_l0<[P2oeYdd`03o`00
0?n9P/KoRH;600;o000000CoYI2oo`000?l0003o^Z2n0_l000000oo>]/?o0000omO4a`05o`0000;o
/96f00?o0000ojF:]onUR[L01OnUR[L5o`0000;oYHZh00?o0000oiV3^_nIPkX03OnIPkX2o`0000Wo
SH;200?o0000oi>=bonCSL/01OnCSL/00ol0003oQH[@o`000004oiBQg@03o`000?nW`^goYl;]00;o
Yl;]00Go0000ok[XmOnjj?Go0000ok_li@02o`0002Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`009oooool00ol0003oooooooooo`0oooooo`04o`0cXol0003o0000o`00
00?oKJKc00?o0000ojG0kOnU`>d00_l00006ol;2fP03o`000?o?`<cocl3<00Oocl3<00Co0000omFn
`ooE_/?o00002?o</Kl2o`0000OocZnk00?o0000olBT^?o4Y;P02?o4Y;P3o`000003olFT^?l0003o
^iZg00Ko^iZg00So03:ho`000?mJM=?oFWCCo`000?n9P/Ko0000oiR9`PCo000000Coa:[0o`000?l0
003oelC70_l000000ooTj=Co0000o`000003ok2A]P03o`000?nUR[OoYHZg00Go00002?nUR[P00ol0
003oVH>joiV3^P09oiV3^P?o000000?oVhRno`000?n=P/801_n=P/82o`0000SoThg;0ol00003oiBQ
g@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go0000ok_li@02o`0002Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0003oooooooooo`10oooo
o`03o`0cXol0LM[o000000Go00000onU`Nd6ol;2fP;o00002?o?`<`00ol0003oeKk3o`00000:olba
_`?o00000oo>[k/00ol0003oa:BholBT^00<olBT^0co00000_mJM=<00ol0003oRH;6o`000006o`00
0005omO4aol0003o0000onCXe?oMnmP02?l0000=ojF:^003o`000?nIPk[oVH>j00KoVH>j0ol00005
oi^8_P03o`000?n=P/;oSH;200?oSH;200?o0000oi>=bonCSL/01_nCSL/2o`0000?oVj7I00?o0000
oiBQgOl000001?nW`^d01_l0003o^^Seok[XmOl0003o^ocUo`0002Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`03ooooo`00:Oooool2o`00047ooooo00?o0000o`1af_l0LMX01?mR
[?T4ojG1k@03o`000?o2`][o`/;J00Co`/;J00?o0000olo0c?o?`<`01_o?`<`00ol0003oc;6oolba
_`0<olba_`;o000000?ocZnko`000?o4Y;P03_o4Y;P00ol0003o^iZgok^J]`06ok^J]`?o00000_mJ
M=<:o`0000;ogO_H00?o0000ok2B]on`T[L00on`T[L00ol0003oYHZhojF:^00=ojF:^003o`000?nI
Pk[oVH>j00?oVH>j0ol00009oi^8_P03o`000?n=P/;oSH;200;o00002?nCSL/00ol0003oVj7Ioi^Q
f@03oi^Qf@Co00000_nW`^d00ol0003o^^Seok[Xm@03o`0002_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`10ooooo`03o`0cXol0LM[o
000000?oHZci00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o`/;Jol;2fP03ol;2fP03o`000?o?`<co
cl3<00Gocl3<00Co0000olReaol0003o00003Oo</Kl00ol0003oa:BholBT^00>olBT^003o`000?nk
V[Oo^iZg00So^iZg3Ol000000onkoLko/9:gok2B]`05ok2B]`03o`000?nUR[SoYHZh00koYHZh00?o
0000oiV3^_l000000_l0000<oi^8_P03o`000?n=P/;o000000SoThg;0_l00005oi^Qf@03o`000?nW
`^goYl;]00;oYl;]1_l0000^ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool002cooooo00?o0000ooooooooool0@Oooool00ol0003o077Jo`000003of:/n@04o`000?nU`Ngo
YL7]ojG1k@;o00001?o2`]X2o`0000Cocl3<00?o0000olReaoo8]LL00_o8]LL2o`0000_oc;6o00?o
0000ol>V_?o3Y[`01?l0000:olBT^003o`000?nkV[Oo^iZg00[o^iZg2ol00008ok2B]`03o`000?nU
R[SoYHZh00coYHZh1?l0000?oi^8_P;o00001onCSL/2o`0000GoVj7I0_l00004ojO2k@03o`000?n[
j_WoZn[i00?o0000<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000]
ooooo`03o`000?oooooooooo047ooooo00?o03>So`1af_l000000omR[?T00ol0003oYL7]ojG1k@02
ojG1k@03o`000?o2`][o`/;J00?o`/;J00Co0000olo0c?o?`<co00001oo8]LL3o`0000Ooc;6o00?o
0000ol>V_?o3Y[`01Oo3Y[`4o`0000Goa:Bh00?o0000ok^J]onkV[L03OnkV[L2o`000003ofc1o_l0
003oS=cn00?o00002_n`T[L00ol0003oYHZhojF:^007ojF:^0Co00000_nVS[`00ol0003oVhRnoi^8
_P0;oi^8_P?o000000?oWY77o`000?nCSL/01?nCSL/2o`0000KoVj7I00?o0000ojO2kOnW`^d00_nW
`^d2o`000004oj_ZnOl0003o0000o`0003;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`00;_ooool2o`0004?ooooo00?o0000o`1af_l000000_mR[?T2o`0000?oYL7]00?o
0000ol;2f_o2`]X00oo2`]X00ol0003ocl3<o`00000:olRea`;o00001Oo</Kl00ol0003o`jJlol>V
_009ol>V_0Co000000?oa:Bho`000?nkV[L03onkV[L4o`0000go/9:g00?o0000ojF:^?nUR[P00onU
R[P4o`0000OoYXjl00?o0000oi^8__nKR;h01onKR;h3o`0000GoWY7700Go0000oi>=bonCSL_oThg;
o`000006oi^Qf@;o00001?nW`^d00ol0003oZn[io`000003o`0003Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`00<?ooool00ol0003oooooooooo`11ooooo`04o`0cXol0
003o0000o`0000;oHZci00Co0000ojG1kOnU`NgoYL7]0_l00003ol;2fP;o00003Oo8]LL2o`0000?o
c;6o00?o0000ol>V_?o3Y[`03Oo3Y[`2o`000003ok^J]ol0003o000000Ko00001onkV[L00ol0003o
/9:gok2B]`0>ok2B]`03o`000?nUR[So000000?o00002onVS[`00ol0003oVhRnoi^8_P05oi^8_P;o
00002?nNTLL01?l0003oThg;o`000?l00005oi^Qf@;o00001?nW`^d2o`000004oj_ZnOl0003o0000
o`0003Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00<Oooool00ol0
003oooooooooo`12ooooo`03o`000?l0LM[o000000;oHZci0_l00003ojG1k@03o`000?o2`][o0000
00?o_[_F0ol0000;olRea`?o00004Oo3Y[`00ol0003o^YfkokZM^`07okZM^a[o00003onVS[`00ol0
003oVhRnoi^8_P02oi^8_P?o00002_nNTLL2o`0000KoVj7I00?o0000ojO2kOnW`^d00onW`^d00ol0
003oZn[io`000002o`0003Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`00<_ooool00ol0003oooooooooo`12ooooo`Co00000_mR[?T01Ol0003oYL7]ojG1kOnU`Ngo0000
00Oo_[_F0ol0000:olRea`03o`000?o3Y[co`jJl00oo`jJl00?o0000okZM^onjWK/03_njWK/00ol0
003o/IFkok6E^`0>ok6E^`03o`000?nVS[coYXjl00ooYXjl1?l0000:oijAa`?o00000_nSXmH01?l0
003oVj7Ioi^QfOnKXMT2o`0000CoYl;]0_l000001?n[j_Wo0000o`000?l0000kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool003?ooooo0_l00014ooooo`?o00000_mR[?T0
0ol0003oYL7]o`000002ojG1k@03o`000?nn^mKo_[_F00Ko_[_F0_l00008olRea`03o`000?o1[<Go
`Jc500Co00002oo3Y[`00ol0003o^YfkokZM^`0>okZM^`03o`000?naUK_o/IFk00ko/IFk00?o0000
ojJ>_?nVS[`03?nVS[`4o`0000[oWY770ol00006oj>SeP03o`000?nKXMWo000000GoYl;]00?o0000
oj_ZnOl000000_l0000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
03Gooooo00?o0000ooooooooool0@oooool00ol0IKgo0000o`000002o`0000KoYL7]0_l00006okjk
eP?o00001?o8]LL00ol0003o`Jc5ol6/a@05ol6/a@Go00001Oo3Y[`00ol0003o^YfkokZM^`0?okZM
^`03o`000?naUK_o/IFk00oo/IFk00?o0000ojJ>_?nVS[`01OnVS[`6o`0000?oZ9O400?o0000oijA
aonNTLL01_nNTLL2o`0000WoXj?F0ol00003ojO2k@Ko0000@?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo04Gooooo0omJ/o/00ol0003o
YL7]ojG1k@04ojG1k@?o00001_nn^mH3o`000003olReaol0003o`Jc500_o`Jc51?l000000oo3Y[co
0000okZM^`0@okZM^`03o`000?naUK_o/IFk00oo/IFk00?o0000ojJ>_?nVS[`01Ol0000:ojRGa003
o`000?nNTLOoWY7700;oWY770ol00008oj>SeP?o00000onW`^d01?l0003oYl;]o`000?n[j_T3o`00
04;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool00ol0003o
ooooooooo`16ooooo`04o`000?mJ/o_oF[?koeZcn`;o00001OnU`Nd2o`0000Oo_[_F00?o0000ol6/
aOo1[<D03oo1[<D2o`000003okZM^ol0003o000000Ko00002?njWK/00ol0003o/IFkok6E^`06ok6E
^`co00003onXUl@00ol0003oWY77o`000002o`0000WoXj?F0_l00006ojO2k@Go0000AOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000hooooo`;o0000B?ooool01?l0IKgo
0000oeZcnomJ/o/3o`0000CoYL7]0_l00005okjkeP03o`000?nj]=Co^[CD00Go00002oo1[<D00ol0
003o^J?3okVS``07okVS`a7o00002OnaW<<00ol0003oZ9O4ojRGa00>ojRGa0?o00002OnSXmH3o`00
00GoYl;]1Ol00019ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool003[o
oooo00?o0000ooooooooool0B?ooool2o`0000;oF[?k0_l00004ojG1k@?o000000?o_[_Fo`000?nj
]=@01onj]=@4o`0000Oo`Jc500?o0000okVS`oniXl<03oniXl<00ol0003o/Ic3ok6L``0?ok6L``03
o`000?nXUlCoZ9O400WoZ9O41Ol00002ojVVd`03o`000?nSXmKoXj?F00GoXj?F0_l00005ojO2k@Go
0000COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000kooooo`03o`00
0?oooooooooo04Wooooo0_l00002oeZcn`;o00001OnU`Nd00ol0003o^[CDokZde00;okZde0Go0000
00?o`Jc5o`000?niXl<04OniXl<00ol0003o/Ic3ok6L``0@ok6L``03o`000?nXUlCoZ9O400CoZ9O4
1?l00008ojVVd`03o`000?nSXmKoXj?F00;oXj?F0_l00004ojO2k@Ko0000Coooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo000looooo`;o0000Boooool3o`000006oeZcnol0
003o0000o`000?nU`Ngo00000onU`Nd4o`0000co^[CD0_l00002okVS``?o00003OniXl<00ol0003o
/Ic3ok6L``0@ok6L``03o`000?nXUlCo000000Co00003?nYY]<00ol0003oXj?Fo`000002o`0000?o
Yl;]1_l0001Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003kooooo
00?o0000ooooooooool0Boooool2o`000003oeZcnol0003o000000SoYL7]1?l00009okZde003o`00
0?ne[m?o]JoC00?o]JoC2Ol00004okVS``03o`000?naW<?o/Ic300Oo/Ic32ol0000?ojVVd`Go0000
0_nW`^d3o`000003oiOVo?l0003o000005Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`01ooooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?mH^ocoF;_l00;oF;_l0_l0
0008ojG1k@?o00001_nj]=@00ol0003o]JoCokF_d`0<okF_d`ko00002On_Z]800ol0003oZJKCojVV
d`07ojVVd`Oo00000onV`^d4o`000004oiOVo?l0003o0000o`0005[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`1>ooooo`03o`000?mH
^ocoF;_l00?oF;_l1?l00005ojG1k@Co000000?o^[CDo`000?ne[m<04_ne[m<00ol0003o[j[BojnZ
dP0AojnZdP03o`000?nYY]?oZJKC00Ko00001OnV`^d5o`000003oh3Mo?l0003o000000;o0000GOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o0000D_ooool2
o`0000CoF;_l1?l00005ojG1k@;o00001?ne[m<00ol0003o]JoCokF_d`0<okF_d`03o`000?n_Z];o
[j[B00co[j[B2?l00006ojK2k@Go000000?oP=glo`000?l000000ol0001Rooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool00_ooool3o`0000;oF;_l1?l00002ojG1k@03o`000?nU`^koYL;^00?oYL;^2_l00004okF_
d`03o`000?n_Z];o[j[B00;o[j[B2_l00005ojK2kP04o`000?nV`^goY/;]ojK2k@Go000000?oP=gl
o`000?l000000ol0001Xooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0014oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool01_ooool4o`000003oeRko?l0003o0000
013oYL;^2Ol0000;ojK2kPSo000000?oP=glo`000?l000000ol0001^ooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`7ooooo0015ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool02_ooool2o`0000KoGLKk2ol00004ojG2kP03o`000?nV`^koY/;^00;oY/;^5?l0001cooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`;o0000COooool00ol0003ooooo
ooooo`0Gooooo`KoGLKk3ol00022ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0018ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00Boooool2o`0004Sooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0/oooool01Ol0003ooooooooooooooooo0000007ooooo001@
ooooo`;o0000@oooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`00007ooooo001B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]Oooool00ol0003oooooo`000001
ooooo`00Doooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool00Ol0000005Cooooo0_l0000oooooo`03o`000?oooooooooo0;Kooooo0Ol00001ooooo`7o
0000001Fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0]oooool2o`000000Eooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;Kooooo0ol0000005Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2booooo`Co00000oooool005Wooooo0_l0000joooo
o`03o`000?oooooooooo0:kooooo1?l00007ooooo`00Foooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo0:[ooooo1?l0000;ooooo`00G?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Kooooo1?l0000?ooooo`00GOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo0:;ooooo1?l0000Cooooo`00G_ooool2o`0003Gooooo00?o0000ooooooooool0W_ooool4
o`0001Oooooo001Pooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0V_ooool4o`00
01_ooooo001Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool3o`0001oo
oooo001Rooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002;ooooo
001Sooooo`;o0000;oooool00ol0003oooooooooo`2@ooooo`Co00009_ooool006Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`2<ooooo`Co0000:_ooool006Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`28ooooo`Co0000;_ooool006Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`24ooooo`Co0000<_ooool006Sooooo0_l0000Zooooo`03o`00
0?oooooooooo083ooooo1?l0000fooooo`00J_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo07cooooo1?l0000jooooo`00Joooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0000nooooo`00K?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l00012ooooo`00KOooool2o`0002Gooooo00?o0000ooooooooool0L?ooool4o`0004Ko
oooo001_ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0K?ooool4o`0004[ooooo
001`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J?ooool4o`0004kooooo001a
ooooo`;o00008Oooool00ol0003oooooooooo`1Tooooo`Co0000D_ooool007?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000E_ooool007Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Looooo`Co0000F_ooool007Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Iooooo`?o0000G_ooool007Kooooo0_l0000Looooo`03o`000?oo
oooooooo05Gooooo1?l0001Qooooo`00N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo057ooooo1?l0001Uooooo`00NOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04gooooo1?l0001Yooooo`00N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo1?l0001]ooooo`00Noooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`00077ooooo
001mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0007Gooooo001n
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool4o`0007Wooooo001ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool4o`0007gooooo0020ooooo`;o
00004_ooool00ol0003oooooooooo`0eooooo`Co0000POooool008;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0aooooo`Co0000QOooool008?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0^ooooo`Co0000ROooool008Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Zooooo`Co0000SOooool008Gooooo0_l0000<ooooo`03o`000?oooooooooo
02Kooooo1?l0002Aooooo`00Qoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo1?l0002Eooooo`00R?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo
1?l0002Iooooo`00ROooool2o`0000Sooooo00?o0000ooooooooool06oooool3o`0009gooooo002;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool4o`000:3ooooo002<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool4o`000:Cooooo002=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool4o`000:Sooooo002>ooooo`;o0000
0oooool00ol0003oooooooooo`0;ooooo`Co0000[?ooool0093ooooo00Co0000oooooooooooo0000
2Oooool4o`000;3ooooo002Aooooo`03o`000?oooooo000000Gooooo1?l0002dooooo`00T_ooool2
o`000003ooooool0003o000000;o0000^?ooool009?ooooo0_l0002looooo`00oooooomBooooo`00
oooooomBooooo`00oooooomBooooo`00\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65567 m .51694 .65827 L .43899 .65168 L p .394 .781 .99 r
F P
0 g
s
.51694 .65827 m .51723 .65567 L .59271 .65149 L p .446 .826 .99 r
F P
0 g
s
.59271 .65149 m .59527 .65394 L .51694 .65827 L p .446 .826 .99 r
F P
0 g
s
.59527 .65394 m .59271 .65149 L .66488 .63689 L p .52 .868 .99 r
F P
0 g
s
.66488 .63689 m .67023 .63881 L .59527 .65394 L p .52 .868 .99 r
F P
0 g
s
.44214 .64931 m .43899 .65168 L .36521 .63435 L p .372 .741 .99 r
F P
0 g
s
.43899 .65168 m .44214 .64931 L .51723 .65567 L p .394 .781 .99 r
F P
0 g
s
.51754 .65268 m .51723 .65567 L .44214 .64931 L p .437 .79 .997 r
F P
0 g
s
.51723 .65567 m .51754 .65268 L .59011 .64865 L p .483 .83 .997 r
F P
0 g
s
.59011 .64865 m .59271 .65149 L .51723 .65567 L p .483 .83 .997 r
F P
0 g
s
.59271 .65149 m .59011 .64865 L .65946 .6346 L p .546 .865 .995 r
F P
0 g
s
.65946 .6346 m .66488 .63689 L .59271 .65149 L p .546 .865 .995 r
F P
0 g
s
.36521 .63435 m .37112 .63259 L .44214 .64931 L p .372 .741 .99 r
F P
0 g
s
.44534 .64655 m .44214 .64931 L .37112 .63259 L p .415 .753 .995 r
F P
0 g
s
.44214 .64931 m .44534 .64655 L .51754 .65268 L p .437 .79 .997 r
F P
0 g
s
.51784 .6488 m .51754 .65268 L .44534 .64655 L p .519 .797 .996 r
F P
0 g
s
.51754 .65268 m .51784 .6488 L .58747 .64492 L p .552 .825 .997 r
F P
0 g
s
.58747 .64492 m .59011 .64865 L .51754 .65268 L p .552 .825 .997 r
F P
0 g
s
.67023 .63881 m .66488 .63689 L .73002 .61232 L p .602 .899 .987 r
F P
0 g
s
.73002 .61232 m .73799 .61332 L .67023 .63881 L p .602 .899 .987 r
F P
0 g
s
.59011 .64865 m .58747 .64492 L .65396 .63141 L p .593 .847 .993 r
F P
0 g
s
.65396 .63141 m .65946 .6346 L .59011 .64865 L p .593 .847 .993 r
F P
0 g
s
.37112 .63259 m .37711 .63046 L .44534 .64655 L p .415 .753 .995 r
F P
0 g
s
.44858 .6429 m .44534 .64655 L .37711 .63046 L p .501 .768 .991 r
F P
0 g
s
.44534 .64655 m .44858 .6429 L .51784 .6488 L p .519 .797 .996 r
F P
0 g
s
.37112 .63259 m .36521 .63435 L .29943 .6068 L p .378 .707 .985 r
F P
0 g
s
.51816 .64359 m .51784 .6488 L .44858 .6429 L p .599 .783 .969 r
F P
0 g
s
.51784 .6488 m .51816 .64359 L .58478 .63987 L p .614 .796 .969 r
F P
0 g
s
.58478 .63987 m .58747 .64492 L .51784 .6488 L p .614 .796 .969 r
F P
0 g
s
.66488 .63689 m .65946 .6346 L .72196 .61096 L p .615 .889 .989 r
F P
0 g
s
.72196 .61096 m .73002 .61232 L .66488 .63689 L p .615 .889 .989 r
F P
0 g
s
.58747 .64492 m .58478 .63987 L .64835 .6269 L p .633 .806 .966 r
F P
0 g
s
.64835 .6269 m .65396 .63141 L .58747 .64492 L p .633 .806 .966 r
F P
0 g
s
.37711 .63046 m .38319 .62743 L .44858 .6429 L p .501 .768 .991 r
F P
0 g
s
.45189 .63793 m .44858 .6429 L .38319 .62743 L p .588 .768 .965 r
F P
0 g
s
.44858 .6429 m .45189 .63793 L .51816 .64359 L p .599 .783 .969 r
F P
0 g
s
.29943 .6068 m .30791 .60604 L .37112 .63259 L p .378 .707 .985 r
F P
0 g
s
.37711 .63046 m .37112 .63259 L .30791 .60604 L p .417 .719 .987 r
F P
0 g
s
.51848 .63677 m .51816 .64359 L .45189 .63793 L p .653 .754 .924 r
F P
0 g
s
.51816 .64359 m .51848 .63677 L .58204 .63321 L p .654 .754 .924 r
F P
0 g
s
.58204 .63321 m .58478 .63987 L .51816 .64359 L p .654 .754 .924 r
F P
0 g
s
.65946 .6346 m .65396 .63141 L .71378 .60871 L p .637 .861 .984 r
F P
0 g
s
.71378 .60871 m .72196 .61096 L .65946 .6346 L p .637 .861 .984 r
F P
0 g
s
.58478 .63987 m .58204 .63321 L .64265 .62079 L p .654 .755 .924 r
F P
0 g
s
.64265 .62079 m .64835 .6269 L .58478 .63987 L p .654 .755 .924 r
F P
0 g
s
.38319 .62743 m .38937 .62309 L .45189 .63793 L p .588 .768 .965 r
F P
0 g
s
.45525 .63135 m .45189 .63793 L .38937 .62309 L p .653 .753 .924 r
F P
0 g
s
.45189 .63793 m .45525 .63135 L .51848 .63677 L p .653 .754 .924 r
F P
0 g
s
.30791 .60604 m .31649 .60492 L .37711 .63046 L p .417 .719 .987 r
F P
0 g
s
.38319 .62743 m .37711 .63046 L .31649 .60492 L p .496 .74 .981 r
F P
0 g
s
.5188 .62823 m .51848 .63677 L .45525 .63135 L p .684 .723 .879 r
F P
0 g
s
.51848 .63677 m .5188 .62823 L .57925 .62483 L p .674 .714 .879 r
F P
0 g
s
.57925 .62483 m .58204 .63321 L .51848 .63677 L p .674 .714 .879 r
F P
0 g
s
.65396 .63141 m .64835 .6269 L .70546 .60514 L p .652 .812 .96 r
F P
0 g
s
.70546 .60514 m .71378 .60871 L .65396 .63141 L p .652 .812 .96 r
F P
0 g
s
.58204 .63321 m .57925 .62483 L .63684 .61296 L p .662 .707 .881 r
F P
0 g
s
.63684 .61296 m .64265 .62079 L .58204 .63321 L p .662 .707 .881 r
F P
0 g
s
.73799 .61332 m .73002 .61232 L .78434 .57863 L p .674 .91 .976 r
F P
0 g
s
.78434 .57863 m .79464 .57831 L .73799 .61332 L p .674 .91 .976 r
F P
0 g
s
.38937 .62309 m .39567 .61714 L .45525 .63135 L p .653 .753 .924 r
F P
0 g
s
.45868 .62305 m .45525 .63135 L .39567 .61714 L p .693 .734 .882 r
F P
0 g
s
.45525 .63135 m .45868 .62305 L .5188 .62823 L p .684 .723 .879 r
F P
0 g
s
.51913 .61809 m .5188 .62823 L .45868 .62305 L p .701 .698 .844 r
F P
0 g
s
.5188 .62823 m .51913 .61809 L .57641 .61484 L p .683 .683 .843 r
F P
0 g
s
.57641 .61484 m .57925 .62483 L .5188 .62823 L p .683 .683 .843 r
F P
0 g
s
.31649 .60492 m .32519 .60292 L .38319 .62743 L p .496 .74 .981 r
F P
0 g
s
.38937 .62309 m .38319 .62743 L .32519 .60292 L p .582 .753 .959 r
F P
0 g
s
.57925 .62483 m .57641 .61484 L .63095 .60353 L p .664 .671 .847 r
F P
0 g
s
.63095 .60353 m .63684 .61296 L .57925 .62483 L p .664 .671 .847 r
F P
0 g
s
.64835 .6269 m .64265 .62079 L .697 .59997 L p .655 .755 .923 r
F P
0 g
s
.697 .59997 m .70546 .60514 L .64835 .6269 L p .655 .755 .923 r
F P
0 g
s
.39567 .61714 m .40208 .60947 L .45868 .62305 L p .693 .734 .882 r
F P
0 g
s
.46217 .61315 m .45868 .62305 L .40208 .60947 L p .717 .716 .848 r
F P
0 g
s
.45868 .62305 m .46217 .61315 L .51913 .61809 L p .701 .698 .844 r
F P
0 g
s
.30791 .60604 m .29943 .6068 L .24558 .56996 L p .405 .679 .973 r
F P
0 g
s
.51946 .60665 m .51913 .61809 L .46217 .61315 L p .71 .681 .82 r
F P
0 g
s
.51913 .61809 m .51946 .60665 L .57354 .60356 L p .687 .662 .819 r
F P
0 g
s
.57354 .60356 m .57641 .61484 L .51913 .61809 L p .687 .662 .819 r
F P
0 g
s
.73002 .61232 m .72196 .61096 L .77394 .57859 L p .677 .897 .976 r
F P
0 g
s
.77394 .57859 m .78434 .57863 L .73002 .61232 L p .677 .897 .976 r
F P
0 g
s
.32519 .60292 m .33403 .59959 L .38937 .62309 L p .582 .753 .959 r
F P
0 g
s
.39567 .61714 m .38937 .62309 L .33403 .59959 L p .652 .753 .923 r
F P
0 g
s
.57641 .61484 m .57354 .60356 L .62498 .59281 L p .663 .646 .823 r
F P
0 g
s
.62498 .59281 m .63095 .60353 L .57641 .61484 L p .663 .646 .823 r
F P
0 g
s
.64265 .62079 m .63684 .61296 L .68841 .59309 L p .65 .703 .885 r
F P
0 g
s
.68841 .59309 m .697 .59997 L .64265 .62079 L p .65 .703 .885 r
F P
0 g
s
.40208 .60947 m .40859 .60021 L .46217 .61315 L p .717 .716 .848 r
F P
0 g
s
.4657 .60195 m .46217 .61315 L .40859 .60021 L p .73 .703 .825 r
F P
0 g
s
.46217 .61315 m .4657 .60195 L .51946 .60665 L p .71 .681 .82 r
F P
0 g
s
.5198 .59439 m .51946 .60665 L .4657 .60195 L p .714 .671 .807 r
F P
0 g
s
.51946 .60665 m .5198 .59439 L .57064 .59147 L p .689 .65 .807 r
F P
0 g
s
.57064 .59147 m .57354 .60356 L .51946 .60665 L p .689 .65 .807 r
F P
0 g
s
.24558 .56996 m .25632 .5706 L .30791 .60604 L p .405 .679 .973 r
F P
0 g
s
.31649 .60492 m .30791 .60604 L .25632 .5706 L p .437 .691 .972 r
F P
0 g
s
.72196 .61096 m .71378 .60871 L .7634 .57767 L p .677 .864 .97 r
F P
0 g
s
.7634 .57767 m .77394 .57859 L .72196 .61096 L p .677 .864 .97 r
F P
0 g
s
.33403 .59959 m .34303 .59466 L .39567 .61714 L p .652 .753 .923 r
F P
0 g
s
.40208 .60947 m .39567 .61714 L .34303 .59466 L p .701 .746 .886 r
F P
0 g
s
.57354 .60356 m .57064 .59147 L .61896 .58129 L p .662 .633 .811 r
F P
0 g
s
.61896 .58129 m .62498 .59281 L .57354 .60356 L p .662 .633 .811 r
F P
0 g
s
.4657 .60195 m .46926 .58994 L .5198 .59439 L p .714 .671 .807 r
F P
0 g
s
.52014 .58193 m .5198 .59439 L .46926 .58994 L p .714 .67 .805 r
F P
0 g
s
.5198 .59439 m .52014 .58193 L .56772 .57917 L p .689 .649 .804 r
F P
0 g
s
.56772 .57917 m .57064 .59147 L .5198 .59439 L p .689 .649 .804 r
F P
0 g
s
.40859 .60021 m .41517 .58966 L .4657 .60195 L p .73 .703 .825 r
F P
0 g
s
.46926 .58994 m .4657 .60195 L .41517 .58966 L p .737 .696 .812 r
F P
0 g
s
.63684 .61296 m .63095 .60353 L .67969 .58461 L p .643 .662 .854 r
F P
0 g
s
.67969 .58461 m .68841 .59309 L .63684 .61296 L p .643 .662 .854 r
F P
0 g
s
.57064 .59147 m .56772 .57917 L .61291 .56958 L p .662 .631 .809 r
F P
0 g
s
.61291 .56958 m .61896 .58129 L .57064 .59147 L p .662 .631 .809 r
F P
0 g
s
.34303 .59466 m .35216 .58803 L .40208 .60947 L p .701 .746 .886 r
F P
0 g
s
.40859 .60021 m .40208 .60947 L .35216 .58803 L p .731 .736 .856 r
F P
0 g
s
.25632 .5706 m .26715 .57089 L .31649 .60492 L p .437 .691 .972 r
F P
0 g
s
.32519 .60292 m .31649 .60492 L .26715 .57089 L p .504 .715 .967 r
F P
0 g
s
.71378 .60871 m .70546 .60514 L .7527 .57543 L p .67 .813 .952 r
F P
0 g
s
.7527 .57543 m .7634 .57767 L .71378 .60871 L p .67 .813 .952 r
F P
0 g
s
.41517 .58966 m .42181 .5783 L .46926 .58994 L p .737 .696 .812 r
F P
0 g
s
.47284 .57773 m .46926 .58994 L .42181 .5783 L p .738 .695 .81 r
F P
0 g
s
.46926 .58994 m .47284 .57773 L .52014 .58193 L p .714 .67 .805 r
F P
0 g
s
.52048 .56992 m .52014 .58193 L .47284 .57773 L p .712 .676 .814 r
F P
0 g
s
.52014 .58193 m .52048 .56992 L .56479 .56733 L p .688 .656 .813 r
F P
0 g
s
.56479 .56733 m .56772 .57917 L .52014 .58193 L p .688 .656 .813 r
F P
0 g
s
.63095 .60353 m .62498 .59281 L .67088 .57485 L p .637 .635 .832 r
F P
0 g
s
.67088 .57485 m .67969 .58461 L .63095 .60353 L p .637 .635 .832 r
F P
0 g
s
.56772 .57917 m .56479 .56733 L .60684 .55834 L p .662 .64 .817 r
F P
0 g
s
.60684 .55834 m .61291 .56958 L .56772 .57917 L p .662 .64 .817 r
F P
0 g
s
.35216 .58803 m .36142 .57979 L .40859 .60021 L p .731 .736 .856 r
F P
0 g
s
.41517 .58966 m .40859 .60021 L .36142 .57979 L p .749 .729 .834 r
F P
0 g
s
.42181 .5783 m .42848 .56676 L .47284 .57773 L p .738 .695 .81 r
F P
0 g
s
.47644 .56598 m .47284 .57773 L .42848 .56676 L p .734 .7 .819 r
F P
0 g
s
.47284 .57773 m .47644 .56598 L .52048 .56992 L p .712 .676 .814 r
F P
0 g
s
.62498 .59281 m .61896 .58129 L .66201 .5643 L p .633 .62 .819 r
F P
0 g
s
.66201 .5643 m .67088 .57485 L .62498 .59281 L p .633 .62 .819 r
F P
0 g
s
.52083 .559 m .52048 .56992 L .47644 .56598 L p .704 .692 .835 r
F P
0 g
s
.52048 .56992 m .52083 .559 L .56186 .55659 L p .685 .675 .835 r
F P
0 g
s
.56186 .55659 m .56479 .56733 L .52048 .56992 L p .685 .675 .835 r
F P
0 g
s
.26715 .57089 m .27813 .57029 L .32519 .60292 L p .504 .715 .967 r
F P
0 g
s
.33403 .59959 m .32519 .60292 L .27813 .57029 L p .582 .738 .95 r
F P
0 g
s
.70546 .60514 m .697 .59997 L .74184 .57158 L p .655 .755 .923 r
F P
0 g
s
.74184 .57158 m .7527 .57543 L .70546 .60514 L p .655 .755 .923 r
F P
0 g
s
.56479 .56733 m .56186 .55659 L .60077 .54821 L p .664 .662 .838 r
F P
0 g
s
.60077 .54821 m .60684 .55834 L .56479 .56733 L p .664 .662 .838 r
F P
0 g
s
.36142 .57979 m .37078 .57028 L .41517 .58966 L p .749 .729 .834 r
F P
0 g
s
.42181 .5783 m .41517 .58966 L .37078 .57028 L p .758 .725 .822 r
F P
0 g
s
.61896 .58129 m .61291 .56958 L .65309 .55358 L p .632 .617 .817 r
F P
0 g
s
.65309 .55358 m .66201 .5643 L .61896 .58129 L p .632 .617 .817 r
F P
0 g
s
.42848 .56676 m .43517 .5557 L .47644 .56598 L p .734 .7 .819 r
F P
0 g
s
.48004 .55533 m .47644 .56598 L .43517 .5557 L p .722 .711 .839 r
F P
0 g
s
.47644 .56598 m .48004 .55533 L .52083 .559 L p .704 .692 .835 r
F P
0 g
s
.52117 .54973 m .52083 .559 L .48004 .55533 L p .688 .718 .872 r
F P
0 g
s
.52083 .559 m .52117 .54973 L .55893 .5475 L p .676 .708 .872 r
F P
0 g
s
.55893 .5475 m .56186 .55659 L .52083 .559 L p .676 .708 .872 r
F P
0 g
s
.697 .59997 m .68841 .59309 L .73082 .56603 L p .637 .701 .892 r
F P
0 g
s
.73082 .56603 m .74184 .57158 L .697 .59997 L p .637 .701 .892 r
F P
0 g
s
.27813 .57029 m .28926 .56837 L .33403 .59959 L p .582 .738 .95 r
F P
0 g
s
.34303 .59466 m .33403 .59959 L .28926 .56837 L p .652 .752 .923 r
F P
0 g
s
.37078 .57028 m .3802 .55999 L .42181 .5783 L p .758 .725 .822 r
F P
0 g
s
.42848 .56676 m .42181 .5783 L .3802 .55999 L p .759 .724 .82 r
F P
0 g
s
.61291 .56958 m .60684 .55834 L .64417 .54335 L p .635 .627 .826 r
F P
0 g
s
.64417 .54335 m .65309 .55358 L .61291 .56958 L p .635 .627 .826 r
F P
0 g
s
.56186 .55659 m .55893 .5475 L .59471 .53975 L p .663 .7 .874 r
F P
0 g
s
.59471 .53975 m .60077 .54821 L .56186 .55659 L p .663 .7 .874 r
F P
0 g
s
.79464 .57831 m .78434 .57863 L .82406 .53716 L p .727 .901 .956 r
F P
0 g
s
.82406 .53716 m .83625 .53514 L .79464 .57831 L p .727 .901 .956 r
F P
0 g
s
.43517 .5557 m .44186 .54575 L .48004 .55533 L p .722 .711 .839 r
F P
0 g
s
.48364 .54633 m .48004 .55533 L .44186 .54575 L p .698 .73 .875 r
F P
0 g
s
.48004 .55533 m .48364 .54633 L .52117 .54973 L p .688 .718 .872 r
F P
0 g
s
.3802 .55999 m .38965 .54952 L .42848 .56676 L p .759 .724 .82 r
F P
0 g
s
.43517 .5557 m .42848 .56676 L .38965 .54952 L p .753 .727 .828 r
F P
0 g
s
.68841 .59309 m .67969 .58461 L .71967 .55889 L p .621 .657 .864 r
F P
0 g
s
.71967 .55889 m .73082 .56603 L .68841 .59309 L p .621 .657 .864 r
F P
0 g
s
.28926 .56837 m .30057 .56485 L .34303 .59466 L p .652 .752 .923 r
F P
0 g
s
.35216 .58803 m .34303 .59466 L .30057 .56485 L p .705 .758 .893 r
F P
0 g
s
.60684 .55834 m .60077 .54821 L .63526 .53427 L p .641 .652 .846 r
F P
0 g
s
.63526 .53427 m .64417 .54335 L .60684 .55834 L p .641 .652 .846 r
F P
0 g
s
.52151 .54249 m .52117 .54973 L .48364 .54633 L p .65 .755 .926 r
F P
0 g
s
.52117 .54973 m .52151 .54249 L .55599 .54045 L p .653 .757 .926 r
F P
0 g
s
.55599 .54045 m .55893 .5475 L .52117 .54973 L p .653 .757 .926 r
F P
0 g
s
.38965 .54952 m .39912 .53956 L .43517 .5557 L p .753 .727 .828 r
F P
0 g
s
.44186 .54575 m .43517 .5557 L .39912 .53956 L p .737 .733 .848 r
F P
0 g
s
.55893 .5475 m .55599 .54045 L .58864 .53335 L p .655 .758 .926 r
F P
0 g
s
.58864 .53335 m .59471 .53975 L .55893 .5475 L p .655 .758 .926 r
F P
0 g
s
.67969 .58461 m .67088 .57485 L .70842 .55047 L p .608 .627 .844 r
F P
0 g
s
.70842 .55047 m .71967 .55889 L .67969 .58461 L p .608 .627 .844 r
F P
0 g
s
.78434 .57863 m .77394 .57859 L .81177 .53883 L p .722 .888 .956 r
F P
0 g
s
.81177 .53883 m .82406 .53716 L .78434 .57863 L p .722 .888 .956 r
F P
0 g
s
.44186 .54575 m .44854 .53748 L .48364 .54633 L p .698 .73 .875 r
F P
0 g
s
.48724 .53938 m .48364 .54633 L .44854 .53748 L p .648 .753 .926 r
F P
0 g
s
.48364 .54633 m .48724 .53938 L .52151 .54249 L p .65 .755 .926 r
F P
0 g
s
.30057 .56485 m .31203 .55962 L .35216 .58803 L p .705 .758 .893 r
F P
0 g
s
.36142 .57979 m .35216 .58803 L .31203 .55962 L p .741 .759 .867 r
F P
0 g
s
.60077 .54821 m .59471 .53975 L .62635 .52687 L p .65 .695 .879 r
F P
0 g
s
.62635 .52687 m .63526 .53427 L .60077 .54821 L p .65 .695 .879 r
F P
0 g
s
.25632 .5706 m .24558 .56996 L .20758 .52532 L p .443 .657 .952 r
F P
0 g
s
.67088 .57485 m .66201 .5643 L .6971 .54128 L p .601 .611 .833 r
F P
0 g
s
.6971 .54128 m .70842 .55047 L .67088 .57485 L p .601 .611 .833 r
F P
0 g
s
.39912 .53956 m .40857 .53073 L .44186 .54575 L p .737 .733 .848 r
F P
0 g
s
.44854 .53748 m .44186 .54575 L .40857 .53073 L p .706 .743 .88 r
F P
0 g
s
.31203 .55962 m .32362 .5528 L .36142 .57979 L p .741 .759 .867 r
F P
0 g
s
.37078 .57028 m .36142 .57979 L .32362 .5528 L p .764 .758 .847 r
F P
0 g
s
.52185 .53749 m .52151 .54249 L .48724 .53938 L p .561 .791 .985 r
F P
0 g
s
.52151 .54249 m .52185 .53749 L .55305 .53563 L p .587 .814 .986 r
F P
0 g
s
.55305 .53563 m .55599 .54045 L .52151 .54249 L p .587 .814 .986 r
F P
0 g
s
.66201 .5643 m .65309 .55358 L .68576 .53194 L p .6 .608 .831 r
F P
0 g
s
.68576 .53194 m .6971 .54128 L .66201 .5643 L p .6 .608 .831 r
F P
0 g
s
.77394 .57859 m .7634 .57767 L .79935 .53961 L p .709 .857 .953 r
F P
0 g
s
.79935 .53961 m .81177 .53883 L .77394 .57859 L p .709 .857 .953 r
F P
0 g
s
.55599 .54045 m .55305 .53563 L .58256 .52919 L p .62 .831 .981 r
F P
0 g
s
.58256 .52919 m .58864 .53335 L .55599 .54045 L p .62 .831 .981 r
F P
0 g
s
.59471 .53975 m .58864 .53335 L .61746 .52155 L p .658 .759 .925 r
F P
0 g
s
.61746 .52155 m .62635 .52687 L .59471 .53975 L p .658 .759 .925 r
F P
0 g
s
.32362 .5528 m .33531 .54471 L .37078 .57028 L p .764 .758 .847 r
F P
0 g
s
.3802 .55999 m .37078 .57028 L .33531 .54471 L p .775 .757 .836 r
F P
0 g
s
.44854 .53748 m .45523 .53127 L .48724 .53938 L p .648 .753 .926 r
F P
0 g
s
.49086 .53466 m .48724 .53938 L .45523 .53127 L p .545 .767 .98 r
F P
0 g
s
.48724 .53938 m .49086 .53466 L .52185 .53749 L p .561 .791 .985 r
F P
0 g
s
.20758 .52532 m .22009 .52775 L .25632 .5706 L p .443 .657 .952 r
F P
0 g
s
.26715 .57089 m .25632 .5706 L .22009 .52775 L p .467 .67 .952 r
F P
0 g
s
.65309 .55358 m .64417 .54335 L .67443 .52312 L p .605 .619 .839 r
F P
0 g
s
.67443 .52312 m .68576 .53194 L .65309 .55358 L p .605 .619 .839 r
F P
0 g
s
.40857 .53073 m .41801 .52361 L .44854 .53748 L p .706 .743 .88 r
F P
0 g
s
.45523 .53127 m .44854 .53748 L .41801 .52361 L p .647 .75 .924 r
F P
0 g
s
.33531 .54471 m .34707 .53585 L .3802 .55999 L p .775 .757 .836 r
F P
0 g
s
.38965 .54952 m .3802 .55999 L .34707 .53585 L p .777 .757 .835 r
F P
0 g
s
.7634 .57767 m .7527 .57543 L .78677 .53906 L p .686 .81 .942 r
F P
0 g
s
.78677 .53906 m .79935 .53961 L .7634 .57767 L p .686 .81 .942 r
F P
0 g
s
.64417 .54335 m .63526 .53427 L .66312 .51546 L p .617 .647 .857 r
F P
0 g
s
.66312 .51546 m .67443 .52312 L .64417 .54335 L p .617 .647 .857 r
F P
0 g
s
.34707 .53585 m .35884 .52684 L .38965 .54952 L p .777 .757 .835 r
F P
0 g
s
.39912 .53956 m .38965 .54952 L .35884 .52684 L p .769 .757 .842 r
F P
0 g
s
.22009 .52775 m .23269 .52981 L .26715 .57089 L p .467 .67 .952 r
F P
0 g
s
.27813 .57029 m .26715 .57089 L .23269 .52981 L p .52 .695 .949 r
F P
0 g
s
.5222 .53467 m .52185 .53749 L .49086 .53466 L p .368 .772 .984 r
F P
0 g
s
.52185 .53749 m .5222 .53467 L .55009 .53301 L p .428 .823 .983 r
F P
0 g
s
.55009 .53301 m .55305 .53563 L .52185 .53749 L p .428 .823 .983 r
F P
0 g
s
.58864 .53335 m .58256 .52919 L .60857 .5185 L p .653 .841 .972 r
F P
0 g
s
.60857 .5185 m .61746 .52155 L .58864 .53335 L p .653 .841 .972 r
F P
0 g
s
.63526 .53427 m .62635 .52687 L .65185 .50952 L p .636 .693 .886 r
F P
0 g
s
.65185 .50952 m .66312 .51546 L .63526 .53427 L p .636 .693 .886 r
F P
0 g
s
.35884 .52684 m .37061 .51835 L .39912 .53956 L p .769 .757 .842 r
F P
0 g
s
.40857 .53073 m .39912 .53956 L .37061 .51835 L p .749 .758 .86 r
F P
0 g
s
.55305 .53563 m .55009 .53301 L .57645 .52724 L p .514 .873 .985 r
F P
0 g
s
.57645 .52724 m .58256 .52919 L .55305 .53563 L p .514 .873 .985 r
F P
0 g
s
.41801 .52361 m .42743 .51857 L .45523 .53127 L p .647 .75 .924 r
F P
0 g
s
.46192 .5273 m .45523 .53127 L .42743 .51857 L p .538 .742 .97 r
F P
0 g
s
.45523 .53127 m .46192 .5273 L .49086 .53466 L p .545 .767 .98 r
F P
0 g
s
.7527 .57543 m .74184 .57158 L .77402 .53691 L p .656 .755 .923 r
F P
0 g
s
.77402 .53691 m .78677 .53906 L .7527 .57543 L p .656 .755 .923 r
F P
0 g
s
.49448 .53214 m .49086 .53466 L .46192 .5273 L p .344 .727 .985 r
F P
0 g
s
.49086 .53466 m .49448 .53214 L .5222 .53467 L p .368 .772 .984 r
F P
0 g
s
.23269 .52981 m .24543 .53099 L .27813 .57029 L p .52 .695 .949 r
F P
0 g
s
.28926 .56837 m .27813 .57029 L .24543 .53099 L p .587 .725 .939 r
F P
0 g
s
.37061 .51835 m .38234 .51103 L .40857 .53073 L p .749 .758 .86 r
F P
0 g
s
.41801 .52361 m .40857 .53073 L .38234 .51103 L p .712 .757 .888 r
F P
0 g
s
.62635 .52687 m .61746 .52155 L .64062 .50569 L p .66 .76 .923 r
F P
0 g
s
.64062 .50569 m .65185 .50952 L .62635 .52687 L p .66 .76 .923 r
F P
0 g
s
.74184 .57158 m .73082 .56603 L .76111 .53304 L p .625 .702 .9 r
F P
0 g
s
.76111 .53304 m .77402 .53691 L .74184 .57158 L p .625 .702 .9 r
F P
0 g
s
.58256 .52919 m .57645 .52724 L .59965 .51769 L p .607 .908 .983 r
F P
0 g
s
.59965 .51769 m .60857 .5185 L .58256 .52919 L p .607 .908 .983 r
F P
0 g
s
.38234 .51103 m .39402 .50544 L .41801 .52361 L p .712 .757 .888 r
F P
0 g
s
.42743 .51857 m .41801 .52361 L .39402 .50544 L p .647 .748 .923 r
F P
0 g
s
.24543 .53099 m .25833 .53084 L .28926 .56837 L p .587 .725 .939 r
F P
0 g
s
.30057 .56485 m .28926 .56837 L .25833 .53084 L p .652 .752 .923 r
F P
0 g
s
.73082 .56603 m .71967 .55889 L .74808 .52759 L p .598 .657 .878 r
F P
0 g
s
.74808 .52759 m .76111 .53304 L .73082 .56603 L p .598 .657 .878 r
F P
0 g
s
.52255 .53376 m .5222 .53467 L .49448 .53214 L p .086 .634 .834 r
F P
0 g
s
.49814 .53153 m .52255 .53376 L p .50188 .53257 L .086 .634 .834 r
F P
0 g
s
.49448 .53214 m .49814 .53153 L p .50188 .53257 L .086 .634 .834 r
F P
0 g
s
.49814 .53153 m .47541 .52573 L p .49381 .53034 L 0 .433 .703 r
F P
0 g
s
.52255 .53376 m .49814 .53153 L p .51537 .53343 L .135 0 0 r
F P
0 g
s
.5222 .53467 m .52255 .53376 L p .52875 .53404 L .175 .709 .83 r
F P
0 g
s
.50183 .53234 m .5229 .53426 L p .50215 .53198 L .135 0 0 r
F P
0 g
s
.49814 .53153 m .50183 .53234 L p .50215 .53198 L .135 0 0 r
F P
0 g
s
.50183 .53234 m .49814 .53153 L p .49381 .53034 L 0 .433 .703 r
F P
0 g
s
.49814 .53153 m .49448 .53214 L .46864 .52555 L p .067 .592 .872 r
F P
0 g
s
.46864 .52555 m .47541 .52573 L .49814 .53153 L p .067 .592 .872 r
F P
0 g
s
.48223 .52734 m .50183 .53234 L p .4797 .52681 L 0 .433 .703 r
F P
0 g
s
.47541 .52573 m .48223 .52734 L p .4797 .52681 L 0 .433 .703 r
F P
0 g
s
.48223 .52734 m .46535 .51955 L p .48498 .52792 L 0 .371 .734 r
F P
0 g
s
.50183 .53234 m .48223 .52734 L p .50149 .53274 L .256 0 0 r
F P
0 g
s
.48223 .52734 m .48914 .52969 L .50557 .53388 L p .256 0 0 r
F P
0 g
s
.48914 .52969 m .48223 .52734 L p .48498 .52792 L 0 .371 .734 r
F P
0 g
s
.50557 .53388 m .50183 .53234 L p .50149 .53274 L .256 0 0 r
F P
0 g
s
.5229 .53426 m .52255 .53376 L p .51537 .53343 L .135 0 0 r
F P
0 g
s
.52255 .53376 m .54711 .5323 L p .52875 .53404 L .175 .709 .83 r
F P
0 g
s
.54711 .5323 m .55009 .53301 L .5413 .53353 L p .175 .709 .83 r
F P
0 g
s
.55009 .53301 m .54711 .5323 L .57031 .52722 L p .323 .809 .862 r
F P
0 g
s
.54711 .5323 m .5441 .533 L .55423 .53078 L p 0 0 0 r
F P
0 g
s
.55423 .53078 m .56411 .52862 L p .54711 .5323 L 0 0 0 r
F P
0 g
s
.5413 .53353 m .5222 .53467 L p .54711 .5323 L .175 .709 .83 r
F P
0 g
s
.42743 .51857 m .43686 .5158 L .46192 .5273 L p .538 .742 .97 r
F P
0 g
s
.46864 .52555 m .46192 .5273 L .43686 .5158 L p .353 .69 .981 r
F P
0 g
s
.46192 .5273 m .46864 .52555 L .49448 .53214 L p .344 .727 .985 r
F P
0 g
s
.57031 .52722 m .57645 .52724 L .55009 .53301 L p .323 .809 .862 r
F P
0 g
s
.61746 .52155 m .60857 .5185 L .6294 .50416 L p .683 .842 .959 r
F P
0 g
s
.6294 .50416 m .64062 .50569 L .61746 .52155 L p .683 .842 .959 r
F P
0 g
s
.71967 .55889 m .70842 .55047 L .73496 .52086 L p .578 .624 .862 r
F P
0 g
s
.73496 .52086 m .74808 .52759 L .71967 .55889 L p .578 .624 .862 r
F P
0 g
s
.25833 .53084 m .27139 .52908 L .30057 .56485 L p .652 .752 .923 r
F P
0 g
s
.31203 .55962 m .30057 .56485 L .27139 .52908 L p .707 .771 .902 r
F P
0 g
s
.70842 .55047 m .6971 .54128 L .72179 .51338 L p .567 .606 .852 r
F P
0 g
s
.72179 .51338 m .73496 .52086 L .70842 .55047 L p .567 .606 .852 r
F P
0 g
s
.39402 .50544 m .40567 .50197 L .42743 .51857 L p .647 .748 .923 r
F P
0 g
s
.43686 .5158 m .42743 .51857 L .40567 .50197 L p .541 .72 .956 r
F P
0 g
s
.6971 .54128 m .68576 .53194 L .70862 .50576 L p .565 .603 .85 r
F P
0 g
s
.70862 .50576 m .72179 .51338 L .6971 .54128 L p .565 .603 .85 r
F P
0 g
s
.27139 .52908 m .2846 .5256 L .31203 .55962 L p .707 .771 .902 r
F P
0 g
s
.32362 .5528 m .31203 .55962 L .2846 .5256 L p .747 .783 .882 r
F P
0 g
s
.68576 .53194 m .67443 .52312 L .69549 .49869 L p .573 .616 .857 r
F P
0 g
s
.69549 .49869 m .70862 .50576 L .68576 .53194 L p .573 .616 .857 r
F P
0 g
s
.57645 .52724 m .57031 .52722 L .59069 .51881 L p .501 .906 .908 r
F P
0 g
s
.59069 .51881 m .59965 .51769 L .57645 .52724 L p .501 .906 .908 r
F P
0 g
s
.67443 .52312 m .66312 .51546 L .68241 .4928 L p .592 .646 .872 r
F P
0 g
s
.68241 .4928 m .69549 .49869 L .67443 .52312 L p .592 .646 .872 r
F P
0 g
s
.2846 .5256 m .29794 .52053 L .32362 .5528 L p .747 .783 .882 r
F P
0 g
s
.33531 .54471 m .32362 .5528 L .29794 .52053 L p .774 .789 .866 r
F P
0 g
s
.60857 .5185 m .59965 .51769 L .61818 .50488 L p .688 .92 .971 r
F P
0 g
s
.61818 .50488 m .6294 .50416 L .60857 .5185 L p .688 .92 .971 r
F P
0 g
s
.43686 .5158 m .4463 .51527 L .46864 .52555 L p .353 .69 .981 r
F P
0 g
s
.47541 .52573 m .46864 .52555 L .4463 .51527 L p .114 .575 .917 r
F P
0 g
s
.29794 .52053 m .31136 .5142 L .33531 .54471 L p .774 .789 .866 r
F P
0 g
s
.34707 .53585 m .33531 .54471 L .31136 .5142 L p .788 .792 .856 r
F P
0 g
s
.66312 .51546 m .65185 .50952 L .66941 .48866 L p .623 .694 .895 r
F P
0 g
s
.66941 .48866 m .68241 .4928 L .66312 .51546 L p .623 .694 .895 r
F P
0 g
s
.31136 .5142 m .32482 .50711 L .34707 .53585 L p .788 .792 .856 r
F P
0 g
s
.35884 .52684 m .34707 .53585 L .32482 .50711 L p .79 .793 .855 r
F P
0 g
s
.52255 .53376 m .5229 .53426 L .5441 .533 L p .032 0 0 r
F P
0 g
s
.5441 .533 m .54711 .5323 L .52255 .53376 L p .032 0 0 r
F P
0 g
s
.40567 .50197 m .41729 .5008 L .43686 .5158 L p .541 .72 .956 r
F P
0 g
s
.4463 .51527 m .43686 .5158 L .41729 .5008 L p .386 .66 .967 r
F P
0 g
s
.32482 .50711 m .33828 .49989 L .35884 .52684 L p .79 .793 .855 r
F P
0 g
s
.37061 .51835 m .35884 .52684 L .33828 .49989 L p .78 .791 .861 r
F P
0 g
s
.55783 .53077 m .56411 .52862 L .5441 .533 L p 0 0 0 r
F P
0 g
s
.56411 .52862 m .55783 .53077 L .56155 .52923 L p .313 .79 .706 r
F P
0 g
s
.56643 .52807 m .54711 .5323 L p .56411 .52862 L 0 0 0 r
F P
0 g
s
.56155 .52923 m .57252 .5247 L p .56411 .52862 L .313 .79 .706 r
F P
0 g
s
.56411 .52862 m .57031 .52722 L .56643 .52807 L p 0 0 0 r
F P
0 g
s
.33828 .49989 m .35169 .49321 L .37061 .51835 L p .78 .791 .861 r
F P
0 g
s
.38234 .51103 m .37061 .51835 L .35169 .49321 L p .756 .784 .876 r
F P
0 g
s
.65185 .50952 m .64062 .50569 L .65648 .48666 L p .663 .759 .922 r
F P
0 g
s
.65648 .48666 m .66941 .48866 L .65185 .50952 L p .663 .759 .922 r
F P
0 g
s
.83625 .53514 m .82406 .53716 L .8456 .4899 L p .759 .876 .932 r
F P
0 g
s
.8456 .4899 m .85906 .48583 L .83625 .53514 L p .759 .876 .932 r
F P
0 g
s
.35169 .49321 m .36504 .48773 L .38234 .51103 L p .756 .784 .876 r
F P
0 g
s
.39402 .50544 m .38234 .51103 L .36504 .48773 L p .714 .771 .897 r
F P
0 g
s
.59965 .51769 m .59069 .51881 L .60691 .50756 L p .661 .96 .936 r
F P
0 g
s
.60691 .50756 m .61818 .50488 L .59965 .51769 L p .661 .96 .936 r
F P
0 g
s
.36504 .48773 m .3783 .484 L .39402 .50544 L p .714 .771 .897 r
F P
0 g
s
.40567 .50197 m .39402 .50544 L .3783 .484 L p .647 .745 .921 r
F P
0 g
s
.64062 .50569 m .6294 .50416 L .6436 .48698 L p .707 .835 .943 r
F P
0 g
s
.6436 .48698 m .65648 .48666 L .64062 .50569 L p .707 .835 .943 r
F P
0 g
s
.57031 .52722 m .56411 .52862 L .58165 .52138 L p .381 .841 .785 r
F P
0 g
s
.58165 .52138 m .59069 .51881 L .57031 .52722 L p .381 .841 .785 r
F P
0 g
s
.82406 .53716 m .81177 .53883 L .83208 .4936 L p .75 .866 .933 r
F P
0 g
s
.83208 .4936 m .8456 .4899 L .82406 .53716 L p .75 .866 .933 r
F P
0 g
s
.4463 .51527 m .45579 .51669 L .47541 .52573 L p .114 .575 .917 r
F P
0 g
s
.48223 .52734 m .47541 .52573 L .45579 .51669 L p 0 .445 .806 r
F P
0 g
s
.41729 .5008 m .42892 .50188 L .4463 .51527 L p .386 .66 .967 r
F P
0 g
s
.45579 .51669 m .4463 .51527 L .42892 .50188 L p .203 .568 .938 r
F P
0 g
s
.3783 .484 m .39149 .48241 L .40567 .50197 L p .647 .745 .921 r
F P
0 g
s
.41729 .5008 m .40567 .50197 L .39149 .48241 L p .551 .702 .94 r
F P
0 g
s
.81177 .53883 m .79935 .53961 L .81844 .49641 L p .729 .841 .933 r
F P
0 g
s
.81844 .49641 m .83208 .4936 L .81177 .53883 L p .729 .841 .933 r
F P
0 g
s
.6294 .50416 m .61818 .50488 L .63073 .48957 L p .745 .908 .949 r
F P
0 g
s
.63073 .48957 m .6436 .48698 L .6294 .50416 L p .745 .908 .949 r
F P
0 g
s
.52325 .5355 m .5229 .53426 L .50183 .53234 L p .23 0 0 r
F P
0 g
s
.5229 .53426 m .52325 .5355 L .54105 .53444 L p .125 0 0 r
F P
0 g
s
.54105 .53444 m .5441 .533 L .5229 .53426 L p .125 0 0 r
F P
0 g
s
.22009 .52775 m .20758 .52532 L .18911 .47507 L p .484 .643 .926 r
F P
0 g
s
.5441 .533 m .54105 .53444 L .55783 .53077 L p 0 0 0 r
F P
0 g
s
.50183 .53234 m .50557 .53388 L .52325 .5355 L p .23 0 0 r
F P
0 g
s
.59069 .51881 m .58165 .52138 L .59558 .5117 L p .614 .957 .872 r
F P
0 g
s
.59558 .5117 m .60691 .50756 L .59069 .51881 L p .614 .957 .872 r
F P
0 g
s
.79935 .53961 m .78677 .53906 L .80465 .49788 L p .697 .802 .93 r
F P
0 g
s
.80465 .49788 m .81844 .49641 L .79935 .53961 L p .697 .802 .93 r
F P
0 g
s
.39149 .48241 m .40463 .48315 L .41729 .5008 L p .551 .702 .94 r
F P
0 g
s
.42892 .50188 m .41729 .5008 L .40463 .48315 L p .429 .638 .943 r
F P
0 g
s
.18911 .47507 m .20272 .47959 L .22009 .52775 L p .484 .643 .926 r
F P
0 g
s
.23269 .52981 m .22009 .52775 L .20272 .47959 L p .502 .654 .928 r
F P
0 g
s
.42892 .50188 m .44058 .50493 L .45579 .51669 L p .203 .568 .938 r
F P
0 g
s
.46535 .51955 m .45579 .51669 L .44058 .50493 L p .046 .474 .884 r
F P
0 g
s
.45579 .51669 m .46535 .51955 L .48223 .52734 L p 0 .445 .806 r
F P
0 g
s
.57252 .5247 m .58165 .52138 L .56411 .52862 L p .313 .79 .706 r
F P
0 g
s
.78677 .53906 m .77402 .53691 L .79071 .49773 L p .656 .755 .922 r
F P
0 g
s
.79071 .49773 m .80465 .49788 L .78677 .53906 L p .656 .755 .922 r
F P
0 g
s
.61818 .50488 m .60691 .50756 L .61785 .49414 L p .766 .959 .932 r
F P
0 g
s
.61785 .49414 m .63073 .48957 L .61818 .50488 L p .766 .959 .932 r
F P
0 g
s
.20272 .47959 m .2164 .48375 L .23269 .52981 L p .502 .654 .928 r
F P
0 g
s
.24543 .53099 m .23269 .52981 L .2164 .48375 L p .541 .681 .929 r
F P
0 g
s
.77402 .53691 m .76111 .53304 L .77664 .49586 L p .614 .705 .91 r
F P
0 g
s
.77664 .49586 m .79071 .49773 L .77402 .53691 L p .614 .705 .91 r
F P
0 g
s
.70862 .50576 m .69549 .49869 L .70559 .47146 L p .538 .618 .88 r
F P
0 g
s
.69549 .49869 m .68241 .4928 L .69154 .46761 L p .567 .65 .891 r
F P
0 g
s
.69154 .46761 m .70559 .47146 L .69549 .49869 L p .567 .65 .891 r
F P
0 g
s
.72179 .51338 m .70862 .50576 L .71974 .47653 L p .526 .604 .874 r
F P
0 g
s
.70559 .47146 m .71974 .47653 L .70862 .50576 L p .538 .618 .88 r
F P
0 g
s
.68241 .4928 m .66941 .48866 L .67761 .46553 L p .61 .698 .906 r
F P
0 g
s
.67761 .46553 m .69154 .46761 L .68241 .4928 L p .61 .698 .906 r
F P
0 g
s
.40463 .48315 m .41774 .48616 L .42892 .50188 L p .429 .638 .943 r
F P
0 g
s
.44058 .50493 m .42892 .50188 L .41774 .48616 L p .302 .562 .928 r
F P
0 g
s
.76111 .53304 m .74808 .52759 L .76246 .49238 L p .576 .661 .896 r
F P
0 g
s
.76246 .49238 m .77664 .49586 L .76111 .53304 L p .576 .661 .896 r
F P
0 g
s
.73496 .52086 m .72179 .51338 L .73396 .48215 L p .529 .608 .876 r
F P
0 g
s
.71974 .47653 m .73396 .48215 L .72179 .51338 L p .526 .604 .874 r
F P
0 g
s
.74808 .52759 m .73496 .52086 L .74822 .48764 L p .547 .627 .883 r
F P
0 g
s
.73396 .48215 m .74822 .48764 L .73496 .52086 L p .529 .608 .876 r
F P
0 g
s
.74822 .48764 m .76246 .49238 L .74808 .52759 L p .547 .627 .883 r
F P
0 g
s
.66941 .48866 m .65648 .48666 L .66377 .4656 L p .665 .758 .92 r
F P
0 g
s
.66377 .4656 m .67761 .46553 L .66941 .48866 L p .665 .758 .92 r
F P
0 g
s
.2164 .48375 m .2302 .48702 L .24543 .53099 L p .541 .681 .929 r
F P
0 g
s
.25833 .53084 m .24543 .53099 L .2302 .48702 L p .595 .715 .928 r
F P
0 g
s
.52361 .53666 m .52325 .5355 L .50557 .53388 L p .219 0 0 r
F P
0 g
s
.52325 .5355 m .52361 .53666 L .53796 .5358 L p .114 0 0 r
F P
0 g
s
.53796 .5358 m .54105 .53444 L .52325 .5355 L p .114 0 0 r
F P
0 g
s
.58165 .52138 m .57252 .5247 L .58414 .51661 L p .581 .942 .827 r
F P
0 g
s
.58414 .51661 m .59558 .5117 L .58165 .52138 L p .581 .942 .827 r
F P
0 g
s
.65648 .48666 m .6436 .48698 L .65003 .46801 L p .723 .822 .926 r
F P
0 g
s
.65003 .46801 m .66377 .4656 L .65648 .48666 L p .723 .822 .926 r
F P
0 g
s
.54105 .53444 m .53796 .5358 L .55147 .53285 L p 0 0 0 r
F P
0 g
s
.55147 .53285 m .55783 .53077 L .54105 .53444 L p 0 0 0 r
F P
0 g
s
.60691 .50756 m .59558 .5117 L .60491 .50019 L p .771 .984 .904 r
F P
0 g
s
.60491 .50019 m .61785 .49414 L .60691 .50756 L p .771 .984 .904 r
F P
0 g
s
.50937 .53536 m .50557 .53388 L .48914 .52969 L p .244 0 0 r
F P
0 g
s
.50557 .53388 m .50937 .53536 L .52361 .53666 L p .219 0 0 r
F P
0 g
s
.2302 .48702 m .24413 .48895 L .25833 .53084 L p .595 .715 .928 r
F P
0 g
s
.27139 .52908 m .25833 .53084 L .24413 .48895 L p .652 .751 .922 r
F P
0 g
s
.34404 .46562 m .35817 .46221 L .36504 .48773 L p .757 .811 .895 r
F P
0 g
s
.36504 .48773 m .35169 .49321 L .34404 .46562 L p .757 .811 .895 r
F P
0 g
s
.3783 .484 m .36504 .48773 L .35817 .46221 L p .712 .784 .908 r
F P
0 g
s
.32979 .47024 m .34404 .46562 L .35169 .49321 L p .784 .826 .885 r
F P
0 g
s
.35169 .49321 m .33828 .49989 L .32979 .47024 L p .784 .826 .885 r
F P
0 g
s
.44058 .50493 m .45231 .50944 L .46535 .51955 L p .046 .474 .884 r
F P
0 g
s
.47501 .52317 m .46535 .51955 L .45231 .50944 L p 0 .419 .845 r
F P
0 g
s
.46535 .51955 m .47501 .52317 L .48914 .52969 L p 0 .371 .734 r
F P
0 g
s
.31546 .47542 m .32979 .47024 L .33828 .49989 L p .795 .832 .88 r
F P
0 g
s
.33828 .49989 m .32482 .50711 L .31546 .47542 L p .795 .832 .88 r
F P
0 g
s
.35817 .46221 m .37219 .46057 L .3783 .484 L p .712 .784 .908 r
F P
0 g
s
.39149 .48241 m .3783 .484 L .37219 .46057 L p .648 .743 .919 r
F P
0 g
s
.30109 .48047 m .31546 .47542 L .32482 .50711 L p .792 .83 .881 r
F P
0 g
s
.32482 .50711 m .31136 .5142 L .30109 .48047 L p .792 .83 .881 r
F P
0 g
s
.24413 .48895 m .25821 .48924 L .27139 .52908 L p .652 .751 .922 r
F P
0 g
s
.2846 .5256 m .27139 .52908 L .25821 .48924 L p .705 .782 .912 r
F P
0 g
s
.6436 .48698 m .63073 .48957 L .63633 .47271 L p .776 .879 .921 r
F P
0 g
s
.63633 .47271 m .65003 .46801 L .6436 .48698 L p .776 .879 .921 r
F P
0 g
s
.41774 .48616 m .43086 .49116 L .44058 .50493 L p .302 .562 .928 r
F P
0 g
s
.45231 .50944 m .44058 .50493 L .43086 .49116 L p .198 .496 .904 r
F P
0 g
s
.28673 .48478 m .30109 .48047 L .31136 .5142 L p .776 .822 .888 r
F P
0 g
s
.31136 .5142 m .29794 .52053 L .28673 .48478 L p .776 .822 .888 r
F P
0 g
s
.25821 .48924 m .27242 .48781 L .2846 .5256 L p .705 .782 .912 r
F P
0 g
s
.29794 .52053 m .2846 .5256 L .27242 .48781 L p .747 .806 .899 r
F P
0 g
s
.37219 .46057 m .3861 .4611 L .39149 .48241 L p .648 .743 .919 r
F P
0 g
s
.40463 .48315 m .39149 .48241 L .3861 .4611 L p .566 .688 .923 r
F P
0 g
s
.55783 .53077 m .55147 .53285 L .56327 .52797 L p .321 .797 .716 r
F P
0 g
s
.56327 .52797 m .57252 .5247 L .55783 .53077 L p .321 .797 .716 r
F P
0 g
s
.27242 .48781 m .28673 .48478 L .29794 .52053 L p .747 .806 .899 r
F P
0 g
s
.48914 .52969 m .49614 .53199 L .50937 .53536 L p .244 0 0 r
F P
0 g
s
.49614 .53199 m .48914 .52969 L .47501 .52317 L p 0 .38 .743 r
F P
0 g
s
.3861 .4611 m .39992 .46396 L .40463 .48315 L p .566 .688 .923 r
F P
0 g
s
.41774 .48616 m .40463 .48315 L .39992 .46396 L p .476 .623 .915 r
F P
0 g
s
.63073 .48957 m .61785 .49414 L .62265 .47939 L p .816 .921 .907 r
F P
0 g
s
.62265 .47939 m .63633 .47271 L .63073 .48957 L p .816 .921 .907 r
F P
0 g
s
.59558 .5117 m .58414 .51661 L .59189 .507 L p .769 .992 .884 r
F P
0 g
s
.59189 .507 m .60491 .50019 L .59558 .5117 L p .769 .992 .884 r
F P
0 g
s
.57252 .5247 m .56327 .52797 L .57258 .52148 L p .585 .945 .833 r
F P
0 g
s
.57258 .52148 m .58414 .51661 L .57252 .5247 L p .585 .945 .833 r
F P
0 g
s
.43086 .49116 m .44403 .49763 L .45231 .50944 L p .198 .496 .904 r
F P
0 g
s
.46414 .51472 m .45231 .50944 L .44403 .49763 L p .144 .459 .887 r
F P
0 g
s
.45231 .50944 m .46414 .51472 L .47501 .52317 L p 0 .419 .845 r
F P
0 g
s
.39992 .46396 m .41367 .46911 L .41774 .48616 L p .476 .623 .915 r
F P
0 g
s
.43086 .49116 m .41774 .48616 L .41367 .46911 L p .391 .559 .9 r
F P
0 g
s
.48479 .52675 m .47501 .52317 L .46414 .51472 L p 0 .426 .851 r
F P
0 g
s
.47501 .52317 m .48479 .52675 L .49614 .53199 L p 0 .38 .743 r
F P
0 g
s
.52398 .5369 m .52361 .53666 L .50937 .53536 L p .094 0 0 r
F P
0 g
s
.52361 .53666 m .52398 .5369 L .53481 .53625 L p 0 0 0 r
F P
0 g
s
.53481 .53625 m .53796 .5358 L .52361 .53666 L p 0 0 0 r
F P
0 g
s
.53796 .5358 m .53481 .53625 L .54501 .53402 L p .18 .711 .722 r
F P
0 g
s
.54501 .53402 m .55147 .53285 L .53796 .5358 L p .18 .711 .722 r
F P
0 g
s
.50937 .53536 m .51322 .53592 L .52398 .5369 L p .094 0 0 r
F P
0 g
s
.51322 .53592 m .50937 .53536 L .49614 .53199 L p 0 .466 .739 r
F P
0 g
s
.61785 .49414 m .60491 .50019 L .60894 .48755 L p .84 .945 .889 r
F P
0 g
s
.60894 .48755 m .62265 .47939 L .61785 .49414 L p .84 .945 .889 r
F P
0 g
s
.55147 .53285 m .54501 .53402 L .5539 .53035 L p .406 .857 .813 r
F P
0 g
s
.5539 .53035 m .56327 .52797 L .55147 .53285 L p .406 .857 .813 r
F P
0 g
s
.50324 .53337 m .49614 .53199 L .48479 .52675 L p 0 .473 .831 r
F P
0 g
s
.49614 .53199 m .50324 .53337 L .51322 .53592 L p 0 .466 .739 r
F P
0 g
s
.41367 .46911 m .42741 .47625 L .43086 .49116 L p .391 .559 .9 r
F P
0 g
s
.44403 .49763 m .43086 .49116 L .42741 .47625 L p .328 .51 .884 r
F P
0 g
s
.58414 .51661 m .57258 .52148 L .57875 .51378 L p .769 .991 .887 r
F P
0 g
s
.57875 .51378 m .59189 .507 L .58414 .51661 L p .769 .991 .887 r
F P
0 g
s
.69154 .46761 m .67761 .46553 L .6755 .4416 L p .599 .705 .918 r
F P
0 g
s
.67761 .46553 m .66377 .4656 L .66169 .44387 L p .666 .756 .918 r
F P
0 g
s
.66169 .44387 m .6755 .4416 L .67761 .46553 L p .666 .756 .918 r
F P
0 g
s
.44403 .49763 m .45728 .50487 L .46414 .51472 L p .144 .459 .887 r
F P
0 g
s
.47609 .51997 m .46414 .51472 L .45728 .50487 L p .151 .463 .889 r
F P
0 g
s
.46414 .51472 m .47609 .51997 L .48479 .52675 L p 0 .426 .851 r
F P
0 g
s
.66377 .4656 m .65003 .46801 L .648 .44848 L p .732 .804 .909 r
F P
0 g
s
.648 .44848 m .66169 .44387 L .66377 .4656 L p .732 .804 .909 r
F P
0 g
s
.56327 .52797 m .5539 .53035 L .56089 .52546 L p .624 .96 .887 r
F P
0 g
s
.56089 .52546 m .57258 .52148 L .56327 .52797 L p .624 .96 .887 r
F P
0 g
s
.70559 .47146 m .69154 .46761 L .68945 .44149 L p .542 .66 .913 r
F P
0 g
s
.6755 .4416 m .68945 .44149 L .69154 .46761 L p .599 .705 .918 r
F P
0 g
s
.60491 .50019 m .59189 .507 L .59517 .49648 L p .851 .956 .879 r
F P
0 g
s
.59517 .49648 m .60894 .48755 L .60491 .50019 L p .851 .956 .879 r
F P
0 g
s
.4947 .52942 m .48479 .52675 L .47609 .51997 L p .077 .494 .897 r
F P
0 g
s
.48479 .52675 m .4947 .52942 L .50324 .53337 L p 0 .473 .831 r
F P
0 g
s
.65003 .46801 m .63633 .47271 L .63439 .45539 L p .787 .842 .893 r
F P
0 g
s
.63439 .45539 m .648 .44848 L .65003 .46801 L p .787 .842 .893 r
F P
0 g
s
.71974 .47653 m .70559 .47146 L .70354 .44316 L p .502 .627 .906 r
F P
0 g
s
.68945 .44149 m .70354 .44316 L .70559 .47146 L p .542 .66 .913 r
F P
0 g
s
.42741 .47625 m .44116 .48487 L .44403 .49763 L p .328 .51 .884 r
F P
0 g
s
.45728 .50487 m .44403 .49763 L .44116 .48487 L p .296 .484 .874 r
F P
0 g
s
.52435 .53542 m .52398 .5369 L .51322 .53592 L p .162 .68 .886 r
F P
0 g
s
.52398 .5369 m .52435 .53542 L .53162 .53499 L p .244 .75 .883 r
F P
0 g
s
.53162 .53499 m .53481 .53625 L .52398 .5369 L p .244 .75 .883 r
F P
0 g
s
.37649 .43668 m .39018 .43941 L .3861 .4611 L p .649 .742 .917 r
F P
0 g
s
.3861 .4611 m .37219 .46057 L .37649 .43668 L p .649 .742 .917 r
F P
0 g
s
.39992 .46396 m .3861 .4611 L .39018 .43941 L p .584 .679 .906 r
F P
0 g
s
.73396 .48215 m .71974 .47653 L .71778 .44606 L p .484 .612 .903 r
F P
0 g
s
.70354 .44316 m .71778 .44606 L .71974 .47653 L p .502 .627 .906 r
F P
0 g
s
.63633 .47271 m .62265 .47939 L .62083 .46428 L p .829 .868 .874 r
F P
0 g
s
.62083 .46428 m .63439 .45539 L .63633 .47271 L p .829 .868 .874 r
F P
0 g
s
.53481 .53625 m .53162 .53499 L .53846 .53349 L p .377 .836 .906 r
F P
0 g
s
.53846 .53349 m .54501 .53402 L .53481 .53625 L p .377 .836 .906 r
F P
0 g
s
.36267 .43612 m .37649 .43668 L .37219 .46057 L p .706 .796 .92 r
F P
0 g
s
.37219 .46057 m .35817 .46221 L .36267 .43612 L p .706 .796 .92 r
F P
0 g
s
.51713 .53477 m .51322 .53592 L .50324 .53337 L p .141 .636 .913 r
F P
0 g
s
.51322 .53592 m .51713 .53477 L .52435 .53542 L p .162 .68 .886 r
F P
0 g
s
.39018 .43941 m .40373 .44448 L .39992 .46396 L p .584 .679 .906 r
F P
0 g
s
.41367 .46911 m .39992 .46396 L .40373 .44448 L p .52 .615 .888 r
F P
0 g
s
.34869 .43733 m .36267 .43612 L .35817 .46221 L p .749 .835 .917 r
F P
0 g
s
.35817 .46221 m .34404 .46562 L .34869 .43733 L p .749 .835 .917 r
F P
0 g
s
.85906 .48583 m .8456 .4899 L .84599 .43954 L p .772 .844 .906 r
F P
0 g
s
.84599 .43954 m .85986 .43317 L .85906 .48583 L p .772 .844 .906 r
F P
0 g
s
.54501 .53402 m .53846 .53349 L .54441 .53103 L p .532 .914 .936 r
F P
0 g
s
.54441 .53103 m .5539 .53035 L .54501 .53402 L p .532 .914 .936 r
F P
0 g
s
.57258 .52148 m .56089 .52546 L .5655 .51968 L p .77 .98 .911 r
F P
0 g
s
.5655 .51968 m .57875 .51378 L .57258 .52148 L p .77 .98 .911 r
F P
0 g
s
.74822 .48764 m .73396 .48215 L .73212 .44952 L p .489 .616 .904 r
F P
0 g
s
.71778 .44606 m .73212 .44952 L .73396 .48215 L p .484 .612 .903 r
F P
0 g
s
.51045 .53306 m .50324 .53337 L .4947 .52942 L p .178 .611 .941 r
F P
0 g
s
.50324 .53337 m .51045 .53306 L .51713 .53477 L p .141 .636 .913 r
F P
0 g
s
.59189 .507 m .57875 .51378 L .58133 .50538 L p .85 .955 .88 r
F P
0 g
s
.58133 .50538 m .59517 .49648 L .59189 .507 L p .85 .955 .88 r
F P
0 g
s
.33457 .43977 m .34869 .43733 L .34404 .46562 L p .776 .86 .912 r
F P
0 g
s
.34404 .46562 m .32979 .47024 L .33457 .43977 L p .776 .86 .912 r
F P
0 g
s
.40373 .44448 m .4172 .45185 L .41367 .46911 L p .52 .615 .888 r
F P
0 g
s
.42741 .47625 m .41367 .46911 L .4172 .45185 L p .465 .561 .868 r
F P
0 g
s
.62265 .47939 m .60894 .48755 L .60728 .47464 L p .854 .883 .859 r
F P
0 g
s
.60728 .47464 m .62083 .46428 L .62265 .47939 L p .854 .883 .859 r
F P
0 g
s
.45728 .50487 m .47063 .51208 L .47609 .51997 L p .151 .463 .889 r
F P
0 g
s
.48817 .52432 m .47609 .51997 L .47063 .51208 L p .219 .509 .909 r
F P
0 g
s
.47609 .51997 m .48817 .52432 L .4947 .52942 L p .077 .494 .897 r
F P
0 g
s
.8456 .4899 m .83208 .4936 L .83207 .44553 L p .763 .837 .909 r
F P
0 g
s
.83207 .44553 m .84599 .43954 L .8456 .4899 L p .763 .837 .909 r
F P
0 g
s
.76246 .49238 m .74822 .48764 L .74653 .45285 L p .514 .637 .909 r
F P
0 g
s
.73212 .44952 m .74653 .45285 L .74822 .48764 L p .489 .616 .904 r
F P
0 g
s
.44116 .48487 m .45496 .49425 L .45728 .50487 L p .296 .484 .874 r
F P
0 g
s
.47063 .51208 m .45728 .50487 L .45496 .49425 L p .3 .487 .875 r
F P
0 g
s
.5539 .53035 m .54441 .53103 L .54907 .52776 L p .669 .954 .95 r
F P
0 g
s
.54907 .52776 m .56089 .52546 L .5539 .53035 L p .669 .954 .95 r
F P
0 g
s
.32033 .44277 m .33457 .43977 L .32979 .47024 L p .787 .87 .909 r
F P
0 g
s
.32979 .47024 m .31546 .47542 L .32033 .44277 L p .787 .87 .909 r
F P
0 g
s
.83208 .4936 m .81844 .49641 L .81807 .45061 L p .74 .819 .914 r
F P
0 g
s
.81807 .45061 m .83207 .44553 L .83208 .4936 L p .74 .819 .914 r
F P
0 g
s
.50473 .53041 m .4947 .52942 L .48817 .52432 L p .251 .595 .95 r
F P
0 g
s
.4947 .52942 m .50473 .53041 L .51045 .53306 L p .178 .611 .941 r
F P
0 g
s
.4172 .45185 m .43062 .46119 L .42741 .47625 L p .465 .561 .868 r
F P
0 g
s
.44116 .48487 m .42741 .47625 L .43062 .46119 L p .427 .522 .852 r
F P
0 g
s
.77664 .49586 m .76246 .49238 L .76097 .45542 L p .555 .671 .915 r
F P
0 g
s
.74653 .45285 m .76097 .45542 L .76246 .49238 L p .514 .637 .909 r
F P
0 g
s
.81844 .49641 m .80465 .49788 L .80395 .45433 L p .703 .791 .919 r
F P
0 g
s
.80395 .45433 m .81807 .45061 L .81844 .49641 L p .703 .791 .919 r
F P
0 g
s
.60894 .48755 m .59517 .49648 L .5937 .48576 L p .866 .889 .85 r
F P
0 g
s
.5937 .48576 m .60728 .47464 L .60894 .48755 L p .866 .889 .85 r
F P
0 g
s
.79071 .49773 m .77664 .49586 L .77538 .45672 L p .605 .712 .92 r
F P
0 g
s
.76097 .45542 m .77538 .45672 L .77664 .49586 L p .555 .671 .915 r
F P
0 g
s
.80465 .49788 m .79071 .49773 L .78971 .45639 L p .657 .754 .922 r
F P
0 g
s
.78971 .45639 m .80395 .45433 L .80465 .49788 L p .657 .754 .922 r
F P
0 g
s
.30601 .44565 m .32033 .44277 L .31546 .47542 L p .785 .867 .91 r
F P
0 g
s
.31546 .47542 m .30109 .48047 L .30601 .44565 L p .785 .867 .91 r
F P
0 g
s
.77538 .45672 m .78971 .45639 L .79071 .49773 L p .605 .712 .92 r
F P
0 g
s
.57875 .51378 m .5655 .51968 L .56738 .51338 L p .836 .941 .893 r
F P
0 g
s
.56738 .51338 m .58133 .50538 L .57875 .51378 L p .836 .941 .893 r
F P
0 g
s
.52473 .53158 m .52435 .53542 L .51713 .53477 L p .445 .791 .998 r
F P
0 g
s
.52435 .53542 m .52473 .53158 L .52839 .53136 L p .492 .831 .998 r
F P
0 g
s
.52839 .53136 m .53162 .53499 L .52435 .53542 L p .492 .831 .998 r
F P
0 g
s
.56089 .52546 m .54907 .52776 L .55213 .5239 L p .761 .948 .939 r
F P
0 g
s
.55213 .5239 m .5655 .51968 L .56089 .52546 L p .761 .948 .939 r
F P
0 g
s
.43062 .46119 m .44401 .47201 L .44116 .48487 L p .427 .522 .852 r
F P
0 g
s
.45496 .49425 m .44116 .48487 L .44401 .47201 L p .408 .502 .844 r
F P
0 g
s
.53162 .53499 m .52839 .53136 L .53182 .5306 L p .556 .867 .996 r
F P
0 g
s
.53182 .5306 m .53846 .53349 L .53162 .53499 L p .556 .867 .996 r
F P
0 g
s
.5211 .53125 m .51713 .53477 L .51045 .53306 L p .422 .751 .994 r
F P
0 g
s
.51713 .53477 m .5211 .53125 L .52473 .53158 L p .445 .791 .998 r
F P
0 g
s
.45496 .49425 m .46884 .50359 L .47063 .51208 L p .3 .487 .875 r
F P
0 g
s
.48411 .5184 m .47063 .51208 L .46884 .50359 L p .34 .52 .887 r
F P
0 g
s
.47063 .51208 m .48411 .5184 L .48817 .52432 L p .219 .509 .909 r
F P
0 g
s
.50038 .527 m .48817 .52432 L .48411 .5184 L p .334 .584 .935 r
F P
0 g
s
.48817 .52432 m .50038 .527 L .50473 .53041 L p .251 .595 .95 r
F P
0 g
s
.20272 .47959 m .18911 .47507 L .19318 .42214 L p .525 .634 .901 r
F P
0 g
s
.29167 .44776 m .30601 .44565 L .30109 .48047 L p .768 .853 .914 r
F P
0 g
s
.30109 .48047 m .28673 .48478 L .29167 .44776 L p .768 .853 .914 r
F P
0 g
s
.53846 .53349 m .53182 .5306 L .53481 .52936 L p .625 .89 .988 r
F P
0 g
s
.53481 .52936 m .54441 .53103 L .53846 .53349 L p .625 .89 .988 r
F P
0 g
s
.51774 .53039 m .51045 .53306 L .50473 .53041 L p .423 .716 .985 r
F P
0 g
s
.51045 .53306 m .51774 .53039 L .5211 .53125 L p .422 .751 .994 r
F P
0 g
s
.59517 .49648 m .58133 .50538 L .58008 .49683 L p .865 .889 .851 r
F P
0 g
s
.58008 .49683 m .5937 .48576 L .59517 .49648 L p .865 .889 .851 r
F P
0 g
s
.19318 .42214 m .20702 .429 L .20272 .47959 L p .525 .634 .901 r
F P
0 g
s
.2164 .48375 m .20272 .47959 L .20702 .429 L p .537 .645 .904 r
F P
0 g
s
.27734 .44859 m .29167 .44776 L .28673 .48478 L p .739 .828 .919 r
F P
0 g
s
.28673 .48478 m .27242 .48781 L .27734 .44859 L p .739 .828 .919 r
F P
0 g
s
.54441 .53103 m .53481 .52936 L .53714 .52772 L p .686 .896 .973 r
F P
0 g
s
.53714 .52772 m .54907 .52776 L .54441 .53103 L p .686 .896 .973 r
F P
0 g
s
.44401 .47201 m .45743 .48358 L .45496 .49425 L p .408 .502 .844 r
F P
0 g
s
.46884 .50359 m .45496 .49425 L .45743 .48358 L p .41 .505 .845 r
F P
0 g
s
.51488 .52905 m .50473 .53041 L .50038 .527 L p .442 .687 .969 r
F P
0 g
s
.50473 .53041 m .51488 .52905 L .51774 .53039 L p .423 .716 .985 r
F P
0 g
s
.20702 .429 m .22089 .43549 L .2164 .48375 L p .537 .645 .904 r
F P
0 g
s
.2302 .48702 m .2164 .48375 L .22089 .43549 L p .565 .671 .91 r
F P
0 g
s
.66169 .44387 m .648 .44848 L .63738 .42975 L p .733 .784 .894 r
F P
0 g
s
.648 .44848 m .63439 .45539 L .62483 .43881 L p .785 .804 .868 r
F P
0 g
s
.62483 .43881 m .63738 .42975 L .648 .44848 L p .785 .804 .868 r
F P
0 g
s
.6755 .4416 m .66169 .44387 L .65004 .42296 L p .667 .754 .916 r
F P
0 g
s
.63738 .42975 m .65004 .42296 L .66169 .44387 L p .733 .784 .894 r
F P
0 g
s
.5655 .51968 m .55213 .5239 L .55335 .5197 L p .806 .912 .912 r
F P
0 g
s
.55335 .5197 m .56738 .51338 L .5655 .51968 L p .806 .912 .912 r
F P
0 g
s
.26307 .4478 m .27734 .44859 L .27242 .48781 L p .699 .792 .923 r
F P
0 g
s
.27242 .48781 m .25821 .48924 L .26307 .4478 L p .699 .792 .923 r
F P
0 g
s
.63439 .45539 m .62083 .46428 L .61236 .44985 L p .82 .815 .845 r
F P
0 g
s
.61236 .44985 m .62483 .43881 L .63439 .45539 L p .82 .815 .845 r
F P
0 g
s
.22089 .43549 m .23484 .44105 L .2302 .48702 L p .565 .671 .91 r
F P
0 g
s
.24413 .48895 m .2302 .48702 L .23484 .44105 L p .606 .708 .917 r
F P
0 g
s
.2489 .44525 m .26307 .4478 L .25821 .48924 L p .653 .751 .922 r
F P
0 g
s
.25821 .48924 m .24413 .48895 L .2489 .44525 L p .653 .751 .922 r
F P
0 g
s
.46884 .50359 m .48281 .51205 L .48411 .5184 L p .34 .52 .887 r
F P
0 g
s
.49769 .52304 m .48411 .5184 L .48281 .51205 L p .412 .577 .906 r
F P
0 g
s
.48411 .5184 m .49769 .52304 L .50038 .527 L p .334 .584 .935 r
F P
0 g
s
.23484 .44105 m .2489 .44525 L .24413 .48895 L p .606 .708 .917 r
F P
0 g
s
.68945 .44149 m .6755 .4416 L .66283 .41852 L p .591 .716 .93 r
F P
0 g
s
.65004 .42296 m .66283 .41852 L .6755 .4416 L p .667 .754 .916 r
F P
0 g
s
.58133 .50538 m .56738 .51338 L .5664 .50699 L p .849 .881 .862 r
F P
0 g
s
.5664 .50699 m .58008 .49683 L .58133 .50538 L p .849 .881 .862 r
F P
0 g
s
.54907 .52776 m .53714 .52772 L .53866 .52578 L p .73 .886 .952 r
F P
0 g
s
.53866 .52578 m .55213 .5239 L .54907 .52776 L p .73 .886 .952 r
F P
0 g
s
.62083 .46428 m .60728 .47464 L .59992 .46234 L p .842 .821 .828 r
F P
0 g
s
.59992 .46234 m .61236 .44985 L .62083 .46428 L p .842 .821 .828 r
F P
0 g
s
.5127 .52734 m .50038 .527 L .49769 .52304 L p .471 .664 .947 r
F P
0 g
s
.50038 .527 m .5127 .52734 L .51488 .52905 L p .442 .687 .969 r
F P
0 g
s
.40378 .41887 m .4161 .42609 L .40373 .44448 L p .603 .674 .891 r
F P
0 g
s
.40373 .44448 m .39018 .43941 L .40378 .41887 L p .603 .674 .891 r
F P
0 g
s
.4172 .45185 m .40373 .44448 L .4161 .42609 L p .56 .614 .864 r
F P
0 g
s
.4161 .42609 m .4283 .43558 L .4172 .45185 L p .56 .614 .864 r
F P
0 g
s
.43062 .46119 m .4172 .45185 L .4283 .43558 L p .525 .567 .84 r
F P
0 g
s
.45743 .48358 m .47089 .49509 L .46884 .50359 L p .41 .505 .845 r
F P
0 g
s
.48281 .51205 m .46884 .50359 L .47089 .49509 L p .434 .529 .855 r
F P
0 g
s
.39132 .414 m .40378 .41887 L .39018 .43941 L p .651 .741 .915 r
F P
0 g
s
.39018 .43941 m .37649 .43668 L .39132 .414 L p .651 .741 .915 r
F P
0 g
s
.52511 .52492 m .52473 .53158 L .5211 .53125 L closepath p .61 .779 .962 r
F P
0 g
s
.52511 .52492 m .52839 .53136 L .52473 .53158 L closepath p .623 .79 .962 r
F P
0 g
s
.60728 .47464 m .5937 .48576 L .58749 .47557 L p .851 .823 .82 r
F P
0 g
s
.58749 .47557 m .59992 .46234 L .60728 .47464 L p .851 .823 .82 r
F P
0 g
s
.70354 .44316 m .68945 .44149 L .67579 .41625 L p .52 .676 .935 r
F P
0 g
s
.66283 .41852 m .67579 .41625 L .68945 .44149 L p .591 .716 .93 r
F P
0 g
s
.52511 .52492 m .53182 .5306 L .52839 .53136 L closepath p .637 .798 .96 r
F P
0 g
s
.52511 .52492 m .5211 .53125 L .51774 .53039 L closepath p .601 .767 .959 r
F P
0 g
s
.4283 .43558 m .44043 .44704 L .43062 .46119 L p .525 .567 .84 r
F P
0 g
s
.44401 .47201 m .43062 .46119 L .44043 .44704 L p .502 .535 .823 r
F P
0 g
s
.52511 .52492 m .53481 .52936 L .53182 .5306 L closepath p .653 .803 .955 r
F P
0 g
s
.52511 .52492 m .51774 .53039 L .51488 .52905 L closepath p .596 .754 .953 r
F P
0 g
s
.55213 .5239 m .53866 .52578 L .53925 .52369 L p .757 .862 .927 r
F P
0 g
s
.53925 .52369 m .55335 .5197 L .55213 .5239 L p .757 .862 .927 r
F P
0 g
s
.3787 .41129 m .39132 .414 L .37649 .43668 L p .695 .804 .933 r
F P
0 g
s
.37649 .43668 m .36267 .43612 L .3787 .41129 L p .695 .804 .933 r
F P
0 g
s
.56738 .51338 m .55335 .5197 L .55266 .51545 L p .818 .863 .881 r
F P
0 g
s
.55266 .51545 m .5664 .50699 L .56738 .51338 L p .818 .863 .881 r
F P
0 g
s
.48281 .51205 m .49686 .51881 L .49769 .52304 L p .412 .577 .906 r
F P
0 g
s
.51137 .52536 m .49769 .52304 L .49686 .51881 L p .505 .648 .922 r
F P
0 g
s
.49769 .52304 m .51137 .52536 L .5127 .52734 L p .471 .664 .947 r
F P
0 g
s
.52511 .52492 m .53714 .52772 L .53481 .52936 L closepath p .668 .803 .948 r
F P
0 g
s
.52511 .52492 m .51488 .52905 L .5127 .52734 L closepath p .595 .742 .946 r
F P
0 g
s
.44043 .44704 m .45252 .45995 L .44401 .47201 L p .502 .535 .823 r
F P
0 g
s
.45743 .48358 m .44401 .47201 L .45252 .45995 L p .491 .52 .814 r
F P
0 g
s
.5937 .48576 m .58008 .49683 L .57504 .48872 L p .85 .823 .821 r
F P
0 g
s
.57504 .48872 m .58749 .47557 L .5937 .48576 L p .85 .823 .821 r
F P
0 g
s
.47089 .49509 m .4844 .50569 L .48281 .51205 L p .434 .529 .855 r
F P
0 g
s
.49686 .51881 m .48281 .51205 L .4844 .50569 L p .478 .575 .874 r
F P
0 g
s
.52511 .52492 m .53866 .52578 L .53714 .52772 L closepath p .68 .801 .939 r
F P
0 g
s
.71778 .44606 m .70354 .44316 L .68891 .41575 L p .466 .644 .935 r
F P
0 g
s
.67579 .41625 m .68891 .41575 L .70354 .44316 L p .52 .676 .935 r
F P
0 g
s
.52511 .52492 m .5127 .52734 L .51137 .52536 L closepath p .598 .731 .937 r
F P
0 g
s
.45252 .45995 m .4646 .47359 L .45743 .48358 L p .491 .52 .814 r
F P
0 g
s
.47089 .49509 m .45743 .48358 L .4646 .47359 L p .492 .522 .815 r
F P
0 g
s
.36591 .41036 m .3787 .41129 L .36267 .43612 L p .73 .855 .94 r
F P
0 g
s
.36267 .43612 m .34869 .43733 L .36591 .41036 L p .73 .855 .94 r
F P
0 g
s
.55335 .5197 m .53925 .52369 L .53889 .52157 L p .768 .833 .902 r
F P
0 g
s
.53889 .52157 m .55266 .51545 L .55335 .5197 L p .768 .833 .902 r
F P
0 g
s
.52511 .52492 m .53925 .52369 L .53866 .52578 L closepath p .69 .794 .93 r
F P
0 g
s
.58008 .49683 m .5664 .50699 L .56257 .50094 L p .838 .82 .832 r
F P
0 g
s
.56257 .50094 m .57504 .48872 L .58008 .49683 L p .838 .82 .832 r
F P
0 g
s
.49686 .51881 m .51097 .52324 L .51137 .52536 L p .505 .648 .922 r
F P
0 g
s
.52511 .52492 m .51137 .52536 L .51097 .52324 L closepath p .605 .722 .928 r
F P
0 g
s
.4844 .50569 m .49795 .51459 L .49686 .51881 L p .478 .575 .874 r
F P
0 g
s
.51097 .52324 m .49686 .51881 L .49795 .51459 L p .54 .639 .897 r
F P
0 g
s
.4646 .47359 m .47669 .48715 L .47089 .49509 L p .492 .522 .815 r
F P
0 g
s
.4844 .50569 m .47089 .49509 L .47669 .48715 L p .506 .541 .826 r
F P
0 g
s
.52511 .52492 m .53889 .52157 L .53925 .52369 L closepath p .696 .786 .92 r
F P
0 g
s
.5664 .50699 m .55266 .51545 L .55007 .51144 L p .812 .814 .852 r
F P
0 g
s
.55007 .51144 m .56257 .50094 L .5664 .50699 L p .812 .814 .852 r
F P
0 g
s
.49795 .51459 m .51154 .52114 L .51097 .52324 L p .54 .639 .897 r
F P
0 g
s
.52511 .52492 m .51097 .52324 L .51154 .52114 L closepath p .614 .716 .918 r
F P
0 g
s
.73212 .44952 m .71778 .44606 L .70219 .41647 L p .441 .628 .933 r
F P
0 g
s
.68891 .41575 m .70219 .41647 L .71778 .44606 L p .466 .644 .935 r
F P
0 g
s
.52511 .52492 m .53542 .51784 L .53758 .51957 L closepath p .697 .764 .903 r
F P
0 g
s
.52511 .52492 m .53255 .51649 L .53542 .51784 L closepath p .693 .752 .897 r
F P
0 g
s
.52511 .52492 m .52916 .51561 L .53255 .51649 L closepath p .687 .742 .893 r
F P
0 g
s
.52511 .52492 m .5255 .51527 L .52916 .51561 L closepath p .679 .732 .89 r
F P
0 g
s
.52511 .52492 m .52181 .51549 L .5255 .51527 L closepath p .669 .724 .89 r
F P
0 g
s
.52511 .52492 m .51835 .51626 L .52181 .51549 L closepath p .658 .717 .892 r
F P
0 g
s
.52511 .52492 m .51535 .51752 L .51835 .51626 L closepath p .647 .713 .896 r
F P
0 g
s
.52511 .52492 m .51303 .51918 L .51535 .51752 L closepath p .635 .712 .902 r
F P
0 g
s
.52511 .52492 m .51154 .52114 L .51303 .51918 L closepath p .624 .712 .91 r
F P
0 g
s
.52511 .52492 m .53758 .51957 L .53889 .52157 L closepath p .698 .775 .911 r
F P
0 g
s
.35296 .41064 m .36591 .41036 L .34869 .43733 L p .752 .887 .94 r
F P
0 g
s
.34869 .43733 m .33457 .43977 L .35296 .41064 L p .752 .887 .94 r
F P
0 g
s
.47669 .48715 m .48879 .49977 L .4844 .50569 L p .506 .541 .826 r
F P
0 g
s
.49795 .51459 m .4844 .50569 L .48879 .49977 L p .533 .579 .847 r
F P
0 g
s
.55266 .51545 m .53889 .52157 L .53758 .51957 L p .767 .801 .88 r
F P
0 g
s
.53758 .51957 m .55007 .51144 L .55266 .51545 L p .767 .801 .88 r
F P
0 g
s
.50091 .51067 m .51303 .51918 L .51154 .52114 L p .573 .636 .876 r
F P
0 g
s
.51154 .52114 m .49795 .51459 L .50091 .51067 L p .573 .636 .876 r
F P
0 g
s
.48879 .49977 m .50091 .51067 L .49795 .51459 L p .533 .579 .847 r
F P
0 g
s
.62483 .43881 m .61236 .44985 L .59767 .43715 L p .801 .767 .822 r
F P
0 g
s
.61236 .44985 m .59992 .46234 L .58726 .45154 L p .818 .766 .804 r
F P
0 g
s
.58726 .45154 m .59767 .43715 L .61236 .44985 L p .818 .766 .804 r
F P
0 g
s
.63738 .42975 m .62483 .43881 L .60813 .42419 L p .773 .768 .848 r
F P
0 g
s
.59767 .43715 m .60813 .42419 L .62483 .43881 L p .801 .767 .822 r
F P
0 g
s
.59992 .46234 m .58749 .47557 L .57688 .46664 L p .825 .765 .796 r
F P
0 g
s
.57688 .46664 m .58726 .45154 L .59992 .46234 L p .825 .765 .796 r
F P
0 g
s
.55007 .51144 m .53758 .51957 L .53542 .51784 L p .759 .769 .862 r
F P
0 g
s
.50555 .50732 m .51535 .51752 L .51303 .51918 L p .604 .639 .859 r
F P
0 g
s
.51303 .51918 m .50091 .51067 L .50555 .50732 L p .604 .639 .859 r
F P
0 g
s
.65004 .42296 m .63738 .42975 L .61867 .41318 L p .729 .764 .88 r
F P
0 g
s
.60813 .42419 m .61867 .41318 L .63738 .42975 L p .773 .768 .848 r
F P
0 g
s
.58749 .47557 m .57504 .48872 L .56651 .48164 L p .824 .765 .797 r
F P
0 g
s
.56651 .48164 m .57688 .46664 L .58749 .47557 L p .824 .765 .797 r
F P
0 g
s
.74653 .45285 m .73212 .44952 L .71561 .41774 L p .447 .632 .933 r
F P
0 g
s
.70219 .41647 m .71561 .41774 L .73212 .44952 L p .441 .628 .933 r
F P
0 g
s
.56257 .50094 m .55007 .51144 L .54577 .50795 L p .795 .769 .829 r
F P
0 g
s
.53542 .51784 m .54577 .50795 L .55007 .51144 L p .759 .769 .862 r
F P
0 g
s
.54577 .50795 m .53542 .51784 L .53255 .51649 L p .745 .74 .848 r
F P
0 g
s
.57504 .48872 m .56257 .50094 L .55613 .49567 L p .815 .766 .808 r
F P
0 g
s
.55613 .49567 m .56651 .48164 L .57504 .48872 L p .815 .766 .808 r
F P
0 g
s
.51154 .50477 m .51835 .51626 L .51535 .51752 L p .633 .646 .846 r
F P
0 g
s
.51535 .51752 m .50555 .50732 L .51154 .50477 L p .633 .646 .846 r
F P
0 g
s
.44638 .4215 m .45631 .43482 L .44043 .44704 L p .575 .577 .818 r
F P
0 g
s
.44043 .44704 m .4283 .43558 L .44638 .4215 L p .575 .577 .818 r
F P
0 g
s
.45252 .45995 m .44043 .44704 L .45631 .43482 L p .561 .551 .8 r
F P
0 g
s
.54577 .50795 m .55613 .49567 L .56257 .50094 L p .795 .769 .829 r
F P
0 g
s
.45631 .43482 m .46619 .44956 L .45252 .45995 L p .561 .551 .8 r
F P
0 g
s
.4646 .47359 m .45252 .45995 L .46619 .44956 L p .555 .539 .792 r
F P
0 g
s
.33987 .41148 m .35296 .41064 L .33457 .43977 L p .761 .901 .939 r
F P
0 g
s
.33457 .43977 m .32033 .44277 L .33987 .41148 L p .761 .901 .939 r
F P
0 g
s
.49572 .49471 m .50555 .50732 L .50091 .51067 L p .58 .588 .825 r
F P
0 g
s
.50091 .51067 m .48879 .49977 L .49572 .49471 L p .58 .588 .825 r
F P
0 g
s
.43636 .41014 m .44638 .4215 L .4283 .43558 L p .596 .619 .844 r
F P
0 g
s
.4283 .43558 m .4161 .42609 L .43636 .41014 L p .596 .619 .844 r
F P
0 g
s
.46619 .44956 m .47604 .46501 L .4646 .47359 L p .555 .539 .792 r
F P
0 g
s
.47669 .48715 m .4646 .47359 L .47604 .46501 L p .556 .54 .793 r
F P
0 g
s
.53255 .51649 m .54002 .50522 L .54577 .50795 L p .745 .74 .848 r
F P
0 g
s
.54002 .50522 m .53255 .51649 L .52916 .51561 L p .727 .715 .839 r
F P
0 g
s
.51848 .50322 m .52181 .51549 L .51835 .51626 L p .659 .658 .837 r
F P
0 g
s
.51835 .51626 m .51154 .50477 L .51848 .50322 L p .659 .658 .837 r
F P
0 g
s
.66283 .41852 m .65004 .42296 L .62933 .40444 L p .667 .752 .914 r
F P
0 g
s
.61867 .41318 m .62933 .40444 L .65004 .42296 L p .729 .764 .88 r
F P
0 g
s
.47604 .46501 m .48588 .48034 L .47669 .48715 L p .556 .54 .793 r
F P
0 g
s
.48879 .49977 m .47669 .48715 L .48588 .48034 L p .564 .556 .804 r
F P
0 g
s
.48588 .48034 m .49572 .49471 L .48879 .49977 L p .564 .556 .804 r
F P
0 g
s
.52916 .51561 m .53324 .50346 L .54002 .50522 L p .727 .715 .839 r
F P
0 g
s
.53324 .50346 m .52916 .51561 L .5255 .51527 L p .707 .692 .834 r
F P
0 g
s
.52589 .50277 m .5255 .51527 L .52181 .51549 L p .684 .673 .833 r
F P
0 g
s
.52181 .51549 m .51848 .50322 L .52589 .50277 L p .684 .673 .833 r
F P
0 g
s
.5255 .51527 m .52589 .50277 L .53324 .50346 L p .707 .692 .834 r
F P
0 g
s
.42623 .40104 m .43636 .41014 L .4161 .42609 L p .623 .674 .878 r
F P
0 g
s
.4161 .42609 m .40378 .41887 L .42623 .40104 L p .623 .674 .878 r
F P
0 g
s
.55613 .49567 m .54577 .50795 L .54002 .50522 L p .772 .729 .813 r
F P
0 g
s
.50471 .49086 m .51154 .50477 L .50555 .50732 L p .62 .601 .81 r
F P
0 g
s
.50555 .50732 m .49572 .49471 L .50471 .49086 L p .62 .601 .81 r
F P
0 g
s
.76097 .45542 m .74653 .45285 L .72912 .41889 L p .482 .654 .935 r
F P
0 g
s
.71561 .41774 m .72912 .41889 L .74653 .45285 L p .447 .632 .933 r
F P
0 g
s
.67579 .41625 m .66283 .41852 L .64012 .39803 L p .587 .729 .942 r
F P
0 g
s
.62933 .40444 m .64012 .39803 L .66283 .41852 L p .667 .752 .914 r
F P
0 g
s
.41597 .39426 m .42623 .40104 L .40378 .41887 L p .653 .741 .914 r
F P
0 g
s
.40378 .41887 m .39132 .414 L .41597 .39426 L p .653 .741 .914 r
F P
0 g
s
.56651 .48164 m .55613 .49567 L .54753 .49154 L p .787 .721 .79 r
F P
0 g
s
.54002 .50522 m .54753 .49154 L .55613 .49567 L p .772 .729 .813 r
F P
0 g
s
.32667 .41218 m .33987 .41148 L .32033 .44277 L p .758 .897 .939 r
F P
0 g
s
.32033 .44277 m .30601 .44565 L .32667 .41218 L p .758 .897 .939 r
F P
0 g
s
.54753 .49154 m .54002 .50522 L .53324 .50346 L p .747 .694 .802 r
F P
0 g
s
.51514 .48851 m .51848 .50322 L .51154 .50477 L p .656 .619 .8 r
F P
0 g
s
.51154 .50477 m .50471 .49086 L .51514 .48851 L p .656 .619 .8 r
F P
0 g
s
.49786 .47516 m .50471 .49086 L .49572 .49471 L p .612 .574 .788 r
F P
0 g
s
.49572 .49471 m .48588 .48034 L .49786 .47516 L p .612 .574 .788 r
F P
0 g
s
.57688 .46664 m .56651 .48164 L .55504 .47608 L p .793 .716 .779 r
F P
0 g
s
.54753 .49154 m .55504 .47608 L .56651 .48164 L p .787 .721 .79 r
F P
0 g
s
.58726 .45154 m .57688 .46664 L .56258 .45962 L p .794 .716 .778 r
F P
0 g
s
.55504 .47608 m .56258 .45962 L .57688 .46664 L p .793 .716 .779 r
F P
0 g
s
.53324 .50346 m .53734 .48886 L .54753 .49154 L p .747 .694 .802 r
F P
0 g
s
.53734 .48886 m .53324 .50346 L .52589 .50277 L p .719 .665 .796 r
F P
0 g
s
.52628 .48782 m .52589 .50277 L .51848 .50322 L p .689 .64 .796 r
F P
0 g
s
.51848 .50322 m .51514 .48851 L .52628 .48782 L p .689 .64 .796 r
F P
0 g
s
.491 .45846 m .49786 .47516 L .48588 .48034 L p .607 .561 .777 r
F P
0 g
s
.48588 .48034 m .47604 .46501 L .491 .45846 L p .607 .561 .777 r
F P
0 g
s
.77538 .45672 m .76097 .45542 L .7427 .41925 L p .536 .686 .935 r
F P
0 g
s
.72912 .41889 m .7427 .41925 L .76097 .45542 L p .482 .654 .935 r
F P
0 g
s
.52589 .50277 m .52628 .48782 L .53734 .48886 L p .719 .665 .796 r
F P
0 g
s
.59767 .43715 m .58726 .45154 L .57012 .44304 L p .789 .719 .787 r
F P
0 g
s
.56258 .45962 m .57012 .44304 L .58726 .45154 L p .794 .716 .778 r
F P
0 g
s
.48412 .44162 m .491 .45846 L .47604 .46501 L p .607 .56 .775 r
F P
0 g
s
.47604 .46501 m .46619 .44956 L .48412 .44162 L p .607 .56 .775 r
F P
0 g
s
.40555 .38963 m .41597 .39426 L .39132 .414 L p .68 .809 .944 r
F P
0 g
s
.39132 .414 m .3787 .41129 L .40555 .38963 L p .68 .809 .944 r
F P
0 g
s
.55504 .47608 m .54753 .49154 L .53734 .48886 L p .756 .682 .779 r
F P
0 g
s
.60813 .42419 m .59767 .43715 L .57771 .42714 L p .777 .726 .805 r
F P
0 g
s
.57012 .44304 m .57771 .42714 L .59767 .43715 L p .789 .719 .787 r
F P
0 g
s
.68891 .41575 m .67579 .41625 L .65107 .39378 L p .503 .698 .957 r
F P
0 g
s
.64012 .39803 m .65107 .39378 L .67579 .41625 L p .587 .729 .942 r
F P
0 g
s
.51179 .47199 m .51514 .48851 L .50471 .49086 L p .653 .595 .777 r
F P
0 g
s
.50471 .49086 m .49786 .47516 L .51179 .47199 L p .653 .595 .777 r
F P
0 g
s
.47721 .42547 m .48412 .44162 L .46619 .44956 L p .61 .57 .784 r
F P
0 g
s
.46619 .44956 m .45631 .43482 L .47721 .42547 L p .61 .57 .784 r
F P
0 g
s
.31342 .4121 m .32667 .41218 L .30601 .44565 L p .745 .878 .941 r
F P
0 g
s
.30601 .44565 m .29167 .44776 L .31342 .4121 L p .745 .878 .941 r
F P
0 g
s
.61867 .41318 m .60813 .42419 L .58534 .41264 L p .756 .735 .833 r
F P
0 g
s
.57771 .42714 m .58534 .41264 L .60813 .42419 L p .777 .726 .805 r
F P
0 g
s
.47025 .41072 m .47721 .42547 L .45631 .43482 L p .618 .592 .802 r
F P
0 g
s
.45631 .43482 m .44638 .4215 L .47025 .41072 L p .618 .592 .802 r
F P
0 g
s
.78971 .45639 m .77538 .45672 L .75628 .41832 L p .598 .722 .931 r
F P
0 g
s
.7427 .41925 m .75628 .41832 L .77538 .45672 L p .536 .686 .935 r
F P
0 g
s
.53734 .48886 m .54145 .47247 L .55504 .47608 L p .756 .682 .779 r
F P
0 g
s
.54145 .47247 m .53734 .48886 L .52628 .48782 L p .724 .648 .773 r
F P
0 g
s
.56258 .45962 m .55504 .47608 L .54145 .47247 L p .761 .675 .768 r
F P
0 g
s
.52667 .47107 m .52628 .48782 L .51514 .48851 L p .69 .62 .773 r
F P
0 g
s
.51514 .48851 m .51179 .47199 L .52667 .47107 L p .69 .62 .773 r
F P
0 g
s
.50842 .45445 m .51179 .47199 L .49786 .47516 L p .651 .584 .767 r
F P
0 g
s
.49786 .47516 m .491 .45846 L .50842 .45445 L p .651 .584 .767 r
F P
0 g
s
.52628 .48782 m .52667 .47107 L .54145 .47247 L p .724 .648 .773 r
F P
0 g
s
.46322 .3979 m .47025 .41072 L .44638 .4215 L p .629 .628 .83 r
F P
0 g
s
.44638 .4215 m .43636 .41014 L .46322 .3979 L p .629 .628 .83 r
F P
0 g
s
.57012 .44304 m .56258 .45962 L .54557 .45506 L p .761 .675 .767 r
F P
0 g
s
.54145 .47247 m .54557 .45506 L .56258 .45962 L p .761 .675 .768 r
F P
0 g
s
.62933 .40444 m .61867 .41318 L .59304 .40008 L p .721 .744 .87 r
F P
0 g
s
.58534 .41264 m .59304 .40008 L .61867 .41318 L p .756 .735 .833 r
F P
0 g
s
.80395 .45433 m .78971 .45639 L .76983 .41574 L p .657 .754 .921 r
F P
0 g
s
.75628 .41832 m .76983 .41574 L .78971 .45639 L p .598 .722 .931 r
F P
0 g
s
.39497 .38677 m .40555 .38963 L .3787 .41129 L p .699 .866 .961 r
F P
0 g
s
.3787 .41129 m .36591 .41036 L .39497 .38677 L p .699 .866 .961 r
F P
0 g
s
.50505 .43676 m .50842 .45445 L .491 .45846 L p .651 .583 .765 r
F P
0 g
s
.491 .45846 m .48412 .44162 L .50505 .43676 L p .651 .583 .765 r
F P
0 g
s
.30015 .41071 m .31342 .4121 L .29167 .44776 L p .722 .844 .94 r
F P
0 g
s
.29167 .44776 m .27734 .44859 L .30015 .41071 L p .722 .844 .94 r
F P
0 g
s
.54557 .45506 m .54145 .47247 L .52667 .47107 L p .726 .641 .762 r
F P
0 g
s
.70219 .41647 m .68891 .41575 L .66219 .39129 L p .434 .669 .961 r
F P
0 g
s
.65107 .39378 m .66219 .39129 L .68891 .41575 L p .503 .698 .957 r
F P
0 g
s
.52707 .45329 m .52667 .47107 L .51179 .47199 L p .69 .61 .762 r
F P
0 g
s
.51179 .47199 m .50842 .45445 L .52707 .45329 L p .69 .61 .762 r
F P
0 g
s
.57771 .42714 m .57012 .44304 L .5497 .43749 L p .758 .68 .776 r
F P
0 g
s
.54557 .45506 m .5497 .43749 L .57012 .44304 L p .761 .675 .767 r
F P
0 g
s
.81807 .45061 m .80395 .45433 L .78331 .41138 L p .706 .779 .909 r
F P
0 g
s
.76983 .41574 m .78331 .41138 L .80395 .45433 L p .657 .754 .921 r
F P
0 g
s
.52667 .47107 m .52707 .45329 L .54557 .45506 L p .726 .641 .762 r
F P
0 g
s
.85986 .43317 m .84599 .43954 L .82333 .38952 L p .772 .809 .883 r
F P
0 g
s
.82333 .38952 m .8366 .38074 L .85986 .43317 L p .772 .809 .883 r
F P
0 g
s
.45611 .38732 m .46322 .3979 L .43636 .41014 L p .643 .678 .868 r
F P
0 g
s
.43636 .41014 m .42623 .40104 L .45611 .38732 L p .643 .678 .868 r
F P
0 g
s
.83207 .44553 m .81807 .45061 L .79672 .40533 L p .741 .796 .896 r
F P
0 g
s
.78331 .41138 m .79672 .40533 L .81807 .45061 L p .706 .779 .909 r
F P
0 g
s
.84599 .43954 m .83207 .44553 L .81005 .3979 L p .763 .806 .887 r
F P
0 g
s
.81005 .3979 m .82333 .38952 L .84599 .43954 L p .763 .806 .887 r
F P
0 g
s
.79672 .40533 m .81005 .3979 L .83207 .44553 L p .741 .796 .896 r
F P
0 g
s
.50166 .41973 m .50505 .43676 L .48412 .44162 L p .652 .592 .774 r
F P
0 g
s
.48412 .44162 m .47721 .42547 L .50166 .41973 L p .652 .592 .774 r
F P
0 g
s
.64012 .39803 m .62933 .40444 L .60084 .38976 L p .666 .75 .913 r
F P
0 g
s
.59304 .40008 m .60084 .38976 L .62933 .40444 L p .721 .744 .87 r
F P
0 g
s
.5497 .43749 m .54557 .45506 L .52707 .45329 L p .727 .64 .761 r
F P
0 g
s
.58534 .41264 m .57771 .42714 L .55385 .4206 L p .75 .69 .794 r
F P
0 g
s
.5497 .43749 m .55385 .4206 L .57771 .42714 L p .758 .68 .776 r
F P
0 g
s
.52746 .43534 m .52707 .45329 L .50842 .45445 L p .69 .609 .761 r
F P
0 g
s
.50842 .45445 m .50505 .43676 L .52746 .43534 L p .69 .609 .761 r
F P
0 g
s
.28691 .40767 m .30015 .41071 L .27734 .44859 L p .69 .8 .933 r
F P
0 g
s
.27734 .44859 m .26307 .4478 L .28691 .40767 L p .69 .8 .933 r
F P
0 g
s
.52707 .45329 m .52746 .43534 L .5497 .43749 L p .727 .64 .761 r
F P
0 g
s
.49824 .40409 m .50166 .41973 L .47721 .42547 L p .655 .611 .792 r
F P
0 g
s
.47721 .42547 m .47025 .41072 L .49824 .40409 L p .655 .611 .792 r
F P
0 g
s
.38424 .38511 m .39497 .38677 L .36591 .41036 L p .707 .902 .966 r
F P
0 g
s
.36591 .41036 m .35296 .41064 L .38424 .38511 L p .707 .902 .966 r
F P
0 g
s
.55385 .4206 m .5497 .43749 L .52746 .43534 L p .725 .646 .77 r
F P
0 g
s
.44889 .37905 m .45611 .38732 L .42623 .40104 L p .656 .741 .912 r
F P
0 g
s
.42623 .40104 m .41597 .39426 L .44889 .37905 L p .656 .741 .912 r
F P
0 g
s
.59304 .40008 m .58534 .41264 L .55804 .40509 L p .735 .705 .823 r
F P
0 g
s
.55385 .4206 m .55804 .40509 L .58534 .41264 L p .75 .69 .794 r
F P
0 g
s
.71561 .41774 m .70219 .41647 L .67347 .39 L p .4 .653 .96 r
F P
0 g
s
.66219 .39129 m .67347 .39 L .70219 .41647 L p .434 .669 .961 r
F P
0 g
s
.52786 .41806 m .52746 .43534 L .50505 .43676 L p .69 .617 .769 r
F P
0 g
s
.50505 .43676 m .50166 .41973 L .52786 .41806 L p .69 .617 .769 r
F P
0 g
s
.27372 .40285 m .28691 .40767 L .26307 .4478 L p .653 .751 .921 r
F P
0 g
s
.26307 .4478 m .2489 .44525 L .27372 .40285 L p .653 .751 .921 r
F P
0 g
s
.52746 .43534 m .52786 .41806 L .55385 .4206 L p .725 .646 .77 r
F P
0 g
s
.49478 .39036 m .49824 .40409 L .47025 .41072 L p .659 .641 .821 r
F P
0 g
s
.47025 .41072 m .46322 .3979 L .49478 .39036 L p .659 .641 .821 r
F P
0 g
s
.65107 .39378 m .64012 .39803 L .60875 .38176 L p .588 .745 .951 r
F P
0 g
s
.60084 .38976 m .60875 .38176 L .64012 .39803 L p .666 .75 .913 r
F P
0 g
s
.55804 .40509 m .55385 .4206 L .52786 .41806 L p .721 .659 .788 r
F P
0 g
s
.2606 .39633 m .27372 .40285 L .2489 .44525 L p .618 .704 .907 r
F P
0 g
s
.2489 .44525 m .23484 .44105 L .2606 .39633 L p .618 .704 .907 r
F P
0 g
s
.52826 .40216 m .52786 .41806 L .50166 .41973 L p .689 .633 .788 r
F P
0 g
s
.50166 .41973 m .49824 .40409 L .52826 .40216 L p .689 .633 .788 r
F P
0 g
s
.24755 .38841 m .2606 .39633 L .23484 .44105 L p .59 .667 .893 r
F P
0 g
s
.23484 .44105 m .22089 .43549 L .24755 .38841 L p .59 .667 .893 r
F P
0 g
s
.60084 .38976 m .59304 .40008 L .56227 .3915 L p .709 .726 .863 r
F P
0 g
s
.55804 .40509 m .56227 .3915 L .59304 .40008 L p .735 .705 .823 r
F P
0 g
s
.23454 .37954 m .24755 .38841 L .22089 .43549 L p .57 .642 .883 r
F P
0 g
s
.22089 .43549 m .20702 .429 L .23454 .37954 L p .57 .642 .883 r
F P
0 g
s
.52786 .41806 m .52826 .40216 L .55804 .40509 L p .721 .659 .788 r
F P
0 g
s
.22154 .37026 m .23454 .37954 L .20702 .429 L p .562 .632 .878 r
F P
0 g
s
.20702 .429 m .19318 .42214 L .22154 .37026 L p .562 .632 .878 r
F P
0 g
s
.44155 .37291 m .44889 .37905 L .41597 .39426 L p .662 .808 .953 r
F P
0 g
s
.41597 .39426 m .40555 .38963 L .44155 .37291 L p .662 .808 .953 r
F P
0 g
s
.37336 .38399 m .38424 .38511 L .35296 .41064 L p .709 .917 .965 r
F P
0 g
s
.35296 .41064 m .33987 .41148 L .37336 .38399 L p .709 .917 .965 r
F P
0 g
s
.49128 .37886 m .49478 .39036 L .46322 .3979 L p .661 .686 .862 r
F P
0 g
s
.46322 .3979 m .45611 .38732 L .49128 .37886 L p .661 .686 .862 r
F P
0 g
s
.72912 .41889 m .71561 .41774 L .68489 .38927 L p .409 .657 .961 r
F P
0 g
s
.67347 .39 m .68489 .38927 L .71561 .41774 L p .4 .653 .96 r
F P
0 g
s
.56227 .3915 m .55804 .40509 L .52826 .40216 L p .712 .68 .818 r
F P
0 g
s
.52866 .38816 m .52826 .40216 L .49824 .40409 L p .687 .659 .817 r
F P
0 g
s
.49824 .40409 m .49478 .39036 L .52866 .38816 L p .687 .659 .817 r
F P
0 g
s
.66219 .39129 m .65107 .39378 L .61679 .3759 L p .496 .727 .975 r
F P
0 g
s
.60875 .38176 m .61679 .3759 L .65107 .39378 L p .588 .745 .951 r
F P
0 g
s
.52826 .40216 m .52866 .38816 L .56227 .3915 L p .712 .68 .818 r
F P
0 g
s
.60875 .38176 m .60084 .38976 L .56656 .38014 L p .665 .747 .912 r
F P
0 g
s
.56227 .3915 m .56656 .38014 L .60084 .38976 L p .709 .726 .863 r
F P
0 g
s
.48772 .36966 m .49128 .37886 L .45611 .38732 L p .658 .742 .912 r
F P
0 g
s
.45611 .38732 m .44889 .37905 L .48772 .36966 L p .658 .742 .912 r
F P
0 g
s
.56656 .38014 m .56227 .3915 L .52866 .38816 L p .695 .71 .859 r
F P
0 g
s
.43408 .36853 m .44155 .37291 L .40555 .38963 L p .656 .864 .978 r
F P
0 g
s
.40555 .38963 m .39497 .38677 L .43408 .36853 L p .656 .864 .978 r
F P
0 g
s
.36238 .38271 m .37336 .38399 L .33987 .41148 L p .708 .913 .965 r
F P
0 g
s
.33987 .41148 m .32667 .41218 L .36238 .38271 L p .708 .913 .965 r
F P
0 g
s
.52907 .3764 m .52866 .38816 L .49478 .39036 L p .679 .696 .859 r
F P
0 g
s
.49478 .39036 m .49128 .37886 L .52907 .3764 L p .679 .696 .859 r
F P
0 g
s
.7427 .41925 m .72912 .41889 L .69642 .38837 L p .455 .678 .961 r
F P
0 g
s
.68489 .38927 m .69642 .38837 L .72912 .41889 L p .409 .657 .961 r
F P
0 g
s
.52866 .38816 m .52907 .3764 L .56656 .38014 L p .695 .71 .859 r
F P
0 g
s
.67347 .39 m .66219 .39129 L .62497 .37179 L p .413 .702 .981 r
F P
0 g
s
.61679 .3759 m .62497 .37179 L .66219 .39129 L p .496 .727 .975 r
F P
0 g
s
.61679 .3759 m .60875 .38176 L .57092 .37108 L p .595 .762 .959 r
F P
0 g
s
.56656 .38014 m .57092 .37108 L .60875 .38176 L p .665 .747 .912 r
F P
0 g
s
.57092 .37108 m .56656 .38014 L .52907 .3764 L p .663 .745 .911 r
F P
0 g
s
.4841 .36258 m .48772 .36966 L .44889 .37905 L p .642 .802 .96 r
F P
0 g
s
.44889 .37905 m .44155 .37291 L .4841 .36258 L p .642 .802 .96 r
F P
0 g
s
.52949 .36692 m .52907 .3764 L .49128 .37886 L p .661 .743 .911 r
F P
0 g
s
.49128 .37886 m .48772 .36966 L .52949 .36692 L p .661 .743 .911 r
F P
0 g
s
.35132 .38063 m .36238 .38271 L .32667 .41218 L p .705 .892 .965 r
F P
0 g
s
.32667 .41218 m .31342 .4121 L .35132 .38063 L p .705 .892 .965 r
F P
0 g
s
.75628 .41832 m .7427 .41925 L .70802 .38668 L p .523 .707 .955 r
F P
0 g
s
.69642 .38837 m .70802 .38668 L .7427 .41925 L p .455 .678 .961 r
F P
0 g
s
.42649 .36533 m .43408 .36853 L .39497 .38677 L p .642 .898 .984 r
F P
0 g
s
.39497 .38677 m .38424 .38511 L .42649 .36533 L p .642 .898 .984 r
F P
0 g
s
.52907 .3764 m .52949 .36692 L .57092 .37108 L p .663 .745 .911 r
F P
0 g
s
.68489 .38927 m .67347 .39 L .63328 .36887 L p .371 .686 .98 r
F P
0 g
s
.62497 .37179 m .63328 .36887 L .67347 .39 L p .413 .702 .981 r
F P
0 g
s
.62497 .37179 m .61679 .3759 L .57535 .36415 L p .502 .759 .988 r
F P
0 g
s
.57092 .37108 m .57535 .36415 L .61679 .3759 L p .595 .762 .959 r
F P
0 g
s
.76983 .41574 m .75628 .41832 L .71966 .38365 L p .595 .734 .941 r
F P
0 g
s
.70802 .38668 m .71966 .38365 L .75628 .41832 L p .523 .707 .955 r
F P
0 g
s
.57535 .36415 m .57092 .37108 L .52949 .36692 L p .607 .778 .963 r
F P
0 g
s
.34022 .37721 m .35132 .38063 L .31342 .4121 L p .694 .853 .959 r
F P
0 g
s
.31342 .4121 m .30015 .41071 L .34022 .37721 L p .694 .853 .959 r
F P
0 g
s
.48041 .35724 m .4841 .36258 L .44155 .37291 L p .608 .85 .99 r
F P
0 g
s
.44155 .37291 m .43408 .36853 L .48041 .35724 L p .608 .85 .99 r
F P
0 g
s
.52992 .35957 m .52949 .36692 L .48772 .36966 L p .623 .792 .963 r
F P
0 g
s
.48772 .36966 m .4841 .36258 L .52992 .35957 L p .623 .792 .963 r
F P
0 g
s
.41879 .36265 m .42649 .36533 L .38424 .38511 L p .632 .91 .982 r
F P
0 g
s
.38424 .38511 m .37336 .38399 L .41879 .36265 L p .632 .91 .982 r
F P
0 g
s
.52949 .36692 m .52992 .35957 L .57535 .36415 L p .607 .778 .963 r
F P
0 g
s
.78331 .41138 m .76983 .41574 L .73129 .37895 L p .657 .753 .921 r
F P
0 g
s
.71966 .38365 m .73129 .37895 L .76983 .41574 L p .595 .734 .941 r
F P
0 g
s
.32913 .3721 m .34022 .37721 L .30015 .41071 L p .676 .803 .943 r
F P
0 g
s
.30015 .41071 m .28691 .40767 L .32913 .3721 L p .676 .803 .943 r
F P
0 g
s
.69642 .38837 m .68489 .38927 L .64171 .36647 L p .382 .69 .98 r
F P
0 g
s
.63328 .36887 m .64171 .36647 L .68489 .38927 L p .371 .686 .98 r
F P
0 g
s
.63328 .36887 m .62497 .37179 L .57986 .35895 L p .413 .742 .993 r
F P
0 g
s
.57535 .36415 m .57986 .35895 L .62497 .37179 L p .502 .759 .988 r
F P
0 g
s
.79672 .40533 m .78331 .41138 L .74289 .37243 L p .704 .765 .899 r
F P
0 g
s
.73129 .37895 m .74289 .37243 L .78331 .41138 L p .657 .753 .921 r
F P
0 g
s
.57986 .35895 m .57535 .36415 L .52992 .35957 L p .524 .793 .994 r
F P
0 g
s
.47666 .35308 m .48041 .35724 L .43408 .36853 L p .566 .873 .994 r
F P
0 g
s
.43408 .36853 m .42649 .36533 L .47666 .35308 L p .566 .873 .994 r
F P
0 g
s
.53035 .35395 m .52992 .35957 L .4841 .36258 L p .561 .825 .995 r
F P
0 g
s
.4841 .36258 m .48041 .35724 L .53035 .35395 L p .561 .825 .995 r
F P
0 g
s
.81005 .3979 m .79672 .40533 L .75446 .36418 L p .737 .772 .881 r
F P
0 g
s
.74289 .37243 m .75446 .36418 L .79672 .40533 L p .704 .765 .899 r
F P
0 g
s
.41099 .3598 m .41879 .36265 L .37336 .38399 L p .635 .907 .983 r
F P
0 g
s
.37336 .38399 m .36238 .38271 L .41099 .3598 L p .635 .907 .983 r
F P
0 g
s
.31805 .36516 m .32913 .3721 L .28691 .40767 L p .654 .751 .921 r
F P
0 g
s
.28691 .40767 m .27372 .40285 L .31805 .36516 L p .654 .751 .921 r
F P
0 g
s
.52992 .35957 m .53035 .35395 L .57986 .35895 L p .524 .793 .994 r
F P
0 g
s
.82333 .38952 m .81005 .3979 L .76598 .3545 L p .756 .775 .869 r
F P
0 g
s
.75446 .36418 m .76598 .3545 L .81005 .3979 L p .737 .772 .881 r
F P
0 g
s
.8366 .38074 m .82333 .38952 L .77749 .34384 L p .763 .776 .864 r
F P
0 g
s
.76598 .3545 m .77749 .34384 L .82333 .38952 L p .756 .775 .869 r
F P
0 g
s
.70802 .38668 m .69642 .38837 L .65024 .3639 L p .439 .71 .981 r
F P
0 g
s
.64171 .36647 m .65024 .3639 L .69642 .38837 L p .382 .69 .98 r
F P
0 g
s
.30701 .35649 m .31805 .36516 L .27372 .40285 L p .632 .704 .898 r
F P
0 g
s
.27372 .40285 m .2606 .39633 L .30701 .35649 L p .632 .704 .898 r
F P
0 g
s
.77749 .34384 m .78901 .33274 L .8366 .38074 L p .763 .776 .864 r
F P
0 g
s
.64171 .36647 m .63328 .36887 L .58445 .35493 L p .364 .727 .988 r
F P
0 g
s
.57986 .35895 m .58445 .35493 L .63328 .36887 L p .413 .742 .993 r
F P
0 g
s
.58445 .35493 m .57986 .35895 L .53035 .35395 L p .439 .787 .998 r
F P
0 g
s
.29601 .34638 m .30701 .35649 L .2606 .39633 L p .614 .668 .878 r
F P
0 g
s
.2606 .39633 m .24755 .38841 L .29601 .34638 L p .614 .668 .878 r
F P
0 g
s
.47285 .34942 m .47666 .35308 L .42649 .36533 L p .54 .878 .989 r
F P
0 g
s
.42649 .36533 m .41879 .36265 L .47285 .34942 L p .54 .878 .989 r
F P
0 g
s
.40314 .35611 m .41099 .3598 L .36238 .38271 L p .647 .889 .984 r
F P
0 g
s
.36238 .38271 m .35132 .38063 L .40314 .35611 L p .647 .889 .984 r
F P
0 g
s
.53079 .3495 m .53035 .35395 L .48041 .35724 L p .493 .833 .998 r
F P
0 g
s
.48041 .35724 m .47666 .35308 L .53079 .3495 L p .493 .833 .998 r
F P
0 g
s
.28501 .33528 m .29601 .34638 L .24755 .38841 L p .602 .645 .865 r
F P
0 g
s
.24755 .38841 m .23454 .37954 L .28501 .33528 L p .602 .645 .865 r
F P
0 g
s
.53035 .35395 m .53079 .3495 L .58445 .35493 L p .439 .787 .998 r
F P
0 g
s
.71966 .38365 m .70802 .38668 L .65883 .3605 L p .519 .733 .971 r
F P
0 g
s
.65024 .3639 m .65883 .3605 L .70802 .38668 L p .439 .71 .981 r
F P
0 g
s
.27399 .32374 m .28501 .33528 L .23454 .37954 L p .597 .636 .86 r
F P
0 g
s
.23454 .37954 m .22154 .37026 L .27399 .32374 L p .597 .636 .86 r
F P
0 g
s
.65024 .3639 m .64171 .36647 L .58912 .35142 L p .377 .732 .99 r
F P
0 g
s
.58445 .35493 m .58912 .35142 L .64171 .36647 L p .364 .727 .988 r
F P
0 g
s
.39524 .35105 m .40314 .35611 L .35132 .38063 L p .658 .852 .974 r
F P
0 g
s
.35132 .38063 m .34022 .37721 L .39524 .35105 L p .658 .852 .974 r
F P
0 g
s
.58912 .35142 m .58445 .35493 L .53079 .3495 L p .391 .776 .99 r
F P
0 g
s
.46899 .34556 m .47285 .34942 L .41879 .36265 L p .547 .877 .991 r
F P
0 g
s
.41879 .36265 m .41099 .3598 L .46899 .34556 L p .547 .877 .991 r
F P
0 g
s
.73129 .37895 m .71966 .38365 L .66747 .35574 L p .596 .748 .95 r
F P
0 g
s
.65883 .3605 m .66747 .35574 L .71966 .38365 L p .519 .733 .971 r
F P
0 g
s
.53124 .34555 m .53079 .3495 L .47666 .35308 L p .453 .83 .99 r
F P
0 g
s
.47666 .35308 m .47285 .34942 L .53124 .34555 L p .453 .83 .99 r
F P
0 g
s
.53079 .3495 m .53124 .34555 L .58912 .35142 L p .391 .776 .99 r
F P
0 g
s
.38733 .34427 m .39524 .35105 L .34022 .37721 L p .66 .803 .951 r
F P
0 g
s
.34022 .37721 m .32913 .3721 L .38733 .34427 L p .66 .803 .951 r
F P
0 g
s
.65883 .3605 m .65024 .3639 L .59384 .34772 L p .441 .749 .993 r
F P
0 g
s
.58912 .35142 m .59384 .34772 L .65024 .3639 L p .377 .732 .99 r
F P
0 g
s
.74289 .37243 m .73129 .37895 L .67612 .34926 L p .657 .753 .921 r
F P
0 g
s
.66747 .35574 m .67612 .34926 L .73129 .37895 L p .596 .748 .95 r
F P
0 g
s
.59384 .34772 m .58912 .35142 L .53124 .34555 L p .404 .78 .993 r
F P
0 g
s
.46509 .34085 m .46899 .34556 L .41099 .3598 L p .58 .868 .995 r
F P
0 g
s
.41099 .3598 m .40314 .35611 L .46509 .34085 L p .58 .868 .995 r
F P
0 g
s
.53169 .3414 m .53124 .34555 L .47285 .34942 L p .464 .831 .993 r
F P
0 g
s
.47285 .34942 m .46899 .34556 L .53169 .3414 L p .464 .831 .993 r
F P
0 g
s
.75446 .36418 m .74289 .37243 L .68476 .34093 L p .7 .752 .892 r
F P
0 g
s
.67612 .34926 m .68476 .34093 L .74289 .37243 L p .657 .753 .921 r
F P
0 g
s
.37942 .33563 m .38733 .34427 L .32913 .3721 L p .654 .751 .921 r
F P
0 g
s
.32913 .3721 m .31805 .36516 L .37942 .33563 L p .654 .751 .921 r
F P
0 g
s
.53124 .34555 m .53169 .3414 L .59384 .34772 L p .404 .78 .993 r
F P
0 g
s
.66747 .35574 m .65883 .3605 L .5986 .34317 L p .526 .762 .983 r
F P
0 g
s
.59384 .34772 m .5986 .34317 L .65883 .3605 L p .441 .749 .993 r
F P
0 g
s
.76598 .3545 m .75446 .36418 L .69339 .33083 L p .727 .749 .869 r
F P
0 g
s
.68476 .34093 m .69339 .33083 L .75446 .36418 L p .7 .752 .892 r
F P
0 g
s
.37152 .32521 m .37942 .33563 L .31805 .36516 L p .645 .706 .891 r
F P
0 g
s
.31805 .36516 m .30701 .35649 L .37152 .32521 L p .645 .706 .891 r
F P
0 g
s
.46117 .33476 m .46509 .34085 L .40314 .35611 L p .617 .84 .985 r
F P
0 g
s
.40314 .35611 m .39524 .35105 L .46117 .33476 L p .617 .84 .985 r
F P
0 g
s
.5986 .34317 m .59384 .34772 L .53169 .3414 L p .467 .791 .999 r
F P
0 g
s
.77749 .34384 m .76598 .3545 L .702 .31926 L p .742 .746 .855 r
F P
0 g
s
.69339 .33083 m .702 .31926 L .76598 .3545 L p .727 .749 .869 r
F P
0 g
s
.53215 .33639 m .53169 .3414 L .46899 .34556 L p .515 .833 1 r
F P
0 g
s
.46899 .34556 m .46509 .34085 L .53215 .33639 L p .515 .833 1 r
F P
0 g
s
.36363 .31332 m .37152 .32521 L .30701 .35649 L p .637 .673 .867 r
F P
0 g
s
.30701 .35649 m .29601 .34638 L .36363 .31332 L p .637 .673 .867 r
F P
0 g
s
.67612 .34926 m .66747 .35574 L .60339 .33723 L p .602 .762 .956 r
F P
0 g
s
.5986 .34317 m .60339 .33723 L .66747 .35574 L p .526 .762 .983 r
F P
0 g
s
.78901 .33274 m .77749 .34384 L .71062 .30668 L p .748 .745 .849 r
F P
0 g
s
.702 .31926 m .71062 .30668 L .77749 .34384 L p .742 .746 .855 r
F P
0 g
s
.53169 .3414 m .53215 .33639 L .5986 .34317 L p .467 .791 .999 r
F P
0 g
s
.71062 .30668 m .71927 .29362 L .78901 .33274 L p .748 .745 .849 r
F P
0 g
s
.35574 .3004 m .36363 .31332 L .29601 .34638 L p .631 .652 .852 r
F P
0 g
s
.29601 .34638 m .28501 .33528 L .35574 .3004 L p .631 .652 .852 r
F P
0 g
s
.45724 .32691 m .46117 .33476 L .39524 .35105 L p .643 .797 .957 r
F P
0 g
s
.39524 .35105 m .38733 .34427 L .45724 .32691 L p .643 .797 .957 r
F P
0 g
s
.60339 .33723 m .5986 .34317 L .53215 .33639 L p .546 .792 .99 r
F P
0 g
s
.34782 .287 m .35574 .3004 L .28501 .33528 L p .628 .644 .846 r
F P
0 g
s
.28501 .33528 m .27399 .32374 L .34782 .287 L p .628 .644 .846 r
F P
0 g
s
.68476 .34093 m .67612 .34926 L .6082 .32955 L p .657 .752 .92 r
F P
0 g
s
.60339 .33723 m .6082 .32955 L .67612 .34926 L p .602 .762 .956 r
F P
0 g
s
.53261 .32998 m .53215 .33639 L .46509 .34085 L p .578 .819 .99 r
F P
0 g
s
.46509 .34085 m .46117 .33476 L .53261 .32998 L p .578 .819 .99 r
F P
0 g
s
.53215 .33639 m .53261 .32998 L .60339 .33723 L p .546 .792 .99 r
F P
0 g
s
.4533 .31718 m .45724 .32691 L .38733 .34427 L p .655 .751 .92 r
F P
0 g
s
.38733 .34427 m .37942 .33563 L .4533 .31718 L p .655 .751 .92 r
F P
0 g
s
.69339 .33083 m .68476 .34093 L .61301 .31998 L p .692 .739 .887 r
F P
0 g
s
.6082 .32955 m .61301 .31998 L .68476 .34093 L p .657 .752 .92 r
F P
0 g
s
.6082 .32955 m .60339 .33723 L .53261 .32998 L p .612 .776 .959 r
F P
0 g
s
.53307 .32182 m .53261 .32998 L .46117 .33476 L p .626 .788 .96 r
F P
0 g
s
.46117 .33476 m .45724 .32691 L .53307 .32182 L p .626 .788 .96 r
F P
0 g
s
.44937 .30564 m .4533 .31718 L .37942 .33563 L p .659 .711 .886 r
F P
0 g
s
.37942 .33563 m .37152 .32521 L .44937 .30564 L p .659 .711 .886 r
F P
0 g
s
.702 .31926 m .69339 .33083 L .61782 .30862 L p .713 .728 .861 r
F P
0 g
s
.61301 .31998 m .61782 .30862 L .69339 .33083 L p .692 .739 .887 r
F P
0 g
s
.53261 .32998 m .53307 .32182 L .6082 .32955 L p .612 .776 .959 r
F P
0 g
s
.61301 .31998 m .6082 .32955 L .53307 .32182 L p .656 .752 .92 r
F P
0 g
s
.44544 .2926 m .44937 .30564 L .37152 .32521 L p .659 .681 .86 r
F P
0 g
s
.37152 .32521 m .36363 .31332 L .44544 .2926 L p .659 .681 .86 r
F P
0 g
s
.71062 .30668 m .702 .31926 L .62262 .29575 L p .725 .72 .845 r
F P
0 g
s
.61782 .30862 m .62262 .29575 L .702 .31926 L p .713 .728 .861 r
F P
0 g
s
.53353 .31176 m .53307 .32182 L .45724 .32691 L p .656 .751 .92 r
F P
0 g
s
.45724 .32691 m .4533 .31718 L .53353 .31176 L p .656 .751 .92 r
F P
0 g
s
.53307 .32182 m .53353 .31176 L .61301 .31998 L p .656 .752 .92 r
F P
0 g
s
.71927 .29362 m .71062 .30668 L .62743 .28184 L p .729 .717 .839 r
F P
0 g
s
.62262 .29575 m .62743 .28184 L .71062 .30668 L p .725 .72 .845 r
F P
0 g
s
.4415 .27851 m .44544 .2926 L .36363 .31332 L p .658 .663 .844 r
F P
0 g
s
.36363 .31332 m .35574 .3004 L .4415 .27851 L p .658 .663 .844 r
F P
0 g
s
.61782 .30862 m .61301 .31998 L .53353 .31176 L p .682 .728 .884 r
F P
0 g
s
.53399 .2999 m .53353 .31176 L .4533 .31718 L p .671 .718 .884 r
F P
0 g
s
.4533 .31718 m .44937 .30564 L .53399 .2999 L p .671 .718 .884 r
F P
0 g
s
.62743 .28184 m .63227 .26744 L .71927 .29362 L p .729 .717 .839 r
F P
0 g
s
.43754 .26392 m .4415 .27851 L .35574 .3004 L p .657 .656 .838 r
F P
0 g
s
.35574 .3004 m .34782 .287 L .43754 .26392 L p .657 .656 .838 r
F P
0 g
s
.53353 .31176 m .53399 .2999 L .61782 .30862 L p .682 .728 .884 r
F P
0 g
s
.62262 .29575 m .61782 .30862 L .53399 .2999 L p .697 .709 .857 r
F P
0 g
s
.53446 .28652 m .53399 .2999 L .44937 .30564 L p .679 .694 .857 r
F P
0 g
s
.44937 .30564 m .44544 .2926 L .53446 .28652 L p .679 .694 .857 r
F P
0 g
s
.62743 .28184 m .62262 .29575 L .53446 .28652 L p .705 .698 .841 r
F P
0 g
s
.53399 .2999 m .53446 .28652 L .62262 .29575 L p .697 .709 .857 r
F P
0 g
s
.53492 .27208 m .53446 .28652 L .44544 .2926 L p .682 .679 .84 r
F P
0 g
s
.44544 .2926 m .4415 .27851 L .53492 .27208 L p .682 .679 .84 r
F P
0 g
s
.63227 .26744 m .62743 .28184 L .53492 .27208 L p .707 .693 .834 r
F P
0 g
s
.53446 .28652 m .53492 .27208 L .62743 .28184 L p .705 .698 .841 r
F P
0 g
s
.53539 .25714 m .53492 .27208 L .4415 .27851 L p .683 .673 .834 r
F P
0 g
s
.4415 .27851 m .43754 .26392 L .53539 .25714 L p .683 .673 .834 r
F P
0 g
s
.53492 .27208 m .53539 .25714 L .63227 .26744 L p .707 .693 .834 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000So[ZcE00?o0000okBaeOnd/MD00ond/MD;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`0001Oo[ZcE00?o0000
okBaeOnd/MD03_nd/MD:o`0001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[
ooooo`004_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool0K?ooool4o`0000;oZ:OF00?o0000ojj/eOn^[=D07?n^[=D00ol0003o];7EokBae@0HokBa
e@Oo00004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`Co
00001onXYmH00ol0003o[ZcEojj/e@0Kojj/e@03o`000?nd/MGo];7E01co];7E00?o0000okZge_nj
]mH00ol0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
1?l0000;ojRWeP03o`000?n^[=Go[ZcE01Co[ZcE2?l0000MokBae@03o`000?nj]mKo^[OF00Co^[OF
0ol0000<ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:Oooool001gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo1?l0
000?ojRWeP03o`000?n^[=Go[ZcE00Go[ZcE3ol00007ojj]e`03o`000?nd/]Oo];;G00?o];;G2_l0
000>okBae@03o`000?nj]mKo^[OF00Oo^[OF0ol00009ooooo`03o`000?oooooooooo02oooooo0_l0
000[ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003oooooooooo`1H
ooooo`Co00004_nXYmH3o`000003ojj/eOl0003o000000?o00005_n^[ML00ol0003o];;GokBbe`0=
okBbe`Wo00001Ond/MD00ol0003o^[OFokZgeP0:okZgeP?o00001_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02Sooooo000Kooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Cooooo`Co00004_nXYmH4o`0000;oZ:WH00?o0000ojj]
eon^[ML06_n^[ML00ol0003o];;GokBbe`0FokBbe`Go00004?nj]mH3o`0000Cooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Xooooo`008oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo04oooooo0ol0000BojRWePCo00001_nXZMP00ol0003o[ZgGojj]e`0Cojj]e`So
00007?nd/]L00ol0003o^KSHokVhf002o`0000oo^[OF0ol000000ooooooo0000ooooo`0booooo`03
o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
C?ooool2o`000003oj2Tf?l0003oZ:OF00koZ:OF1?l0000;ojRYf003o`000?n^[MOo[ZgG00Co[ZgG
3_l00007ojfaf`03o`000?nb]M_o/[GK00?o/[GK2Ol0000>okBbe`03o`000?ni^=So^KSH00?o^KSH
0ol0000>okZgeP?o0000<oooool00ol0003oooooooooo`0Vooooo`008oooool2o`0000gooooo00?o
0000ooooooooool0BOooool2o`0000CoX:CH00?o0000ojRWe_nXYmH02OnXYmH3o`0000goZ:WH0ol0
00000on^[MOo0000o`000003o`0001Go[K7K00?o0000ok:efonb]M/03?nb]M/9o`0000Co];;G00?o
0000okVhf?ni^=P01oni^=P3o`0000co^[OF00?o0000okZge_l000000_l0000`ooooo`03o`000?oo
oooooooo02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2
o`0000OoX:CH00?o0000ojRWe_nXYmH01?nXYmH4o`0000coZ:WH1?l00002ojR^g003o`000?n]/M_o
[K7K01Wo[K7K00?o0000ok:efonb]M/05Onb]M/5o`0000co^KSH1?l00008okZgeP03o`000?nj]mKo
^[OF00;o^[OF0_l0000^ooooo`;o00009oooool002?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`13ooooo`;o00002OnPY=P01?l0003oZ:OFojRWe_nXYmH3o`0000goZ:WH0ol00006
ojR^g003o`000?n]/M_o[K7K01Wo[K7K00?o0000ok:efonb]M/06Onb]M/01?l0003o][[LokJjg?l0
000=okVhf0?o00001Onj]mH00ol0003o^[OFokZgeP02okZgeP04o`000?no_]Wo0000o`0002kooooo
00?o0000ooooooooool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`10ooooo`;o00002onPY=P3o`0000goZ:WH1?l0000:ojR^g003o`000?n]/M_o[K7K00_o[K7K3_l0
0006ok:ef`03o`000?nb]M_o/[GK017o/[GK00?o0000okJjg?nf^]`01?nf^]`3o`0000_o^KSH0ol0
0002okZgeP05o`000?nj]mKo^[OFokZge_l000001?no_]T2o`0002cooooo00?o0000ooooooooool0
9?ooool002;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nP
Y=SoX:CH00WoX:CH0_l000000onQY][o0000ojRYf009ojRYf0Co00003?nX[]`3o`000003ojfafol0
003o000000[o00003On[]n800ol0003o[[[RojjjhP05ojjjhPgo00001_nb]M/00ol0003o][[LokJj
g007okJjg0?o00002oni^=P3o`0000;o^[OF00?o0000oknnfOno_]T01Ono_]T00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02?ooooo000Rooooo`;o00004oooool00ol0003oooooooooo`0k
ooooo`;o00002_nPY=P2o`0000CoXJKJ00?o0000ojRYf?nXZMP01?nXZMP3o`0000coZ:kL1?l00002
ojRfhP03o`000?n[]n;oZkOR01SoZkOR00?o0000ojjjh_n^^^804_n^^^86o`0000go][[L0ol00006
okVhf0?o000000Co^KSHo`000?l0003o00002Ono_]T2o`0002_ooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`;o00002_nPY=P2
o`0000KoXJKJ00Co0000ojRYf?nXZMSoZ:WH0ol0000;ojR^g0Co00001_nX]^800ol0003oZkORoj^g
hP0Boj^ghPOo00006On^^^801?l0003o/KgSok6mhol0000=okJjg0Ko00001Oni^=P2o`000003okfn
f_l0003o_kkI00So_kkI0_l0000Yooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=Oooool2o`0000[oX:CH0_l00008oj6VfP?o00002onX
[]`4o`0000_oZ;KR00?o0000oj^gh_n[]n801On[]n8<o`0000KoYl3[00?o0000ojO0jonW`>/00_nW
`>/9o`0000co[[[R00?o0000ok6mhona_N<00ona_N<4o`0000Oo][[L1_l00005okVhf0;o00000onm
_]X2o`0000So_kkI0_l0000Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0booooo`;o00002_nPY=P2o`0000SoXJKJ0_l00002oj>/g@03o`00
0?nX[]coZ:kL00GoZ:kL1?l0000=ojRfhP?o00000_n[]n84o`0001;oYl3[00?o0000ojO0jonW`>/0
3?nW`>/8o`0000?o[[[R00?o0000ok6mhona_N<02?na_N<3o`000004okJjg?l0003o0000o`0000Ko
][[L0ol000001Oni^=So0000okfnf_nm_][o000000Co_KkJ0_l00008oknnf@;o00009oooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool0027ooooo0ol0000Gooooo`03o`000?oooooooooo02oooooo0_l0000:oj2T
f0;o00002?nQY]X2o`0000GoXjcM00Co0000ojR^g?nX[]coZ:kL0ol0000=ojRfhPCo00000_nW`>/0
0ol0003oYl3[ojO0j`0@ojO0j`Oo00005_nW`>/4o`0000_o/KgS1Ol0000:okJjg005o`000?nm_][o
_KkJokfnf_l000001_nm_]X2o`0000So_kkI0_l0000Uooooo`03o`000?oooooooooo00Gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_l0000]ooooo`;o00002_nPY=P2o`0000SoXJKJ0_l00007oj>/g@?o00003OnX
]^84o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/:o`0000KoX<We00?o0000oic6mOnLa_D00_nL
a_D8o`0000goYl3[00?o0000ojS0jonX`>/00_l00004ok6mh`?o00001Ona_N<4o`0000Ko][[L00?o
0000okZog_l000000_nm_]X00ol0003o_KkJokfnfP05okfnfP;o00002?no_]T00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:Oooool01?l0003oV:;LoiRRg?l00007oj2Tf0;o00002?nQY]X2o`0000OoXjcM0_l000000onU
]>Co0000ojRfhP0:ojRfhP?o00002_nW`>/3o`000003ojO0jol0003o000000;o00004OnPbOD00ol0
003oW<Keoic6m@0:oic6m@So00001?nW`>/00ol0003oZ<3[ojS0j`04ojS0j`Co00002ona_N<3o`00
00;o][[L00?o0000okZog_nj_mh00_nj_mh3o`0000So_KkJ00?o0000oknnfOno_]T01_no_]T2o`00
02Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Wooooo`03o`000?nHX]coV:;L00;oV:;L00?o0000oj2Tf?nPY=P00_nPY=P2o`0000OoXJKJ0ol0
0007oj>/g@;o00001?nU]>@00ol0003oZ;KRojRfhP04ojRfhPCo00002?nW`>/5o`0000;oY<cd00?o
0000oj39mOnPbOD02OnPbOD<o`0001CoW<Ke1?l00004ojS0j`?o00001?nX`>/4o`0000[o/KgS0_l0
0007okZogP;o00002?nm_]X2o`0000So_kkI0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000oiRRg?nHX]`01?nHX]`01?l0003oX:CHoj2Tf?l00007oj6VfP;o
00002?nS[=d2o`0000KoYKCT00Co0000ojRfh_nX]^;oZ;KR0ol00008ojO0j`Co00001_nTc?@3o`00
00;oX<We2?l0000;oi?Ao@03o`000?n;b_goRl[m00CoRl[m2ol00005oic6m@03o`000?nJ`oCoV/?d
00?o00002onX`>/4o`0000Ko/KgS00?o0000ok?0i?nc`>@01onj_mh2o`0000Wo_KkJ0_l00008oknn
f@03o`000?oooooooooo01kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02?ooooo00?o0000
oiRRg?nHX]`01OnHX]`2o`0000OoXJKJ0_l00008oj>/g@;o00002?nU]>@3o`0000SoYl3[1?l00007
ojC<m0?o00000_nMeo`00ol0003oTm7moi?Ao@09oi?Ao@_o00004On;b_d8o`0000CoV/?d1?l0000:
ojS0j`?o00000_na_N<00ol0003o/l3Tok?0i003ok?0i003o`000?nj_mko^[oN00?o^[oN0ol00009
okfnfP;o00001?no_]T01?l0003o`lKMol?6gOl0000Qooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo027ooooo00?o0000oiRRg?nHX]`01OnHX]`01?l0003oVZGMoiZUgOl00004oj6V
fP;o00002?nS[=d2o`0000SoYKCT0_l00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00007ojC<
m0Co00001?nMeo`3o`0000?oTm7m1ol0000:oh?Eo`03o`000?mgb_ooMl[o00?oMl[o2ol00003oh_:
o@?o00000_n6`o/00ol0003oV/?doi[3m006oi[3m0?o00002_nX`>/2o`0000Oo/l3T0_l00004okZo
gP04o`000?nj_mko0000o`0000Wo_KkJ0_l000000ono_]Wo0000ol?6g@03ol?6g@03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07?ooool000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0O
ooooo`03o`000?nHX]coV:;L00GoV:;L00?o0000oiZUgOnJYMd00_nJYMd01?l0003oXJKJoj6Vf_l0
0008oj>/g@;o00002?nU]>@2o`0000GoYl3[0ol00009ojC<m0?o00001?nMeo`4o`0000;oU=kn00?o
0000oh?Eoon3eOl02?n3eOl;o`00013oMl[o1Ol00006ohK3n`Co00001OnJ`o@4o`0000KoZ<3[00?o
0000ojS0jonX`>/02?nc`>@2o`0000;o^[oN00Co0000okZog_nj_mko^[oN0_l00009okfnfP03o`00
0?o3a]go`lKM00Co`lKM00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01gooooo00?o0000oiRRg?nHX]`01OnHX]`00ol0003oVZGM
oiZUg@03oiZUg@?o00001onS[=d2o`0000SoYKCT0_l00005ojO0j`;o000000?oZ<gco`000?nTc?@0
1_nTc?@3o`0000?oWMOl1?l00005oiCNoP?o00000_n3eOl7o`0000KoM]Cn1Ol00005ofO7oP_o0000
1?mgb_l01?l0003oL;onog2oo_l00007ohK3n`?o00001_nJ`o@3o`0000;oZ<3[00?o0000ojS0jonX
`>/00onX`>/00ol0003o/l3Tok?0i005ok?0i0;o000000?o^[oNo`000?nj_mh00onj_mh00ol0003o
_KkJokfnfP05okfnfP;o00001oo3a]d00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01_o
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Sooooo`03
o`000?oooooooooo01_ooooo00?o0000oiRRg?nHX]`01?nHX]`2o`0000GoVZGM00Go0000oif[h?nM
Zn3oWJ_Po`000004oj>/g@;o00001onU]>@3o`0000GoYl3[0_l00004ojS=l`03o`000?nTc?CoY<cd
00;oY<cd00?o0000oigGo?nMeo`00_nMeo`3o`0000CoU=kn1Ol00002ohcPo@?o00001?mfe?h4o`00
00GoLmCm1Ol00005ofC6o@So00000_mWaoh5o`0000KoL;on0ol00005ohK3n`Co00001OnJ`o@2o`00
00SoZ<3[00?o0000ok?0i?nc`>@01Onc`>@00ol0003o^[oNo`000004okZogP;o00001?nm_]X01?l0
003o`LKNol76g_l00007ol?6g@03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0
023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?nHX]coV:;L
00CoV:;L00?o0000oiZUgOnJYMd01?nJYMd00ol0003oWJ_Poif[h003oif[h004o`000?nS[=goXjcM
o`0000OoYKCT0_l00006ojO0j`;o00001_nXcO<4o`0000CoWMOl0_l00003oiCNoPCo00000on<h?d4
o`000004oh[PoOl0003o0000o`0000?oLmCm1Ol00004ogkEo`Go00001?m`bOl6o`0000CoI<Km1?l0
0004of2ko@03o`000?m`_okoL;on00CoL;on0ol00006ohK3n`?o00000_nJ`o@01?l0003oV;ocoiRo
lol00007ojS0j`;o00001_nc`>@3o`0000Go^[oN0_l000000onm_][o0000ol76gP03ol76gP03o`00
0?o3a]go`lKM00Go`lKM00?o0000ooooooooool07?ooool00ol0003oooooo`00000Kooooo`008?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo00?o0000oiRRg?nHX]`01?nH
X]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3oWJ_P00CoWJ_P0_l00007ojFdi0;o00001OnW
`>/3o`0000KoZ<gc0_l00003ojSJn@?o00001?nDg_h3o`0000CoS>3m0ol00002oh[Po@?o000000Co
T=ono`000?l0003o00000omneOl4o`0000SoSm?n00?o0000ohK;o_n6boh00_n6boh5o`0000CoL<Wo
1?l00003oefjo0GoH;_m0ol00004og2ooP?o00001_n6`o/2o`0000GoV;oc0_l00006ojS0j`;o0000
1_nc`>@2o`0000Ko^[oN00?o0000ol76g_o1a]h01?o1a]h00ol0003o`lKMol?6g@05ol?6g@03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?nHX]coV:;L00CoV:;L00?o0000oiZUgOnJYMd01?nJ
YMd00ol0003oWJ_Poif[h004oif[h004o`000?nQ]>GoXKCUo`0000CoYKCT0_l00005ojO0j`;o0000
1onXcO<2o`0000?oZ=[i0_l00002ojGSn`Co00001On<h?d00ol0003oR^3moh[Po@02oh[Po@;o0000
0_n@goh3o`0000;oVmWm00?o0000ohoCo_n?doh01_n?doh7o`0000;oQ/_n0ol00007ohK;oPCo0000
1?mY_Oh00ol0003oGK[loefjo002oefjo003o`000?mP^ogoH;_m00;oH;_m0ol00003og2ooP?o0000
0_n6`o/01?l0003oQ;_hohBkn?n4^oP6oiRol`;o00001_nX`>/2o`0000Go/l3T0_l00004okZogP03
o`000?nlaN7o_<GQ00Ko`LKN00?o0000ol?6gOo3a]d01Oo3a]d00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Sooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?nHX]coV:;L00CoV:;L00?o0000oiZUgOnJYMd01?nJYMd00ol0003oWJ_Poif[h004oif[h003o`00
0?nQ]>GoXKCU00;oXKCU00Co0000ojFdi?nU]>Co00001OnW`>/2o`0000OoZ<gc0_l00003ojSJn@;o
00000_nUho/2o`0000?oX^Sk0_l000000on<h?goR^3moh[Po@03oh[Po@04o`000?n@gokoT=onoi3O
oP;o00001OnKfOd3o`0000;oSm?n1?l00007oio:mP?o00000_nKaoH7o`0000CoQ/_n00Co0000oh32
o?n0`_co00001OmY_Oh3o`0000?oGK[l00?o0000of2koOmP^od00ol00003og2ooP;o00001_n4^oP0
0ol0003oV;ocoiRol`03oiRol`;o00001_nX`>/2o`0000Co/l3T0ol000000onj_mko0000okc5h@03
okc5h@Ko`LKN00?o0000ol?6gOo3a]d01Oo3a]d00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Oooooo000Oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oV:;LoiRRg003oiRRg0;o00001OnJYMd2o`0000KoWJ_P00?o0000oj6diOnQ]>D00onQ]>D3o`00
00GoYl3[00?o0000ojS=lonXcO<01?nXcO<3o`0000?oZ=[i0_l00002ojGSn`;o00000onRj?/2o`00
00;oXNSk0_l000000on:h?goT=onoi3OoP02oi3OoP;o00000onKfOd5o`0000;oY<ge00?o0000oio:
m_nOb_H02OnOb_H3o`0000_oVlOf1?l00006oh32o0Co00000_mY_Oh4o`0000?oGK[l1Ol00003og2e
n`KoQ;_h0_l00005oiRol`;o00001_nX`>/00ol0003o/l3Tok?0i002ok?0i0?o00001_nlaN400ol0
003o`LKNol76gP03ol76gP03o`000?o3a]go`lKM00Go`lKM00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oo
oooo00?o0000oiRRg?nHX]`00onHX]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3oWJ_P00Go
WJ_P00?o0000oj6diOnQ]>D00onQ]>D01Ol0003oYl3[ojO0jonW`>_o000000;oYl3[00?o0000ojS=
lonXcO<01?nXcO<2o`0000?oZ=[i0ol000001?nUho_o0000o`000?l00003oj;Xn`;o00000_nQj?/2
o`0000;oY>Gk1?l00004oi_Io@;o00001_nTcOD3o`000003oio:m_l0003o000000[o00003OnKaoH0
1?l0003oV<?eoiS3mOnH`oD2o`0000KoP<;l0ol00003ofVmoP?o00000omN[oX2of6`nPGoL;Gk00?o
0000ohBkn?n4^oP00on4^oP2o`0000GoV;oc0_l00005ojS0j`;o000000?o/l3To`000?l000000_nd
`nH00ol0003o_<GQokc5h@04okc5h@03o`000?o1a]ko`LKN00?o`LKN00?o0000ol?6gOo3a]d01Oo3
a]d00ol0003oooooooooo`0Kooooo`;o00006?ooool001oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0=ooooo`;o00001?nHX]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3o
WJ_P00GoWJ_P00?o0000oj6diOnQ]>D00onQ]>D00ol0003oYl3[ojO0j`02ojO0j`?o00001OnXcO<2
o`0000?oZ=[i0_l00003ojGSn`04o`000?nRj?_oX^Skoj;Xn`?o00000_nQj?/2o`0000;oY>Gk0_l0
0003ojOMnP?o00001_nTcOD4o`0000;oZ;gY00?o0000ojVnjOnY_^T00_nY_^T3o`0000GoZKkY00?o
0000ojVnjOnY_^T01OnY_^T6o`0000WoV<?e1?l00002oh32o0?o00000omY/o/4oej_nP;o000000?o
HK3jo`000?m`]O/00om`]O/2o`0000CoQ;_h0_l00005oiRol`;o00001?nX`>/2o`0000;o]<?V00Co
0000okC3i_nd`nKo00001_nlaN400ol0003o`LKNol76gP03ol76gP03o`000?o3a]go`lKM00Go`lKM
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00cooooo00Co0000ohnQh?l0003o00000_nHX]`6oiZUg@03o`00
0?nMZn3oWJ_P00CoWJ_P0_l00005oj6di@03o`000?nW`>_oYl3[00;oYl3[00Co0000ojg=lOn]cO7o
[Lga0_l00002ojS=l`03o`000?nXf_WoZ=[i00;oZ=[i00Go0000ojGSnonUho_oYN?ko`000003oj;X
n`;o00000_nQj?/3o`0000;oY>Gk0_l00003ojOMnP;o00000_nYc_<01?l0003oY<geojC=mOnTcOD3
o`0000OoZ;gY1?l00008ojVnj@03o`000?nY_^WoZKkY00[oZKkY00?o0000ojZojOnZ_nT01?l00007
oiS3m@;o00000omn^_T5ofVcn`CoGZoj0_l000000omQ/?[o0000og2en`03og2en`03o`000?n4^oSo
Q;_h00?oQ;_h0_l00005oiRol`;o000000?oZ<3[o`000?nX`>/00_nX`>/2okC3iP04o`000?nd`nKo
]<?Vo`0000Ko_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMol?6g@05ol?6g@03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool05Oooool001oooooo0_l0000]ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ohnQh?n?XN000_n?XN02o`0000GoVZGM00?o0000oif[h?nMZn001?nMZn00
0ol0003oXKCUoj6di@04oj6di@03o`000?nW`>_oYl3[00;oYl3[00?o0000ojg=lOn]cO400on]cO44
o`0000;oZ=[i00Go0000ojGSnonUho_oYN?ko`000004oj;Xn`05o`000?nQj?_oXNSkoj7Xnol00000
0onTiO/2o`0000?oYmgj0_l00004ojW>l`?o00002OnX_NT3o`000003ojVnjOl0003o000000Wo0000
0_nY_^T4o`0000GoZKkY00?o0000ojZojOnZ_nT01OnZ_nT4o`0000;oV<?e00Co0000oiJnlonF__?o
U[kc1?mn^_T01?l0003oJK?kofVcnomY/o/2o`0000?oGZoj00Go0000of6`n_mQ/?[oHK3jo`000002
og2en`;o00001On4^oP00ol0003oV;ocoiRol`03oiRol`;o00001OnX`>/2okC3iP04o`000?nd`nKo
]<?Vo`0000Ko_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMol?6g@05ol?6g@03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`09ooooo`03o`000?n?XN3oSj7P00;oSj7P00?o0000oi6Th_l000001?nJYMd6
oif[h003o`000?nQ]>GoXKCU00CoXKCU00?o0000ojO0jonW`>/00_nW`>/00ol0003o[Lgaojg=l@03
ojg=l@04o`000?naf_Go/M[eok7Jm@So00000_nRj?/01Ol0003oXNSkoj7XnonQj?_o000000CoY>Gk
00Co0000ojOMn_nWgO[oYmgj0_l00004ojW>l`;o000000?oYkgYo`000?nX_NT01OnX_NT4o`0000;o
ZJoL00?o0000ojfbfon]/]/02On]/]/00ol0003o/KGKok6ef`04ok6ef`Ko00002onZ_nT2o`0000Ko
U[kc00Go0000ogjjnOmn^_WoO[[io`000003ofVcn`;o00000_mN[oX2o`0000?oHK3j0_l000000om`
]O_o0000o`000004ohBkn0;o000000?oV;oco`000?l000000_nH^o000ol0003oZ<3[ojS0j`03ojS0
j`;o00000ond`nH00ol0003o_<GQokc5h@04okc5h@03o`000?o1a]ko`LKN00?o`LKN00?o0000ol?6
gOo3a]d01?o3a]d2o`0001gooooo00?o0000ooooooooool04oooool001kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`07ooooo`03o`000?n?XN3oSj7P00;oSj7P00Go0000oi6Th_nA
Y>;oTJCRo`000002oiZUg@KoWJ_P00?o0000oj6diOnQ]>D00onQ]>D2o`0000CoYl3[00?o0000ojg=
lOn]cO400on]cO401Ol0003o/M[eok7JmOnaf_Go000000?o]>Cg00Co0000okGYmonejOOo]NWg2?l0
0002ojCUn`04o`000?nWgO[oYmgjojOMnP;o00001?nYc_<2o`0000CoYkgY00?o0000ojRmjOnX_NT0
1?l00005ojV_g003o`000?n]/]_o[K;K00Wo[K;K00?o0000ok6efona]M/02Ona]M/00ol0003o]KWL
okFig004o`0000KoZ[oY00?o0000ojZojOl000001OnF__<2o`0000?oO[[i0_l00002ofVcn`04o`00
0?mN[o[oGZojoej_nP;o00000omQ/?X2o`000003og2enol0003o000000;oQ;_h0ol00005oiRkl003
o`000?nX`>_oZ<3[00?oZ<3[0_l00003okC3iP03o`000?nlaN7o_<GQ00Co_<GQ00?o0000ol76g_o1
a]h00oo1a]h01?l0003o`lKMol?6gOo3a]d2o`000003olG?h_l0003ooooo01cooooo00?o0000oooo
ooooool04oooool001kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?n?XN3oSj7P00?oSj7P00?o0000oi6Th_nAY>800_nAY>82o`0000GoWJ_P00?o0000oj6diOnQ
]>D00onQ]>D00ol0003oYl3[ojO0j`02ojO0j`;o00001?n]cO42o`0000?o/M[e00Go0000okCTmond
i?Oo]>Cgo`000003okGYm`05o`000?nej_Oo]N[gokGZmol000000ondi_L4o`0000;oYmgj00?o0000
ojW>lonYc_<00_nYc_<2o`0000KoYkgY1?l00009ojV_g003o`000?n]/]_o[K;K00?o[K;K1_l00002
ok6ef`Co00001?na]M/00ol0003o]KWLokFig005okFig0?o00000_nZ_nT00ol0003oZ[oYojZoj@02
ojZoj@;o00001?nF__<2o`0000?oO[[i0_l000000omY/o_o0000o`000003oej_nP03o`000?mQ/?[o
HK3j00Oo00000on5]?@00ol0003oV;_`oiRkl003oiRkl003o`000?nX`>_oZ<3[00?oZ<3[0_l00003
okC3iP03o`000?nlaN7o_<GQ00Co_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMo`000004
olG?hP03o`000?oooooooooo01Wooooo00?o0000ooooool000005?ooool001kooooo0ol0000aoooo
o`;o00001Oooool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZ
i?l000000onMZn000ol0003oXKCUoj6di@03oj6di@03o`000?nW`>_oYl3[00;oYl3[00?o0000ojg=
lOn]cO400on]cO400ol0003o/M[eok7Jm@02ok7Jm@05o`000?ndi?Oo]>CgokCTmol000000onejOL0
1Ol0003o]N[gokGZmonej_Oo000000?o]>Kg00Co0000ok;Mm_nbgOKo/]gf1?l00003ojW>l`03o`00
0?nW_NWoYkgY00CoYkgY0ol000000onT[Mko0000ojV_g007ojV_g0So00001On_Z=400ol0003o]ZkA
okJ^d@04okJ^d@Go00002_ne^M`2o`0000OoZ[oY0_l00004oiJnl`03o`000?mn^_WoO[[i00_o0000
0omXZ?H01?l0003oM:gfogB]m_md[OH4ohFdm003o`000?nH^o3oV;_`00?oV;_`00?o0000ojS0jonX
`>/00onX`>/2o`0000?o]<?V00?o0000okc5hOnlaN401?nlaN400ol0003o`LKNol76gP02ol76gP;o
00001Oo5cn800ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo000Nooooo`03o`00
0?oooooooooo03?ooooo00Go0000ooooooooooooooooo`000004ohnQh003o`000?nAY>;oTJCR00?o
TJCR00Go0000oiNZi?nGZ^CoUj[To`000002oif[h0GoXKCU00?o0000ojO0jonW`>/00_nW`>/00ol0
003o[Lgaojg=l@03ojg=l@03o`000?naf_Go/M[e00;o/M[e00Go0000okCTmondi?Oo]>Cgo`000003
okGYm`05o`000?nej_Oo]N[gokGZmol000000ondi_L01Ol0003o/]gfok;Mm_nbgOKo000000Co[/oa
0ol00004ojNmj@?o00001OnT[Mh00ol0003oZJoLojV_g005o`0000;oZ:CB00?o0000ojnXdOn_Z=40
2?n_Z=400ol0003o]ZkAokJ^d@08okJ^d@03o`000?nl]=;o_;CB00?o00001One^M`00ol0003o^;kN
okRngP02o`0000KoZ[oY0_l00003oiJnl`;o00000on0/_@01?l0003oKj_fofn[m_m_ZoH4ofJWm@Co
J:Sf00Co0000ogB]m_md[OKoM:gf1?n5]?@00ol0003oV;_`oiRkl003oiRkl003o`000?nX`>_oZ<3[
00?oZ<3[00?o0000okC3i_nd`nH00_nd`nH00ol0003o_<GQokc5h@04okc5h@06o`000?o1a]ko0000
o`000?o3c^?o00001_o5cn800ol0003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo000C
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0dooooo`04o`000?oo
ooooooooo`0000CoSj7P00?o0000oi6Th_nAY>800onAY>800ol0003oUj[ToiNZi002oiNZi0;o0000
1OnQ]>D4ojO0j`03o`000?n]cO7o[Lga00?o[Lga00?o0000ok7JmOnaf_D00_naf_D01Ol0003o]>Cg
okCTmondi?Oo000000?o]NWg00?o0000okGZmonej_L00_l00002okCVm`;o00000onbgOH00ol0003o
[/oaojk?l@02ojk?l@04o`000?nW_NWoYkgYojNmj@Co00002?nT[Mh3o`0000SoZ:CB00?o0000ojnX
dOn_Z=401on_Z=400ol0003o]ZkAokJ^d@07okJ^d@03o`000?nl]=;o_;CB00Co_;CB0ol000000one
^Mco0000okRngP04okRngP?o00001OnZ_nT2o`0000?oU[[a1?n0/_@01Ol0003oKj_fofn[m_m_ZoKo
000000?oIZOe1?mXZ?H01Ol0003oM:gfogB]m_md[OKo000000?oQKCd00?o0000oiRkl?nH^o000onH
^o000ol0003oZ<3[ojS0j`03ojS0j`03o`000?nd`nKo]<?V00;o]<?V00?o0000okc5hOnlaN400onl
aN42o`0000Co`lkS00?o0000olG?h_o5cn800oo5cn800ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo013ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`0fooooo`;o00001?n?XN000ol0003oTJCRoi6ThP03oi6ThP03o`000?nGZ^CoUj[T00?oUj[T00Co
0000oijdj?l0003o00000_nQ]>D5ojO0j`Co[Lga0_l00004ok7Jm@05o`000?ndi?Oo]>CgokCTmol0
00000onejOL01?l0003o]N[gokGZmol00003okCVm`04o`000?nbgOKo/]gfok;MmP;o00001?n^co40
0ol0003oYkgYojNmj@04o`0000SoY:gN0_l000000onQX=Co0000ojRTdP08ojRTdP03o`000?n_Z=7o
[jSA00Oo[jSA00?o0000okJ^dOnf[]401onf[]400ol0003o_;CBokbddP07okbddP03o`000?nh_]ko
^;kN00Oo^;kN0_l000001OnZ_nWo0000oj[0jOnZ`>Wo000000CoU[[a00Go0000oh2bm?n0/_CoP;;d
o`000003ofn[mP05o`000?mVYoGoIZOeofJWmOl000000omXZ?H01Ol0003oM:gfogB]m_md[OKo0000
00?oQKCd00?o0000oiRkl?nH^o000onH^o000ol0003oZ<3[ojS0j`03ojS0j`03o`000?nd`nKo]<?V
00;o]<?V00Oo0000okc5hOnlaN7o_<GQo`000?nmbnGo000000Co`lkS00?o0000olG?h_o5cn800oo5
cn800ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo1?l000000ol@413ooooooooo
o`02ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZi?nGZ^@00_nG
Z^@00ol0003oW[CXoijdj002oijdj0?o00000onW`>/5ojg=l@Go/M[e00Go0000okCTmondi?Oo]>Cg
o`000003okGYm`04o`000?nej_Oo]N[gokGZm`Co]>Kg0onbgOH00ol0003o[/oaojk?l@02ojk?l@Go
000000GoYkgYo`000?nO[>3oWjcPo`000004ojB]gP?o00001?nQX=@00ol0003oZ:CBojRTdP05ojRT
dQ7o00001?nf[]400ol0003o_;CBokbddP07okbddP04o`000?o1_=Go0000o`0000So^;kN00?o0000
oj[0jOnZ`>T00_nZ`>T00ol0003oU[[aoiJjl@02oiJjl@05o`000?n0/_CoP;;doh2bm?l000000om_
ZoH01Ol0003oIZOeofJWmOmVYoGo000000?oJ:Sf00Go0000ogB]m_md[OKoM:gfo`000003ohFdm003
o`000?nH^o3oV;_`00?oV;_`00?o0000ojS0jonX`>/00onX`>/00ol0003o]<?VokC3iP02okC3iP03
o`000?nlaN7o000000?o_L_U00?o0000ol?>hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03
o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05o`00
0?ooooooooooooooool000001Oooool2o`0003Oooooo00?o0000ohnQh?n?XN000_n?XN000ol0003o
TJCRoi6ThP03oi6ThP03o`000?nGZ^CoUj[T00?oUj[T00?o0000oijdj?nN]>P00_nN]>P00ol0003o
Yl3[ojO0j`04o`0000?o[Lga1_naf_D3okCTm`05o`000?nejOOo]NWgokGYmol000000onej_L4okCV
m`Co/]gf1?n^co43o`0000?oYkgY00?o0000oin/h?nO[>000_nO[>001?l0003oY:gNojB]g_l00007
oj6Pe003o`000?nXY=;oZ:CB00Go00000_nWW<X00ol0003o/:;9ok2Rb@06ok2Rb@03o`000?nhZ<Wo
^:S900?o^:S91?l00009okbddP03o`000?o1_=Go`KcE00;o`KcE0_l00004okRngP04o`000?nj`n7o
^/?Qo`0000CoZ/3Y00?o0000oiJjlOnF^_400_nF^_401Ol0003oP;;doh2bm?n0/_Co000000?oKj_f
00?o0000ofJWmOmVYoD00_mVYoD01?l0003oJ:SfofRXm_l00003ogB]mP05o`000?n5]?CoQKCdohFd
m?l000001OnH^o000ol0003oZ<3[ojS0j`02ojS0j`;o00000_nd`nH3o`0000Co_L_U00?o0000ol?>
hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`004oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0=_ooool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR
00?oTJCR00?o0000oiNZi?nGZ^@00_nGZ^@00ol0003oW[CXoijdj002oijdj003o`000?nW`>_oYl3[
00;oYl3[00?o0000ok3<k_n`c>h01Ol00003ok7Jm@Co]>Cg1?nejOL@o`0000GoYkgY00?o0000oin/
h?nO[>000onO[>02o`0000WoXJ3D0ol00007ojNLbP03o`000?n`X/Wo/:;900Ko/:;900?o0000okRX
bOnhZ<T01_nhZ<T00ol0003o_k3;okn`b`05o`0000;o_;CB00?o0000ol6leOo1_=D01?o1_=D2o`00
0003okRng_l0003o^/?Q00?o^/?Q00?o0000oj[0jOnZ`>T00_nZ`>T00ol0003oU[[aoiJjl@02oiJj
l@05o`000?n0/_CoP;;doh2bm?l000000om_ZoH00ol0003oIZOeofJWm@02ofJWm@04o`000?mXZ?Ko
J:Sfo`0000?oM:gf00Go0000ohFdm?n5]?CoQKCdo`000005oiRkl003o`000?nX`>_oZ<3[00;oZ<3[
0ol00002okC7j0Ko_L_U00?o0000ol?>hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`004ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oSj7P
ohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZi?nGZ^@00_nGZ^@00ol0003oW[CX
oijdj002oijdj003o`000?nW`>_oYl3[00;oYl3[00?o0000ok3<k_n`c>h00_n`c>h01?l0003o^=S`
okSHl?nhf?0;o`0000;o`^K`00Go0000ol3Sl?o0ho3o`>?`o`000003ok[Jl0Ko00001?nW_NT00ol0
003oWjcPoin/h003oin/h003o`000?nHW]So000000OoXJ3D0_l000000onNUlgo0000ojNLbP08ojNL
bP03o`000?n`X/Wo/:;900Go/:;900?o0000okRXbOnhZ<T01_nhZ<T00ol0003o_k3;okn`b`05okn`
b`;o00002Oo1_=D00ol0003o^/?Qok[3h@04ok[3h@03o`000?nZ`>WoZ/3Y00;oZ/3Y00?o0000oiJj
lOnF^_400_nF^_401Ol0003oP;;doh2bm?n0/_Co000000?oKj_f00?o0000ofJWmOmVYoD00_mVYoD0
1?l0003oJ:SfofRXm_l00003ogB]mP05o`000?n5]?CoQKCdohFdm?l000001OnH^o001_l0003oZ<3[
o`000?l0003oZ<7[o`0000Co]<OX1OnmbnD00ol0003o`lkSol?>h`02ol?>h`03o`000?o5cn;oaLoR
00?oaLoR00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0doooo
o`03o`000?n?XN3oSj7P00?oSj7P00?o0000oi6Th_nAY>800_nAY>800ol0003oUj[ToiNZi003oiNZ
i003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/01Ol0003o/<c^ok3<k_n`c>ko
000000Go^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;Ul004o`000?o2i_3o`^K`o`0000?o`>?`
00?o0000ok[Jl?l000000_l00004ok7=kP06o`000?nV_N[o0000o`000?nW_NWo00001OnO[>001Ol0
003oV9kHoiRNf?nHW]So000000CoXJ3D0_l00004oijGc@03o`000?nWW<[oYic:00KoYic:00?o0000
ok2RbOn`X/T01On`X/T00ol0003o^:S9okRXb@05okRXb@03o`000?no/<_o_k3;00Oo_k3;00?o0000
olJic_l000000_l00004ol6le@04o`000?o5a=WoaLCIo`0000Go^/?Q00?o0000oj[0jOnZ`>T00_nZ
`>T00ol0003oU[[aoiJjl@0Co`0000?oM:gf00Go0000ohFdm?n5]?CoQKCdo`000003oiRkl0?o0000
0onX`N/00ol0003o]<OXokC7j002okC7j003o`000?nmbnGo_L_U00?o_L_U00?o0000ol?>hoo3c^<0
0_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_l0000eooooo`03o`000?n?XN3oSj7P00;oSj7P00?o0000oi6Th_nAY>800onAY>800ol0003oUj[T
oiNZi002oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/00ol0003o/<c^
ok3<kP02ok3<kP03o`000?nhf?3o^=S`00;o^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;Ul004
o`000?o2i_3o`^K`o`0000?o`>?`0ol000000onjf_3o0000ok7=kP03ok7=kP03o`000?nV_N[oY[gZ
00;oY[gZ0_l00004oin/h003o`000?nHW]SoV9kH00?oV9kH00Co0000oj6Pe?nQX=Co00001_nNUld0
0ol0003oYic:ojNLbP04ojNLbQ?o00002?no/</00ol0003oa[W>olJicP03olJicP;o000000?o`KcE
o`000?o5a=T00oo5a=T00ol0003o^/?Qok[3h@03ok[3h@03o`000?nZ`>WoZ/3Y00Co00000_nG]nh0
1Ol0003oQJg_ohF]kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h00_m`X>h3og:QkPco00000_nI
^>h5ojS1j`03o`000?ndanSo]<OX00;o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>
h`03ol?>h`03o`000?o5cn;oaLoR00;oaLoR00?o0000ooooooooool06oooool3o`0000Oooooo00?o
0000ooooooooool01?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000?oSj7P00?o0000
oi6Th_nAY>800onAY>800ol0003oUj[ToiNZi003oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000
ojO0jonW`>/00_nW`>/01Ol0003o/<c^ok3<k_n`c>ko000000Co^=S`00Go0000okkPl?nnh?3o_^3`
o`000003ol;Ul004o`000?o2i_3o`^K`ol;Vl0Go00000onjf_001Ol0003o/Lg^ok7=k_nacNko0000
00GoY[gZ00Ko0000oiZ/i?l0003o0000oin/h?l00006oiRNf0;o00002?nNUld00ol0003oYic:ojNL
bP04o`0000;oYYO600?o0000ok2Ma?n`WL@01On`WL@00ol0003o^JG5okVUa@05okVUa@03o`000?o2
[/Ko`Zk600?o00000_no/</00ol0003oa[W>olJicP06olJicP03o`000?o5a=WoaLCI00CoaLCI00?o
0000ok[3hOnj`n400onj`n42o`0000;oZ/7Z00?o0000oiNgk_nG]nh00_nG]nh01Ol0003oQJg_ohF]
kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h00_m`X>h3og:QkPCoNjO_1?n9[nl6oiVhkPGoZ<7[
00Go0000okC7j?ndanSo]<OXo`000005okg;i@03o`000?o3c^?o`lkS00;o`lkS00?o0000olG?h_o5
cn800_o5cn800ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l0
00001_ooool001cooooo00?o0000ooooooooool0=?ooool2ohJRiP;o000000?oSj7Po`000?nAY>80
1?nAY>800ol0003oUj[ToiNZi002oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/0
0_nW`>/01Ol0003o/<c^ok3<k_n`c>ko000000Go^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;U
l003o`000?o2i_3o`^K`00;o00000_o0ho001Ol0003o^][`ok[Jl?njf_3o000000?o/Lg^00?o0000
ojJmj_nV_NX00onV_NX00ol0003oVZcToiZ/i002oiZ/i0;o00001OnHW]P00ol0003oTi?Ao`000008
oijGc@?o00001_nVUlH00ol0003o/9g4ok2Ma005ok2Ma003o`000?niYLGo^JG500Go^JG500?o0000
ol:^a_o2[/H00oo2[/H2o`0000Woa[W>0_l00006olG4f@06o`000?nj`n7o0000o`000?nkb>Co0000
1?nZ`NX01Ol0003oUkO^oiNgk_nG]nko000000CoQJg_00Co0000ogNTkomgY>oo00001?m`X>h01?l0
003oLZ7^og:Qk_mbXNh4og^Wk`CoRJo_1OnI^>h00ol0003oZ<7[ojS1j`02ojS1j`;o00000ondanP0
0ol0003o_L_Uokg;i@02okg;i@03o`000?o3c^?o`lkS00?o`lkS00?o0000olG?h_o5cn800_o5cn80
0ol0003oooooooooo`0Looooo`?o00003?ooool001cooooo00?o0000ooooooooool0=?ooool4ohJR
iP;o00001?nAY>800ol0003oUj[ToiNZi003oiNZi005o`000?nN]>SoW[CXoijdj?l000001?nW`>/0
0ol0003o/<c^ok3<kP02ok3<kP03o`000?nhf?3o^=S`00;o^=S`00Go0000okkPl?nnh?3o_^3`o`00
0003ol;Ul0Co00001?o0ho001Ol0003o^][`ok[Jl?njf_3o000000?o/Lg^00?o0000ojJmj_nV_NX0
0_nV_NX00ol0003oVZcToiZ/i003oiZ/i0;oSigM00Go0000oiRNf?nHW]SoV9kHo`000003oi>Cd@03
o`000?nNUlgoWYO=00;oWYO=0ol000000onLTLSo0000ojJGaP07ojJGaP03o`000?n`WLCo/9g400Co
/9g400?o0000okVUaOniYLD01OniYLD00ol0003o`Zk6ol:^aP04ol:^aP04o`000?o9^<Wo0000o`00
00Goa[W>00Co0000olg4d_o=a=;o00001_o5a=T00ol0003o^lSTok_8i002ok_8i005o`000?nZ`N[o
Z/7Zoj[1j_l000001?nG]nh01Ol0003oQJg_ohF]kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h0
0_m`X>h01?l0003oLZ7^og:Qk_l00003og^Wk`05o`000?n9[nooRJo_ohV_kol000001OnI^>h01?l0
003oZ<7[ojS1jonX`N/2o`0000?o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>h`03
ol?>h`03o`000?o5cn;oaLoR00;oaLoR00?o0000ooooooooool06Oooool3o`0000;ooooo00?o0000
ooooooooool02_ooool001cooooo00?o0000ooooooooool0=?ooool4ohJRiP;oRJGW0ol000000onA
Y>;o0000oiNZi003oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/01Ol0
003o/<c^ok3<k_n`c>ko000000Co^=S`00Go0000okkPl?nnh?3o_^3`o`000002ol;Ul0?o00000_o2
i_001Ol0003o`>?`ol3Sl?o0ho3o000000?o^][`00Go0000ok7=k_nacNko/Lg^o`000005ojJmjP03
o`000?nJ[>CoVZcT00;oVZcT00Oo0000ohnMgOn?WMgoSigMo`000?nHW]So000000GoTi?A00Co0000
oijGcOnNUlgo00001OnLTLP00ol0003oYYO6ojJGaP05ojJGaP03o`000?n`WLCo/9g400Co/9g400?o
0000okVUaOniYLD01?niYLD00ol0003o`Zk6ol:^aP04ol:^aP03o`000?o9^<WobKS900;obKS900Go
0000olJic_o6^Lkoa[W>o`000004olg4dP07o`000?o5a=WoaLCIolG4fOl0003ob<gNo`000004ok_8
i003o`000?nZ`N[oZ/7Z00;oZ/7Z00Go0000oiNgk_nG]nkoUkO^o`000004ohF]k`05o`000?mgY>oo
MjC_ogNTkol000000om`X>h01Ol0003oLZ7^og:Qk_mbXNko000000?oNjO_00Go0000ohV_kon9[noo
RJo_o`000004oiVhkP03o`000?nX`N_oZ<7[00;oZ<7[0_l00003okC7j003o`000?nmbnGo_L_U00;o
_L_U00?o0000ol?>hoo3c^<00oo3c^<01?l0003oaLoRolG?h_o5cn82o`0001Oooooo0ol00005oooo
o`03o`000?oooooooooo00[ooooo000Looooo`;o0000=Oooool01?l0003oQZ;VohJRi_n6X^H5ohVU
i`;o00000onGZ^@00ol0003oW[CXoijdj002oijdj003o`000?nW`>_oYl3[00;oYl3[00?o0000ok3<
k_n`c>h00_n`c>h00ol0003o^=S`okSHl002okSHl003o`000?nnh?3o_^3`00Co000000Go`^G`o`00
0?o2i_3o`^K`o`000004ol3Sl0_o00000_nV_NX00ol0003oVZcToiZ/i002oiZ/i003o`000?n?WMgo
SigM00?oSigM00?o0000oi>CdOnCTm401?nCTm42o`0000OoW97800?o0000ojJGa_nVUlH00onVUlH>
o`0000;o^JG500?o0000ol:^a_o2[/H01?o2[/H00ol0003obKS9olVhb@03olVhb@;o000000?oa[W>
o`000?o=a=801?o=a=800ol0003oaLCIo`000003olS=gP03o`000?nkb>Co^lST00;o^lST00?o0000
oj[1j_nZ`NX00_nZ`NX01Ol0003oUkO^oiNgk_nG]nko000000?oQJg_00Go0000ogNTkomgY>ooMjC_
o`000004og2PkP04o`000?mbXNkoLZ7^o`0000?oNjO_00Go0000ohV_kon9[nooRJo_o`000005oiVh
kP07o`000?nX`N_oZ<7[ojS1jol0003o]<OXo`000002okC7j003o`000?nmbnGo_L_U00;o_L_U00?o
0000ol?>hoo3c^<00oo3c^<01_l0003oaLoRo`000?l0003oaMSWo`0001Cooooo0ol00008ooooo`03
o`000?oooooooooo00[ooooo000Looooo`03o`000?oooooooooo03Cooooo00Co0000ohJRi_n6X^Ko
QZ;V1On9YNL2oi2[j0;o000000?oUj[To`000?nN]>P00onN]>P00ol0003oYl3[ojO0j`02ojO0j`05
o`000?n`c>ko/<c^ok3<k_l000001?nhf?000ol0003o_^3`o`000002o`0000?o`^G`2_l00002okoE
jP05o`000?ndbn_o]<_[okC;jol000000onV_NX3o`0000CoVZcT00?o0000ohnMgOn?WMd00on?WMd0
0ol0003oTi?Aoi>Cd@03oi>Cd@03o`000?n?SLco000000OoW97800?o0000ojJGa_nVUlH00ol00002
ojJE``03o`000?n`Vl;o/9_200Co/9_200?o0000okZS`_njXl800_njXl86o`0000?o`Zk600?o0000
olVhbOo9^<T01Oo9^<T00ol0003ocLCBolg4dP05olg4dP03o`000?o8cMkob<gN00;ob<gN00?o0000
ok_8i?nkb>@00onkb>@01Ol0003oZ/7Zoj[1j_nZ`N[o000000?oUkO^00?o0000ohF]kon5[Nl00_n5
[Nl01Ol0003oMjC_ogNTkomgY>oo000000?oL:3^00Go0000og:Qk_mbXNkoLZ7^o`000003og^Wk`05
o`000?n9[nooRJo_ohV_kol000001?nI^>h00ol0003oZ<7[ojS1j`02ojS1j`03o`000?ndanSo0000
00;o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>h`02ol?>h`;o00000oo5f>L00ol0
003oooooooooo`0>ooooo`Co00002oooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003o
ooooooooo`0eooooo`05o`000?n6X^KoQZ;VohJRi_l000001?n9YNL4oi2[j0?o00000_nN]>P00ol0
003oYl3[ojO0j`02ojO0j`05o`000?n`c>ko/<c^ok3<k_l000001?nhf?03o`000003okkPl?l0003o
`^G`00Co00000_o9g^P00ol0003oa]cYolKLj@02olKLj@05o`000?noeN[o_mGZokoEj_l000000ond
bn/00ol0003oY[gZojJmjP02ojJmjP;oUJgW0_l000000onJ[>Co0000ohnMg@04ohnMg@03o`000?n6
TMOo000000?oTi?A00Go0000ohn=c?n?SLcoShg<o`000006oibAb0?o00001OnVUL<00ol0003o/9_2
ok2K`P04ok2K`P03o`000?njXl;o^Z?200Co^Z?200Co0000ol:/a?o2[<Co`Zc40ol00007olVhb@03
o`000?oAa<go000000GocLCB0_l00005olS=gP03o`000?nkb>Co^lST00;o^lST00?o0000oj[1j_nZ
`NX03ol00004og2PkP04o`000?mbXNkoLZ7^o`0000CoNjO_00Co0000ohV_kon9[noo00001?nI^>h0
0ol0003oZ<7[ojS1j`02ojS1j`03o`000?ndanSo000000;o]<OX00?o0000okg;iOnmbnD00_nmbnD0
0ol0003o`lkSo`000002o`000003ol?Fj?l0003oaMSW00;oaMSW00?o0000ooooooooool02oooool3
o`00013ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Oooool01Ol0
003oQZ;VohJRi_n6X^Ko000000CoRJGW1?n@ZnP3oi^ejPGo00000_nW`>/01_l0003o/<c^ok3<k_n`
c>ko0000okSHl0Wo00000_o8gNP01Ol0003obMkXolWNj?o9g^So000000Coa]cY00Go0000okoEj_no
eN[o_mGZo`000003okC;j`03o`000?nV_N[oY[gZ00;oY[gZ00Co0000oiF]ionE[NOoUJgW0_l00004
ohnMg@07o`000?n6TMOoQY7GohJAeol0003oTi?Ao`000005ohn=c003o`000?nLTLSoW97800?o0000
00?oVho6o`000?nVUL<01OnVUL<00ol0003o/9_2ok2K`P04ok2K`P03o`000?njXl;o^Z?200?o^Z?2
00?o0000ol:/a?o2[<@01?o2[<@01?l0003obkO7o`000?l00003olVhb@05o`000?oAa<godLC=om74
cOl000000oo=a=801?l0003odM3Hom7@f?l00004olS=gP04o`000?nkb>Co^lSTok_8i0Co00000_nZ
`N/4oiVdj`GoRZSY0on0X>L6o`0000?oLZ7^00Go0000og^WkomkYnooNjO_o`000003ohV_k`03o`00
0?nI^>koVKS^00;oVKS^00?o0000ojS1jonX`N/00_nX`N/00ol0003o]<OXo`000002okC7j004o`00
0?nmbnGo_L_Uokg;i@;o00001?o3e^P01Ol0003oaMSWolGHioo5f>Oo000000[ooooo0ol0000Coooo
o`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Gooooo00Go0000ohJRi_n6
X^KoQZ;Vo`000004ohVUi`CoT:_X1?nK]NX01?l0003oYl3/ojO0k?nW`>`<o`0000;oa=[Y00?o0000
olSMj?o8gNP00_o8gNP01Ol0003obMkXolWNj?o9g^So000000?oa]cY00?o0000okoEj_noeNX00_no
eNX01Ol0003o]<_[okC;jondbn_o000000?oY[gZ00?o0000oiF]ionE[NL00_nE[NL2ohFMh`;o0000
00?oSigMo`000?n6TML01?n6TML00ol0003oShg<ohn=c005ohn=c0;o00001OnKSlH00ol0003oYYG3
ojJE``04ojJE``03o`000?n`Vl;o/9_200?o/9_200?o0000okZS`_njXl800onjXl800ol0003o`Zc4
ol:/a003ol:/a003o`000?o;]lOobkO700;obkO700?o0000olVhbOl000001OoAa<d00ol0003ocLCB
o`000004om7@f004o`000?o8cMkob<gNolS=gPCo00000_nkcNP01Ol0003oZ/7[oj[1jonZ`N_o0000
00?oVKC[00?o0000ohZXjOn:Z>T00_n:Z>T01?l0003oP:3Woh2Pion0X>L4og^Li`Go00001?mkYnl0
1?l0003oRJo_ohV_kol00004oiVhkP03o`000?nX`N_oZ<7[00;oZ<7[00Oo0000okC7j?ndanSo0000
okC7j?l0003o_L_U00;o000000?o_M7Yo`000?o3e^P00oo3e^P01Ol0003oaMSWolGHioo5f>Oo0000
00Oooooo0ol0000Fooooo`03o`000?oooooooooo00Wooooo000Kooooo`;o0000=Oooool00ol0003o
QZ;VohJRiP02ohJRiP05o`000?n9YNOoRJGWohVUiol000001?n@ZnP01Ol0003oVkGZoi^ej_nK]N[o
000000CoYl3/1Ol00004okgCj`05o`000?o4f^Woa=[YolCJjOl000001?o8gNP01Ol0003obMkXolWN
j?o9g^So000000?oa]cY00Go0000okoEj_noeN[o_mGZo`000003okC;j`03o`000?nV_N[oY[gZ00;o
Y[gZ00?o0000oiF]ionE[NL00_nE[NL01?l0003oQIgSohFMhon5WN<2o`0000GoQY7G00?oP8SBo`00
0?n?SL`01?n?SL`2o`0000KoVho600?o0000ojJE`onVUL<01?nVUL<00ol0003o/9_2ok2K`P03ok2K
`P03o`000?njXl;o^Z?200?o^Z?200?o0000ol:/a?o2[<@00oo2[<@00ol0003obkO7ol^ga`03ol^g
a`;o00001_oAa<d00ol0003odM3Hom7@f003om7@f006o`000?o8cMko0000o`000?o9enCo00001?nk
cNP01Ol0003oZ/7[oj[1jonZ`N_o000000?oVKC[00?o0000ohZXjOn:Z>T00_n:Z>T01Ol0003oP:3W
oh2Pion0X>Oo000000CoNicW0ommWNL6o`0000?oRJo_00?o0000oiVhk_nI^>h00_nI^>h01Ol0003o
Z<7[ojS1jonX`N_o000000?o]<OX0ol00003okgAj@03o`000?o3e^So`mKX00;o`mKX00Go0000olGH
ioo5f>OoaMSWo`000004ooooo`?o00006Oooool00ol0003oooooooooo`09ooooo`006oooool00ol0
003oooooooooo`0dooooo`03o`000?n6X^KoQZ;V00;oQZ;V00Go0000ohVUion9YNOoRJGWo`000003
oi2[j003o`000?nK]N[oVkGZ00;oVkGZ00?o0000ojO0k?nW`>`00ol00003ok;:k003o`000?nmdn_o
_M?[00;o_M?[00Go0000olCJjOo4f^Woa=[Yo`000003olSMj003o`000?o9g^SobMkX00;obMkX00Go
0000olKLjOo6g>Woa]cYo`000003okoEjP05o`000?ndbn_o]<_[okC;jol000001?nV_NX00ol0003o
UJgWoiF]i`02oiF]i`04o`000?n5WN?oQIgSohFMh`;oMhoN00Go0000ohJAeon6TMOoQY7Go`000002
oh28dP05o`000?n?SLcoShg<ohn=c?l000000_n>RLX00ol0003oVho6oi^?aP03oi^?aP04o`000?nV
UL?oYYG3ojJE`a7o00001?o2[<@00ol0003obkO7ol^ga`03ol^ga`03o`000?oC`l_o000000?odLC=
00?o0000omOBdol000001_oAd=P01Ol0003obMOTolWGi?o9enCo000000Co^lgX00?o0000oj[1jonZ
`N/00_nZ`N/01?l0003oVKC[oiVdjol00004ohZXj@05o`000?n0X>OoP:3Woh2Piol000001?mkW>L0
1?l0003oOIgWogfMiommWNL4oh>Sj0Go00001?nI^>h00ol0003oZ<7[ojS1j`06o`000003ok?:jol0
003o_M7Y00;o_M7Y00?o0000ol?Fj?o3e^P00_o3e^P01?l0003oaMSWolGHioo5f>L5o`0001cooooo
00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01Ol0003oQZ;VohJR
i_n6X^Ko000000CoRJGW00Go0000oi2[j?n@ZnSoT:_Xo`000004oi^ejP?o00000_nW`>`01Ol0003o
//[/ok;:k?nbb^co000000Co_M?[00Go0000olCJjOo4f^Woa=[Yo`000003olSMj005o`000?o9g^So
bMkXolWNj?l000001?o6g>T01Ol0003o_mGZokoEj_noeN[o000000?o]<_[00Go0000ojJmj_nV_N[o
Y[gZo`000004oiF]i`03o`000?n5WN?oQIgS00;oQIgS00Ko0000ogN?g_mgSmko0000ohJAeol00004
oh28dP03o`000?n?SLco000000CoSXW:00?o0000oi^?a_nKSlH00_nKSlH4o`0000?oYYG400?o0000
ok2L`on`W<<00on`W<<00ol0003o^JC3okVT``02okVT``03o`000?o2[<Co`Zc400Co00001Oo;]lL0
1ol0003odl?;om?3booC`l_o0000om74cOl000000ooGd]<01ol0003odM3Hom7@f?oAd=So0000omCN
gol000000oo9en@00ol0003o^lgXok_=j002ok_=j003o`000?nZ`N_oZ/7[00;oZ/7[00Go0000oiVd
jonI]>_oVKC[o`000004ohZXj@04o`000?n0X>OoP:3Wo`0000CoNicW00Go0000ogfMiommWNOoOIgW
o`000004oh>Sj0?oSZ_Z2?l00002ojS1k004o`000?ncb^_o/l[[ok?:j`;o00000onmdNT00ol0003o
`mKXol?Fj002ol?Fj005o`000?o5f>OoaMSWolGHiol000008?ooool00ol0003oooooooooo`09oooo
o`006_ooool00ol0003oooooooooo`0eooooo`05o`000?n6X^KoQZ;VohJRi_l000001?n9YNL01_l0
003oT:_Xoi2[j?n@ZnSo0000oi^ejPCo00000onW`>`00ol0003o//[/ok;:k002ok;:k005o`000?nm
dn_o_M?[okgCjol000001?o4f^T01Ol0003ob=gXolSMj?o8gNSo000000?obMkX00Go0000olKLjOo6
g>Woa]cYo`000002okoEjPko000000?oUJgWo`000?n5WN<00on5WN<01?l0003oMhoNogN?g_mgSmh2
o`0000GoP8SB00?o0000ohj9b_n>RLX01?n>RLX01_l0003oVho6o`000?l0003oVho6o`0000GoYYG4
00?o0000ok2L`on`W<<00on`W<<00ol0003o^JC3okVT``02okVT``03o`000?o2[<Co`Zc400?o`Zc4
0_l00003ol^ga`03o`000?oC`l_odl?;00?odl?;00?o0000omOBdooGd]<00ooGd]<00ol0003odM3H
o`000002omCNg`03o`000?o9enCobMOT00;obMOT00Go0000ok_=j?nkcNSo^lgXo`000004oj[1j`05
o`000?nI]>_oVKC[oiVdjol000001?n:Z>T01?l0003oP:3Woh2Piol00004og^Li`05o`000?mmWNOo
OIgWogfMiol000001?n3XnP01?l0003oSZ_Zohj[j_n>ZnX5oiZfj`05o`000?nX`NcoZ<7/ojS1k?l0
00001?ncb^/01Ol0003o_M7YokgAjOnmdNWo000000Co`mKX00Go0000olGHioo5f>OoaMSWo`00000P
ooooo`03o`000?oooooooooo00Wooooo000Jooooo`?o0000=Oooool01Ol0003oQZ;VohJRi_n6X^Ko
000000CoRJGW00?o0000oi2[j?n@ZnP00ol00003oi^ejP05o`000?nW`>coYl3/ojO0k?l000001?nb
b^`01Ol0003o_M?[okgCjonmdn_o000000?oa=[Y00?o0000olSMj?o8gNP00_o8gNP01Ol0003obMkX
olWNj?o9g^So000000;oa]cY1?l00002ol7?i@Co]/SX1?nU_^/4oi2`k0?o00000_n5WN<00ol0003o
MhoNogN?gP02ogN?gP;oKHGJ0_l00003oh28dP03ogf5d?l0003oSXW:00CoSXW:0_l00004oi^?aP03
o`000?nVULCoYYG400?oYYG400Go0000ok2L`on`W<?o/9c3o`000005okVT``03o`000?o2[<Co`Zc4
00?o`Zc400Ko0000ol^gaol0003o0000ol^gaol00005om?3b`03o`000?oGd]?oem;C00Coem;C00Go
0000omCNgooDg]ooe=kOo`000004olWGi003o`000?nkcNSo000000Wo000000?oVKC[o`000?n:Z>T0
0on:Z>T01Ol0003oP:3Woh2Pion0X>Oo000000?oNicW00Go0000ogfMiommWNOoOIgWo`000004oh>S
j005o`000?n>Zn[oSZ_Zohj[j_l000001?nJ]^/01Ol0003oZ<7/ojS1k?nX`Nco000000Co/l[[0_l0
0002okgAj@03o`000?o3e^So`mKX00;o`mKX00Go0000olGHioo5f>OoaMSWo`00000Qooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000ohJRi_n6X^KoQZ;V
o`000004ohVUi`?o000000?oT:_Xo`000?nK]NX00onK]NX01Ol0003oYl3/ojO0k?nW`>co000000Co
//[/00Go0000okgCjonmdn_o_M?[o`000003olCJj@03o`000?o8gNSob=gX00;ob=gX00Co0000olWN
j?o9g^SobMkX0ol000000oo8dn;o0000ol7?i@03ol7?i@05o`000?nfb>So]/SXokK8j?l000000onU
_^/00ol0003oT;3/oi2`k002oi2`k0;oNIoZ00?o0000ohFMhol000001?mgSmh01ol0003oKHGJoff5
f_m]QM[o0000oh28d_l000000_mmQM001ol0003oSXW:ohj9b_n>RL[o0000ohj:bol000001?nKSlH0
0ol0003oYYG4ojJEa003ojJEa005o`000?n`W<?o/9c3ok2L`ol000001?niY<<00ol0003o`Zc4ol:/
a003ol:/a003o`000?o;]lOobkO700;obkO70_l00004om?3b`03o`000?oId]7o000000?oem;C00?o
0000om[Rfol000001?oDg]l00ol0003obMOTolWGi003o`0000;o^M;]00?o0000oj[2jonZ`^/00_nZ
`^/00ol0003oW;;Woibbi`05o`000003ohZXjOl0003oP:3W00;oP:3W00Go0000og^LiomkW>OoNicW
o`000003ogfMi`03o`000?n3XnSoPj?X00;oPj?X00Go0000ohj[j_n>Zn[oSZ_Zo`000004oiZfj`05
o`000?nX`NcoZ<7/ojS1k?l000001?ncb^/2o`0000;o_M7Y00Go0000ol?Fj?o3e^So`mKXo`000004
olGHi`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool00004oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0eooooo`06o`000?n6X^KoQZ;VohJRi_l0003oRJGW1?l00003oi2[j005o`000?nK]N[oVkGZoi^e
j_l000001?nW`>`01Ol0003o//[/ok;:k?nbb^co000000Co_M?[00Go0000olCJjOo4f^Woa=[Yo`00
0003olSMj004o`000?o9g^SobMkXolWNj0;o00001?o8dn800ol0003o`LoUol7?i@02ol7?i@05o`00
0?nfb>So]/SXokK8j?l000000onU_^/01Ol0003oT;3/oi2`k?n@/>co000000?oNIoZ0_l00002ogN?
gP03o`000?m]QM[oKHGJ00?oKHGJ00?o0000ogf5d?mmQM000_mmQM000ol0003oSXW:o`000003ohj:
b`05o`000?nKSlKoVho6oi^?a_l000000onVUL@:o`000003okVT`ol0003o`Zc400?o`Zc400?o0000
ol^gaoo;]lL00oo;]lL00ol0003od/?<o`000002om?3b`07o`000?oId]7ofM;AomWBdOl0003oem;C
o`000002om[Rf`03o`000?oDg]ooe=kO00;oe=kO0ol000000oo6hN_o0000okWBk@02okWBk@05o`00
0?nZ`^_oZ/;[oj[2jol000001?nL/^L01?l0003oTJKToi6Vi?nAY^@3o`0000;oP:3W00Go0000og^L
iomkW>OoNicWo`000004ogfMi`05o`000?n3XnSoPj?Xoh>Sj?l000000on>ZnX00ol0003oV[K[oiZf
j`02oiZfj`05o`000?nX`NcoZ<7/ojS1k?l000001?ncb^/01Ol0003o_M7Yo`000?nmdNWo000000?o
`mKX00?o0000olGHioo5f>L00_o5f>L00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00So
oooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Gooooo0_l000001?n6X^Ko0000o`000?l00002ohVUi`03o`000?n@ZnSoT:_X
00;oT:_X00Go0000oi^ej_nK]N[oVkGZo`000004ojO0k005o`000?nbb^co//[/ok;:k?l000001?nm
dn/01Ol0003oa=[YolCJjOo4f^Wo000000?ob=gX1?l000000oo;e>7o0000olSChP03olSChP03o`00
0?o1cnGo`LoU00;o`LoU00Go0000okK8j?nfb>So]/SXo`000003ojFnj`05o`000?n@/>coT;3/oi2`
k?l000000omiWnX2ofB?iP03o`000?mgSmko000000GoKHGJ00?oJ83Ho`000?mmQM000ommQM000ol0
003oSX[;ohj:b`03ohj:b`03o`000?nKSlKoVho600Co00000_nWV<H01Ol0003o/9k5ok2NaOn`W/Go
000000?o^JG51?l00002ol:/a003o`000?o;]lOobkO700;obkO700Oo0000om;3c?oB`lcod/?<o`00
0?oC`l_o000000CofM;A00?o0000om[RfooJh]/00_oJh]/00ol0003oe=kOomCNg`02o`0000;oa^7[
00Go0000okWBkOnid^go^M;]o`000004oj[2j`05o`000?nL/^OoW;;Woibbiol000001OnAY^@2ohVN
h@03o`000?n0X>Oo000000?oNicW00?o0000ogfMiommWNL00_mmWNL01Ol0003oPj?Xoh>Sj?n3XnSo
000000?oSZ_Z00?o0000oiZfjonJ]^/00_nJ]^/01Ol0003oZ<7/ojS1k?nX`Nco000000Co/l[[00?o
0000okgAjOnmdNT00_l00003ol?Fj003o`000?o5f>OoaMSW00;oaMSW00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`08ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool5o`0000?oRJGW00Go0000oi2[j?n@ZnSoT:_Xo`00
0004oi^ejP03o`000?nW`>coYl3/00;oYl3/00Go0000ok;:k?nbb^co//[/o`000003okgCj`03o`00
0?o4f^Woa=[Y00;oa=[Y00?o0000olSMj?l000000_l00004ol_Dh@03o`000?o8dn;ob=?R00;ob=?R
00?o0000ol7?iOo1cnD00_o1cnD01Ol0003o]/SXokK8j?nfb>So000000?oYKk[00?o0000oi2`k?n@
/>`00_n@/>`01?l0003oNIoZogVOj_l00003ofB?iP;o00001?m]QMX00ol0003oJ83Ho`000004ogf5
d003o`000?n>R/_oSX[;00;oSX[;00Go0000oi^?a_l0003oW9;9o`000004ojNHaP05o`000?n`W/Go
/9k5ok2NaOl000001?niYLD00ol0003o`Jk7ol6^a`03o`0000?obkO700?o0000om;3c?oB`l`00ooB
`l`01ol0003ofM;AomWBdOoId]7o0000omgSfOl000001?oJh]/3o`000005om3[j?l0003oa^7[olKQ
jol000000onid^d00ol0003oZ/;[oj[2j`02oj[2j`05o`000?nL/^OoW;;Woibbiol000001?nAY^@0
0ol0003oRIkQohVNh@02ohVNh@;o00000_mkW>L00ol0003oOIgWogfMi`02ogfMi`05o`000?n3XnSo
Pj?Xoh>Sj?l000000on>ZnX00ol0003oV[K[oiZfj`02oiZfj`05o`000?nX`NcoZ<7/ojS1k?l00000
1?ncb^/00ol0003o_M7YokgAj@02o`0000?o`mKX00?o0000olGHioo5f>L00_o5f>L00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Sooooo0003ooooo`03o`000?oooooooooo00gooooo00?o
MgMgoc8b<_ooool00oooool3o`0003?ooooo1?l00003og^Tk@?o000000?oRJGWo`000?n@ZnP00_n@
ZnP00ol0003oVkGZoi^ejP02oi^ejP03o`000?nW`>coYl3/00;oYl3/00Go0000ok;:k?nbb^co//[/
o`000003okgCj`03o`000?o4f^Woa=[Y00Co00000_o:e>400ol0003obmCQol_Dh@03ol_Dh@03o`00
0?o8dn;ob=?R00;ob=?R00Go0000ol7?iOo1cnGo`LoUo`000004okK8j005o`000?nU_^_oYKk[ojFn
jol000000on@/>`01Ol0003oNIoZogVOj_miWn[o000000;oI8oV0_mCP^82o`000003off5f_l0003o
J83H00;oJ83H00?o0000ogf5d?l000000_mmQM001?l0003oSX[;ohj:bon>R//2o`0000?oW9;900Go
0000ojNHa_nWV<KoYiS6o`000003ok2Na@03o`000?niYLGo^JG500;o^JG500Ko0000ol6^aoo1[/Oo
`Jk7o`000?o9^<X2o`000003ol^gaol0003od/?<00?od/?<0_l00002omWBd@04o`000?oMhmWogN?I
o`0000?of^;K0_l00002om3[j005o`000?o6hN_oa^7[olKQjol000000onid^d01Ol0003oZ/;[oj[2
jonZ`^_o000000CoW;;W00?o0000oi6Vi?nAY^@00_nAY^@00ol0003oRIkQohVNh@02ohVNh@;oQY[O
00?o0000og^Liol000001?mmWNL01Ol0003oPj?Xoh>Sj?n3XnSo000000CoSZ_Z00Go0000oiZfjonJ
]^_oV[K[o`000004ojS1k005o`000?ncb^_o/l[[ok?:jol000000onmdNT01Ol0003o`mKXol?Fj?o3
e^So000000CoaMSW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0aooooo`;o00001?ooool3og^Tk@?oP:O]1?l000000on@ZnSo0000oi^ejP03oi^ejP05o`000?nW
`>coYl3/ojO0k?l000001?nbb^`00ol0003o_M?[o`000004o`0000;oa];S00?o0000ol[DhOo:e>40
0_o:e>400ol0003obmCQol_Dh@02ol_Dh@03o`000?o8dn;ob=?R00;ob=?R00?o0000ol7?iOo1cnD0
0_o1cnD00ol0003o]/SXo`00000<o`000005ogVOj_l0003oI8oVofB?i_l000000omCP^800om]QM[o
0000ofR0f003ofR0f003o`000?mmQM3oOHG@00;oOHG@00Go0000ohj:bol0003oT8k=o`000004oibB
b@05o`000?nWV<KoYiS6ojNHa_l000000_n`W/D01Ol0003o^JG5okVUaOniYLGo000000?o`Jk700?o
0000olVhb_o9^<X00_o9^<X2o`0000?od/?<00?o0000omWBd_oId]800_l00003omgSf@Co000000Go
eo7So`000?o@jnSod>_Xo`000002olKQj`05o`000?nid^go^M;]okWBkOl000001?nZ`^/01Ol0003o
W;;WoibbionL/^Oo000000CoTJKT00?o0000ohVNhOn9W^400_n9W^400ol0003oQY[OohJJg`02ohJJ
g`Co000000?oOIgWo`000?n3XnP00_n3XnP00ol0003oSZ_Zohj[jP02ohj[jP05o`000?nJ]^_oV[K[
oiZfjol000001?nX`N`01Ol0003o/l[[ok?:joncb^_o000000?o_M7Y0_l00002ol?Fj003o`000?o5
f>OoaMSW00;oaMSW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool3
o`0000Kooooo00Co0000og^TkOmkY>goNjC]0on0Ynd3ohZ^k@Go000000?oVkGZo`000?nW`>`00_nW
`>`00ol0003o//[/ok;:k004o`0000;o_lkV00?o0000olKBhoo6d^<00_o6d^<00ol0003ob]CQol[D
h@02ol[Dh@03o`000?o;e>7obmCQ00;obmCQ00?o0000olSCh_o8dn800_o8dn801?l0003o`LoUol7?
iOo1cnD3o`0000;o]/GU00Go0000ojFnjonU_^_oYKk[o`000003ohfcl003o`000?m]Xo7oKJ?a00Co
000000?oI8oVo`000?mCP^800_mCP^82o`0000?oJ83H00?oJ87Ho`000?mmQM000ommQM001Ol0003o
T8k=oi2>cOn@S/go000000?oW9;900Ko0000ojNHa_nWV<KoYiS6o`000?n`W/D4o`000003okVUaOl0
003o`Jk700;o`Jk700?o0000olVhb_o9^<X00_o9^<X01Ol0003od<C>o`000?oB`lco000000?ofM;B
00?o0000omgSfOoMhmT00_oMhmT01Ol0003oeo7SomOahooGlN?o000000?od>_X2_l00002oj[2j`05
o`000?nL/^OoW;;Woibbiol000001?nAY^@00ol0003oRIkQohVNh@02ohVNh@03o`000?n6V]ooQY[O
00;oQY[O1?n7Vn03o`0000;oPj?X00?o0000ohj[j_n>ZnX00_n>ZnX01Ol0003oV[K[oiZfjonJ]^_o
000000CoZ<7/00Go0000ok?:joncb^_o/l[[o`000003okgAj@05o`000?o3e^So0000ol?Fj?l00000
0_o5f>L3o`0002;ooooo00?o0000ooooooooool01oooool00004oiRHV?ooooooV9RHogMgM`cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`?o00002Oooool01?l0003oNjC]
og^TkOmkY>d4oh2Wk@?oRZk]1?nH]nd8o`0000;o]<SY1Onoc^H00ol0003oa];SolKBh`02olKBh`05
o`000?o:e>7ob]CQol[DhOl000001?o;e>400ol0003ob=?RolSChP03olSChP?o000000?o`LSPo`00
0?nfaND00onfaND01Ol0003oYKk[ojFnjonU_^_o000000?oSK?`00Co0000offSlOm]Xo7o00000_m=
Snd3o`0000;oDh;R0_m;Nml00ol0003oJ83Ho`000002ofR1f006o`000?mmQM3oOHG@ogf5d?n1R]?o
00000on@S/d00ol0003oW9;9oibBb@06o`000004ok2Sbol0003o^:[;okRZb`Co000000?o`Jk7o`00
0?o9^<X00_o9^<X01Ol0003od<C>om34c_o@a<ko000000;ofM;B00?o0000omgSfOl000000_oMhmT0
0ol0003ofOCQo`000003omOah`Go00000_nnj?801Ol0003o]=GaokCElOndeO7o000000;oZL;/1?l0
0002oibbi`03o`000?nAY^CoTJKT00;oTJKT00Go0000ohVNhOn9W^7oRIkQo`000004ohJJg`03o`00
0?n7Vn3oQi_P00?oQi_P0_n<X>800ol0003oPj?Xo`000004ohj[jP05o`000?nJ]^_oV[K[oiZfjol0
00001?nX`N`01Ol0003o/l[[ok?:joncb^_o000000?o_M7Y00?o0000ol?Fj?l000001?l00002ol;P
kP03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00004oc8b<_l0003o<S8bonk^
kPcooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo0ol0000=ooooo`04o`000?mkY>goNjC]
o`0000?oP:O]00Co0000ohZ^kOn:[^goRZk]1?nH]nd4ojK0k0Ko]<SY1?noc^H00ol0003oa];SolKB
h`02olKBh`03o`000?o:e>7ob]CQ00;ob]CQ00Go0000ol_DhOo;e>7obmCQo`000004olSChP;o0000
1?o1b>000ol0003o]/GUokK5i@02okK5i@05o`000?nU_^_oYKk[ojFnjol000000on=/o001?l0003o
KJ?aoffSlOl00002odf?k@05o`000?lbO^Oo0000oe>2h_l000000om;Nml2o`0000;oJ87H00?o0000
ogf5d?l000000_n1R]<02?l0003oT8k=oi2>cOl0003oW9;9o`000?nNVLoo00000_nWW/`01?l0003o
/:?;ok2Sbol00003okRZb`03o`000?no/Lgo_k7=00?o000000?obKS:o`000?o@a<h00_o@a<h2o`00
0003omWBd_l0003ogN?I00;ogN?I0_l00002omWdh@03o`000?oGlN?o000000;o00000_o4mNh01?l0
003o_^SbokkXl_l00003okCEl@03o`000?nY`^coZL;/00;oZL;/00?o0000oinaiOnO/ND00ol00003
oi6Vi003o`000?n9W^7oRIkQ00;oRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh002
ohNKh003o`000?n<X>;oS:3R00;oS:3R1?l000000on>Zn[o0000oiZfj`02oiZfj`03o`000?nX`Nco
Z<7/00;oZ<7/00Ko0000ok?:joncb^_o/l[[o`000?nmdNT4o`000003okoMk_l0003o000000?o`^3^
00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`006Oooool2o`0002Kooooo0ol0
000@ooooo`05o`000?mkY>goNjC]og^TkOl000000_n0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?o
V;O]00?o0000ojK0k?nV`>`00_nV`>`5okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<00ol0
003ob]CQol[Dh@02ol[Dh@03o`000?o;e>7obmCQ00;obmCQ1?l000000oo7b]co0000ol78h004ol78
h003o`000?nfaNGo]/GU00;o]/GU00Co0000ojFnjonU_^_o00000on=/o001Ol0003oKJ?aoffSlOm]
Xo7o000000;oCHo]00Go0000oc9niolbO^OoDh;Ro`000002od]kg`;oC7cO00?o0000ofR1f?mXPMP0
0_l00003oh6:d`04o`000?n@S/go0000o`0000?oWYW?00?o0000ojNNc?l000000_n`Xl/01?l0003o
^:[;okRZbol00003oknac@04o`000?o5^]3oaK[@o`0000?od<C>00Co0000omKAe?oFdMCo00001?oM
hmT00ol0003ofOCQomWdh@03o`000005olGkiol0003oa?G^olCek_l000000_nnj?801Ol0003o]=Ga
okCElOndeO7o000000CoZL;/00?o0000oinaiOnO/ND00_nO/ND01_l0003oUjGOo`000?l0003oTJKT
o`0000CoRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh002ohNKh003o`000?n<X>;o
S:3R00;oS:3R00Co0000oi>YiOnCZNGoTjWU1?l000000onJ]^_o0000ojS1k003ojS1k003o`000?nc
b^_o000000?o00000_njenh00ol0003o_mg^okoMkP02o`0000?o`^3^00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Sooooo`?o00004oooool0
1Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go00001?nH]nd01Ol0003oY/3/
ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H00ol0003oa];SolKBh`02olKBh`05
o`000?o:e>7ob]CQol[DhOl000000oo;e>42o`0000Goal[L00?o0000ol78h?o1b>000_o1b>000ol0
003o]/GUokK5i@02okK5i@05o`000?nU_^_oYKk[ojFnjol000000on=/o001Ol0003oKJ?aoffSlOm]
Xo7o000000;oCHo]00?o0000oc9niolbO^L00_l000001?m;Nmoo0000odalgom<O=l2ofR1f0;oKhOJ
00Oo0000oh6:don1R]?oPH[Co`000?nDU]?o000000?oWYW?00Ko0000ojNNc?nWW/co0000ok2Sbol0
0002okRZb`04o`000?no/Lgo_k7=o`0000;oaK[@00Go0000ol_4e?l0003od<C>o`000002omKAe008
omWQg?l0003ogN?IomgSfOl0003ofOCQo`000?oIm>42o`0000;oaO_W00Co0000olCek_o4mNko0000
0onnj?801?l0003o]=GaokCElOl00004ojW2k003o`000?nO/NGoWk7U00;oWk7U00?o0000oiNUgonG
YMl00_nGYMl2o`0000?oRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh003ohNKh005
o`000?n<X>;oS:3RohbPh_l000001OnCZND00ol0003oWKCXoifdj008o`0000;o//g^00Co0000ok[G
k_njenko00000onogNh01Ol0003o`^3^o`000?o2h>ko000002Cooooo00?o0000ooooooooool01ooo
ool001Sooooo00?o0000ooooooooool08?ooool3o`0001Oooooo00Co0000og^TkOmkY>go00000on0
Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00Go0000ojK0k?nV`>coY/3/o`000005okC8j@05
o`000?noc^Ko_lkVoko>i_l000001?o6d^<00ol0003ob]CQol[Dh@02ol[Dh@?o000000?ob/_Jo`00
0?o7b]`01Oo7b]`00ol0003o`LSPol78h002ol78h003o`000?nfaNGo]/GU00;o]/GU00?o0000ojFn
jonU_^/03?l00002oc9ni`05o`000?lTMN?o0000od]kgol000000_m<O=l2o`0000;oKhOJ00Co0000
oh6:dol0003o00000_nDU]<01Ol0003oWYW?oijIcol0003oYik<00So000000Co_k7=o`000?o5^]3o
00000oo;a=@00ol0003oe]7Do`000003omWQg0;o000000SofOCQo`000?l0003o0000olCmh_l0003o
aO_Wo`0000;oa?G^00Go0000okkXl_nnj?;o_^Sbo`000002okCEl@03o`000?nY`^coZL;/00;oZL;/
00?o0000oinaiOnO/ND00_nO/ND00ol0003oUjGOoiNUg`03oiNUg`06o`000?nBWM_o0000o`000?n9
W^7o00001?n6V]l00ol0003oQi_PohNKh002ohNKh003o`000?n<X>;oS:3R00;oS:3R00?o0000oi>Y
iOnCZND00_nCZND00ol0003oWKCXoifdj002oifdj003o`000?nW`NcoYl7/00;oYl7/00Co0000ok;=
k_nbcNko00000onjenh02Ol0003o_mg^okoMk_nogNko0000ol;Pk_l0003o`^3^o`00000Tooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Jooooo`05o`00
0?mkY>goNjC]og^TkOl000000_n0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00?o0000ojK0
k?nV`>`00_nV`>`00ol0003o]<SYokC8j@02okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<0
1?l0003ob]CQol[DhOo:e>42o`0000Cob/_J00?o0000olO:g?o7b]`00oo7b]`00ol0003o`LSPol78
h002ol78h003o`000?nfaNGo]/GU00;o]/GU0ol00003ojFok0CoR[Sd1?mRZ?L00olcTO3o0000o`00
0002o`0000;o97GS0_l000001?m<O=oo0000oeN5hol00002ofn7fP;o000000KoR9CHo`000?nDU]?o
U9KCo`000?nNVLl2o`000006ojRXe_l0003o[jcEo`000?nd/MGo00000_nj]mH00ol0003oaK[@o`00
0003ol_4e0;ocm3J00?o0000omWQg?oIhM`00_oIhM`01?l0003ofOCQomWdhOl00002olCmhP03o`00
0?o5nnOoaO_W00co00000_nY`^`00ol0003oWk7Uoinai@02oinai@03o`000?nGYMooUjGO00?oUjGO
00?o0000oi:MfonBWM/00_nBWM/2o`0000CoQY[O00?o0000ohNKh?n7Vn000_n7Vn000ol0003oS:3R
ohbPhP02ohbPhP03o`000?nCZNGoTjWU00;oTjWU00Go0000oifdj?nM]>SoWKCXo`000004ojO1k005
o`000?nbcNko//g^ok;=k_l000000_njenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Joooo
o`?o00007Oooool01Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go00001?nH
]nd01Ol0003oY/3/ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H01Ol0003oa];S
olKBhoo6d^?o000000;ob]CQ00?o0000olW:fol000001Oo:bmX00ol0003oal[LolO:g003olO:g003
o`000?o1b>3o`LSP00;o`LSP00Co0000okK5iOl0003o00000onf`N<4ojFok0;o00000_n:^?@01ol0
003oHZSgof:XmomRZ?Oo0000oc>Al?l;NN801?l000001?lVM^?o0000odalgol00002oeN5h`07ofn7
f_l0003oNY?Oo`000?n8U=So0000oiBFd`02o`00000<oj:Uf?l0003oZ:SFo`000?n_[=Go0000okBa
eOl0003o^[OFo`000?nn_MWo00000_o;a=@01?l0003ocm3Jolo@f_oAg>44o`000004omK`i?l0003o
0000o`0000;oa?gR1Ol00002ok3[n0;o00000_n^eoD00ol0003oZ<;/ojS2k002ojS2k0?o00000onO
/ND00ol0003oUjGOoiNUg`03oiNUg`03o`000?nBWM_oTYgK00?oTYgK00?o0000oi2JfOl000000ol0
0005ohNKh005o`000?n<X>;oS:3RohbPh_l000001OnCZND01Ol0003oWKCXoifdj?nM]>So000000Co
Yl7/00Co0000ok;=k_nbcNko00000onjenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^0_l0000T
ooooo`03o`000?oooooooooo00Oooooo000Hooooo`;o00006?ooool3o`00027ooooo00Co0000og^T
kOmkY>go00000on0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00Go0000ojK0k?nV`>coY/3/
o`000005okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<2o`0000?obL[K00?o0000ol[;f_o:
bmX00oo:bmX00ol0003oal[LolO:g002olO:g003o`000?o1b>3o`LSP00;o`LSP0_l00006okK1h`03
o`000?nU_ncoYKo/00;oYKo/00Go0000ohZhm?n:^?CoR[Sdo`000002of:Xm`03o`000?lcTO3o<i7`
00;o2gWR0_l00002obIfh`;o00000_mGQN<2o`000003ogZCgon8U=SoR9CH00;o000000GoVZ?Ko`00
0?nRYMSo0000ojRXeP03o`000004okZge_l0003o_[gIo`0000;o`/CL00?o0000olo@f_l000000_oA
g>401?l0003oe_3TomK`i?oFl>@:o`0000;o/>_h00?o0000ojkGmOn^eoD00_l00004ojS2k007o`00
0?nR/N;oX[7Roj:ah_l0003oWk7Uo`000005oiNUg`03o`000?nBWM_oTYgK00?oTYgK00?o0000oi2J
fOn@V]T00on@V]T2o`0000?oQi_P00?o0000ohbPh_n<X>800_n<X>800ol0003oTjWUoi>Yi@02oi>Y
i@03o`000?nM]>SoWKCX00;oWKCX00Go0000ojO1k?nW`NcoYl7/o`000003ok;=kP05o`000?njenko
^]O^ok[Gk_l000000_nogNh01Ol0003o`^3^ol;Pk_o2h>ko000000;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`06ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o00009?oo
ool01Ol0003oNjC]og^TkOmkY>go000000;oP:O]00Go0000ohZ^kOn:[^goRZk]o`000003oiRgk@03
o`000?nV`>coY/3/00;oY/3/00?o0000okC8jOndb>T00_ndb>T01Ol0003o_lkVoko>i_noc^Ko0000
00?oa];S0_l00005olW:f`03o`000?o:bm[ob/_J00?ob/_J00?o0000olO:g?o7b]`00_o7b]`01?l0
003o`LSPo`000?l00003oko2g0Ko]/7S00?o0000ojFok?nU_n`00_nU_n`00ol0003oR[SdohZhm008
o`000003o`]ih_l0JmSo000000;o000000Oo>8;Xo`000?mGQN?o0000ofVCiol0003oNY?O00;o0000
00GoTZ;Po`000?l0003o0000oj:Uf005o`000004okjmfOl0003o`/CLol;4g0;oa<gQ00So0000om7L
hOl0003oc^WYo`000?oFl>Co0000omK`i0Co000000CoWOCOo`000?nYmNoo00000_n`joP2o`0000;o
[]Oe00?o0000ojS2k?nX`^`00onX`^`00ol0003oX[7Roj:ahP02oj:ahP?o00001OnGYMl00ol0003o
TYgKoi:Mf`02oi:Mf`03o`000?n@V]WoT9[I00CoT9[I00?o0000oi6Kf_l000000_n7Vn000ol0003o
S:3RohbPhP02ohbPhP03o`000?nCZNGoTjWU00;oTjWU00Go0000oifdj?nM]>SoWKCXo`000004ojO1
k005o`000?nbcNko//g^ok;=k_l000000_njenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^00Co
0000oooooooooooo00009?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003ooooooooo
o`0Booooo`?o00009oooool01Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go
00001?nH]nd01Ol0003oY/3/ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H3o`00
0003olK9gOl0003obL[K00CobL[K00?o0000ol[;f_o:bmX00oo:bmX00ol0003oal[LolO:g003olO:
g003o`000?no`]co_l;L00Co_l;L00?o0000okK1honf`N<00onf`N<01?l0003oYKo/ojFok?nU_n`3
o`0000?oRKgh00Co0000oeZ`nomJ/?_o00000_lMTnX00ol0LLko0000o`000002o`0000;o>8;X0ol0
00000omYTnOo0000o`00000<o`0000;oa<gQ00?o0000olCEi_l000000oo>jNT2o`000004olGjjOl0
003o0000oiCad`[o000000?o[]Oeo`000?nX`^`00onX`^`2o`0000CoX[7R00Go0000oifUfonMYM_o
WJGKo`000003oiNUg`03o`000?nBWM_oTYgK00;oTYgK00?o0000oi2JfOn@V]T01?n@V]T01ol0003o
TI_Joi6Kf_nAVm[o0000ohNKh?l000000on<X>800ol0003oTjWUoi>Yi@02oi>Yi@03o`000?nM]>So
WKCX00;oWKCX00Go0000ojO1k?nW`NcoYl7/o`000003ok;=kP05o`000?njenko^]O^ok[Gk_l00000
0onogNh01Ol0003o`^3^ol;Pk_o2h>ko000000?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`06ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000:oooool01?l0003oNjC]
og^TkOl00003oh2Wk@05o`000?n:[^goRZk]ohZ^kOl000000onH]nd01Ol0003oY/3/ojK0k?nV`>co
000000Go]<SY00?o0000oko>i_l000000_l00004olK9g@03o`000?o9b]_obL[K00?obL[K00?o0000
ol[;f_o:bmX00oo:bmX01Ol0003oal[LolO:g?o7b]co000000;oa<7G00?o0000oko2g?no`]`00ono
`]`2o`0000Co]/7S00?o0000ojFok?l000000onU_n`00ol0003oRKghohVmn002ohVmn0;o00000_mJ
/?/01Ol0003o7I?Zo`1ac_l0003o06gI00?o00000_mEUNl5o`000003ohZSiOl0003o000000Oo0000
0_o4eNH00ol0003o`Mc]o`00000?o`0000?oYmOh0ol00003ojS2k003o`000?nR/N;oX[7R00;oX[7R
0_l00005oifUf`03o`000?nGYMoo000000CoTYgK00?o0000oi2JfOn@V]T01?n@V]T00ol0003oTI_J
oi6KfP03oi6KfP;o00000on<X>800ol0003oTjWUoi>Yi@02oi>Yi@05o`000?nM]>SoWKCXoifdj?l0
00001?nW`N`01Ol0003o//g^ok;=k_nbcNko000000;o^]O^00Go0000okoMk_nogNko_mg^o`000003
ol;PkP03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06
ooooo`005oooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool3o`000005og^TkOl0003oP:O]
oh2WkOl000000on:[^d01Ol0003oV;O]oiRgkOnH]ngo000000CoY/3/00?o0000okC8jOndb>T01?l0
0002oko8h@03o`000?o6bMgoa/WM00?oa/WM00?o0000olW:foo9b]/00oo9b]/00ol0003ob/_Jol[;
fP03ol[;fP03o`000?o7b]co000000Coa<7G00?o0000oko2g?no`]`01?no`]`01?l0003o]/7SokK1
honf`N<2o`0000KoYKo/0ol00002ohVmn0;o00000_mJ/?/5o`000003oa=niOl0003o000000;o0000
0omhZO8:o`0000?o`Mc]00?o0000ol;bl?o2l_002ol00004ojOGn0;o00000onX`^`00ol0003oZ<;/
o`000004oj:ahP03o`000?nMYM_oWJGK00GoWJGK0ol00003oi:Mf`03o`000?n@V]WoT9[I00CoT9[I
00?o0000oi6Kf_nAVmX00onAVmX00ol0003oTioLoi>Og002o`000003ohbPh_l0003oTjWU00;oTjWU
00?o0000oifdj?nM]>P00_nM]>P00ol0003oYl7/ojO1k002ojO1k004o`000?nbcNko//g^o`0000?o
^]O^00Go0000okoMk_nogNko_mg^o`000003ol;PkP03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`06ooooo`005oooool2o`0000[ooooo0ol0000aooooo`03
o`000?maZ??oLJSc00Co000000GoP:O]o`000?n:[^goRZk]o`000004oiRgk@03o`000?nV`>co0000
00Co00000_ndaNH00ol0003o_lSQoko8h@02oko8h@03o`000?o6bMgoa/WM00?oa/WM00?o0000olW:
foo9b]/00oo9b]/00ol0003ob/_Jol[;fP02ol[;fP;o00001_o4`ML2o`0000Go_l;L00?o0000okK1
hol000000ond_^42o`0000KoYKo/0_l00002ohVmn003o`000?mH^_coF;[l00;oF;[l4Ol000000onW
cOCo0000o`000004o`000003oj_dlol0003o000000Oo00001?nWeoP3o`0000GoZ<;/0_l00003oj:a
hP;o00001_nMYM/2o`0000?oVYkF00?o0000oi:Mfol000001_n@V]T00ol0003oTI_Joi6KfP03oi6K
fP03o`000?nCWmcoTioL00?oTioL0_l00003oi>Yi@05o`000?nM]>SoWKCXoifdj?l000001?nW`N`0
1Ol0003o//g^ok;=k_nbcNko000000;o^]O^00Go0000okoMk_nogNko_mg^o`000003ol;PkP03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`005ooo
ool00ol0003oooooooooo`06ooooo`?o0000=Oooool01?l0003oLJScog6Xlol00002ogN[l`_o0000
0_nV`>`00ol0003o]<GVokC5iP03okC5iP03o`000?nob>7o_lSQ00;o_lSQ00?o0000olK9gOo6bMd0
0oo6bMd00ol0003obL[KolW:f`02olW:f`05o`000?o:bm[ob/_Jol[;f_l000000oo6`MD00ol0003o
a<7GolC1e`04olC1e`03o`000?no`]co_l;L00?o_l;L00?o0000okBnhOnd_^401Ond_^42o`0000Go
YKo/00?o0000oh_4n_n;a?X00_n;a?X3o`0000?oF;[l00Co0000o`1ie?l0NMCo;Ic`0ol00002ofbg
o0Go00000_nOho`;o`0000?oW]Ck00Co0000ojOGn?l0003o00001OnX`^`3o`0000;oY[7Q00?o0000
oj:ah_l000001onMYM/00ol0003oVYkFoiZNeP03oiZNeP?o00001On@V]T00ol0003oTI_Joi6KfP03
oi6KfP03o`000?nCWmcoTioL00CoTioL00Ko0000oiVXh?l0003o0000oi>YiOl00003oifdj003o`00
0?nW`NcoYl7/00;oYl7/00Co0000ok;=k_nbcNko00000onjenh01Ol0003o_mg^okoMk_nogNko0000
00?o`^3^00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0000iooooo`04o`000?maZ??oLJSco`00
00;oMj_c00Go0000ohFal_n5/O;oQK7bo`000003oiJil003o`000?nV`>coY/3/00;oY/3/00?o0000
okC5i_ndaNH00ondaNH00ol0003o_lSQoko8h@02oko8h@03o`000?o6bMgoa/WM00;oa/WM00?o0000
olW:foo9b]/00oo9b]/00ol0003ob/_Jo`000005olK1e@03o`000?o4`MOoa<7G00Coa<7G00Go0000
oko2g?no`]co_l;Lo`000002okbkf@;o00001_nd_^43o`000003ojFok?l0003oYL3]00;oYL3]0ol0
0004oh_4nP;o00000_mNaO/00om1003o0000o`000003o`000003og7:ool0003o000000[o00001onN
e?/3o`0000GoZ<;/0_l00005ojJah@;o00001_nMYM/2o`0000GoVYkF00Go0000oiVKe?nIVmCoVI_D
o`000003oi2Jf@03o`000?nAVm[oTI_J00?oTI_J00?o0000oi>Og?nCWm`01?nCWm`00ol0003oVJSP
oiVXh002oiVXh0?o00000_nM]>P01Ol0003oYl7/ojO1k?nW`Nco000000?o//g^00Go0000ok[Gk_nj
enko^]O^o`000003okoMkPCo00002_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Gooooo000Fooooo`04o`000?ooooooooooooooo`?o0000?Oooool01?l0003oLJScog6Xlol00002
ogN[l`05o`000?n5/O;oQK7bohFal_l000000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?nd
aNKo]<GV00?o]<GV00?o0000oko8hOnob>400_nob>400ol0003oa/WMolK9g@02olK9g@03o`000?o9
b]_obL[K00;obL[K0_l00007olK1e@;o00001Oo4`ML00ol0003o_l;Lo`000005okbkf@?o00001_nd
_^400ol0003oYL3]ojG0k@05ojG0k@?o00000_n;a?X00ol0003oSl[loho:o003oho:o0;o000000?o
:JkRo`000?l000001Ol00004oiK@o004o`000?nNe?_oW]CkoikDn`Go00000onW`^d00ol0003oZ<;/
o`000002o`0000CoY[7Q0ol00002ojBVf004o`000?nMYM_oWJGKoifUf`;o00001OnJW]H2o`0000Go
VI_D00?o0000oi2JfOl000001OnAVmX00ol0003oTioLoi>Og004oi>Og003o`000?nIZ>3oVJSP00;o
VJSP00Co0000oinci_nO/nKoWk?V1?l00002ojO1k004o`000?nbcNko//g^ok;=kPWo000000?o^^Kd
o`000?ooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Foooo
o`Co0000@Oooool01?l0003oLJScog6Xlol00002ogN[l`05o`000?n5/O;oQK7bohFal_l000000onF
^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo]<GV00;o]<GV00?o0000oko8hOnob>400_no
b>400ol0003oa/WMolK9g@03olK9g@04o`000?o9b]_o0000o`0000?oa/7F00?o0000olK1eOo6`MD0
1Oo6`MD00ol0003oa<7GolC1e`03olC1e`03o`000?nl^mWo_;_I00Oo_;_I0_l00004okBnh@03o`00
0?nb^]oo/[[O00Co00001?nU`>d2o`0000GoSl[l00?o0000oho:o?n?b_`00_n?b_`00ol0003oU]3l
oiK@o003oiK@o0So00001_nW`^d4o`0000GoY[7Q0_l00006ojBVf003o`000?nMYM_o000000KoVYkF
00?o0000oiVKe?nIVm@01OnIVm@2o`0000GoTI_J00?o0000oi>Og?nCWm`01?nCWm`00ol0003oVJSP
oiVXh002oiVXh003o`000?nO/nKoWk?V00?oWk?V00?o0000ojO1k?nW`N`01ol00002okGKl`04o`00
0?nhhoCo^>?do`0000;o^^Kd00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Gooooo000Fooooo`?o0000@oooool01?l0003oLJScog6Xlol00002ogN[l`05
o`000?n5/O;oQK7bohFal_l000000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo]<GV
00;o]<GV00?o0000oko8hOnob>400_nob>400ol0003oa/WMolK9g@03olK9g@03o`000?o6`MKoa/7F
00Coa/7F0_l00006olK1e@05o`000?o4`MOoa<7GolC1eol000000_o0^]<3o`0000Oo_;_I0_l00000
0ond_^7o0000ok:jg`06ok:jg`?o00000_nU`>d00ol0003oY/7]ojK1k@04ojK1k@[o00001OnW`Nd0
1?l0003oYl;]ojO2kOnW`^d5o`0000CoZK?O00?o0000ojJahOl000000_l00008ojBVf0;o00001_nJ
W]H00ol0003oVI_DoiVKe005oiVKe004o`000?nIW=GoVIcEo`0000?oTI_J00?o0000oi>Og?nCWm`0
1?nCWm`00ol0003oVJSPoiVXh002oiVXh003o`000?nO/nKoWk?V00?oWk?V00Go0000ojO1k?nW`Nco
Yl7/o`000004ojo?l@04o`000?nefo?o]M_co`0000;o^>?d00Co0000ok[Vm?nji_Co00003oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000<ooooo`Co000000?o410@oooo
ooooool01Oooool00ol0003oooooooooo`12ooooo`04o`000?maZ??oLJSco`0000;oMj_c00Go0000
ohFal_n5/O;oQK7bo`000003oiJil003o`000?nV`>coY/3/00;oY/3/00?o0000okC5i_ndaNH00_nd
aNH00ol0003o_lSQoko8h@02oko8h@05o`000?o6bMgoa/WMolK9gOl000000_o3`]P00ol0003oa/7F
olK1eP04olK1eP;o00001Oo6`MD00ol0003oa<7Go`000006ol2jd`;o00001onl^mT00ol0003o/[[O
ok:jg`09ok:jg`;o00001OnV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nW`NgoYl7]00?oYl7]
2Ol00008ojVcg`?o00002OnTY]P2o`0000;oXZ3C00Co0000oiZNe_nJW]KoVYkF0_l00006oiVKe0;o
00001?nIW=D00ol0003oTI_Jo`000006oi>Og003o`000?nIZ>3oVJSP00;oVJSP00?o0000oinci_nO
/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@0
1?l0003o^^Kdok[Vm?l0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`05o`000?maZ??o
LJScog6Xlol000000_mgZo<01Ol0003oQK7bohFal_n5/O;o000000?oU[W`00Go0000ojK0k?nV`>co
Y/3/o`000004okC5iP03o`000?nob>7o_lSQ00?o_lSQ00?o0000olK9gOl000001?o3`]P2o`0000Ko
a/7F00?o0000olK1eOo6`MD00oo6`MD00ol0003o`;[Col2jd`07ol2jd`;o00001Onl^mT00ol0003o
^;KFokRfeP04o`0000Ko/[[O00?o0000ok2ggon`]ml01?n`]ml;o`0000Ko[KGO00?o0000ojVcgonY
/ml00onY/ml5o`0000;oZJWF00?o0000ojBVf?nTY]P01?nTY]P3o`0000GoXZ3C00?o0000oiZNe_l0
00001_nIVm@2o`0000KoVIcE0ol00005oi>Og003o`000?nIZ>3oVJSP00;oVJSP00?o0000oinci_nO
/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@0
1?l0003o^^Kdok[Vm?l0000Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`11ooooo`05o`000?maZ??o
LJScog6Xlol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`000?nV`>coY/3/00;oY/3/
00?o0000okC5i_ndaNH00_ndaNH00ol0003o_lSQoko8h@02oko8h@;o00001oo3`]P00ol0003oa/7F
olK1eP04olK1eP;o00000oo6`MD00ol0003o`[WAo`000002o`0000Oo`;[C0ol000000onl^mWo0000
okRfeP06okRfePCo000000?o/[[Oo`000?n`]ml02on`]ml00ol0003o[KGOojfeg`09ojfeg`03o`00
0?nY/moo000000?o00002?nYZMH01?l0003oY:KHojBVf?nTY]P2o`0000SoXZ3C0_l00006oiVKe003
o`000?nIW=GoVIcE00GoVIcE00Go0000oi^Pf?nKX=SoVj3Ho`000003oi>Og003o`000?nIZ>3oVJSP
00;oVJSP00?o0000oinci_nO/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000
okGKlonefo?o00000_nhho@01?l0003o^^Kdok[Vm?l0000Dooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`0004;ooooo00Go
0000og6XlomaZ??oLJSco`000002ogN[l`04o`000?n5/O;oQK7bo`0000?oU[W`00?o0000ojK0k?nV
`>`00_nV`>`00ol0003o]<GVokC5iP02okC5iP04o`000?nob>7o0000o`0000?o_L;M00?o0000ol?2
f?o3`]P01?o3`]P2o`0000Koa/7F00?o0000olK1eOl000001Oo2^M43o`0000Oo`;[C00?o0000okRf
e_nh]]H02_nh]]H2o`0000;o/;OO1Ol00005ok2gg`03o`000?n]]Moo[KGO00?o[KGO2?l0000<ojVY
eP04o`000?nTY]So0000o`0000OoXZ3C0ol00002oj6Md@04o`000?nIVmCoVI_DoiVKe0;o00001onI
W=D00ol0003oVj3Hoi^Pf003oi^Pf003o`000?nCWmco000000CoVJSP00?o0000oinci_nO/nH00onO
/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@01?l0003o
^^Kdok[Vm?l0000Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`05o`000?maZ??oLJScog6X
lol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`000?nV`>coY/3/00;oY/3/00Co0000
okC5i_ndaNKo]<GV0_l00006okg2g@;o00001_o3`]P00ol0003oa/7FolK1eP04olK1eP03o`000?o2
^M7o`[WA00Oo`[WA0_l00005ol2jd`03o`000?nk/m7o^k?A00Go00001_nh]]H00ol0003o];7EokBa
e@05okBae@_o00001_n_[=D00ol0003oZJWFojVYeP09ojVYePCo00001_nRX=<3o`0000KoXIgA00?o
0000oiVKe?l000001onIW=D2o`0000KoVj3H0ol00003oiVXh003o`000?nO/nKoWk?V00?oWk?V00Go
0000ojO1k?nW`NcoYl7/o`000004ojo?l@04o`000?nefo?o]M_co`0000;o^>?d00Co0000ok[Vm?nj
i_Co00006?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool01Ol0003oLJScog6XlomaZ??o0000
00;oMj_c00Co0000ohFal_n5/O;o00000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo
000000?o]<;T1onm`]d00ol0003o`l;Hol?2f004ol?2f0;o00000oo6`MH00ol0003o`[WBol:idP02
o`0000So`[WA0ol000000oo0^]?o0000ok^cd@07ok^cd@Co000000?o^;KFo`000?nd/MD03?nd/MD0
0ol0003o[jcEojn/e@0:ojn/e@04o`000?nYZMKoZJWFojVYePOo00000onYXm400ol0003oXZ3Coj:P
d`02oj:Pd`;o00002OnQWM42o`0000OoVIcE00?o0000oi^Pf?nKX=P01OnKX=P01ol0003oWZSMoijX
gOnNZ=go0000oiVXh?l000001OnO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGK
lonefo?o00000_nhho@01?l0003o^^Kdok[Vm?l0000Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`10
ooooo`05o`000?maZ??oLJScog6Xlol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`00
0?nV`>coY/3/00?o00001Ond`^@2o`0000Go_L;M0_l00006ol?2f003o`000?o6`MKo000000Go`[WB
0_l00009ol:id@03o`000?nk/m7o^k?A00_o^k?A0_l00003okBae@Co00001Ond/MD00ol0003o[jcE
ojn/e@04ojn/e@_o00002onYXm44o`0000SoXIgA0ol000000onRW]7o0000oiVLe@04oiVLe@;o0000
1_nKX=P2o`0000CoWZSM0ol00004oinciP05o`000?nW`NcoYl7/ojO1k?l000001?n_co401?l0003o
]M_cokGKlol00002okSSm004o`000?nji_Co^^Kdo`0001_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000@Oooool@o`00
00CoY/3/1_nd`^@00ol0003o_L;Mokg2g@04okg2g@03o`000?o3`]So`l;H00Co`l;H00?o0000ol:i
d_o2^M801_o2^M83o`0000Ko`[WA00?o0000okbaconl/Ll00ol00009ok^cd@03o`000?nf[M3o]Zg@
00Go]Zg@3?l00007ok2Wd003o`000?nYXm7oZJ?A00[oZJ?A0ol00009oj6Md@;o00001OnRW]401Ol0
003oVIcEoiVLeOnIW=Go000000KoVj3H0_l00005oijXg@04o`000?nS/nCoXk?Toj>ci0;o000000?o
Wk?Vo`000?nW`N`00_nW`N`00ol0003o[loaojo?l@02ojo?l@04o`000?nefo?o]M_co`0000;o^>?d
00Co0000ok[Vm?nji_Co00007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Co
oooo000Rooooo`03o`000?oooooooooo043ooooo1?mW[OT3ofn`n0?oPKOg1?nD_?<5ojK0k003o`00
0?nd`^Co]<;T00?o]<;T0_l00005okg2g@;o00000oo3`]P00ol0003o_k[Eoknje@02o`0000So`[WB
0_l00003ol:id@03o`000?nl/Loo_;7?00Co_;7?1?l00005ok^cd@03o`000?nf[M3o]Zg@00[o]Zg@
00?o0000ok2Wd?n`Ym002on`Ym000ol0003oZJ?AojVSd@05ojVSd@Go00000_nYXLl00ol0003oXIgA
oj6Md@05oj6Md@;o00002?nRW]400ol0003oVIcEo`000006oi^Pf003o`000?nNZ=goWZSM00?oWZSM
0_l00005oj>ci0Co000000?oYl7/o`000?n_co400on_co401?l0003o]M_cokGKlol00002okSSm004
o`000?nji_Co^^Kdo`0001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`008oooool00ol0003oooooooooo`10ooooo`05o`000?mW[OWoIjgiofN]nOl000000_m_/?P3oh6g
m`05o`000?nD_??oU;ccoiBllol000001OnV`>`00ol0003o]<;TokC2i003okC2i003o`000?nm`]go
_L;M00Co_L;M00?o0000ol?2f?l000001Ono^]D2o`0000So`[WB0_l000000oo2^M7o0000okbac`09
okbac`?o000000?o^k?Ao`000?nf[M003?nf[M000ol0003o/:O@ok2Wd00<ok2Wd003o`000?nYXm7o
000000Co00002?nYXLl01?l0003oXIgAoj6MdOnQWM43o`0000[oXYkA0_l00005oi^Pf0;o00001?nN
Z=d2o`0000KoXk?T00Co0000ojO1k?nW`NcoYl7/1?l00002ojo?l@04o`000?nefo?o]M_co`0000;o
^>?d00Co0000ok[Vm?nji_Co00008?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo000Tooooo`;o0000@_ooool3ofN]n@04o`000?m_/?SoKk3hofn`n0;oPKOg0_l00003oiBl
l`03o`000?nV`>coY/3/00;oY/3/0_l00004okC2i003o`000?nm`]go_L;M00Co_L;M00?o0000oknj
eOno^]D01_no^]D3o`0000Oo`[WB00?o0000okbaconl/Ll03?nl/Ll2o`000003okJ]d?l0003o0000
00Co00001_nf[M000ol0003o/:O@ok2Wd005ok2Wd0Wo00003OnYXLl01?l0003oXIgAo`000?l0000:
oj:Nd@?o000000?oXj;Do`000?nKX=P00_nKX=P2o`0000GoWZSM00?o0000oj>ci?nS/n@01?nS/n@2
o`0000?oYl7/00?o0000oj_@lon[d?<00_n[d?<;o`0002;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`10ooooo`05o`000?mW[OWoIjgi
ofN]nOl000000_m_/?P01?l0003oPKOgoh6gmol00003oiBll`;o00001?nV`>`00ol0003o]<;TokC2
i002okC2i0;o00000onm`]d00ol0003o^kcKok^lf`02o`0000So_k[E0_l00004ol:idP04o`000?nl
//oo_;;?okbbc`Go00002?nl/Ll00ol0003o]Z_>okJ[cP05okJ[cPko00001on`Y/d00ol0003oZJ7?
ojVQc`0;ojVQc`?o00002OnRW]43o`0000GoXj;D00?o0000oi^Pf?l000001OnNZ=d2o`0000KoXk?T
00Co0000ojO1k?nW`NcoYl7/0_l00003oj_@l`;o00000_n]gOP01?l0003o[NGio`000?l00002ojcX
n@03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`009oooool00ol0003oooooooooo`10ooooo`;o00000_mW[OT01?l0003oKk3hofn`n?m_/?P2oh6g
m`;o00000onD_?<2o`0000?oY/3/00?o0000okC2i?nd`^@00ond`^@00ol0003o_L;Mo`000005ok^l
f`;o00002?no^]D2o`000003ol:id_l0003o_;;?00So_;;?1Ol00002okbac`03o`000?nfZlko]Z_>
00co]Z_>00?o0000ok2VcOn`Y/d03?n`Y/d00ol0003oZJ7?ojVQc`06ojVQc`Go00000_nYX/l00ol0
003oXYkAoj:Nd@04oj:Nd@?o00002?nSX]@3o`0000?oWZSM0_l00006oj>ci0;o00000onW`N`00ol0
003oZm3coj_@l`02oj_@l`03o`000?n]gOSo[Mgh00;o000000Co[NGio`000?n/j?Wo[>Si0_l0000W
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002Sooooo00?o0000oooo
ooooool0@Oooool00ol0003oIjgiofN]n@02o`0000;oKk3h00Co0000oh6gmon1]oOo00001?nD_?<0
1?l0003oY/3/ojK0k?nV`>`2o`0000?o]<;T0_l00008ok^lf`;o00002?no^]D00ol0003o_;;?okbb
c`0=okbbc`;o00000onfZlh00ol0003o]Z_>okJ[cP09okJ[cP03o`000?n`Y/go/:K=00go/:K=00?o
0000ojVQconYXLl01Ol00008ojVRc`03o`000?nRW]7oXYkA00?o00002?nSX]@3o`0000?oY:WJ00?o
0000oijXgOl000001_nS/n@2o`0000?oYl7/0_l00003oj_@l`;o000000Co[Mgho`000?l0003o[NGi
0_l00002ojcXn@03o`000?oooooooooo02Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`00:Oooool2o`0004;ooooo0_l00002ofN]n@03o`000?m_/?SoKk3h00;o000000?o
PKOgo`000?nD_?<00onD_?<2o`0000?oY/3/00?o0000okC2i?l000000onc_^800ol0003o^kcKok^l
f`06ok^lf`;o00001_no^]D00ol0003o^[?CokZcd`04o`0000[o_;;?00?o0000okJ[c_nfZlh00_nf
Zlh8o`0000?o]Z_>00?o0000ok2VcOn`Y/d01On`Y/d;o`0000coZJ;?1?l00009oj>Re0;o00001_nT
ZMX2o`0000KoXk?T00Co0000ojO1k?nW`NcoYl7/0_l00003oj_@l`;o00000_n]gOP01?l0003o[NGi
o`000?l00002ojcXn@;o0000:oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo000[ooooo`03o`000?oooooooooo047ooooo00Co0000ofN]nOmW[OWo00000om_/?P01?l0003o
PKOgo`000?l00004oiBll`03o`000?nV`>coY/3/00;o00001_nc_^82o`0000Oo^kcK0_l00003oknj
e@03o`000?nj/m?o^[?C00Go^[?C1?l00006okbbc`03o`000?nfZlko]Z_>00[o]Z_>2ol00008ok2V
cP03o`000?nYX/ooZJ;?00SoZJ;?1?l00002ojVUdP03o`000?nSX]CoXj;D00GoXj;D0ol00006ojBY
fP;o00000_nV/n801?l0003oXk?Toj>ci?nS/n@2o`0000?oYl7/00Co0000oj_@lon[d??oZm3c0_l0
0002ojgMn0;o000000Co[NGio`000?n/j?Wo[>Si0_l0000^ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0@Oooool00ol0003oIjgiofN]
n@02o`0000;oKk3h0_l000000on1]oOo0000oiBll`02oiBll`?o00000onV`>`00ol0003o/kkRok>n
hP04ok>nhP?o00001_nk_=/2o`000003oknjeOl0003o^[?C00[o^[?C1?l000000onl//oo0000okJ[
cP0?okJ[cP03o`000?n`Y/ko/:K>00go/:K>00?o0000ojVRconYX/l01?nYX/l4o`0000OoZJGB00?o
0000oj>Re?nSX]@00_nSX]@2o`0000KoY:WJ0ol00005ojJchP03o`000?nS/nCo000000?oYl7/0_l0
0002oj_@l`;o00000on]gOP01?l0003o[NGio`000?l00002ojcXn@03o`000?oooooooooo02oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003ooooooooo
o`11ooooo`;o00000_mW[OT02Ol0003oKk3hofn`n?m_/?So0000oh6gmol0003oU;cco`000003oiC0
m@03o`000?nV`>coY/3/00;oY/3/0_l00006ok>nhP;o00001_nk_=/00ol0003o^[?CokZcd`0>okZc
d`;o00000onfZlh00ol0003o]Z_>okJ[cP0:okJ[cP03o`000?n`Y/ko/:K>00ko/:K>00?o0000ojVR
col000000ol0000;ojVUdP03o`000?nSX]Co000000;o00001_nTZMX2o`0000SoY[?R1?l000000onW
`Nco0000oj_@l`02oj_@l`04o`000?n]gOSo[MghojgMn0Co00000_n/j?T2o`0003;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;_ooool2o`0004?ooooo00Co0000ofN]
nOmW[OWo00000_m_/?P4o`0000KoU<3e0_l00004ojK0k0;o00001Onc_^82o`0000Co^kcK00?o0000
okNgfOng]mT01?l0000;okZcd`03o`000?ne[]7o]JkA00;o]JkA2Ol00003okJ[cP03o`000?n`Y/ko
/:K>00Ko/:K>2_l0000=ojVUdPCo00001onTZMX2o`0000OoY[?R0ol00003ojO1k0?o000000?oZm3c
o`000?l000000_n]gOP2o`000003ojgUnOl0003o[>Si00;o[>Si00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo
047ooooo1Ol00003ofZho0;oO[gk00?o0000oiC0mOnD`?D01?nD`?D2o`0000CoY/3/0_l00005ok>n
hP;o000000?o^kcKo`000?ng]mT01_ng]mT5o`0000Ko^[?C00?o0000okF^dOne[]402one[]4<o`00
00So[jWA00?o0000ojVUd_nYYM801_nYYM86o`0000?oZJ_H00?o0000ojBYf_nTZMX00_nTZMX3o`00
00KoY[?R0ol00003ojO1k0?o00000_nVcoD4o`000003ojgMn?l0003o[NGi00;o00000_n/j?T2o`00
03Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00<Oooool00ol0003o
ooooooooo`12ooooo`?oH;Cl00?o0000ofZho?mZ^?`00omZ^?`2ogjmn`03o`000?nD`?GoU<3e00?o
U<3e0ol00003ojK0k0?o00001?nc_^800ol0003o]kOIokNgf@0;okNgf@Co000000?o^[?Co`000?ne
[]404?ne[]400ol0003o[jWAojnYd@0?ojnYd@03o`000?nYYM;oZJGB00Go00002_nYZmP01?l0003o
Y:WJo`000?l00006ojJchP?o00001?nW`N`2o`0000;oY/oe0ol00003oj?Ln`Ko000000?o[>Sio`00
0?ooool0>?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03
o`000?oooooooooo04Cooooo0omP]?`00ol0003oJ[SlofZho002ofZho004o`000?mn_O_o0000o`00
00GoU<3e0_l00004ojK0k0;o000000?o/kkRo`000?na^n400_na^n45o`0000[o]kOI0_l00004okF^
d@Go00002?ne[]400ol0003o[jWAojnYd@06ojnYd@co00003OnYZmP4o`0000GoY[?R0ol00004ojO1
k0?o000000CoY/oeo`000?l0003o00000onSg?/5o`0000?oV^Kl0_l0000kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool003?ooooo0_l00017ooooo`;oH;Cl0_l00003ofZh
o0;o000000CoO[gko`000?l0003o00000onD`?D2o`0000CoY/3/00?o0000ok6khOna^n401ona^n44
o`0000Oo]kOI00?o0000ok>bf?nc/]P01onc/]PAo`0000Wo[ZkG00?o0000ojV[f?nYZmP01onYZmP6
o`0000CoZKCQ00?o0000ojJch_l000000_l00004ojO1k0?o000000CoY/oeo`000?l0003o00000onS
g?/5o`0000?oV^Kl0ol0000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool003Gooooo00?o0000ooooooooool0A_ooool00ol0003oH;Clof2do002o`0000?oJ[Sl0_l00000
0omn_O_o0000o`000003oiC0m@;o000000?oY/3/o`000?nW`>`00_nW`>`3o`0000So/K_Q1Ol00000
0ong]mWo0000ok>bf00Aok>bf003o`000?n^[]Oo[ZkG013o[ZkG00?o0000ojV[f?nYZmP01_l00009
ojVdh@?o00001OnW`N`2o`0000;oY/oe0_l00003oj?Ln`Ko00000_nJi_`3o`0004;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`18oooo
o`03o`000?mP]?co000000;o00000_mZ^?`2o`000004ogjmnol0003o0000o`0000;oU<3e00?o0000
ojO0k?nW`>`01onW`>`5o`0000Ko/K_Q0_l00004ok>bf0Ko00002?nc/]P00ol0003o[ZkGojj^e`07
ojj^e`co00002_nY]>45o`0000?oYl7/00?o0000ojO1k?l000000_l000001?nVcoGo0000o`000?l0
0002oj?Ln`?o000000?oWN?mo`000?l000000_nJi_`3o`0004Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=oooool00ol0003oooooooooo`19ooooo`;o000000?oH;Cl
o`000?l000000_mZ^?`3o`000003ogjmnol0003oU/Cg00?oU/Cg0ol00009ojO0k0Go00000_na^n40
0ol0003o[kWQojnih@08ojnihA;o00002On/]^400ol0003oZKCQojVdh@05ojVdh@Go00001onW`N`3
o`000004ojK?mOl0003o0000o`0000;oXmck0ol000001?nMhogo0000o`000?l00002oi[Vo0;o0000
BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000hooooo`;o0000C?oo
ool5o`0000;oJ[Sl00Go0000oh34oOn0a?goP<Cmo`000005oiK4m`Co00002OnW`>`2o`0001?o[kWQ
00?o0000ojbfhOn/]^404On/]^400ol0003oZKCQo`000004o`0000OoYl7/1Ol000000onRc_Oo0000
o`000002o`000004oj?Lnol0003o0000o`0000;oWN?m0_l00002oi[Vo0?o0000C?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000jooooo`03o`000?oooooooooo04cooooo
0ol00004of[0oP03o`000?n0a?goP<Cm00;oP<Cm0_l00004oiK4m`Co00001_nW`>`00ol0003oYl7/
ojO1k003ojO1k0[o00001?n_^N400ol0003o[;KQojbfh@07ojbfh@co00001onW`N`5o`0000;oX/kg
1?l00002oiOHoPCo000000GoWN?mo`000?l0003o0000oi[Vo003o`00053ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`01ooooo`00>oooool00ol0003oooooooooo`1>ooooo`;oGkgm
00?o0000of[0o_mZ`?h00omZ`?h2o`0000CoP<Cm0ol00002oiK4m`Co000000?oYl3/o`000?nW`N`0
3onW`N`>o`0000[oYl7/00Co0000ojO1k?nW`NcoYl7/1Ol00003oj;>m`Co000000?oUmSno`000?l0
00000ol00002oh_MoP?o000000CoV^Klo`000?l0003o0000Doooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo000looooo`;o0000D_ooool00ol0003oGkgmoenmo@02o`0000Co
J/3n0ol00002oh34o@Co000000?oU/Cgo`000?l000002_nW`N`00ol0003oYl7/ojO1k007ojO1k003
o`000?nW`NcoYl7/00SoYl7/3Ol00004oj;>m`Co000000?oUmSno`000?l000000_l00002oh_MoPGo
000000CoQMkmo`000?l0003o0000Eoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo000nooooo`03o`000?oooooooooo05?ooooo0_l000001?mO_Ogo0000o`000?l00003of[0
oPCo000000?oP<Cmo`000?l000003?nIb?PDo`0000[oWL_h00?o0000oj;>monRc_L01?l000000onG
f?ko0000o`000002o`000003oh_Mo_l0003o000000?o000000?oQMkmo`000?l000000ol0001Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool003oooooo00?o0000oooooooo
ool0Doooool00ol0003oooooo`000008o`000003of[0o_l0003o000000OoQ<cn2ol00004oiW8n003
o`000?nMboSoWL_h00SoWL_h4_l000000on;gOko0000o`000002o`000003ohGNoOl0003o000000?o
0000HOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool00oooool4o`000003oenmoOl0003o000000OoKl[o
1_l00006ohC<oQco000000?oRmgno`000?l000000ol000000on5g_go0000o`000002o`0006Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool2o`0005;ooooo00?o
0000ooooooooool01oooool2o`0000OoI<Om1_l00006ofo:oako000000?oQMkmo`000?l000000ol0
001[ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool03oooool6o`0000KoI<Om4Ol000000ombdogo0000o`00000<
o`00077ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0Koooooa;o0000P?ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0:go
oooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo0_l0001=ooooo`03o`00
0?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Sooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo0019ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?ooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01?ooool1o`00007ooooo001;ooooo`;o
0000B?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo001>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2cooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo0_l00013
ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo00000Oooool005;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo0000007ooooo001Coooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`01o`00
0000E?ooool2o`0003oooooo00?o0000ooooooooool0]_ooool1o`00007ooooo0Ol0000005Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`;o0000001Gooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0]_ooool3o`000000F?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo0;;ooooo1?l00003ooooo`00FOooool2o`0003[ooooo00?o0000oooo
ooooool0[_ooool4o`0000Oooooo001Kooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Z_ooool4o`0000_ooooo001Looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
Y_ooool4o`0000oooooo001Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X_oo
ool4o`0001?ooooo001Nooooo`;o0000=Oooool00ol0003oooooooooo`2Nooooo`Co00005oooool0
063ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`Co00006oooool0067o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Hooooo`?o00007oooool006;ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`Co00008_ooool006?ooooo0_l0
000_ooooo`03o`000?oooooooooo093ooooo1?l0000Vooooo`00IOooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo08cooooo1?l0000Zooooo`00I_ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Sooooo1?l0000^ooooo`00Ioooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo08Cooooo1?l0000booooo`00J?ooool2o`0002[ooooo00?o0000ooooooooool0
P?ooool4o`0003Kooooo001Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0O?oo
ool4o`0003[ooooo001[ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4
o`0003kooooo001/ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`00
04;ooooo001]ooooo`;o00009Oooool00ol0003oooooooooo`1`ooooo`Co0000A_ooool006oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`Co0000B_ooool0073ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000C_ooool0077ooooo0_l0000Q
ooooo`03o`000?oooooooooo06Cooooo1?l0001Booooo`00Loooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo063ooooo1?l0001Fooooo`00M?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05cooooo1?l0001Jooooo`00MOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Wooooo0ol0001Nooooo`00M_ooool2o`0001cooooo00?o0000ooooooooool0EOoo
ool4o`00067ooooo001hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool4
o`0006Gooooo001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool4o`00
06Wooooo001jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0006go
oooo001kooooo`;o00005oooool00ol0003oooooooooo`15ooooo`Co0000LOooool007gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`Co0000MOooool007kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0mooooo`Co0000NOooool007oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0iooooo`Co0000OOooool0083ooooo0_l0000Booooo`03
o`000?oooooooooo03Gooooo1?l00021ooooo`00P_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo037ooooo1?l00025ooooo`00Poooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02kooooo1?l00029ooooo`00Q?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02[ooooo1?l0002=ooooo`00QOooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`00
097ooooo0027ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0009Go
oooo0028ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`0009Wooooo
0029ooooo`;o00002?ooool00ol0003oooooooooo`0Kooooo`?o0000WOooool008_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`Co0000X?ooool008cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Cooooo`Co0000Y?ooool008gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`Co0000Z?ooool008kooooo0_l00003ooooo`03o`00
0?oooooooooo00_ooooo1?l0002/ooooo`00T?ooool01?l0003oooooooooool00009ooooo`Co0000
/?ooool0097ooooo00?o0000ooooool000001Oooool4o`000;Cooooo002Booooo`;o000000?ooooo
o`000?l000000_l0002hooooo`00Toooool2o`000;cooooo003ooooooe;ooooo003ooooooe;ooooo
003ooooooe;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .64752 m .51694 .65827 L .43899 .65168 L p .709 .682 .822 r
F P
0 g
s
.51694 .65827 m .51725 .64752 L .59255 .64333 L p .687 .663 .821 r
F P
0 g
s
.59255 .64333 m .59527 .65394 L .51694 .65827 L p .687 .663 .821 r
F P
0 g
s
.59527 .65394 m .59255 .64333 L .66454 .6287 L p .664 .649 .825 r
F P
0 g
s
.66454 .6287 m .67023 .63881 L .59527 .65394 L p .664 .649 .825 r
F P
0 g
s
.43899 .65168 m .44234 .64114 L .51725 .64752 L p .709 .682 .822 r
F P
0 g
s
.51757 .63706 m .51725 .64752 L .44234 .64114 L p .706 .686 .828 r
F P
0 g
s
.51725 .64752 m .51757 .63706 L .58981 .63301 L p .686 .669 .828 r
F P
0 g
s
.58981 .63301 m .59255 .64333 L .51725 .64752 L p .686 .669 .828 r
F P
0 g
s
.44234 .64114 m .43899 .65168 L .36521 .63435 L p .728 .703 .826 r
F P
0 g
s
.59255 .64333 m .58981 .63301 L .65884 .61888 L p .664 .656 .832 r
F P
0 g
s
.65884 .61888 m .66454 .6287 L .59255 .64333 L p .664 .656 .832 r
F P
0 g
s
.44234 .64114 m .4457 .6309 L .51757 .63706 L p .706 .686 .828 r
F P
0 g
s
.51789 .62738 m .51757 .63706 L .4457 .6309 L p .7 .699 .846 r
F P
0 g
s
.51757 .63706 m .51789 .62738 L .58708 .62348 L p .683 .685 .846 r
F P
0 g
s
.58708 .62348 m .58981 .63301 L .51757 .63706 L p .683 .685 .846 r
F P
0 g
s
.36521 .63435 m .37149 .62438 L .44234 .64114 L p .728 .703 .826 r
F P
0 g
s
.4457 .6309 m .44234 .64114 L .37149 .62438 L p .725 .707 .833 r
F P
0 g
s
.58981 .63301 m .58708 .62348 L .65314 .60987 L p .665 .674 .849 r
F P
0 g
s
.65314 .60987 m .65884 .61888 L .58981 .63301 L p .665 .674 .849 r
F P
0 g
s
.4457 .6309 m .44906 .62145 L .51789 .62738 L p .7 .699 .846 r
F P
0 g
s
.51821 .6189 m .51789 .62738 L .44906 .62145 L p .686 .72 .875 r
F P
0 g
s
.51789 .62738 m .51821 .6189 L .58435 .61515 L p .675 .711 .875 r
F P
0 g
s
.58435 .61515 m .58708 .62348 L .51789 .62738 L p .675 .711 .875 r
F P
0 g
s
.37149 .62438 m .37779 .61472 L .4457 .6309 L p .725 .707 .833 r
F P
0 g
s
.44906 .62145 m .4457 .6309 L .37779 .61472 L p .715 .716 .85 r
F P
0 g
s
.58708 .62348 m .58435 .61515 L .64745 .60208 L p .664 .704 .877 r
F P
0 g
s
.64745 .60208 m .65314 .60987 L .58708 .62348 L p .664 .704 .877 r
F P
0 g
s
.67023 .63881 m .66454 .6287 L .72952 .60406 L p .639 .638 .833 r
F P
0 g
s
.72952 .60406 m .73799 .61332 L .67023 .63881 L p .639 .638 .833 r
F P
0 g
s
.37779 .61472 m .38409 .60587 L .44906 .62145 L p .715 .716 .85 r
F P
0 g
s
.45242 .6132 m .44906 .62145 L .38409 .60587 L p .695 .731 .878 r
F P
0 g
s
.44906 .62145 m .45242 .6132 L .51821 .6189 L p .686 .72 .875 r
F P
0 g
s
.51852 .61189 m .51821 .6189 L .45242 .6132 L p .658 .749 .917 r
F P
0 g
s
.51821 .6189 m .51852 .61189 L .58162 .6083 L p .658 .748 .917 r
F P
0 g
s
.58162 .6083 m .58435 .61515 L .51821 .6189 L p .658 .748 .917 r
F P
0 g
s
.66454 .6287 m .65884 .61888 L .72104 .59513 L p .641 .646 .839 r
F P
0 g
s
.72104 .59513 m .72952 .60406 L .66454 .6287 L p .641 .646 .839 r
F P
0 g
s
.37149 .62438 m .36521 .63435 L .29943 .6068 L p .746 .727 .835 r
F P
0 g
s
.58435 .61515 m .58162 .6083 L .64178 .59578 L p .657 .748 .917 r
F P
0 g
s
.64178 .59578 m .64745 .60208 L .58435 .61515 L p .657 .748 .917 r
F P
0 g
s
.38409 .60587 m .39037 .59823 L .45242 .6132 L p .695 .731 .878 r
F P
0 g
s
.45577 .60643 m .45242 .6132 L .39037 .59823 L p .659 .749 .917 r
F P
0 g
s
.45242 .6132 m .45577 .60643 L .51852 .61189 L p .658 .749 .917 r
F P
0 g
s
.65884 .61888 m .65314 .60987 L .71257 .58702 L p .645 .666 .855 r
F P
0 g
s
.71257 .58702 m .72104 .59513 L .65884 .61888 L p .645 .666 .855 r
F P
0 g
s
.29943 .6068 m .30845 .59776 L .37149 .62438 L p .746 .727 .835 r
F P
0 g
s
.37779 .61472 m .37149 .62438 L .30845 .59776 L p .741 .73 .841 r
F P
0 g
s
.51884 .60645 m .51852 .61189 L .45577 .60643 L p .606 .78 .964 r
F P
0 g
s
.51852 .61189 m .51884 .60645 L .5789 .60302 L p .62 .792 .964 r
F P
0 g
s
.5789 .60302 m .58162 .6083 L .51852 .61189 L p .62 .792 .964 r
F P
0 g
s
.58162 .6083 m .5789 .60302 L .63612 .59107 L p .638 .802 .961 r
F P
0 g
s
.63612 .59107 m .64178 .59578 L .58162 .6083 L p .638 .802 .961 r
F P
0 g
s
.30845 .59776 m .31747 .58906 L .37779 .61472 L p .741 .73 .841 r
F P
0 g
s
.38409 .60587 m .37779 .61472 L .31747 .58906 L p .727 .735 .857 r
F P
0 g
s
.65314 .60987 m .64745 .60208 L .70413 .58015 L p .651 .7 .882 r
F P
0 g
s
.70413 .58015 m .71257 .58702 L .65314 .60987 L p .651 .7 .882 r
F P
0 g
s
.39037 .59823 m .39663 .5921 L .45577 .60643 L p .659 .749 .917 r
F P
0 g
s
.45911 .60123 m .45577 .60643 L .39663 .5921 L p .595 .765 .961 r
F P
0 g
s
.45577 .60643 m .45911 .60123 L .51884 .60645 L p .606 .78 .964 r
F P
0 g
s
.51916 .60249 m .51884 .60645 L .45911 .60123 L p .515 .796 .997 r
F P
0 g
s
.51884 .60645 m .51916 .60249 L .57617 .59923 L p .549 .826 .997 r
F P
0 g
s
.57617 .59923 m .5789 .60302 L .51884 .60645 L p .549 .826 .997 r
F P
0 g
s
.31747 .58906 m .32648 .58118 L .38409 .60587 L p .727 .735 .857 r
F P
0 g
s
.39037 .59823 m .38409 .60587 L .32648 .58118 L p .702 .743 .883 r
F P
0 g
s
.64745 .60208 m .64178 .59578 L .69572 .5748 L p .657 .748 .917 r
F P
0 g
s
.69572 .5748 m .70413 .58015 L .64745 .60208 L p .657 .748 .917 r
F P
0 g
s
.5789 .60302 m .57617 .59923 L .63045 .58786 L p .593 .85 .993 r
F P
0 g
s
.63045 .58786 m .63612 .59107 L .5789 .60302 L p .593 .85 .993 r
F P
0 g
s
.39663 .5921 m .40288 .58756 L .45911 .60123 L p .595 .765 .961 r
F P
0 g
s
.46246 .59752 m .45911 .60123 L .40288 .58756 L p .495 .765 .991 r
F P
0 g
s
.45911 .60123 m .46246 .59752 L .51916 .60249 L p .515 .796 .997 r
F P
0 g
s
.32648 .58118 m .33545 .57455 L .39037 .59823 L p .702 .743 .883 r
F P
0 g
s
.39663 .5921 m .39037 .59823 L .33545 .57455 L p .659 .75 .917 r
F P
0 g
s
.64178 .59578 m .63612 .59107 L .68734 .57106 L p .656 .807 .956 r
F P
0 g
s
.68734 .57106 m .69572 .5748 L .64178 .59578 L p .656 .807 .956 r
F P
0 g
s
.51948 .59971 m .51916 .60249 L .46246 .59752 L p .393 .78 .99 r
F P
0 g
s
.51916 .60249 m .51948 .59971 L .57344 .59661 L p .447 .826 .99 r
F P
0 g
s
.57344 .59661 m .57617 .59923 L .51916 .60249 L p .447 .826 .99 r
F P
0 g
s
.73799 .61332 m .72952 .60406 L .7837 .57028 L p .613 .631 .845 r
F P
0 g
s
.7837 .57028 m .79464 .57831 L .73799 .61332 L p .613 .631 .845 r
F P
0 g
s
.57617 .59923 m .57344 .59661 L .62477 .58584 L p .524 .87 .99 r
F P
0 g
s
.62477 .58584 m .63045 .58786 L .57617 .59923 L p .524 .87 .99 r
F P
0 g
s
.33545 .57455 m .34439 .56945 L .39663 .5921 L p .659 .75 .917 r
F P
0 g
s
.40288 .58756 m .39663 .5921 L .34439 .56945 L p .59 .751 .954 r
F P
0 g
s
.72952 .60406 m .72104 .59513 L .77275 .56259 L p .617 .64 .851 r
F P
0 g
s
.77275 .56259 m .7837 .57028 L .72952 .60406 L p .617 .64 .851 r
F P
0 g
s
.40288 .58756 m .40913 .58452 L .46246 .59752 L p .495 .765 .991 r
F P
0 g
s
.46582 .595 m .46246 .59752 L .40913 .58452 L p .37 .738 .989 r
F P
0 g
s
.46246 .59752 m .46582 .595 L .51948 .59971 L p .393 .78 .99 r
F P
0 g
s
.63612 .59107 m .63045 .58786 L .67896 .56884 L p .64 .864 .983 r
F P
0 g
s
.67896 .56884 m .68734 .57106 L .63612 .59107 L p .64 .864 .983 r
F P
0 g
s
.72104 .59513 m .71257 .58702 L .76184 .55576 L p .625 .662 .865 r
F P
0 g
s
.76184 .55576 m .77275 .56259 L .72104 .59513 L p .625 .662 .865 r
F P
0 g
s
.30845 .59776 m .29943 .6068 L .24558 .56996 L p .759 .754 .848 r
F P
0 g
s
.5198 .59763 m .51948 .59971 L .46582 .595 L p .293 .746 .956 r
F P
0 g
s
.51948 .59971 m .5198 .59763 L .57068 .59471 L p .359 .803 .955 r
F P
0 g
s
.57068 .59471 m .57344 .59661 L .51948 .59971 L p .359 .803 .955 r
F P
0 g
s
.24558 .56996 m .25699 .56223 L .30845 .59776 L p .759 .754 .848 r
F P
0 g
s
.31747 .58906 m .30845 .59776 L .25699 .56223 L p .753 .755 .854 r
F P
0 g
s
.34439 .56945 m .3533 .56597 L .40288 .58756 L p .59 .751 .954 r
F P
0 g
s
.40913 .58452 m .40288 .58756 L .3533 .56597 L p .49 .736 .981 r
F P
0 g
s
.71257 .58702 m .70413 .58015 L .75099 .5502 L p .639 .698 .888 r
F P
0 g
s
.75099 .5502 m .76184 .55576 L .71257 .58702 L p .639 .698 .888 r
F P
0 g
s
.57344 .59661 m .57068 .59471 L .61905 .58455 L p .46 .864 .964 r
F P
0 g
s
.61905 .58455 m .62477 .58584 L .57344 .59661 L p .46 .864 .964 r
F P
0 g
s
.25699 .56223 m .26839 .55486 L .31747 .58906 L p .753 .755 .854 r
F P
0 g
s
.32648 .58118 m .31747 .58906 L .26839 .55486 L p .737 .756 .868 r
F P
0 g
s
.40913 .58452 m .4154 .58268 L .46582 .595 L p .37 .738 .989 r
F P
0 g
s
.4692 .59319 m .46582 .595 L .4154 .58268 L p .27 .701 .966 r
F P
0 g
s
.46582 .595 m .4692 .59319 L .5198 .59763 L p .293 .746 .956 r
F P
0 g
s
.63045 .58786 m .62477 .58584 L .67058 .56784 L p .608 .901 .986 r
F P
0 g
s
.67058 .56784 m .67896 .56884 L .63045 .58786 L p .608 .901 .986 r
F P
0 g
s
.70413 .58015 m .69572 .5748 L .74019 .54619 L p .656 .748 .917 r
F P
0 g
s
.74019 .54619 m .75099 .5502 L .70413 .58015 L p .656 .748 .917 r
F P
0 g
s
.26839 .55486 m .27975 .54834 L .32648 .58118 L p .737 .756 .868 r
F P
0 g
s
.33545 .57455 m .32648 .58118 L .27975 .54834 L p .707 .755 .89 r
F P
0 g
s
.3533 .56597 m .36219 .564 L .40913 .58452 L p .49 .736 .981 r
F P
0 g
s
.4154 .58268 m .40913 .58452 L .36219 .564 L p .376 .702 .984 r
F P
0 g
s
.52012 .59567 m .5198 .59763 L .4692 .59319 L p .272 .737 .947 r
F P
0 g
s
.5198 .59763 m .52012 .59567 L .5679 .59293 L p .341 .796 .946 r
F P
0 g
s
.5679 .59293 m .57068 .59471 L .5198 .59763 L p .341 .796 .946 r
F P
0 g
s
.69572 .5748 m .68734 .57106 L .72945 .54382 L p .673 .808 .948 r
F P
0 g
s
.72945 .54382 m .74019 .54619 L .69572 .5748 L p .673 .808 .948 r
F P
0 g
s
.27975 .54834 m .29105 .54309 L .33545 .57455 L p .707 .755 .89 r
F P
0 g
s
.34439 .56945 m .33545 .57455 L .29105 .54309 L p .659 .75 .918 r
F P
0 g
s
.57068 .59471 m .5679 .59293 L .61327 .58338 L p .447 .861 .956 r
F P
0 g
s
.61327 .58338 m .61905 .58455 L .57068 .59471 L p .447 .861 .956 r
F P
0 g
s
.62477 .58584 m .61905 .58455 L .66214 .56758 L p .574 .913 .972 r
F P
0 g
s
.66214 .56758 m .67058 .56784 L .62477 .58584 L p .574 .913 .972 r
F P
0 g
s
.4154 .58268 m .42171 .58156 L .4692 .59319 L p .27 .701 .966 r
F P
0 g
s
.47263 .5915 m .4692 .59319 L .42171 .58156 L p .25 .693 .959 r
F P
0 g
s
.4692 .59319 m .47263 .5915 L .52012 .59567 L p .272 .737 .947 r
F P
0 g
s
.29105 .54309 m .30228 .53941 L .34439 .56945 L p .659 .75 .918 r
F P
0 g
s
.3533 .56597 m .34439 .56945 L .30228 .53941 L p .589 .737 .946 r
F P
0 g
s
.36219 .564 m .3711 .56326 L .4154 .58268 L p .376 .702 .984 r
F P
0 g
s
.42171 .58156 m .4154 .58268 L .3711 .56326 L p .289 .668 .972 r
F P
0 g
s
.68734 .57106 m .67896 .56884 L .71874 .543 L p .683 .867 .969 r
F P
0 g
s
.71874 .543 m .72945 .54382 L .68734 .57106 L p .683 .867 .969 r
F P
0 g
s
.52045 .59316 m .52012 .59567 L .47263 .5915 L p .347 .767 .977 r
F P
0 g
s
.52012 .59567 m .52045 .59316 L .56507 .59059 L p .407 .818 .977 r
F P
0 g
s
.56507 .59059 m .5679 .59293 L .52012 .59567 L p .407 .818 .977 r
F P
0 g
s
.5679 .59293 m .56507 .59059 L .60742 .58166 L p .495 .869 .98 r
F P
0 g
s
.60742 .58166 m .61327 .58338 L .5679 .59293 L p .495 .869 .98 r
F P
0 g
s
.30228 .53941 m .31345 .53737 L .3533 .56597 L p .589 .737 .946 r
F P
0 g
s
.36219 .564 m .3533 .56597 L .31345 .53737 L p .498 .71 .965 r
F P
0 g
s
.61905 .58455 m .61327 .58338 L .65363 .56745 L p .567 .913 .967 r
F P
0 g
s
.65363 .56745 m .66214 .56758 L .61905 .58455 L p .567 .913 .967 r
F P
0 g
s
.42171 .58156 m .42808 .58058 L .47263 .5915 L p .25 .693 .959 r
F P
0 g
s
.4761 .58925 m .47263 .5915 L .42808 .58058 L p .324 .723 .981 r
F P
0 g
s
.47263 .5915 m .4761 .58925 L .52045 .59316 L p .347 .767 .977 r
F P
0 g
s
.67896 .56884 m .67058 .56784 L .70803 .54341 L p .681 .912 .974 r
F P
0 g
s
.70803 .54341 m .71874 .543 L .67896 .56884 L p .681 .912 .974 r
F P
0 g
s
.3711 .56326 m .38005 .56326 L .42171 .58156 L p .289 .668 .972 r
F P
0 g
s
.42808 .58058 m .42171 .58156 L .38005 .56326 L p .272 .66 .968 r
F P
0 g
s
.79464 .57831 m .7837 .57028 L .82329 .5287 L p .585 .629 .861 r
F P
0 g
s
.82329 .5287 m .83625 .53514 L .79464 .57831 L p .585 .629 .861 r
F P
0 g
s
.7837 .57028 m .77275 .56259 L .81037 .52264 L p .591 .638 .866 r
F P
0 g
s
.81037 .52264 m .82329 .5287 L .7837 .57028 L p .591 .638 .866 r
F P
0 g
s
.31345 .53737 m .32459 .53688 L .36219 .564 L p .498 .71 .965 r
F P
0 g
s
.3711 .56326 m .36219 .564 L .32459 .53688 L p .403 .673 .97 r
F P
0 g
s
.52079 .58942 m .52045 .59316 L .4761 .58925 L p .477 .795 .999 r
F P
0 g
s
.52045 .59316 m .52079 .58942 L .5622 .58703 L p .518 .83 1 r
F P
0 g
s
.5622 .58703 m .56507 .59059 L .52045 .59316 L p .518 .83 1 r
F P
0 g
s
.77275 .56259 m .76184 .55576 L .79751 .51745 L p .605 .661 .878 r
F P
0 g
s
.79751 .51745 m .81037 .52264 L .77275 .56259 L p .605 .661 .878 r
F P
0 g
s
.56507 .59059 m .5622 .58703 L .60147 .57873 L p .573 .86 .996 r
F P
0 g
s
.60147 .57873 m .60742 .58166 L .56507 .59059 L p .573 .86 .996 r
F P
0 g
s
.67058 .56784 m .66214 .56758 L .69727 .54458 L p .674 .934 .968 r
F P
0 g
s
.69727 .54458 m .70803 .54341 L .67058 .56784 L p .674 .934 .968 r
F P
0 g
s
.61327 .58338 m .60742 .58166 L .64501 .56679 L p .593 .908 .981 r
F P
0 g
s
.64501 .56679 m .65363 .56745 L .61327 .58338 L p .593 .908 .981 r
F P
0 g
s
.76184 .55576 m .75099 .5502 L .78475 .51356 L p .627 .699 .896 r
F P
0 g
s
.78475 .51356 m .79751 .51745 L .76184 .55576 L p .627 .699 .896 r
F P
0 g
s
.42808 .58058 m .43453 .57904 L .4761 .58925 L p .324 .723 .981 r
F P
0 g
s
.47962 .58579 m .4761 .58925 L .43453 .57904 L p .456 .76 .995 r
F P
0 g
s
.4761 .58925 m .47962 .58579 L .52079 .58942 L p .477 .795 .999 r
F P
0 g
s
.38005 .56326 m .38909 .56341 L .42808 .58058 L p .272 .66 .968 r
F P
0 g
s
.43453 .57904 m .42808 .58058 L .38909 .56341 L p .336 .687 .98 r
F P
0 g
s
.25699 .56223 m .24558 .56996 L .20758 .52532 L p .769 .784 .865 r
F P
0 g
s
.75099 .5502 m .74019 .54619 L .77209 .51125 L p .656 .748 .918 r
F P
0 g
s
.77209 .51125 m .78475 .51356 L .75099 .5502 L p .656 .748 .918 r
F P
0 g
s
.32459 .53688 m .33572 .53763 L .3711 .56326 L p .403 .673 .97 r
F P
0 g
s
.38005 .56326 m .3711 .56326 L .33572 .53763 L p .335 .643 .966 r
F P
0 g
s
.20758 .52532 m .22088 .51927 L .25699 .56223 L p .769 .784 .865 r
F P
0 g
s
.26839 .55486 m .25699 .56223 L .22088 .51927 L p .761 .782 .87 r
F P
0 g
s
.22088 .51927 m .23413 .51358 L .26839 .55486 L p .761 .782 .87 r
F P
0 g
s
.27975 .54834 m .26839 .55486 L .23413 .51358 L p .742 .778 .882 r
F P
0 g
s
.52113 .58389 m .52079 .58942 L .47962 .58579 L p .592 .785 .972 r
F P
0 g
s
.52079 .58942 m .52113 .58389 L .55927 .58168 L p .61 .8 .972 r
F P
0 g
s
.55927 .58168 m .5622 .58703 L .52079 .58942 L p .61 .8 .972 r
F P
0 g
s
.74019 .54619 m .72945 .54382 L .75951 .51062 L p .687 .804 .938 r
F P
0 g
s
.75951 .51062 m .77209 .51125 L .74019 .54619 L p .687 .804 .938 r
F P
0 g
s
.66214 .56758 m .65363 .56745 L .68644 .5459 L p .672 .937 .966 r
F P
0 g
s
.68644 .5459 m .69727 .54458 L .66214 .56758 L p .672 .937 .966 r
F P
0 g
s
.23413 .51358 m .24731 .50878 L .27975 .54834 L p .742 .778 .882 r
F P
0 g
s
.29105 .54309 m .27975 .54834 L .24731 .50878 L p .709 .768 .898 r
F P
0 g
s
.5622 .58703 m .55927 .58168 L .59543 .57401 L p .631 .811 .969 r
F P
0 g
s
.59543 .57401 m .60147 .57873 L .5622 .58703 L p .631 .811 .969 r
F P
0 g
s
.60742 .58166 m .60147 .57873 L .63628 .56492 L p .631 .879 .987 r
F P
0 g
s
.63628 .56492 m .64501 .56679 L .60742 .58166 L p .631 .879 .987 r
F P
0 g
s
.43453 .57904 m .44109 .5763 L .47962 .58579 L p .456 .76 .995 r
F P
0 g
s
.48321 .58053 m .47962 .58579 L .44109 .5763 L p .58 .768 .968 r
F P
0 g
s
.47962 .58579 m .48321 .58053 L .52113 .58389 L p .592 .785 .972 r
F P
0 g
s
.24731 .50878 m .26039 .50528 L .29105 .54309 L p .709 .768 .898 r
F P
0 g
s
.30228 .53941 m .29105 .54309 L .26039 .50528 L p .659 .751 .918 r
F P
0 g
s
.38909 .56341 m .39822 .56301 L .43453 .57904 L p .336 .687 .98 r
F P
0 g
s
.44109 .5763 m .43453 .57904 L .39822 .56301 L p .454 .727 .985 r
F P
0 g
s
.33572 .53763 m .34689 .53915 L .38005 .56326 L p .335 .643 .966 r
F P
0 g
s
.38909 .56341 m .38005 .56326 L .34689 .53915 L p .322 .637 .964 r
F P
0 g
s
.72945 .54382 m .71874 .543 L .74699 .51155 L p .715 .859 .95 r
F P
0 g
s
.74699 .51155 m .75951 .51062 L .72945 .54382 L p .715 .859 .95 r
F P
0 g
s
.26039 .50528 m .27336 .50337 L .30228 .53941 L p .659 .751 .918 r
F P
0 g
s
.31345 .53737 m .30228 .53941 L .27336 .50337 L p .593 .724 .935 r
F P
0 g
s
.52147 .57614 m .52113 .58389 L .48321 .58053 L p .661 .748 .914 r
F P
0 g
s
.52113 .58389 m .52147 .57614 L .5563 .57412 L p .659 .746 .914 r
F P
0 g
s
.5563 .57412 m .55927 .58168 L .52113 .58389 L p .659 .746 .914 r
F P
0 g
s
.65363 .56745 m .64501 .56679 L .6755 .54669 L p .679 .923 .972 r
F P
0 g
s
.6755 .54669 m .68644 .5459 L .65363 .56745 L p .679 .923 .972 r
F P
0 g
s
.55927 .58168 m .5563 .57412 L .58929 .56709 L p .656 .744 .915 r
F P
0 g
s
.58929 .56709 m .59543 .57401 L .55927 .58168 L p .656 .744 .915 r
F P
0 g
s
.60147 .57873 m .59543 .57401 L .62741 .56126 L p .653 .818 .963 r
F P
0 g
s
.62741 .56126 m .63628 .56492 L .60147 .57873 L p .653 .818 .963 r
F P
0 g
s
.71874 .543 m .70803 .54341 L .7345 .51374 L p .735 .901 .953 r
F P
0 g
s
.7345 .51374 m .74699 .51155 L .71874 .543 L p .735 .901 .953 r
F P
0 g
s
.44109 .5763 m .44775 .57177 L .48321 .58053 L p .58 .768 .968 r
F P
0 g
s
.48686 .57306 m .48321 .58053 L .44775 .57177 L p .663 .75 .915 r
F P
0 g
s
.48321 .58053 m .48686 .57306 L .52147 .57614 L p .661 .748 .914 r
F P
0 g
s
.27336 .50337 m .28624 .50313 L .31345 .53737 L p .593 .724 .935 r
F P
0 g
s
.32459 .53688 m .31345 .53737 L .28624 .50313 L p .516 .689 .946 r
F P
0 g
s
.39822 .56301 m .40749 .56141 L .44109 .5763 L p .454 .727 .985 r
F P
0 g
s
.44775 .57177 m .44109 .5763 L .40749 .56141 L p .574 .751 .961 r
F P
0 g
s
.34689 .53915 m .35814 .54081 L .38909 .56341 L p .322 .637 .964 r
F P
0 g
s
.39822 .56301 m .38909 .56341 L .35814 .54081 L p .372 .66 .969 r
F P
0 g
s
.52182 .56599 m .52147 .57614 L .48686 .57306 L p .695 .708 .858 r
F P
0 g
s
.52147 .57614 m .52182 .56599 L .55329 .56415 L p .68 .695 .858 r
F P
0 g
s
.55329 .56415 m .5563 .57412 L .52147 .57614 L p .68 .695 .858 r
F P
0 g
s
.64501 .56679 m .63628 .56492 L .66442 .54628 L p .682 .884 .973 r
F P
0 g
s
.66442 .54628 m .6755 .54669 L .64501 .56679 L p .682 .884 .973 r
F P
0 g
s
.28624 .50313 m .29905 .50447 L .32459 .53688 L p .516 .689 .946 r
F P
0 g
s
.33572 .53763 m .32459 .53688 L .29905 .50447 L p .442 .651 .948 r
F P
0 g
s
.70803 .54341 m .69727 .54458 L .72199 .5167 L p .744 .925 .951 r
F P
0 g
s
.72199 .5167 m .7345 .51374 L .70803 .54341 L p .744 .925 .951 r
F P
0 g
s
.5563 .57412 m .55329 .56415 L .58305 .55776 L p .662 .684 .861 r
F P
0 g
s
.58305 .55776 m .58929 .56709 L .5563 .57412 L p .662 .684 .861 r
F P
0 g
s
.59543 .57401 m .58929 .56709 L .61841 .55541 L p .654 .744 .916 r
F P
0 g
s
.61841 .55541 m .62741 .56126 L .59543 .57401 L p .654 .744 .916 r
F P
0 g
s
.44775 .57177 m .45451 .56503 L .48686 .57306 L p .663 .75 .915 r
F P
0 g
s
.49056 .56319 m .48686 .57306 L .45451 .56503 L p .709 .724 .862 r
F P
0 g
s
.48686 .57306 m .49056 .56319 L .52182 .56599 L p .695 .708 .858 r
F P
0 g
s
.40749 .56141 m .41689 .55803 L .44775 .57177 L p .574 .751 .961 r
F P
0 g
s
.45451 .56503 m .44775 .57177 L .41689 .55803 L p .664 .752 .916 r
F P
0 g
s
.35814 .54081 m .3695 .54195 L .39822 .56301 L p .372 .66 .969 r
F P
0 g
s
.40749 .56141 m .39822 .56301 L .3695 .54195 L p .467 .699 .969 r
F P
0 g
s
.52218 .55349 m .52182 .56599 L .49056 .56319 L p .712 .677 .815 r
F P
0 g
s
.52182 .56599 m .52218 .55349 L .55023 .55184 L p .687 .657 .814 r
F P
0 g
s
.55023 .55184 m .55329 .56415 L .52182 .56599 L p .687 .657 .814 r
F P
0 g
s
.29905 .50447 m .31183 .50707 L .33572 .53763 L p .442 .651 .948 r
F P
0 g
s
.34689 .53915 m .33572 .53763 L .31183 .50707 L p .392 .624 .945 r
F P
0 g
s
.55329 .56415 m .55023 .55184 L .57675 .54611 L p .661 .64 .818 r
F P
0 g
s
.57675 .54611 m .58305 .55776 L .55329 .56415 L p .661 .64 .818 r
F P
0 g
s
.69727 .54458 m .68644 .5459 L .70941 .51982 L p .746 .929 .95 r
F P
0 g
s
.70941 .51982 m .72199 .5167 L .69727 .54458 L p .746 .929 .95 r
F P
0 g
s
.63628 .56492 m .62741 .56126 L .65319 .54409 L p .673 .819 .953 r
F P
0 g
s
.65319 .54409 m .66442 .54628 L .63628 .56492 L p .673 .819 .953 r
F P
0 g
s
.45451 .56503 m .46138 .55589 L .49056 .56319 L p .709 .724 .862 r
F P
0 g
s
.49431 .55098 m .49056 .56319 L .46138 .55589 L p .735 .702 .82 r
F P
0 g
s
.49056 .56319 m .49431 .55098 L .52218 .55349 L p .712 .677 .815 r
F P
0 g
s
.58929 .56709 m .58305 .55776 L .6093 .54717 L p .644 .677 .867 r
F P
0 g
s
.6093 .54717 m .61841 .55541 L .58929 .56709 L p .644 .677 .867 r
F P
0 g
s
.41689 .55803 m .42643 .55245 L .45451 .56503 L p .664 .752 .916 r
F P
0 g
s
.46138 .55589 m .45451 .56503 L .42643 .55245 L p .721 .742 .869 r
F P
0 g
s
.52254 .53896 m .52218 .55349 L .49431 .55098 L p .72 .656 .785 r
F P
0 g
s
.52218 .55349 m .52254 .53896 L .54714 .5375 L p .69 .631 .784 r
F P
0 g
s
.54714 .5375 m .55023 .55184 L .52218 .55349 L p .69 .631 .784 r
F P
0 g
s
.3695 .54195 m .38099 .54189 L .40749 .56141 L p .467 .699 .969 r
F P
0 g
s
.41689 .55803 m .40749 .56141 L .38099 .54189 L p .574 .735 .951 r
F P
0 g
s
.55023 .55184 m .54714 .5375 L .57038 .53243 L p .658 .609 .789 r
F P
0 g
s
.57038 .53243 m .57675 .54611 L .55023 .55184 L p .658 .609 .789 r
F P
0 g
s
.46138 .55589 m .46832 .54443 L .49431 .55098 L p .735 .702 .82 r
F P
0 g
s
.4981 .53674 m .49431 .55098 L .46832 .54443 L p .748 .685 .79 r
F P
0 g
s
.49431 .55098 m .4981 .53674 L .52254 .53896 L p .72 .656 .785 r
F P
0 g
s
.31183 .50707 m .32462 .51044 L .34689 .53915 L p .392 .624 .945 r
F P
0 g
s
.35814 .54081 m .34689 .53915 L .32462 .51044 L p .383 .619 .945 r
F P
0 g
s
.58305 .55776 m .57675 .54611 L .60008 .5366 L p .632 .627 .827 r
F P
0 g
s
.60008 .5366 m .6093 .54717 L .58305 .55776 L p .632 .627 .827 r
F P
0 g
s
.68644 .5459 m .6755 .54669 L .69672 .52242 L p .739 .913 .952 r
F P
0 g
s
.69672 .52242 m .70941 .51982 L .68644 .5459 L p .739 .913 .952 r
F P
0 g
s
.62741 .56126 m .61841 .55541 L .64182 .5397 L p .651 .743 .917 r
F P
0 g
s
.64182 .5397 m .65319 .54409 L .62741 .56126 L p .651 .743 .917 r
F P
0 g
s
.83625 .53514 m .82329 .5287 L .84476 .48133 L p .557 .633 .882 r
F P
0 g
s
.84476 .48133 m .85906 .48583 L .83625 .53514 L p .557 .633 .882 r
F P
0 g
s
.82329 .5287 m .81037 .52264 L .83054 .47721 L p .565 .642 .886 r
F P
0 g
s
.83054 .47721 m .84476 .48133 L .82329 .5287 L p .565 .642 .886 r
F P
0 g
s
.5229 .52295 m .52254 .53896 L .4981 .53674 L p .724 .643 .767 r
F P
0 g
s
.52254 .53896 m .5229 .52295 L .54403 .52168 L p .691 .615 .766 r
F P
0 g
s
.54403 .52168 m .54714 .5375 L .52254 .53896 L p .691 .615 .766 r
F P
0 g
s
.81037 .52264 m .79751 .51745 L .81642 .47399 L p .585 .666 .894 r
F P
0 g
s
.81642 .47399 m .83054 .47721 L .81037 .52264 L p .585 .666 .894 r
F P
0 g
s
.42643 .55245 m .43608 .54449 L .46138 .55589 L p .721 .742 .869 r
F P
0 g
s
.46832 .54443 m .46138 .55589 L .43608 .54449 L p .755 .73 .829 r
F P
0 g
s
.79751 .51745 m .78475 .51356 L .80244 .47209 L p .616 .702 .906 r
F P
0 g
s
.80244 .47209 m .81642 .47399 L .79751 .51745 L p .616 .702 .906 r
F P
0 g
s
.54714 .5375 m .54403 .52168 L .56398 .51728 L p .655 .591 .771 r
F P
0 g
s
.56398 .51728 m .57038 .53243 L .54714 .5375 L p .655 .591 .771 r
F P
0 g
s
.78475 .51356 m .77209 .51125 L .7886 .4718 L p .655 .748 .918 r
F P
0 g
s
.7886 .4718 m .80244 .47209 L .78475 .51356 L p .655 .748 .918 r
F P
0 g
s
.46832 .54443 m .47533 .53095 L .4981 .53674 L p .748 .685 .79 r
F P
0 g
s
.50191 .52102 m .4981 .53674 L .47533 .53095 L p .756 .675 .772 r
F P
0 g
s
.4981 .53674 m .50191 .52102 L .5229 .52295 L p .724 .643 .767 r
F P
0 g
s
.38099 .54189 m .39264 .54005 L .41689 .55803 L p .574 .735 .951 r
F P
0 g
s
.42643 .55245 m .41689 .55803 L .39264 .54005 L p .665 .755 .917 r
F P
0 g
s
.57675 .54611 m .57038 .53243 L .5908 .52404 L p .622 .592 .798 r
F P
0 g
s
.5908 .52404 m .60008 .5366 L .57675 .54611 L p .622 .592 .798 r
F P
0 g
s
.52327 .50615 m .5229 .52295 L .50191 .52102 L p .726 .637 .759 r
F P
0 g
s
.5229 .52295 m .52327 .50615 L .54091 .50508 L p .691 .608 .758 r
F P
0 g
s
.54091 .50508 m .54403 .52168 L .5229 .52295 L p .691 .608 .758 r
F P
0 g
s
.77209 .51125 m .75951 .51062 L .77489 .4732 L p .697 .797 .927 r
F P
0 g
s
.77489 .4732 m .7886 .4718 L .77209 .51125 L p .697 .797 .927 r
F P
0 g
s
.54403 .52168 m .54091 .50508 L .55754 .50138 L p .654 .583 .763 r
F P
0 g
s
.55754 .50138 m .56398 .51728 L .54403 .52168 L p .654 .583 .763 r
F P
0 g
s
.32462 .51044 m .33748 .51397 L .35814 .54081 L p .383 .619 .945 r
F P
0 g
s
.3695 .54195 m .35814 .54081 L .33748 .51397 L p .419 .639 .947 r
F P
0 g
s
.43608 .54449 m .44584 .5342 L .46832 .54443 L p .755 .73 .829 r
F P
0 g
s
.47533 .53095 m .46832 .54443 L .44584 .5342 L p .774 .719 .801 r
F P
0 g
s
.61841 .55541 m .6093 .54717 L .63032 .53294 L p .625 .673 .876 r
F P
0 g
s
.63032 .53294 m .64182 .5397 L .61841 .55541 L p .625 .673 .876 r
F P
0 g
s
.47533 .53095 m .48238 .516 L .50191 .52102 L p .756 .675 .772 r
F P
0 g
s
.50575 .50452 m .50191 .52102 L .48238 .516 L p .758 .67 .764 r
F P
0 g
s
.50191 .52102 m .50575 .50452 L .52327 .50615 L p .726 .637 .759 r
F P
0 g
s
.6755 .54669 m .66442 .54628 L .68391 .52382 L p .721 .874 .953 r
F P
0 g
s
.68391 .52382 m .69672 .52242 L .6755 .54669 L p .721 .874 .953 r
F P
0 g
s
.57038 .53243 m .56398 .51728 L .58146 .51002 L p .616 .571 .781 r
F P
0 g
s
.58146 .51002 m .5908 .52404 L .57038 .53243 L p .616 .571 .781 r
F P
0 g
s
.52364 .48938 m .52327 .50615 L .50575 .50452 L p .726 .638 .76 r
F P
0 g
s
.52327 .50615 m .52364 .48938 L .53777 .48852 L p .691 .609 .759 r
F P
0 g
s
.53777 .48852 m .54091 .50508 L .52327 .50615 L p .691 .609 .759 r
F P
0 g
s
.75951 .51062 m .74699 .51155 L .76128 .47619 L p .736 .842 .93 r
F P
0 g
s
.76128 .47619 m .77489 .4732 L .75951 .51062 L p .736 .842 .93 r
F P
0 g
s
.54091 .50508 m .53777 .48852 L .55109 .48552 L p .654 .584 .764 r
F P
0 g
s
.55109 .48552 m .55754 .50138 L .54091 .50508 L p .654 .584 .764 r
F P
0 g
s
.44584 .5342 m .45568 .52192 L .47533 .53095 L p .774 .719 .801 r
F P
0 g
s
.48238 .516 m .47533 .53095 L .45568 .52192 L p .785 .712 .783 r
F P
0 g
s
.48238 .516 m .48946 .5003 L .50575 .50452 L p .758 .67 .764 r
F P
0 g
s
.50959 .48807 m .50575 .50452 L .48946 .5003 L p .758 .671 .765 r
F P
0 g
s
.50575 .50452 m .50959 .48807 L .52364 .48938 L p .726 .638 .76 r
F P
0 g
s
.39264 .54005 m .40442 .53602 L .42643 .55245 L p .665 .755 .917 r
F P
0 g
s
.43608 .54449 m .42643 .55245 L .40442 .53602 L p .729 .762 .879 r
F P
0 g
s
.56398 .51728 m .55754 .50138 L .5721 .49527 L p .613 .561 .772 r
F P
0 g
s
.5721 .49527 m .58146 .51002 L .56398 .51728 L p .613 .561 .772 r
F P
0 g
s
.20357 .471 m .21796 .46732 L .23413 .51358 L p .763 .81 .89 r
F P
0 g
s
.23413 .51358 m .22088 .51927 L .20357 .471 L p .763 .81 .89 r
F P
0 g
s
.24731 .50878 m .23413 .51358 L .21796 .46732 L p .742 .799 .898 r
F P
0 g
s
.18911 .47507 m .20357 .471 L .22088 .51927 L p .771 .814 .887 r
F P
0 g
s
.22088 .51927 m .20758 .52532 L .18911 .47507 L p .771 .814 .887 r
F P
0 g
s
.21796 .46732 m .23223 .46454 L .24731 .50878 L p .742 .799 .898 r
F P
0 g
s
.26039 .50528 m .24731 .50878 L .23223 .46454 L p .707 .78 .908 r
F P
0 g
s
.6093 .54717 m .60008 .5366 L .61872 .52386 L p .601 .618 .84 r
F P
0 g
s
.61872 .52386 m .63032 .53294 L .6093 .54717 L p .601 .618 .84 r
F P
0 g
s
.524 .47345 m .52364 .48938 L .50959 .48807 L p .723 .645 .77 r
F P
0 g
s
.52364 .48938 m .524 .47345 L .53463 .47279 L p .691 .618 .77 r
F P
0 g
s
.53463 .47279 m .53777 .48852 L .52364 .48938 L p .691 .618 .77 r
F P
0 g
s
.23223 .46454 m .24636 .46309 L .26039 .50528 L p .707 .78 .908 r
F P
0 g
s
.27336 .50337 m .26039 .50528 L .24636 .46309 L p .659 .751 .918 r
F P
0 g
s
.45568 .52192 m .46556 .50819 L .48238 .516 L p .785 .712 .783 r
F P
0 g
s
.48946 .5003 m .48238 .516 L .46556 .50819 L p .79 .709 .775 r
F P
0 g
s
.53777 .48852 m .53463 .47279 L .54463 .47052 L p .656 .595 .774 r
F P
0 g
s
.54463 .47052 m .55109 .48552 L .53777 .48852 L p .656 .595 .774 r
F P
0 g
s
.33748 .51397 m .35043 .51698 L .3695 .54195 L p .419 .639 .947 r
F P
0 g
s
.38099 .54189 m .3695 .54195 L .35043 .51698 L p .491 .677 .948 r
F P
0 g
s
.48946 .5003 m .49656 .48465 L .50959 .48807 L p .758 .671 .765 r
F P
0 g
s
.51345 .47245 m .50959 .48807 L .49656 .48465 L p .754 .677 .776 r
F P
0 g
s
.50959 .48807 m .51345 .47245 L .524 .47345 L p .723 .645 .77 r
F P
0 g
s
.74699 .51155 m .7345 .51374 L .74772 .48045 L p .765 .875 .927 r
F P
0 g
s
.74772 .48045 m .76128 .47619 L .74699 .51155 L p .765 .875 .927 r
F P
0 g
s
.55754 .50138 m .55109 .48552 L .56273 .48058 L p .613 .562 .773 r
F P
0 g
s
.56273 .48058 m .5721 .49527 L .55754 .50138 L p .613 .562 .773 r
F P
0 g
s
.66442 .54628 m .65319 .54409 L .67095 .52343 L p .69 .815 .942 r
F P
0 g
s
.67095 .52343 m .68391 .52382 L .66442 .54628 L p .69 .815 .942 r
F P
0 g
s
.24636 .46309 m .26034 .46325 L .27336 .50337 L p .659 .751 .918 r
F P
0 g
s
.28624 .50313 m .27336 .50337 L .26034 .46325 L p .6 .715 .925 r
F P
0 g
s
.40442 .53602 m .41634 .5296 L .43608 .54449 L p .729 .762 .879 r
F P
0 g
s
.44584 .5342 m .43608 .54449 L .41634 .5296 L p .772 .762 .844 r
F P
0 g
s
.46556 .50819 m .47546 .49373 L .48946 .5003 L p .79 .709 .775 r
F P
0 g
s
.49656 .48465 m .48946 .5003 L .47546 .49373 L p .789 .709 .776 r
F P
0 g
s
.60008 .5366 m .5908 .52404 L .60704 .5128 L p .582 .578 .813 r
F P
0 g
s
.60704 .5128 m .61872 .52386 L .60008 .5366 L p .582 .578 .813 r
F P
0 g
s
.52437 .45908 m .524 .47345 L .51345 .47245 L p .718 .661 .792 r
F P
0 g
s
.524 .47345 m .52437 .45908 L .53147 .45864 L p .69 .637 .792 r
F P
0 g
s
.53147 .45864 m .53463 .47279 L .524 .47345 L p .69 .637 .792 r
F P
0 g
s
.55109 .48552 m .54463 .47052 L .55335 .46678 L p .617 .575 .784 r
F P
0 g
s
.55335 .46678 m .56273 .48058 L .55109 .48552 L p .617 .575 .784 r
F P
0 g
s
.53463 .47279 m .53147 .45864 L .53815 .45711 L p .659 .617 .796 r
F P
0 g
s
.53815 .45711 m .54463 .47052 L .53463 .47279 L p .659 .617 .796 r
F P
0 g
s
.47546 .49373 m .48537 .47934 L .49656 .48465 L p .789 .709 .776 r
F P
0 g
s
.50366 .46986 m .49656 .48465 L .48537 .47934 L p .783 .714 .787 r
F P
0 g
s
.49656 .48465 m .50366 .46986 L .51345 .47245 L p .754 .677 .776 r
F P
0 g
s
.51732 .45841 m .51345 .47245 L .50366 .46986 L p .745 .689 .797 r
F P
0 g
s
.51345 .47245 m .51732 .45841 L .52437 .45908 L p .718 .661 .792 r
F P
0 g
s
.26034 .46325 m .27418 .46511 L .28624 .50313 L p .6 .715 .925 r
F P
0 g
s
.29905 .50447 m .28624 .50313 L .27418 .46511 L p .538 .674 .925 r
F P
0 g
s
.5908 .52404 m .58146 .51002 L .59533 .50031 L p .57 .553 .796 r
F P
0 g
s
.59533 .50031 m .60704 .5128 L .5908 .52404 L p .57 .553 .796 r
F P
0 g
s
.41634 .5296 m .42836 .52088 L .44584 .5342 L p .772 .762 .844 r
F P
0 g
s
.45568 .52192 m .44584 .5342 L .42836 .52088 L p .798 .759 .817 r
F P
0 g
s
.7345 .51374 m .72199 .5167 L .73418 .4855 L p .782 .895 .924 r
F P
0 g
s
.73418 .4855 m .74772 .48045 L .7345 .51374 L p .782 .895 .924 r
F P
0 g
s
.58146 .51002 m .5721 .49527 L .58361 .48711 L p .565 .542 .788 r
F P
0 g
s
.58361 .48711 m .59533 .50031 L .58146 .51002 L p .565 .542 .788 r
F P
0 g
s
.54463 .47052 m .53815 .45711 L .54396 .4546 L p .625 .601 .805 r
F P
0 g
s
.54396 .4546 m .55335 .46678 L .54463 .47052 L p .625 .601 .805 r
F P
0 g
s
.35043 .51698 m .36351 .51879 L .38099 .54189 L p .491 .677 .948 r
F P
0 g
s
.39264 .54005 m .38099 .54189 L .36351 .51879 L p .58 .721 .939 r
F P
0 g
s
.42836 .52088 m .44044 .51018 L .45568 .52192 L p .798 .759 .817 r
F P
0 g
s
.46556 .50819 m .45568 .52192 L .44044 .51018 L p .813 .756 .8 r
F P
0 g
s
.48537 .47934 m .49529 .46584 L .50366 .46986 L p .783 .714 .787 r
F P
0 g
s
.51078 .45667 m .50366 .46986 L .49529 .46584 L p .77 .721 .808 r
F P
0 g
s
.50366 .46986 m .51078 .45667 L .51732 .45841 L p .745 .689 .797 r
F P
0 g
s
.65319 .54409 m .64182 .5397 L .65786 .52085 L p .649 .744 .919 r
F P
0 g
s
.65786 .52085 m .67095 .52343 L .65319 .54409 L p .649 .744 .919 r
F P
0 g
s
.5721 .49527 m .56273 .48058 L .5719 .47401 L p .565 .543 .789 r
F P
0 g
s
.5719 .47401 m .58361 .48711 L .5721 .49527 L p .565 .543 .789 r
F P
0 g
s
.44044 .51018 m .45256 .49804 L .46556 .50819 L p .813 .756 .8 r
F P
0 g
s
.47546 .49373 m .46556 .50819 L .45256 .49804 L p .819 .755 .792 r
F P
0 g
s
.52474 .44687 m .52437 .45908 L .51732 .45841 L p .707 .687 .828 r
F P
0 g
s
.52437 .45908 m .52474 .44687 L .5283 .44665 L p .686 .669 .828 r
F P
0 g
s
.5283 .44665 m .53147 .45864 L .52437 .45908 L p .686 .669 .828 r
F P
0 g
s
.27418 .46511 m .28792 .46855 L .29905 .50447 L p .538 .674 .925 r
F P
0 g
s
.31183 .50707 m .29905 .50447 L .28792 .46855 L p .484 .636 .922 r
F P
0 g
s
.56273 .48058 m .55335 .46678 L .5602 .46181 L p .573 .558 .799 r
F P
0 g
s
.5602 .46181 m .5719 .47401 L .56273 .48058 L p .573 .558 .799 r
F P
0 g
s
.53147 .45864 m .5283 .44665 L .53165 .44588 L p .663 .654 .831 r
F P
0 g
s
.53165 .44588 m .53815 .45711 L .53147 .45864 L p .663 .654 .831 r
F P
0 g
s
.5212 .44653 m .51732 .45841 L .51078 .45667 L p .727 .708 .833 r
F P
0 g
s
.51732 .45841 m .5212 .44653 L .52474 .44687 L p .707 .687 .828 r
F P
0 g
s
.45256 .49804 m .46469 .48521 L .47546 .49373 L p .819 .755 .792 r
F P
0 g
s
.48537 .47934 m .47546 .49373 L .46469 .48521 L p .818 .755 .793 r
F P
0 g
s
.46469 .48521 m .4768 .47247 L .48537 .47934 L p .818 .755 .793 r
F P
0 g
s
.49529 .46584 m .48537 .47934 L .4768 .47247 L p .81 .757 .803 r
F P
0 g
s
.55335 .46678 m .54396 .4546 L .54852 .45126 L p .588 .588 .82 r
F P
0 g
s
.54852 .45126 m .5602 .46181 L .55335 .46678 L p .588 .588 .82 r
F P
0 g
s
.53815 .45711 m .53165 .44588 L .53456 .44461 L p .638 .643 .839 r
F P
0 g
s
.53456 .44461 m .54396 .4546 L .53815 .45711 L p .638 .643 .839 r
F P
0 g
s
.49529 .46584 m .5052 .45397 L .51078 .45667 L p .77 .721 .808 r
F P
0 g
s
.51793 .44565 m .51078 .45667 L .5052 .45397 L p .744 .732 .841 r
F P
0 g
s
.51078 .45667 m .51793 .44565 L .5212 .44653 L p .727 .708 .833 r
F P
0 g
s
.72199 .5167 m .70941 .51982 L .72059 .4907 L p .785 .898 .923 r
F P
0 g
s
.72059 .4907 m .73418 .4855 L .72199 .5167 L p .785 .898 .923 r
F P
0 g
s
.4768 .47247 m .48888 .46065 L .49529 .46584 L p .81 .757 .803 r
F P
0 g
s
.5052 .45397 m .49529 .46584 L .48888 .46065 L p .791 .759 .824 r
F P
0 g
s
.64182 .5397 m .63032 .53294 L .64465 .5159 L p .605 .674 .889 r
F P
0 g
s
.64465 .5159 m .65786 .52085 L .64182 .5397 L p .605 .674 .889 r
F P
0 g
s
.36351 .51879 m .37673 .51881 L .39264 .54005 L p .58 .721 .939 r
F P
0 g
s
.40442 .53602 m .39264 .54005 L .37673 .51881 L p .665 .757 .919 r
F P
0 g
s
.28792 .46855 m .30159 .47327 L .31183 .50707 L p .484 .636 .922 r
F P
0 g
s
.32462 .51044 m .31183 .50707 L .30159 .47327 L p .45 .612 .918 r
F P
0 g
s
.54396 .4546 m .53456 .44461 L .53683 .44293 L p .611 .637 .851 r
F P
0 g
s
.53683 .44293 m .54852 .45126 L .54396 .4546 L p .611 .637 .851 r
F P
0 g
s
.48888 .46065 m .50095 .45048 L .5052 .45397 L p .791 .759 .824 r
F P
0 g
s
.51514 .44429 m .5052 .45397 L .50095 .45048 L p .757 .76 .855 r
F P
0 g
s
.5052 .45397 m .51514 .44429 L .51793 .44565 L p .744 .732 .841 r
F P
0 g
s
.63032 .53294 m .61872 .52386 L .63135 .50864 L p .567 .614 .859 r
F P
0 g
s
.63135 .50864 m .64465 .5159 L .63032 .53294 L p .567 .614 .859 r
F P
0 g
s
.52511 .4372 m .52474 .44687 L .5212 .44653 L closepath p .682 .724 .882 r
F P
0 g
s
.52511 .4372 m .5283 .44665 L .52474 .44687 L closepath p .673 .717 .882 r
F P
0 g
s
.52511 .4372 m .53165 .44588 L .5283 .44665 L closepath p .663 .711 .883 r
F P
0 g
s
.52511 .4372 m .5212 .44653 L .51793 .44565 L closepath p .69 .734 .884 r
F P
0 g
s
.5719 .47401 m .5602 .46181 L .56472 .45593 L p .521 .545 .821 r
F P
0 g
s
.5602 .46181 m .54852 .45126 L .5515 .44732 L p .546 .581 .841 r
F P
0 g
s
.5515 .44732 m .56472 .45593 L .5602 .46181 L p .546 .581 .841 r
F P
0 g
s
.58361 .48711 m .5719 .47401 L .57797 .46621 L p .508 .527 .811 r
F P
0 g
s
.56472 .45593 m .57797 .46621 L .5719 .47401 L p .521 .545 .821 r
F P
0 g
s
.37673 .51881 m .39009 .51665 L .40442 .53602 L p .665 .757 .919 r
F P
0 g
s
.41634 .5296 m .40442 .53602 L .39009 .51665 L p .733 .782 .892 r
F P
0 g
s
.52511 .4372 m .53456 .44461 L .53165 .44588 L closepath p .653 .707 .887 r
F P
0 g
s
.52511 .4372 m .51793 .44565 L .51514 .44429 L closepath p .696 .744 .888 r
F P
0 g
s
.59533 .50031 m .58361 .48711 L .59128 .47742 L p .507 .526 .81 r
F P
0 g
s
.57797 .46621 m .59128 .47742 L .58361 .48711 L p .508 .527 .811 r
F P
0 g
s
.61872 .52386 m .60704 .5128 L .618 .4994 L p .537 .569 .835 r
F P
0 g
s
.618 .4994 m .63135 .50864 L .61872 .52386 L p .537 .569 .835 r
F P
0 g
s
.54852 .45126 m .53683 .44293 L .53831 .44095 L p .583 .635 .868 r
F P
0 g
s
.53831 .44095 m .5515 .44732 L .54852 .45126 L p .583 .635 .868 r
F P
0 g
s
.70941 .51982 m .69672 .52242 L .70692 .49537 L p .773 .885 .926 r
F P
0 g
s
.70692 .49537 m .72059 .4907 L .70941 .51982 L p .773 .885 .926 r
F P
0 g
s
.60704 .5128 m .59533 .50031 L .60463 .48876 L p .517 .539 .818 r
F P
0 g
s
.59128 .47742 m .60463 .48876 L .59533 .50031 L p .507 .526 .81 r
F P
0 g
s
.47143 .46448 m .4849 .45463 L .48888 .46065 L p .832 .807 .827 r
F P
0 g
s
.48888 .46065 m .4768 .47247 L .47143 .46448 L p .832 .807 .827 r
F P
0 g
s
.50095 .45048 m .48888 .46065 L .4849 .45463 L p .808 .801 .846 r
F P
0 g
s
.60463 .48876 m .618 .4994 L .60704 .5128 L p .517 .539 .818 r
F P
0 g
s
.52511 .4372 m .53683 .44293 L .53456 .44461 L closepath p .642 .705 .893 r
F P
0 g
s
.45789 .47527 m .47143 .46448 L .4768 .47247 L p .844 .809 .816 r
F P
0 g
s
.4768 .47247 m .46469 .48521 L .45789 .47527 L p .844 .809 .816 r
F P
0 g
s
.50095 .45048 m .51302 .44254 L .51514 .44429 L p .757 .76 .855 r
F P
0 g
s
.52511 .4372 m .51514 .44429 L .51302 .44254 L closepath p .7 .755 .894 r
F P
0 g
s
.4849 .45463 m .49833 .44644 L .50095 .45048 L p .808 .801 .846 r
F P
0 g
s
.51302 .44254 m .50095 .45048 L .49833 .44644 L p .766 .789 .872 r
F P
0 g
s
.30159 .47327 m .31524 .47877 L .32462 .51044 L p .45 .612 .918 r
F P
0 g
s
.33748 .51397 m .32462 .51044 L .31524 .47877 L p .443 .607 .917 r
F P
0 g
s
.44431 .48619 m .45789 .47527 L .46469 .48521 L p .845 .809 .815 r
F P
0 g
s
.46469 .48521 m .45256 .49804 L .44431 .48619 L p .845 .809 .815 r
F P
0 g
s
.39009 .51665 m .40356 .5121 L .41634 .5296 L p .733 .782 .892 r
F P
0 g
s
.42836 .52088 m .41634 .5296 L .40356 .5121 L p .783 .797 .864 r
F P
0 g
s
.52511 .4372 m .53831 .44095 L .53683 .44293 L closepath p .632 .706 .9 r
F P
0 g
s
.49833 .44644 m .51172 .44051 L .51302 .44254 L p .766 .789 .872 r
F P
0 g
s
.52511 .4372 m .51302 .44254 L .51172 .44051 L closepath p .701 .765 .902 r
F P
0 g
s
.43071 .49643 m .44431 .48619 L .45256 .49804 L p .836 .808 .823 r
F P
0 g
s
.45256 .49804 m .44044 .51018 L .43071 .49643 L p .836 .808 .823 r
F P
0 g
s
.40356 .5121 m .41711 .50525 L .42836 .52088 L p .783 .797 .864 r
F P
0 g
s
.44044 .51018 m .42836 .52088 L .41711 .50525 L p .816 .804 .84 r
F P
0 g
s
.41711 .50525 m .43071 .49643 L .44044 .51018 L p .816 .804 .84 r
F P
0 g
s
.56472 .45593 m .5515 .44732 L .5527 .44303 L p .497 .578 .867 r
F P
0 g
s
.5515 .44732 m .53831 .44095 L .53889 .4388 L p .554 .638 .889 r
F P
0 g
s
.53889 .4388 m .5527 .44303 L .5515 .44732 L p .554 .638 .889 r
F P
0 g
s
.52511 .4372 m .53889 .4388 L .53831 .44095 L closepath p .623 .71 .908 r
F P
0 g
s
.49752 .44213 m .51134 .43835 L .51172 .44051 L p .767 .819 .893 r
F P
0 g
s
.51172 .44051 m .49833 .44644 L .49752 .44213 L p .767 .819 .893 r
F P
0 g
s
.52511 .4372 m .51172 .44051 L .51134 .43835 L closepath p .7 .775 .91 r
F P
0 g
s
.48363 .44816 m .49752 .44213 L .49833 .44644 L p .815 .848 .873 r
F P
0 g
s
.49833 .44644 m .4849 .45463 L .48363 .44816 L p .815 .848 .873 r
F P
0 g
s
.57797 .46621 m .56472 .45593 L .56656 .44952 L p .457 .536 .85 r
F P
0 g
s
.5527 .44303 m .56656 .44952 L .56472 .45593 L p .497 .578 .867 r
F P
0 g
s
.69672 .52242 m .68391 .52382 L .69315 .49884 L p .746 .854 .93 r
F P
0 g
s
.69315 .49884 m .70692 .49537 L .69672 .52242 L p .746 .854 .93 r
F P
0 g
s
.52511 .4372 m .53515 .43282 L .53726 .43459 L closepath p .608 .735 .935 r
F P
0 g
s
.52511 .4372 m .53236 .43144 L .53515 .43282 L closepath p .609 .746 .942 r
F P
0 g
s
.52511 .4372 m .52906 .43054 L .53236 .43144 L closepath p .615 .758 .948 r
F P
0 g
s
.52511 .4372 m .52549 .4302 L .52906 .43054 L closepath p .623 .77 .95 r
F P
0 g
s
.52511 .4372 m .5219 .43042 L .52549 .4302 L closepath p .635 .78 .951 r
F P
0 g
s
.52511 .4372 m .51852 .43121 L .5219 .43042 L closepath p .649 .788 .948 r
F P
0 g
s
.52511 .4372 m .5156 .4325 L .51852 .43121 L closepath p .663 .792 .943 r
F P
0 g
s
.52511 .4372 m .51334 .4342 L .5156 .4325 L closepath p .676 .792 .937 r
F P
0 g
s
.52511 .4372 m .51189 .43619 L .51334 .4342 L closepath p .687 .79 .928 r
F P
0 g
s
.52511 .4372 m .51134 .43835 L .51189 .43619 L closepath p .695 .784 .919 r
F P
0 g
s
.52511 .4372 m .53853 .43663 L .53889 .4388 L closepath p .615 .716 .917 r
F P
0 g
s
.52511 .4372 m .53726 .43459 L .53853 .43663 L closepath p .61 .724 .926 r
F P
0 g
s
.31524 .47877 m .32893 .48443 L .33748 .51397 L p .443 .607 .917 r
F P
0 g
s
.35043 .51698 m .33748 .51397 L .32893 .48443 L p .468 .625 .92 r
F P
0 g
s
.5527 .44303 m .53889 .4388 L .53853 .43663 L p .524 .648 .912 r
F P
0 g
s
.46966 .45589 m .48363 .44816 L .4849 .45463 L p .845 .864 .857 r
F P
0 g
s
.4849 .45463 m .47143 .46448 L .46966 .45589 L p .845 .864 .857 r
F P
0 g
s
.49859 .43782 m .51189 .43619 L .51134 .43835 L p .759 .847 .917 r
F P
0 g
s
.51134 .43835 m .49752 .44213 L .49859 .43782 L p .759 .847 .917 r
F P
0 g
s
.59128 .47742 m .57797 .46621 L .58051 .45769 L p .437 .514 .84 r
F P
0 g
s
.56656 .44952 m .58051 .45769 L .57797 .46621 L p .457 .536 .85 r
F P
0 g
s
.56656 .44952 m .5527 .44303 L .55202 .4387 L p .441 .583 .899 r
F P
0 g
s
.53853 .43663 m .55202 .4387 L .5527 .44303 L p .524 .648 .912 r
F P
0 g
s
.55202 .4387 m .53853 .43663 L .53726 .43459 L p .496 .665 .937 r
F P
0 g
s
.4556 .46457 m .46966 .45589 L .47143 .46448 L p .859 .871 .847 r
F P
0 g
s
.47143 .46448 m .45789 .47527 L .4556 .46457 L p .859 .871 .847 r
F P
0 g
s
.50148 .43381 m .51334 .4342 L .51189 .43619 L p .737 .87 .942 r
F P
0 g
s
.51189 .43619 m .49859 .43782 L .50148 .43381 L p .737 .87 .942 r
F P
0 g
s
.48519 .4417 m .49859 .43782 L .49752 .44213 L p .807 .894 .905 r
F P
0 g
s
.49752 .44213 m .48363 .44816 L .48519 .4417 L p .807 .894 .905 r
F P
0 g
s
.68391 .52382 m .67095 .52343 L .67926 .50051 L p .702 .806 .93 r
F P
0 g
s
.67926 .50051 m .69315 .49884 L .68391 .52382 L p .702 .806 .93 r
F P
0 g
s
.60463 .48876 m .59128 .47742 L .59454 .46682 L p .435 .512 .839 r
F P
0 g
s
.58051 .45769 m .59454 .46682 L .59128 .47742 L p .437 .514 .84 r
F P
0 g
s
.53726 .43459 m .54949 .4346 L .55202 .4387 L p .496 .665 .937 r
F P
0 g
s
.54949 .4346 m .53726 .43459 L .53515 .43282 L p .473 .688 .961 r
F P
0 g
s
.32893 .48443 m .34269 .48956 L .35043 .51698 L p .468 .625 .92 r
F P
0 g
s
.36351 .51879 m .35043 .51698 L .34269 .48956 L p .52 .662 .925 r
F P
0 g
s
.50601 .43039 m .5156 .4325 L .51334 .4342 L p .7 .882 .965 r
F P
0 g
s
.51334 .4342 m .50148 .43381 L .50601 .43039 L p .7 .882 .965 r
F P
0 g
s
.58051 .45769 m .56656 .44952 L .56559 .44302 L p .378 .532 .883 r
F P
0 g
s
.55202 .4387 m .56559 .44302 L .56656 .44952 L p .441 .583 .899 r
F P
0 g
s
.44145 .47339 m .4556 .46457 L .45789 .47527 L p .86 .871 .846 r
F P
0 g
s
.45789 .47527 m .44431 .48619 L .44145 .47339 L p .86 .871 .846 r
F P
0 g
s
.618 .4994 m .60463 .48876 L .60865 .47609 L p .451 .529 .847 r
F P
0 g
s
.59454 .46682 m .60865 .47609 L .60463 .48876 L p .435 .512 .839 r
F P
0 g
s
.53515 .43282 m .54528 .43104 L .54949 .4346 L p .473 .688 .961 r
F P
0 g
s
.54528 .43104 m .53515 .43282 L .53236 .43144 L p .461 .719 .98 r
F P
0 g
s
.51186 .4278 m .51852 .43121 L .5156 .4325 L p .648 .88 .983 r
F P
0 g
s
.5156 .4325 m .50601 .43039 L .51186 .4278 L p .648 .88 .983 r
F P
0 g
s
.56559 .44302 m .55202 .4387 L .54949 .4346 L p .377 .594 .93 r
F P
0 g
s
.47168 .44728 m .48519 .4417 L .48363 .44816 L p .837 .922 .89 r
F P
0 g
s
.48363 .44816 m .46966 .45589 L .47168 .44728 L p .837 .922 .89 r
F P
0 g
s
.67095 .52343 m .65786 .52085 L .66525 .49999 L p .647 .745 .921 r
F P
0 g
s
.66525 .49999 m .67926 .50051 L .67095 .52343 L p .647 .745 .921 r
F P
0 g
s
.48951 .43568 m .50148 .43381 L .49859 .43782 L p .772 .932 .937 r
F P
0 g
s
.49859 .43782 m .48519 .4417 L .48951 .43568 L p .772 .932 .937 r
F P
0 g
s
.53236 .43144 m .53967 .42826 L .54528 .43104 L p .461 .719 .98 r
F P
0 g
s
.53967 .42826 m .53236 .43144 L .52906 .43054 L p .465 .754 .993 r
F P
0 g
s
.51864 .42622 m .5219 .43042 L .51852 .43121 L p .589 .861 .994 r
F P
0 g
s
.51852 .43121 m .51186 .4278 L .51864 .42622 L p .589 .861 .994 r
F P
0 g
s
.63135 .50864 m .618 .4994 L .62281 .48468 L p .483 .564 .862 r
F P
0 g
s
.60865 .47609 m .62281 .48468 L .618 .4994 L p .451 .529 .847 r
F P
0 g
s
.52906 .43054 m .53305 .42646 L .53967 .42826 L p .465 .754 .993 r
F P
0 g
s
.53305 .42646 m .52906 .43054 L .52549 .4302 L p .489 .793 .999 r
F P
0 g
s
.52587 .42576 m .52549 .4302 L .5219 .43042 L p .532 .831 .999 r
F P
0 g
s
.5219 .43042 m .51864 .42622 L .52587 .42576 L p .532 .831 .999 r
F P
0 g
s
.34269 .48956 m .35656 .49348 L .36351 .51879 L p .52 .662 .925 r
F P
0 g
s
.37673 .51881 m .36351 .51879 L .35656 .49348 L p .589 .71 .927 r
F P
0 g
s
.42725 .48154 m .44145 .47339 L .44431 .48619 L p .849 .866 .854 r
F P
0 g
s
.44431 .48619 m .43071 .49643 L .42725 .48154 L p .849 .866 .854 r
F P
0 g
s
.52549 .4302 m .52587 .42576 L .53305 .42646 L p .489 .793 .999 r
F P
0 g
s
.65786 .52085 m .64465 .5159 L .65115 .49708 L p .586 .678 .904 r
F P
0 g
s
.65115 .49708 m .66525 .49999 L .65786 .52085 L p .586 .678 .904 r
F P
0 g
s
.59454 .46682 m .58051 .45769 L .57927 .44904 L p .343 .504 .873 r
F P
0 g
s
.56559 .44302 m .57927 .44904 L .58051 .45769 L p .378 .532 .883 r
F P
0 g
s
.64465 .5159 m .63135 .50864 L .63699 .49186 L p .529 .616 .883 r
F P
0 g
s
.62281 .48468 m .63699 .49186 L .63135 .50864 L p .483 .564 .862 r
F P
0 g
s
.63699 .49186 m .65115 .49708 L .64465 .5159 L p .529 .616 .883 r
F P
0 g
s
.54949 .4346 m .56183 .43687 L .56559 .44302 L p .377 .594 .93 r
F P
0 g
s
.56183 .43687 m .54949 .4346 L .54528 .43104 L p .31 .613 .955 r
F P
0 g
s
.41301 .48828 m .42725 .48154 L .43071 .49643 L p .825 .854 .869 r
F P
0 g
s
.43071 .49643 m .41711 .50525 L .41301 .48828 L p .825 .854 .869 r
F P
0 g
s
.4963 .43053 m .50601 .43039 L .50148 .43381 L p .699 .946 .958 r
F P
0 g
s
.50148 .43381 m .48951 .43568 L .4963 .43053 L p .699 .946 .958 r
F P
0 g
s
.45805 .45381 m .47168 .44728 L .46966 .45589 L p .851 .935 .88 r
F P
0 g
s
.46966 .45589 m .4556 .46457 L .45805 .45381 L p .851 .935 .88 r
F P
0 g
s
.35656 .49348 m .37053 .4956 L .37673 .51881 L p .589 .71 .927 r
F P
0 g
s
.39009 .51665 m .37673 .51881 L .37053 .4956 L p .664 .759 .921 r
F P
0 g
s
.81642 .47399 m .80244 .47209 L .80169 .42824 L p .607 .709 .917 r
F P
0 g
s
.80244 .47209 m .7886 .4718 L .78756 .43018 L p .655 .749 .919 r
F P
0 g
s
.78756 .43018 m .80169 .42824 L .80244 .47209 L p .655 .749 .919 r
F P
0 g
s
.57927 .44904 m .56559 .44302 L .56183 .43687 L p .278 .531 .913 r
F P
0 g
s
.7886 .4718 m .77489 .4732 L .7736 .43383 L p .703 .787 .916 r
F P
0 g
s
.7736 .43383 m .78756 .43018 L .7886 .4718 L p .703 .787 .916 r
F P
0 g
s
.83054 .47721 m .81642 .47399 L .816 .42792 L p .566 .676 .913 r
F P
0 g
s
.80169 .42824 m .816 .42792 L .81642 .47399 L p .607 .709 .917 r
F P
0 g
s
.39879 .49306 m .41301 .48828 L .41711 .50525 L p .787 .833 .888 r
F P
0 g
s
.41711 .50525 m .40356 .5121 L .39879 .49306 L p .787 .833 .888 r
F P
0 g
s
.77489 .4732 m .76128 .47619 L .75977 .43908 L p .746 .819 .909 r
F P
0 g
s
.75977 .43908 m .7736 .43383 L .77489 .4732 L p .746 .819 .909 r
F P
0 g
s
.4774 .43924 m .48951 .43568 L .48519 .4417 L p .788 .967 .918 r
F P
0 g
s
.48519 .4417 m .47168 .44728 L .4774 .43924 L p .788 .967 .918 r
F P
0 g
s
.37053 .4956 m .38462 .49552 L .39009 .51665 L p .664 .759 .921 r
F P
0 g
s
.40356 .5121 m .39009 .51665 L .38462 .49552 L p .732 .802 .907 r
F P
0 g
s
.38462 .49552 m .39879 .49306 L .40356 .5121 L p .732 .802 .907 r
F P
0 g
s
.84476 .48133 m .83054 .47721 L .83049 .42893 L p .539 .652 .908 r
F P
0 g
s
.816 .42792 m .83049 .42893 L .83054 .47721 L p .566 .676 .913 r
F P
0 g
s
.54528 .43104 m .55552 .43151 L .56183 .43687 L p .31 .613 .955 r
F P
0 g
s
.55552 .43151 m .54528 .43104 L .53967 .42826 L p .254 .64 .963 r
F P
0 g
s
.60865 .47609 m .59454 .46682 L .59308 .45601 L p .34 .501 .872 r
F P
0 g
s
.57927 .44904 m .59308 .45601 L .59454 .46682 L p .343 .504 .873 r
F P
0 g
s
.50511 .42662 m .51186 .4278 L .50601 .43039 L p .586 .924 .962 r
F P
0 g
s
.50601 .43039 m .4963 .43053 L .50511 .42662 L p .586 .924 .962 r
F P
0 g
s
.76128 .47619 m .74772 .48045 L .74603 .4456 L p .777 .842 .901 r
F P
0 g
s
.74603 .4456 m .75977 .43908 L .76128 .47619 L p .777 .842 .901 r
F P
0 g
s
.85906 .48583 m .84476 .48133 L .84512 .43086 L p .528 .642 .906 r
F P
0 g
s
.83049 .42893 m .84512 .43086 L .84476 .48133 L p .539 .652 .908 r
F P
0 g
s
.4443 .46049 m .45805 .45381 L .4556 .46457 L p .853 .936 .879 r
F P
0 g
s
.4556 .46457 m .44145 .47339 L .4443 .46049 L p .853 .936 .879 r
F P
0 g
s
.53967 .42826 m .54709 .42732 L .55552 .43151 L p .254 .64 .963 r
F P
0 g
s
.54709 .42732 m .53967 .42826 L .53305 .42646 L p .229 .676 .953 r
F P
0 g
s
.51534 .42423 m .51864 .42622 L .51186 .4278 L p .452 .867 .95 r
F P
0 g
s
.51186 .4278 m .50511 .42662 L .51534 .42423 L p .452 .867 .95 r
F P
0 g
s
.74772 .48045 m .73418 .4855 L .73234 .4529 L p .795 .854 .895 r
F P
0 g
s
.73234 .4529 m .74603 .4456 L .74772 .48045 L p .795 .854 .895 r
F P
0 g
s
.84512 .43086 m .85986 .43317 L .85906 .48583 L p .528 .642 .906 r
F P
0 g
s
.56183 .43687 m .5743 .44083 L .57927 .44904 L p .278 .531 .913 r
F P
0 g
s
.5743 .44083 m .56183 .43687 L .55552 .43151 L p .163 .532 .922 r
F P
0 g
s
.59308 .45601 m .57927 .44904 L .5743 .44083 L p .221 .493 .899 r
F P
0 g
s
.53305 .42646 m .5371 .42459 L .54709 .42732 L p .229 .676 .953 r
F P
0 g
s
.5371 .42459 m .53305 .42646 L .52587 .42576 L p .254 .727 .94 r
F P
0 g
s
.52626 .42354 m .52587 .42576 L .51864 .42622 L p .332 .794 .939 r
F P
0 g
s
.51864 .42622 m .51534 .42423 L .52626 .42354 L p .332 .794 .939 r
F P
0 g
s
.62281 .48468 m .60865 .47609 L .60699 .46313 L p .366 .523 .88 r
F P
0 g
s
.59308 .45601 m .60699 .46313 L .60865 .47609 L p .34 .501 .872 r
F P
0 g
s
.48646 .43234 m .4963 .43053 L .48951 .43568 L p .674 .969 .919 r
F P
0 g
s
.48951 .43568 m .4774 .43924 L .48646 .43234 L p .674 .969 .919 r
F P
0 g
s
.52587 .42576 m .52626 .42354 L .5371 .42459 L p .254 .727 .94 r
F P
0 g
s
.46516 .44375 m .4774 .43924 L .47168 .44728 L p .793 .981 .901 r
F P
0 g
s
.47168 .44728 m .45805 .45381 L .46516 .44375 L p .793 .981 .901 r
F P
0 g
s
.25115 .41911 m .26521 .42153 L .26034 .46325 L p .659 .752 .919 r
F P
0 g
s
.26034 .46325 m .24636 .46309 L .25115 .41911 L p .659 .752 .919 r
F P
0 g
s
.27418 .46511 m .26034 .46325 L .26521 .42153 L p .61 .708 .914 r
F P
0 g
s
.73418 .4855 m .72059 .4907 L .71863 .46034 L p .798 .857 .893 r
F P
0 g
s
.71863 .46034 m .73234 .4529 L .73418 .4855 L p .798 .857 .893 r
F P
0 g
s
.2369 .41831 m .25115 .41911 L .24636 .46309 L p .702 .79 .919 r
F P
0 g
s
.24636 .46309 m .23223 .46454 L .2369 .41831 L p .702 .79 .919 r
F P
0 g
s
.26521 .42153 m .2791 .42566 L .27418 .46511 L p .61 .708 .914 r
F P
0 g
s
.28792 .46855 m .27418 .46511 L .2791 .42566 L p .563 .664 .905 r
F P
0 g
s
.43046 .4665 m .4443 .46049 L .44145 .47339 L p .842 .926 .887 r
F P
0 g
s
.44145 .47339 m .42725 .48154 L .43046 .4665 L p .842 .926 .887 r
F P
0 g
s
.22247 .41885 m .2369 .41831 L .23223 .46454 L p .735 .819 .917 r
F P
0 g
s
.23223 .46454 m .21796 .46732 L .22247 .41885 L p .735 .819 .917 r
F P
0 g
s
.2791 .42566 m .29285 .43138 L .28792 .46855 L p .563 .664 .905 r
F P
0 g
s
.30159 .47327 m .28792 .46855 L .29285 .43138 L p .525 .628 .896 r
F P
0 g
s
.63699 .49186 m .62281 .48468 L .62099 .46958 L p .419 .566 .895 r
F P
0 g
s
.60699 .46313 m .62099 .46958 L .62281 .48468 L p .366 .523 .88 r
F P
0 g
s
.55552 .43151 m .5659 .43365 L .5743 .44083 L p .163 .532 .922 r
F P
0 g
s
.5659 .43365 m .55552 .43151 L .54709 .42732 L p .056 .533 .892 r
F P
0 g
s
.20788 .4203 m .22247 .41885 L .21796 .46732 L p .756 .836 .913 r
F P
0 g
s
.21796 .46732 m .20357 .471 L .20788 .4203 L p .756 .836 .913 r
F P
0 g
s
.72059 .4907 m .70692 .49537 L .70488 .46725 L p .786 .848 .898 r
F P
0 g
s
.70488 .46725 m .71863 .46034 L .72059 .4907 L p .786 .848 .898 r
F P
0 g
s
.49826 .4271 m .50511 .42662 L .4963 .43053 L p .492 .904 .881 r
F P
0 g
s
.4963 .43053 m .48646 .43234 L .49826 .4271 L p .492 .904 .881 r
F P
0 g
s
.60699 .46313 m .59308 .45601 L .58691 .44574 L p .215 .489 .897 r
F P
0 g
s
.5743 .44083 m .58691 .44574 L .59308 .45601 L p .221 .493 .899 r
F P
0 g
s
.29285 .43138 m .30651 .43838 L .30159 .47327 L p .525 .628 .896 r
F P
0 g
s
.31524 .47877 m .30159 .47327 L .30651 .43838 L p .502 .606 .889 r
F P
0 g
s
.19318 .42214 m .20788 .4203 L .20357 .471 L p .764 .843 .911 r
F P
0 g
s
.20357 .471 m .18911 .47507 L .19318 .42214 L p .764 .843 .911 r
F P
0 g
s
.58691 .44574 m .5743 .44083 L .5659 .43365 L p .075 .478 .892 r
F P
0 g
s
.41656 .4711 m .43046 .4665 L .42725 .48154 L p .817 .905 .901 r
F P
0 g
s
.42725 .48154 m .41301 .48828 L .41656 .4711 L p .817 .905 .901 r
F P
0 g
s
.65115 .49708 m .63699 .49186 L .63504 .47463 L p .49 .624 .91 r
F P
0 g
s
.62099 .46958 m .63504 .47463 L .63699 .49186 L p .419 .566 .895 r
F P
0 g
s
.70692 .49537 m .69315 .49884 L .69106 .47293 L p .757 .828 .907 r
F P
0 g
s
.69106 .47293 m .70488 .46725 L .70692 .49537 L p .757 .828 .907 r
F P
0 g
s
.45278 .4484 m .46516 .44375 L .45805 .45381 L p .794 .982 .899 r
F P
0 g
s
.45805 .45381 m .4443 .46049 L .45278 .4484 L p .794 .982 .899 r
F P
0 g
s
.54709 .42732 m .5546 .42803 L .5659 .43365 L p .056 .533 .892 r
F P
0 g
s
.5546 .42803 m .54709 .42732 L .5371 .42459 L p 0 .545 .832 r
F P
0 g
s
.30651 .43838 m .32011 .44615 L .31524 .47877 L p .502 .606 .889 r
F P
0 g
s
.32893 .48443 m .31524 .47877 L .32011 .44615 L p .498 .602 .887 r
F P
0 g
s
.4765 .4351 m .48646 .43234 L .4774 .43924 L p .651 .969 .883 r
F P
0 g
s
.4774 .43924 m .46516 .44375 L .4765 .4351 L p .651 .969 .883 r
F P
0 g
s
.51199 .42389 m .51534 .42423 L .50511 .42662 L p .287 .788 .819 r
F P
0 g
s
.50511 .42662 m .49826 .4271 L .51199 .42389 L p .287 .788 .819 r
F P
0 g
s
.69315 .49884 m .67926 .50051 L .67715 .4768 L p .709 .794 .917 r
F P
0 g
s
.67715 .4768 m .69106 .47293 L .69315 .49884 L p .709 .794 .917 r
F P
0 g
s
.66525 .49999 m .65115 .49708 L .64911 .4777 L p .569 .687 .92 r
F P
0 g
s
.63504 .47463 m .64911 .4777 L .65115 .49708 L p .49 .624 .91 r
F P
0 g
s
.5371 .42459 m .5412 .42437 L .5546 .42803 L p 0 .545 .832 r
F P
0 g
s
.5412 .42437 m .5371 .42459 L .52626 .42354 L p .019 .586 .783 r
F P
0 g
s
.67926 .50051 m .66525 .49999 L .66316 .47845 L p .645 .746 .923 r
F P
0 g
s
.66316 .47845 m .67715 .4768 L .67926 .50051 L p .645 .746 .923 r
F P
0 g
s
.52665 .42296 m .52626 .42354 L .51534 .42423 L p .118 .67 .777 r
F P
0 g
s
.51534 .42423 m .51199 .42389 L .52665 .42296 L p .118 .67 .777 r
F P
0 g
s
.40263 .47373 m .41656 .4711 L .41301 .48828 L p .777 .869 .916 r
F P
0 g
s
.41301 .48828 m .39879 .49306 L .40263 .47373 L p .777 .869 .916 r
F P
0 g
s
.32011 .44615 m .33372 .45408 L .32893 .48443 L p .498 .602 .887 r
F P
0 g
s
.34269 .48956 m .32893 .48443 L .33372 .45408 L p .514 .617 .893 r
F P
0 g
s
.64911 .4777 m .66316 .47845 L .66525 .49999 L p .569 .687 .92 r
F P
0 g
s
.52626 .42354 m .52665 .42296 L .5412 .42437 L p .019 .586 .783 r
F P
0 g
s
.62099 .46958 m .60699 .46313 L .59965 .4508 L p .26 .519 .909 r
F P
0 g
s
.58691 .44574 m .59965 .4508 L .60699 .46313 L p .215 .489 .897 r
F P
0 g
s
.33372 .45408 m .34736 .46145 L .34269 .48956 L p .514 .617 .893 r
F P
0 g
s
.35656 .49348 m .34269 .48956 L .34736 .46145 L p .55 .652 .903 r
F P
0 g
s
.38872 .47403 m .40263 .47373 L .39879 .49306 L p .724 .819 .924 r
F P
0 g
s
.39879 .49306 m .38462 .49552 L .38872 .47403 L p .724 .819 .924 r
F P
0 g
s
.5659 .43365 m .5764 .43674 L .58691 .44574 L p .075 .478 .892 r
F P
0 g
s
.5764 .43674 m .5659 .43365 L .5546 .42803 L p 0 .458 .829 r
F P
0 g
s
.44029 .45236 m .45278 .4484 L .4443 .46049 L p .79 .972 .913 r
F P
0 g
s
.4443 .46049 m .43046 .4665 L .44029 .45236 L p .79 .972 .913 r
F P
0 g
s
.34736 .46145 m .36107 .4676 L .35656 .49348 L p .55 .652 .903 r
F P
0 g
s
.37053 .4956 m .35656 .49348 L .36107 .4676 L p .601 .702 .915 r
F P
0 g
s
.49132 .4285 m .49826 .4271 L .48646 .43234 L p .425 .868 .81 r
F P
0 g
s
.48646 .43234 m .4765 .4351 L .49132 .4285 L p .425 .868 .81 r
F P
0 g
s
.37486 .47193 m .38872 .47403 L .38462 .49552 L p .663 .761 .923 r
F P
0 g
s
.38462 .49552 m .37053 .4956 L .37486 .47193 L p .663 .761 .923 r
F P
0 g
s
.59965 .4508 m .58691 .44574 L .5764 .43674 L p .066 .472 .888 r
F P
0 g
s
.36107 .4676 m .37486 .47193 L .37053 .4956 L p .601 .702 .915 r
F P
0 g
s
.4664 .43798 m .4765 .4351 L .46516 .44375 L p .648 .968 .879 r
F P
0 g
s
.46516 .44375 m .45278 .4484 L .4664 .43798 L p .648 .968 .879 r
F P
0 g
s
.63504 .47463 m .62099 .46958 L .6125 .45517 L p .343 .574 .926 r
F P
0 g
s
.59965 .4508 m .6125 .45517 L .62099 .46958 L p .26 .519 .909 r
F P
0 g
s
.5546 .42803 m .56223 .42968 L .5764 .43674 L p 0 .458 .829 r
F P
0 g
s
.56223 .42968 m .5546 .42803 L .5412 .42437 L p 0 .452 .734 r
F P
0 g
s
.50858 .42446 m .51199 .42389 L .49826 .4271 L p .185 .714 .715 r
F P
0 g
s
.49826 .4271 m .49132 .4285 L .50858 .42446 L p .185 .714 .715 r
F P
0 g
s
.42772 .45491 m .44029 .45236 L .43046 .4665 L p .778 .945 .932 r
F P
0 g
s
.43046 .4665 m .41656 .4711 L .42772 .45491 L p .778 .945 .932 r
F P
0 g
s
.5412 .42437 m .54538 .42507 L .56223 .42968 L p 0 .452 .734 r
F P
0 g
s
.54538 .42507 m .5412 .42437 L .52665 .42296 L p .108 0 0 r
F P
0 g
s
.52705 .42329 m .52665 .42296 L .51199 .42389 L p .001 0 0 r
F P
0 g
s
.51199 .42389 m .50858 .42446 L .52705 .42329 L p .001 0 0 r
F P
0 g
s
.52665 .42296 m .52705 .42329 L .54538 .42507 L p .108 0 0 r
F P
0 g
s
.5764 .43674 m .58704 .43996 L .59965 .4508 L p .066 .472 .888 r
F P
0 g
s
.58704 .43996 m .5764 .43674 L .56223 .42968 L p 0 .45 .822 r
F P
0 g
s
.64911 .4777 m .63504 .47463 L .62543 .45813 L p .449 .64 .938 r
F P
0 g
s
.6125 .45517 m .62543 .45813 L .63504 .47463 L p .343 .574 .926 r
F P
0 g
s
.6125 .45517 m .59965 .4508 L .58704 .43996 L p .135 .515 .913 r
F P
0 g
s
.48427 .43002 m .49132 .4285 L .4765 .4351 L p .418 .863 .802 r
F P
0 g
s
.4765 .4351 m .4664 .43798 L .48427 .43002 L p .418 .863 .802 r
F P
0 g
s
.45619 .44016 m .4664 .43798 L .45278 .4484 L p .667 .97 .909 r
F P
0 g
s
.45278 .4484 m .44029 .45236 L .45619 .44016 L p .667 .97 .909 r
F P
0 g
s
.41509 .45547 m .42772 .45491 L .41656 .4711 L p .75 .897 .944 r
F P
0 g
s
.41656 .4711 m .40263 .47373 L .41509 .45547 L p .75 .897 .944 r
F P
0 g
s
.66316 .47845 m .64911 .4777 L .63841 .4591 L p .554 .701 .938 r
F P
0 g
s
.62543 .45813 m .63841 .4591 L .64911 .4777 L p .449 .64 .938 r
F P
0 g
s
.56223 .42968 m .56996 .43144 L .58704 .43996 L p 0 .45 .822 r
F P
0 g
s
.56996 .43144 m .56223 .42968 L .54538 .42507 L p 0 .442 .723 r
F P
0 g
s
.7736 .43383 m .75977 .43908 L .74157 .40276 L p .747 .794 .891 r
F P
0 g
s
.75977 .43908 m .74603 .4456 L .72866 .41157 L p .776 .806 .877 r
F P
0 g
s
.72866 .41157 m .74157 .40276 L .75977 .43908 L p .776 .806 .877 r
F P
0 g
s
.50512 .42514 m .50162 .42509 L .50599 .42482 L p .079 .64 .74 r
F P
0 g
s
.50512 .42514 m .50858 .42446 L .50419 .42549 L p .175 .705 .704 r
F P
0 g
s
.52745 .42372 m .52705 .42329 L .50858 .42446 L p .012 0 0 r
F P
0 g
s
.50858 .42446 m .50512 .42514 L .52745 .42372 L p .012 0 0 r
F P
0 g
s
.54961 .42588 m .56996 .43144 L p .54965 .42618 L 0 .442 .723 r
F P
0 g
s
.54538 .42507 m .54961 .42588 L p .54965 .42618 L 0 .442 .723 r
F P
0 g
s
.52745 .42372 m .54961 .42588 L p .53096 .42374 L .12 0 0 r
F P
0 g
s
.54961 .42588 m .54538 .42507 L .52705 .42329 L p .12 0 0 r
F P
0 g
s
.54961 .42588 m .52745 .42372 L p .54957 .42559 L 0 .555 .746 r
F P
0 g
s
.5539 .42596 m .54961 .42588 L p .54957 .42559 L 0 .555 .746 r
F P
0 g
s
.52705 .42329 m .52745 .42372 L p .53096 .42374 L .12 0 0 r
F P
0 g
s
.50599 .42482 m .52348 .4237 L p .50512 .42514 L .079 .64 .74 r
F P
0 g
s
.52348 .4237 m .52786 .42343 L p .52413 .42371 L .079 .64 .74 r
F P
0 g
s
.50512 .42514 m .52348 .4237 L .52413 .42371 L .079 .64 .74 r
F
.50419 .42549 m .49132 .4285 L p .50512 .42514 L .175 .705 .704 r
F P
0 g
s
.49132 .4285 m .48427 .43002 L .50512 .42514 L p .175 .705 .704 r
F P
0 g
s
.67715 .4768 m .66316 .47845 L .6514 .45773 L p .644 .748 .925 r
F P
0 g
s
.63841 .4591 m .6514 .45773 L .66316 .47845 L p .554 .701 .938 r
F P
0 g
s
.78756 .43018 m .7736 .43383 L .7546 .39522 L p .706 .775 .906 r
F P
0 g
s
.74157 .40276 m .7546 .39522 L .7736 .43383 L p .747 .794 .891 r
F P
0 g
s
.74603 .4456 m .73234 .4529 L .71581 .42115 L p .792 .812 .868 r
F P
0 g
s
.71581 .42115 m .72866 .41157 L .74603 .4456 L p .792 .812 .868 r
F P
0 g
s
.62543 .45813 m .6125 .45517 L .59779 .44249 L p .262 .589 .947 r
F P
0 g
s
.58704 .43996 m .59779 .44249 L .6125 .45517 L p .135 .515 .913 r
F P
0 g
s
.40245 .45367 m .41509 .45547 L .40263 .47373 L p .709 .832 .941 r
F P
0 g
s
.40263 .47373 m .38872 .47403 L .40245 .45367 L p .709 .832 .941 r
F P
0 g
s
.80169 .42824 m .78756 .43018 L .76779 .38926 L p .655 .749 .919 r
F P
0 g
s
.7546 .39522 m .76779 .38926 L .78756 .43018 L p .706 .775 .906 r
F P
0 g
s
.73234 .4529 m .71863 .46034 L .70299 .43086 L p .795 .813 .867 r
F P
0 g
s
.70299 .43086 m .71581 .42115 L .73234 .4529 L p .795 .813 .867 r
F P
0 g
s
.69106 .47293 m .67715 .4768 L .66436 .45393 L p .712 .78 .905 r
F P
0 g
s
.6514 .45773 m .66436 .45393 L .67715 .4768 L p .644 .748 .925 r
F P
0 g
s
.71863 .46034 m .70488 .46725 L .69016 .44 L p .784 .809 .873 r
F P
0 g
s
.69016 .44 m .70299 .43086 L .71863 .46034 L p .784 .809 .873 r
F P
0 g
s
.59779 .44249 m .58704 .43996 L .56996 .43144 L p .019 .51 .873 r
F P
0 g
s
.70488 .46725 m .69106 .47293 L .67728 .44788 L p .757 .799 .887 r
F P
0 g
s
.67728 .44788 m .69016 .44 L .70488 .46725 L p .757 .799 .887 r
F P
0 g
s
.66436 .45393 m .67728 .44788 L .69106 .47293 L p .712 .78 .905 r
F P
0 g
s
.816 .42792 m .80169 .42824 L .78117 .38502 L p .6 .719 .928 r
F P
0 g
s
.76779 .38926 m .78117 .38502 L .80169 .42824 L p .655 .749 .919 r
F P
0 g
s
.4459 .44091 m .45619 .44016 L .44029 .45236 L p .692 .957 .949 r
F P
0 g
s
.44029 .45236 m .42772 .45491 L .4459 .44091 L p .692 .957 .949 r
F P
0 g
s
.38983 .44945 m .40245 .45367 L .38872 .47403 L p .661 .762 .925 r
F P
0 g
s
.38872 .47403 m .37486 .47193 L .38983 .44945 L p .661 .762 .925 r
F P
0 g
s
.47713 .43083 m .48427 .43002 L .4664 .43798 L p .471 .894 .859 r
F P
0 g
s
.4664 .43798 m .45619 .44016 L .47713 .43083 L p .471 .894 .859 r
F P
0 g
s
.83049 .42893 m .816 .42792 L .79475 .3824 L p .551 .69 .932 r
F P
0 g
s
.78117 .38502 m .79475 .3824 L .816 .42792 L p .6 .719 .928 r
F P
0 g
s
.37724 .44297 m .38983 .44945 L .37486 .47193 L p .615 .698 .903 r
F P
0 g
s
.37486 .47193 m .36107 .4676 L .37724 .44297 L p .615 .698 .903 r
F P
0 g
s
.30179 .38757 m .31452 .39558 L .29285 .43138 L p .589 .66 .887 r
F P
0 g
s
.29285 .43138 m .2791 .42566 L .30179 .38757 L p .589 .66 .887 r
F P
0 g
s
.30651 .43838 m .29285 .43138 L .31452 .39558 L p .563 .626 .873 r
F P
0 g
s
.31452 .39558 m .32713 .40485 L .30651 .43838 L p .563 .626 .873 r
F P
0 g
s
.32011 .44615 m .30651 .43838 L .32713 .40485 L p .548 .606 .863 r
F P
0 g
s
.32713 .40485 m .33967 .41489 L .32011 .44615 L p .548 .606 .863 r
F P
0 g
s
.33372 .45408 m .32011 .44615 L .33967 .41489 L p .545 .603 .862 r
F P
0 g
s
.28889 .38115 m .30179 .38757 L .2791 .42566 L p .622 .704 .904 r
F P
0 g
s
.2791 .42566 m .26521 .42153 L .28889 .38115 L p .622 .704 .904 r
F P
0 g
s
.63841 .4591 m .62543 .45813 L .60863 .44358 L p .411 .664 .964 r
F P
0 g
s
.59779 .44249 m .60863 .44358 L .62543 .45813 L p .262 .589 .947 r
F P
0 g
s
.36469 .43464 m .37724 .44297 L .36107 .4676 L p .579 .649 .883 r
F P
0 g
s
.36107 .4676 m .34736 .46145 L .36469 .43464 L p .579 .649 .883 r
F P
0 g
s
.33967 .41489 m .35218 .42505 L .33372 .45408 L p .545 .603 .862 r
F P
0 g
s
.34736 .46145 m .33372 .45408 L .35218 .42505 L p .556 .617 .868 r
F P
0 g
s
.35218 .42505 m .36469 .43464 L .34736 .46145 L p .556 .617 .868 r
F P
0 g
s
.27581 .37644 m .28889 .38115 L .26521 .42153 L p .658 .752 .919 r
F P
0 g
s
.26521 .42153 m .25115 .41911 L .27581 .37644 L p .658 .752 .919 r
F P
0 g
s
.84512 .43086 m .83049 .42893 L .80854 .38111 L p .516 .669 .932 r
F P
0 g
s
.79475 .3824 m .80854 .38111 L .83049 .42893 L p .551 .69 .932 r
F P
0 g
s
.56996 .43144 m .57779 .43249 L .59779 .44249 L p .019 .51 .873 r
F P
0 g
s
.57779 .43249 m .56996 .43144 L .54961 .42588 L p 0 .516 .802 r
F P
0 g
s
.43554 .43963 m .4459 .44091 L .42772 .45491 L p .7 .911 .968 r
F P
0 g
s
.42772 .45491 m .41509 .45547 L .43554 .43963 L p .7 .911 .968 r
F P
0 g
s
.26252 .37334 m .27581 .37644 L .25115 .41911 L p .692 .797 .93 r
F P
0 g
s
.25115 .41911 m .2369 .41831 L .26252 .37334 L p .692 .797 .93 r
F P
0 g
s
.50162 .42509 m .50512 .42514 L .48427 .43002 L p .254 .765 .787 r
F P
0 g
s
.48427 .43002 m .47713 .43083 L .50162 .42509 L p .254 .765 .787 r
F P
0 g
s
.60863 .44358 m .59779 .44249 L .57779 .43249 L p .19 .609 .945 r
F P
0 g
s
.85986 .43317 m .84512 .43086 L .8225 .38074 L p .501 .659 .932 r
F P
0 g
s
.80854 .38111 m .8225 .38074 L .84512 .43086 L p .516 .669 .932 r
F P
0 g
s
.6514 .45773 m .63841 .4591 L .61954 .44266 L p .545 .719 .954 r
F P
0 g
s
.60863 .44358 m .61954 .44266 L .63841 .4591 L p .411 .664 .964 r
F P
0 g
s
.24903 .37159 m .26252 .37334 L .2369 .41831 L p .719 .834 .936 r
F P
0 g
s
.2369 .41831 m .22247 .41885 L .24903 .37159 L p .719 .834 .936 r
F P
0 g
s
.46991 .43017 m .47713 .43083 L .45619 .44016 L p .557 .923 .941 r
F P
0 g
s
.45619 .44016 m .4459 .44091 L .46991 .43017 L p .557 .923 .941 r
F P
0 g
s
.54961 .42588 m .5539 .42596 L .57779 .43249 L p 0 .516 .802 r
F P
0 g
s
.52786 .42343 m .52745 .42372 L .50512 .42514 L p .079 .64 .74 r
F P
0 g
s
.8225 .38074 m .8366 .38074 L .85986 .43317 L p .501 .659 .932 r
F P
0 g
s
.52745 .42372 m .52786 .42343 L .5539 .42596 L p 0 .555 .746 r
F P
0 g
s
.42514 .43599 m .43554 .43963 L .41509 .45547 L p .685 .839 .957 r
F P
0 g
s
.41509 .45547 m .40245 .45367 L .42514 .43599 L p .685 .839 .957 r
F P
0 g
s
.23536 .37074 m .24903 .37159 L .22247 .41885 L p .736 .857 .937 r
F P
0 g
s
.22247 .41885 m .20788 .4203 L .23536 .37074 L p .736 .857 .937 r
F P
0 g
s
.66436 .45393 m .6514 .45773 L .63047 .43937 L p .644 .75 .926 r
F P
0 g
s
.61954 .44266 m .63047 .43937 L .6514 .45773 L p .545 .719 .954 r
F P
0 g
s
.61954 .44266 m .60863 .44358 L .5857 .43209 L p .385 .696 .982 r
F P
0 g
s
.57779 .43249 m .5857 .43209 L .60863 .44358 L p .19 .609 .945 r
F P
0 g
s
.5857 .43209 m .57779 .43249 L .5539 .42596 L p .153 .638 .921 r
F P
0 g
s
.22154 .37026 m .23536 .37074 L .20788 .4203 L p .743 .866 .937 r
F P
0 g
s
.20788 .4203 m .19318 .42214 L .22154 .37026 L p .743 .866 .937 r
F P
0 g
s
.49807 .42357 m .50162 .42509 L .47713 .43083 L p .4 .848 .915 r
F P
0 g
s
.47713 .43083 m .46991 .43017 L .49807 .42357 L p .4 .848 .915 r
F P
0 g
s
.41474 .42987 m .42514 .43599 L .40245 .45367 L p .658 .762 .927 r
F P
0 g
s
.40245 .45367 m .38983 .44945 L .41474 .42987 L p .658 .762 .927 r
F P
0 g
s
.67728 .44788 m .66436 .45393 L .64141 .43362 L p .71 .765 .895 r
F P
0 g
s
.63047 .43937 m .64141 .43362 L .66436 .45393 L p .644 .75 .926 r
F P
0 g
s
.46265 .42748 m .46991 .43017 L .4459 .44091 L p .627 .904 .985 r
F P
0 g
s
.4459 .44091 m .43554 .43963 L .46265 .42748 L p .627 .904 .985 r
F P
0 g
s
.69016 .44 m .67728 .44788 L .65234 .42559 L p .75 .771 .87 r
F P
0 g
s
.64141 .43362 m .65234 .42559 L .67728 .44788 L p .71 .765 .895 r
F P
0 g
s
.5539 .42596 m .55824 .42457 L .5857 .43209 L p .153 .638 .921 r
F P
0 g
s
.55824 .42457 m .5539 .42596 L .52786 .42343 L p .175 .687 .897 r
F P
0 g
s
.40435 .42147 m .41474 .42987 L .38983 .44945 L p .63 .697 .894 r
F P
0 g
s
.38983 .44945 m .37724 .44297 L .40435 .42147 L p .63 .697 .894 r
F P
0 g
s
.70299 .43086 m .69016 .44 L .66325 .41568 L p .773 .772 .853 r
F P
0 g
s
.65234 .42559 m .66325 .41568 L .69016 .44 L p .75 .771 .87 r
F P
0 g
s
.52828 .42165 m .52786 .42343 L .50162 .42509 L p .262 .76 .894 r
F P
0 g
s
.50162 .42509 m .49807 .42357 L .52828 .42165 L p .262 .76 .894 r
F P
0 g
s
.71581 .42115 m .70299 .43086 L .67415 .40449 L p .782 .773 .845 r
F P
0 g
s
.66325 .41568 m .67415 .40449 L .70299 .43086 L p .773 .772 .853 r
F P
0 g
s
.63047 .43937 m .61954 .44266 L .59367 .42964 L p .543 .741 .968 r
F P
0 g
s
.5857 .43209 m .59367 .42964 L .61954 .44266 L p .385 .696 .982 r
F P
0 g
s
.52786 .42343 m .52828 .42165 L .55824 .42457 L p .175 .687 .897 r
F P
0 g
s
.72866 .41157 m .71581 .42115 L .68506 .39269 L p .779 .773 .847 r
F P
0 g
s
.67415 .40449 m .68506 .39269 L .71581 .42115 L p .782 .773 .845 r
F P
0 g
s
.39396 .41119 m .40435 .42147 L .37724 .44297 L p .608 .65 .867 r
F P
0 g
s
.37724 .44297 m .36469 .43464 L .39396 .41119 L p .608 .65 .867 r
F P
0 g
s
.74157 .40276 m .72866 .41157 L .69602 .38101 L p .766 .772 .857 r
F P
0 g
s
.68506 .39269 m .69602 .38101 L .72866 .41157 L p .779 .773 .847 r
F P
0 g
s
.59367 .42964 m .5857 .43209 L .55824 .42457 L p .38 .735 .991 r
F P
0 g
s
.45534 .42238 m .46265 .42748 L .43554 .43963 L p .656 .838 .97 r
F P
0 g
s
.43554 .43963 m .42514 .43599 L .45534 .42238 L p .656 .838 .97 r
F P
0 g
s
.7546 .39522 m .74157 .40276 L .70706 .37006 L p .741 .769 .875 r
F P
0 g
s
.69602 .38101 m .70706 .37006 L .74157 .40276 L p .766 .772 .857 r
F P
0 g
s
.38359 .39961 m .39396 .41119 L .36469 .43464 L p .593 .621 .849 r
F P
0 g
s
.36469 .43464 m .35218 .42505 L .38359 .39961 L p .593 .621 .849 r
F P
0 g
s
.4945 .41999 m .49807 .42357 L .46991 .43017 L p .543 .875 .991 r
F P
0 g
s
.46991 .43017 m .46265 .42748 L .4945 .41999 L p .543 .875 .991 r
F P
0 g
s
.3732 .38742 m .38359 .39961 L .35218 .42505 L p .587 .609 .841 r
F P
0 g
s
.35218 .42505 m .33967 .41489 L .3732 .38742 L p .587 .609 .841 r
F P
0 g
s
.76779 .38926 m .7546 .39522 L .71822 .36037 L p .704 .762 .897 r
F P
0 g
s
.70706 .37006 m .71822 .36037 L .7546 .39522 L p .741 .769 .875 r
F P
0 g
s
.36276 .37534 m .3732 .38742 L .33967 .41489 L p .588 .612 .843 r
F P
0 g
s
.33967 .41489 m .32713 .40485 L .36276 .37534 L p .588 .612 .843 r
F P
0 g
s
.64141 .43362 m .63047 .43937 L .60168 .42481 L p .645 .753 .928 r
F P
0 g
s
.59367 .42964 m .60168 .42481 L .63047 .43937 L p .543 .741 .968 r
F P
0 g
s
.35224 .36399 m .36276 .37534 L .32713 .40485 L p .598 .63 .854 r
F P
0 g
s
.32713 .40485 m .31452 .39558 L .35224 .36399 L p .598 .63 .854 r
F P
0 g
s
.78117 .38502 m .76779 .38926 L .72954 .35225 L p .655 .75 .92 r
F P
0 g
s
.71822 .36037 m .72954 .35225 L .76779 .38926 L p .704 .762 .897 r
F P
0 g
s
.55824 .42457 m .56262 .42113 L .59367 .42964 L p .38 .735 .991 r
F P
0 g
s
.56262 .42113 m .55824 .42457 L .52828 .42165 L p .406 .781 .993 r
F P
0 g
s
.34159 .35389 m .35224 .36399 L .31452 .39558 L p .614 .661 .872 r
F P
0 g
s
.31452 .39558 m .30179 .38757 L .34159 .35389 L p .614 .661 .872 r
F P
0 g
s
.44802 .41479 m .45534 .42238 L .42514 .43599 L p .655 .762 .928 r
F P
0 g
s
.42514 .43599 m .41474 .42987 L .44802 .41479 L p .655 .762 .928 r
F P
0 g
s
.5287 .41781 m .52828 .42165 L .49807 .42357 L p .463 .83 .993 r
F P
0 g
s
.49807 .42357 m .4945 .41999 L .5287 .41781 L p .463 .83 .993 r
F P
0 g
s
.60168 .42481 m .59367 .42964 L .56262 .42113 L p .549 .765 .978 r
F P
0 g
s
.52828 .42165 m .5287 .41781 L .56262 .42113 L p .406 .781 .993 r
F P
0 g
s
.33079 .34536 m .34159 .35389 L .30179 .38757 L p .635 .703 .895 r
F P
0 g
s
.30179 .38757 m .28889 .38115 L .33079 .34536 L p .635 .703 .895 r
F P
0 g
s
.79475 .3824 m .78117 .38502 L .74105 .34584 L p .597 .731 .938 r
F P
0 g
s
.72954 .35225 m .74105 .34584 L .78117 .38502 L p .655 .75 .92 r
F P
0 g
s
.65234 .42559 m .64141 .43362 L .6097 .41748 L p .704 .75 .888 r
F P
0 g
s
.60168 .42481 m .6097 .41748 L .64141 .43362 L p .645 .753 .928 r
F P
0 g
s
.4909 .41399 m .4945 .41999 L .46265 .42748 L p .623 .829 .979 r
F P
0 g
s
.46265 .42748 m .45534 .42238 L .4909 .41399 L p .623 .829 .979 r
F P
0 g
s
.31981 .33853 m .33079 .34536 L .28889 .38115 L p .658 .752 .92 r
F P
0 g
s
.28889 .38115 m .27581 .37644 L .31981 .33853 L p .658 .752 .92 r
F P
0 g
s
.4407 .40488 m .44802 .41479 L .41474 .42987 L p .645 .7 .886 r
F P
0 g
s
.41474 .42987 m .40435 .42147 L .4407 .40488 L p .645 .7 .886 r
F P
0 g
s
.66325 .41568 m .65234 .42559 L .61772 .40784 L p .738 .744 .857 r
F P
0 g
s
.6097 .41748 m .61772 .40784 L .65234 .42559 L p .704 .75 .888 r
F P
0 g
s
.80854 .38111 m .79475 .3824 L .75276 .34103 L p .541 .71 .95 r
F P
0 g
s
.74105 .34584 m .75276 .34103 L .79475 .3824 L p .597 .731 .938 r
F P
0 g
s
.56262 .42113 m .56702 .41526 L .60168 .42481 L p .549 .765 .978 r
F P
0 g
s
.56702 .41526 m .56262 .42113 L .5287 .41781 L p .566 .79 .983 r
F P
0 g
s
.30863 .33331 m .31981 .33853 L .27581 .37644 L p .679 .801 .94 r
F P
0 g
s
.27581 .37644 m .26252 .37334 L .30863 .33331 L p .679 .801 .94 r
F P
0 g
s
.6097 .41748 m .60168 .42481 L .56702 .41526 L p .646 .756 .929 r
F P
0 g
s
.52912 .41155 m .5287 .41781 L .4945 .41999 L p .592 .812 .984 r
F P
0 g
s
.4945 .41999 m .4909 .41399 L .52912 .41155 L p .592 .812 .984 r
F P
0 g
s
.67415 .40449 m .66325 .41568 L .62575 .39629 L p .756 .739 .837 r
F P
0 g
s
.61772 .40784 m .62575 .39629 L .66325 .41568 L p .738 .744 .857 r
F P
0 g
s
.43337 .39305 m .4407 .40488 L .40435 .42147 L p .634 .657 .854 r
F P
0 g
s
.40435 .42147 m .39396 .41119 L .43337 .39305 L p .634 .657 .854 r
F P
0 g
s
.48729 .40548 m .4909 .41399 L .45534 .42238 L p .653 .761 .929 r
F P
0 g
s
.45534 .42238 m .44802 .41479 L .48729 .40548 L p .653 .761 .929 r
F P
0 g
s
.5287 .41781 m .52912 .41155 L .56702 .41526 L p .566 .79 .983 r
F P
0 g
s
.8225 .38074 m .80854 .38111 L .76467 .33755 L p .498 .692 .955 r
F P
0 g
s
.75276 .34103 m .76467 .33755 L .80854 .38111 L p .541 .71 .95 r
F P
0 g
s
.68506 .39269 m .67415 .40449 L .63378 .38342 L p .762 .737 .829 r
F P
0 g
s
.62575 .39629 m .63378 .38342 L .67415 .40449 L p .756 .739 .837 r
F P
0 g
s
.42603 .37989 m .43337 .39305 L .39396 .41119 L p .627 .631 .835 r
F P
0 g
s
.39396 .41119 m .38359 .39961 L .42603 .37989 L p .627 .631 .835 r
F P
0 g
s
.29725 .32941 m .30863 .33331 L .26252 .37334 L p .695 .842 .953 r
F P
0 g
s
.26252 .37334 m .24903 .37159 L .29725 .32941 L p .695 .842 .953 r
F P
0 g
s
.69602 .38101 m .68506 .39269 L .64184 .36992 L p .761 .737 .831 r
F P
0 g
s
.63378 .38342 m .64184 .36992 L .68506 .39269 L p .762 .737 .829 r
F P
0 g
s
.61772 .40784 m .6097 .41748 L .57144 .40689 L p .696 .736 .882 r
F P
0 g
s
.56702 .41526 m .57144 .40689 L .6097 .41748 L p .646 .756 .929 r
F P
0 g
s
.41867 .3661 m .42603 .37989 L .38359 .39961 L p .624 .62 .826 r
F P
0 g
s
.38359 .39961 m .3732 .38742 L .41867 .3661 L p .624 .62 .826 r
F P
0 g
s
.8366 .38074 m .8225 .38074 L .77677 .33497 L p .479 .684 .956 r
F P
0 g
s
.76467 .33755 m .77677 .33497 L .8225 .38074 L p .498 .692 .955 r
F P
0 g
s
.57144 .40689 m .56702 .41526 L .52912 .41155 L p .648 .758 .93 r
F P
0 g
s
.70706 .37006 m .69602 .38101 L .64994 .3565 L p .751 .74 .843 r
F P
0 g
s
.64184 .36992 m .64994 .3565 L .69602 .38101 L p .761 .737 .831 r
F P
0 g
s
.48368 .39462 m .48729 .40548 L .44802 .41479 L p .659 .705 .881 r
F P
0 g
s
.44802 .41479 m .4407 .40488 L .48368 .39462 L p .659 .705 .881 r
F P
0 g
s
.52954 .40276 m .52912 .41155 L .4909 .41399 L p .65 .76 .93 r
F P
0 g
s
.4909 .41399 m .48729 .40548 L .52954 .40276 L p .65 .76 .93 r
F P
0 g
s
.2857 .3264 m .29725 .32941 L .24903 .37159 L p .704 .869 .959 r
F P
0 g
s
.24903 .37159 m .23536 .37074 L .2857 .3264 L p .704 .869 .959 r
F P
0 g
s
.41126 .35238 m .41867 .3661 L .3732 .38742 L p .624 .623 .828 r
F P
0 g
s
.3732 .38742 m .36276 .37534 L .41126 .35238 L p .624 .623 .828 r
F P
0 g
s
.52912 .41155 m .52954 .40276 L .57144 .40689 L p .648 .758 .93 r
F P
0 g
s
.71822 .36037 m .70706 .37006 L .65812 .34379 L p .731 .745 .863 r
F P
0 g
s
.64994 .3565 m .65812 .34379 L .70706 .37006 L p .751 .74 .843 r
F P
0 g
s
.62575 .39629 m .61772 .40784 L .57587 .39617 L p .722 .72 .848 r
F P
0 g
s
.57144 .40689 m .57587 .39617 L .61772 .40784 L p .696 .736 .882 r
F P
0 g
s
.40379 .33938 m .41126 .35238 L .36276 .37534 L p .629 .638 .84 r
F P
0 g
s
.36276 .37534 m .35224 .36399 L .40379 .33938 L p .629 .638 .84 r
F P
0 g
s
.77677 .33497 m .78901 .33274 L .8366 .38074 L p .479 .684 .956 r
F P
0 g
s
.48006 .38182 m .48368 .39462 L .4407 .40488 L p .659 .667 .846 r
F P
0 g
s
.4407 .40488 m .43337 .39305 L .48006 .38182 L p .659 .667 .846 r
F P
0 g
s
.72954 .35225 m .71822 .36037 L .6664 .33232 L p .699 .749 .89 r
F P
0 g
s
.65812 .34379 m .6664 .33232 L .71822 .36037 L p .731 .745 .863 r
F P
0 g
s
.57587 .39617 m .57144 .40689 L .52954 .40276 L p .685 .724 .879 r
F P
0 g
s
.27399 .32374 m .2857 .3264 L .23536 .37074 L p .708 .879 .961 r
F P
0 g
s
.23536 .37074 m .22154 .37026 L .27399 .32374 L p .708 .879 .961 r
F P
0 g
s
.39621 .3276 m .40379 .33938 L .35224 .36399 L p .637 .666 .861 r
F P
0 g
s
.35224 .36399 m .34159 .35389 L .39621 .3276 L p .637 .666 .861 r
F P
0 g
s
.52997 .39163 m .52954 .40276 L .48729 .40548 L p .673 .713 .879 r
F P
0 g
s
.48729 .40548 m .48368 .39462 L .52997 .39163 L p .673 .713 .879 r
F P
0 g
s
.63378 .38342 m .62575 .39629 L .58029 .38352 L p .735 .709 .827 r
F P
0 g
s
.57587 .39617 m .58029 .38352 L .62575 .39629 L p .722 .72 .848 r
F P
0 g
s
.52954 .40276 m .52997 .39163 L .57587 .39617 L p .685 .724 .879 r
F P
0 g
s
.47643 .36768 m .48006 .38182 L .43337 .39305 L p .657 .644 .826 r
F P
0 g
s
.43337 .39305 m .42603 .37989 L .47643 .36768 L p .657 .644 .826 r
F P
0 g
s
.74105 .34584 m .72954 .35225 L .67482 .3224 L p .655 .75 .92 r
F P
0 g
s
.6664 .33232 m .67482 .3224 L .72954 .35225 L p .699 .749 .89 r
F P
0 g
s
.38852 .31738 m .39621 .3276 L .34159 .35389 L p .647 .705 .889 r
F P
0 g
s
.34159 .35389 m .33079 .34536 L .38852 .31738 L p .647 .705 .889 r
F P
0 g
s
.64184 .36992 m .63378 .38342 L .58473 .36953 L p .74 .705 .818 r
F P
0 g
s
.58029 .38352 m .58473 .36953 L .63378 .38342 L p .735 .709 .827 r
F P
0 g
s
.58029 .38352 m .57587 .39617 L .52997 .39163 L p .703 .699 .843 r
F P
0 g
s
.53039 .37855 m .52997 .39163 L .48368 .39462 L p .682 .681 .843 r
F P
0 g
s
.48368 .39462 m .48006 .38182 L .53039 .37855 L p .682 .681 .843 r
F P
0 g
s
.47279 .35288 m .47643 .36768 L .42603 .37989 L p .657 .635 .817 r
F P
0 g
s
.42603 .37989 m .41867 .3661 L .47279 .35288 L p .657 .635 .817 r
F P
0 g
s
.64994 .3565 m .64184 .36992 L .58919 .35488 L p .738 .706 .821 r
F P
0 g
s
.58473 .36953 m .58919 .35488 L .64184 .36992 L p .74 .705 .818 r
F P
0 g
s
.75276 .34103 m .74105 .34584 L .68339 .31417 L p .598 .745 .947 r
F P
0 g
s
.67482 .3224 m .68339 .31417 L .74105 .34584 L p .655 .75 .92 r
F P
0 g
s
.38067 .30883 m .38852 .31738 L .33079 .34536 L p .657 .752 .92 r
F P
0 g
s
.33079 .34536 m .31981 .33853 L .38067 .30883 L p .657 .752 .92 r
F P
0 g
s
.52997 .39163 m .53039 .37855 L .58029 .38352 L p .703 .699 .843 r
F P
0 g
s
.58473 .36953 m .58029 .38352 L .53039 .37855 L p .711 .684 .822 r
F P
0 g
s
.46912 .33813 m .47279 .35288 L .41867 .3661 L p .657 .637 .819 r
F P
0 g
s
.41867 .3661 m .41126 .35238 L .46912 .33813 L p .657 .637 .819 r
F P
0 g
s
.65812 .34379 m .64994 .3565 L .59367 .34029 L p .731 .712 .833 r
F P
0 g
s
.58919 .35488 m .59367 .34029 L .64994 .3565 L p .738 .706 .821 r
F P
0 g
s
.53082 .36411 m .53039 .37855 L .48006 .38182 L p .686 .662 .821 r
F P
0 g
s
.48006 .38182 m .47643 .36768 L .53082 .36411 L p .686 .662 .821 r
F P
0 g
s
.37268 .30188 m .38067 .30883 L .31981 .33853 L p .663 .8 .948 r
F P
0 g
s
.31981 .33853 m .30863 .33331 L .37268 .30188 L p .663 .8 .948 r
F P
0 g
s
.76467 .33755 m .75276 .34103 L .69212 .30753 L p .538 .734 .965 r
F P
0 g
s
.68339 .31417 m .69212 .30753 L .75276 .34103 L p .598 .745 .947 r
F P
0 g
s
.53039 .37855 m .53082 .36411 L .58473 .36953 L p .711 .684 .822 r
F P
0 g
s
.46541 .32407 m .46912 .33813 L .41126 .35238 L p .658 .651 .831 r
F P
0 g
s
.41126 .35238 m .40379 .33938 L .46541 .32407 L p .658 .651 .831 r
F P
0 g
s
.58919 .35488 m .58473 .36953 L .53082 .36411 L p .714 .677 .813 r
F P
0 g
s
.6664 .33232 m .65812 .34379 L .59821 .3264 L p .717 .723 .855 r
F P
0 g
s
.59367 .34029 m .59821 .3264 L .65812 .34379 L p .731 .712 .833 r
F P
0 g
s
.53124 .34901 m .53082 .36411 L .47643 .36768 L p .687 .654 .812 r
F P
0 g
s
.47643 .36768 m .47279 .35288 L .53124 .34901 L p .687 .654 .812 r
F P
0 g
s
.46165 .31123 m .46541 .32407 L .40379 .33938 L p .66 .675 .854 r
F P
0 g
s
.40379 .33938 m .39621 .3276 L .46165 .31123 L p .66 .675 .854 r
F P
0 g
s
.53082 .36411 m .53124 .34901 L .58919 .35488 L p .714 .677 .813 r
F P
0 g
s
.59367 .34029 m .58919 .35488 L .53124 .34901 L p .714 .679 .815 r
F P
0 g
s
.36453 .29623 m .37268 .30188 L .30863 .33331 L p .663 .841 .968 r
F P
0 g
s
.30863 .33331 m .29725 .32941 L .36453 .29623 L p .663 .841 .968 r
F P
0 g
s
.77677 .33497 m .76467 .33755 L .70102 .3022 L p .49 .722 .974 r
F P
0 g
s
.69212 .30753 m .70102 .3022 L .76467 .33755 L p .538 .734 .965 r
F P
0 g
s
.67482 .3224 m .6664 .33232 L .6028 .31371 L p .692 .737 .885 r
F P
0 g
s
.59821 .3264 m .6028 .31371 L .6664 .33232 L p .717 .723 .855 r
F P
0 g
s
.53167 .33395 m .53124 .34901 L .47279 .35288 L p .686 .656 .815 r
F P
0 g
s
.47279 .35288 m .46912 .33813 L .53167 .33395 L p .686 .656 .815 r
F P
0 g
s
.45783 .29992 m .46165 .31123 L .39621 .3276 L p .66 .71 .884 r
F P
0 g
s
.39621 .3276 m .38852 .31738 L .45783 .29992 L p .66 .71 .884 r
F P
0 g
s
.59821 .3264 m .59367 .34029 L .53167 .33395 L p .709 .688 .828 r
F P
0 g
s
.53124 .34901 m .53167 .33395 L .59367 .34029 L p .714 .679 .815 r
F P
0 g
s
.53211 .31959 m .53167 .33395 L .46912 .33813 L p .685 .668 .827 r
F P
0 g
s
.46912 .33813 m .46541 .32407 L .53211 .31959 L p .685 .668 .827 r
F P
0 g
s
.68339 .31417 m .67482 .3224 L .60748 .30257 L p .655 .751 .92 r
F P
0 g
s
.6028 .31371 m .60748 .30257 L .67482 .3224 L p .692 .737 .885 r
F P
0 g
s
.35623 .29145 m .36453 .29623 L .29725 .32941 L p .66 .868 .978 r
F P
0 g
s
.29725 .32941 m .2857 .3264 L .35623 .29145 L p .66 .868 .978 r
F P
0 g
s
.78901 .33274 m .77677 .33497 L .71008 .29774 L p .468 .715 .977 r
F P
0 g
s
.70102 .3022 m .71008 .29774 L .77677 .33497 L p .49 .722 .974 r
F P
0 g
s
.53167 .33395 m .53211 .31959 L .59821 .3264 L p .709 .688 .828 r
F P
0 g
s
.6028 .31371 m .59821 .3264 L .53211 .31959 L p .7 .704 .851 r
F P
0 g
s
.45393 .29028 m .45783 .29992 L .38852 .31738 L p .657 .752 .92 r
F P
0 g
s
.38852 .31738 m .38067 .30883 L .45393 .29028 L p .657 .752 .92 r
F P
0 g
s
.53255 .30643 m .53211 .31959 L .46541 .32407 L p .681 .688 .85 r
F P
0 g
s
.46541 .32407 m .46165 .31123 L .53255 .30643 L p .681 .688 .85 r
F P
0 g
s
.69212 .30753 m .68339 .31417 L .61225 .2931 L p .604 .76 .953 r
F P
0 g
s
.60748 .30257 m .61225 .2931 L .68339 .31417 L p .655 .751 .92 r
F P
0 g
s
.34782 .287 m .35623 .29145 L .2857 .3264 L p .657 .878 .98 r
F P
0 g
s
.2857 .3264 m .27399 .32374 L .34782 .287 L p .657 .878 .98 r
F P
0 g
s
.53211 .31959 m .53255 .30643 L .6028 .31371 L p .7 .704 .851 r
F P
0 g
s
.71008 .29774 m .71927 .29362 L .78901 .33274 L p .468 .715 .977 r
F P
0 g
s
.60748 .30257 m .6028 .31371 L .53255 .30643 L p .683 .726 .883 r
F P
0 g
s
.44995 .28222 m .45393 .29028 L .38067 .30883 L p .646 .795 .954 r
F P
0 g
s
.38067 .30883 m .37268 .30188 L .44995 .28222 L p .646 .795 .954 r
F P
0 g
s
.533 .29481 m .53255 .30643 L .46165 .31123 L p .672 .717 .882 r
F P
0 g
s
.46165 .31123 m .45783 .29992 L .533 .29481 L p .672 .717 .882 r
F P
0 g
s
.70102 .3022 m .69212 .30753 L .61711 .28521 L p .546 .761 .977 r
F P
0 g
s
.61225 .2931 m .61711 .28521 L .69212 .30753 L p .604 .76 .953 r
F P
0 g
s
.53255 .30643 m .533 .29481 L .60748 .30257 L p .683 .726 .883 r
F P
0 g
s
.61225 .2931 m .60748 .30257 L .533 .29481 L p .655 .751 .92 r
F P
0 g
s
.53346 .28484 m .533 .29481 L .45783 .29992 L p .656 .752 .92 r
F P
0 g
s
.45783 .29992 m .45393 .29028 L .53346 .28484 L p .656 .752 .92 r
F P
0 g
s
.44589 .27545 m .44995 .28222 L .37268 .30188 L p .628 .831 .979 r
F P
0 g
s
.37268 .30188 m .36453 .29623 L .44589 .27545 L p .628 .831 .979 r
F P
0 g
s
.533 .29481 m .53346 .28484 L .61225 .2931 L p .655 .751 .92 r
F P
0 g
s
.71008 .29774 m .70102 .3022 L .62207 .27861 L p .496 .756 .988 r
F P
0 g
s
.61711 .28521 m .62207 .27861 L .70102 .3022 L p .546 .761 .977 r
F P
0 g
s
.61711 .28521 m .61225 .2931 L .53346 .28484 L p .615 .774 .957 r
F P
0 g
s
.53393 .27645 m .53346 .28484 L .45393 .29028 L p .629 .786 .957 r
F P
0 g
s
.45393 .29028 m .44995 .28222 L .53393 .27645 L p .629 .786 .957 r
F P
0 g
s
.44175 .26953 m .44589 .27545 L .36453 .29623 L p .609 .853 .99 r
F P
0 g
s
.36453 .29623 m .35623 .29145 L .44175 .26953 L p .609 .853 .99 r
F P
0 g
s
.53346 .28484 m .53393 .27645 L .61711 .28521 L p .615 .774 .957 r
F P
0 g
s
.71927 .29362 m .71008 .29774 L .62713 .27286 L p .473 .752 .991 r
F P
0 g
s
.62207 .27861 m .62713 .27286 L .71008 .29774 L p .496 .756 .988 r
F P
0 g
s
.62207 .27861 m .61711 .28521 L .53393 .27645 L p .565 .788 .983 r
F P
0 g
s
.5344 .26934 m .53393 .27645 L .44995 .28222 L p .593 .813 .984 r
F P
0 g
s
.44995 .28222 m .44589 .27545 L .5344 .26934 L p .593 .813 .984 r
F P
0 g
s
.43754 .26392 m .44175 .26953 L .35623 .29145 L p .599 .861 .993 r
F P
0 g
s
.35623 .29145 m .34782 .287 L .43754 .26392 L p .599 .861 .993 r
F P
0 g
s
.53393 .27645 m .5344 .26934 L .62207 .27861 L p .565 .788 .983 r
F P
0 g
s
.62713 .27286 m .63227 .26744 L .71927 .29362 L p .473 .752 .991 r
F P
0 g
s
.62713 .27286 m .62207 .27861 L .5344 .26934 L p .52 .792 .995 r
F P
0 g
s
.53489 .26309 m .5344 .26934 L .44589 .27545 L p .559 .826 .996 r
F P
0 g
s
.44589 .27545 m .44175 .26953 L .53489 .26309 L p .559 .826 .996 r
F P
0 g
s
.5344 .26934 m .53489 .26309 L .62713 .27286 L p .52 .792 .995 r
F P
0 g
s
.63227 .26744 m .62713 .27286 L .53489 .26309 L p .498 .792 .998 r
F P
0 g
s
.53539 .25714 m .53489 .26309 L .44175 .26953 L p .542 .83 .998 r
F P
0 g
s
.44175 .26953 m .43754 .26392 L .53539 .25714 L p .542 .83 .998 r
F P
0 g
s
.53489 .26309 m .53539 .25714 L .63227 .26744 L p .498 .792 .998 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000SoR]Co00?o0000ogo:oomob_l00omob_l;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`00013oR]Co2?l0000@
ogo:o`[o00006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Boooo
o`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`1/oooo
o`Co00000onIg?h00ol0003oR]Cooh[Do`09oh[Do`_o00001on?doh00ol0003oQL[nohG:oP03ohG:
oP[o00002omob_l7o`0001;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[oooo
o`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Ioooool4o`0000KoVMcn0ol00003oh[Do`?o00003on?doh8o`0000ooQL[n2Ol00005ogo:o`04
o`000?mi`?goNL3mogW0o@?o00003oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02[ooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Rooooo`Co00001_nIg?h4o`0000;oVm[m00?o0000ohoCo_n?doh02On?doh:o`0000Oo
Um3k00?o0000oi39non@bO/00on@bO/9o`0000[oQL[n1Ol00007ogW0o@?o00003?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`Co00001_nIg?h4o`0000GoVm[m
0ol00003ohoCoP?o00003_nGd?/8o`0000koT<Wk2Ol00004ohG:oP04o`000?mn`OcoO/7logk1o0So
NL3m0ol00009ooooo`03o`000?oooooooooo02oooooo0_l0000[ooooo`007Oooool00ol0003ooooo
ooooo`03ooooo`?o00002?ooool00ol0003oooooooooo`1Hooooo`Co00001_nIg?h4o`0000GoVm[m
1?l00002oj3DnP03o`000?nGd?_oUm3k00SoUm3k2_l00007oj79m003o`000?nMa_CoWLKd00;oWLKd
2Ol0000:oi39n`Co00001omn`O`00ol0003oNL3mogW0o@05ogW0o@?o00001_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo02Sooooo000Kooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`Co00001onIg?h3o`0000GoVm[m1?l0
0005oj3DnP?o00000_nGd?/4o`0001CoXLWd00?o0000oig6m?nMa_@02onMa_@9o`0000CoT<Wk00?o
0000oh_2n_n;`_X02?mn`O`2o`0000KoNL3m0ol00004ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0:?ooool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?
ooooo`?o00002?nIg?h3o`0000CoVm[m1?l00005oj3DnPCo00000onUbo@00ol0003oXLWdoj79m00;
oj79m0go00005_nMa_@4o`0000KoRl;j0_l00006ogk1o0Co00001?mi`?d3o`000003ooooool0003o
oooo03;ooooo00?o0000ooooooooool09oooool002?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1<ooooo`;o00000onXh?X00ol0003oVMcnoiWLoP02oiWLoP;o00001OnKf_d2o`00
00KoX=Cj1?l00006ojG;m0?o00000_nQbO@:o`0000coYl3[00?o0000ojO0jonW`>/01?nW`>/<o`00
00KoWLKd00Go0000oi[2lonJ`_?oV/;co`000007oh_2nP?o00001Omn`O`3o`0000CoNL3m0ol0000c
ooooo`03o`000?oooooooooo02Kooooo000Sooooo`;o00003Oooool00ol0003oooooooooo`19oooo
o`;o00001OnXh?X4o`0000GoVm[m00?o0000oj3Dn_nPe?X01?nPe?X4o`0000KoYL_d1?l00002ojS0
j`03o`000?nW`>_oYl3[01GoYl3[00?o0000ojO0jonW`>/04OnW`>/6o`0000OoV/;c0ol00006oh_2
nP?o00001?mn`O`3o`0000;oNL3m00?o0000ogW0oOl000000_l0000`ooooo`03o`000?oooooooooo
02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2o`0000Go
Z>3j0_l00003ojSNnP;o000000?oVm[moj3Dn_nPe?X01OnPe?X3o`0000KoYL_d1?l00006ojS0j`03
o`000?nW`>_oYl3[00ooYl3[1ol0000HojO0j`04o`000?nW`>_oYl3[o`0000OoV/;c1?l00005oh_2
nPCo00000omn`O`3o`0000CoNL3m0_l0000^ooooo`;o00009oooool002?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`13ooooo`;o00001OnXh?X2o`0000?oZ=kj0_l00002ojWGm`03
o`000?nPe?[oX=Cj00;oX=Cj0_l00007ojG;m0?o00002onX`>/00ol0003oYl3[ojO0j`04ojO0j`[o
00001_n/]n400ol0003o[[WRojjihP04ojjihPco00001OnW`>/00ol0003oYl3[ojO0j`04ojO0j`?o
00001_nJ`_<3o`0000KoRl;j0ol00002ogk1o0Co00000omg]oX2o`0002kooooo00?o0000oooooooo
ool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`;o0000
1OnXh?X2o`0000?oZ=kj0_l00004ojWGm`?o00002?nUbo@3o`0000coZ<3[0ol000000onW`>_o0000
o`000002o`00017o[;OQ00?o0000ojjih_n^^N804?n^^N86o`0000WoYl3[1?l00005oi[2l`?o0000
1_n;`_X3o`0000?oOKSi1Omg]oX2o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nXh?[oZ>3j00?oZ>3j0_l0
0003ojSNnP;o00001?nYeoL2o`0000?oZLcb00?o0000ojG;m?nUbo@00_nUbo@2o`0000_oZ<3[1Ol0
0002ojRehP03o`000?n/]n7o[;OQ01Co[;OQ00?o0000ojjih_n^^N805On^^N801?l0003o/KcRok6l
h_l0000:ojO0j`?o00001OnJ`_<3o`0000;oRl;j00Co0000ohVkmol0003o00001Omm^?T5ogNgnP03
o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool002;ooooo0_l0000Cooooo`03o`00
0?oooooooooo03_ooooo0_l00004ojSPnP;o00000onXg_X2o`0000CoZMOg0_l00005ojW<lP?o0000
2onX`>/4o`0000SoZ;GR00?o0000ojbghOn/]n402?n/]n4<o`0000Go[[WR00?o0000ojjih_n^^N80
3_n^^N800ol0003o/KcRok6lhP04ok6lhP?o00002?nW`>/3o`0000GoV/;c1?l000001?n9^oOo0000
ohVkmon9^oL4ogfhn@;o00000omg]oX2o`0002_ooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`;o00001?nXh?X2o`0000?oZ=kj
0_l00004ojWGm`;o00001OnYc?82o`000003ojS0jol0003oZ<3[00OoZ<3[1?l0000:ojRehP?o0000
00?o[;OQo`000?l000001ol0000;ojj`f@03o`000?nc]=Wo/kCI00Co/kCI2ol00005ojjihP03o`00
0?na_>;o/KcR00Oo/KcR0ol00008ojO0j`Ko00000_nI__83ohVkm`04o`000?n9^oOoRK_gohVkm`Co
OKSi0_l00003ogNgnP;o0000:Oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Gooooo0_l00004ojSPnP;o00000onXg_X2o`0000CoZMOg
0_l00005ojW<lP;o00001?nX`>/01?l0003oZ<3[ojS0jonX`>/4o`0000[oZ;GR1?l00002ojR/fP03
o`000?n^/=Wo[[3I01?o[[3I00?o0000ok>dfOnc]=T03onc]=T5o`0000go/KcR0ol00005ojO0j`Go
00001OnI__800ol0003oRK_go`000003ohVkm`;o00000omm^?T2o`0000?oMkOj0_l0000Wooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0boooo
o`;o00001?nXh?X2o`0000?oZ=kj0_l00004ojWGm`;o00001OnYc?82o`0000KoZ<3[0ol0000;ojRe
hPCo00001_nX[=X00ol0003o[[3Iojj`f@0Cojj`f@03o`000?nc]=Wo/kCI01?o/kCI00?o0000okNi
f_ng^MX00_l0000<ok6lhPGo00000onW`>/00ol0003oYko[ojNoj`06oiVnlP;o00001?n9^oL2o`00
00?oOKSi00?o0000ogNgn_mg]oX00_mg]oX2o`0002Oooooo00?o0000ooooooooool01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo000Qoooo
o`?o00005oooool00ol0003oooooooooo`0_ooooo`;o00001OnXh?X00ol0003oZ=kjojSNnP02ojSN
nP03o`000?nYeoOoZMOg00;oZMOg0_l00005ojW<lP;o00001_nX`>/2o`0000;oYKCS00?o0000ojRe
h_nX]N801OnX]N84o`0000_oZ:cJ00?o0000ojj`fOn^/=T02?n^/=T;o`0001Go/kCI00?o0000okNi
f_ng^MX00ong^MX3o`0000Oo/KcR0ol000001_na_>;o0000o`000?l0003oYl3[o`0000GoYko[00?o
0000oiVnl_nI__800_nI__83o`0000CoRK_g0_l00002ogfhn@;o00001?mg]oX2o`0002Gooooo00?o
0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool0027ooooo00?o0000ooooooooool06?ooool2o`0002gooooo1?l00003ojSPnP03o`000?nX
g_[oZ=kj00;oZ=kj00?o0000ojWGmonYeoL00_nYeoL2o`0000KoZLcb00?o0000ojS0jonX`>/01?nX
`>/2o`0000GoYKCS00?o0000ojReh_nX]N800_nX]N82o`0000goZ:cJ0ol000000on^/=Wo0000o`00
0007o`0000[o[j_C00?o0000okF`done/=<00one/=<;o`0000Co/kCI00?o0000okNif_ng^MX01ong
^MX7o`0000Oo/KcR00?o0000ojNojonW_n/01_nW_n/01ol0003oVKkboiVnl_nI__;o0000oiVnl_l0
00001On9^oL2o`0000;oOKSi0_l00004ogNgnP03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?nehOKo
]N7f00;o]N7f1?l00002ojSNnP03o`000?nYeoOoZMOg00?oZMOg00?o0000ojW<l_nYc?801?nYc?82
o`0000GoZ<3[0_l00007ojFdh`?o00003OnX[=X4o`0000;oZ:KD00?o0000ojn[don_Zm<04_n_Zm<0
0ol0003o]K3CokF`d`0>okF`d`Go00002_ng^MX6o`0000Ko/KcR00Co0000ok:ohonb_n?o00001onW
_n/2o`0000;oVKkb00Co0000oiVnl_l0003o00001On9^oL01?l0003oOKSiogfhnOmm^?T2o`0000?o
MkOj0_l0000Tooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09oooool00ol0003o]N7fokGQmP02okGQmP04o`000?ndg_Go]=keokCNm@Co00000onY
eoL00ol0003oZLcbojW<lP04ojW<lP;o00001OnX`>/2o`0000OoYKCS0_l000000onSZ]co0000ojR/
fP09ojR/fPCo00001_nXY]@00ol0003o[j_Cojn[d`0Bojn[d`03o`000?ne/=?o]K3C01;o]K3C00?o
0000ok^feOnk]]D00ol00002okNifP?o00001_ng^MX3o`0000;o/KcR00?o0000ok:ohonb_n<00onb
_n<2o`0000KoYko[0_l000001?nI__;o0000oiVnl_nI__82o`0000CoRK_g0_l00003ogfhn@03o`00
0?mg]o[oMkOj00;oMkOj0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo02Go
oooo00?o0000okGQm_nehOH00_nehOH01Ol0003o]=keokCNmOndg_Go000000Co/MOc0ol00005ojW<
lP;o00001OnX`>/2o`0000KoYKCS0ol00004oj>Zg003o`000?nX[=[oZ:cJ00CoZ:cJ0ol0000;ojRV
e003o`000?n_Zm?o[j_C00co[j_C1_l00004okF`d`03o`000?ne/=?o]K3C00co]K3C00?o0000ok^f
eOnk]]D00onk]]D6o`0000Wo]kWJ0_l00008ok:oh`;o00001_nW_n/2o`0000CoVKkb0_l00004ohVk
m`;o00000_mm^?T2o`0000;oMkOj0ol0000Pooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0S
ooooo`03o`000?nehOKo]N7f00;o]N7f00Go0000okCNmOndg_Go]=keo`000004ok7Gl`04o`000?n]
cO3o[Lg`ojg=l0;o00000_nYc?800ol0003oZ<3[ojS0j`03ojS0j`;o00001_nU]><2o`0000OoXj[L
00Co0000ojR/f_nX[=[oZ:cJ0ol0000>ojRVe003o`000?n_Zm?o[j_C00;o[j_C2_l00005ojnWd003
o`000?nf[M3o]Zg@00?o]Zg@2Ol00005okF`d`03o`000?nk]]Go^kKE00?o00001_nk]]D3o`0000Oo
]kWJ00?o0000ok^ng?l000002?nb_n<2o`0000KoYko[0_l00004oiVnlP;o00000_n9^oL8o`0000?o
NZod00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?nehOKo]N7f00;o]N7f00Go0000okCNmOndg_Go]=keo`000004ok7Gl`03o`000?n]
cO3o[Lg`00?o[Lg`0ol00004ojS0j`;o00001_nU]><2o`0000WoXj[L0ol0000@ojRVe0?o000000Co
[j_Co`000?l0003o00003on_Ym000ol0003o]Zg@okJ]d00<okJ]d0So00003?nk]]D4o`0000;o]kWJ
00?o0000ok^ng?nk_]`00_nk_]`2o`0000Oo/[oS00?o0000ojNojonW_n/01?nW_n/2o`0000CoVKkb
0ol00003ohZel`05o`000?mo/OCoOk7dognam?l000001?mj[o@00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01cooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003o
]N7fokGQmP02okGQmP05o`000?ndg_Go]=keokCNmOl000001?naeo<00ol0003o[Lg`ojg=l003ojg=
l005o`000?nX`>_oZ<3[ojS0jol000000_nX`>/00ol0003oYKCSojFdh`04ojFdh`;o00002OnSZ]`2
o`000003oj6Seol0003oZ:KD00_oZ:KD1Ol00002ojRSd@03o`000?n_Ym3o[jO@017o[jO@00?o0000
okJ]d?nf[M003_nf[M03o`0000;o_;CB0ol0000>ok^fe@;o00001onk_]`2o`0000Ko/[oS0_l00004
ojNoj`06o`000?nW_n_o0000o`000?nI__;o00000onH^o04ohZel`05o`000?mo/OCoOk7dognam?l0
00001?mj[o@00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool07Oooool00ol0003o]N7fokGQmP02okGQmP05o`000?ndg_Go]=keokCN
mOl000001?naeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[0ol00004ojFd
h`?o00002OnSZ]`2o`0000CoXJ?G00?o0000ojRVe?nXY]@01OnXY]@4o`0000SoZ:?A00?o0000ojnW
d?n_Ym004?n_Ym000ol0003o]Zg@okJ]d00;okJ]d0?o00000_nf[M000ol0003o_;CBokbddP03okbd
dPCo00002onk]]D00ol0003o`;gGo`000007ok^ng0?o00001Onb_n<2o`0000?oYko[00Co0000ojNo
jol0003o00001OnH^o04ohZel`05o`000?mo/OCoOk7dognam?l000001?mj[o@00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo01_ooooo00Co0000okGQm_nehOKo]N7f
0_l00002okCNm@;o00001?naeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[
00Go0000oj:ciOnR/nGoX[?Uo`000002ojFdh`03o`000?nSZ]coXj[L00SoXj[L0_l00006oj6Se`04
o`000?nXY]CoZ:KDojRVe0Co00003?nXXm400ol0003o[jO@ojnWd007ojnWd0[o00000_nf[M03o`00
00Go]Zg@0ol00004okJ]d003o`000?nl]=;o_;CB00So_;CB1?l00006ok^fe@03o`000?o0_MOo`;gG
00;o`;gG00?o0000ok^ng?nk_]`01_nk_]`2o`0000Go/[oS0_l000000onW_n_o0000o`000002ojNo
j`03o`000?nH^o3oV;_`00?oV;_`1?n:]O<01Ol0003oOk7dognam?mo/OCo000000CoNZod00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`008?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01Wooooo00Go0000okGQm_nehOKo]N7fo`000003okCNm@03o`000?naeo?o
/MOc00?o/MOc00?o0000ojg=l?n]cO000on]cO000ol0003oZ<3[ojS0j`02ojS0j`03o`000?nR/nGo
X[?U00;oX[?U0_l0000:oj>Zg0;o00002?nQXmL3o`00013oZ:?A0ol000000on_Ym3o0000o`000005
o`0000Wo[jO?00?o0000okJ]d?nf[M000onf[M09o`0000?o]Zg@00?o0000okbdd_nl]=803?nl]=83
o`0000;o^kKE00?o0000ol2meoo0_ML01?o0_ML2o`0000So^kkL0_l00005ok:oh`04o`000?nW_n_o
Yko[o`0000;oYko[00?o0000oiRkl?nH^o000onH^o001Ol0003oR[GcohZelon:]O?o000000?oOk7d
00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0Looooo`03o`000?oooooo000001_ooooo
000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool01Ol0003o]N7fokGQ
m_nehOKo000000Co]=ke1Onaeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[
00?o0000oj:ciOnR/nD00_nR/nD01?l0003oWJWOoifYgol00007oj>Zg0;o00002?nQXmL2o`000003
oinOdol0003oZ:?A00coZ:?A1?l00002ojRRd@03o`000?n_Yloo[jO?00oo[jO?00?o0000okJ]d?nf
[M000_nf[M03o`0000Oo]Zg@1?l0000AokbddP;o00002Oo0_ML2o`0000So^kkL0_l000001onb_n?o
0000okC3iOnd`nGo0000ojNojol000000onW_n/00ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?o
R[GcohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_m003o`000?oooooooooo01gooooo00?o
0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0E
ooooo`05o`000?nehOKo]N7fokGQm_l000001?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`0_l0
0004ojS0j`03o`000?nR/nGoX[?U00;oX[?U00?o0000oifYgonMZMl00_nMZMl00ol0003oXj[Loj>Z
g002oj>Zg0;o00002?nQXmL2o`0000CoWioC00?o0000ojRSdOnXXm401OnXXm45o`0000KoZ:;A00?o
0000ojnWcon_Yll03on_Yll00ol0003o]Zg@o`000002o`0000go]Zg@00?o0000okfddOnm]=401?l0
000<okbddP03o`000?o2_=Co000000Wo`;gG00?o0000ok^ng?nk_]`01onk_]`00ol0003o]<?UokC3
i@02okC3i@03o`000?nW_n_o000000?oYko[00?o0000oiRkl?nH^o000onH^o001Ol0003oR[GcohZe
lon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Sooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Cooooo`03o`000?ne
hOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0jonX`>/00_nX
`>/2o`0000CoX[?U00?o0000oifYgonMZMl01?nMZMl01?l0003oXj[Loj>Zg?l00007oj6Se`?o0000
1onOWm<01?l0003oZ:?AojRSdOnXXm43o`0000coZ:;A00?o0000ojnWcon_Yll03On_Yll3o`00013o
]Zg@00?o0000okfddOnm]=401?nm]=45o`0000Ko_;CB00?o0000ol:le?o2_=@00_o2_=@2o`0000Oo
`;gG0_l00006ok^ng003o`000?nma=oo000000Co]<?U00?o0000ojNojol000000onW_n/00ol0003o
V;_`oiRkl003oiRkl005o`000?n:]O?oR[GcohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_
m003o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool001oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?nehOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03
o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0jonX`>/00_nX`>/00ol0003oX[?Uoj:ci@03oj:ci@03
o`000?nMZMooWJWO00GoWJWO0_l00007oj6Se`;o00002_nOWm<3o`00013oZ:;A00?o0000ojnWcon_
Yll01_n_Yll9o`0000;o]Zg@1ol00007okJ]d003o`000?nm]=7o_KCA00[o_KCA1?l00002okbddP03
o`000?o2_=Co`[cD00Co`[cD0_l00007ol2me`;o00000onk_]`01Ol0003o_LCOokg4gonma=oo0000
00Co]<?U00?o0000ojNojol000000onW_n/00ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?oR[Gc
ohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_m003o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?oooo
o`03o`000?nehOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0
jonX`>/00_nX`>/00ol0003oX[?Uoj:ci@03oj:ci@03o`000?nMZMooWJWO00GoWJWO00Co0000oiVQ
f_nIXM[o00001?nQXmL2o`0000[oWioC0_l000000onOW]?o0000ojRRd@0>ojRRd@_o00000_n_ZM83
o`0000?o[jWB00?o0000okJ_d_nf[m801onf[m88o`00013o_KCA0_l00009ol:le003o`000?o0_MOo
`;gG00Ko`;gG00?o0000ok^ng?l000001Onma=l00ol0003o]<?UokC3i@02okC3i@;o00001?nW_n/0
0ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?oR[GcohZelol000000omo/O@00ol0003oNZodogZ_
m002ogZ_m003o`000?oooooooooo01_ooooo0_l0000Hooooo`007oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00gooooo3?l00003ok7Gl`Co[Lg`00?o0000ojS0jonX`>/00_nX`>/0
0ol0003oX[?Uoj:ci@03oj:ci@03o`000?nMZMooWJWO00GoWJWO00?o0000oiVQf_nIXMX00_nIXMX0
1?l0003oXJ?Goj6Seol0000:oinOd`;o00001?nOW]<00ol0003oZ:;AojRRd@08ojRRd@Co00000_nX
Y=<00ol0003o[jWBojnYdP05ojnYdP?o00001_n_ZM800ol0003o]ZoBokJ_dP0>okJ_dP03o`000?nl
]M?o_;GC00?o00003?nm]=400ol0003o`kcDo`000008ol:le0;o00001oo0_ML00ol0003o_LCOokg4
g`05okg4g`03o`000?nd`nGo]<?U00;o]<?U0_l00004ojNoj`03o`000?nH^o3oV;_`00?oV;_`00Go
0000ohZelon:]O?oR[Gco`000003ognam003o`000?mj[oCoNZod00;oNZod00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00cooooo00Go0000okkMkonngNoo_]g_o`000003okcKk`04o`000?nheNoo^=G_okSEk`Co
00000on]cO05ojS0j`GoX[?U00?o0000oifYgonMZMl01OnMZMl00ol0003oVJ7JoiVQfP03oiVQfP;o
00002OnOWm<3o`0000KoWikC00?o0000ojRRdOnXX]401?nXX]44o`0000KoZ:CC00?o0000ojnYd_n_
ZM800_n_ZM83o`0000Wo[jWB00?o0000okJ_d_nf[m803Onf[m800ol0003o_;GCokbed`04okbed`?o
00002?nm]=401?l0003o`kcDol>le?o3_=@2o`0000So`[cD0_l00004ol2me`03o`000?o4aM_oa<GK
00Oo_LCO00?o0000okC3iOnd`nD00_nd`nD2o`0000CoYko[00?o0000oiRkl?nH^o000onH^o001Ol0
003oR[GcohZelon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Gooooo000Oooooo`;o0000;Oooool00ol0003oooooooooo`0:oooo
o`05o`000?nngNoo_]g_okkMkol000000onlfnl00ol0003o^=G_okSEk`03okSEk`03o`000?nac>ko
/Lc^00Co00000onX`>/5oj:ci@03o`000?nMZMooWJWO00GoWJWO00?o0000oiVQf_nIXMX00onIXMX0
0ol0003oUYcGo`000007oinOd`;o00002OnOW]<00ol0003oZ:;AojRRd@04o`0000_oZ:CC1?l00004
ojnYdPWo00000_nf[m82o`0000_o]ZoB00?o0000okbedonl]M<01onl]M<3o`0000Co_KCA00?o0000
ol>le?o3_=@01?o3_=@2o`0000So`[cD0_l000000oo0_MOo0000olC5f`03olC5f`03o`000?nma=oo
_LCO00Co_LCO00?o0000okC3iOnd`nD00_nd`nD2o`0000CoYko[00?o0000oiRkl?nH^o000onH^o00
1Ol0003oR[GcohZelon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02Oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00?o
0000ok7<k_nac>h00_nac>h00ol0003oZ<3[ojS0j`03o`0000CoX[?U00?o0000oifYgonMZMl01?nM
ZMl2o`0000GoVJ7J00Go0000oiJLeonFW=OoUYcGo`000004oinOd`;o00002onOW]<3o`0000goZ:CC
0ol000000on_ZM;o0000o`000004o`0000So[ZkG00?o0000ok>beonc/]L00_nc/]L7o`0000Co]ZoB
00?o0000okbedonl]M<02_nl]M<3o`000003okfddOl0003o`kcD00Oo`kcD00?o0000ol:le?o2_=@0
1oo2_=@00ol0003oa<GKolC5f`04olC5f`03o`000?nma=oo_LCO00Co_LCO00?o0000okC3iOnd`nD0
0_nd`nD00ol0003oYko[ojNoj`03ojNoj`04o`000?nH^o3oV;_`oiRkl13o00007Oooool00ol0003o
ooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo
00Go0000okkMkonngNoo_]g_o`000003okcKk`03o`000?nheNoo^=G_00?o^=G_00Go0000ok7<k_na
c>ko/Lc^o`000004ojS0j`04o`000?nO]>Oo0000o`0000;oX[?U1_nMZMl00ol0003oVJ7JoiVQfP04
oiVQfP03o`000?nFW=OoUYcG00?oUYcG00Co0000oinOdonOWm?o00002onOW]<2o`000003oj2QeOl0
003oZ:CC00WoZ:CC1?l00002ojRZf003o`000?n^[]Oo[ZkG00go[ZkG00?o0000ok>beonc/]L02Onc
/]L4o`00013o_;GC00?o0000ol>le?o3_=@02?o3_=@2o`0000Ko`[cD00?o0000olO5f?l000001_o4
aM/00ol0003o_LCOokg4g`04okg4g`03o`000?nd`nGo]<?U00;o]<?U00?o0000ojNojonW_n/00_nW
_n/4o`0000;oVKS]1?n=/>h4ohB[kPGoP:S^00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Cooooo`007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00Go0000
okkMkonngNoo_]g_o`000004okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_nac>ko/Lc^
o`000004ojS0j`03o`000?nO]>OoWkCW00;oWkCW0_l00005oifYg`03o`000?nIXM[oVJ7J00?oVJ7J
0_l00006oiJLe`;o00002onOW]<2o`0000CoX:7E00?o0000ojRTdonXY=<01?nXY=<4o`0000GoZ:[H
00?o0000ojj^eon^[]L03?n^[]L00ol0003o/k;Gok>be`0=ok>be`03o`000?nh^=Wo^;SI00Co0000
2_nl]M<01?l0003o`KgFo`000?l00009ol>le0;o00000oo2_=@01Ol0003oalGHolO5f?o7aMSo0000
00Koa<GK00?o0000okg4gonma=l01?nma=l00ol0003o]<?UokC3i@02okC3i@05o`000?nW_n_o0000
o`000?nW_n/01_nI^>d4ohf`kPCoQ:_^1On0Z>h00ol0003oooooooooo`0Iooooo`03o`000?oooooo
000001Cooooo000Nooooo`?o0000<Oooool2o`0000Gooooo00Go0000okkMkonngNoo_]g_o`000003
okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000ok7<k_nac>h00_nac>h01Ol0003oZ<3[ojS0jonX
`>_o000000GoWkCW00?o0000oiJXhol000000onMZMl00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nF
W=OoUYcG00GoUYcG00Co0000oiJKeonFVmOo00001onOW]<3o`0000KoX:7E00Co0000ojRTdonXY=?o
Z:CC1?l00009ojRZf003o`000?n^[]Oo[ZkG00Co[ZkG2?l00003ok>be`03o`000?nc/]Oo/k;G00Wo
/k;G00?o0000okRhfOnh^=T01?nh^=T3o`0000Ko_;GC00?o0000ol6me_o1_MH00_o1_MH2o`0000Wo
`kcD00?o0000ol:le?l000001Oo7aMP00ol0003oa<GKolC5f`04olC5f`03o`000?nma=oo_LCO00Co
_LCO00?o0000okC3iOnd`nD00ol00004ojNoj`GoVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[
kP03o`000?n0Z>koP:S^00;oP:S^00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aoooo
o`007_ooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool000000onngNl00ol0
003o_=__okcKk`02okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_nac>ko/Lc^o`000004
ojS0j`03o`000?nO]>OoWkCW00;oWkCW00Oo0000oiJXhonFZ>?oUZSSo`000?nMZMoo000000GoVJ7J
00?o0000oiJLeonFW=L01OnFW=L00ol0003oUY_GoiJKe`02oiJKe`03o`000?nOW]?oWikC00;oWikC
0_l00009oj2Qe@Go00002_nXZ]P3o`000003ojj^eol0003o000000?o00001on/]^400ol0003o[kWQ
ojnih@02ojnih@Oo00000onc/]L00ol0003o^;SIokRhf@08okRhf@Co00000_nl]M<00ol0003o`KgF
ol6meP04ol6meP?o00001oo3_=@00ol0003oalGHolO5f005olO5f003o`000?o4aM_oa<GK00Coa<GK
00?o0000okg4gonma=l00onma=l3o`0000;o]<KW00?o0000ojNojonW_n/00_nW_n/00ol0003oVKS]
oiVhk@02oiVhk@03o`000?n=/>koSK3^00;oSK3^1?n4Znh00ol0003oP:S^oh2XkP02oh2XkP03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool04Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00000_nngNl00ol0003o
_=__okcKk`02okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000ok7<k_nac>h00_nac>h01Ol0003o
Z<3[ojS0jonX`>_o000000GoWkCW00?o0000oiJXhonFZ><00_nFZ><2o`0000CoVJ7J00?o0000oiJL
eonFW=L01OnFW=L00ol0003oUY_GoiJKe`04oiJKe`04o`000?nOW]?oWikCo`0000SoX:7E1Ol00008
ojRZf0Go00000_nX]>400ol0003o[;KQojbfh@0;ojbfh@03o`000?n_^N7o[kWQ00Wo[kWQ1?l0000>
okRhf@;o00002_o1_MH2o`0000Co`kcD00?o0000olS5f?o8aMP01oo7aMP00ol0003oa<GKolC5f`04
olC5f`06o`000?nma=oo_LCOokg4gol0003o_l_T1Onda^L00ol0003oYko[ojNoj`02ojNoj`03o`00
0?nI^>goVKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[kP03o`000?n0Z>koP:S^00;o
P:S^00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`004oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=_ooool2o`0000?o_]g_00Go0000okcKkonl
fnoo_=__o`000005okSEk`05o`000?nac>ko/Lc^ok7<k_l000001?nX`>/00ol0003oWkCWoindi`02
oindi`03o`000?nFZ>?oUZSS00?oUZSS0_n@X=l2o`0000;oVJ7J1onFW=L00ol0003oUY_GoiJKe`05
oiJKe`;o00002?nPXMD4o`0000?oXZSJ00Co0000ojRZf?nXZ]SoZ:[H1?l00007ojRdh@03o`000?n/
]^7o[;KQ00_o[;KQ00?o0000ojnihOn_^N403?n_^N400ol0003o/[cQok:lh@05o`0000Oo^;SI00?o
0000okbnfonl_]/00_l00009ol6meP;o000000?o`kcDo`000?o8aMP00oo8aMP00ol0003oalGHolO5
f004olO5f003o`000?o4aM_oa<GK00Coa<GK00?o0000okg4gol000000onobn@4okC6i`;o00000onW
_n/00ol0003oVKS]oiVhk@02oiVhk@03o`000?n=/>koSK3^00;oSK3^00Co0000ohB[k_n4Znko0000
1?n0Z>h00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo1?l000000ol@413ooooo
ooooo`02ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
=oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_na
c>ko/Lc^o`000004ojS0j`03o`000?nO]>OoWkCW00;oWkCW00?o0000oiJXhonFZ><00onFZ><00ol0
003oT:3Ooi2Pg`02oi2Pg`03o`000?nFW=OoUYcG00GoUYcG00?o0000oiJKeonFVmL01OnFVmL01?l0
003oUikIoiNNfOl00005oj2Qe@?o00001_nRZ=X3o`0000goZ;CQ00?o0000ojbfhOn/]^401?n/]^47
o`0000?o[kWQ1?l00006ojnih@03o`000?nb_>7o/[cQ00Ko/[cQ1?l00002okRhf@03o`000?nl_]_o
_;kK00?o_;kK0_l00009ol6meP03o`000?o8aMSob<GH00Cob<GH00?o0000olO5f?o7aMP01?o7aMP0
0ol0003oa<GKolC5f`03olC5f`;o00001?nobn@00ol0003o]<KWokC6i`02okC6i`;o00000onW_n/0
0ol0003oVKS]oiVhk@02oiVhk@05o`000?n=/>koSK3^ohf`k_l000000on4Znh00ol0003oP:S^oh2X
kP02oh2XkP03o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo000C
ooooo`05o`000?ooooooooooooooool000001Oooool2o`0003Oooooo00Go0000okkMkonngNoo_]g_
o`000003okcKk`03o`000?nheNoo^=G_00?o^=G_00Go0000ok7<k_nac>ko/Lc^o`000003ojS0j`03
o`000?nO]>OoWkCW00?oWkCW00?o0000oiJXhonFZ><00_nFZ><00ol0003oT:3Ooi2Pg`03oi2Pg`03
ohbKg?l0003oUYcG00CoUYcG00?o0000oiJKeonFVmL01OnFVmL00ol0003oUikIoiNNf@02oiNNf@03
o`000?nPXMGo000000;o00001onRZ=X2o`000003ojFch_l0003oZ;CQ00_oZ;CQ2Ol00006ojK2kP03
o`000?nU`^koYL;^00GoYL;^1_l0000=ok:lh@;o00002?nl_]/00ol0003o`KgFol6meP05ol6meP03
o`000?o5aM[o000000Kob<GH00?o0000olO5f?o7aMP01?o7aMP01ol0003oa<GKolC5foo4aM_o0000
olK>h?l000001Onobn@01?l0003o]<KWokC6ionda^L2o`0000?oYko[00?o0000oiVhkOnI^>d00_nI
^>d00ol0003oSK3^ohf`kP02ohf`kP04o`000?n4ZnkoQ:_^o`0000CoP:S^00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0fooooo`04o`000?nngNoo_]g_o`0000Co
_=__00?o0000okSEkonheNl00_nheNl01Ol0003o/Lc^ok7<k_nac>ko000000CoZ<3[00?o0000oind
ionO]>L00_nO]>L00ol0003oUZSSoiJXh`03oiJXh`03o`000?n@X=ooT:3O00;oT:3O00Co0000ohbK
g?n<Vmco00000onFW=L00ol0003oUY_GoiJKe`05oiJKe`03o`000?nGW]WoUikI00;oUikI0ol00008
oj:XfP;o00001?nU/n800ol0003oZ;CQojRdh@05ojRdh@Co00000_nW`^d00ol0003oY/;^ojK2kP0:
ojK2kP03o`000?nU`^koYL;^00[oYL;^00?o0000ojG1kOnU`Nd01?l00007ok:lh@04o`000?nd_n?o
];oSo`0000Oo_;kK0_l00004ol6meP05o`000?o5aM[oaLGJolG5f_l000001_o8aMP00ol0003oalGH
olO5f004olO5f003o`000?o4aM_o000000?oa/kP00?o0000oko;i?nobn@00_nobn@00ol0003o]<KW
okC6i`02okC6i`;o00000onW_n/01Ol0003oVKS]oiVhkOnI^>go000000CoSK3^00Go0000ohB[k_n4
ZnkoQ:_^o`000004oh2XkP03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool0=Oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000
ok7<k_nac>h00_nac>h01Ol0003oZ<3[ojS0jonX`>_o000000GoWkCW00?o0000oiJXhonFZ><00_nF
Z><00ol0003oT:3Ooi2Pg`02oi2Pg`03o`000?n<VmcoS9_L00;oS9_L00?o0000oiJLeol000001_nF
VmL2o`0000;oUikI1?l000000onKY]go0000oj:XfP06oj:XfP03o`000?nU/n;oYK?R00GoYK?R00?o
0000ojRdhOnX]>401?l00005ojO2k@?o000000?oY/;^o`000?l000002Ol00002ojG2kPCo00001OnU
`^h00ol0003oYL7]ojG1k@05ojG1k@Co00000_nb_>400ol0003o];oSokBoh`03okBoh`;o00001_nl
_]/2o`000003ol6me_l0003oaLGJ00CoaLGJ00?o0000olS5f?o8aMP01?o8aMP00ol0003oalGHolO5
f003olO5f0;o00001?o6c^000ol0003o_l_Toko;i003oko;i007o`000?nda^Oo]<KWokC6iol0003o
Yko[o`000002ojNoj`03o`000?nI^>goVKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[
kP03o`000?n0Z>koP:S^00;oP:S^00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`0dooooo`05o`000?nngNoo_]g_okkMkol000001?nlfnl00ol0003o^=G_okSEk`02
okSEk`05o`000?nac>ko/Lc^ok7<k_l000001?nX`>/00ol0003oWkCWoindi`02oindi`03o`000?nF
Z>?oUZSS00;oUZSS00?o0000oi2Pgon@X=l00on@X=l00ol0003oS9_LohbKg003ohbKg0;o00001OnF
VmL00ol0003oUikIo`000002o`0000;oUikI00Go0000oi^VgOnKY]goVjKMo`000004oj:XfP;o0000
2?nU/n83o`0000GoYl;]1?l00002oioDnP03o`000?nGco_oUlok00KoUlok1?l00006oi3:n`Ko0000
2onU`Nd2o`0000So];oS00?o0000okbnfonl_]/01Onl_]/00ol0003oaLGJolG5fP05olG5fP03o`00
0?o8aMSob<GH00Cob<GH00Oo0000olO5f?o7aMSoalGHo`000?o:cmko000000Goa/kP00?o0000oko;
i?nobn@00_nobn@00ol0003o]<KWokC6i`02okC6i`;o00000onW_n/01Ol0003oVKS]oiVhkOnI^>go
000000CoSK3^00Go0000ohB[k_n4ZnkoQ:_^o`000004oh2XkP03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`004oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_l0000eoooooaCo00000_nX`>/00ol0003oWkCWoindi`02oindi`03o`000?nF
Z>?oUZSS00?oUZSS00?o0000oi2Pgon@X=l00_n@X=l00ol0003oS9_LohbKg004ohbKg0;oRi[L00Co
0000oiJKeonFVmOoUY_G0ol00004oiNNf@03o`000?nKY]goVjKM00?oVjKM00Co0000oj:Xf_nRZ=[o
00001onU/n83o`0000;oYl?]00Co0000ojO2kOnW`^goYl;]0_l00005oioDnP?o00000_nGco/3o`00
00GoM]Cn00Co0000ofO7o_mWaokoIlOn1Ol00003oi3:n`03o`000?n<`o[oS<?j00Co00001_nU`Nd0
0ol0003oYL3]o`000007okBoh`;o00001?nl_]/00ol0003o_lGNoko5gP07olG5fP03o`000?o8aMSo
b<GH00Cob<GH00?o0000olO5f?l000000oo:cmh00ol0003oa/kPolK>h002olK>h003o`000?nobnCo
_l_T00;o_l_T00?o0000okC6ionda^L00_nda^L00ol0003oYko[o`000002ojNoj`03o`000?nI^>go
VKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[kP03o`000?n0Z>koP:S^00;oP:S^00?o
0000ooooooooool06oooool3o`0000Oooooo00?o0000ooooooooool01?ooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000;o`mOY00?o0000ol7FjOo1e^T00_o1e^T00ol0003o_=7ZokcAjP02
okcAjP05o`000?ncb^_o/l[[ok?:jol000000_nX`>/5o`0000;oWkCW00?o0000oiJXhonFZ><00_nF
Z><00ol0003oT:3Ooi2Pg`02oi2Pg`03o`000?n<VmcoS9_L00CoS9_L00Co0000oh^Jg?n;V]coRi[L
0ol00006oiNNf@03o`000?nKY]goVjKM00CoVjKM0ol00005ojFchP?o00001OnW`nd3o`0000GoWmCj
0ol000001?n;gogo0000o`000?l00002ogKDoPSo00002?mWaoh3o`0000OoS<?j0ol00002ojG1k@03
o`000?nU`>goYL3]00;oYL3]0_l00006okBoh`;o000000?o_;kKo`000?noaMh00onoaMh00ol0003o
aLGJolG5fP04olG5fP03o`000?o8aMSob<GH00?ob<GH0_l00004ol[?gP03o`000?o6c^3oa/kP00?o
a/kP00?o0000oko;i?nobn@00_nobn@00ol0003o]<KWokC6i`02okC6i`03o`000?nW_n_o000000;o
Yko[00Go0000oiVhkOnI^>goVKS]o`000004ohf`kP04o`000?n4ZnkoQ:_^o`0000CoP:S^00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Kooooo000Loooo
o`03o`000?oooooooooo03Cooooo00Go0000ol?GjOo3enWo`mOYo`000004ol7Fj@03o`000?nldN[o
_=7Z00;o_=7Z00Go0000ok?:joncb^_o/l[[o`000003ojS0j`CoW;GY0ol00004oiJXh`03o`000?n@
X=ooT:3O00;oT:3O00?o0000ohbKg?n<Vm`00on<Vm`00ol0003oRi[Loh^Jg002o`000003oh^Jg?l0
003o000000GoUikI00?o0000oi^VgOnKY]d01?nKY]d01Ol0003oXK;Toj6bi?nQ/^Co000000;oYK?R
0_l00006ojO3k@;o00000_nWe_P01?l0003oWmCjoioDn_nOe?X2o`000004oh_OoOl0003o0000o`00
00;oI]WZ0ol00003od?2i004o`000?lNZlKo0000o`0000;o@K[`00?o0000oa/00?l000001Ol00004
of6lo@Co00001?n<`oX2o`0000OoYL3]0_l00006okBoh`03o`000?noaMko_lGN00Co_lGN0_l00005
olG5fP07o`000?o8aMSob<GHolS5f?l0003obm3Mo`000005ol[?gP03o`000?o6c^3oa/kP00?oa/kP
00Go0000oko;i?nobnCo_l_To`000004okC6i`06o`000?nW_n_oYko[o`000?nW_n_o00000onI^>d0
0ol0003oSK3^ohf`kP02ohf`kP05o`000?n4ZnkoQ:_^ohB[k_l000001?n0Z>h00ol0003ooooooooo
o`0Looooo`?o00003?ooool001cooooo00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3
enWo000000Co`MKY00?o0000okcAj_nldNX00_nldNX01Ol0003o/l[[ok?:joncb^_o000000?oZ<3[
1OnL]NT2oi2Yi`;o000000?oUZSSo`000?n@X=l00on@X=l00ol0003oS9_LohbKg004ohbKg0?o0000
0on;V]`2ohjMgP05o`000?nGW]WoUikIoiNNfOl000001_nKY]d00ol0003oXK;Toj6bi002oj6bi0?o
00001OnW`nd3o`0000CoYmKh1_l00003ofKIjP?o000000?o;;Bdo`000?l000001?l000001?nFg?ko
0000o`000?l00003ogO1oP07o`000?m1XoKo@J?fo`000?l0LKWo0000o`24c@05o`0000?oHKcm0ol0
0003oh^mm`;o00001_nU`>d2o`000003okBohol0003o000000?o]L?U00?o0000oko5g_noaMh01?no
aMh00ol0003oaLGJolG5fP03olG5fP03o`000?o8aMSo000000?obm3M00?o0000ol[?g_o:cmh00_o:
cmh00ol0003oa/kPolK>h003olK>h003o`000?nobnCo_l_T00;o_l_T00Co0000okC6ionda^Oo]<KW
4ol00004oh2XkP03o`000?oooooooooo01Wooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo
000Looooo`03o`000?oooooooooo03Cooooo00Go0000ol?GjOo3enWo`mOYo`000004ol7Fj@05o`00
0?nldN[o_=7ZokcAj_l000001?ncb^/01Ol0003oZ<3[ojS0jonX`>_o000000CoW;GY1?n@ZNL2o`00
00CoT:3O00Co0000ohbKg?n<VmcoS9_L0ol00005oh^Jg007o`000?n>WMkoSYgNohjMg_l0003oUikI
o`000005oi^Vg@;o00001?nQ/^@01?l0003oZ<?]ojS3kOnX`nd2o`0000;oYl?]00?o0000ojOFn?nW
e_P00_nWe_P3o`000004oj3Wo?l0003o0000ohk/l0So00000onbl_D00ol0003o/n7gok?Qm`07o`00
00;oM[Sj0_l000001_m1XoKo0000o`000?l0003o07GDo`1a^@Ko00000omR/_/00ol0003oRkggoh^m
m`02oh^mm`?o00001OnU`>d00ol0003o]L?UokG3i@04okG3i@03o`000?noaMko_lGN00Co_lGN00?o
0000olG5f_o5aMX00_o5aMX2o`0000Cobm3M00?o0000ol[?g_o:cmh00oo:cmh00ol0003oa/kPolK>
h003olK>h006o`000?nobnCo_l_Toko;i?l0003o]<KW0_l000001_ncbN[o0000ojNojonW_n_o0000
ojNoj`CoVkGZ1On@[NT3ohVVj0Oo00005oooool3o`0000Gooooo00?o0000ooooooooool02_ooool0
01cooooo0_l0000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T01Ol0003o_=7ZokcAj_nl
dN[o000000Co/l[[00Go0000ojS0jonX`>_oZ<3[o`000004oibej@04o`000?n@ZNOoT:WWoi2Yi`;o
QZ3U0_l000000on@X=oo0000ohbKg003o`000003ohbKg?l0003oRi[L00CoRi[L00?o0000ohjMg_n>
WMh00on>WMh2o`0000CoVjKM00?o0000oj6bi?nQ/^@00onQ/^@00ol0003oZ<?]ojS3k@03ojS3k@Co
00000_nWe_P2o`0000;oX>Ol1Ol000000omhi=_o0000o`00000Eo`000004ogV`m_l0003o0000odnL
m0;o:HS/00Go0000oa=ji?l0MMCo0000o`B2g`03oc2Kl@04o`000?mR/__oH[;kof:bn`?o00000on;
_OL2o`000003ojG0kOl0003oY;o]00;oY;o]1_ne`nD00ol0003o_lGNoko5gP04oko5gP06o`000?o5
aM[o0000o`000?o8cmoo00001Oo;d=d00ol0003ob/oNol[?gP02ol[?gP03o`000?o6c^3oa/kP00?o
a/kP00?o0000oko;i?nobn@00ol00003ok?9jP05o`000?nW_n_oYko[ojNojol000001?nK]NX00ol0
003oT:gYoi2]j@02oi2]j@CoRJKX1On7Y>L00ol0003oooooooooo`0Booooo`?o00002?ooool00ol0
003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`05o`000?o3enWo`mOYol?G
jOl000001?o1e^T01Ol0003o_=7ZokcAj_nldN[o000000Co/l[[00Go0000ojS0jonX`>_oZ<3[o`00
0003oibej@03o`000?n@ZNOoT:WW00;oT:WW1?n6X>D3o`0000CoS9_L00?o0000oh^Jg?n;V]`00on;
V]`00ol0003oSYgNohjMgP03ohjMgP06o`000?nDY^;o0000o`000?nKY]go00001OnQ/^@00ol0003o
Z<?]ojS3k@03ojS3k@04o`000?n_e_Co[mKdojoFm0Co00000_nPio`:o`000003olWgjol0003oaNk_
013o000000CoQZGYogjZkol0003o00000_mPV>h00ol0003o:HS/o`000002oa=ji004o`000?l@N>?o
0000o`B2g`;o<9_a00?o0000of:bnomR/_/00_mR/_/2o`0000?oRkgg00?o0000ojBokOnT_nd00onT
_nd00ol0003o]L?UokG3i@03okG3i@03o`000?noaMko_lGN00?o_lGN0_l00004olS?g`03o`000?o;
d=gobm3M00?obm3M00?o0000ol[?g_o:cmh00_o:cmh00ol0003oa/kPolK>h002olK>h0?o00000_nn
dNP01Ol0003o/lWZok?9j_ncbN[o000000CoYko[00Go0000oi^ej_nK]N[oVkGZo`000004oi2]j@04
o`000?n9Y^SoRJKXohVVj0GoQjCW00?o0000ooooooooool03_ooool4o`0000_ooooo00?o0000oooo
ooooool02_ooool001_ooooo00?o0000ooooooooool0=Oooool01Ol0003o`mOYol?GjOo3enWo0000
00Co`MKY00Go0000okcAj_nldN[o_=7Zo`000004ok?:j`05o`000?nX`>_oZ<3[ojS0jol000000onL
]NT00ol0003oT:WWoi2Yi`02oi2Yi`Co00000_n0Vn<3o`000003ohbKg?l0003oRi[L00CoRi[L00?o
0000ohjMg_n>WMh00on>WMh00ol0003oU:KRoiBVhP02oiBVhP;o00001?nQ/^@00ol0003oZ<?]ojS3
k@03ojS3k@05o`000?n_e_Co[mKdojoFm?l000000oncjOL3o`0000;oZ_SX0_l000001?nUmn7o0000
o`000?o;nnHEo`0000;oSJ?S0_l00002og2EiP;o000000?oAhOYo`000?l000000_l000001Ol@N>?o
0000ob:3jOl0003o<9_a00;o00000_mR/_/01?l0003oH[;ko`000?l00003oh^hm0GoY;o]00?o0000
okG3iOne`nD00one`nD01ol0003o_lGNoko5g_noaMko0000ol7<hol000001?o8cml00ol0003obm3M
ol_@g@03ol_@g@03o`000?o:cmkob/oN00;ob/oN00?o0000olK>h?l000000_l000000oo6enKo0000
okkAj002okkAj005o`000?ncbN[o/lWZok?9j_l000001?nW_n/01Ol0003oVkGZoi^ej_nK]N[o0000
00CoT:gY00Go0000ohVVj?n9Y^SoRJKXo`000004ohNTi`03o`000?oooooooooo00_ooooo0ol0000@
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Gooooo00Go0000ol?G
jOo3enWo`mOYo`000003ol7Fj@03o`000?nldN[o_=7Z00;o_=7Z00Go0000ok?:joncb^_o/l[[o`00
0003ojS0j`03o`000?nL]NWoW;GY00;oW;GY00?o0000oi2Yion@ZNL00ol00003ohJPi@GoP9_S0_l0
0004oh^Jg003o`000?n>WMkoSYgN00?oSYgN00?o0000oiBVh_nDY^800onDY^801_l0003oWK;Wo`00
0?l0003oXK;To`0000CoZ<?]0_l00002ojoFm0;o00000oncjOL00ol0003o/OCbo`000002oj[hj0Co
00000_o;nnH2o`000005omK/hol0003o0000o`000?o@fMl01?l00002ol72fPOo000000?oW:?IoiFR
g_l000000_n=Xn<2ognCg@04o`000?m`UNKoH8SRof28hP;o000000?o>7kVo`000?l000000_l00002
ob:3j@04o`000?m3U_;o0000o`0000?oJJWf00?o0000oh^hm?n;^?@00_n;^?@00ol0003oY;o]ojBo
k@02ojBok@03o`000?ne`nGo]L?U00?o]L?U00?o0000oko5g_l000000oo1c><00ol0003ob<oOolS?
g`02olS?g`03o`000?o;d=gobm3M00?obm3M00Co0000ol[?g_o:cmkob/oN0_l00004olKGiP05o`00
0?nndNSo_]7XokkAj?l000000oncbNX00ol0003oYko[ojNoj`02ojNoj`;o00000_nK]NX00ol0003o
T:gYoi2]j@02oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L00ol0003oooooooooo`08oooo
o`?o00004oooool00ol0003oooooooooo`09ooooo`006oooool00ol0003oooooooooo`0eooooo`04
o`000?o3enWo`mOYo`0000Co`MKY00?o0000okcAj_nldNX00_nldNX01Ol0003o/l[[ok?:joncb^_o
000000?oZ<3[00?o0000oibejOnL]NT00_nL]NT3o`0000;oT:WW00Go0000ohJPiOn6X>GoQZ3Uo`00
0004oh2Kh`;oOi[S00Go0000oh^Jg?n;V]coRi[Lo`000004ohjMgP03o`000?nDY^;oU:KR00?oU:KR
00?o0000oifbionM/^L00_nM/^L2o`0000?oZ<?]00Go0000ojoFm?n_e_Co[mKdo`000003ok?Ym`;o
00000_nam?84o`0000;obo_V0ol00002omK/h`;o000000Cod=WOo`000?l0003oc/gH0_l00002ol72
fP03o`000?nn^mOo000000Co000000?oXjCFo`000?nLXmT00_nEX]h2o`0000?oOi?M00So0000of28
h_mPR>;oH8SRo`000?lhO^Ko0000ocMmi@;o00000_lRPnT00ol0003o@iKbod>FlP04ofVYmP03o`00
0?n;^?CoRkSd00;oRkSd00?o0000ojBokOnT_nd00_nT_nd00ol0003o]L?UokG3i@02okG3i@;o0000
1?o1c><00ol0003ob<oOolS?g`03olS?g`03o`000?o;d=gobm3M00;obm3M00Ko0000ol[?g_l0003o
0000ol_JiOl00004olKGiP05o`000?nndNSo_]7XokkAj?l000000oncbNX00ol0003oYko[ojNoj`02
ojNoj`05o`000?nK]N[o0000oi^ej_l000001?n@[NT01Ol0003oRJKXohVVj?n9Y^So000000CoQjCW
00?o0000ooooooooool01Oooool3o`0001Kooooo00?o0000ooooooooool02Oooool001_ooooo0_l0
000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T00ol0003o_=7ZokcAjP02okcAjP05o`00
0?ncb^_o/l[[ok?:jol000000onX`>/00ol0003oW;GYo`000003o`0000?oT:WW00?o0000ohJPiOn6
X>D00_n6X>D00ol0003oP9_Soh2Kh`02oh2Kh`?oOi[S00?o0000oh^Jg?l000001On>WMh00ol0003o
U:KRoiBVhP02oiBVhP03o`000?nM/^OoWK;W00?oWK;W00Go0000ojW3k?l0003oZ<?]o`000004ojoF
m0?o/nWg1Ol00002ol[hj@03o`000?o;nnKobo_V00;o000000GofNoQo`000?l0003o0000omSMf`02
o`0000?oc/gH0_l000001Oo1`][o0000okjkeol0003o^[GE00?o000000?oZJODoj>Te_nSY=H00_nL
XmT01?l0003oRiCGoh^Deol00002ognCg@;oM8WI0_mPR>82oeN1g`;o00000_lgOND4o`0000;o@iKb
00Go0000ofVYm_mYZOKoJJWfo`000004oh^hm003o`000?nT_ngoY;o]00;oY;o]00Ko0000okG3iOl0
003o0000okK7iol00005ol7<h`03o`000?o8cmoob<oO00;ob<oO00?o0000ol_@gOo;d=d00_o;d=d2
o`0000?obm[U00?o0000olKGi_o6enH00_o6enH01Ol0003o_]7XokkAj?nndNSo000000Co/lWZ00Go
0000ojNojonW_n_oYko[o`000002oi^ejP;o00001?n@[NT01Ol0003oRJKXohVVj?n9Y^So000000Co
QjCW00?o0000ooooooooool00_ooool3o`0001Wooooo00?o0000ooooooooool02Oooool001_ooooo
00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3enWo000000Co`MKY00Go0000okcAj_nl
dN[o_=7Zo`000004ok?:j`03o`000?nX`>_oZ<3[00?o00000onL]NT01Ol0003oT:WWoi2Yion@ZNOo
000000CoQZ3U00?o0000oh2Khon0Vn<00_n0Vn<4ognJh`;o00001?n>WMh00ol0003oU:KRoiBVhP03
oiBVhP03o`000?nM/^OoWK;W00;oWK;W00Co0000ojW3k?nY`ncoZL?/2_l00002olOakP05o`000?o:
n>Wob_SYo`000?o;nnH00_l00002omW_h@;o00000_oHgM/2o`0000?oc/gH00ko0000ol[2d_o:`];o
0000okjkeol0003o^[GEo`000?nd[m?o0000ojn[donYYmCo0000oj>TeP;o00000_nFU]43oh^De`;o
00000_mdRMT00omPR>;o0000oeN1g`02oeN1g`?o00000_m2Q>P5o`0000?oJJWf00?o0000oh^hm?n;
^?@00_n;^?@00ol0003oY;o]ojBok@03o`0000Co]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003o
b<oOolS?g`03olS?g`06o`000?o;d=gobm3Mo`000?o<fnCo00000oo;f^D00ol0003oa]OVolKGiP02
olKGiP05o`000?nndNSo_]7XokkAj?l000001?ncbNX01Ol0003oYko[ojNojonW_n_o000000;oVkGZ
0_l00004oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L5o`0001cooooo00?o0000oooooooo
ool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3enWo000000Co
`MKY00Go0000okcAj_nldN[o_=7Zo`000004ok?:j`?o000000?oZ<3[o`000?nL]NT00_nL]NT00ol0
003oT:WWoi2Yi`02oi2Yi`05o`000?n6X>GoQZ3UohJPiOl000001?n0Vn<00ol0003oOi[SognJh`02
ognJh`;oPigT0_l000000on>WMko0000oiBVhP04oiBVhP03o`000?nM/^OoWK;W00;oWK;W00?o0000
ojW3k?nY`n`00_nY`n`01Ol0003o]MC`okGDl?nee?3o000000?o_nGa00Co0000olOak_o7lNko0000
0oo:n>T2o`000008om[_hOl0003o0000o`000?oKg]So0000omSMfol00002omC>d`03o`000?o>cMSo
000000?ob/;B2ol000000onOVLko0000oiJFd@02oiJFd@;oRiCG0_n5Rm800ol0003oM8WIogB9f@02
o`0000;oEh7O0_mGP=l2o`0000;o@XCX00?o0000oeNBkOmGT^d03?l00002ojBok003o`000?nfanOo
]/OW00;o]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003ob<oOolS?g`03olS?g`03o`000?o;d=go
000000;oc=_T00Go0000ol_JiOo;f^Gobm[Uo`000004olKGiP05o`000?nndNSo_]7XokkAj?l00000
1?ncbNX01Ol0003oYko[ojNojonW_n_o000000?oVkGZ00?o0000oi2]jOn@[NT00_n@[NT01Ol0003o
RJKXohVVj?n9Y^So000000CoQjCW00?o0000ooooooooool07_ooool00ol0003oooooooooo`09oooo
o`006_ooool00ol0003oooooooooo`0eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T01_l0
003o_=7ZokcAj_nldN[o0000ok?:j`Co00000onX`>/01Ol0003oW;GYoibejOnL]NWo000000CoT:WW
00Go0000ohJPiOn6X>GoQZ3Uo`000004oh2Kh`03o`000?moV^?oOi[S00;oOi[S1?n3WN@2o`0000Go
U:KR00Go0000oifbionM/^OoWK;Wo`000004ojW3k005o`000?nee?3o]MC`okGDl?l000000onoiO40
1?l0003oao7^olOak_l00002ol[hj@;o00000_oJkn42o`0000?ofmkH0_l00004omC>d`07o`000?o:
`];ob/;Bol[2d_l0003oaKS>o`000002okj`c007o`000?ngZL[o0000ok2Sb_l0003oZ9g;o`000002
oinIcP05o`000?nFU]7oUYKAoiJFdOl000000on5Rm82ogB9f@;oKh?G00?o0000oeN1gol000000omG
P=l01?l0003o@XCXod:4j?l00002oeNBk@05o`000?mbXo3oLZ?`og:Sl?l000001?n=/o000ol0003o
Y;o/ojBok002ojBok003o`000?nfanOo]/OW00;o]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003o
b<oOolS?g`02olS?g`;o00000oo<fn@01Ol0003obm[Uol_JiOo;f^Go000000Coa]OV00Go0000okkA
j?nndNSo_]7Xo`000004ok?9jP05o`000?nW_n_oYko[ojNojol000000onK]NX2o`0000?oT:gY00Go
0000ohVVj?n9Y^SoRJKXo`000004ohNTi`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2Oooool001[ooooo0ol0000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T00ol0003o_=7Z
o`00000Bo`000003oi2Yiol0003oQZ3U00;oQZ3U00?o0000oh2Khon0Vn<00_n0Vn<01Ol0003oOi[S
ognJhomoV^?o000000CoPigT0_n<Y^L3o`000003oiBVh_l0003oWK;W00?oWK;W00Go0000ojW3k?nY
`ncoZL?/o`000004okGDl004o`000?noiO7o_nGao`0000?oao7^0ol000000ooGkN?o0000om[_h@02
o`0000CofmkH00?o0000omC>dooDc]<00_oDc]<01ol0003ocl7=o`000?o:`];o0000olFhc_l00000
0_nn/<`01_l0003o]jW:okNYb_l0003o/:?:o`0000;oZ9g;00?o0000oinIc_nOVLh00_nFU]400ol0
003oTXk<o`000003ohF;dP03ogB9fOl0003oKh?G00;oKh?G00?oEh7Oo`000?mGP=l00_mGP=l2o`00
0005od:4j?l0003oEi;]oeNBkOl000000ombXo000ol0003oSK?`ohfcl002ohfcl005o`000?nT_nco
Y;o/ojBok?l000001?nfanL00ol0003o`LcSol7<h`02ol7<h`03o`000?o8cmoo000000;o000000?o
bMWUo`000?o<fn@00_o<fn@00ol0003obm[Uol_Ji@02ol_Ji@05o`000?o6enKoa]OVolKGi_l00000
0onndNP00ol0003o/lWZok?9jP02ok?9jP05o`000?nW_n_oYko[ojNojol000000onK]NX00ol0003o
T:gYo`000002oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000ol?GjOo3
enWo`mOYo`000002ol7Fj@Go000000?o_LcUokC7j?ndanP00ondanP4ojS0j`CoVKO/1?n9[>`3o`00
00;oQZ3U00?o0000oh2Khon0Vn<00_n0Vn<01Ol0003oOi[SognJhomoV^?o000000CoPigT1On<Y^L3
o`0000;oWK;W00?o0000ojW3k?nY`n`00_nY`n`01Ol0003o]MC`okGDl?nee?3o000000?o_nGa1?l0
0004omO]h`;o000000?og=kHo`000?oKg]P00_oKg]P2o`0000?oe<kC00Co0000olo1cOo?`Lgocl7=
0_l000001Oo5^<ko0000okj`c?nn/<co000000;o]jW:00Ko0000ok2Sb_n`Xl[o0000ojRMbol00002
oinIcP;o00000onBS/`01?l0003oQH_BohF;d_n5Rm82o`0000?oKh?G0_l00002oeN0g`;oGHGQ0_l0
0003oeNBk@05o`000?mbXo3oLZ?`og:Sl?l000000on=/o000ol0003oY;o/ojBok002ojBok003o`00
0?nfanOo]/OW00;o]/OW00Co0000ol7<hoo1c>?o`LcS0_l00004olWIi@05o`000?o<fnCoc=_TolcK
i?l000001?o;f^D01Ol0003oa]OVolKGi_o6enKo000000?o_]7X00?o0000ok?9j_ncbNX00_ncbNX0
1Ol0003oYko[ojNojonW_n_o000000?oVkGZ00?o0000oi2]jOl000000_n@[NT01Ol0003oRJKXohVV
j?n9Y^So000000CoQjCW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`0000Co
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03Gooooo00?o0000ol?GjOl000001_l00005okg<i@Co]<OX00?o0000ojS0jonX
`>/00_nX`>/4oiVgk0CoRJc/0_mkX^`3o`0000CoP9_S00Go0000ognJhomoV^?oOi[So`000004oh>M
i003o`000?n<Y^OoS:KW00;oS:KW0onI/nX4o`0000;oZL?/00?o0000okGDl?nee?000_nee?05o`00
00;odNOV00Co0000omO]hooGkN?oengS0_l00002omcNf004o`000?oKg]SofmkHo`0000;of<o@00?o
0000omC>dol000000oo?`Ld00ol0003ob;K9olRfb@03o`000005okj`c?l0003o]jW:okNYb_l00000
0_n`XlX2ojRMb`?o000000?oWI?8o`000?nBS/`00onBS/`2ohF;dP03o`000?n2Q/ooPXK?00?oKh?G
0_m_PmH2oeN0g`04o`000?mMQN7oGHGQoef5h@Co00000ombXo000ol0003oSK?`ohfcl002ohfcl003
o`000?nT_ncoY;o/00;oY;o/00Ko0000okK7ionfanOo]/OWo`000?o1c><2o`000003ol7Cj?l0003o
bMWU00?obMWU00?o0000olcKi?o<fn@00_o<fn@01Ol0003obm[Uol_JiOo;f^Go000000?oa]OV00Go
0000okkAj?nndNSo_]7Xo`000002ok?9jPGo000000?oYko[o`000?nK]NX00_nK]NX01_l0003oT:gY
oi2]jOl0003oT:gYo`0000?oRJKX00?o0000ohNTion7Y>L00_n7Y>L00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l000001?o5d>?o0000o`000?l00004
ol??h`Co_LcU00?o0000okC7j?ndanP00_ndanP01Ol0003oZ<3[ojS0jonX`>_o000000?oVKO/00Go
0000ohV/k?n9[>coRJc/o`000003og^Rk0;o00000_n0Vn<00ol0003oOi[SognJh`02ognJh`03o`00
0?n3WNCoPigT00;oPigT00?o0000ohbVion<Y^L00_n<Y^L4oiVcjP03o`000?nY`^coZL;/00So0000
0_o6g^X01Ol0003odNOVom7Wi_oAinKo000000;oengS0_l00004omcNf0;o00001?oHcm001Ol0003o
cl7=olo1cOo?`Lgo000000?ob;K900?o0000ol6]a_o1[LH02Ol000000onWV<Ko0000oifCb002oifC
b004o`000?nBS/coTXk<oi:>c0;o00001?n2Q/l00om_PmOo0000ofn3eP02ofn3eP03oeN0gol0003o
GHGQ00;oGHGQ0om[T>D6o`0000?oSK?`00?o0000ojBok?nT_n`00_nT_n`00ol0003o]/OWokK7i`03
o`0000?o`M?X00?o0000olWIiOo9fND00_o9fND00ol0003oc=_TolcKi002olcKi005o`000?o;f^Go
bm[Uol_JiOl000000oo6enH00ol0003o_]7Xo`000004o`0000;o//c]00?o0000ojNojonW_n/02ol0
0003ohVVj003o`000?n7Y>OoQjCW00;oQjCW00?o0000ooooooooool07oooool00ol0003ooooooooo
o`08ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=Oooool3o`0000;oaM3S00?o0000ol??hoo3cn<00_o3cn<01Ol0003o_LcUokg<iOnm
c>Go000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk003o`000?n9[>coRJc/00;oRJc/
0omkX^`2og>Lj`?o00001?moV^<01Ol0003oPigToh>Mi?n3WNCo000000CoS:KW00?o0000oiVcj_nI
/nX00_nI/nX01Ol0003oZL;/ojW2k?nY`^co000000Co^M7/00Go0000olKNj_o6g^[oa]kZo`000002
om7WiPCo000000?ofMgJo`000?oLg]P00_oLg]P2o`0000Cof<o@00Go0000om71bol0003ocl7=o`00
0003olRfb@05o`000?o1[LKo`Jg6ol6]a_l000000oniYLD01?l0003o/9k5ok2NaOl00003ojNHaP09
o`000?nMTlSoWI?8oifCb?l0003oTXk<o`000?n@RlWo000000GoPXK?00?o0000ofn3e_m_PmH00_m_
PmH2o`0000;oGHGQ00Co0000of^@iOm[T>GoJi3U1?mmWnP5o`0000?oY;o/1?l00002okG;jP05o`00
0?o1dnSo`M?Xol7Cj?l000001?o9fND00ol0003oc=_TolcKi002olcKi006o`000?o;f^Gobm[Uol_J
iOl0003oa]OV1?l00002okcGkP05o`000?nbc>go//c]ok;<kOl000001?nW_n/01Ol0003oWK?Woifc
ionM/nOo000000?oUJ[T1?l000000on9Y^So0000ohNTi`03ohNTi`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8boooo
o`03ooooo`?o0000<oooool4o`0000CoaM3S00?o0000ol??hoo3cn<00_o3cn<00ol0003o_LcUokg<
i@02okg<i@05o`000?ndanSo]<OXokC7j?l000001?nX`>/01Ol0003oVKO/oiVgk?nI]nco000000?o
RJc/00Co0000og^Rk?mkX^co00000omcW>/3o`000003ognJhol0003oPigT00?oPigT00?o0000ohbV
ion<Y^L00_n<Y^L01Ol0003oVK?ZoiVcj_nI/n[o000000CoZL;/00Go0000okWAk?nidNco^M7/o`00
0004olKNjP04o`000?oAinKo0000o`0000CofMgJ00Ko0000omcNf?oLg]So0000omS?d?l00003omS?
d004o`000?oA`L_odL7;om71b`?o00000_o8]/T01Ol0003o`Jg6ol6]a_o1[LKo000000?o^JG500Co
0000ok2NaOn`W/Go00000onWV<H01?l0003oWI?8oifCb?nMTlP2o`0000?oT8_900Oo0000oh:6con2
Q/ooPXK?o`000?n1Q/oo000000?oKh?F0_mcQmP2o`000005oef5hOl0003oJi3Uof^@iOl000001?mm
WnP3oi6_j`Co00000_nU_^`01Ol0003o]L_ZokG;j_nebn[o000000?o`M?X00?o0000olWIiOo9fND0
0_o9fND00ol0003oc=_TolcKi002olcKi003o`000?o;f^Gobm[U00?o00000_o3gnd01?l0003o_=O^
okcGk_l00004ok;<k@05o`000?nW_n_oYko[ojNojol000000onM/nL00ol0003oUJ[ToiFZi003oiFZ
i003o`000?n@Y>;oT:CR00?o00000on7Y>L00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00Sooooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo037ooooo0_l00004ooooo`05o`000?o5d>?oaM3SolG@hol000001Oo3cn<0
1Ol0003o_LcUokg<iOnmc>Go000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk005o`00
0?n9[>coRJc/ohV/k?l000000omkX^`3og>Lj`?oLI_Z0ol00003oh>Mi003o`000?n<Y^OoS:KW00;o
S:KW00Go0000oiVcj_nI/n[oVK?Zo`000004ojW2k005o`000?nidNco^M7/okWAk?l000000oo6g^X0
1Ol0003odNOVo`000?oCf]ko000000GofMgJ0_l00003omS?d003o`000?oHcm3o000000CodL7;00?o
0000olVea_o9]LH00ol00002ol6]aP05o`000?niYLGo^JG5okVUaOl000001?n`W/D01Ol0003oYiS6
ojNHa_l0003oWI?800;o000000?oW8o5o`000?n@RlT00on@RlT00ol0003oPXK?o`000003oh66c`04
o`000?m_PmKoKh?Fo`0000CoLhOH0_l000000om[T>Go0000ogfOj003ogfOj005o`000?nA[n_oTJo[
oi6_jol000001?nU_^`01Ol0003o]L_ZokG;j_nebn[o000000Co`M?X00Go0000olWIiOo9fNGobMWU
o`000004olcKi0?o000000Gob>G/o`000?o3gngo`mo]o`000003okcGkP05o`000?nbc>go//c]ok;<
kOl000001?nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00?o0000oi2Th_l000000_n@Y>80
0ol0003oSZ;Qo`000003o`00027ooooo00?o0000ooooooooool02?ooool000?ooooo00?o410@oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo0ol00006oooo
o`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??hoo3cn<00_o3cn<01Ol0003o_LcUokg<iOnmc>Go
000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk005o`000?n9[>coRJc/ohV/k?l00000
0omkX^`01?l0003oLic[og>Ljol00003og6KjP;oMio[1?l00004ohbVi`05o`000?nI/n[oVK?ZoiVc
j_l000000onY`^`00ol0003o^M7/okWAk002okWAk004o`000?o6g^[oa]kZolKNjP;o00000_oCf]h0
0ol0003ofMgJomWMfP02omWMfP;o00001OoHcm000ol0003odL7;om71b`02om71b`03o`000?o9]LKo
bKG600;obKG600?o0000ol:[`ol000000_l00003okVUa@03o`000?n`W/Go/9k500;o/9k500?o0000
ojNHa_l000000_l00004oib?a@03o`000?n@RlWoT8_900;oT8_900?o0000oh66con1Q/l00on1Q/l0
0om_PmKo0000og>7f004og>7f0;oNi3L0_m[T>D01Ol0003oOIoXogfOj?mmWnSo000000?oTJo[00?o
0000ojFnk?nU_^`00_nU_^`01Ol0003o]L_ZokG;j_nebn[o000000Co`M?X00Go0000olWIiOo9fNGo
bMWUo`000002olcKi0?o00000_o8iN`01Ol0003o`mo]ol?OkOo3gngo000000?o_=O^00Go0000ok;<
kOnbc>go//c]o`000003ojNoj`05o`000?nM/nOoWK?Woifciol000001OnEZ^@00ol0003oT:CRoi2T
hP02o`0000GoSZ;Q00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`0000CoV9RH
oooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02_ooooo0ol0
0009ooooo`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??hoo3cn<00_o3cn<00ol0003o_LcUokg<
i@02okg<i@05o`000?ndanSo]<OXokC7j?l000001?nX`>/01Ol0003oVKO/oiVgk?nI]nco000000?o
RJc/00Co0000og^Rk?mkX^co00000omcW>/01?l0003oLI_Zog6Kj_l00004ogNOj`?o000000?oS:KW
o`000?nI/nX00onI/nX01Ol0003oZL;/ojW2k?nY`^co000000?o^M7/00?o0000olKNj_o6g^X00ol0
0004om?JgP06o`000?oIgM[o0000o`000?oFc];o00001?oHcm001_l0003odL7:om71b_l0003odL7;
o`0000CobKG600?o0000ol:[`oo2Zl<00_o2Zl<;o`0000;oYiG300?o0000oib?aOnLSlD00onLSlD0
1_l0003oT8_9oi2;bOl0003oT8[9o`0000GoPHK?0_l00003og>7f006o`000?mkT=coNi3Log^@g?m[
T>Go00000ommWnP01Ol0003oTJo[oi6_jonA[n_o000000CoYKk/00?o0000okG;j_nebnX00_nebnX0
1Ol0003o`M?Xol7Cj?o1dnSo000000;obMWU1?l00002olSUk004o`000?o8iNcob>G/o`0000?o`mo]
00Co0000okcGk_nlenko00000onbc>d00ol0003oYko[ojNoj`02ojNoj`05o`000?nM/nOoWK?Woifc
iol000001?nEZ^@01?l0003oT:CRoi2Th_n@Y>82o`0000GoSZ;Q00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`07ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000
ooooooooool0:?ooool3o`0000gooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??h`02
ol??h`05o`000?nmc>Go_LcUokg<iOl000001?ndanP01Ol0003oZ<3[ojS0jonX`>_o000000?oVKO/
00Go0000ohV/k?n9[>coRJc/o`000003og^Rk004o`000?mcW>_oLic[o`0000?oLI_Z00Co0000ogNO
jomgWn_oMio[0on5ZN`4o`000003oiVcj_l0003oZL;/00?oZL;/00?o0000okWAk?l000001?l00002
olWEh`03o`000?oCf]kodm[N00;odm[N0_l00004omK>dP04o`000?oHcm3of<o@o`0000CodL7:0_l0
0004olVeaP03o`000?o2Zl?o`Z_300;o`Z_300Go0000okVS`_niXl;o^J?2o`000004ok2K`P03o`00
0?nWUL?oYiG300;oYiG300?o0000oib?aOnLSlD00_nLSlD00ol0003oT8_9o`000003oi2:b@05o`00
0?n1Q/ooPHK?oh66col000000_n4RM401?l0003oLhOHog>7f?l00004og^@g0?o000000?oOIoXo`00
0?nA[n/00onA[n/01Ol0003oYKk/ojFnk?nU_^co000000Co]L_Z00Co0000ol7Cj?o1dnSo`M?X0ol0
00000oo5h^go0000olSUk002olSUk005o`000?o8iNcob>G/olSUk?l000000_o3gnd01Ol0003o_=O^
okcGk_nlenko000000?o//c]00Go0000ojNojonW_n_oYko[o`000004oifci`03o`000?nEZ^CoUJ[T
00;oUJ[T00Co0000oi2Th_n@Y>;oT:CR0_l00004ohjRh@03o`000?oooooooooo027ooooo00?o0000
ooooooooool01oooool001Wooooo0_l0000Vooooo`?o00004?ooool00ol0003oaM3SolG@h`02olG@
h`03o`000?o3cn?o`loS00;o`loS00Go0000okg<iOnmc>Go_LcUo`000004okC7j005o`000?nX`>_o
Z<3[ojS0jol000000onI]n`01Ol0003oRJc/ohV/k?n9[>co000000?oNj;/00Co0000og>LjomcW>_o
00000omaVnX01Ol0003oMio[ogNOjomgWn_o000000?oQJW/0onF]Nd8o`0000;o^lgX00?o0000olWE
hoo9eN<00_o9eN<01?l0003odm[Nom?Jg_oCf]h2o`0000Goe/kB00?o0000omS?d?l000001OoA`LX0
0ol0003ob[G6o`000002o`000003olVea_l0003o`Z_300?o`Z_300Go0000okVS`_niXl;o^J?2o`00
0004ok2K`P03o`000?nWUL?oYiG300;oYiG300?o0000oib?aOnLSlD00_nLSlD2o`0000GoT8[900?o
0000oh66col000001?n4RM42og>7f003o`000?mkT=coNi3L00;oNi3L0on7WN85o`000003oi6_jol0
003oYKk/00;oYKk/00?o0000okG;j_nebnX00_nebnX00ol0003o`M?Xo`000002o`0000;oaN;]00?o
0000olSUk?o8iN`00_o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko_=O^o`0000Co
//c]00Go0000ojNojonW_n_oYko[o`000003oifci`03o`000?nEZ^CoUJ[T00;oUJ[T00?o0000oi2T
h_n@Y>800_n@Y>800ol0003oSZ;Qo`000003ohjRh@03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01oooool001Sooooo00?o0000ooooooooool08oooool3o`0001?ooooo00?o0000olG@hoo5
d><00_o5d><00ol0003o`loSol??h`02ol??h`03o`000?nmc>Go_LcU00;o_LcU00Go0000okC7j?nd
anSo]<OXo`000004ojS0j`05o`000?nI]ncoVKO/oiVgk?l000000_n9[>`01Ol0003oNj;/og^Rk?mk
X^co000000?oLic[00Co0000og6Kj_maVn[o00001?mgWn/01?l0003oQJW/ohFYk?l00003oiJek@03
o`000?nY`^_oZL;[00;oZL;[00?o0000ok_=j?nkcNP00_nkcNP00ol0003obMGSolWEh`02olWEh`05
o`000?oCf]ko0000om3=eol000001OoFc]82o`0000GodL7:00?o0000olZea_o:]LH00oo:]LH2o`00
00?o`Z_300?o0000okVS`_niXl800_niXl800ol0003o/9_2ok2K`P03ok2K`P06o`000?nWUL?oYiG3
ojNE`ol0003oW8o50ol000000onLSlGo0000oi2:b@04oi2:b@;o00001_n4RM42o`0000?oNi3L00?o
0000ohNMh_n7WN800_n7WN801?l0003oUZgWoiJ]ionF[NL<o`0000;o_][^00Co0000olGRkOo5h^go
00001?o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko_=O^o`0000?o//c]00?o0000
ojNojonW_n/00_nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00Go0000oi2Th_n@Y>;oT:CR
o`000003ohjRh@03o`000?n>X^7o000002Cooooo00?o0000ooooooooool01oooool001Sooooo00?o
0000ooooooooool08?ooool3o`0001Oooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??
h`02ol??h`05o`000?nmc>Go_LcUokg<iOl000001?ndanP00ol0003oZ<3[o`000008o`000003ohV/
k?l0003oNj;/00;oNj;/00Co0000og>LjomcW>_o00000omaVnX01Ol0003oMio[ogNOjomgWn_o0000
00?oQJW/00Co0000oiJekOnF]Ngo00001OnY`^/01Ol0003o^lgXok_=j?nkcNSo000000CobMGS0_l0
0003om3=e`05o`000?oFc];oe/kBomK>d_l000000oo@`L`01?l0003odL7:om71b_l00006olZeaP03
o`000?o2Zl?o000000?o00001?niXl800ol0003o/9_2ok2K`P03ok2K`P03o`000?nWUL?oYiG300?o
00001OnLSlD01Ol0003oT8[9oi2:bOn@R/Wo000000;oTHg;00?o0000ohB9dOn4RM400on4RM400ol0
003oRI7Eo`000002og^@g005o`000?n7WN;oQigRohNMh_l000001OnF[NL01Ol0003oYKk[ojFnjonU
_^_o000000Co/lk^00Co0000okkJk_nnf^ko00000oo5h^d01Ol0003ob>G/olSUk?o8iNco000000?o
b>G/00Co0000ol?OkOo3gngo00000_nlenh00ol0003o//c]ok;<k@02ok;<k@05o`000?nW_n_oYko[
ojNojol000000onM/nL00ol0003oUJ[ToiFZi002oiFZi003o`000?n@Y>;oT:CR00;oT:CR00Oo0000
ohjRhOn>X^7oSZ;Qo`000?n>X^7o000002Cooooo00?o0000ooooooooool01oooool001Sooooo00?o
0000ooooooooool07Oooool3o`0001[ooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??
h`02ol??h`05o`000?nmc>Go_LcUokg<iOl000000_ndanP4o`0000;oZ<3[00Go0000oiNikonG^Noo
UkW_o`000002ohB`lPOo000000?oLic[o`000?maVnX00_maVnX01Ol0003oMio[ogNOjomgWn_o0000
00?oQJW/00Go0000oiJekOnF]NgoU[G]o`000004ojW2j`05o`000?nkcNSo^lgXok_=j?l000000oo9
eN<2o`0000God<gG00?o0000omK>d_l000001Oo@`L`00ol0003odL7:o`000005olZeaP03o`000?o2
Zl?o`Z_300?o`Z_33_l00002ojNE``03o`000?nLSlGoW8o500CoW8o500?o0000oi2:bOl000001?nA
SL/01Ol0003oQ8WAohB9dOn4RM7o000000?oRI7E00?o0000og^@g?l000000on7WN800ol0003oUZgW
oiJ]i`03oiJ]i`05o`000?nU_^_oYKk[ojFnjol000000oncc^h01Ol0003o_][^okkJk_nnf^ko0000
00;oaN;]00?o0000olSUk?o8iN`00_o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko
_=O^o`0000?o//c]00?o0000ojNojonW_n/00_nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T
00Go0000oi2Th_n@Y>;oT:CRo`000005ohjRh@03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01oooool001Sooooo00?o0000ooooooooool06_ooool3o`0001gooooo00?o0000olG@hoo5d><0
0oo5d><01Ol0003o`loSol??hoo3cn?o000000?o_LcU0ol00002okG4i@03o`000?nX`>_oZ<3[00;o
Z<3[00Go0000oiNikonG^NooUkW_o`000002ohB`lP09o`000?maY_;oLJKbog6Vl_l0003oI9oao`00
0?mcW>_o000000;oLI_Z00Go0000ogNOjomgWn_oMio[o`000003ohFYk005o`000?nF]NgoU[G]oiJe
kOl000001?nY`^/00ol0003o^lgXok_=j002ok_=j0?o000000?ob<cMo`000?o@cML01Oo@cML00ol0
003od<7<om31c005om31c0?o00001?o:]LH00ol0003o`Z_3ol:[``03ol:[``03o`000?niXl;o^J?2
00;o^J?200?o0000ok2K`_n`Vl800on`Vl800ol0003oYiG3ojNE``03ojNE``03o`000?nLSlGoW8o5
00?oW8o50_l00006oi6=b`03o`000?n4RM7o000000GoRI7E0_l00003ohNMhP03o`000?nF[NOoUZgW
00;oUZgW00Go0000ojFnjonU_^_oYKk[o`000004ok?>kP05o`000?nnf^ko_][^okkJk_l000000_o5
h^d01Ol0003ob>G/olSUk?o8iNco000000?ob>G/00Go0000ol?OkOo3gngo`mo]o`000002okcGkP05
o`000?nbc>go//c]ok;<kOl000000onW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00?o0000
oi2Th_n@Y>800_n@Y>800ol0003oSZ;QohjRh@03ohjRh@;o00009?ooool00ol0003oooooooooo`07
ooooo`006?ooool2o`0001Sooooo0ol0000Qooooo`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??
hoo3cn<00_o3cn<3o`000003okg7hOl0003o]LCU00?o]LCU00?o0000ojS0jonX`>/00_nX`>/01Ol0
003oUkW_oiNikonG^Noo000000;oQ;3b00Go0000og6Vl_maY_;oLJKbo`000002ofBOl@?o000000Go
LI_Zo`000?mgWn_oMio[o`000003ohFYk005o`000?nF]NgoU[G]oiJekOl000001OnY`^/00ol0003o
^lgXo`000002o`0000Cob<cM00?o0000om3=eoo@cML00oo@cML00ol0003oc<;Ao`000005om31c003
o`000?o8]/Sob;K800?o000000?ob[G6o`000?o2Zl<01?o2Zl<00ol0003o^J?2okVS`P02okVS`P03
o`000?n`Vl;o/9_200?o/9_200?o0000ojNE`onWUL<00onWUL<01?l0003oW8o5oib?aOnLSlD2o`00
0003oifBaol0003oTHg;00GoTHg;0_l00006ohVAe@03o`000?nAWM_o000000;o00001OnF[NL01Ol0
003oYKk[ojFnjonU_^_o000000Co/lk^00Co0000okkJk_nnf^ko00000oo5h^d01Ol0003ob>G/olSU
k?o8iNco000000?ob>G/3Ol00002ojNoj`05o`000?nM/nOoWK?Woifciol000001?nEZ^@00ol0003o
T:CRoi2ThP02oi2ThP03o`000?n>X^7oSZ;Q00;oSZ;Q00Co0000oooooooooooo00009?ooool00ol0
003oooooooooo`06ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o00009?ooool00ol0003o
aM3SolG@h`02olG@h`03o`000?o3cn?o`loS00?o00001?nman400ol0003o]LCUokG4i@02okG4i@03
o`000?nX`>_oZ<3[00;oZ<3[00Go0000oiNikonG^NooUkW_o`000002ohB`lP07o`000?maY_;oLJKb
og6Vl_l0003oI9oao`000002of:Nl@Co000000?oMio[o`000?n5ZN`00_n5ZN`01Ol0003oU[G]oiJe
kOnF]Ngo000000;oZL;[1?l00002ok_8i003o`000?o8c=gob<cM00?ob<cM00Go0000om3=eoo@cMOo
d<gGo`000003olc2d@05o`000?o@`Lcod<7<om31c?l000001_o8]/P3o`0000?o`Z_300?o0000okVS
`_niXl800oniXl800ol0003o/9_2ok2K`P04ok2K`P03o`000?nWUL?oYiG300;oYiG300Co0000oib?
aOl0003o00001?nMT/L00ol0003oTHg;oi6=b`02oi6=b`03o`000?nDTm3o000000GoRI7E00?o0000
oi6MfonAWM/00_nAWM/2o`0000CoUZgW00Go0000ojFnjonU_^_oYKk[o`000003ok?>kP05o`000?nn
f^ko_][^okkJk_l000000_o5h^d00ol0003ob>G/olSUk002olSUk0Go00000_nli_<01?l0003o]m_c
okOKlol00003ojo=l003o`000?nW_n_oYko[00Co00000_nM/nL01Ol0003oUJ[ToiFZi?nEZ^Co0000
00CoT:CR00?o0000ohjRhOn>X^400on>X^401?l0003oooooooooool0000Tooooo`03o`000?oooooo
oooo00Kooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0000Wooooo`03o`000?o5d>?oaM3S
00;oaM3S0ol00002ol;8gP03o`000?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D01Ol0
003oZ<3[ojS0jonX`>_o000000CoUkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oao`00
0002of:Nl@03o`000?m[Xo;oJj?b00co00000_nZ`N/00ol0003o^lSTok_8i002ok_8i003o`000?o8
c=gob<cM00?ob<cM00?o0000om3=eol000001Oo<`]400ol0003od<7<o`000007olRfb003o`000?o1
[<Go`Jc500Co00001OniXl800ol0003o/9_2ok2K`P04ok2K`P03o`000?nWUL?oYiG300Co00001onM
T/L01?l0003oTHg;oi6=bol00003oiBCd005o`000?n9TMGoRI7EohVAeOl000001OnAWM/01_l0003o
VZcSo`000?l0003oUZgWo`0000CoYKk[00Go0000ok?>k_ncc^ko/lk^o`000003okkJkPWo000000?o
_^cco`000?nli_<00_nli_<01?l0003o]m_cokOKlol00003ojo=l003o`000?nW_n_oYko[00;oYko[
00?o0000oj2biOnP/^D01?l00002oiFZi003o`000?n@Y>;oT:CR00;oT:CR00?o0000ohjRhOn>X^40
0on>X^401Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool01_ooool001Oooooo
00?o0000ooooooooool03oooool3o`0002_ooooo1?l000000oo4b=go0000ol;8gP03ol;8gP03o`00
0?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D01Ol0003oZ<3[ojS0jonX`>_o000000Co
UkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oao`000002of:Nl@04o`000?m[Xo;oJj?b
o`0000?oOJgb00Go0000oiBhl?nD^?3oU;S`o`000005oj[1j`03o`000?nkb>Co^lST00;o^lST00?o
0000olS<gOo8c=d00_o8c=d2o`0000Ooc<;A00?o0000olRfb?o8]/P01Oo8]/P00ol0003o`Jc5ol6/
a@04ol6/aA3o00000onWUlD00ol0003oWI;7oifBa`05oifBa`03o`000?nASL_o000000GoU9?@00?o
0000ohVAeOl000001OnAWM/00ol0003oVZcSoiZ/h`03oiZ/h`?o000000?oYKk[o`000?ncc^h00onc
c^h5o`0000;o_NWc00Co0000okk]lonnkO?o00000_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o
]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNoj`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZY
h?nJZN000ol00003oi2ThP03o`000?n>X^7oSZ;Q00?oSZ;Q00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00co
oooo0ol0000^ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_o2b=h00_o2b=h00ol0003o
_LOQokg7h@03okg7h@03o`000?nea>Go]LCU00;o]LCU00Go0000ojS0jonX`>_oZ<3[o`000003oiNi
k`04o`000?n4/?;oQ;3bo`0000?oLJKb00Co0000ofBOlOmTWo7o00000_mRW_401?l0003oJj?bof^S
l_l00003ogf]lP05o`000?nD^?3oU;S`oiBhl?l000001?nZ`N/00ol0003o^lSTok_8i002ok_8i005
o`000?o8c=gob<cMolS<gOl000000oo5`mP00ol0003oc<;Aolc2d@03olc2d@04o`000?o6^<go0000
o`0000?ob;K800?o0000ol6/aOo1[<D01Oo1[<D00ol0003o^JC4okVTa003okVTa003o`000?n`WLCo
/9g400Co/9g400?o0000ojNGaOnWUlD01?nWUlD00ol0003oWI;7oifBa`03oifBa`?o00001_nDTm03
o`0000CoTIgK00?o0000oiZ/honJ[><01?nJ[><00ol0003oY[k[ojJnj`07o`0000;o^=oc00Co0000
okgYlonmjO?o00000_nnkO<01?l0003o_^ccokk/lol00003okcVl`04o`000?ngfo?o]m_co`0000?o
[lg`00?o0000ojNojonW_n/00_nW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;o
VZWP00Ko0000oiNSgOl0003o0000oi2Th_l00005ohjRh@03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`06ooooo`005oooool2o`0000[ooooo0ol0000aoooo
o`03o`000?o4b=goa<SM00Coa<SM00?o0000ol;8g_o2b=h00_o2b=h00ol0003o_LOQokg7h@03okg7
h@05o`000?nea>Go]LCUokG4iOl000001?nX`>/01Ol0003oUkW_oiNikonG^Noo000000;oQ;3b00Go
0000og6Vl_maY_;oLJKbo`000002ofBOl@04o`000?mRW_7oHYkao`0000;oJj?b00Go0000ogf]l_mm
[O;oOJgbo`000003oiBhl003o`000?nZ`N_oZ/7[00;oZ/7[00?o0000ok_8i?nkb>@00_nkb>@00ol0
003ob<cMo`000005olG3f005o`000?o<`]7oc<;Aolc2dOl000001?o6^<d2o`000003olRfb?l0003o
`Jc500Go`Jc500?o0000okVTa?niY<@01?niY<@00ol0003o/9g4ok2Ma004ok2Ma003o`000?nWUlGo
YiO500CoYiO500?o0000oifBaonMT/L00ol00002oinGc003o`000?nDTm3oU9?@00?oU9?@00Go0000
oiVNeonIW]OoVIkGo`000003oi6Mf`03o`000?nJ[>?oVZcS00?oVZcS00Go0000ojJnjonV_^_oY[k[
o`000004ok3@l@04o`000?nhgo?o^=oco`0000;o_NWc00Co0000okk]lonnkO?o00000_nnk?<01Ol0
003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNoj`03o`000?nP
/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003oUj?MoiNSg@02oiNSg@;o00001?n>
X^400ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_oo
ool001Oooooo00?o0000ooooooooool01_ooool3o`0003Gooooo00?o0000olC8gOo4b=d01?o4b=d0
0ol0003o`/SNol;8gP02ol;8gP03o`000?nman7o_LOQ00;o_LOQ00?o0000okG4iOnea>D00_nea>D0
1Ol0003oZ<3[ojS0jonX`>_o000000CoUkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oa
o`000003of:Nl@04o`000?m[Xo;oJj?bo`0000?oOJgb00Go0000oiBhl?nD^?3oU;S`o`000004oj[1
j`04o`000?nkb>Co^lSTok_8i0;o00001oo5`mP00ol0003oc<;Ao`000007olJhc@03o`000?o1[<Go
000000Go`Jc500?o0000okVTa?niY<@01?niY<@00ol0003o/9g4ok2Ma005ok2Ma003o`000?nWUlGo
YiO500;oYiO51?l00006oinGc003o`000?nDTm3oU9?@00;o00001OnIW]L00ol0003oTIgKo`000005
oiZ/h`05o`000?nV_^_oY[k[ojJnjol000001?n`d?401?l0003o^=ocokSOlol00002okgYl`04o`00
0?nnkO?o_^gco`0000;o_^cc00Go0000okcVlonli_?o_>Kco`000002okOKl`05o`000?n_cO3o[lg`
ojo=l?l000001?nW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000
oiNSgOnGXmd00onGXmd00ol0003oUJ7Lo`000002o`000003ohjRhOl0003ooooo00Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`03oooo
o`?o0000>Oooool00ol0003oa<SMolC8g@04olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7
hOnman400_nman400ol0003o]LCUokG4i@02okG4i@05o`000?nX`>_oZ<3[ojS0jol000001?nG^Nl0
1?l0003oQ;3bohB`l_l00003og6VlP03o`000?mTWo7o000000?oHYka00Co0000of^Sl_m[Xo;o0000
0omm[O801?l0003oU;S`oiBhl?l00004oj[1j`04o`000?nkb>Co0000o`0000?o^/?Q00?o0000olG3
f?o5`mP01?o5`mP00ol0003oa[S=olJhc@06olJhc@03o`000?no[l[o_jo:00?o00000_o1[<D00ol0
003o^JC4okVTa004okVTa003o`000?n`WLCo/9g400Go/9g400?o0000ojNGaOl000000_l00002ojRK
b@03o`000?nOUlcoWiO<00GoWiO<00?o0000oiBCd?l000001onIW]L3o`0000CoVZcS00Go0000ojJn
jonV_^_oY[k[o`000004ok3@l@04o`000?nhgo?o^=oco`0000;o_NWc00Co0000okk]lonnkO?o0000
0_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNo
j`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003oUj?MoiNSg@03oiNS
g@03o`000?nEXMcoUJ7L00?oUJ7L00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Gooooo000Fooooo`04o`000?ooooooooooooooo`?o0000?Oooool00ol0
003oa<SMolC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7hOnman400onman400ol0
003o]LCUokG4i@02okG4i@05o`000?nX`>_oZ<3[ojS0jol000000_nG^Nl<o`0000?oHYka00Co0000
of^Sl_m[Xo;o00000omm[O801?l0003oU;S`oiBhl?l00002oj[1j`?o00001_nj`n42o`0000?oaL?H
00?o0000ol6je?o1^]@00ol00003olJhc@03o`000?no[l[o_jo:00Co_jo:4ol00006ojRKb@03o`00
0?nOUlcoWiO<00CoWiO<0_l00006oiVNe`;o00000onO[>02o`000003oiZ/hol0003oY[k[00;oY[k[
00?o0000ok3@lOn`d?400_n`d?401?l0003o^=ocokSOlol00003okgYl`03o`000?nnkO?o000000;o
_^cc00Go0000okcVlonli_?o_>Kco`000002okOKl`05o`000?n_cO3o[lg`ojo=l?l000001?nW_n/0
0ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000oiNSgOnGXmd00onGXmd0
0ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`005_ooool4o`00047ooooo00?o0000olC8gOo4b=d00oo4b=d00ol0
003o`/SNol;8gP02ol;8gP03o`000?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D00ol0
003oZ<3[ojS0j`03o`0000CoU[cb0omo]OL4ofN/n003oeFTmol0003o000000ko00001?nZ`NX00ol0
003o^/?Qok[3h@04ok[3h@03o`000?o5`mSo000000Ko`K[D0_l000000oo6^<go0000okn_bP06okn_
bP03o`000?nhYlSo^:O800Go^:O800?o0000ok2Qb?n`XLP01On`XLP00ol0003oZ9_9ojRKb@05ojRK
b@04o`000?nOUlcoWiO<oinGc0?o00000_nQX=<00ol0003oVIkGoiVNe`02oiVNe`03o`000?nO[>3o
WjcP00CoWjcP1?l000000onV_^_o0000ok3@l@03ok3@l@04o`000?nhgo?o^=oco`0000?o_NWc00?o
0000okk]lol000000_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o
[lg`o`000004ojNoj`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003o
Uj?MoiNSg@03oiNSg@03o`000?nEXMcoUJ7L00?oUJ7L00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Fooooo`?o0000@oooool00ol0003oa<SM
olC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7hOnman400onman400ol0003o]LCU
okG4i@04o`0000?oZ;o[1OnF_?801?l0003oOkGgognemol00003ofN/n0;oEJCg1?mBXoH3oenXn0Co
Mk;h0onB_?<5oj[1jP;o00001Onj`n400ol0003o`K[Dol6je007ol6je003o`000?no[l[o000000Ko
_jo:00?o0000okRWb?nhYlP01OnhYlP00ol0003o/:78ok2Qb005ok2Qb003o`000?nXVlWoZ9_900Go
Z9_900Co0000oinGc?l0003o00001_nQX=<01?l0003oVIkGo`000?l00006oin/h004o`000?nV_^[o
Y[kZojJnjPCo00000_n`d?401?l0003o^=ocokSOlol00003okgYl`oo000000?o[lg`o`000?nW_n/0
0onW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000oiNSgOnGXmd0
0onGXmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo00gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`05ooooo`003?ooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0@_ooool00ol0003oa<SMolC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o
0000okg7hOnman400_nman43o`0000Co]<7S1?nX_n/00ol0003oU[cboiJllP02oiJllP;o00000_mo
]OL01_l0003oIjchofN/n?l0003oEJCgo`0000?oDZ?f00Co0000oenXn?mOZ?So00000omg/_P00ol0
003oT[ccoi:ll`02o`0000CoZ/7Z00Go0000ok[3hOnj`n7o^/?Qo`000002okRmgP;o00001_o1^]@0
0ol0003o_;?Aokbcd@04o`000003okn_b_l0003o^:O800Oo^:O800?o0000ok2Qb?n`XLP01_n`XLP0
0ol0003oZ9_9ojRKb@03ojRKb@?o00002?nQX=<2o`0000KoWjcP0_l00003ojJnjP03o`000?n/dO?o
[=7c00;o[=7c2_l00002ojc_m`05o`000?n^jOWo[^WiojkYnOl000000_n^gOP01?l0003o[<kbojc>
l_n/c_84o`0000;oYko[00?o0000oj2biOnP/^D00_nP/^D00ol0003oVZWPoiZYh003oiZYh003o`00
0?nGXmgoUj?M00;oUj?M00?o0000oiFQg?nEXM`00onEXM`00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`11ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_o2b=h00oo2
b=h01?l0003o_LOQo`000?l00003okc1gPGo]<7S00?o0000ojRojonX_n/00_nX_n/00ol0003oU[cb
oiJllP02oiJllP03o`000?mo]OOoOkGg00;o00000_mW[?P00ol0003oEJCgo`000002oe:SmP04o`00
0?mOZ?SoGjSho`0000?oMk;h00Co0000oi:llonB_??oT[cc0_l00003oj[1jP03o`000?nj`n7o0000
00Go^;gN0_l00003ol6je003o`000?nl/m7o_;?A00Go_;?A1ol00003okRWb003o`000?n`XLSo/:78
00Ko/:7800?o0000ojRKbOl000000ol00002ojVSd@03o`000?nQX=?oXJ3C00?oXJ3C0ol00002ojB]
g@04o`000?nO[>3oWjcPoin/h0;o00000onV_^X2o`0000Co[=7c00Co0000ojkRnOn^h_Wo00000_n]
k?P4o`0000;o[>og00?o0000ojkYnOn^jOT00_l000000on^gOSo0000o`000003ojc>lP03o`000?nW
_n[oYkoZ00;oYkoZ0ol00003oj2bi@03o`000?nJZN3oVZWP00?oVZWP00?o0000oiNSgOnGXmd00_nG
Xmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo013ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo047ooooo00?o0000olC8gOo4b=d00oo4b=d00ol0003o`/SNol;8gP03ol;8gP03o`000?nl`Mko
_<7N00Co_<7N00?o0000okC1hond`N<00_nd`N<2o`0000?oZ;o[0_l00003oiJllP05o`000?mo]OOo
OkGgognemol000000_mW[?P00ol0003oEJCgo`000003oe:SmP04o`000?mOZ?SoGjSho`0000;oMk;h
00?o0000oi:llonB_?<00_nB_?<00ol0003oZ/7Zoj[1jP02o`0000So^;gN0_l000000oo1^]Co0000
okbcd@07okbcd@03o`000?nf[M3o]Zg@00?o]Zg@3_l00007ojVSd@03o`000?nQX=?o000000;o0000
1_nT[Md00ol0003oWjcPo`000003ojJnjP;o00001?n/dO<2o`000004ojkRnOl0003o0000ojg/n0Co
00000_n/koL2o`000003ojkYnOl0003o000000;o[]gh00Co0000ojc>l_n/c_;o[<kb0_l00003ojNo
jP;o00000onS/^<00ol0003oX;;Uo`000005oiZYh003o`000?nGXmgoUj?M00;oUj?M00?o0000oiFQ
g?nEXM`00onEXM`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`0004;ooooo00?o0000olC8gOo4
b=d00oo4b=d01Ol0003o`/SNol;8g_o2b=ko000000;o`<7J1_nl`Mh2o`0000Co]<7S00?o0000ojRo
jonX_n/00_nX_n/01?l0003oU[cboiJll_nF_?82o`0000;oOkGg0_l00002ofN/n0?o00000_mBXoH0
1?l0003oGjShoenXn?l00002ogNbn004o`000?nB_??oT[ccoi:ll`?o00000onY`>X2o`0000Oo^;gN
00?o0000okbcdOnl/m401onl/m400ol0003o]Zg@okJ]d006okJ]d003o`000?n_Z=3o[jS@00Ko[jS@
00?o0000ojVSdOnYXm401OnYXm43o`0000WoY:gM1?l000000onV_^[o0000ojcAl`04ojcAl`04o`00
0?n^h_Wo[^;io`0000;o[Nch00?o0000ojc_mol000000on/koL01?l0003o[^WiojkYnOl00002ojkM
n0;o00000on/c_800ol0003oYkoZojNojP02ojNojP03o`000?nS/^?oXk;S00?oXk;S0ol00004oiZY
h003o`000?nGXmgoUj?M00;oUj?M00?o0000oiFQg?nEXM`00onEXM`00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`10ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_l0
00001?o0`MX00ol0003o_<7Nokc1gP04okc1gP03o`000?nd`N?o]<7S00;o]<7S00?o0000ojRojonX
_n/00_nX_n/00ol0003oU[cboiJllP02oiJllP05o`000?mo]OOoOkGgognemol000000_mW[?P00ol0
003oEJCgo`000002oe:SmP04o`000?mOZ?SoGjSho`0000;oMk;h00?o0000oi:llol000000onB`?H0
0ol0003oZL3ZojW0jP02ojW0jP?o00001?nh_Mh00ol0003o]KWLokFig005o`000003okbcdOl0003o
]Zg@00So]Zg@00?o0000ojnXd?n_Z=001on_Z=000ol0003oZJ?Ao`000004o`0000;oZJoL00?o0000
ojB]gOnT[Md01?nT[Md3o`0000?oYkkZ0ol00003ojcAl`;o000000Co[^;io`000?l0003o[Nch1?l0
0002ojc_m`;o000000?o[^Wio`000?l000000_n^gOP01?l0003o[<kbojc>l_n/c_82o`0000?oYkoZ
0_l00005oj>bh`04o`000?nOZMgoWjWMoinYg@;o000000?oVZWPo`000?nGXmd00onGXmd00ol0003o
UJ7LoiFQg003oiFQg003o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo043ooooo
00?o0000olC8gOo4b=d00_o4b=d2o`0000Oo`<7J00?o0000okc1g_nl`Mh00onl`Mh2o`0000?o]<7S
00?o0000ojRojonX_n/00_nX_n/2o`0000?oU[cb00?o0000ognemomo]OL04?l00006oi;0mP;o0000
1?nY`>X2o`000003okRmg_l0003o]KWL00Oo]KWL0_l000000onf[M3o0000o`000002o`0000Co]Zg@
00?o0000ojnXd?n_Z=000_n_Z=07o`0000SoZJoL00?o0000ojB]gOnT[Md00ol00003ojNnjP?o0000
0onWdOH00ol0003o[=7co`000002ojkRn@06o`000?n]k?So0000o`000?n/koOo00000on/koL01?l0
003o[^Wio`000?l00003ojkMn003o`000?n/c_;o[<kb00;o00000onW_nX2o`0000GoXk;S0_l00005
oinYg@?o00000onGXmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo01Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo043ooooo00Co0000olC8gOl0003o00000oo2`MT7ol31fP;o00001Onl`Mh0
1?l0003o]<7SokC1hond`N<2o`0000CoZ;o[00?o0000oiJll_nF_?800ol00003ogfln`?oH;?k0_m9
ZoP3odFXm`04o`000?mF[o[oEZojo`0000;oM;[l00?o0000oi;0m_nB`?H01?nB`?H2o`0000CoZL3Z
00?o0000okFig?ne^M`02?ne^M`00ol0003o/KGKok6ef`03ok6ef`Wo00001On^/M/00ol0003oZJoL
ojV_g006ojV_g0Co00001?nW_^X2o`0000KoYm7f3?l000001?n/koOo0000ojkYnOl00003ojkMn0;o
00000_n/c_800ol0003oYkoZojNojP02ojNojP03o`000?nS/^?oXk;S00CoXk;S00?o0000oinYgOnO
ZMd00onOZMd2o`0000?oWJ?I00?o0000oiNSgOl000001OnEXM`00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool000cooooo00?oEEEEofIVI_l00000
4Oooool2o`00047ooooo00?o0000ol;1fOo2`MT01?o2`MT2o`0000Ko`<7J00?o0000okc1g_nl`Mh0
0onl`Mh00ol0003o]<7SokC1h`02okC1h`04o`000?nX_n_oZ;o[ojRoj`?o00000onG`?@00ol0003o
OKckogfln`02ogfln`04o`000?mP/o_oH;?kof2cn`;oBJ_h0_m5Z?L2o`0000;oEZoj00?o0000ogBj
o?md^_`00ol00003oi;0mP;o000000?oZL3Zo`000?nY_nX00onY_nX5o`000003okFig?l0003o/KGK
00Wo/KGK00?o0000ojjafon^/M/01on^/M/00ol0003oZJoLojV_g003ojV_g0?o00000onW_^X00ol0
003oYkkZo`000002o`0000GoYm7f2ol00003oi;Yn0Ko000000Co[]gho`000?n/c_;o[<kb0_l00003
ojNojP;o00001OnS/^<2o`0000GoWjWM00?o0000oifSfOnMXmT00onMXmT2o`0000GoUJ7L00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000Roooo
o`03o`000?oooooooooo043ooooo1oo2`MT00ol0003o`<7Jol31fP04ol31fP03o`000?nl`Mko_<7N
00?o_<7N0_l00003okC1h`03o`000?nX_n_o000000?oZ;oZ00?o0000oiO0m?nG`?@00_nG`?@2o`00
00?oOKck0_l00002of2cn`04o`000?m9ZoSo0000odFXm`?o000000?oEZojo`000?l000000_md^_`3
o`0000;oT/3f00?o0000ojVoj_nY_nX02?nY_nX2o`0000;o/KGK1?l00004ok6ef`03o`000?n^/M_o
[[7K00So[[7K00?o0000ojV_g?l000000_l00005ojNnjP?o00001OnWdOH3o`000003oj7Qo?l0003o
000000;o000000?oTNWgo`000?l000000onBjOP5o`0000?oXmgk0ol000000on/c_;o0000ojNojP02
ojNojP;o00001_nS/^<00ol0003oWjWMoinYg@03oinYg@;o00001OnMXmT01?l0003oW:7HoibQf?l0
0003oiFQg003o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`04ooooo`008oooool00ol0003oooooooooo`10ooooo`03o`000?o2`MWo`/7I00Co`/7I0_l00005
ol31fP;o00001Onl`Mh01Ol0003o]<7SokC1hond`N?o000000OoZ;oZ00?o0000oiO0m?nG`?@00_nG
`?@2o`0000?oOKck0_l000001?mP/o_o0000odV[n?l00002odFXm`;o000000CoEZojo`000?l0003o
00000_md^_`00ol0003oU<CgoiC4m`02oiC4m`Co00001OnY_nX00ol0003oZKoYojVoj@04ojVojA7o
00001?nW_^X4o`0000?oXLoh00?o0000ojOAm_l000000_l00002oj7Qo0Co000000?oTNWgo`000?l0
00000_nBjOP5o`0000?oXmgk0ol00002ojO>m0Co000000?oYkoZo`000?nS/^<01OnS/^<2o`0000Co
WjWM0_l00005oifSf@;o00001?nLXMP00ol0003oUJ7Lo`00000Pooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01?ooool002Cooooo0_l00012ooooo`03o`000?o2`MWo`/7I00Co`/7I
00?o0000ol31f_o0`MX01?o0`MX00ol0003o_<7Nokc1gP03okc1gP03o`000?nd`N?o000000;o/kkR
00?o0000ojRoj_nX_nX01OnX_nX2o`0000?oUl3d0_l00003ogfln`;o00000_mP/o/01?l0003oBJ_h
o`000?m5Z?L2o`000003oeJ_n_l0003o000000CoM<;n00?o0000oiC4monDa?L00onDa?L3o`000003
ojVoj_l0003oZKoY00[oZKoY00?o0000ojRnjOnX_^T02?nX_^T00ol0003oYkkZojNnjP03o`0000Ko
XLoh1?l000000onQhOco0000o`000006o`000003oi;Yn?l0003o000000Co00000_nSgO/3o`0000;o
Ylkd0ol00003ojRojP;o00001_nS/^<00ol0003oWjWMoinYg@03oinYg@03o`000?nMXmWoWJ?I00Co
WJ?I00?o0000oibQf?nLXMP01?nLXMP2o`0002;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`009_ooool00ol0003oooooooooo`10ooooo`03o`000?o2`MWo`/7I00Co`/7I
00?o0000ol31f_o0`MX01?o0`MX2o`0000?o_<7N0_l00006ok>nhP;o00001_nX_nX2o`0000;oUl3d
0ol00002ogfln`;o000000?oH;?ko`000?l000001?l00004oe:in`;o00001?md`_h4o`000003oiC4
mol0003o000000;oZKoY1?l00005ojVoj@03o`000?nX_^WoZ;kY00?oZ;kY2?l00005oj7?n0Co0000
0_nBg?h5o`000004oi7Ymol0003o0000oi;Yn0?o000000?oVnKlo`000?l000000onSgO/2o`0000;o
Ylkd0ol00003ojRojP?o00000_nV/n401?l0003oXk;Soj>bhonS/^<2o`0000CoWjWM0_l00005oifS
f@;o00001_nLXMP00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool002Oooooo00?o0000ooooooooool0@?ooool2o`0000Go`/7I0_l00006ol31fP03
o`000?nl`Mko000000?o^[cK00?o0000ok>nh_nc_^801?nc_^83o`0000GoZ;oZ0_l00003oiO0m0;o
000000?oOKcko`000?l000001?mN_?d01?l0003oAK?go`000?lo/OD2o`0000GoD[Wk1?l000000omd
`_ko0000o`000007oiO8n0_o00001_nLc?P00ol0003oXLohoj7?n004o`000003oi;Lo_l0003o0000
00Go000000?oL]cdo`000?l000001?l000001?nKi_co0000o`000?l00002oj?Mn`?o00000_nWc_@2
o`0000CoZ;oZ0_l00006ojJch@03o`000?nS/^?o000000CoWjWM0_l00005oifSf@;o00001_nLXMP2
o`0002Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0
003oooooooooo`11ooooo`03o`000?o2`MWo`/7I00Co`/7I00?o0000ol31f_o0`MX01?o0`MX00ol0
003o^[cKokZlf`05okZlf`;o00001Onc_^83o`0000CoZ;oZ0ol00002oiO0m003o`000?mn`ogoO/?m
00;oO/?m00?o0000oejloOmN_?d00omN_?d2o`000003odFcmol0003o?k7e00Co00000_mB^O/2o`00
00SoN/_o6ol000000ombg?Co0000o`000005o`000003ohKNoOl0003o000000?o000000CoXmgko`00
0?l0003o00000_nWc_@3o`0000?oZ;oZ0ol00008ojJch@;o00001?nOZMd00ol0003oWJ?IoifSf@04
oifSf@03o`000?nLXMSoW:7H00GoW:7H00?o0000ooooooooool09oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo000Yooooo`;o0000@_ooool2o`0000Go`/7I0_l00003ol31
fP04o`000?nm^]Oo_K[Go`0000Oo^[cK0ol00005ok>nhP;o00001OnX_nX00ol0003oV<?foiS3mP02
oiS3mP03o`000?mn`ogoO/?m00?oO/?m0ol00002oejlo@Co000000CoAK?go`000?l0003o00002OmH
a?XGo`000003og;Lm?l0003o000000_o00000onGfOh4o`000004ojO>m?l0003o0000o`0000?oZ;oZ
0ol00008ojJch@?o00000_nUZ]X01?l0003oWjWMo`000?l00005oifSf@;o00001_nLXMP2o`0002_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003ooooo
ooooo`11ooooo`03o`000?o2`MWo`/7I00Co`/7I00?o0000ol31f_l000001_nm^]L2o`0000Ko^[cK
0ol00004ok>nhP?o000000?oZ;oZo`000?nX_nX00_nX_nX00ol0003oV<?foiS3mP03oiS3mP?o0000
0omn`od4o`000003oejloOl0003o000000GoBkkd1?l000000om5_?;o0000o`00000No`0000CoUmWn
1Ol00002oj?=mP?o00001?nX_nX2o`0000SoY[?Q0ol00005ojFZfP;o00001_nMXmT00ol0003oW:7H
oibQf004oibQf0;o0000;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo
000/ooooo`03o`000?oooooooooo047ooooo00?o0000ol;1fOo2`MT01?o2`MT00ol0003o_K[Gokfj
e`07okfje`;o00001onj_=/2o`0000Go/kkR00?o0000ojRoj_nX_nX01OnX_nX4o`0000CoV<?f1?l0
00000omn`ogo0000o`000005ofC7o@Go00001?m;__@;o`000003oe_=m?l0003o000000[o00001OnG
fOh4o`0000;oXlgf1Ol00002ojRojP03o`000?nX_n[o000000;o00001onV/n43o`0000GoYJ[J0ol0
0002ojBUeP04o`000?nMXmWoWJ?IoifSf@;o00001_nLXMP00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool002gooooo00?o0000ooooooooool0@Ooo
ool2o`0000?o`/7I00Co0000okjjeOnn^]Go00002Onm^]L3o`0000Ko^[cK0ol000000onc_^;o0000
ok6kh002ok6kh003o`000?nX_n[oZ;oZ00KoZ;oZ1?l00004oiS3mP;o00002_n3bol5ofC7o@co0000
2On<dol00ol0003oUmWnoiOIoP05o`000003oj?=m_l0003o000000?o00001_nX_nX3o`0000SoY[?Q
0_l00006ojFZfP;o00001_nTYMH00ol0003oWJ?Io`000006oibQf0;o0000<_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000^ooooo`;o0000@oooool00ol0003o`/7Io`00
0006okjje@;o00002?nm^]L2o`0000Oo^[cK00?o0000ok6kh?na^n001_na^n04o`0000GoZ;oZ0ol0
0002oiS3mP03o`000?nKaoKoVlOf00?oVlOf2Ol00004oh?;o`03o`000?n<doooS=?o00OoS=?o2ol0
00000onScOKo0000o`000003o`0000KoZ;oZ1Ol00002ojVdh003o`000?nV/n7oY[?Q00?oY[?Q0ol0
0006ojFZfP;o00002?nTYMH2o`0000KoW:7H00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000
okjjeOnn^]D01onn^]D3o`0000Oo_K[G0_l00005okZlf`03o`000?ng]mWo]kOI00;o00002?na^n03
o`0000GoZ;oZ0_l0000?oi_7mQ[o00001_nX_nX5o`0000SoZKCP00?o0000ojJchOl000000_l00006
ojFZfP?o00001onTYMH3o`0000;oXj?E00Co0000oibQf?nLXMSoW:7H0_l0000gooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool0037ooooo00?o0000ooooooooool0@_ooool0
0ol0003o_[[Eokjje@08okjje@;o00001onm^]L3o`000003okZlfol0003o]kOI00Ko]kOI1?l00005
ok6kh0Co00000_nX_nX00ol0003oZ;oZojRojP08ojRojQ?o00002_nX_nX00ol0003oZ;oZojRojP05
o`0000_oZKCP1?l00007ojFZfP;o00002?nTYMH2o`0000KoXj?E00?o0000oibQf?l00000>Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03o`000?oooooooooo
04Cooooo0ol00007okjje@?o00001onm^]L00ol0003o]kOIokNgf@0:okNgf@Co00001Ona^n02o`00
01CoZ;oZ00?o0000ojRoj_nX_nX03OnX_nX7o`0000_oZKCP1Ol00003ojZ/f@03o`000?nUZ][oYJ[J
00?oYJ[J0_l00007ojBUeP?o00002?nSXmD2o`0003_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`00<oooool2o`0004Oooooo0_l00008okjje@;o00001Onm^]L00ol0003o
^KCEokVde@04o`0000[o]kOI1?l00002ok6kh003o`000?n_^=oo[kSO00?o[kSO2ol00004ojRojP03
o`000?nX_n[oZ;oZ00;oZ;oZ2ol00005ojbfg`03o`000?nY]>3oZKCP00GoZKCP1Ol00009ojZ/f@03
o`000?nUZ][o000000;o00001onTYMH2o`0000SoXj?E0ol0000nooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0A_ooool3o`0000Oo_[[E
0ol000000onm^]Oo0000okVde@06okVde@Go00002Ong]mT2o`00017o[kSO2Ol0000@ojbfg`03o`00
0?nY]>3oZKCP00Go00003?nZ[=T4o`0000OoY:GF0ol00007oj>Se@?o0000@_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo04Sooooo0_l0
0008okjje@03o`000?ni]=Go^KCE00_o^KCE1?l00006okNgf@03o`000?nc/]So/k;H00Co/k;H2ol0
0004ojnhg`03o`000?n/]]oo[;KO00So[;KO3Ol0000<ojZ/f@Go00000onYYm@00ol0003oY:GFojBU
eP03ojBUeP;o00001onSXmD3o`0004Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`00=oooool00ol0003oooooooooo`19ooooo`?o00001Onn^]D00ol0003o^[?CokZcd`04
o`0000_o^KCE1?l000000ong]mWo0000ok>bf00Aok>bf0oo00002_n^[mP00ol0003oZZcIojZ/f@06
ojZ/f@Ko00002OnYYm@00ol0003oY:GFo`000002o`0000OoXj?E0_l00019ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00Oooool003Sooooo0_l0001<ooooo`?o000000?o_[[Eo`00
0?nj/m<01_nj/m<3o`0000co^KCE0_l0000Fok>bf003o`000?n^[mSo[ZoH01?o[ZoH00?o0000ojZ/
fOnZ[=T01Ol0000=ojVWe0Co00001onSXmD3o`0004cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`01ooooo`00>_ooool00ol0003oooooooooo`1<ooooo`03o`000?nj/m?o^[?C00Wo
^[?C1?l00009okVde@03o`000?nd[m?o]:oC00Co]:oC2ol00005ok>bf003o`000?n^[mSo[ZoH00So
[ZoH3_l0000<ojVWe0Ko00000onYY]<00ol0003oXj?Eoj>Se@02oj>Se@?o0000D?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000kooooo`03o`000?oooooooooo04kooooo
0_l0000;okZcd`Co00001Oni]=D00ol0003o]:oCokB_d`0?okB_da3o00002on_Zm<00ol0003oZJOD
ojVWe007ojVWe0Go00002_nYY]<4o`0005?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00??ooool2o`0005;ooooo1?l00009okZcd`?o000000?o^KCEo`000?nd[m<05_nd
[m<00ol0003o[j_Cojn[d`0Dojn[d`03o`000?nYYmCoZJOD00Ko00003OnYY]<3o`0005Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?_ooool00ol0003oooooooooo`1C
ooooo`?o00002Onj/m<2o`0000Go]:oC00?o0000okB_dond[m<03ond[m<00ol0003o[j_Cojn[d`0>
ojn[d`Wo00003_nYY]<5o`0005_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01
ooooo`00?oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo000000?o00001_nj/m<00ol0
003o]JkBokF^dP04okF^dP_o00001Ond[m<00ol0003o[j_Cojn[d`03ojn[d`co00001_n_ZM800ol0
003oZJKCojVVd`09ojVVd`Go0000HOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo0010ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00oooool4o`000003
okZcdol0003o]JkB017o]JkB2ol0000BojnYdP03o`000?nYY]?oZJKC00GoZJKC1?l0001Vooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Booooo`03o`00
0?oooooooooo00Oooooo0_l0000GokF^dP03o`000?n_ZM;o[jWB01Ko[jWB00?o0000ojVVdol00000
1?l0001[ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool03oooool<o`0000Go]JkB00?o0000ojnYd_n_ZM802_n_
ZM8>o`00077ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Cooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Koooooa;o0000P?ooool00ol0003oooooooooo`06
ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo0_l0001=ooooo`03
o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01?ooool1o`00007ooooo001;oooo
o`;o0000B?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`2cooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo0_l0
0013ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo00000Oooool005;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo0000007ooooo001C
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`01
o`000000E?ooool2o`0003oooooo00?o0000ooooooooool0]_ooool1o`00007ooooo0Ol0000005Ko
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`;o0000001Gooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0]_ooool3o`000000F?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo0;;ooooo1?l00003ooooo`00FOooool2o`0003[ooooo00?o0000
ooooooooool0[_ooool4o`0000Oooooo001Kooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0Z_ooool4o`0000_ooooo001Looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0Y_ooool4o`0000oooooo001Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
X_ooool4o`0001?ooooo001Nooooo`;o0000=Oooool00ol0003oooooooooo`2Nooooo`Co00005ooo
ool0063ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`Co00006oooool0
067ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Hooooo`?o00007oooool006;o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`Co00008_ooool006?ooooo
0_l0000_ooooo`03o`000?oooooooooo093ooooo1?l0000Vooooo`00IOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo08cooooo1?l0000Zooooo`00I_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo08Sooooo1?l0000^ooooo`00Ioooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08Cooooo1?l0000booooo`00J?ooool2o`0002[ooooo00?o0000oooooooo
ool0P?ooool4o`0003Kooooo001Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
O?ooool4o`0003[ooooo001[ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?oo
ool4o`0003kooooo001/ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4
o`0004;ooooo001]ooooo`;o00009Oooool00ol0003oooooooooo`1`ooooo`Co0000A_ooool006oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`Co0000B_ooool0073ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000C_ooool0077ooooo0_l0
000Qooooo`03o`000?oooooooooo06Cooooo1?l0001Booooo`00Loooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo063ooooo1?l0001Fooooo`00M?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05cooooo1?l0001Jooooo`00MOooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05Wooooo0ol0001Nooooo`00M_ooool2o`0001cooooo00?o0000ooooooooool0
EOooool4o`00067ooooo001hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOoo
ool4o`0006Gooooo001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool4
o`0006Wooooo001jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`00
06gooooo001kooooo`;o00005oooool00ol0003oooooooooo`15ooooo`Co0000LOooool007gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`Co0000MOooool007kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0mooooo`Co0000NOooool007oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0iooooo`Co0000OOooool0083ooooo0_l0000Boooo
o`03o`000?oooooooooo03Gooooo1?l00021ooooo`00P_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo037ooooo1?l00025ooooo`00Poooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02kooooo1?l00029ooooo`00Q?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02[ooooo1?l0002=ooooo`00QOooool2o`0000cooooo00?o0000ooooooooool09_ooool4
o`00097ooooo0027ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`00
09Gooooo0028ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`0009Wo
oooo0029ooooo`;o00002?ooool00ol0003oooooooooo`0Kooooo`?o0000WOooool008_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`Co0000X?ooool008cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`Co0000Y?ooool008gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`Co0000Z?ooool008kooooo0_l00003ooooo`03
o`000?oooooooooo00_ooooo1?l0002/ooooo`00T?ooool01?l0003oooooooooool00009ooooo`Co
0000/?ooool0097ooooo00?o0000ooooool000001Oooool4o`000;Cooooo002Booooo`;o000000?o
ooooo`000?l000000_l0002hooooo`00Toooool2o`000;cooooo003ooooooe;ooooo003ooooooe;o
oooo003ooooooe;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .64096 m .51694 .65827 L .43899 .65168 L p .728 .619 .736 r
F P
0 g
s
.51694 .65827 m .51727 .64096 L .59242 .63676 L p .692 .589 .736 r
F P
0 g
s
.59242 .63676 m .59527 .65394 L .51694 .65827 L p .692 .589 .736 r
F P
0 g
s
.43899 .65168 m .4425 .63457 L .51727 .64096 L p .728 .619 .736 r
F P
0 g
s
.5176 .62453 m .51727 .64096 L .4425 .63457 L p .727 .625 .745 r
F P
0 g
s
.51727 .64096 m .5176 .62453 L .58957 .62047 L p .692 .596 .744 r
F P
0 g
s
.58957 .62047 m .59242 .63676 L .51727 .64096 L p .692 .596 .744 r
F P
0 g
s
.4425 .63457 m .44599 .61834 L .5176 .62453 L p .727 .625 .745 r
F P
0 g
s
.51793 .61026 m .5176 .62453 L .44599 .61834 L p .722 .643 .769 r
F P
0 g
s
.5176 .62453 m .51793 .61026 L .58677 .60633 L p .692 .618 .769 r
F P
0 g
s
.58677 .60633 m .58957 .62047 L .5176 .62453 L p .692 .618 .769 r
F P
0 g
s
.59527 .65394 m .59242 .63676 L .66427 .62209 L p .654 .563 .74 r
F P
0 g
s
.66427 .62209 m .67023 .63881 L .59527 .65394 L p .654 .563 .74 r
F P
0 g
s
.59242 .63676 m .58957 .62047 L .65834 .60628 L p .656 .571 .748 r
F P
0 g
s
.65834 .60628 m .66427 .62209 L .59242 .63676 L p .656 .571 .748 r
F P
0 g
s
.4425 .63457 m .43899 .65168 L .36521 .63435 L p .762 .652 .741 r
F P
0 g
s
.44599 .61834 m .44945 .60429 L .51793 .61026 L p .722 .643 .769 r
F P
0 g
s
.51825 .59919 m .51793 .61026 L .44945 .60429 L p .71 .679 .819 r
F P
0 g
s
.51793 .61026 m .51825 .59919 L .584 .59542 L p .688 .661 .818 r
F P
0 g
s
.584 .59542 m .58677 .60633 L .51793 .61026 L p .688 .661 .818 r
F P
0 g
s
.58957 .62047 m .58677 .60633 L .65249 .59265 L p .659 .596 .773 r
F P
0 g
s
.65249 .59265 m .65834 .60628 L .58957 .62047 L p .659 .596 .773 r
F P
0 g
s
.36521 .63435 m .37179 .61777 L .4425 .63457 L p .762 .652 .741 r
F P
0 g
s
.44599 .61834 m .4425 .63457 L .37179 .61777 L p .759 .658 .75 r
F P
0 g
s
.37179 .61777 m .37834 .6021 L .44599 .61834 L p .759 .658 .75 r
F P
0 g
s
.44945 .60429 m .44599 .61834 L .37834 .6021 L p .751 .672 .774 r
F P
0 g
s
.58677 .60633 m .584 .59542 L .64673 .58226 L p .664 .646 .822 r
F P
0 g
s
.64673 .58226 m .65249 .59265 L .58677 .60633 L p .664 .646 .822 r
F P
0 g
s
.44945 .60429 m .45284 .59345 L .51825 .59919 L p .71 .679 .819 r
F P
0 g
s
.51856 .59203 m .51825 .59919 L .45284 .59345 L p .662 .745 .911 r
F P
0 g
s
.51825 .59919 m .51856 .59203 L .58129 .58842 L p .661 .744 .911 r
F P
0 g
s
.58129 .58842 m .584 .59542 L .51825 .59919 L p .661 .744 .911 r
F P
0 g
s
.37834 .6021 m .38481 .58862 L .44945 .60429 L p .751 .672 .774 r
F P
0 g
s
.45284 .59345 m .44945 .60429 L .38481 .58862 L p .729 .701 .823 r
F P
0 g
s
.584 .59542 m .58129 .58842 L .64109 .57582 L p .659 .743 .912 r
F P
0 g
s
.64109 .57582 m .64673 .58226 L .584 .59542 L p .659 .743 .912 r
F P
0 g
s
.38481 .58862 m .39116 .57839 L .45284 .59345 L p .729 .701 .823 r
F P
0 g
s
.45618 .58653 m .45284 .59345 L .39116 .57839 L p .663 .746 .912 r
F P
0 g
s
.45284 .59345 m .45618 .58653 L .51856 .59203 L p .662 .745 .911 r
F P
0 g
s
.51887 .58904 m .51856 .59203 L .45618 .58653 L p .427 .787 .996 r
F P
0 g
s
.45945 .58379 m .51887 .58904 L p .47411 .58725 L .427 .787 .996 r
F P
0 g
s
.45618 .58653 m .45945 .58379 L p .47411 .58725 L .427 .787 .996 r
F P
0 g
s
.40352 .57004 m .45945 .58379 L p .41522 .57547 L .403 .746 .993 r
F P
0 g
s
.39739 .57211 m .40352 .57004 L p .41522 .57547 L .403 .746 .993 r
F P
0 g
s
.40352 .57004 m .35421 .54833 L p .3852 .56154 L 0 .39 .745 r
F P
0 g
s
.45945 .58379 m .40352 .57004 L p .43657 .57839 L .234 0 0 r
F P
0 g
s
.45945 .58379 m .45618 .58653 L .39739 .57211 L p .403 .746 .993 r
F P
0 g
s
.40956 .57193 m .46269 .58499 L p .41512 .57297 L .234 0 0 r
F P
0 g
s
.40352 .57004 m .40956 .57193 L p .41512 .57297 L .234 0 0 r
F P
0 g
s
.40956 .57193 m .40352 .57004 L p .3852 .56154 L 0 .39 .745 r
F P
0 g
s
.40352 .57004 m .39739 .57211 L .34548 .54932 L p .406 .711 .985 r
F P
0 g
s
.34548 .54932 m .35421 .54833 L .40352 .57004 L p .406 .711 .985 r
F P
0 g
s
.36281 .55134 m .40956 .57193 L p .3651 .55297 L 0 .39 .745 r
F P
0 g
s
.35421 .54833 m .36281 .55134 L p .3651 .55297 L 0 .39 .745 r
F P
0 g
s
.32536 .52411 m .36281 .55134 L p .32411 .52586 L 0 .435 .853 r
F P
0 g
s
.31459 .51958 m .32536 .52411 L p .32411 .52586 L 0 .435 .853 r
F P
0 g
s
.32536 .52411 m .29994 .49158 L p .327 .52182 L 0 .256 .759 r
F P
0 g
s
.36281 .55134 m .32536 .52411 L p .3598 .54919 L .421 0 0 r
F P
0 g
s
.36281 .55134 m .35421 .54833 L .31459 .51958 L p 0 .435 .853 r
F P
0 g
s
.33605 .53193 m .37136 .5576 L p .33083 .52809 L .421 0 0 r
F P
0 g
s
.32536 .52411 m .33605 .53193 L p .33083 .52809 L .421 0 0 r
F P
0 g
s
.33659 .55456 m .34548 .54932 L .39739 .57211 L p .664 .748 .912 r
F P
0 g
s
.37994 .56592 m .37136 .5576 L .33605 .53193 L p .588 .042 0 r
F P
0 g
s
.33605 .53193 m .3122 .50131 L p .34212 .5364 L 0 .118 .646 r
F P
0 g
s
.34675 .54182 m .37994 .56592 L p .33714 .53278 L .588 .042 0 r
F P
0 g
s
.33605 .53193 m .34675 .54182 L p .33714 .53278 L .588 .042 0 r
F P
0 g
s
.35421 .54833 m .34548 .54932 L .30365 .5191 L p .428 .681 .969 r
F P
0 g
s
.30365 .5191 m .31459 .51958 L .35421 .54833 L p .428 .681 .969 r
F P
0 g
s
.39739 .57211 m .39116 .57839 L .33659 .55456 L p .664 .748 .912 r
F P
0 g
s
.38862 .57473 m .37994 .56592 L .34675 .54182 L p .612 .068 0 r
F P
0 g
s
.34675 .54182 m .35756 .55221 L .38862 .57473 L p .612 .068 0 r
F P
0 g
s
.34675 .54182 m .32446 .51314 L p .35673 .55122 L 0 .094 .625 r
F P
0 g
s
.35756 .55221 m .34675 .54182 L p .35673 .55122 L 0 .094 .625 r
F P
0 g
s
.34675 .54182 m .33605 .53193 L p .34212 .5364 L 0 .118 .646 r
F P
0 g
s
.33605 .53193 m .32536 .52411 L p .327 .52182 L 0 .256 .759 r
F P
0 g
s
.37136 .5576 m .36281 .55134 L p .3598 .54919 L .421 0 0 r
F P
0 g
s
.40956 .57193 m .36281 .55134 L p .40228 .57057 L .555 0 0 r
F P
0 g
s
.39116 .57839 m .39739 .57211 L .45618 .58653 L p .663 .746 .912 r
F P
0 g
s
.41558 .57705 m .40956 .57193 L p .40228 .57057 L .555 0 0 r
F P
0 g
s
.46269 .58499 m .45945 .58379 L p .43657 .57839 L .234 0 0 r
F P
0 g
s
.51887 .58904 m .45945 .58379 L p .49274 .58723 L .21 0 0 r
F P
0 g
s
.51856 .59203 m .51887 .58904 L p .53568 .59019 L .477 .83 .996 r
F P
0 g
s
.51918 .58997 m .51887 .58904 L p .49274 .58723 L .21 0 0 r
F P
0 g
s
.51887 .58904 m .57862 .58559 L p .53568 .59019 L .477 .83 .996 r
F P
0 g
s
.57862 .58559 m .58129 .58842 L .55739 .58979 L p .477 .83 .996 r
F P
0 g
s
.58129 .58842 m .57862 .58559 L .63554 .57357 L p .546 .869 .994 r
F P
0 g
s
.57862 .58559 m .57598 .5867 L .62127 .57714 L p 0 0 0 r
F P
0 g
s
.63554 .57357 m .64109 .57582 L .61822 .58064 L p .546 .869 .994 r
F P
0 g
s
.61822 .58064 m .58129 .58842 L p .63554 .57357 L .546 .869 .994 r
F P
0 g
s
.63006 .57528 m .63554 .57357 L .62238 .57635 L p 0 0 0 r
F P
0 g
s
.62238 .57635 m .57862 .58559 L p .63006 .57528 L 0 0 0 r
F P
0 g
s
.64109 .57582 m .63554 .57357 L .68648 .55345 L p .62 .895 .988 r
F P
0 g
s
.63006 .57528 m .62461 .58022 L .64095 .57377 L p .014 0 0 r
F P
0 g
s
.63554 .57357 m .63006 .57528 L .67049 .55931 L p .311 .792 .719 r
F P
0 g
s
.67049 .55931 m .67838 .55619 L p .63554 .57357 L .311 .792 .719 r
F P
0 g
s
.68648 .55345 m .69469 .5547 L .64109 .57582 L p .62 .895 .988 r
F P
0 g
s
.67838 .55619 m .68648 .55345 L .67466 .55812 L p .311 .792 .719 r
F P
0 g
s
.67466 .55812 m .63554 .57357 L p .67838 .55619 L .311 .792 .719 r
F P
0 g
s
.68648 .55345 m .67838 .55619 L .718 .53025 L p .569 .938 .835 r
F P
0 g
s
.67838 .55619 m .67033 .56219 L .68366 .55346 L p 0 0 0 r
F P
0 g
s
.68366 .55346 m .70771 .53772 L p .67838 .55619 L 0 0 0 r
F P
0 g
s
.64095 .57377 m .67033 .56219 L p .63006 .57528 L .014 0 0 r
F P
0 g
s
.62127 .57714 m .63006 .57528 L p .57862 .58559 L 0 0 0 r
F P
0 g
s
.55739 .58979 m .51856 .59203 L p .57862 .58559 L .477 .83 .996 r
F P
0 g
s
.67023 .63881 m .66427 .62209 L .72912 .5974 L p .612 .539 .748 r
F P
0 g
s
.72912 .5974 m .73799 .61332 L .67023 .63881 L p .612 .539 .748 r
F P
0 g
s
.66427 .62209 m .65834 .60628 L .7203 .58242 L p .615 .549 .757 r
F P
0 g
s
.7203 .58242 m .72912 .5974 L .66427 .62209 L p .615 .549 .757 r
F P
0 g
s
.65834 .60628 m .65249 .59265 L .7116 .56967 L p .624 .578 .782 r
F P
0 g
s
.7116 .56967 m .7203 .58242 L .65834 .60628 L p .624 .578 .782 r
F P
0 g
s
.37179 .61777 m .36521 .63435 L .29943 .6068 L p .795 .692 .751 r
F P
0 g
s
.65249 .59265 m .64673 .58226 L .70306 .56019 L p .64 .635 .83 r
F P
0 g
s
.70306 .56019 m .7116 .56967 L .65249 .59265 L p .64 .635 .83 r
F P
0 g
s
.29943 .6068 m .30888 .59109 L .37179 .61777 L p .795 .692 .751 r
F P
0 g
s
.37834 .6021 m .37179 .61777 L .30888 .59109 L p .791 .696 .76 r
F P
0 g
s
.30888 .59109 m .31826 .57633 L .37834 .6021 L p .791 .696 .76 r
F P
0 g
s
.38481 .58862 m .37834 .6021 L .31826 .57633 L p .778 .706 .784 r
F P
0 g
s
.51887 .58904 m .51918 .58997 L .57598 .5867 L p .109 0 0 r
F P
0 g
s
.57598 .5867 m .57862 .58559 L .51887 .58904 L p .109 0 0 r
F P
0 g
s
.31826 .57633 m .32751 .5638 L .38481 .58862 L p .778 .706 .784 r
F P
0 g
s
.39116 .57839 m .38481 .58862 L .32751 .5638 L p .747 .725 .832 r
F P
0 g
s
.64673 .58226 m .64109 .57582 L .69469 .5547 L p .658 .742 .912 r
F P
0 g
s
.69469 .5547 m .70306 .56019 L .64673 .58226 L p .658 .742 .912 r
F P
0 g
s
.32751 .5638 m .33659 .55456 L .39116 .57839 L p .747 .725 .832 r
F P
0 g
s
.45945 .58379 m .46269 .58499 L .51918 .58997 L p .21 0 0 r
F P
0 g
s
.51949 .59411 m .51918 .58997 L .46269 .58499 L p .509 0 0 r
F P
0 g
s
.51918 .58997 m .51949 .59411 L .57336 .59101 L p .409 0 0 r
F P
0 g
s
.57336 .59101 m .57598 .5867 L .51918 .58997 L p .409 0 0 r
F P
0 g
s
.57598 .5867 m .57336 .59101 L .62461 .58022 L p .254 0 0 r
F P
0 g
s
.62461 .58022 m .63006 .57528 L .57598 .5867 L p .254 0 0 r
F P
0 g
s
.46592 .58939 m .46269 .58499 L .40956 .57193 L p .565 .001 0 r
F P
0 g
s
.46269 .58499 m .46592 .58939 L .51949 .59411 L p .509 0 0 r
F P
0 g
s
.73799 .61332 m .72912 .5974 L .78317 .56355 L p .563 .518 .763 r
F P
0 g
s
.72912 .5974 m .7203 .58242 L .7718 .54976 L p .569 .53 .772 r
F P
0 g
s
.7718 .54976 m .78317 .56355 L .72912 .5974 L p .569 .53 .772 r
F P
0 g
s
.78317 .56355 m .79464 .57831 L .73799 .61332 L p .563 .518 .763 r
F P
0 g
s
.7203 .58242 m .7116 .56967 L .76059 .53825 L p .584 .563 .796 r
F P
0 g
s
.76059 .53825 m .7718 .54976 L .7203 .58242 L p .584 .563 .796 r
F P
0 g
s
.7116 .56967 m .70306 .56019 L .74962 .53007 L p .613 .628 .842 r
F P
0 g
s
.74962 .53007 m .76059 .53825 L .7116 .56967 L p .613 .628 .842 r
F P
0 g
s
.70306 .56019 m .69469 .5547 L .73888 .52593 L p .656 .742 .913 r
F P
0 g
s
.73888 .52593 m .74962 .53007 L .70306 .56019 L p .656 .742 .913 r
F P
0 g
s
.51979 .60026 m .51949 .59411 L .46592 .58939 L p .585 .094 .055 r
F P
0 g
s
.51949 .59411 m .51979 .60026 L .57072 .59734 L p .489 .017 .06 r
F P
0 g
s
.57072 .59734 m .57336 .59101 L .51949 .59411 L p .489 .017 .06 r
F P
0 g
s
.24558 .56996 m .25753 .55549 L .30888 .59109 L p .827 .738 .767 r
F P
0 g
s
.30888 .59109 m .29943 .6068 L .24558 .56996 L p .827 .738 .767 r
F P
0 g
s
.31826 .57633 m .30888 .59109 L .25753 .55549 L p .821 .74 .776 r
F P
0 g
s
.25753 .55549 m .26939 .542 L .31826 .57633 L p .821 .74 .776 r
F P
0 g
s
.32751 .5638 m .31826 .57633 L .26939 .542 L p .803 .746 .8 r
F P
0 g
s
.26939 .542 m .28105 .53078 L .32751 .5638 L p .803 .746 .8 r
F P
0 g
s
.33659 .55456 m .32751 .5638 L .28105 .53078 L p .761 .753 .845 r
F P
0 g
s
.67033 .56219 m .67838 .55619 L .63006 .57528 L p .014 0 0 r
F P
0 g
s
.57336 .59101 m .57072 .59734 L .61913 .58719 L p .352 0 .012 r
F P
0 g
s
.61913 .58719 m .62461 .58022 L .57336 .59101 L p .352 0 .012 r
F P
0 g
s
.69469 .5547 m .68648 .55345 L .72836 .52607 L p .686 .902 .973 r
F P
0 g
s
.72836 .52607 m .73888 .52593 L .69469 .5547 L p .686 .902 .973 r
F P
0 g
s
.28105 .53078 m .29248 .52292 L .33659 .55456 L p .761 .753 .845 r
F P
0 g
s
.34548 .54932 m .33659 .55456 L .29248 .52292 L p .665 .749 .913 r
F P
0 g
s
.40956 .57193 m .41558 .57705 L .46592 .58939 L p .565 .001 0 r
F P
0 g
s
.46916 .59582 m .46592 .58939 L .41558 .57705 L p .65 .131 0 r
F P
0 g
s
.46592 .58939 m .46916 .59582 L .51979 .60026 L p .585 .094 .055 r
F P
0 g
s
.29248 .52292 m .30365 .5191 L .34548 .54932 L p .665 .749 .913 r
F P
0 g
s
.718 .53025 m .72836 .52607 L .68648 .55345 L p .569 .938 .835 r
F P
0 g
s
.52011 .60688 m .51979 .60026 L .46916 .59582 L p .594 .111 .076 r
F P
0 g
s
.51979 .60026 m .52011 .60688 L .56804 .60414 L p .5 .035 .081 r
F P
0 g
s
.56804 .60414 m .57072 .59734 L .51979 .60026 L p .5 .035 .081 r
F P
0 g
s
.62461 .58022 m .61913 .58719 L .66225 .57023 L p .139 0 0 r
F P
0 g
s
.66225 .57023 m .67033 .56219 L .62461 .58022 L p .139 0 0 r
F P
0 g
s
.57072 .59734 m .56804 .60414 L .61357 .59463 L p .365 0 .035 r
F P
0 g
s
.61357 .59463 m .61913 .58719 L .57072 .59734 L p .365 0 .035 r
F P
0 g
s
.36281 .55134 m .37136 .5576 L .41558 .57705 L p .555 0 0 r
F P
0 g
s
.42162 .58421 m .41558 .57705 L .37136 .5576 L p .672 .123 0 r
F P
0 g
s
.41558 .57705 m .42162 .58421 L .46916 .59582 L p .65 .131 0 r
F P
0 g
s
.47245 .60272 m .46916 .59582 L .42162 .58421 L p .66 .15 .018 r
F P
0 g
s
.46916 .59582 m .47245 .60272 L .52011 .60688 L p .594 .111 .076 r
F P
0 g
s
.69741 .54725 m .70771 .53772 L .70681 .53831 L p 0 0 0 r
F P
0 g
s
.70681 .53831 m .67033 .56219 L p .69741 .54725 L 0 0 0 r
F P
0 g
s
.687 .55728 m .69741 .54725 L .66225 .57023 L p 0 0 0 r
F P
0 g
s
.69741 .54725 m .687 .55728 L .68763 .55656 L p .596 .883 .575 r
F P
0 g
s
.71295 .53356 m .67838 .55619 L p .70771 .53772 L 0 0 0 r
F P
0 g
s
.67033 .56219 m .66225 .57023 L .69741 .54725 L p 0 0 0 r
F P
0 g
s
.68763 .55656 m .71005 .53129 L p .69741 .54725 L .596 .883 .575 r
F P
0 g
s
.70771 .53772 m .69741 .54725 L .70148 .54267 L p .61 .897 .599 r
F P
0 g
s
.70148 .54267 m .72215 .5194 L p .70771 .53772 L .61 .897 .599 r
F P
0 g
s
.70771 .53772 m .718 .53025 L .71295 .53356 L p 0 0 0 r
F P
0 g
s
.78317 .56355 m .7718 .54976 L .80925 .50966 L p .514 .513 .793 r
F P
0 g
s
.7718 .54976 m .76059 .53825 L .79605 .49974 L p .539 .553 .817 r
F P
0 g
s
.79605 .49974 m .80925 .50966 L .7718 .54976 L p .539 .553 .817 r
F P
0 g
s
.61913 .58719 m .61357 .59463 L .65406 .57876 L p .157 0 0 r
F P
0 g
s
.65406 .57876 m .66225 .57023 L .61913 .58719 L p .157 0 0 r
F P
0 g
s
.76059 .53825 m .74962 .53007 L .78314 .49322 L p .585 .626 .859 r
F P
0 g
s
.78314 .49322 m .79605 .49974 L .76059 .53825 L p .585 .626 .859 r
F P
0 g
s
.52043 .6122 m .52011 .60688 L .47245 .60272 L p .552 .037 0 r
F P
0 g
s
.52011 .60688 m .52043 .6122 L .5653 .60965 L p .454 0 0 r
F P
0 g
s
.5653 .60965 m .56804 .60414 L .52011 .60688 L p .454 0 0 r
F P
0 g
s
.79464 .57831 m .78317 .56355 L .82268 .5219 L p .504 .499 .784 r
F P
0 g
s
.80925 .50966 m .82268 .5219 L .78317 .56355 L p .514 .513 .793 r
F P
0 g
s
.74962 .53007 m .73888 .52593 L .77055 .49079 L p .655 .742 .914 r
F P
0 g
s
.77055 .49079 m .78314 .49322 L .74962 .53007 L p .655 .742 .914 r
F P
0 g
s
.82268 .5219 m .83625 .53514 L .79464 .57831 L p .504 .499 .784 r
F P
0 g
s
.37136 .5576 m .37994 .56592 L .42162 .58421 L p .672 .123 0 r
F P
0 g
s
.42775 .59184 m .42162 .58421 L .37994 .56592 L p .687 .145 0 r
F P
0 g
s
.42162 .58421 m .42775 .59184 L .47245 .60272 L p .66 .15 .018 r
F P
0 g
s
.56804 .60414 m .5653 .60965 L .60789 .60077 L p .308 0 0 r
F P
0 g
s
.60789 .60077 m .61357 .59463 L .56804 .60414 L p .308 0 0 r
F P
0 g
s
.47582 .60832 m .47245 .60272 L .42775 .59184 L p .613 .071 0 r
F P
0 g
s
.47245 .60272 m .47582 .60832 L .52043 .6122 L p .552 .037 0 r
F P
0 g
s
.73888 .52593 m .72836 .52607 L .75823 .4927 L p .733 .891 .952 r
F P
0 g
s
.75823 .4927 m .77055 .49079 L .73888 .52593 L p .733 .891 .952 r
F P
0 g
s
.23529 .50057 m .24882 .49103 L .28105 .53078 L p .823 .792 .822 r
F P
0 g
s
.28105 .53078 m .26939 .542 L .23529 .50057 L p .823 .792 .822 r
F P
0 g
s
.29248 .52292 m .28105 .53078 L .24882 .49103 L p .771 .783 .863 r
F P
0 g
s
.22151 .51244 m .23529 .50057 L .26939 .542 L p .848 .793 .798 r
F P
0 g
s
.26939 .542 m .25753 .55549 L .22151 .51244 L p .848 .793 .798 r
F P
0 g
s
.24882 .49103 m .26204 .48489 L .29248 .52292 L p .771 .783 .863 r
F P
0 g
s
.30365 .5191 m .29248 .52292 L .26204 .48489 L p .665 .75 .914 r
F P
0 g
s
.20758 .52532 m .22151 .51244 L .25753 .55549 L p .856 .793 .789 r
F P
0 g
s
.25753 .55549 m .24558 .56996 L .20758 .52532 L p .856 .793 .789 r
F P
0 g
s
.72836 .52607 m .718 .53025 L .74612 .49869 L p .754 .989 .891 r
F P
0 g
s
.74612 .49869 m .75823 .4927 L .72836 .52607 L p .754 .989 .891 r
F P
0 g
s
.26204 .48489 m .27494 .48286 L .30365 .5191 L p .665 .75 .914 r
F P
0 g
s
.31459 .51958 m .30365 .5191 L .27494 .48286 L p .46 .658 .947 r
F P
0 g
s
.61357 .59463 m .60789 .60077 L .6457 .58599 L p .081 0 0 r
F P
0 g
s
.6457 .58599 m .65406 .57876 L .61357 .59463 L p .081 0 0 r
F P
0 g
s
.52075 .61444 m .52043 .6122 L .47582 .60832 L p .355 0 0 r
F P
0 g
s
.52043 .6122 m .52075 .61444 L .56247 .61207 L p .252 0 0 r
F P
0 g
s
.56247 .61207 m .5653 .60965 L .52043 .6122 L p .252 0 0 r
F P
0 g
s
.37994 .56592 m .38862 .57473 L .42775 .59184 L p .687 .145 0 r
F P
0 g
s
.43402 .59817 m .42775 .59184 L .38862 .57473 L p .62 .053 0 r
F P
0 g
s
.42775 .59184 m .43402 .59817 L .47582 .60832 L p .613 .071 0 r
F P
0 g
s
.5653 .60965 m .56247 .61207 L .60204 .60384 L p .079 0 0 r
F P
0 g
s
.60204 .60384 m .60789 .60077 L .5653 .60965 L p .079 0 0 r
F P
0 g
s
.66225 .57023 m .65406 .57876 L .687 .55728 L p 0 0 0 r
F P
0 g
s
.27494 .48286 m .28755 .48517 L .31459 .51958 L p .46 .658 .947 r
F P
0 g
s
.32536 .52411 m .31459 .51958 L .28755 .48517 L p .149 .473 .894 r
F P
0 g
s
.47928 .61084 m .47582 .60832 L .43402 .59817 L p .391 0 0 r
F P
0 g
s
.47582 .60832 m .47928 .61084 L .52075 .61444 L p .355 0 0 r
F P
0 g
s
.718 .53025 m .70771 .53772 L .73413 .508 L p .685 .962 .729 r
F P
0 g
s
.73413 .508 m .74612 .49869 L .718 .53025 L p .685 .962 .729 r
F P
0 g
s
.28755 .48517 m .29994 .49158 L .32536 .52411 L p .149 .473 .894 r
F P
0 g
s
.60789 .60077 m .60204 .60384 L .63712 .59013 L p 0 0 0 r
F P
0 g
s
.63712 .59013 m .6457 .58599 L .60789 .60077 L p 0 0 0 r
F P
0 g
s
.52109 .61205 m .52075 .61444 L .47928 .61084 L p .322 .758 .968 r
F P
0 g
s
.52075 .61444 m .52109 .61205 L .55956 .60986 L p .384 .811 .967 r
F P
0 g
s
.55956 .60986 m .56247 .61207 L .52075 .61444 L p .384 .811 .967 r
F P
0 g
s
.38862 .57473 m .39749 .58223 L .43402 .59817 L p .62 .053 0 r
F P
0 g
s
.44046 .60142 m .43402 .59817 L .39749 .58223 L p .34 0 0 r
F P
0 g
s
.43402 .59817 m .44046 .60142 L .47928 .61084 L p .391 0 0 r
F P
0 g
s
.56247 .61207 m .55956 .60986 L .59602 .60226 L p .477 .866 .973 r
F P
0 g
s
.59602 .60226 m .60204 .60384 L .56247 .61207 L p .477 .866 .973 r
F P
0 g
s
.72215 .5194 m .73413 .508 L .70771 .53772 L p .61 .897 .599 r
F P
0 g
s
.65406 .57876 m .6457 .58599 L .67637 .566 L p 0 0 0 r
F P
0 g
s
.67637 .566 m .687 .55728 L .65406 .57876 L p 0 0 0 r
F P
0 g
s
.48286 .60872 m .47928 .61084 L .44046 .60142 L p .3 .715 .974 r
F P
0 g
s
.47928 .61084 m .48286 .60872 L .52109 .61205 L p .322 .758 .968 r
F P
0 g
s
.51363 .42286 m .51746 .39918 L .52438 .39986 L p .733 .592 .699 r
F P
0 g
s
.52438 .39986 m .52402 .42387 L .51363 .42286 L p .733 .592 .699 r
F P
0 g
s
.52475 .38146 m .52438 .39986 L .51746 .39918 L p .728 .624 .742 r
F P
0 g
s
.52402 .42387 m .52438 .39986 L .53136 .39941 L p .689 .556 .698 r
F P
0 g
s
.52438 .39986 m .52475 .38146 L .52824 .38124 L p .692 .593 .741 r
F P
0 g
s
.52824 .38124 m .53136 .39941 L .52438 .39986 L p .692 .593 .741 r
F P
0 g
s
.53136 .39941 m .53448 .42321 L .52402 .42387 L p .689 .556 .698 r
F P
0 g
s
.53448 .42321 m .53136 .39941 L .53791 .39786 L p .642 .522 .702 r
F P
0 g
s
.53136 .39941 m .52824 .38124 L .53152 .38045 L p .652 .566 .746 r
F P
0 g
s
.53152 .38045 m .53791 .39786 L .53136 .39941 L p .652 .566 .746 r
F P
0 g
s
.50399 .42024 m .51105 .39741 L .51746 .39918 L p .775 .633 .703 r
F P
0 g
s
.51746 .39918 m .51363 .42286 L .50399 .42024 L p .775 .633 .703 r
F P
0 g
s
.52128 .38112 m .51746 .39918 L .51105 .39741 L p .763 .659 .747 r
F P
0 g
s
.51746 .39918 m .52128 .38112 L .52475 .38146 L p .728 .624 .742 r
F P
0 g
s
.50977 .45079 m .51363 .42286 L .52402 .42387 L p .735 .576 .677 r
F P
0 g
s
.52402 .42387 m .52365 .45211 L .50977 .45079 L p .735 .576 .677 r
F P
0 g
s
.52365 .45211 m .52402 .42387 L .53448 .42321 L p .688 .537 .677 r
F P
0 g
s
.39749 .58223 m .38862 .57473 L .35756 .55221 L p .51 0 0 r
F P
0 g
s
.53448 .42321 m .53763 .45124 L .52365 .45211 L p .688 .537 .677 r
F P
0 g
s
.53763 .45124 m .53448 .42321 L .54433 .42091 L p .636 .5 .68 r
F P
0 g
s
.53791 .39786 m .54433 .42091 L .53448 .42321 L p .642 .522 .702 r
F P
0 g
s
.49688 .44733 m .50399 .42024 L .51363 .42286 L p .78 .619 .681 r
F P
0 g
s
.51363 .42286 m .50977 .45079 L .49688 .44733 L p .78 .619 .681 r
F P
0 g
s
.54433 .42091 m .53791 .39786 L .54362 .39531 L p .587 .489 .709 r
F P
0 g
s
.53791 .39786 m .53152 .38045 L .53437 .37916 L p .608 .542 .755 r
F P
0 g
s
.53437 .37916 m .54362 .39531 L .53791 .39786 L p .608 .542 .755 r
F P
0 g
s
.49574 .41617 m .50557 .39466 L .51105 .39741 L p .818 .68 .712 r
F P
0 g
s
.51105 .39741 m .50399 .42024 L .49574 .41617 L p .818 .68 .712 r
F P
0 g
s
.51808 .38022 m .51105 .39741 L .50557 .39466 L p .797 .7 .757 r
F P
0 g
s
.51105 .39741 m .51808 .38022 L .52128 .38112 L p .763 .659 .747 r
F P
0 g
s
.29994 .49158 m .3122 .50131 L .33605 .53193 L p 0 .256 .759 r
F P
0 g
s
.52511 .36958 m .52475 .38146 L .52128 .38112 L closepath p .705 .688 .831 r
F P
0 g
s
.52511 .36958 m .52824 .38124 L .52475 .38146 L closepath p .686 .672 .831 r
F P
0 g
s
.52511 .36958 m .53152 .38045 L .52824 .38124 L closepath p .665 .659 .834 r
F P
0 g
s
.52511 .36958 m .52128 .38112 L .51808 .38022 L closepath p .723 .707 .835 r
F P
0 g
s
.52511 .36958 m .53437 .37916 L .53152 .38045 L closepath p .643 .65 .841 r
F P
0 g
s
.50557 .39466 m .51534 .37884 L .51808 .38022 L p .797 .7 .757 r
F P
0 g
s
.52511 .36958 m .51808 .38022 L .51534 .37884 L closepath p .738 .729 .843 r
F P
0 g
s
.54433 .42091 m .55079 .44822 L .53763 .45124 L p .636 .5 .68 r
F P
0 g
s
.55079 .44822 m .54433 .42091 L .55292 .41712 L p .576 .462 .686 r
F P
0 g
s
.54362 .39531 m .55292 .41712 L .54433 .42091 L p .587 .489 .709 r
F P
0 g
s
.50589 .48115 m .50977 .45079 L .52365 .45211 L p .735 .569 .668 r
F P
0 g
s
.52365 .45211 m .52328 .48279 L .50589 .48115 L p .735 .569 .668 r
F P
0 g
s
.52328 .48279 m .52365 .45211 L .53763 .45124 L p .687 .529 .667 r
F P
0 g
s
.52144 .60387 m .52109 .61205 L .48286 .60872 L p .669 .742 .905 r
F P
0 g
s
.52109 .61205 m .52144 .60387 L .55656 .60187 L p .663 .737 .905 r
F P
0 g
s
.55656 .60187 m .55956 .60986 L .52109 .61205 L p .663 .737 .905 r
F P
0 g
s
.48583 .44197 m .49574 .41617 L .50399 .42024 L p .827 .669 .688 r
F P
0 g
s
.50399 .42024 m .49688 .44733 L .48583 .44197 L p .827 .669 .688 r
F P
0 g
s
.55292 .41712 m .54362 .39531 L .54809 .39192 L p .52 .454 .722 r
F P
0 g
s
.54362 .39531 m .53437 .37916 L .53659 .37746 L p .557 .52 .77 r
F P
0 g
s
.53659 .37746 m .54809 .39192 L .54362 .39531 L p .557 .52 .77 r
F P
0 g
s
.52511 .36958 m .53659 .37746 L .53437 .37916 L closepath p .62 .644 .852 r
F P
0 g
s
.53763 .45124 m .5408 .48171 L .52328 .48279 L p .687 .529 .667 r
F P
0 g
s
.5408 .48171 m .53763 .45124 L .55079 .44822 L p .634 .49 .67 r
F P
0 g
s
.5014 .39113 m .51327 .37706 L .51534 .37884 L p .83 .748 .774 r
F P
0 g
s
.51534 .37884 m .50557 .39466 L .5014 .39113 L p .83 .748 .774 r
F P
0 g
s
.52511 .36958 m .51534 .37884 L .51327 .37706 L closepath p .749 .753 .855 r
F P
0 g
s
.48944 .41092 m .5014 .39113 L .50557 .39466 L p .862 .738 .725 r
F P
0 g
s
.50557 .39466 m .49574 .41617 L .48944 .41092 L p .862 .738 .725 r
F P
0 g
s
.79605 .49974 m .78314 .49322 L .80068 .45152 L p .556 .629 .88 r
F P
0 g
s
.78314 .49322 m .77055 .49079 L .78692 .45112 L p .654 .743 .915 r
F P
0 g
s
.78692 .45112 m .80068 .45152 L .78314 .49322 L p .654 .743 .915 r
F P
0 g
s
.80925 .50966 m .79605 .49974 L .81481 .45607 L p .486 .547 .845 r
F P
0 g
s
.80068 .45152 m .81481 .45607 L .79605 .49974 L p .556 .629 .88 r
F P
0 g
s
.48971 .4769 m .49688 .44733 L .50977 .45079 L p .782 .613 .671 r
F P
0 g
s
.50977 .45079 m .50589 .48115 L .48971 .4769 L p .782 .613 .671 r
F P
0 g
s
.60204 .60384 m .59602 .60226 L .62828 .58962 L p .58 .909 .978 r
F P
0 g
s
.62828 .58962 m .63712 .59013 L .60204 .60384 L p .58 .909 .978 r
F P
0 g
s
.54809 .39192 m .53659 .37746 L .53804 .37544 L p .493 .499 .791 r
F P
0 g
s
.52511 .36958 m .53804 .37544 L .53659 .37746 L closepath p .597 .643 .867 r
F P
0 g
s
.55956 .60986 m .55656 .60187 L .58982 .59489 L p .657 .733 .906 r
F P
0 g
s
.58982 .59489 m .59602 .60226 L .55956 .60986 L p .657 .733 .906 r
F P
0 g
s
.49882 .38704 m .512 .375 L .51327 .37706 L p .859 .806 .797 r
F P
0 g
s
.51327 .37706 m .5014 .39113 L .49882 .38704 L p .859 .806 .797 r
F P
0 g
s
.52511 .36958 m .51327 .37706 L .512 .375 L closepath p .757 .778 .871 r
F P
0 g
s
.82268 .5219 m .80925 .50966 L .8293 .46407 L p .445 .499 .821 r
F P
0 g
s
.81481 .45607 m .8293 .46407 L .80925 .50966 L p .486 .547 .845 r
F P
0 g
s
.77055 .49079 m .75823 .4927 L .7735 .4551 L p .761 .867 .926 r
F P
0 g
s
.7735 .4551 m .78692 .45112 L .77055 .49079 L p .761 .867 .926 r
F P
0 g
s
.55292 .41712 m .56229 .44323 L .55079 .44822 L p .576 .462 .686 r
F P
0 g
s
.56229 .44323 m .55292 .41712 L .55966 .41209 L p .501 .419 .696 r
F P
0 g
s
.54809 .39192 m .55966 .41209 L .55292 .41712 L p .52 .454 .722 r
F P
0 g
s
.55079 .44822 m .55731 .47799 L .5408 .48171 L p .634 .49 .67 r
F P
0 g
s
.55731 .47799 m .55079 .44822 L .56229 .44323 L p .572 .45 .675 r
F P
0 g
s
.55966 .41209 m .54809 .39192 L .55101 .38792 L p .431 .413 .739 r
F P
0 g
s
.53804 .37544 m .55101 .38792 L .54809 .39192 L p .493 .499 .791 r
F P
0 g
s
.71005 .53129 m .72215 .5194 L .69741 .54725 L p .596 .883 .575 r
F P
0 g
s
.39749 .58223 m .4066 .58666 L .44046 .60142 L p .34 0 0 r
F P
0 g
s
.44709 .60003 m .44046 .60142 L .4066 .58666 L p .315 .681 .977 r
F P
0 g
s
.44046 .60142 m .44709 .60003 L .48286 .60872 L p .3 .715 .974 r
F P
0 g
s
.48654 .60082 m .48286 .60872 L .44709 .60003 L p .673 .747 .906 r
F P
0 g
s
.48286 .60872 m .48654 .60082 L .52144 .60387 L p .669 .742 .905 r
F P
0 g
s
.50198 .51191 m .50589 .48115 L .52328 .48279 L p .735 .569 .667 r
F P
0 g
s
.52328 .48279 m .52291 .51385 L .50198 .51191 L p .735 .569 .667 r
F P
0 g
s
.52291 .51385 m .52328 .48279 L .5408 .48171 L p .686 .529 .667 r
F P
0 g
s
.55101 .38792 m .53804 .37544 L .53861 .37326 L p .411 .479 .82 r
F P
0 g
s
.52511 .36958 m .53861 .37326 L .53804 .37544 L closepath p .573 .647 .886 r
F P
0 g
s
.47735 .43504 m .48944 .41092 L .49574 .41617 L p .876 .731 .698 r
F P
0 g
s
.49574 .41617 m .48583 .44197 L .47735 .43504 L p .876 .731 .698 r
F P
0 g
s
.48552 .40482 m .49882 .38704 L .5014 .39113 L p .905 .81 .743 r
F P
0 g
s
.5014 .39113 m .48944 .41092 L .48552 .40482 L p .905 .81 .743 r
F P
0 g
s
.47582 .47028 m .48583 .44197 L .49688 .44733 L p .83 .664 .677 r
F P
0 g
s
.49688 .44733 m .48971 .4769 L .47582 .47028 L p .83 .664 .677 r
F P
0 g
s
.52511 .36958 m .53495 .36719 L .53701 .36899 L closepath p .515 .696 .951 r
F P
0 g
s
.52511 .36958 m .53221 .36579 L .53495 .36719 L closepath p .509 .725 .97 r
F P
0 g
s
.52511 .36958 m .52898 .36488 L .53221 .36579 L closepath p .517 .757 .983 r
F P
0 g
s
.52511 .36958 m .52548 .36453 L .52898 .36488 L closepath p .539 .791 .991 r
F P
0 g
s
.52511 .36958 m .52196 .36476 L .52548 .36453 L closepath p .575 .822 .991 r
F P
0 g
s
.52511 .36958 m .51866 .36556 L .52196 .36476 L closepath p .62 .845 .986 r
F P
0 g
s
.52511 .36958 m .5158 .36686 L .51866 .36556 L closepath p .665 .858 .973 r
F P
0 g
s
.52511 .36958 m .51358 .36859 L .5158 .36686 L closepath p .705 .859 .956 r
F P
0 g
s
.52511 .36958 m .51216 .37062 L .51358 .36859 L closepath p .734 .848 .934 r
F P
0 g
s
.52511 .36958 m .51162 .3728 L .51216 .37062 L closepath p .751 .828 .912 r
F P
0 g
s
.52511 .36958 m .512 .375 L .51162 .3728 L closepath p .758 .804 .89 r
F P
0 g
s
.52511 .36958 m .53826 .37106 L .53861 .37326 L closepath p .55 .657 .907 r
F P
0 g
s
.52511 .36958 m .53701 .36899 L .53826 .37106 L closepath p .529 .674 .929 r
F P
0 g
s
.49803 .38265 m .51162 .3728 L .512 .375 L p .88 .874 .826 r
F P
0 g
s
.512 .375 m .49882 .38704 L .49803 .38265 L p .88 .874 .826 r
F P
0 g
s
.6457 .58599 m .63712 .59013 L .66548 .57163 L p .486 .885 .73 r
F P
0 g
s
.66548 .57163 m .67637 .566 L .6457 .58599 L p .486 .885 .73 r
F P
0 g
s
.5408 .48171 m .54398 .51257 L .52291 .51385 L p .686 .529 .667 r
F P
0 g
s
.54398 .51257 m .5408 .48171 L .55731 .47799 L p .633 .49 .669 r
F P
0 g
s
.4825 .50688 m .48971 .4769 L .50589 .48115 L p .782 .613 .67 r
F P
0 g
s
.50589 .48115 m .50198 .51191 L .4825 .50688 L p .782 .613 .67 r
F P
0 g
s
.83625 .53514 m .82268 .5219 L .84408 .47443 L p .429 .481 .812 r
F P
0 g
s
.8293 .46407 m .84408 .47443 L .82268 .5219 L p .445 .499 .821 r
F P
0 g
s
.53861 .37326 m .55219 .38357 L .55101 .38792 L p .411 .479 .82 r
F P
0 g
s
.55219 .38357 m .53861 .37326 L .53826 .37106 L p .299 .458 .851 r
F P
0 g
s
.49908 .37828 m .51216 .37062 L .51162 .3728 L p .874 .947 .857 r
F P
0 g
s
.51162 .3728 m .49803 .38265 L .49908 .37828 L p .874 .947 .857 r
F P
0 g
s
.55101 .38792 m .5641 .40613 L .55966 .41209 L p .431 .413 .739 r
F P
0 g
s
.5641 .40613 m .55101 .38792 L .55219 .38357 L p .299 .361 .758 r
F P
0 g
s
.5218 .58942 m .52144 .60387 L .48654 .60082 L p .72 .656 .785 r
F P
0 g
s
.52144 .60387 m .5218 .58942 L .55349 .58759 L p .69 .631 .785 r
F P
0 g
s
.55349 .58759 m .55656 .60187 L .52144 .60387 L p .69 .631 .785 r
F P
0 g
s
.75823 .4927 m .74612 .49869 L .76034 .46321 L p .839 .958 .888 r
F P
0 g
s
.76034 .46321 m .7735 .4551 L .75823 .4927 L p .839 .958 .888 r
F P
0 g
s
.55966 .41209 m .57136 .43659 L .56229 .44323 L p .501 .419 .696 r
F P
0 g
s
.57136 .43659 m .55966 .41209 L .5641 .40613 L p .396 .366 .708 r
F P
0 g
s
.53826 .37106 m .55152 .37918 L .55219 .38357 L p .299 .458 .851 r
F P
0 g
s
.55152 .37918 m .53826 .37106 L .53701 .36899 L p .143 .431 .869 r
F P
0 g
s
.48428 .39828 m .49803 .38265 L .49882 .38704 L p .937 .897 .762 r
F P
0 g
s
.49882 .38704 m .48552 .40482 L .48428 .39828 L p .937 .897 .762 r
F P
0 g
s
.49806 .54096 m .50198 .51191 L .52291 .51385 L p .735 .574 .674 r
F P
0 g
s
.52291 .51385 m .52254 .54318 L .49806 .54096 L p .735 .574 .674 r
F P
0 g
s
.52254 .54318 m .52291 .51385 L .54398 .51257 L p .687 .535 .674 r
F P
0 g
s
.56229 .44323 m .57176 .47183 L .55731 .47799 L p .572 .45 .675 r
F P
0 g
s
.57176 .47183 m .56229 .44323 L .57136 .43659 L p .492 .404 .684 r
F P
0 g
s
.50192 .37422 m .51358 .36859 L .51216 .37062 L p .805 .994 .868 r
F P
0 g
s
.51216 .37062 m .49908 .37828 L .50192 .37422 L p .805 .994 .868 r
F P
0 g
s
.55731 .47799 m .56387 .50817 L .54398 .51257 L p .633 .49 .669 r
F P
0 g
s
.56387 .50817 m .55731 .47799 L .57176 .47183 L p .571 .449 .674 r
F P
0 g
s
.35756 .55221 m .36859 .56129 L .39749 .58223 L p .51 0 0 r
F P
0 g
s
.4066 .58666 m .39749 .58223 L .36859 .56129 L p 0 .325 .762 r
F P
0 g
s
.47205 .42697 m .48552 .40482 L .48944 .41092 L p .925 .808 .711 r
F P
0 g
s
.48944 .41092 m .47735 .43504 L .47205 .42697 L p .925 .808 .711 r
F P
0 g
s
.3122 .50131 m .32446 .51314 L .34675 .54182 L p 0 .118 .646 r
F P
0 g
s
.23386 .44658 m .24814 .44247 L .26204 .48489 L p .774 .813 .884 r
F P
0 g
s
.26204 .48489 m .24882 .49103 L .23386 .44658 L p .774 .813 .884 r
F P
0 g
s
.27494 .48286 m .26204 .48489 L .24814 .44247 L p .664 .752 .915 r
F P
0 g
s
.84408 .47443 m .85906 .48583 L .83625 .53514 L p .429 .481 .812 r
F P
0 g
s
.54398 .51257 m .54717 .54172 L .52254 .54318 L p .687 .535 .674 r
F P
0 g
s
.54717 .54172 m .54398 .51257 L .56387 .50817 L p .635 .497 .676 r
F P
0 g
s
.46512 .46171 m .47735 .43504 L .48583 .44197 L p .881 .727 .686 r
F P
0 g
s
.48583 .44197 m .47582 .47028 L .46512 .46171 L p .881 .727 .686 r
F P
0 g
s
.55656 .60187 m .55349 .58759 L .58346 .58125 L p .657 .609 .789 r
F P
0 g
s
.58346 .58125 m .58982 .59489 L .55656 .60187 L p .657 .609 .789 r
F P
0 g
s
.21921 .45415 m .23386 .44658 L .24882 .49103 L p .836 .843 .851 r
F P
0 g
s
.24882 .49103 m .23529 .50057 L .21921 .45415 L p .836 .843 .851 r
F P
0 g
s
.46572 .49905 m .47582 .47028 L .48971 .4769 L p .831 .664 .676 r
F P
0 g
s
.48971 .4769 m .4825 .50688 L .46572 .49905 L p .831 .664 .676 r
F P
0 g
s
.53701 .36899 m .54904 .37503 L .55152 .37918 L p .143 .431 .869 r
F P
0 g
s
.54904 .37503 m .53701 .36899 L .53495 .36719 L p 0 .389 .835 r
F P
0 g
s
.47526 .53518 m .4825 .50688 L .50198 .51191 L p .781 .617 .677 r
F P
0 g
s
.50198 .51191 m .49806 .54096 L .47526 .53518 L p .781 .617 .677 r
F P
0 g
s
.50636 .37076 m .5158 .36686 L .51358 .36859 L p .619 .956 .817 r
F P
0 g
s
.51358 .36859 m .50192 .37422 L .50636 .37076 L p .619 .956 .817 r
F P
0 g
s
.59602 .60226 m .58982 .59489 L .6192 .58331 L p .65 .731 .908 r
F P
0 g
s
.6192 .58331 m .62828 .58962 L .59602 .60226 L p .65 .731 .908 r
F P
0 g
s
.44709 .60003 m .45393 .59285 L .48654 .60082 L p .673 .747 .906 r
F P
0 g
s
.49032 .58664 m .48654 .60082 L .45393 .59285 L p .749 .686 .791 r
F P
0 g
s
.48654 .60082 m .49032 .58664 L .5218 .58942 L p .72 .656 .785 r
F P
0 g
s
.24814 .44247 m .26204 .44252 L .27494 .48286 L p .664 .752 .915 r
F P
0 g
s
.28755 .48517 m .27494 .48286 L .26204 .44252 L p .497 .643 .921 r
F P
0 g
s
.55219 .38357 m .56592 .39965 L .5641 .40613 L p .299 .361 .758 r
F P
0 g
s
.56592 .39965 m .55219 .38357 L .55152 .37918 L p .09 .28 .762 r
F P
0 g
s
.49417 .56638 m .49806 .54096 L .52254 .54318 L p .734 .587 .691 r
F P
0 g
s
.52254 .54318 m .52217 .56888 L .49417 .56638 L p .734 .587 .691 r
F P
0 g
s
.52217 .56888 m .52254 .54318 L .54717 .54172 L p .689 .549 .691 r
F P
0 g
s
.53495 .36719 m .54491 .37142 L .54904 .37503 L p 0 .389 .835 r
F P
0 g
s
.54491 .37142 m .53495 .36719 L .53221 .36579 L p 0 .337 .719 r
F P
0 g
s
.52217 .56888 m .5218 .58942 L .49032 .58664 L p .731 .611 .724 r
F P
0 g
s
.5218 .58942 m .52217 .56888 L .55035 .56723 L p .691 .577 .723 r
F P
0 g
s
.55035 .56723 m .55349 .58759 L .5218 .58942 L p .691 .577 .723 r
F P
0 g
s
.20426 .46408 m .21921 .45415 L .23529 .50057 L p .867 .855 .828 r
F P
0 g
s
.23529 .50057 m .22151 .51244 L .20426 .46408 L p .867 .855 .828 r
F P
0 g
s
.51211 .36813 m .51866 .36556 L .5158 .36686 L p .332 .797 .689 r
F P
0 g
s
.5158 .36686 m .50636 .37076 L .51211 .36813 L p .332 .797 .689 r
F P
0 g
s
.48582 .39173 m .49908 .37828 L .49803 .38265 L p .916 .979 .757 r
F P
0 g
s
.49803 .38265 m .48428 .39828 L .48582 .39173 L p .916 .979 .757 r
F P
0 g
s
.4066 .58666 m .41597 .58641 L .44709 .60003 L p .315 .681 .977 r
F P
0 g
s
.45393 .59285 m .44709 .60003 L .41597 .58641 L p .677 .754 .909 r
F P
0 g
s
.53221 .36579 m .5394 .3686 L .54491 .37142 L p 0 .337 .719 r
F P
0 g
s
.5394 .3686 m .53221 .36579 L .52898 .36488 L p .292 0 0 r
F P
0 g
s
.49032 .58664 m .49417 .56638 L .52217 .56888 L p .731 .611 .724 r
F P
0 g
s
.54717 .54172 m .55035 .56723 L .52217 .56888 L p .689 .549 .691 r
F P
0 g
s
.55035 .56723 m .54717 .54172 L .57044 .53666 L p .64 .514 .694 r
F P
0 g
s
.56387 .50817 m .57044 .53666 L .54717 .54172 L p .635 .497 .676 r
F P
0 g
s
.51876 .36652 m .52196 .36476 L .51866 .36556 L p 0 0 0 r
F P
0 g
s
.51866 .36556 m .51211 .36813 L .51876 .36652 L p 0 0 0 r
F P
0 g
s
.5641 .40613 m .57736 .42872 L .57136 .43659 L p .396 .366 .708 r
F P
0 g
s
.57736 .42872 m .5641 .40613 L .56592 .39965 L p .233 .289 .717 r
F P
0 g
s
.55349 .58759 m .55035 .56723 L .57699 .56153 L p .647 .547 .727 r
F P
0 g
s
.57699 .56153 m .58346 .58125 L .55349 .58759 L p .647 .547 .727 r
F P
0 g
s
.52898 .36488 m .5329 .36677 L .5394 .3686 L p .292 0 0 r
F P
0 g
s
.5329 .36677 m .52898 .36488 L .52548 .36453 L p .263 0 0 r
F P
0 g
s
.46806 .55986 m .47526 .53518 L .49806 .54096 L p .778 .628 .695 r
F P
0 g
s
.49806 .54096 m .49417 .56638 L .46806 .55986 L p .778 .628 .695 r
F P
0 g
s
.52586 .36606 m .52548 .36453 L .52196 .36476 L p .147 0 0 r
F P
0 g
s
.52196 .36476 m .51876 .36652 L .52586 .36606 L p .147 0 0 r
F P
0 g
s
.57044 .53666 m .56387 .50817 L .5813 .50089 L p .575 .458 .682 r
F P
0 g
s
.57176 .47183 m .5813 .50089 L .56387 .50817 L p .571 .449 .674 r
F P
0 g
s
.52548 .36453 m .52586 .36606 L .5329 .36677 L p .263 0 0 r
F P
0 g
s
.74612 .49869 m .73413 .508 L .74733 .47466 L p .869 .992 .816 r
F P
0 g
s
.74733 .47466 m .76034 .46321 L .74612 .49869 L p .869 .992 .816 r
F P
0 g
s
.5813 .50089 m .57176 .47183 L .58319 .46363 L p .491 .402 .683 r
F P
0 g
s
.57136 .43659 m .58319 .46363 L .57176 .47183 L p .492 .404 .684 r
F P
0 g
s
.58319 .46363 m .57136 .43659 L .57736 .42872 L p .38 .344 .693 r
F P
0 g
s
.45393 .59285 m .46093 .57939 L .49032 .58664 L p .749 .686 .791 r
F P
0 g
s
.49417 .56638 m .49032 .58664 L .46093 .57939 L p .77 .649 .729 r
F P
0 g
s
.57044 .53666 m .57699 .56153 L .55035 .56723 L p .64 .514 .694 r
F P
0 g
s
.47031 .4183 m .48428 .39828 L .48552 .40482 L p .962 .901 .716 r
F P
0 g
s
.48552 .40482 m .47205 .42697 L .47031 .4183 L p .962 .901 .716 r
F P
0 g
s
.687 .55728 m .67637 .566 L .69774 .54187 L p .65 .933 .668 r
F P
0 g
s
.69774 .54187 m .71005 .53129 L .687 .55728 L p .65 .933 .668 r
F P
0 g
s
.26204 .44252 m .27559 .44697 L .28755 .48517 L p .497 .643 .921 r
F P
0 g
s
.29994 .49158 m .28755 .48517 L .27559 .44697 L p .297 .497 .883 r
F P
0 g
s
.45559 .52616 m .46572 .49905 L .4825 .50688 L p .828 .668 .684 r
F P
0 g
s
.4825 .50688 m .47526 .53518 L .45559 .52616 L p .828 .668 .684 r
F P
0 g
s
.18911 .47507 m .20426 .46408 L .22151 .51244 L p .878 .859 .818 r
F P
0 g
s
.22151 .51244 m .20758 .52532 L .18911 .47507 L p .878 .859 .818 r
F P
0 g
s
.55152 .37918 m .56496 .39307 L .56592 .39965 L p .09 .28 .762 r
F P
0 g
s
.56496 .39307 m .55152 .37918 L .54904 .37503 L p 0 .146 .685 r
F P
0 g
s
.63712 .59013 m .62828 .58962 L .65429 .57259 L p .672 .927 .972 r
F P
0 g
s
.65429 .57259 m .66548 .57163 L .63712 .59013 L p .672 .927 .972 r
F P
0 g
s
.46093 .57939 m .46806 .55986 L .49417 .56638 L p .77 .649 .729 r
F P
0 g
s
.45838 .45172 m .47205 .42697 L .47735 .43504 L p .934 .806 .695 r
F P
0 g
s
.47735 .43504 m .46512 .46171 L .45838 .45172 L p .934 .806 .695 r
F P
0 g
s
.45276 .48888 m .46512 .46171 L .47582 .47028 L p .882 .726 .685 r
F P
0 g
s
.47582 .47028 m .46572 .49905 L .45276 .48888 L p .882 .726 .685 r
F P
0 g
s
.49006 .38564 m .50192 .37422 L .49908 .37828 L p .725 .95 .65 r
F P
0 g
s
.49908 .37828 m .48582 .39173 L .49006 .38564 L p .725 .95 .65 r
F P
0 g
s
.58982 .59489 m .58346 .58125 L .6099 .57072 L p .621 .591 .799 r
F P
0 g
s
.6099 .57072 m .6192 .58331 L .58982 .59489 L p .621 .591 .799 r
F P
0 g
s
.57699 .56153 m .57044 .53666 L .59088 .52828 L p .583 .479 .701 r
F P
0 g
s
.5813 .50089 m .59088 .52828 L .57044 .53666 L p .575 .458 .682 r
F P
0 g
s
.41597 .58641 m .4256 .58039 L .45393 .59285 L p .677 .754 .909 r
F P
0 g
s
.46093 .57939 m .45393 .59285 L .4256 .58039 L p .775 .721 .801 r
F P
0 g
s
.36859 .56129 m .37989 .56728 L .4066 .58666 L p 0 .325 .762 r
F P
0 g
s
.41597 .58641 m .4066 .58666 L .37989 .56728 L p .355 .655 .969 r
F P
0 g
s
.54904 .37503 m .56126 .38685 L .56496 .39307 L p 0 .146 .685 r
F P
0 g
s
.56126 .38685 m .54904 .37503 L .54491 .37142 L p .541 .018 0 r
F P
0 g
s
.56592 .39965 m .57986 .42012 L .57736 .42872 L p .233 .289 .717 r
F P
0 g
s
.57986 .42012 m .56592 .39965 L .56496 .39307 L p 0 .162 .689 r
F P
0 g
s
.44547 .54968 m .45559 .52616 L .47526 .53518 L p .822 .677 .703 r
F P
0 g
s
.47526 .53518 m .46806 .55986 L .44547 .54968 L p .822 .677 .703 r
F P
0 g
s
.49675 .38043 m .50636 .37076 L .50192 .37422 L p 0 0 0 r
F P
0 g
s
.50192 .37422 m .49006 .38564 L .49675 .38043 L p 0 0 0 r
F P
0 g
s
.32446 .51314 m .33682 .52546 L .35756 .55221 L p 0 .094 .625 r
F P
0 g
s
.36859 .56129 m .35756 .55221 L .33682 .52546 L p 0 .189 .706 r
F P
0 g
s
.58346 .58125 m .57699 .56153 L .60043 .55207 L p .598 .518 .736 r
F P
0 g
s
.60043 .55207 m .6099 .57072 L .58346 .58125 L p .598 .518 .736 r
F P
0 g
s
.59088 .52828 m .60043 .55207 L .57699 .56153 L p .583 .479 .701 r
F P
0 g
s
.47231 .40961 m .48582 .39173 L .48428 .39828 L p .916 .969 .67 r
F P
0 g
s
.48428 .39828 m .47031 .4183 L .47231 .40961 L p .916 .969 .67 r
F P
0 g
s
.59088 .52828 m .5813 .50089 L .59514 .49116 L p .498 .414 .692 r
F P
0 g
s
.58319 .46363 m .59514 .49116 L .5813 .50089 L p .491 .402 .683 r
F P
0 g
s
.27559 .44697 m .28887 .45554 L .29994 .49158 L p .297 .497 .883 r
F P
0 g
s
.3122 .50131 m .29994 .49158 L .28887 .45554 L p .122 .358 .82 r
F P
0 g
s
.57736 .42872 m .5908 .45388 L .58319 .46363 L p .38 .344 .693 r
F P
0 g
s
.5908 .45388 m .57736 .42872 L .57986 .42012 L p .201 .256 .696 r
F P
0 g
s
.4256 .58039 m .43545 .56807 L .46093 .57939 L p .775 .721 .801 r
F P
0 g
s
.46806 .55986 m .46093 .57939 L .43545 .56807 L p .808 .694 .738 r
F P
0 g
s
.43545 .56807 m .44547 .54968 L .46806 .55986 L p .808 .694 .738 r
F P
0 g
s
.73413 .508 m .72215 .5194 L .73435 .48821 L p .871 .994 .758 r
F P
0 g
s
.73435 .48821 m .74733 .47466 L .73413 .508 L p .871 .994 .758 r
F P
0 g
s
.54491 .37142 m .55505 .38142 L .56126 .38685 L p .541 .018 0 r
F P
0 g
s
.55505 .38142 m .54491 .37142 L .5394 .3686 L p .666 .114 0 r
F P
0 g
s
.59514 .49116 m .58319 .46363 L .5908 .45388 L p .378 .342 .692 r
F P
0 g
s
.44033 .51443 m .45276 .48888 L .46572 .49905 L p .878 .729 .694 r
F P
0 g
s
.46572 .49905 m .45559 .52616 L .44033 .51443 L p .878 .729 .694 r
F P
0 g
s
.50542 .37647 m .51211 .36813 L .50636 .37076 L p .068 0 0 r
F P
0 g
s
.50636 .37076 m .49675 .38043 L .50542 .37647 L p .068 0 0 r
F P
0 g
s
.62828 .58962 m .6192 .58331 L .64281 .56774 L p .643 .73 .912 r
F P
0 g
s
.64281 .56774 m .65429 .57259 L .62828 .58962 L p .643 .73 .912 r
F P
0 g
s
.45611 .44095 m .47031 .4183 L .47205 .42697 L p .971 .901 .693 r
F P
0 g
s
.47205 .42697 m .45838 .45172 L .45611 .44095 L p .971 .901 .693 r
F P
0 g
s
.44454 .477 m .45838 .45172 L .46512 .46171 L p .934 .806 .694 r
F P
0 g
s
.46512 .46171 m .45276 .48888 L .44454 .477 L p .934 .806 .694 r
F P
0 g
s
.5394 .3686 m .54674 .37718 L .55505 .38142 L p .666 .114 0 r
F P
0 g
s
.54674 .37718 m .5394 .3686 L .5329 .36677 L p .653 .126 0 r
F P
0 g
s
.51549 .37406 m .51876 .36652 L .51211 .36813 L p .318 0 0 r
F P
0 g
s
.51211 .36813 m .50542 .37647 L .51549 .37406 L p .318 0 0 r
F P
0 g
s
.67637 .566 m .66548 .57163 L .68514 .54934 L p .735 .992 .844 r
F P
0 g
s
.68514 .54934 m .69774 .54187 L .67637 .566 L p .735 .992 .844 r
F P
0 g
s
.56496 .39307 m .57864 .41138 L .57986 .42012 L p 0 .162 .689 r
F P
0 g
s
.57864 .41138 m .56496 .39307 L .56126 .38685 L p 0 0 .524 r
F P
0 g
s
.60043 .55207 m .59088 .52828 L .60715 .51706 L p .512 .441 .713 r
F P
0 g
s
.59514 .49116 m .60715 .51706 L .59088 .52828 L p .498 .414 .692 r
F P
0 g
s
.5329 .36677 m .53691 .37442 L .54674 .37718 L p .653 .126 0 r
F P
0 g
s
.53691 .37442 m .5329 .36677 L .52586 .36606 L p .583 .084 .036 r
F P
0 g
s
.52624 .37335 m .52586 .36606 L .51876 .36652 L p .476 0 .042 r
F P
0 g
s
.51876 .36652 m .51549 .37406 L .52624 .37335 L p .476 0 .042 r
F P
0 g
s
.47796 .4015 m .49006 .38564 L .48582 .39173 L p .619 .845 .465 r
F P
0 g
s
.48582 .39173 m .47231 .40961 L .47796 .4015 L p .619 .845 .465 r
F P
0 g
s
.37989 .56728 m .39149 .56858 L .41597 .58641 L p .355 .655 .969 r
F P
0 g
s
.4256 .58039 m .41597 .58641 L .39149 .56858 L p .679 .76 .913 r
F P
0 g
s
.52586 .36606 m .52624 .37335 L .53691 .37442 L p .583 .084 .036 r
F P
0 g
s
.4279 .53641 m .44033 .51443 L .45559 .52616 L p .868 .736 .716 r
F P
0 g
s
.45559 .52616 m .44547 .54968 L .4279 .53641 L p .868 .736 .716 r
F P
0 g
s
.28887 .45554 m .30199 .46747 L .3122 .50131 L p .122 .358 .82 r
F P
0 g
s
.32446 .51314 m .3122 .50131 L .30199 .46747 L p .017 .271 .771 r
F P
0 g
s
.6192 .58331 m .6099 .57072 L .63107 .5566 L p .58 .577 .814 r
F P
0 g
s
.63107 .5566 m .64281 .56774 L .6192 .58331 L p .58 .577 .814 r
F P
0 g
s
.6099 .57072 m .60043 .55207 L .61916 .53939 L p .538 .49 .75 r
F P
0 g
s
.60715 .51706 m .61916 .53939 L .60043 .55207 L p .512 .441 .713 r
F P
0 g
s
.57986 .42012 m .59403 .44321 L .5908 .45388 L p .201 .256 .696 r
F P
0 g
s
.59403 .44321 m .57986 .42012 L .57864 .41138 L p 0 .104 .649 r
F P
0 g
s
.33682 .52546 m .3494 .53647 L .36859 .56129 L p 0 .189 .706 r
F P
0 g
s
.37989 .56728 m .36859 .56129 L .3494 .53647 L p .04 .4 .855 r
F P
0 g
s
.60715 .51706 m .59514 .49116 L .60441 .47957 L p .39 .359 .703 r
F P
0 g
s
.5908 .45388 m .60441 .47957 L .59514 .49116 L p .378 .342 .692 r
F P
0 g
s
.61916 .53939 m .63107 .5566 L .6099 .57072 L p .538 .49 .75 r
F P
0 g
s
.56126 .38685 m .57373 .4031 L .57864 .41138 L p 0 0 .524 r
F P
0 g
s
.57373 .4031 m .56126 .38685 L .55505 .38142 L p .724 .217 0 r
F P
0 g
s
.72215 .5194 m .71005 .53129 L .72128 .50226 L p .87 .992 .747 r
F P
0 g
s
.72128 .50226 m .73435 .48821 L .72215 .5194 L p .87 .992 .747 r
F P
0 g
s
.45854 .43013 m .47231 .40961 L .47031 .4183 L p .908 .957 .624 r
F P
0 g
s
.47031 .4183 m .45611 .44095 L .45854 .43013 L p .908 .957 .624 r
F P
0 g
s
.60441 .47957 m .5908 .45388 L .59403 .44321 L p .199 .253 .694 r
F P
0 g
s
.39149 .56858 m .4034 .56408 L .4256 .58039 L p .679 .76 .913 r
F P
0 g
s
.43545 .56807 m .4256 .58039 L .4034 .56408 L p .799 .761 .818 r
F P
0 g
s
.41556 .55328 m .4279 .53641 L .44547 .54968 L p .846 .747 .754 r
F P
0 g
s
.44547 .54968 m .43545 .56807 L .41556 .55328 L p .846 .747 .754 r
F P
0 g
s
.48692 .39454 m .49675 .38043 L .49006 .38564 L p 0 0 0 r
F P
0 g
s
.49006 .38564 m .47796 .4015 L .48692 .39454 L p 0 0 0 r
F P
0 g
s
.43058 .5007 m .44454 .477 L .45276 .48888 L p .928 .807 .706 r
F P
0 g
s
.45276 .48888 m .44033 .51443 L .43058 .5007 L p .928 .807 .706 r
F P
0 g
s
.4034 .56408 m .41556 .55328 L .43545 .56807 L p .799 .761 .818 r
F P
0 g
s
.44169 .46417 m .45611 .44095 L .45838 .45172 L p .972 .9 .691 r
F P
0 g
s
.45838 .45172 m .44454 .477 L .44169 .46417 L p .972 .9 .691 r
F P
0 g
s
.66548 .57163 m .65429 .57259 L .67222 .55211 L p .737 .918 .954 r
F P
0 g
s
.67222 .55211 m .68514 .54934 L .66548 .57163 L p .737 .918 .954 r
F P
0 g
s
.55505 .38142 m .56541 .39586 L .57373 .4031 L p .724 .217 0 r
F P
0 g
s
.56541 .39586 m .55505 .38142 L .54674 .37718 L p .771 .272 .022 r
F P
0 g
s
.49858 .38925 m .50542 .37647 L .49675 .38043 L p .206 0 .054 r
F P
0 g
s
.49675 .38043 m .48692 .39454 L .49858 .38925 L p .206 0 .054 r
F P
0 g
s
.61916 .53939 m .60715 .51706 L .61812 .50367 L p .416 .396 .728 r
F P
0 g
s
.60441 .47957 m .61812 .50367 L .60715 .51706 L p .39 .359 .703 r
F P
0 g
s
.30199 .46747 m .31507 .4815 L .32446 .51314 L p .017 .271 .771 r
F P
0 g
s
.33682 .52546 m .32446 .51314 L .31507 .4815 L p 0 .255 .761 r
F P
0 g
s
.57864 .41138 m .59258 .43234 L .59403 .44321 L p 0 .104 .649 r
F P
0 g
s
.59258 .43234 m .57864 .41138 L .57373 .4031 L p 0 0 .442 r
F P
0 g
s
.3494 .53647 m .36226 .54435 L .37989 .56728 L p .04 .4 .855 r
F P
0 g
s
.39149 .56858 m .37989 .56728 L .36226 .54435 L p .406 .636 .949 r
F P
0 g
s
.4656 .42 m .47796 .4015 L .47231 .40961 L p 0 0 0 r
F P
0 g
s
.47231 .40961 m .45854 .43013 L .4656 .42 L p 0 0 0 r
F P
0 g
s
.41659 .52085 m .43058 .5007 L .44033 .51443 L p .913 .811 .732 r
F P
0 g
s
.44033 .51443 m .4279 .53641 L .41659 .52085 L p .913 .811 .732 r
F P
0 g
s
.54674 .37718 m .55425 .39019 L .56541 .39586 L p .771 .272 .022 r
F P
0 g
s
.55425 .39019 m .54674 .37718 L .53691 .37442 L p .723 .257 .142 r
F P
0 g
s
.51214 .38601 m .51549 .37406 L .50542 .37647 L p .413 .008 .157 r
F P
0 g
s
.50542 .37647 m .49858 .38925 L .51214 .38601 L p .413 .008 .157 r
F P
0 g
s
.71005 .53129 m .69774 .54187 L .70801 .51498 L p .871 .995 .789 r
F P
0 g
s
.70801 .51498 m .72128 .50226 L .71005 .53129 L p .871 .995 .789 r
F P
0 g
s
.65429 .57259 m .64281 .56774 L .659 .54905 L p .637 .731 .916 r
F P
0 g
s
.659 .54905 m .67222 .55211 L .65429 .57259 L p .637 .731 .916 r
F P
0 g
s
.81481 .45607 m .80068 .45152 L .79989 .40745 L p .527 .639 .904 r
F P
0 g
s
.80068 .45152 m .78692 .45112 L .78585 .40929 L p .653 .744 .916 r
F P
0 g
s
.78585 .40929 m .79989 .40745 L .80068 .45152 L p .653 .744 .916 r
F P
0 g
s
.78692 .45112 m .7735 .4551 L .77218 .41555 L p .772 .836 .901 r
F P
0 g
s
.77218 .41555 m .78585 .40929 L .78692 .45112 L p .772 .836 .901 r
F P
0 g
s
.61812 .50367 m .60441 .47957 L .60841 .46687 L p .221 .278 .71 r
F P
0 g
s
.59403 .44321 m .60841 .46687 L .60441 .47957 L p .199 .253 .694 r
F P
0 g
s
.60841 .46687 m .59403 .44321 L .59258 .43234 L p 0 .099 .646 r
F P
0 g
s
.53691 .37442 m .54101 .3865 L .55425 .39019 L p .723 .257 .142 r
F P
0 g
s
.54101 .3865 m .53691 .37442 L .52624 .37335 L p .646 .207 .192 r
F P
0 g
s
.63107 .5566 m .61916 .53939 L .63185 .52423 L p .462 .461 .771 r
F P
0 g
s
.61812 .50367 m .63185 .52423 L .61916 .53939 L p .416 .396 .728 r
F P
0 g
s
.52663 .38507 m .52624 .37335 L .51549 .37406 L p .548 .128 .197 r
F P
0 g
s
.51549 .37406 m .51214 .38601 L .52663 .38507 L p .548 .128 .197 r
F P
0 g
s
.8293 .46407 m .81481 .45607 L .81435 .4098 L p .422 .548 .878 r
F P
0 g
s
.79989 .40745 m .81435 .4098 L .81481 .45607 L p .527 .639 .904 r
F P
0 g
s
.52624 .37335 m .52663 .38507 L .54101 .3865 L p .646 .207 .192 r
F P
0 g
s
.7735 .4551 m .76034 .46321 L .75881 .42597 L p .859 .895 .86 r
F P
0 g
s
.75881 .42597 m .77218 .41555 L .7735 .4551 L p .859 .895 .86 r
F P
0 g
s
.44453 .45124 m .45854 .43013 L .45611 .44095 L p .908 .956 .619 r
F P
0 g
s
.45611 .44095 m .44169 .46417 L .44453 .45124 L p .908 .956 .619 r
F P
0 g
s
.42712 .48583 m .44169 .46417 L .44454 .477 L p .965 .901 .708 r
F P
0 g
s
.44454 .477 m .43058 .5007 L .42712 .48583 L p .965 .901 .708 r
F P
0 g
s
.64281 .56774 m .63107 .5566 L .64551 .53967 L p .534 .568 .835 r
F P
0 g
s
.64551 .53967 m .659 .54905 L .64281 .56774 L p .534 .568 .835 r
F P
0 g
s
.36226 .54435 m .37544 .54753 L .39149 .56858 L p .406 .636 .949 r
F P
0 g
s
.4034 .56408 m .39149 .56858 L .37544 .54753 L p .679 .766 .917 r
F P
0 g
s
.63185 .52423 m .64551 .53967 L .63107 .5566 L p .462 .461 .771 r
F P
0 g
s
.40267 .5359 m .41659 .52085 L .4279 .53641 L p .882 .813 .776 r
F P
0 g
s
.4279 .53641 m .41556 .55328 L .40267 .5359 L p .882 .813 .776 r
F P
0 g
s
.57373 .4031 m .58646 .42201 L .59258 .43234 L p 0 0 .442 r
F P
0 g
s
.58646 .42201 m .57373 .4031 L .56541 .39586 L p .78 .289 0 r
F P
0 g
s
.31507 .4815 m .32823 .49601 L .33682 .52546 L p 0 .255 .761 r
F P
0 g
s
.3494 .53647 m .33682 .52546 L .32823 .49601 L p .07 .316 .798 r
F P
0 g
s
.84408 .47443 m .8293 .46407 L .82922 .41563 L p .355 .488 .855 r
F P
0 g
s
.81435 .4098 m .82922 .41563 L .8293 .46407 L p .422 .548 .878 r
F P
0 g
s
.47686 .4113 m .48692 .39454 L .47796 .4015 L p 0 0 0 r
F P
0 g
s
.47796 .4015 m .4656 .42 L .47686 .4113 L p 0 0 0 r
F P
0 g
s
.76034 .46321 m .74733 .47466 L .74563 .43975 L p .908 .922 .815 r
F P
0 g
s
.74563 .43975 m .75881 .42597 L .76034 .46321 L p .908 .922 .815 r
F P
0 g
s
.37544 .54753 m .38893 .54487 L .4034 .56408 L p .679 .766 .917 r
F P
0 g
s
.41556 .55328 m .4034 .56408 L .38893 .54487 L p .818 .807 .841 r
F P
0 g
s
.38893 .54487 m .40267 .5359 L .41556 .55328 L p .818 .807 .841 r
F P
0 g
s
.25294 .39827 m .26692 .40059 L .26204 .44252 L p .663 .753 .917 r
F P
0 g
s
.26204 .44252 m .24814 .44247 L .25294 .39827 L p .663 .753 .917 r
F P
0 g
s
.27559 .44697 m .26204 .44252 L .26692 .40059 L p .534 .634 .896 r
F P
0 g
s
.69774 .54187 m .68514 .54934 L .69447 .52454 L p .852 .976 .867 r
F P
0 g
s
.69447 .52454 m .70801 .51498 L .69774 .54187 L p .852 .976 .867 r
F P
0 g
s
.23854 .40015 m .25294 .39827 L .24814 .44247 L p .767 .843 .909 r
F P
0 g
s
.24814 .44247 m .23386 .44658 L .23854 .40015 L p .767 .843 .909 r
F P
0 g
s
.63185 .52423 m .61812 .50367 L .62293 .48896 L p .272 .334 .744 r
F P
0 g
s
.60841 .46687 m .62293 .48896 L .61812 .50367 L p .221 .278 .71 r
F P
0 g
s
.26692 .40059 m .28051 .40734 L .27559 .44697 L p .534 .634 .896 r
F P
0 g
s
.28887 .45554 m .27559 .44697 L .28051 .40734 L p .408 .514 .854 r
F P
0 g
s
.59258 .43234 m .60675 .45389 L .60841 .46687 L p 0 .099 .646 r
F P
0 g
s
.60675 .45389 m .59258 .43234 L .58646 .42201 L p 0 0 .435 r
F P
0 g
s
.85906 .48583 m .84408 .47443 L .84442 .42387 L p .329 .464 .845 r
F P
0 g
s
.82922 .41563 m .84442 .42387 L .84408 .47443 L p .355 .488 .855 r
F P
0 g
s
.22374 .40552 m .23854 .40015 L .23386 .44658 L p .833 .896 .885 r
F P
0 g
s
.23386 .44658 m .21921 .45415 L .22374 .40552 L p .833 .896 .885 r
F P
0 g
s
.56541 .39586 m .57602 .41296 L .58646 .42201 L p .78 .289 0 r
F P
0 g
s
.57602 .41296 m .56541 .39586 L .55425 .39019 L p .799 .324 .096 r
F P
0 g
s
.41247 .50396 m .42712 .48583 L .43058 .5007 L p .947 .901 .746 r
F P
0 g
s
.43058 .5007 m .41659 .52085 L .41247 .50396 L p .947 .901 .746 r
F P
0 g
s
.49157 .40467 m .49858 .38925 L .48692 .39454 L p .251 0 .125 r
F P
0 g
s
.48692 .39454 m .47686 .4113 L .49157 .40467 L p .251 0 .125 r
F P
0 g
s
.62293 .48896 m .60841 .46687 L .60675 .45389 L p 0 .142 .676 r
F P
0 g
s
.45299 .43911 m .4656 .42 L .45854 .43013 L p 0 0 0 r
F P
0 g
s
.45854 .43013 m .44453 .45124 L .45299 .43911 L p 0 0 0 r
F P
0 g
s
.74733 .47466 m .73435 .48821 L .73251 .45563 L p .929 .932 .785 r
F P
0 g
s
.73251 .45563 m .74563 .43975 L .74733 .47466 L p .929 .932 .785 r
F P
0 g
s
.32823 .49601 m .3416 .5092 L .3494 .53647 L p .07 .316 .798 r
F P
0 g
s
.36226 .54435 m .3494 .53647 L .3416 .5092 L p .232 .449 .865 r
F P
0 g
s
.28051 .40734 m .29381 .41825 L .28887 .45554 L p .408 .514 .854 r
F P
0 g
s
.30199 .46747 m .28887 .45554 L .29381 .41825 L p .312 .419 .811 r
F P
0 g
s
.43033 .47081 m .44453 .45124 L .44169 .46417 L p .913 .966 .655 r
F P
0 g
s
.44169 .46417 m .42712 .48583 L .43033 .47081 L p .913 .966 .655 r
F P
0 g
s
.20858 .41329 m .22374 .40552 L .21921 .45415 L p .867 .922 .862 r
F P
0 g
s
.21921 .45415 m .20426 .46408 L .20858 .41329 L p .867 .922 .862 r
F P
0 g
s
.68514 .54934 m .67222 .55211 L .68062 .52938 L p .774 .89 .928 r
F P
0 g
s
.68062 .52938 m .69447 .52454 L .68514 .54934 L p .774 .89 .928 r
F P
0 g
s
.55425 .39019 m .56195 .40585 L .57602 .41296 L p .799 .324 .096 r
F P
0 g
s
.56195 .40585 m .55425 .39019 L .54101 .3865 L p .742 .299 .201 r
F P
0 g
s
.84442 .42387 m .85986 .43317 L .85906 .48583 L p .329 .464 .845 r
F P
0 g
s
.64551 .53967 m .63185 .52423 L .63752 .50752 L p .356 .427 .797 r
F P
0 g
s
.62293 .48896 m .63752 .50752 L .63185 .52423 L p .272 .334 .744 r
F P
0 g
s
.5087 .40061 m .51214 .38601 L .49858 .38925 L p .443 .059 .214 r
F P
0 g
s
.49858 .38925 m .49157 .40467 L .5087 .40061 L p .443 .059 .214 r
F P
0 g
s
.39786 .51698 m .41247 .50396 L .41659 .52085 L p .908 .892 .802 r
F P
0 g
s
.41659 .52085 m .40267 .5359 L .39786 .51698 L p .908 .892 .802 r
F P
0 g
s
.54101 .3865 m .54522 .40122 L .56195 .40585 L p .742 .299 .201 r
F P
0 g
s
.54522 .40122 m .54101 .3865 L .52663 .38507 L p .664 .247 .244 r
F P
0 g
s
.29381 .41825 m .30691 .43252 L .30199 .46747 L p .312 .419 .811 r
F P
0 g
s
.31507 .4815 m .30199 .46747 L .30691 .43252 L p .257 .365 .783 r
F P
0 g
s
.52703 .39943 m .52663 .38507 L .51214 .38601 L p .569 .171 .248 r
F P
0 g
s
.51214 .38601 m .5087 .40061 L .52703 .39943 L p .569 .171 .248 r
F P
0 g
s
.67222 .55211 m .659 .54905 L .66646 .52835 L p .631 .733 .921 r
F P
0 g
s
.66646 .52835 m .68062 .52938 L .67222 .55211 L p .631 .733 .921 r
F P
0 g
s
.59944 .44152 m .60675 .45389 L p .58999 .42756 L 0 0 .435 r
F P
0 g
s
.62112 .47389 m .60675 .45389 L .59944 .44152 L p 0 0 .496 r
F P
0 g
s
.61262 .45949 m .62112 .47389 L p .606 .45132 L 0 0 .496 r
F P
0 g
s
.59944 .44152 m .61262 .45949 L p .606 .45132 L 0 0 .496 r
F P
0 g
s
.60675 .45389 m .62112 .47389 L .62293 .48896 L p 0 .142 .676 r
F P
0 g
s
.63558 .49036 m .62112 .47389 L .61262 .45949 L p 0 .074 .626 r
F P
0 g
s
.62592 .47393 m .63558 .49036 L p .62233 .47255 L 0 .074 .626 r
F P
0 g
s
.61262 .45949 m .62592 .47393 L p .62233 .47255 L 0 .074 .626 r
F P
0 g
s
.62592 .47393 m .61262 .45949 L p .6185 .46675 L .623 .101 0 r
F P
0 g
s
.60905 .45944 m .62592 .47393 L p .60973 .45827 L .623 .101 0 r
F P
0 g
s
.59789 .44682 m .60905 .45944 L p .60973 .45827 L .623 .101 0 r
F P
0 g
s
.60905 .45944 m .586 .44799 L p .60848 .4604 L .479 0 0 r
F P
0 g
s
.62592 .47393 m .60905 .45944 L p .62889 .47508 L 0 .202 .674 r
F P
0 g
s
.61262 .45949 m .59789 .44682 L p .6185 .46675 L .623 .101 0 r
F P
0 g
s
.62025 .4669 m .63926 .48325 L p .62671 .47336 L 0 .202 .674 r
F P
0 g
s
.60905 .45944 m .62025 .4669 L p .62671 .47336 L 0 .202 .674 r
F P
0 g
s
.62025 .4669 m .60905 .45944 L p .60848 .4604 L .479 0 0 r
F P
0 g
s
.59419 .45397 m .62025 .4669 L p .60601 .45904 L .479 0 0 r
F P
0 g
s
.586 .44799 m .59419 .45397 L p .60601 .45904 L .479 0 0 r
F P
0 g
s
.59419 .45397 m .586 .44799 L .55841 .44051 L p .516 0 0 r
F P
0 g
s
.56291 .4455 m .59419 .45397 L p .57928 .44836 L .516 0 0 r
F P
0 g
s
.55841 .44051 m .56291 .4455 L p .57928 .44836 L .516 0 0 r
F P
0 g
s
.52872 .44221 m .56291 .4455 L p .54846 .4422 L .464 0 0 r
F P
0 g
s
.52829 .4376 m .52872 .44221 L p .54846 .4422 L .464 0 0 r
F P
0 g
s
.49794 .43951 m .49426 .44438 L .52872 .44221 L p .351 0 0 r
F P
0 g
s
.52872 .44221 m .49426 .44438 L p .51407 .44222 L .238 .747 .878 r
F P
0 g
s
.52872 .44221 m .52829 .4376 L .49794 .43951 L p .351 0 0 r
F P
0 g
s
.52916 .44057 m .52872 .44221 L p .51407 .44222 L .238 .747 .878 r
F P
0 g
s
.56291 .4455 m .52872 .44221 L p .55072 .44337 L .151 .673 .881 r
F P
0 g
s
.56291 .4455 m .55841 .44051 L .52829 .4376 L p .464 0 0 r
F P
0 g
s
.56741 .44426 m .56291 .4455 L p .55072 .44337 L .151 .673 .881 r
F P
0 g
s
.59419 .45397 m .56291 .4455 L p .58538 .45019 L .13 .626 .909 r
F P
0 g
s
.60905 .45944 m .59789 .44682 L .57786 .43683 L p .716 .183 0 r
F P
0 g
s
.57786 .43683 m .586 .44799 L .60905 .45944 L p .716 .183 0 r
F P
0 g
s
.60237 .45373 m .59419 .45397 L p .58538 .45019 L .13 .626 .909 r
F P
0 g
s
.62025 .4669 m .59419 .45397 L p .61542 .46208 L .169 .6 .938 r
F P
0 g
s
.63142 .46819 m .62025 .4669 L p .61542 .46208 L .169 .6 .938 r
F P
0 g
s
.63926 .48325 m .62592 .47393 L p .62889 .47508 L 0 .202 .674 r
F P
0 g
s
.59944 .44152 m .58686 .43066 L p .60841 .45478 L .745 .243 0 r
F P
0 g
s
.61262 .45949 m .59944 .44152 L p .60841 .45478 L .745 .243 0 r
F P
0 g
s
.58646 .42201 m .59944 .44152 L p .58999 .42756 L 0 0 .435 r
F P
0 g
s
.59944 .44152 m .58646 .42201 L .57602 .41296 L p .785 .295 0 r
F P
0 g
s
.3416 .5092 m .35523 .51922 L .36226 .54435 L p .232 .449 .865 r
F P
0 g
s
.37544 .54753 m .36226 .54435 L .35523 .51922 L p .459 .622 .922 r
F P
0 g
s
.73435 .48821 m .72128 .50226 L .71933 .472 L p .933 .933 .779 r
F P
0 g
s
.71933 .472 m .73251 .45563 L .73435 .48821 L p .933 .933 .779 r
F P
0 g
s
.19318 .42214 m .20858 .41329 L .20426 .46408 L p .879 .93 .852 r
F P
0 g
s
.20426 .46408 m .18911 .47507 L .19318 .42214 L p .879 .93 .852 r
F P
0 g
s
.659 .54905 m .64551 .53967 L .65207 .52098 L p .478 .563 .863 r
F P
0 g
s
.63752 .50752 m .65207 .52098 L .64551 .53967 L p .356 .427 .797 r
F P
0 g
s
.52663 .38507 m .52703 .39943 L .54522 .40122 L p .664 .247 .244 r
F P
0 g
s
.65207 .52098 m .66646 .52835 L .659 .54905 L p .478 .563 .863 r
F P
0 g
s
.46657 .42867 m .47686 .4113 L .4656 .42 L p 0 0 0 r
F P
0 g
s
.4656 .42 m .45299 .43911 L .46657 .42867 L p 0 0 0 r
F P
0 g
s
.63752 .50752 m .62293 .48896 L .62112 .47389 L p .037 .235 .737 r
F P
0 g
s
.3834 .52392 m .39786 .51698 L .40267 .5359 L p .827 .858 .87 r
F P
0 g
s
.40267 .5359 m .38893 .54487 L .3834 .52392 L p .827 .858 .87 r
F P
0 g
s
.35523 .51922 m .36917 .52451 L .37544 .54753 L p .459 .622 .922 r
F P
0 g
s
.38893 .54487 m .37544 .54753 L .36917 .52451 L p .677 .772 .922 r
F P
0 g
s
.36917 .52451 m .3834 .52392 L .38893 .54487 L p .677 .772 .922 r
F P
0 g
s
.41603 .48685 m .43033 .47081 L .42712 .48583 L p .917 .979 .726 r
F P
0 g
s
.42712 .48583 m .41247 .50396 L .41603 .48685 L p .917 .979 .726 r
F P
0 g
s
.30691 .43252 m .31994 .4489 L .31507 .4815 L p .257 .365 .783 r
F P
0 g
s
.32823 .49601 m .31507 .4815 L .31994 .4489 L p .248 .356 .778 r
F P
0 g
s
.44018 .45669 m .45299 .43911 L .44453 .45124 L p .599 .824 .434 r
F P
0 g
s
.44453 .45124 m .43033 .47081 L .44018 .45669 L p .599 .824 .434 r
F P
0 g
s
.72128 .50226 m .70801 .51498 L .70598 .487 L p .919 .928 .801 r
F P
0 g
s
.70598 .487 m .71933 .472 L .72128 .50226 L p .919 .928 .801 r
F P
0 g
s
.57602 .41296 m .58686 .43066 L .59944 .44152 L p .785 .295 0 r
F P
0 g
s
.58686 .43066 m .57602 .41296 L .56195 .40585 L p .801 .329 .102 r
F P
0 g
s
.48439 .4207 m .49157 .40467 L .47686 .4113 L p .254 0 .131 r
F P
0 g
s
.47686 .4113 m .46657 .42867 L .48439 .4207 L p .254 0 .131 r
F P
0 g
s
.65207 .52098 m .63752 .50752 L .63558 .49036 L p .199 .381 .819 r
F P
0 g
s
.62112 .47389 m .63558 .49036 L .63752 .50752 L p .037 .235 .737 r
F P
0 g
s
.31994 .4489 m .33302 .46575 L .32823 .49601 L p .248 .356 .778 r
F P
0 g
s
.3416 .5092 m .32823 .49601 L .33302 .46575 L p .285 .393 .798 r
F P
0 g
s
.70801 .51498 m .69447 .52454 L .69238 .49882 L p .877 .908 .847 r
F P
0 g
s
.69238 .49882 m .70598 .487 L .70801 .51498 L p .877 .908 .847 r
F P
0 g
s
.56195 .40585 m .56983 .42212 L .58686 .43066 L p .801 .329 .102 r
F P
0 g
s
.56983 .42212 m .56195 .40585 L .54522 .40122 L p .743 .303 .206 r
F P
0 g
s
.40172 .49778 m .41603 .48685 L .41247 .50396 L p .896 .971 .821 r
F P
0 g
s
.41247 .50396 m .39786 .51698 L .40172 .49778 L p .896 .971 .821 r
F P
0 g
s
.50518 .41581 m .5087 .40061 L .49157 .40467 L p .445 .063 .218 r
F P
0 g
s
.49157 .40467 m .48439 .4207 L .50518 .41581 L p .445 .063 .218 r
F P
0 g
s
.4561 .4445 m .46657 .42867 L .45299 .43911 L p 0 0 0 r
F P
0 g
s
.45299 .43911 m .44018 .45669 L .4561 .4445 L p 0 0 0 r
F P
0 g
s
.79989 .40745 m .78585 .40929 L .76617 .36817 L p .653 .745 .917 r
F P
0 g
s
.78585 .40929 m .77218 .41555 L .75327 .37677 L p .771 .802 .878 r
F P
0 g
s
.75327 .37677 m .76617 .36817 L .78585 .40929 L p .771 .802 .878 r
F P
0 g
s
.66646 .52835 m .65207 .52098 L .65003 .50172 L p .411 .564 .896 r
F P
0 g
s
.63558 .49036 m .65003 .50172 L .65207 .52098 L p .199 .381 .819 r
F P
0 g
s
.77218 .41555 m .75881 .42597 L .74067 .38954 L p .847 .829 .83 r
F P
0 g
s
.74067 .38954 m .75327 .37677 L .77218 .41555 L p .847 .829 .83 r
F P
0 g
s
.54522 .40122 m .54954 .41654 L .56983 .42212 L p .743 .303 .206 r
F P
0 g
s
.54954 .41654 m .54522 .40122 L .52703 .39943 L p .665 .251 .248 r
F P
0 g
s
.69447 .52454 m .68062 .52938 L .67851 .50585 L p .787 .853 .9 r
F P
0 g
s
.67851 .50585 m .69238 .49882 L .69447 .52454 L p .787 .853 .9 r
F P
0 g
s
.52745 .41438 m .52703 .39943 L .5087 .40061 L p .571 .174 .252 r
F P
0 g
s
.5087 .40061 m .50518 .41581 L .52745 .41438 L p .571 .174 .252 r
F P
0 g
s
.33302 .46575 m .34627 .48123 L .3416 .5092 L p .285 .393 .798 r
F P
0 g
s
.35523 .51922 m .3416 .5092 L .34627 .48123 L p .371 .48 .841 r
F P
0 g
s
.42724 .47073 m .41427 .47963 L .4238 .47235 L p .478 .855 .633 r
F P
0 g
s
.42724 .47073 m .44018 .45669 L .43193 .46852 L p .684 .913 .58 r
F P
0 g
s
.44018 .45669 m .42724 .47073 L .44551 .45678 L p 0 0 0 r
F P
0 g
s
.4238 .47235 m .43486 .4639 L p .42724 .47073 L .478 .855 .633 r
F P
0 g
s
.43193 .46852 m .43033 .47081 L p .42724 .47073 L .684 .913 .58 r
F P
0 g
s
.43033 .47081 m .41603 .48685 L .42724 .47073 L p .684 .913 .58 r
F P
0 g
s
.81435 .4098 m .79989 .40745 L .77947 .36402 L p .499 .656 .93 r
F P
0 g
s
.76617 .36817 m .77947 .36402 L .79989 .40745 L p .653 .745 .917 r
F P
0 g
s
.52703 .39943 m .52745 .41438 L .54954 .41654 L p .665 .251 .248 r
F P
0 g
s
.75881 .42597 m .74563 .43975 L .72828 .40568 L p .888 .84 .791 r
F P
0 g
s
.72828 .40568 m .74067 .38954 L .75881 .42597 L p .888 .84 .791 r
F P
0 g
s
.68062 .52938 m .66646 .52835 L .66437 .50698 L p .627 .737 .926 r
F P
0 g
s
.65003 .50172 m .66437 .50698 L .66646 .52835 L p .411 .564 .896 r
F P
0 g
s
.66437 .50698 m .67851 .50585 L .68062 .52938 L p .627 .737 .926 r
F P
0 g
s
.38752 .50259 m .40172 .49778 L .39786 .51698 L p .818 .909 .902 r
F P
0 g
s
.39786 .51698 m .3834 .52392 L .38752 .50259 L p .818 .909 .902 r
F P
0 g
s
.82922 .41563 m .81435 .4098 L .79319 .36408 L p .347 .557 .913 r
F P
0 g
s
.77947 .36402 m .79319 .36408 L .81435 .4098 L p .499 .656 .93 r
F P
0 g
s
.34627 .48123 m .35976 .49352 L .35523 .51922 L p .371 .48 .841 r
F P
0 g
s
.36917 .52451 m .35523 .51922 L .35976 .49352 L p .508 .616 .894 r
F P
0 g
s
.74563 .43975 m .73251 .45563 L .71598 .42391 L p .907 .842 .769 r
F P
0 g
s
.71598 .42391 m .72828 .40568 L .74563 .43975 L p .907 .842 .769 r
F P
0 g
s
.58686 .43066 m .59789 .44682 L .61262 .45949 L p .745 .243 0 r
F P
0 g
s
.59789 .44682 m .58686 .43066 L .56983 .42212 L p .782 .291 .049 r
F P
0 g
s
.29048 .36002 m .30309 .36909 L .28051 .40734 L p .569 .631 .873 r
F P
0 g
s
.28051 .40734 m .26692 .40059 L .29048 .36002 L p .569 .631 .873 r
F P
0 g
s
.29381 .41825 m .28051 .40734 L .30309 .36909 L p .491 .53 .825 r
F P
0 g
s
.37351 .50102 m .38752 .50259 L .3834 .52392 L p .674 .777 .927 r
F P
0 g
s
.3834 .52392 m .36917 .52451 L .37351 .50102 L p .674 .777 .927 r
F P
0 g
s
.27748 .35539 m .29048 .36002 L .26692 .40059 L p .662 .753 .918 r
F P
0 g
s
.26692 .40059 m .25294 .39827 L .27748 .35539 L p .662 .753 .918 r
F P
0 g
s
.35976 .49352 m .37351 .50102 L .36917 .52451 L p .508 .616 .894 r
F P
0 g
s
.47706 .43517 m .48439 .4207 L .46657 .42867 L p .223 0 .08 r
F P
0 g
s
.46657 .42867 m .4561 .4445 L .47706 .43517 L p .223 0 .08 r
F P
0 g
s
.30309 .36909 m .3154 .38234 L .29381 .41825 L p .491 .53 .825 r
F P
0 g
s
.30691 .43252 m .29381 .41825 L .3154 .38234 L p .437 .46 .786 r
F P
0 g
s
.65003 .50172 m .63558 .49036 L .62592 .47393 L p 0 .309 .801 r
F P
0 g
s
.26406 .35499 m .27748 .35539 L .25294 .39827 L p .746 .867 .935 r
F P
0 g
s
.25294 .39827 m .23854 .40015 L .26406 .35499 L p .746 .867 .935 r
F P
0 g
s
.84442 .42387 m .82922 .41563 L .80733 .36766 L p .238 .479 .886 r
F P
0 g
s
.79319 .36408 m .80733 .36766 L .82922 .41563 L p .347 .557 .913 r
F P
0 g
s
.73251 .45563 m .71933 .472 L .70364 .4426 L p .91 .842 .765 r
F P
0 g
s
.70364 .4426 m .71598 .42391 L .73251 .45563 L p .91 .842 .765 r
F P
0 g
s
.41427 .47963 m .42724 .47073 L .41603 .48685 L p .776 .994 .786 r
F P
0 g
s
.41603 .48685 m .40172 .49778 L .41427 .47963 L p .776 .994 .786 r
F P
0 g
s
.3154 .38234 m .3275 .39895 L .30691 .43252 L p .437 .46 .786 r
F P
0 g
s
.31994 .4489 m .30691 .43252 L .3275 .39895 L p .408 .423 .764 r
F P
0 g
s
.25022 .35811 m .26406 .35499 L .23854 .40015 L p .8 .942 .92 r
F P
0 g
s
.23854 .40015 m .22374 .40552 L .25022 .35811 L p .8 .942 .92 r
F P
0 g
s
.44551 .45678 m .4561 .4445 L .44018 .45669 L p 0 0 0 r
F P
0 g
s
.56983 .42212 m .57786 .43683 L .59789 .44682 L p .782 .291 .049 r
F P
0 g
s
.57786 .43683 m .56983 .42212 L .54954 .41654 L p .73 .272 .164 r
F P
0 g
s
.50159 .42944 m .50518 .41581 L .48439 .4207 L p .424 .026 .178 r
F P
0 g
s
.48439 .4207 m .47706 .43517 L .50159 .42944 L p .424 .026 .178 r
F P
0 g
s
.71933 .472 m .70598 .487 L .69118 .45989 L p .898 .841 .781 r
F P
0 g
s
.69118 .45989 m .70364 .4426 L .71933 .472 L p .898 .841 .781 r
F P
0 g
s
.3275 .39895 m .33951 .41765 L .31994 .4489 L p .408 .423 .764 r
F P
0 g
s
.33302 .46575 m .31994 .4489 L .33951 .41765 L p .403 .417 .761 r
F P
0 g
s
.66437 .50698 m .65003 .50172 L .63926 .48325 L p .332 .571 .927 r
F P
0 g
s
.62592 .47393 m .63926 .48325 L .65003 .50172 L p 0 .309 .801 r
F P
0 g
s
.85986 .43317 m .84442 .42387 L .82183 .37367 L p .192 .446 .872 r
F P
0 g
s
.80733 .36766 m .82183 .37367 L .84442 .42387 L p .238 .479 .886 r
F P
0 g
s
.54954 .41654 m .55394 .43031 L .57786 .43683 L p .73 .272 .164 r
F P
0 g
s
.55394 .43031 m .54954 .41654 L .52745 .41438 L p .653 .222 .211 r
F P
0 g
s
.52787 .42778 m .52745 .41438 L .50518 .41581 L p .556 .144 .215 r
F P
0 g
s
.50518 .41581 m .50159 .42944 L .52787 .42778 L p .556 .144 .215 r
F P
0 g
s
.23601 .36365 m .25022 .35811 L .22374 .40552 L p .821 .977 .891 r
F P
0 g
s
.22374 .40552 m .20858 .41329 L .23601 .36365 L p .821 .977 .891 r
F P
0 g
s
.52745 .41438 m .52787 .42778 L .55394 .43031 L p .653 .222 .211 r
F P
0 g
s
.40136 .48239 m .41427 .47963 L .40172 .49778 L p .776 .949 .932 r
F P
0 g
s
.40172 .49778 m .38752 .50259 L .40136 .48239 L p .776 .949 .932 r
F P
0 g
s
.70598 .487 m .69238 .49882 L .67852 .47394 L p .863 .835 .818 r
F P
0 g
s
.67852 .47394 m .69118 .45989 L .70598 .487 L p .863 .835 .818 r
F P
0 g
s
.33951 .41765 m .35154 .43681 L .33302 .46575 L p .403 .417 .761 r
F P
0 g
s
.34627 .48123 m .33302 .46575 L .35154 .43681 L p .422 .442 .776 r
F P
0 g
s
.67851 .50585 m .66437 .50698 L .65252 .48641 L p .624 .742 .932 r
F P
0 g
s
.63926 .48325 m .65252 .48641 L .66437 .50698 L p .332 .571 .927 r
F P
0 g
s
.69238 .49882 m .67851 .50585 L .66562 .48316 L p .785 .813 .874 r
F P
0 g
s
.66562 .48316 m .67852 .47394 L .69238 .49882 L p .785 .813 .874 r
F P
0 g
s
.46964 .44609 m .47706 .43517 L .4561 .4445 L p .131 0 0 r
F P
0 g
s
.4561 .4445 m .44551 .45678 L .46964 .44609 L p .131 0 0 r
F P
0 g
s
.65252 .48641 m .66562 .48316 L .67851 .50585 L p .624 .742 .932 r
F P
0 g
s
.82183 .37367 m .8366 .38074 L .85986 .43317 L p .192 .446 .872 r
F P
0 g
s
.35154 .43681 m .3637 .45456 L .34627 .48123 L p .422 .442 .776 r
F P
0 g
s
.35976 .49352 m .34627 .48123 L .3637 .45456 L p .47 .505 .812 r
F P
0 g
s
.3886 .47871 m .40136 .48239 L .38752 .50259 L p .668 .78 .933 r
F P
0 g
s
.38752 .50259 m .37351 .50102 L .3886 .47871 L p .668 .78 .933 r
F P
0 g
s
.43486 .4639 m .44551 .45678 L .42724 .47073 L p .478 .855 .633 r
F P
0 g
s
.22154 .37026 m .23601 .36365 L .20858 .41329 L p .827 .987 .874 r
F P
0 g
s
.20858 .41329 m .19318 .42214 L .22154 .37026 L p .827 .987 .874 r
F P
0 g
s
.3637 .45456 m .37604 .46906 L .35976 .49352 L p .47 .505 .812 r
F P
0 g
s
.37351 .50102 m .35976 .49352 L .37604 .46906 L p .551 .615 .87 r
F P
0 g
s
.37604 .46906 m .3886 .47871 L .37351 .50102 L p .551 .615 .87 r
F P
0 g
s
.586 .44799 m .57786 .43683 L .55394 .43031 L p .686 .184 .043 r
F P
0 g
s
.49794 .43951 m .50159 .42944 L .47706 .43517 L p .362 0 .062 r
F P
0 g
s
.47706 .43517 m .46964 .44609 L .49794 .43951 L p .362 0 .062 r
F P
0 g
s
.76617 .36817 m .75327 .37677 L .71707 .34178 L p .762 .77 .859 r
F P
0 g
s
.75327 .37677 m .74067 .38954 L .70629 .35675 L p .822 .772 .806 r
F P
0 g
s
.70629 .35675 m .71707 .34178 L .75327 .37677 L p .822 .772 .806 r
F P
0 g
s
.74067 .38954 m .72828 .40568 L .6957 .37507 L p .852 .768 .769 r
F P
0 g
s
.6957 .37507 m .70629 .35675 L .74067 .38954 L p .852 .768 .769 r
F P
0 g
s
.65252 .48641 m .63926 .48325 L .62025 .4669 L p .246 .583 .945 r
F P
0 g
s
.77947 .36402 m .76617 .36817 L .72815 .33099 L p .653 .746 .919 r
F P
0 g
s
.71707 .34178 m .72815 .33099 L .76617 .36817 L p .762 .77 .859 r
F P
0 g
s
.72828 .40568 m .71598 .42391 L .6852 .39547 L p .866 .765 .749 r
F P
0 g
s
.6852 .39547 m .6957 .37507 L .72828 .40568 L p .866 .765 .749 r
F P
0 g
s
.55394 .43031 m .55841 .44051 L .586 .44799 L p .686 .184 .043 r
F P
0 g
s
.55841 .44051 m .55394 .43031 L .52787 .42778 L p .612 .139 .105 r
F P
0 g
s
.42424 .46483 m .43486 .4639 L .41427 .47963 L p .685 .959 .946 r
F P
0 g
s
.41427 .47963 m .40136 .48239 L .42424 .46483 L p .685 .959 .946 r
F P
0 g
s
.52829 .4376 m .52787 .42778 L .50159 .42944 L p .509 .056 .11 r
F P
0 g
s
.50159 .42944 m .49794 .43951 L .52829 .4376 L p .509 .056 .11 r
F P
0 g
s
.79319 .36408 m .77947 .36402 L .73958 .32465 L p .477 .681 .955 r
F P
0 g
s
.72815 .33099 m .73958 .32465 L .77947 .36402 L p .653 .746 .919 r
F P
0 g
s
.71598 .42391 m .70364 .4426 L .6747 .4163 L p .868 .764 .745 r
F P
0 g
s
.6747 .4163 m .6852 .39547 L .71598 .42391 L p .868 .764 .745 r
F P
0 g
s
.46217 .45182 m .46964 .44609 L .44551 .45678 L p 0 0 0 r
F P
0 g
s
.44551 .45678 m .43486 .4639 L .46217 .45182 L p 0 0 0 r
F P
0 g
s
.52787 .42778 m .52829 .4376 L .55841 .44051 L p .612 .139 .105 r
F P
0 g
s
.33212 .32407 m .34269 .33528 L .30309 .36909 L p .602 .634 .856 r
F P
0 g
s
.30309 .36909 m .29048 .36002 L .33212 .32407 L p .602 .634 .856 r
F P
0 g
s
.3154 .38234 m .30309 .36909 L .34269 .33528 L p .554 .548 .801 r
F P
0 g
s
.34269 .33528 m .35297 .35066 L .3154 .38234 L p .554 .548 .801 r
F P
0 g
s
.3275 .39895 m .3154 .38234 L .35297 .35066 L p .524 .493 .765 r
F P
0 g
s
.66562 .48316 m .65252 .48641 L .63142 .46819 L p .623 .748 .936 r
F P
0 g
s
.62025 .4669 m .63142 .46819 L .65252 .48641 L p .246 .583 .945 r
F P
0 g
s
.32121 .31732 m .33212 .32407 L .29048 .36002 L p .661 .753 .919 r
F P
0 g
s
.29048 .36002 m .27748 .35539 L .32121 .31732 L p .661 .753 .919 r
F P
0 g
s
.35297 .35066 m .36307 .3694 L .3275 .39895 L p .524 .493 .765 r
F P
0 g
s
.33951 .41765 m .3275 .39895 L .36307 .3694 L p .508 .466 .745 r
F P
0 g
s
.70364 .4426 m .69118 .45989 L .66412 .43569 L p .859 .767 .759 r
F P
0 g
s
.66412 .43569 m .6747 .4163 L .70364 .4426 L p .859 .767 .759 r
F P
0 g
s
.80733 .36766 m .79319 .36408 L .75141 .32255 L p .265 .573 .939 r
F P
0 g
s
.73958 .32465 m .75141 .32255 L .79319 .36408 L p .477 .681 .955 r
F P
0 g
s
.36307 .3694 m .37306 .39021 L .33951 .41765 L p .508 .466 .745 r
F P
0 g
s
.35154 .43681 m .33951 .41765 L .37306 .39021 L p .505 .461 .742 r
F P
0 g
s
.41373 .45928 m .42424 .46483 L .40136 .48239 L p .662 .781 .937 r
F P
0 g
s
.40136 .48239 m .3886 .47871 L .41373 .45928 L p .662 .781 .937 r
F P
0 g
s
.67852 .47394 m .66562 .48316 L .64248 .463 L p .774 .775 .854 r
F P
0 g
s
.63142 .46819 m .64248 .463 L .66562 .48316 L p .623 .748 .936 r
F P
0 g
s
.69118 .45989 m .67852 .47394 L .65338 .45179 L p .834 .772 .793 r
F P
0 g
s
.65338 .45179 m .66412 .43569 L .69118 .45989 L p .834 .772 .793 r
F P
0 g
s
.30992 .3148 m .32121 .31732 L .27748 .35539 L p .711 .881 .96 r
F P
0 g
s
.27748 .35539 m .26406 .35499 L .30992 .3148 L p .711 .881 .96 r
F P
0 g
s
.64248 .463 m .65338 .45179 L .67852 .47394 L p .774 .775 .854 r
F P
0 g
s
.37306 .39021 m .38306 .41144 L .35154 .43681 L p .505 .461 .742 r
F P
0 g
s
.3637 .45456 m .35154 .43681 L .38306 .41144 L p .516 .48 .755 r
F P
0 g
s
.49426 .44438 m .49794 .43951 L .46964 .44609 L p .169 0 0 r
F P
0 g
s
.46964 .44609 m .46217 .45182 L .49426 .44438 L p .169 0 0 r
F P
0 g
s
.40335 .4477 m .41373 .45928 L .3886 .47871 L p .59 .62 .85 r
F P
0 g
s
.3886 .47871 m .37604 .46906 L .40335 .4477 L p .59 .62 .85 r
F P
0 g
s
.38306 .41144 m .39314 .43122 L .3637 .45456 L p .516 .48 .755 r
F P
0 g
s
.37604 .46906 m .3637 .45456 L .39314 .43122 L p .542 .528 .789 r
F P
0 g
s
.39314 .43122 m .40335 .4477 L .37604 .46906 L p .542 .528 .789 r
F P
0 g
s
.45471 .45132 m .46217 .45182 L .43486 .4639 L p .543 .92 .933 r
F P
0 g
s
.43486 .4639 m .42424 .46483 L .45471 .45132 L p .543 .92 .933 r
F P
0 g
s
.29825 .31581 m .30992 .3148 L .26406 .35499 L p .719 .962 .942 r
F P
0 g
s
.26406 .35499 m .25022 .35811 L .29825 .31581 L p .719 .962 .942 r
F P
0 g
s
.82183 .37367 m .80733 .36766 L .76363 .32398 L p .094 .469 .891 r
F P
0 g
s
.75141 .32255 m .76363 .32398 L .80733 .36766 L p .265 .573 .939 r
F P
0 g
s
.64248 .463 m .63142 .46819 L .60237 .45373 L p .624 .755 .94 r
F P
0 g
s
.59419 .45397 m .60237 .45373 L .63142 .46819 L p .169 .6 .938 r
F P
0 g
s
.28625 .31925 m .29825 .31581 L .25022 .35811 L p .693 .981 .886 r
F P
0 g
s
.25022 .35811 m .23601 .36365 L .28625 .31925 L p .693 .981 .886 r
F P
0 g
s
.44731 .44431 m .45471 .45132 L .42424 .46483 L p .654 .781 .941 r
F P
0 g
s
.42424 .46483 m .41373 .45928 L .44731 .44431 L p .654 .781 .941 r
F P
0 g
s
.8366 .38074 m .82183 .37367 L .77619 .32783 L p .021 .42 .862 r
F P
0 g
s
.76363 .32398 m .77619 .32783 L .82183 .37367 L p .094 .469 .891 r
F P
0 g
s
.71707 .34178 m .70629 .35675 L .65754 .3304 L p .792 .723 .788 r
F P
0 g
s
.70629 .35675 m .6957 .37507 L .6497 .35053 L p .813 .71 .752 r
F P
0 g
s
.6497 .35053 m .65754 .3304 L .70629 .35675 L p .813 .71 .752 r
F P
0 g
s
.6957 .37507 m .6852 .39547 L .64194 .37271 L p .822 .703 .734 r
F P
0 g
s
.64194 .37271 m .6497 .35053 L .6957 .37507 L p .822 .703 .734 r
F P
0 g
s
.49059 .443 m .49426 .44438 L .46217 .45182 L p .38 .839 .902 r
F P
0 g
s
.46217 .45182 m .45471 .45132 L .49059 .443 L p .38 .839 .902 r
F P
0 g
s
.72815 .33099 m .71707 .34178 L .66555 .31362 L p .747 .74 .845 r
F P
0 g
s
.65754 .3304 m .66555 .31362 L .71707 .34178 L p .792 .723 .788 r
F P
0 g
s
.65338 .45179 m .64248 .463 L .61048 .44698 L p .757 .741 .838 r
F P
0 g
s
.60237 .45373 m .61048 .44698 L .64248 .463 L p .624 .755 .94 r
F P
0 g
s
.6852 .39547 m .6747 .4163 L .63419 .39529 L p .823 .702 .73 r
F P
0 g
s
.63419 .39529 m .64194 .37271 L .6852 .39547 L p .823 .702 .73 r
F P
0 g
s
.6747 .4163 m .66412 .43569 L .62639 .41639 L p .817 .707 .743 r
F P
0 g
s
.62639 .41639 m .63419 .39529 L .6747 .4163 L p .817 .707 .743 r
F P
0 g
s
.73958 .32465 m .72815 .33099 L .67378 .301 L p .653 .748 .919 r
F P
0 g
s
.66555 .31362 m .67378 .301 L .72815 .33099 L p .747 .74 .845 r
F P
0 g
s
.66412 .43569 m .65338 .45179 L .61849 .43416 L p .8 .72 .775 r
F P
0 g
s
.61048 .44698 m .61849 .43416 L .65338 .45179 L p .757 .741 .838 r
F P
0 g
s
.39699 .30889 m .40431 .32598 L .35297 .35066 L p .606 .568 .785 r
F P
0 g
s
.35297 .35066 m .34269 .33528 L .39699 .30889 L p .606 .568 .785 r
F P
0 g
s
.36307 .3694 m .35297 .35066 L .40431 .32598 L p .589 .524 .749 r
F P
0 g
s
.43999 .43121 m .44731 .44431 L .41373 .45928 L p .625 .63 .835 r
F P
0 g
s
.41373 .45928 m .40335 .4477 L .43999 .43121 L p .625 .63 .835 r
F P
0 g
s
.61849 .43416 m .62639 .41639 L .66412 .43569 L p .8 .72 .775 r
F P
0 g
s
.40431 .32598 m .41148 .34641 L .36307 .3694 L p .589 .524 .749 r
F P
0 g
s
.37306 .39021 m .36307 .3694 L .41148 .34641 L p .581 .502 .731 r
F P
0 g
s
.56291 .4455 m .56741 .44426 L .60237 .45373 L p .13 .626 .909 r
F P
0 g
s
.38946 .29596 m .39699 .30889 L .34269 .33528 L p .632 .642 .842 r
F P
0 g
s
.34269 .33528 m .33212 .32407 L .38946 .29596 L p .632 .642 .842 r
F P
0 g
s
.41148 .34641 m .41857 .3689 L .37306 .39021 L p .581 .502 .731 r
F P
0 g
s
.38306 .41144 m .37306 .39021 L .41857 .3689 L p .579 .499 .728 r
F P
0 g
s
.49426 .44438 m .49059 .443 L .52916 .44057 L p .238 .747 .878 r
F P
0 g
s
.27399 .32374 m .28625 .31925 L .23601 .36365 L p .674 .977 .851 r
F P
0 g
s
.23601 .36365 m .22154 .37026 L .27399 .32374 L p .674 .977 .851 r
F P
0 g
s
.41857 .3689 m .42565 .39177 L .38306 .41144 L p .579 .499 .728 r
F P
0 g
s
.39314 .43122 m .38306 .41144 L .42565 .39177 L p .585 .513 .74 r
F P
0 g
s
.43278 .41317 m .43999 .43121 L .40335 .4477 L p .599 .552 .772 r
F P
0 g
s
.40335 .4477 m .39314 .43122 L .43278 .41317 L p .599 .552 .772 r
F P
0 g
s
.77619 .32783 m .78901 .33274 L .8366 .38074 L p .021 .42 .862 r
F P
0 g
s
.61048 .44698 m .60237 .45373 L .56741 .44426 L p .627 .762 .943 r
F P
0 g
s
.52872 .44221 m .52916 .44057 L .56741 .44426 L p .151 .673 .881 r
F P
0 g
s
.42565 .39177 m .43278 .41317 L .39314 .43122 L p .585 .513 .74 r
F P
0 g
s
.75141 .32255 m .73958 .32465 L .68229 .29285 L p .466 .713 .976 r
F P
0 g
s
.67378 .301 m .68229 .29285 L .73958 .32465 L p .653 .748 .919 r
F P
0 g
s
.38167 .28749 m .38946 .29596 L .33212 .32407 L p .659 .753 .92 r
F P
0 g
s
.33212 .32407 m .32121 .31732 L .38167 .28749 L p .659 .753 .92 r
F P
0 g
s
.48694 .43506 m .49059 .443 L .45471 .45132 L p .646 .778 .944 r
F P
0 g
s
.45471 .45132 m .44731 .44431 L .48694 .43506 L p .646 .778 .944 r
F P
0 g
s
.3736 .28325 m .38167 .28749 L .32121 .31732 L p .66 .879 .98 r
F P
0 g
s
.32121 .31732 m .30992 .3148 L .3736 .28325 L p .66 .879 .98 r
F P
0 g
s
.61849 .43416 m .61048 .44698 L .57187 .43646 L p .735 .711 .828 r
F P
0 g
s
.56741 .44426 m .57187 .43646 L .61048 .44698 L p .627 .762 .943 r
F P
0 g
s
.57187 .43646 m .56741 .44426 L .52916 .44057 L p .632 .768 .945 r
F P
0 g
s
.76363 .32398 m .75141 .32255 L .69111 .28892 L p .19 .597 .944 r
F P
0 g
s
.68229 .29285 m .69111 .28892 L .75141 .32255 L p .466 .713 .976 r
F P
0 g
s
.48333 .42102 m .48694 .43506 L .44731 .44431 L p .657 .644 .826 r
F P
0 g
s
.44731 .44431 m .43999 .43121 L .48333 .42102 L p .657 .644 .826 r
F P
0 g
s
.52958 .43237 m .52916 .44057 L .49059 .443 L p .639 .774 .945 r
F P
0 g
s
.49059 .443 m .48694 .43506 L .52958 .43237 L p .639 .774 .945 r
F P
0 g
s
.62639 .41639 m .61849 .43416 L .57629 .42256 L p .765 .676 .764 r
F P
0 g
s
.57187 .43646 m .57629 .42256 L .61849 .43416 L p .735 .711 .828 r
F P
0 g
s
.52916 .44057 m .52958 .43237 L .57187 .43646 L p .632 .768 .945 r
F P
0 g
s
.65754 .3304 m .6497 .35053 L .59354 .3343 L p .773 .662 .741 r
F P
0 g
s
.6497 .35053 m .64194 .37271 L .58924 .35769 L p .778 .652 .724 r
F P
0 g
s
.58924 .35769 m .59354 .3343 L .6497 .35053 L p .778 .652 .724 r
F P
0 g
s
.64194 .37271 m .63419 .39529 L .58496 .38144 L p .779 .65 .721 r
F P
0 g
s
.58496 .38144 m .58924 .35769 L .64194 .37271 L p .779 .65 .721 r
F P
0 g
s
.66555 .31362 m .65754 .3304 L .59789 .31296 L p .76 .682 .776 r
F P
0 g
s
.59354 .3343 m .59789 .31296 L .65754 .3304 L p .773 .662 .741 r
F P
0 g
s
.63419 .39529 m .62639 .41639 L .58065 .40369 L p .775 .657 .732 r
F P
0 g
s
.57629 .42256 m .58065 .40369 L .62639 .41639 L p .765 .676 .764 r
F P
0 g
s
.58065 .40369 m .58496 .38144 L .63419 .39529 L p .775 .657 .732 r
F P
0 g
s
.47977 .40199 m .48333 .42102 L .43999 .43121 L p .647 .577 .762 r
F P
0 g
s
.43999 .43121 m .43278 .41317 L .47977 .40199 L p .647 .577 .762 r
F P
0 g
s
.36524 .28254 m .3736 .28325 L .30992 .3148 L p .584 .934 .941 r
F P
0 g
s
.30992 .3148 m .29825 .31581 L .36524 .28254 L p .584 .934 .941 r
F P
0 g
s
.67378 .301 m .66555 .31362 L .60233 .29495 L p .729 .713 .835 r
F P
0 g
s
.59789 .31296 m .60233 .29495 L .66555 .31362 L p .76 .682 .776 r
F P
0 g
s
.46567 .31063 m .46923 .33214 L .41148 .34641 L p .643 .554 .739 r
F P
0 g
s
.41148 .34641 m .40431 .32598 L .46567 .31063 L p .643 .554 .739 r
F P
0 g
s
.41857 .3689 m .41148 .34641 L .46923 .33214 L p .639 .536 .722 r
F P
0 g
s
.47624 .37959 m .47977 .40199 L .43278 .41317 L p .641 .545 .731 r
F P
0 g
s
.43278 .41317 m .42565 .39177 L .47624 .37959 L p .641 .545 .731 r
F P
0 g
s
.46923 .33214 m .47274 .35568 L .41857 .3689 L p .639 .536 .722 r
F P
0 g
s
.42565 .39177 m .41857 .3689 L .47274 .35568 L p .638 .533 .719 r
F P
0 g
s
.47274 .35568 m .47624 .37959 L .42565 .39177 L p .638 .533 .719 r
F P
0 g
s
.57629 .42256 m .57187 .43646 L .52958 .43237 L p .711 .684 .822 r
F P
0 g
s
.46204 .29245 m .46567 .31063 L .40431 .32598 L p .65 .591 .775 r
F P
0 g
s
.40431 .32598 m .39699 .30889 L .46204 .29245 L p .65 .591 .775 r
F P
0 g
s
.53001 .41805 m .52958 .43237 L .48694 .43506 L p .685 .662 .822 r
F P
0 g
s
.48694 .43506 m .48333 .42102 L .53001 .41805 L p .685 .662 .822 r
F P
0 g
s
.77619 .32783 m .76363 .32398 L .70024 .28852 L p 0 .456 .841 r
F P
0 g
s
.69111 .28892 m .70024 .28852 L .76363 .32398 L p .19 .597 .944 r
F P
0 g
s
.4583 .27843 m .46204 .29245 L .39699 .30889 L p .659 .654 .834 r
F P
0 g
s
.39699 .30889 m .38946 .29596 L .4583 .27843 L p .659 .654 .834 r
F P
0 g
s
.52958 .43237 m .53001 .41805 L .57629 .42256 L p .711 .684 .822 r
F P
0 g
s
.68229 .29285 m .67378 .301 L .6069 .2811 L p .654 .749 .92 r
F P
0 g
s
.60233 .29495 m .6069 .2811 L .67378 .301 L p .729 .713 .835 r
F P
0 g
s
.58065 .40369 m .57629 .42256 L .53001 .41805 L p .728 .638 .758 r
F P
0 g
s
.53042 .39873 m .53001 .41805 L .48333 .42102 L p .69 .606 .758 r
F P
0 g
s
.48333 .42102 m .47977 .40199 L .53042 .39873 L p .69 .606 .758 r
F P
0 g
s
.45443 .26887 m .4583 .27843 L .38946 .29596 L p .658 .753 .92 r
F P
0 g
s
.38946 .29596 m .38167 .28749 L .45443 .26887 L p .658 .753 .92 r
F P
0 g
s
.58496 .38144 m .58065 .40369 L .53042 .39873 L p .733 .616 .727 r
F P
0 g
s
.53001 .41805 m .53042 .39873 L .58065 .40369 L p .728 .638 .758 r
F P
0 g
s
.35663 .28425 m .36524 .28254 L .29825 .31581 L p .472 .893 .824 r
F P
0 g
s
.29825 .31581 m .28625 .31925 L .35663 .28425 L p .472 .893 .824 r
F P
0 g
s
.58924 .35769 m .58496 .38144 L .53084 .37603 L p .735 .607 .716 r
F P
0 g
s
.53042 .39873 m .53084 .37603 L .58496 .38144 L p .733 .616 .727 r
F P
0 g
s
.59354 .3343 m .58924 .35769 L .53125 .35182 L p .734 .609 .719 r
F P
0 g
s
.53084 .37603 m .53125 .35182 L .58924 .35769 L p .735 .607 .716 r
F P
0 g
s
.53084 .37603 m .53042 .39873 L .47977 .40199 L p .689 .579 .727 r
F P
0 g
s
.47977 .40199 m .47624 .37959 L .53084 .37603 L p .689 .579 .727 r
F P
0 g
s
.59789 .31296 m .59354 .3343 L .53166 .32796 L p .732 .622 .736 r
F P
0 g
s
.53125 .35182 m .53166 .32796 L .59354 .3343 L p .734 .609 .719 r
F P
0 g
s
.53125 .35182 m .53084 .37603 L .47624 .37959 L p .688 .569 .715 r
F P
0 g
s
.47624 .37959 m .47274 .35568 L .53125 .35182 L p .688 .569 .715 r
F P
0 g
s
.69111 .28892 m .68229 .29285 L .61164 .2717 L p .47 .751 .991 r
F P
0 g
s
.6069 .2811 m .61164 .2717 L .68229 .29285 L p .654 .749 .92 r
F P
0 g
s
.53166 .32796 m .53125 .35182 L .47274 .35568 L p .689 .571 .718 r
F P
0 g
s
.47274 .35568 m .46923 .33214 L .53166 .32796 L p .689 .571 .718 r
F P
0 g
s
.60233 .29495 m .59789 .31296 L .53208 .30613 L p .726 .647 .77 r
F P
0 g
s
.53166 .32796 m .53208 .30613 L .59789 .31296 L p .732 .622 .736 r
F P
0 g
s
.53208 .30613 m .53166 .32796 L .46923 .33214 L p .689 .586 .735 r
F P
0 g
s
.46923 .33214 m .46567 .31063 L .53208 .30613 L p .689 .586 .735 r
F P
0 g
s
.78901 .33274 m .77619 .32783 L .70965 .29055 L p 0 .387 .781 r
F P
0 g
s
.70024 .28852 m .70965 .29055 L .77619 .32783 L p 0 .456 .841 r
F P
0 g
s
.5325 .28764 m .53208 .30613 L .46567 .31063 L p .689 .617 .77 r
F P
0 g
s
.46567 .31063 m .46204 .29245 L .5325 .28764 L p .689 .617 .77 r
F P
0 g
s
.6069 .2811 m .60233 .29495 L .5325 .28764 L p .708 .69 .83 r
F P
0 g
s
.53208 .30613 m .5325 .28764 L .60233 .29495 L p .726 .647 .77 r
F P
0 g
s
.45041 .26353 m .45443 .26887 L .38167 .28749 L p .6 .862 .993 r
F P
0 g
s
.38167 .28749 m .3736 .28325 L .45041 .26353 L p .6 .862 .993 r
F P
0 g
s
.53294 .2733 m .5325 .28764 L .46204 .29245 L p .685 .67 .83 r
F P
0 g
s
.46204 .29245 m .4583 .27843 L .53294 .2733 L p .685 .67 .83 r
F P
0 g
s
.34782 .287 m .35663 .28425 L .28625 .31925 L p .414 .855 .757 r
F P
0 g
s
.28625 .31925 m .27399 .32374 L .34782 .287 L p .414 .855 .757 r
F P
0 g
s
.70024 .28852 m .69111 .28892 L .61655 .26653 L p .152 .631 .924 r
F P
0 g
s
.61164 .2717 m .61655 .26653 L .69111 .28892 L p .47 .751 .991 r
F P
0 g
s
.61164 .2717 m .6069 .2811 L .53294 .2733 L p .655 .751 .92 r
F P
0 g
s
.5325 .28764 m .53294 .2733 L .6069 .2811 L p .708 .69 .83 r
F P
0 g
s
.5334 .26341 m .53294 .2733 L .4583 .27843 L p .656 .752 .92 r
F P
0 g
s
.4583 .27843 m .45443 .26887 L .5334 .26341 L p .656 .752 .92 r
F P
0 g
s
.70965 .29055 m .71927 .29362 L .78901 .33274 L p 0 .387 .781 r
F P
0 g
s
.44624 .26171 m .45041 .26353 L .3736 .28325 L p .419 .859 .918 r
F P
0 g
s
.3736 .28325 m .36524 .28254 L .44624 .26171 L p .419 .859 .918 r
F P
0 g
s
.53294 .2733 m .5334 .26341 L .61164 .2717 L p .655 .751 .92 r
F P
0 g
s
.61655 .26653 m .61164 .2717 L .5334 .26341 L p .496 .792 .998 r
F P
0 g
s
.53387 .25774 m .5334 .26341 L .45443 .26887 L p .541 .831 .999 r
F P
0 g
s
.45443 .26887 m .45041 .26353 L .53387 .25774 L p .541 .831 .999 r
F P
0 g
s
.70965 .29055 m .70024 .28852 L .62164 .26488 L p 0 .455 .752 r
F P
0 g
s
.61655 .26653 m .62164 .26488 L .70024 .28852 L p .152 .631 .924 r
F P
0 g
s
.5334 .26341 m .53387 .25774 L .61655 .26653 L p .496 .792 .998 r
F P
0 g
s
.44195 .2623 m .44624 .26171 L .36524 .28254 L p .22 .739 .734 r
F P
0 g
s
.36524 .28254 m .35663 .28425 L .44195 .2623 L p .22 .739 .734 r
F P
0 g
s
.62164 .26488 m .61655 .26653 L .53387 .25774 L p .177 .686 .901 r
F P
0 g
s
.53436 .25559 m .53387 .25774 L .45041 .26353 L p .271 .766 .898 r
F P
0 g
s
.45041 .26353 m .44624 .26171 L .53436 .25559 L p .271 .766 .898 r
F P
0 g
s
.62164 .26488 m .62689 .26564 L .70965 .29055 L p 0 .455 .752 r
F P
0 g
s
.71927 .29362 m .70965 .29055 L .62689 .26564 L p .222 0 0 r
F P
0 g
s
.53387 .25774 m .53436 .25559 L .62164 .26488 L p .177 .686 .901 r
F P
0 g
s
.43754 .26392 m .44195 .2623 L .35663 .28425 L p 0 0 0 r
F P
0 g
s
.35663 .28425 m .34782 .287 L .43754 .26392 L p 0 0 0 r
F P
0 g
s
.62689 .26564 m .62164 .26488 L .53436 .25559 L p .097 0 0 r
F P
0 g
s
.53487 .25585 m .53436 .25559 L .44624 .26171 L p 0 0 0 r
F P
0 g
s
.44624 .26171 m .44195 .2623 L .53487 .25585 L p 0 0 0 r
F P
0 g
s
.62689 .26564 m .63227 .26744 L .71927 .29362 L p .222 0 0 r
F P
0 g
s
.53436 .25559 m .53487 .25585 L .62689 .26564 L p .097 0 0 r
F P
0 g
s
.63227 .26744 m .62689 .26564 L .53487 .25585 L p .196 0 0 r
F P
0 g
s
.53539 .25714 m .53487 .25585 L .44195 .2623 L p .075 0 0 r
F P
0 g
s
.44195 .2623 m .43754 .26392 L .53539 .25714 L p .075 0 0 r
F P
0 g
s
.53487 .25585 m .53539 .25714 L .63227 .26744 L p .196 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`000003oa<00?m5a>GoR]Co00GoR]Co00?o0000
ogk:oomnb_l00_mnb_l<o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/
ooooo`007Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:
o`000004oa<00?l0003oALCUodG4i@goR]Co1ol0000=ogk:o`go00006Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo02_ooooo000Booooo`Ko00001Oooool00ol0003oooooooooo`04
ooooo`;o00001?ooool00ol0003oooooooooo`1/ooooo`Wo00000_nIg?h00ol0003oR]Cooh[Do`07
oh[Do`[o00001_nW`>/00ol0003oYl3[ojO0j`02ojO0j`So00002_mnb_l;o`0001;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0[ooooo`007Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool9o`0000GoVMcn0ol00002oh[D
o`?o00004_nW`>/00ol0003oYl3[ojO0j`0;ojO0j`So00001?mnb_l01Ol0003oN<3mogS0oOmh`?go
9Z7/00;o07C00_lh0003o`0000oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Z
ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0H_ooool9o`0000GoVMcn1?l00002ojS0j`03o`000?nW`>_oYl3[00ooYl3[1ol0000EojO0
j`Co00001omh`?d00ol0003o07C0o`1d`002ocP000?o00003?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Mooooo`Ko00000_m[fn/6oiWLoPCo00001onX`>/00ol0003o
Yl3[ojO0j`04ojO0j`[o00001_n_Zm@00ol0003o]K3DokF`e002okF`e0So00003?nW`>/01?l0003o
Yko[ojNojol00007ogS0o@03o`000?lVXNco07C000;o>0000ol00009ooooo`03o`000?oooooooooo
02oooooo0_l0000[ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003o
ooooooooo`1Hooooo`Oo000000?oJm_[oiWLo_nIg?h01OnIg?h3o`0000WoZ<3[0ol000000onW`>_o
0000o`000002o`00017o[j_D00?o0000okF`e?ne/=@02_ne/=@8o`0000?oYl3[00?o0000ojNojonW
_n/01OnW_n/2o`0000KoN<3m00Co0000o`1d`?lh003o>0000ol00006ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0:?ooool001_ooooo00?oEEEEofIVI_l000001_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05?ooooo1ol000000om[fn_oVMcnoiWLoP06oiWLoP?o
00001onX`>/5o`0000;oZ:OE00?o0000ojn[e?n_Zm@05?n_Zm@00ol0003o]K3DokF`e00BokF`e0Co
00002_nW_n/4o`0000CoN<3m0_l000000ol0M<3o>000o`000002o`0000Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Xooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04oooooo2?l00003ojSQnP03o`000?nIg?koVMcn00;oVMcn0_l00007ojS0j`Co0000
1onXYmD00ol0003o[j_Dojn[e00Dojn[e003o`000?ne/=Co]K3D01Go]K3D00?o0000okZfeOnj]]D0
0_l0000:ojNoj`Co00000omh`?d2o`000003o`1d`?lh003o000000;o000000?oooooo`000?ooool0
<_ooool00ol0003oooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04cooooo0_l000000omYf/7o0000o`000003o`0000GoZ>7j0ol00007ojS0j`Co00003?nX
YmD00ol0003o[j_Dojn[e008ojn[e0co00001One/=@00ol0003o]K3DokF`e00>okF`e003o`000?nj
]]Go^[KE00Co^[KE1?l00009ojNoj`?o00000omh`?d3o`000004ocP00?l0003o0000o`0003?ooooo
00?o0000ooooooooool09_ooool002?ooooo0_l0000=ooooo`03o`000?oooooooooo04Wooooo0_l0
00000omYf/7o0000o`000003o`0000GoZ>7j0_l00002ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[0ol0
000>ojRWe@?o000000?o[j_Do`000?l000001ol0000;ok2Ma@03o`000?niYLGo^JG500Co^JG52ol0
0005okF`e003o`000?nj]]Go^[KE00So^[KE0ol00009ojNoj`?o00000omg]_T2oc2Hl@03o`000?lh
003o000000;o0000<?ooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Kooooo0_l000001_mYf/7o0000o`000?l0003oUNo`o`0000GoZ>7j
0_l00004ojS0j`?o00003onXYmD4o`0000;oYYO600?o0000ok2MaOn`WLD04on`WLD00ol0003o^JG5
okVUa@0?okVUa@Go00003_nj]]D4o`0000KoYko[00?o0000ojNojomg]_T01?mg]_T01Ol0003o<9Sa
oc2HlOl0M=Oo>00000;o0000;_ooool2o`0002Oooooo000Sooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0@oooool2o`000006ofWJ`Ol0003o0000ogSTd_nEko3o00001OnXhOX2o`00
00CoZ<3[0_l000000onQY=Oo0000ojRWe@0;ojRWe@Co00001_nVUlH00ol0003o/9g5ok2Ma@0Cok2M
a@03o`000?niYLGo^JG501?o^JG500?o0000ol:^a_o2[/H00ol0000=okZfe@?o00000_nW_n/00ol0
003oYko[ojNoj`02ojNoj`?oMkKi0_l00003oc2Hl@04o`1deol0HlOo0000o`0002kooooo00?o0000
ooooooooool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10oooo
o`;o000000KoJM[1o`000?l0003oN>CBoiG_l?l00004ojSQnP?o00001?nX`>/2o`0000CoXJCG00?o
0000ojRWeOnXYmD01OnXYmD4o`0000[oYYO600?o0000ok2MaOn`WLD04on`WLD00ol0003o^JG5okVU
a@0CokVUa@03o`000?o2[/Ko`Zk600?o`Zk60ol0000=okZfe@;o00001onW_n/2o`0000;oMkKi00Ko
0000oc2HlOl`V?7o0000o`1deol0HlL2o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`05o`000?mYf/7o0000o`000?mh
i=800_l00004ojSQnP;o00001OnX`>/2o`0000OoXJCG00Co0000ojRWeOnXYmGoZ:OE0ol0000?ojJG
aP03o`000?n`WLGo/9g500go/9g51_l00003okVUa@03o`000?niYLGo^JG500oo^JG500?o0000ol:^
a_o2[/H01_o2[/H4o`0000[o^[KE00?o0000oknmf?nW_n/01OnW_n/3o`0000?oMkKi00Oo0000oc2H
lOl`V?7o0000o`1deol0HlOo000002cooooo00?o0000ooooooooool08oooool002;ooooo0_l0000C
ooooo`03o`000?oooooooooo03_ooooo0_l000000omYf/7o0000ogSTdP02o`0000CoZ>7j0_l00005
ojS0j`;o00002OnQY=L3o`0001?oYYO600?o0000ok2MaOn`WLD00_n`WLD;o`0000Go/9Jl00?o0000
ok^O_?nkWk`00_nkWk`7o`0000Wo^JG500?o0000ol:^a_o2[/H02oo2[/H3o`0000Ko^[KE00?o0000
oknmf?no_MP00_no_MP4o`000003ojNojol0003oYko[00;o00000omg]_T01Ol0003o<9Saoc2HlOl0
003o07CG00;o0000:oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03Sooooo0_l000001OmYf/7o0000ogSTd_l0003oUNo`00GoZ>7j00?o
0000ojS0jonX`>/00onX`>/2o`0000WoXJCG0_l000000onKTLSo0000ojJGaP0AojJGaP?o000000Co
/9g5o`000?l0003o00004?n`U[`00ol0003o^inlok^O_009ok^O_0Oo00000_niYLD00ol0003o`Zk6
ol:^aP0>ol:^aP?o00000_nj]]D01?l0003o_kgHoknmf?no_MP3o`000003oknmf?l0003o000000;o
Yko[00?o0000ojNojonW_n/00_l00002ogNfn@;o00000_l`V?401?l0003o07CGo`000?l0000Yoooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0=Oooool2o`000004ofWJ`Ol0003oN>CBogSTdP?o00000onXhOX00ol0003oZ<3[ojS0j`03ojS0
j`;o00002OnQY=L2o`0000CoVi7800?o0000ojJGa_nVUlH02onVUlH4o`0000;oY8fm00?o0000ok2F
_?n`U[`04_n`U[`00ol0003o^inlok^O_00@ok^O_0?o00004oo2[/H2o`000004oknmf?l0003o0000
o`0000Ko_kgH0_l000000onW_n_o0000ojNoj`02ojNoj`;o00000_mg]_T2o`0000;o<9Sa1?l0000W
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0booooo`;o00000_mYf/43o`0000Co]^7e0ol00005ojS0j`03o`000?nQY=OoXJCG00OoXJCG0_l0
0006oi^Ab003o`000?nVUlKoYYO600OoYYO61?l00006ojB=_@03o`000?n`U[co/9Jl01;o/9Jl00?o
0000ok^O_?nkWk`04_nkWk`00ol0003oaJVmolFY_@03o`0000ko`Zk61?l0000:oknmf003o`000?nW
_n_o000000CoYko[00Go0000ogNfnOmg]_WoMkKio`000002oc2Hl@;o000000?o06?7o`000?l00000
9oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool0027ooooo0ol0000Gooooo`03o`000?oooooooooo02oooooo
1_l000000onhm_7o0000okKQm@03okKQm@05o`000?nY`>_oZL3[ojW0jol000000_nX`>/00ol0003o
XJCGoj6Te`07oj6Te`;o00002?nKTLP00ol0003oYYO6ojJGaP04ojJGaP?o00002_nTSKd00ol0003o
/9Jlok2F_00Bok2F_003o`000?nkWkco^inl017o^inl00?o0000olFY_Oo5ZKd01?o5ZKd4o`0000Oo
`Zk61?l00004olZib@03o`000?no_MSo_kgH00Oo_kgH0_l00005ojNoj`;o00000_mg]_T2o`0000;o
<9Sa0_l000000ol0HlOo0000o`00000Uooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo01So
oooo0_l0000]ooooo`Co00000_nann800ol0003o^?KaokSfl@04okKQm@03o`000?nY`>_oZL3[00;o
ZL3[0_l0000:oj6Te`03o`000?nKTLSoVi7800WoVi7800?o0000ojJGa_l000000ol0000>ojB=_@03
o`000?n`U[co/9Jl017o/9Jl00?o0000ok^O_?nkWk`04OnkWk`00ol0003oaJVmolFY_@08olFY_@Oo
00000_o2[/H00ol0003ob[W9olZib@04olZib@;o00002Ono_MP2o`0000CoYko[2ol000000ol0HlOo
0000ooooo`0Tooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:Oooool01?l0003o[?[IojcjfOl00002ok7khP03o`000?nhm_7o^?Ka00Co]^7e00?o
0000ojW0jonY`>/00_nY`>/01?l0003oVZ;KoiZRfol00007oj6Te`;o00002onKTLP3o`0001;oY8fm
00?o0000ok2F_?n`U[`03?n`U[`6o`0000;o^inl0ol0000>ok^O_003o`000?o5ZKgoaJVm00WoaJVm
1_l00002ol:^aP03o`000?o:^LWob[W900Kob[W90_l00008oknmf0?o000000GoYko[o`000?nW_^_o
Ykk[o`000003ogZ^m004o`000?m3T_3o@i;`o`0000;o67ST0ol0000Tooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool01?l0003o[?[Iojcj
fOl00002ok7khP03o`000?nhm_7o^?Ka00Co]^7e00?o0000ojW0jonY`>/00_nY`>/00ol0003oVZ;K
oiZRf`02oiZRf`03o`000?nQY=OoXJCG00;oXJCG0_l0000;oi^Ab0;o000000?oUXJoo`000?nTSKd0
4_nTSKd00ol0003o/9Jlok2F_002ok2F_0[o00001On`T[L00ol0003o^i^hok^K^003ok^K^0Wo0000
1?nkWk`00ol0003oaJVmolFY_@07olFY_@?o00001_o5ZKd2o`0000_ob[W90_l00007oknmf003o`00
0?no_MSo000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl005o`000?lHN>Co67STo`00
0?l5Jm`00_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo02Gooooo00Co0000
ojcjfOn/n]Wo00000_nann800ol0003o^?KaokSfl@04okKQm@03o`000?nY`>_oZL3[00;oZL3[00?o
0000oiZRfonJX]/01?nJX]/01?l0003oXJCGoj6Teol0000:oi^Ab0?o00001?nFQ[l00ol0003oY8fm
ojB=_@0>ojB=_@Oo00003on`T[L00ol0003o^i^hok^K^00<ok^K^0Go00001_o5ZKd3o`0000[oaJVm
00?o0000om2e`?l000002oo:^LT2o`0000Go_kgH0_l000000oo3aM_o0000ojNnj`03ojNnj`05o`00
0?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003o`000?oooooooooo
01kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02?ooooo00Co0000ojcjfOn/n]Wo00000_na
nn800ol0003o^?KaokSfl@03okKQm@;o00001?nY`>/00ol0003oVZ;KoiZRf`05oiZRf`;o00002_nK
TLP2o`0000OoUXJo00?o0000ojB=_OnTSKd02OnTSKd5o`0000;oXhVh00?o0000ok2B]on`T[L04On`
T[L00ol0003o^i^hok^K^00@ok^K^003o`000?o7Y[WoajJi00Co00003?o5ZKd00ol0003od;G0om2e
`002om2e`0;o00002_o:^LT00ol0003o_kgHoknmf002oknmf0;o00000_o3aM/00ol0003oYkk[ojNn
j`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003
o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool0
1?l0003o[?[IojcjfOl00002ok7khP?o^?Ka0onfhOD00ol0003oZL3[ojW0j`02ojW0j`;o00001onJ
X]/00ol0003oSHc=o`000008oi^Ab0;o00002OnFQ[l00ol0003oY8fmojB=_@05ojB=_@Co00001onS
RKP00ol0003o/9:gok2B]`0Aok2B]`03o`000?nkVkSo^i^h013o^i^h1?l00002olNV^@Co00002Oo5
ZKd00ol0003od;G0om2e`004om2e`0;o00002Oo:^LT2o`000005oknmf?l0003o`lGKol?5fol00000
0_o3aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o
67SToaQhi?l00002o`E[g003o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Oooooo`04o`000?n/n]Wo[?[Io`0000;o/O_R0onhm_43
okKQm@03o`000?nY`>_oZL3[00;oZL3[00?o0000oiZRfonJX]/01_nJX]/01Ol0003oSHc=ohf<cOn=
S<go000000CoVi780ol0000<oiJ6_`03o`000?nTSKgo000000Co00003?nSRKP00ol0003o/9:gok2B
]`0@ok2B]`03o`000?nkVkSo^i^h00ko^i^h0ol00009olNV^@Co00001Oo5ZKd00ol0003od;G0om2e
`006om2e`0;o00002Oo:^LT01Ol0003o`lGKol?5foo3aM_o000000?o`lGK00?o0000ojNnjonW_^/0
0_nW_^/01Ol0003oNZkdogZ^m?mj[_Co000000;o@i;`00Co0000oaQhi?lHN>Co00000_l5Jm`00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07Oooool00ol0003o[?[Iojcjf@03ok7khP?o^?Ka0onfhOD00ol0003oZL3[ojW0j`02ojW0
j`03o`000?nJX]_oVZ;K00GoVZ;K0_l00005ohf<c@04o`000?nKTLSo0000o`0000koUXJo0ol0000A
oj>9^003o`000?n`T[Oo/9:g013o/9:g00?o0000ok^K^?nkVkP02onkVkP3o`0000;o^i^h00?o0000
olNV^Oo7Y[T02oo7Y[T3o`000003olFY_Ol0003od;G000[od;G00_l00007olZib@;o00000oo3aM/0
1Ol0003o`lGKol?5foo3aM_o000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl004o`00
0?lHN>Co67STo`0000;o1F_L00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`;o00008oooool00ol0003o
ooooooooo`0Kooooo`03o`000?n/n]Wo[?[I00?o/O_R0onhm_44okKQm@CoZL3[00?o0000oiZRfonJ
X]/01OnJX]/00ol0003oSHc=ohf<c@05ohf<c@;o00003_nFQ[l2o`000003oiB0^ol0003oXhVh017o
XhVh00?o0000ok2B]on`T[L04?n`T[L00ol0003o^i^hok^K^008ok^K^0?o00001?nkVkP00ol0003o
ajJiolNV^@0?olNV^@?o00003?o@]L02o`0000Cob[W900Co0000om;5c_oBaLko00000oo3aM/01Ol0
003o`lGKol?5foo3aM_o000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl004o`000?lH
N>Co67STo`0000;o1F_L00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`008?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo00?o0000ojcjfOn/n]T00ona
nn83okSfl@Co]^7e1OnY`>/7oiZRf`03o`000?n=S<goSHc=00GoSHc=00?o0000ohIn`ol000003?nF
Q[l2o`0000CoU82k00?o0000oj>9^?nSRKP04?nSRKP00ol0003o/9:gok2B]`06ok2B]`[o000000?o
^i^ho`000?l000000_l00002ok^K^0?o00001onkVkP00ol0003oajJiolNV^@0@olNV^@04o`000?oB
/k_o0000o`0000cod;G00_l000000oo:^LWo0000om;5cP03om;5cP05o`000?o3aM_o`lGKol?5fol0
00000oo3aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0
003o67SToaQhi?l00002o`E[g003o`000?oooooooooo01cooooo00?o0000ooooool000006oooool0
023ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`03o`000?n/n]Wo[?[I
00?o/O_R2Ol00003ojW0j`OoVZ;K00?o0000ohf<cOn=S<d01On=S<d01Ol0003oQWk3ohIn`on6O/?o
000000SoUXJo0ol00006oiB0^`03o`000?nSRKSoXhVh00koXhVh2ol00009ok2A]`03o`000?nlVkOo
_9^g00;o_9^g2_l00003ok^K^003o`000?o7Y[WoajJi013oajJi00Go0000om:c^ooB/k_od[>ko`00
000=om2e`003o`000?oBaLkod/G>00Cod/G>00Co0000ol?5foo3aM_o00001?o3aM/00ol0003oYkk[
ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[
g003o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Eooooo`04o`000?n/n]Wo[?[Iok7khP?o00000_o<lN/01Ol0
003o_]g_okkMkonngNoo000000;oZL3[0ol00005oiZRf`;o00001on=S<d00ol0003oQWk3ohIn``02
ohIn``03o`000?nFQ[ooUXJo00CoUXJo0_l0000:oiB0^`03o`000?nSRKSoXhVh00WoXhVh1?l00002
oj>8^003o`000?n`TKOo/96g00oo/96g00?o0000okbK]ol000000_l0000:okbK]`Ko00003oo7Y[T0
0ol0003od[>kom:c^`03om:c^`;o00002oo@]L02o`0000Kod/G>00Co0000ol?5foo3aM_o00001?o3
aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67ST
oaQhi?l00002o`E[g003o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool001oooooo
0_l0000Xooooo`03o`000?oooooooooo01?ooooo00?o0000ojcjfOn/n]T00_l000001OoBn^Co0000
olcajoo<lN_o000000?o_]g_00?o0000ojW0jonY`>/00_nY`>/00ol0003oTJ7Oo`000003oiZRf`03
o`000?n=S<goSHc=00KoSHc=00?o0000ohIn`on6O/<01?n6O/<01?l0003oUXJooiJ6_onFQ[l2o`00
00coU82k00?o0000oj>9^?nSRKP01?nSRKP5o`0000KoXhRh00?o0000ok2A]on`TKL03_n`TKL3o`00
013o_9^g00?o0000olNV^?o7Y[P01?l0000;olNV^@03o`000?oB/k_od[>k00God[>k0_l00008om2e
`004o`000?oJa<Cof/C4o`0000Kod/G>00Co0000ol?5foo3aM_o00001?o3aM/00ol0003oYkk[ojNn
j`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003
o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Aooooo`?o00000ooBn^@01Ol0003oc?7[olcajoo<lN_o000000?o
_]g_00Go0000ojW0jonY`>_oZL3[o`000003oi6Qg`03o`000?nJX]_o000000OoSHc=0_l00007ohIn
``04o`000?nFQ[oo0000o`0000koU82k00?o0000oj>9^?nSRKP01?l0000;oj>8^003o`000?n`TKOo
/96g00co/96g0_l000000on`TKOo0000okbK]`0@okbK]`03o`000?o7Y[SoajJh00CoajJh1Ol00006
olNV^@03o`000?oB/k_od[>k00Ood[>k0_l00005om2e`003o`000?oJa<Cof/C400;of/C400?o0000
om;5c_oBaLh01?oBaLh01?l0003o`lGKol?5fol00004ol?5f`03o`000?nW_^_oYkk[00[o00000_lH
N>@01?l0003o1F_Lo`E[g?l0000Nooooo`03o`000?oooooooooo01Oooooo000Oooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03oooool2o`000005om?lgol0003od_[Tom;ji?l00000
0oo<lN/01Ol0003o_]g_okkMkonngNoo000000CoZL3[00?o0000oi6QgonAXMl00_nAXMl00ol0003o
SHc=ohf<c@05ohf<c@03o`000?n6O/?oQWk300OoQWk30_l0000@oiB0^`?o00003onSR;P00ol0003o
/96gok2A]`09ok2A]`?o00000on`TKL00ol0003o_9^gokbK]`0?okbK]`03o`000?o7Y[SoajJh00Wo
ajJh1?l000000oo7Y[Wo0000om:c^`0;om:c^`03o`000?o@]L3od;G000;od;G000?o0000om[4a?oJ
a<@00ooJa<@00ol0003od/G>om;5cP04om;5cP03o`000?o3aM_o000000Co`lGK0ol00002ojNnjPCo
OjO^0omHS^T3o`000005oaQhi?l0003o1F_Lo`E[g?l000007Oooool2o`0001Sooooo000Oooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool01?l0003odocOom?lgol00003om;j
i004o`000?o<lN_oc?7[o`0000Co_]g_00Go0000ojW0jonY`>_oZL3[o`000005oi6Qg`03ogf7dol0
003oSHc=00CoSHc=00?o0000ohIn`on6O/<01on6O/<00ol0003oPWNno`00000>oiB0^`;o000000?o
U7njo`000?nSR;P04?nSR;P00ol0003o/96gok2A]`05ok2A]`?o00001_n`TKL00ol0003o_9^gokbK
]`0>okbK]`03o`000?o7Y[SoajJh00koajJh0ol0000<om:c^`;o000000?od;G0o`000?oJa<@01_oJ
a<@00ol0003od/G>om;5cP04om;5cP04o`000?o3aM_o0000ol?5f`;o000000?oaLgPojNnj_nW_^X0
0onW_^X4ognWkP?oF8kY0_llN^83o`0000;o1F_L00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Eooooo`007oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00Co
0000om?lgooCo=oo00000_oBn^@01Ol0003oc?7[olcajoo<lN_o000000?o_]g_00?o0000ojW0jonY
`>/00_nY`>/00ol0003oTJ7Ooi6Qg`02oi6Qg`04o`000?mmQm?oOHOCo`0000?oSHc=00?o0000ohIn
`on6O/<01on6O/<01Ol0003oPWNnoh9g__n2Mkko000000_oU82k0_l00003oiAo^P03o`000?nSR;So
XhRh00ooXhRh00?o0000ok2A]on`TKL00_n`TKL3o`0000Go/96g1Ol000001?nlVkOo0000o`000?l0
000<okbK]`03o`000?o7Y[SoajJh00ooajJh00Co0000om:c^_l0003o00003?oB/k/2o`0000Sof/C4
00?o0000om;5c_oBaLh01?oBaLh00ol0003o`lGKo`000004olG=h0CoYkkZ00Go0000ognWk_moYnko
OjO^o`000003oeR>j@Co?7[R0_l000000ol5Jmco0000ooooo`0Looooo`03o`000?oooooooooo01Go
oooo000Oooooo`;o0000;Oooool00ol0003oooooooooo`0:ooooo`04o`000?oCo=oodocOo`0000?o
d_[T00Co0000olcajoo<lN_o00000onngNl00ol0003oZL3[ojW0j`02ojW0j`03o`000?nAXMooTJ7O
00?oTJ7O00Oo0000ogf7dommQm?oOHOCo`000?n=S<go000000WoQWk300?o0000oh9g__n2Mkh00_n2
Mkh00ol0003oU82koiB0^`06oiB0^`?o00001_nDOkX00ol0003oXhRhoj>8^00>oj>8^003o`000?n`
TKOo000000[o00001?n`U;X00ol0003o^ifjok^M^P02ok^M^PWo00000onlVkL00ol0003oajJholNV
^00>olNV^003o`000?oB/k[od[>j00;od[>j0_l0000:om:c^`03o`000?oM`koo000000Sof/C400?o
0000om;5c_oBaLh01?oBaLh00ol0003oaLgPo`000003olG=h003o`000?nW_^[oYkkZ00;oYkkZ00Co
0000ognWk_moYnkoOjO^0omHS^T01?l0003o?7[Rocajh_llN^82oc5bg`?o00007Oooool00ol0003o
ooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo
00Co0000om?lgooCo=oo00000_oBn^@01Ol0003oc?7[olcajoo<lN_o000000?o_]g_00Go0000ojW0
jonY`>_oZL3[o`000005oi6Qg`03o`000?mmQm?oOHOC00?oOHOC00?o0000ohIn`on6O/<01on6O/<0
0ol0003oPWNnoh9g_P04oh9g_P03o`000?nDP;_oU82k00?oU82k0_l00009oiAo^P03o`000?nSR;So
XhRh00_oXhRh1ol0000=ok2D^P03o`000?nkWK[o^ifj00_o^ifj1_l0000>olNV^003o`000?oB/k[o
d[>j00Cod[>j0_l00007om:c^`05o`000?oM`koogL>oomg3_ol000002?oJa<@00ol0003od/G>om;5
cP03om;5cP03o`000?o5cN3o000000CoaLgP00Go0000ojNnj_nW_^[oYkkZo`000003ognWkP04o`00
0?mHS^WoF8kYoeR>j@Co?7[R1?laL]l00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?o
oooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool01?l0003odocO
om?lgol00002om;ji005o`000?o<lN_oc?7[olcajol000000onngNl00ol0003oZL3[ojW0j`02ojW0
j`03o`000?nAXMooTJ7O00;oTJ7O00?o0000ogf7dommQm<01?mmQm<00ol0003oQWk3ohIn``06ohIn
``03o`000?n2MkkoPWNn00GoPWNn00Co0000oiB0^onDP;_oU82k0_l0000;oiAo^P03o`000?nSR;So
XhRh00KoXhRh1ol000000onTRk_o0000ok2D^P0?ok2D^P03o`000?nkWK[o^ifj00ko^ifj00?o0000
olJX^oo6Z;/01?l00009olNV^003o`000?oB/k[od[>j00Ood[>j00?o0000om:c^ooB/k/01?oB/k/0
0ol0003ogL>oomg3_`02omg3_`03o`000?oJa<Cof/C400Kof/C400Wo0000om;5c_oBaLkod/G>o`00
0?oHe=Co0000olG=h?l000000oo5cN000ol0003oYkkZojNnjP02ojNnjP05o`000?moYnkoOjO^ognW
k_l000000_mHS^T01Ol0003o?7[Rocajh_llN^;o000000?o<G;O00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Gooooo00Go0000om?lgooCo=oodocOo`000002om;ji005o`000?o<lN_oc?7[olcajol000000onn
gNl01Ol0003oZL3[ojW0jonY`>_o000000GoTJ7O00?o0000ogf7dommQm<00ommQm<00ol0003oKgG9
o`000006ohIn``03o`000?n2MkkoPWNn00KoPWNn00Co0000oiB0^ol0003o00003_nDOkX00ol0003o
XhRhoj>8^005o`000004ojB;^ol0003o0000o`0000CoY8^k00?o0000ok2D^_n`U;X03_n`U;X00ol0
003o^ifjok^M^P0>ok^M^P03o`000?o6Z;_oaZRk00CoaZRk0ol00006olNV^003o`000?oB/k[od[>j
00Sod[>j0_l00003om:c^`03o`000?oM`koogL>o00CogL>o00?o0000om[4a?oJa<@01_oJa<@00ol0
003od/G>o`000002omSDe004o`000?o5cN3oaLgPo`0000?oaLgP00Go0000ojNnj_nW_^[oYkkZo`00
0003ognWkP05o`000?mHS^WoF8kYoeR>jOl000000ollN^84oc5bg`03o`000?oooooooooo01Wooooo
00?o0000ooooool000005?ooool001kooooo0ol0000aooooo`;o00001Oooool01?l0003odocOom?l
gol00002om;ji005o`000?o<lN_oc?7[olcajol000000onngNl00ol0003oZL3[ojW0j`02ojW0j`03
o`000?nAXMooTJ7O00;oTJ7O00?o0000ogf7dommQm<01?mmQm<01?l0003oKgG9ofmebOl00004ohIn
``03o`000?n2MkkoPWNn00OoPWNn0_l0000?oiAo^PCo00000onTRk/3o`0000OoY8^k00?o0000ok2D
^_n`U;X03_n`U;X00ol0003o^ifjok^M^P0=ok^M^P03o`000?o6Z;_oaZRk00SoaZRk1?l00002olNV
^003o`000?oB/k[od[>j00[od[>j0_l000000ooB/k_o0000omg3_`06omg3_`03o`000?oJa<Cof/C4
00Kof/C400?o0000omSDe?oHe=@00_oHe=@01?l0003oaLgPolG=h?l00002olG=h005o`000?nW_^[o
YkkZojNnj_l000001?moYnh01?l0003oF8kYoeR>jOl00003ocajhP05o`000?laL]oo<G;Ooc5bgol0
00007_ooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`0cooooo`05o`00
0?ooooooooooooooool000000_oCo=l01Ol0003od_[Tom;ji?oBn^Co000000;oc?7[00?o0000okkM
konngNl00_nngNl01Ol0003oZL3[ojW0jonY`>_o000000GoTJ7O00?o0000ogf7dommQm<00ommQm<0
1Ol0003oKgG9ofmebOm_MLWo000000?oQWk300?o0000oh9g__n2Mkh01on2Mkh00ol0003oPGJmo`00
000<oiAo^P?o000000CoUH>mo`000?nTRk_oY8^k0ol0000;ojB;^`03o`000?n`U;[o/9Bj00go/9Bj
00?o0000ok^M^_nkWKX03OnkWKX00ol0003oaZRkolJX^`0<olJX^`?o00003_oB/kX2o`0000SogL>o
00?o0000om[4a?oJa<@01OoJa<@00ol0003of=CDomSDe002omSDe004o`000?o5cN3oaLgPo`0000;o
aLgP00?o0000ojNnj_nW_^X00_nW_^X01Ol0003oOjO^ognWk_moYnko000000?oF8kY00Go0000ocaj
h_llN^;o?7[Ro`000003oc5bg`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool0
01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Cooooo00Co0000
oooooooooooo00000_oCo=l01?l0003od_[Tom;ji?l00003olcaj`03o`000?nngNoo000000Co0000
0_nY`>/00ol0003oTJ7Ooi6Qg`02oi6Qg`03o`000?mmQm?oOHOC00?oOHOC00?o0000ofmebOm_MLT0
0om_MLT00ol0003oQWk3o`000009oh9g_P05o`000?n1M[goPGJmoh5f_Ol000002OnDOkX2o`0000Co
UH>m0ol0000>ojB;^`03o`000?n`U;[o/9Bj00go/9Bj00?o0000ok^M^_nkWKX03OnkWKX00ol0003o
aZRkolJX^`0=olJX^`04o`000?oA];ko0000o`0000cod[>j00?o0000omk3__l000002?oM`kl00ol0
003of/C4om[4a003om[4a003o`000?oSel[o000000Cof=CD00Co0000olG=h?o5cN3o00000_o5cN00
1Ol0003oYkkZojNnj_nW_^[o000000CoOjO^00Co0000oeR>jOmHS^Wo00000ollN^801Ol0003o<G;O
oc5bgolaL]oo000001kooooo00?o0000ooooooooool04?ooool001?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo03Kooooo0_l00002om?lg`04o`000?oBn^Cod_[To`00
00;oc?7[1?l00002olCGj003o`000?nY`>[oZL3Z00?o00000onAXMl00ol0003oOHOCogf7d`04ogf7
d`03o`000?m_MLWoKgG900CoKgG900?o0000oh9g__n2Mkh01on2Mkh00ol0003oPGJmoh5f_@02oh5f
_@03o`000?nDOk[oU7nj00GoU7nj0_l00003oiF3_@?o000000?oUH>mo`000?nTRk/03_nTRk/00ol0
003o/9Bjok2D^P05ok2D^Q7o00001_nkWKX00ol0003oaZRkolJX^`0>olJX^`04o`000?oA];kodKBn
om6d_P;o00002OoB/kX01Ol0003og/>nomk3__oN`kko000000SogL>o00Go0000om[4a?oJa<Cof/C4
o`000002on?GbP03o`000?oHe=Cof=CD00;of=CD00Oo0000olG=h?o5cN3oaLgPo`000?o5cN3o0000
00CoYkkZ00Go0000ognWk_moYnkoOjO^o`000002oeR>j@03o`000?llN^;o?7[R00;o?7[R00Co0000
oc5bgolaL]oo00007_ooool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool00_oo
ool001?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Oooooo00Co
0000om?lgooCo=oo00000_oBn^@3o`000003omGUh_l0003oa=OX00?oa=OX00Co0000ojW0j_nY`>[o
ZL3Z0_n8X^D2o`000003oi6Qgol0003oOHOC00CoOHOC00?o0000ofmebOm_MLT01Om_MLT00ol0003o
PWNnoh9g_P05oh9g_P;o00001_n1M[d01?l0003oU7njoiAo^_nDOkX3o`0000;oUH>m0ol00004oiF3
_@03o`000?nTRk_oY8^k00_oY8^k2_l00008ok2K`P03o`000?njXl;o^Z?200Ko^Z?21ol0000?olJX
^`03o`000?oA];kodKBn00CodKBn0_l00007om:c^P03o`000?oN`kkog/>n00;og/>n00?o0000omg3
_ooM`kl01_oM`kl00ol0003of/C4o`000004on?GbP03o`000?oHe=Cof=CD00;of=CD00Oo0000olG=
h?o5cN3oaLgPo`000?o5cN3o000000?oYkkZ00?o0000ognWk_moYnh00_moYnh01?l0003oF8kYoeR>
jOl00003ocajhP05o`000?laL]oo<G;Ooc5bgol000007Oooool2o`0000[ooooo00?o0000oooooooo
ool01?ooool001?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o0000=oooool01Ol0003o
docOom?lgol0003od_[T00;o00001?oEiN800ol0003oa=OXolCGj002olCGj004o`000?nY`>[oZL3Z
ojW0jPCoR:;U00?o0000ogf7dommQm<01?mmQm<00ol0003oKgG9ofmeb@04ofmeb@03o`000?mXK<?o
000000GoPWNn00?o0000oh5f_On1M[d01_n1M[d01?l0003oU7njo`000?l00002oiF3_@?o00001onE
Pkd00ol0003oY8^kojB;^`06ojB;^`Go00000_nUTl<00ol0003o/9_2ok2K`P0=ok2K`P03o`000?nj
Xl;o^Z?200co^Z?200?o0000ol>]`oo3[L<01?l00009olJX^`03o`000?oA];kodKBn00KodKBn00?o
0000om:c^_oB/kX00ooB/kX00ol0003og/>nomk3_P04omk3_P03o`000?oM`koogL>o00KogL>o00?o
0000on?Gb_oSelX00ooSelX00ol0003of=CDomSDe002omSDe007o`000?o5cN3oaLgPolG=h?l0003o
aLgPo`000002ojNnjPOo00000_mHS^T01Ol0003o?7[Rocajh_llN^;o000000?o<G;O00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0fooooo`03o`000?oCo=oodocO
00;o000000?ogNcLo`000?oEiN800ooEiN801Ol0003oa=OXolCGj?o4enSo000000CoZL3Z00Ko0000
ohRRiOn8X^GoR:;UofR3f_l00004ogf7d`03o`000?m_MLWoKgG900CoKgG900Go0000ofQ/`omXK<?o
J6c3o`000003oh9g_P03o`000?n1M[goPGJm00OoPGJm0_l000001?nEPkgo0000o`000?l0000;oiF3
_@03o`000?nTRk_oY8^k00Go00001onUTl<00ol0003o/9_2ok2K`P0=ok2K`P03o`000?njXl;o^Z?2
00co^Z?200?o0000ol>]`oo3[L<01?o3[L<3o`0000KoaZRk00?o0000om6d__oA];h01ooA];h2o`00
00?od[>j00?o0000omk3__oN`kh01OoN`kh00ol0003ogL>oomg3_`05omg3_`03o`000?oSel[ohmO:
00CohmO:00?o0000omSDe?oHe=@00_oHe=@01?l0003oaLgPolG=h?o5cN04o`0000;oYkkZ1?n6XnL3
o`000003oeR>jOl0003o?7[R00;o?7[R00Go0000oc5bgolaL]oo<G;Oo`00000Nooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool001?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo03Gooooo00Co0000om?lgol0003o00000ooMk=`00ol0003oeNGR
omGUhP02omGUhP05o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@;o
J8?J00Co0000ogf7dommQm?o00001om_MLT00ol0003oJ6c3ofQ/``02ofQ/``03o`000?n2Mkko0000
00WoPGJm1?l0000=oiF3_@Co00003OnUTl<00ol0003o/9_2ok2K`P0;ok2K`P03o`000?njXl;o^Z?2
00go^Z?200?o0000ol>]`oo3[L<01oo3[L<4o`000003olJX^ol0003odKBn00_odKBn0_l000000ooB
/k[o0000omk3_P07omk3_P03o`000?oM`koogL>o00?ogL>o00?o0000onSGa?l000001OoSelX00ol0
003of=CDomSDe002omSDe003o`000?o5cN3o000000Co00000onW_^X00ol0003oQZ?WohJSi`02ohJS
i`;oK8cP0_l00003ocajhP05o`000?laL]oo<G;Ooc5bgol000007oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`0dooooo`?o000000?ohNkJo`000?oMk=`00_oMk=`00ol0003oeNGRomGUhP02
omGUhP05o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@06o`000?mX
Pm[oJ8?Jo`000?mmQm?o00001_m_MLT00ol0003oJ6c3ofQ/``04ofQ/``03o`000?n1M[goPGJm00Ko
PGJm0ol00002ohAj`@03o`000?nEPkgoUH>m00WoUH>m0_l000000onISLGo0000ojFC``0>ojFC``03
o`000?n`Vl;o/9_200_o/9_200?o0000okZS`_njXl803?njXl800ol0003o`jg3ol>]``0<ol>]``?o
00003OoA];h2o`0000Wog/>n00Go0000omg3_ooM`koogL>oo`000002onSGa003o`000?oSel[ohmO:
00?ohmO:00?o0000omSDe?oHe=@00_oHe=@2o`0000?oaMKV0_l00003ojNnjP03o`000?n6XnOoQZ?W
00;oQZ?W1?m/S>02o`0000;o?7[R00Go0000oc5bgolaL]oo<G;Oo`00000Oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o0000=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oE
iN801Ol0003oa=OXolCGj?o4enSo000000?oZL3Z00?o0000ohRRiOn8X^D00_n8X^D01?l0003oJ8?J
ofR3f_mXPmX2o`0000KoKgG900?o0000ofQ/`omXK<<01?mXK<<00ol0003oPGJmoh5f_@03oh5f_@Co
00001?n4N/400ol0003oUH>moiF3_@07oiF3_@;o00001?nISLD00ol0003oYI?3ojFC``0:ojFC`a7o
000000?o^Z?2o`000?l000001Ol00006okZS`P03o`000?o3[L?o`jg300go`jg300Co0000olbha_l0
003o00002ooA];h00ol0003oflC2o`000009omk3_P03o`000?oM`koo000000Coj=O400?o0000on?G
b_oSelX00ooSelX01_l0003of=CDomSDe?l0003ofnGLo`0000CoaMKV00Go0000ojNnj_nW_^[oYkkZ
o`000004ohJSi`04o`000?m/S>3oK8cPofb<h0;oFWcJ0ol00003oc5bg`03o`000?oooooooooo01_o
oooo0ol00007ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo
00?o0000on7^f_oQk]X00_oQk]X01Ol0003ogNcLomg/g?oMk=co000000CoeNGR00Go0000olCGj?o4
enSoa=OXo`000003ojW0jP03o`000?n8X^GoR:;U00;oR:;U00Co0000ofR3f_mXPm[oJ8?J0_m?Jll0
0ol0003oKgG9ofmeb@02ofmeb@03o`000?mXK<?oJ6c300CoJ6c300Co0000ofMZ`_l0003oPGJm0ol0
0002oh5f_@03o`000?n4N/7oQ7[100CoQ7[100?o0000oiF3_OnEPkd01?nEPkd2o`0000KoVHg500?o
0000ojFC`onUTl<01onUTl<3o`0000;oZ:CC00?o0000ojnYd_n_ZM802on_ZM800ol0003o]ZoBokJ_
dP06okJ_dPOo00003_o3[L<00ol0003oc;S6olbhaP02olbhaP;o00002?oA];h01Ol0003oflC2om_4
`_oKa<;o000000Wog/>n00?o0000onSGa?oXel@00ooXel@00ol0003ohmO:on?GbP03on?GbP03o`00
0?oHe=Co000000;ofnGL00?o0000olGFi_o5e^H00_o5e^H2o`0000;oYkkZ00?o0000ohJSion6XnL0
0_n6XnL01?l0003oK8cPofb<h?m/S>05oeYlfP;o000000?o<G;Oo`000?ooool07oooool00ol0003o
ooooooooo`02ooooo`03oeEEEOmVIVKo000000Kooooo000Looooo`03o`000?oooooooooo03Cooooo
00?o0000on7^f_oQk]X00_oQk]X01Ol0003ogNcLomg/g?oMk=co000000?oeNGR00?o0000olCGj?o4
enP00_o4enP01Ol0003oZL3ZojW0j_nY`>[o000000CoR:;U00Co0000ofR3f_mXPm[oJ8?J0om?Jll0
1?l0003oKgG9ofmebOl00006ofQ/``03o`000?mWJ/;oIf[200;o00001?n1M[d00ol0003oQ7[1ohAj
`@06ohAj`@04o`000?nEPkgoUH>moiF3_@;o00002?nISLD00ol0003oYI?3ojFC``03ojFC``Co0000
1OnXY=<00ol0003o[jWBojnYdP0;ojnYdP03o`000?nf[m;o]ZoB00co]ZoB00?o0000okbfdonl]]<0
0ol00009ol>]``03o`000?o<^<Koc;S600Coc;S60_l00006om6d_P03o`000?oKa<;oflC200;oflC2
00?o0000omk3__oN`kh01_oN`kh00ol0003oj=O4onSGa004onSGa003o`000?oSel[ohmO:00?ohmO:
00Go0000om_Ug?oKiMcofnGLo`000004olGFiP05o`000?nW_^[o0000ojNnj_l000001?n6XnL01Ol0
003oK8cPofb<h?m/S>3o000000CoFWcJ0_mDM]P00ol0003o<G;Oo`00000Nooooo`?o00003?ooool0
01cooooo00?o0000ooooooooool0=?ooool01Ol0003ohNkJon7^f_oQk][o000000CogNcL00Go0000
omGUh_oEiN;oeNGRo`000004olCGj005o`000?nY`>[oZL3ZojW0j_l000000on8X^D00ol0003oJ8?J
ofR3fP02ofR3fP07o`000?m?JlooCf_?odm[col0003oKgG9o`000006ofQ/``?o000000?oIf[2o`00
0?n1M[d00_n1M[d00ol0003oQ7[1ohAj`@07ohAj`@04o`000?nEPkgo0000o`0000_oVHg500?o0000
ojFC`ol000000_l0000:ojRTd`03o`000?n_ZM;o[jWB00[o[jWB00?o0000okJ_d_nf[m803?nf[m80
0ol0003o_;KCokbfd`03okbfd`?o00001Oo3[L<00ol0003oc;S6olbhaP07olbhaP;o00000ooA];h0
0ol0003oflC2om_4`P04om_4`P03o`000?oN`kkog/>n00Cog/>n00?o0000onSG`ol000001OoXel@0
0ol0003ohmO:on?GbP02on?GbP;o00000ooKiM`00ol0003oaMKVolGFiP02olGFiP05o`000?nW_^[o
0000ojNnj_l000001?n6XnL01Ol0003oK8cPofb<h?m/S>3o000000CoFWcJ1?mDM]P00ol0003ooooo
ooooo`0Iooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003ooooooooo
o`0dooooo`05o`000?oQk][ohNkJon7^f_l000000ooMk=`00ol0003oeNGRomGUhP02omGUhP05o`00
0?o4enSoa=OXolCGj?l000001?nY`>X01Ol0003oR:;UohRRiOn8X^Go000000CoJ8?J00?o0000odm[
com?Jll00_m?Jll00ol0003oJ6c3ofQ/``02ofQ/``?o00001OmWJ/800ol0003oPGJmo`00000:ohAj
`@;o00003?nISLD3o`0000goZ:CC00?o0000ojnYd_n_ZM801?n_ZM87o`0000;o]ZoB1Ol00006okJ_
dP03o`000?nl]]?o_;KC00Oo_;KC0ol00002ol>]``03o`000?o<^<Koc;S600Woc;S60_l000000ooA
];ko0000om_4`P06om_4`P03o`000?oN`kkog/>n00;og/>n00Co0000onSG`ooXel?o00001_oXel@0
1_l0003ohmO:on?Gb_l0003oj>c@o`0000?ofnGL00?o0000olGFi_o5e^H00_o5e^H00ol0003oYkkZ
ojNnjP02o`0000CoQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;o
E7KH00?o0000ooooooooool05Oooool3o`0000Gooooo00?o0000ooooooooool02_ooool001cooooo
0_l0000eooooo`05o`000?oQk][ohNkJon7^f_l000000ooMk=`00ol0003oeNGRomGUhP02omGUhP05
o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@03o`000?mXPm[oJ8?J
00;oJ8?J00?o0000odm[com?Jll00_m?Jll00ol0003oJ6c3o`000002o`0000;oJ6c300?o0000ofMZ
`_mWJ/801?mWJ/800ol0003oQ7[1ohAj`@08ohAj`@03o`000?n:QlWo000000[oVHg50_l000000onO
XMGo0000ojRTd`0;ojRTd`Wo00001_nSa_400ol0003oXLCaoj74l@05oj74l@Oo00003?nl]]<2o`00
00koc;S600?o0000om_4`_oKa<801ooKa<801Ol0003og/>nomk3__oN`kko000000?oj=O300?o0000
onSGa?oXel@00ooXel@00ol0003ohmO:o`000002onS/d005o`000?oKiMcofnGLom_Ug?l000001?o5
e^H01Ol0003oYkkZojNnj_nW_^[o000000CoQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03
o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool04_ooool3o`0000Sooooo00?o0000oooooooo
ool02_ooool001cooooo00?o0000ooooooooool0=?ooool01Ol0003ohNkJon7^f_oQk][o000000?o
gNcL00?o0000omGUh_oEiN800_oEiN801Ol0003oa=OXolCGj?o4enSo000000?oZL3Z00?o0000ohRR
iOn8X^D00_n8X^D01Ol0003oJ8?JofR3f_mXPm[o000000CoCf_?0ol00004ofQ/``03o`000?mWJ/;o
If[200GoIf[200?o0000ohAj`On4N/401_n4N/42o`0000?oRXO900?o0000oiV=aOnISLD01?nISLD3
o`0000CoWj7E00?o0000ojRTdonXY=<01OnXY=<4o`0000;oYLOa00?o0000oj?6lOnSa_402_nSa_40
0ol0003oXLCaoj74l@0;oj74l@03o`000?nP`o7oX<?a00?o00002?nl]]<01?l0003o`KgFo`000?l0
000;olbhaP;o00002OoKa<800ol0003og/>no`000004onSG``03o`000?oXelCoj=O400Coj=O400Go
0000onS/d?oXk=3oj>c@o`000004om_Ug005o`000?o5e^KoaMKVolGFi_l000000onW_^X2o`0000?o
QZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000oooo
ooooool03_ooool4o`0000_ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000oooooooo
ool0=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oEiN800ol0
003oa=OXolCGj007o`0000?oR:;U00Ko0000ofR3f_mXPm[oJ8?Jo`000?m?Jll3o`000004odm[com1
GLSo@Eg8o`0000;oJ6c300?o0000ofMZ`_mWJ/801OmWJ/800ol0003oK776o`000006ohAj`@03o`00
0?n:QlWoRXO900CoRXO900Co0000oiV=aOnISLGoVHg50_l00008oinQe@03o`000?nXY=?oZ:CC00Co
00001OnUao43o`000003oj?6lOl0003o000000Wo00000onQa?43o`0000KoXLCa00?o0000oj33lOnP
`o401?nP`o43o`0000Co_;KC00?o0000ol6me_o1_MH00_o1_MH3o`0000Ooc;S600Co0000omG5booE
aL_o00002OoKa<800ol0003oj=O3onSG``04onSG``03o`000?oXelCoj=O400?oj=O400Go0000onS/
d?oXk=3oj>c@o`000004om_Ug005o`000?o5e^KoaMKVolGFi_l000000onW_^X2o`0000?oQZ?W00Go
0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool0
2oooool3o`00013ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Ooo
ool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oEiN83o`000003olK@
h_nY`>[oZL3Z00;oZL3Z0_moY>/4o`0000;oJ8?J0ol00003odm[c`07o`000?m1GLSo@Eg8od5Mb?l0
003oJ6c3o`000006ofMZ`P04o`000?m/LLKoK776o`0000GoQ7[100?o0000ohZ7bOn:QlT01On:QlT0
1?l0003oVHg5oiV=aOl0000:oinQe@?o00001OnUao44o`000004of7Fi_l0003o0000o`0000Go?;oP
0onlTjd00ol0003o/8V]ok29[@02ok29[@04o`000?nROjko9ZcQobJ/h@Ko00002_nP`o43o`000003
okbfdol0003o`KgF00Ko`KgF0_l00004olbhaP03o`000?oEaL_oeLG;00;oeLG;00?o0000om_4`_oK
a<801_oKa<800ol0003oj=O3onSG``04onSG``03o`000?oXelCoj=O400;oj=O40_l00003onS/d003
o`000?oKiMcofnGL00;ofnGL00Go0000olGFi_o5e^KoaMKVo`000003ojNnjP03o`000?n6XnOo0000
00;oQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000
ooooooooool02?ooool3o`0001?ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000oooo
ooooool0=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00Co0000omGUh_oEiN;oeNGR0_l0
0003olK@hP05o`000?nY`>[oZL3ZojW0j_l000001?moY>/3o`000003ofR3f_l0003oCf_?00?oCf_?
00?o0000od5Mb?m1GLP00_m1GLP00ol0003oIf[2ofMZ`P05ofMZ`P05o`000?m/LLKoK776ofaaa_l0
00000_n4N/42o`0000SoRXO90_l00009oinQe@?o00000_nWao001?l0003oYLOaojG7lOnUao42o`00
00;oHMKV0ol00003omBY[@?o000000?oaij^o`000?nlTjd00_nlTjd00ol0003o/8V]ok29[@02ok29
[@;oXWn^0ol00004oi9c[003o`000?mmIjoo8J3X00Co00001onP`o400ol0003o`KgFol6meP08ol6m
eP;o000000?oc;S6o`000?oEaL/01OoEaL/00ol0003oflC2om_4`P04om_4`P03o`000?oUelOo0000
00Koj=O300Ko0000onSGa?oXelCo0000ong^b?l00004onS/d005o`000?oKiMcofnGLom_Ug?l00000
0oo5e^H01Ol0003oYkkZojNnj_nW_^[o000000;oQZ?W00?o0000ohJSiol000000om/S>000ol0003o
FWcJoeYlfP02oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool01Oooool3o`0001Ko
oooo00?o0000ooooooooool02Oooool001_ooooo0_l0000eooooo`03o`000?oQk][ohNkJ00;ohNkJ
00Co0000omg/g?oMk=cogNcL1?l000000ooFemWo0000olK@hP03olK@hP05o`000?nY`>[oZL3ZojW0
j_moY>/00ol00002odaohP?o00001?m?Jll00ol0003o@Eg8od5Mb002od5Mb003o`000?mWJ/;oIf[2
00CoIf[200?o0000ofaaa_m/LLH00_m/LLH00ol0003oQ7[1o`000009ohZ7b@04o`000?nGW]WoUikI
o`0000GoWj7E0ol00005ojO7l0Co000000?oHMKVo`000?l000000ooQ^Zl01Ol0003oe:V]omBY[OoD
ZJgo000000;ob9b[3?l00002oj9mZ`03o`000?nBLjcoTW>/00;oTW>/00Oo0000ogeW[ommIjoo0000
of5H/Ol0003o8J3X00?o00000_nP`o401?l0003oWl7`oio1l?nO`O02o`0000Wo`KgF0_l00007omG5
b`03o`000?oKa<;oflC200;oflC200Co0000onGGaooUelOo00001_oXel<00ol0003oj=O4o`000002
ong^b003o`000?oXk=3oj>c@00;oj>c@00Ko0000om_Ug?oKiMcofnGLo`000?o5e^H<o`0000?oK8cP
00?o0000oeYlf_mJO=X00_mJO=X00ol0003oE7KHoeAff002oeAff003o`000?oooooooooo00;ooooo
0ol0000Iooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Cooooo00Go
0000on7^f_oQk][ohNkJo`000003omg/g0;o00001?oFemT00ol0003oa]3RolK@hP02olK@hP03o`00
0?nY`>[o000000;o00000omoY>/01Ol0003oC7oRodaoh_m<On;o000000CoCf_?00?o0000od5Mb?m1
GLP00_m1GLP00oloFlOo0000ofMZ`P04ofMZ`P03o`000?m/LLKoK77600?oK77600?o0000ohZ7bOn:
QlT01on:QlT00ol0003oUikIoiNNf@02oiNNf@03o`000?nOXMGoWj7E00;o00001OnWao06o`0000;o
klja00Go0000on6j[ooQ^ZoohKZ_o`000004omBY[@05o`000?o8W:_ob9b[olRLZol000000onlTJ/0
0ol0003o[hNZojn7ZP02ojn7ZP05o`000?nROJ_oXWf[oj9mZol000001?nBLj`01?l0003oOFN_ogeW
[ol00004of5H/@Co00001_nO`O02o`0000Oo`KgF00?o0000olK6f_l000001ooEaL/01Ol0003oflC2
om_4`_oKa<;o000000?oiMO700?o0000onSG`ooXel<01?oXel<01Ol0003okNk8ong^b?o]k/So0000
00Coj>c@00?o0000om_Ug?oKiM`00ol00002ol;Mk@04o`000?nW_^[oYkkZojNnjPCoSZ7Q0ol00002
ofb<h003o`000?mJO=[oFWcJ00;oFWcJ00?o0000oeAff?mDM]P00_mDM]P5o`0001cooooo00?o0000
ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01_l0003ohNkJon7^f_oQk][o
0000omg/g0;o000000?ogM[Co`000?oFemT01?oFemT00ol0003oa]3RolK@hP03o`0000;oZL3Z00?o
0000ognTjomoY>/00_moY>/3odaohP03oamKdOl0003oCf_?00;oCf_?00Go0000od5Mb?m1GLSo@Eg8
o`000002ocmKa`05o`000?mWJ/;oIf[2ofMZ`_l000001_m/LLH00ol0003oRXO9ohZ7b@05ohZ7b@;o
00001OnGW]T3o`0000GoYlO`0_l00002oh_[kP07o`000?ohi[3o0000ono>/Ol0003okljao`000003
on6j[`05o`000?oDZJgoe:V]omBY[Ol000001?o8W:/01Ol0003o_96[okbAZonlTJ_o000000Co[hNZ
00?o0000oj9mZonROJ/00_nROJ/00ol0003oTW>/oi9c[002oi9c[004o`000?mmIjooOFN_o`0000;o
HERa0_l00002oc90/@;o:iW`00?o0000oio1l?nO`O001?nO`O02o`0000Co`KgF00Go0000olK6f_o6
a][oa/KJo`000007omG5b`03o`000?oKa<;o000000GoiMO700?o0000onSG`ooXel<00ooXel<00ol0
003okNk8ong^b002ong^b009o`000?oXk=3oj>c@onS/d?l0003ofnGLo`000?oFmN?o000000;o`]g]
00Go0000ojNnj_nW_^[oYkkZo`000005ohjQh@05o`000?mlS=So0000ofb<h?l000001?mJO=X00ol0
003oE7KHoeAff002oeAff003o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool001[o
oooo00?o0000ooooooooool0=Oooool01?l0003ohNkJon7^f_oQk]X2o`0000CogM[C00?o0000omKG
fOoFemT00_oFemT3o`0000;oa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`08o`000?m<On;o
C7oRo`000?lOFm7o0000odm[col00004od5Mb004o`000?loFlOo?e_7o`0000;oIf[200?o0000ofaa
a_m/LLH01?m/LLH00ol0003oN87?o`000005ohZ7b@03o`000?nGW]WoUikI00CoUikI00Go0000ojW7
konYanooZLO_o`000002ojO7l0;o00000_n;jnh2o`0000;on>J`00Co0000ono>/Oo_c[7o00001?oQ
^Zl01Ol0003oe:V]omBY[OoDZJgo000000Cob9b[00Go0000okbAZonlTJ_o_96[o`000004ojn7ZP03
o`000?nROJ_oXWf[00;oXWf[00?o0000oi9c[?nBLj`00_nBLj`01_l0003oOFN_ogeW[ol0003oHERa
o`0000;oH5Na00Ko0000oc90/Olb@;7o01VUo`000?l[VO03o`0000CoWl7`0_l000000oo1_MKo0000
olK6fP04olK6fP03o`000?oEaL_oeLG;00GoeLG;00?o0000onGGaooUelL01?oUelL00ol0003oj=O3
onSG``02onSG``;o00001?o]k/P01?l0003oj>c@onS/d?oXk=02o`000003omKehol0003o`]g]00;o
`]g]00Go0000ojNnj_nW_^[oYkkZo`000004ohjQh@04o`000?mlS=So0000ogb<f0;o00001?mJO=X0
0ol0003oE7KHoeAff002oeAff003o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool0
01[ooooo0ol0000eooooo`03o`000?oQk][ohNkJ00;o00001OoMf]<00ol0003oe]OIo`000003o`00
00Coa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`04o`000?m<On;oC7oRodaohP;o7e_A0_l0
0004od5Mb007o`000?loFlOo?e_7ocmKaol0003oIf[2o`000005ofaaaP05o`000?mhPLooN87?ogR1
col000000on:QlT00ol0003oUikIoiNNf@04oiNNf@03o`000?nYanooZLO_00;oZLO_1_l000001OoY
mjOo0000ooSV/?ohi[3o000000?oklja0_l00002on6j[`03o`000?oDZJgoe:V]00;oe:V]00?o0000
olRLZoo8W:/00_o8W:/01Ol0003o_96[okbAZonlTJ_o000000Co[hNZ00?o0000oj9mZonROJ/00_nR
OJ/00ol0003oTW>/oi9c[002oi9c[003o`000?mmIjooOFN_00;o00000omPEk401ol0003o<T2aoc90
/Ol06JGo0000o`0BX?l000000_l[VO02o`0000;oWl7`00?o0000oio1l?l000001oo6a]X00ol0003o
eLG;omG5b`03omG5b`;o00001ooUelL01_l0003oj=O3onSG`ol0003ok^k7o`0000CokNk800?o0000
onS/d?oXk=000_l00002omKeh`05o`000?o2gNgo`]g]ol;MkOl000000onW_^X00ol0003oSZ7QohjQ
h@02ohjQh@05o`000?mlS=SoO8cHo`000?mlS=P00_l00003oeYlfP03o`000?mDM]SoE7KH00;oE7KH
00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`0eooooo`05o`000?oQk][o0000on3KdOl000001?oMf]<3o`0000Coe]OI00Go0000olK@h_o6d>;o
a]3Ro`000003ojW0jP05o`000?moY>_oOjC[ognTjol000000om<On801?l0003o7e_AoamKdOl00004
od5Mb003o`000?loFlOo?e_700;o?e_700?o0000ofaaa_m/LLH01?m/LLH00ol0003oN87?ogR1c`02
ogR1c`03o`000?n:QlWo000000KoUikI00?o0000ojW7konYanl00_nYanl01?l0003o[oGbojoel_n_
mO82o`0000;ojONW00Co0000ooSV/?ohi[3o00000_o_c[401_l0003ohKV_on6i[ol0003ohKZ_o`00
00Coe:V]00Go0000olRLZoo8W:_ob9b[o`000004okbAZ`03o`000?n_Qj[o[hNZ00;o[hNZ00?o0000
oj9mZonROJ/00_nROJ/00ol0003oTW>/oi9c[003oi9c[004ogeW[ol0003oOFJ^o`0000CoH5Na00Oo
0000oc90/Olb@;7o0000o`0T[Ol04Z3o03>/00Go00001?nO_nl00ol0003oa/KJolK6fP04olK6fP05
o`000?oEaL_oeLG;omG5bol000000_oLeM400ol0003oiMO7onGGa`04onGGa`03o`000?oXel?o0000
00;ok^k700?o0000ong^b?o]k/P00_o]k/P01Ol0003oj>c@o`000?oNoM3o000000;oe_GS00Co0000
ol;MkOo2gNgo00000onW_^X00ol0003oSZ7QohjQh@02ohjQh@06o`000?mlS=SoO8cHogb<f?l0003o
O8cH0_maOm82o`000003oeYlf_l0003oE7KH00?oE7KH00?o0000ooooooooool07oooool00ol0003o
ooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Gooooo0_l00003on3Kd@Co00000_oMf]<00ol0
003oe]OIomKGf@02omKGf@05o`000?o6d>;oa]3RolK@h_l000001?nY`>X01Ol0003oOjC[ognTjomo
Y>_o000000;oC7oR00Go0000oamKdOlOFm7o14G5o`000003od5Mb003o`000?loFlOo?e_700;o?e_7
00?oB6C<o`000?m/LLH00om/LLH00ol0003oN87?ogR1c`04ogR1c`;o00001OnGW]T00ol0003oZLO_
ojW7k`02ojW7k`03o`000?n_mO;o[oGb00?o00000_oYmjL2o`000003ooSV/?l0003oklja00;oklja
00Co0000on6i[ooQ^JoohKV_0_l00004omBY[@05o`000?o8W:_ob9b[olRLZol000001?nlTJ/00ol0
003o[hNZojn7ZP03ojn7ZP05o`000?nROJ_oXWf[oj9mZol000001?nBLj`2o`0000?oOFJ^00Go0000
of1G/OmPEk7oH5Nao`000002oc90/@03o`000?l09:go02B]00;o01:P00Co03>/ocjElOlnUO7o?YGa
1OnO_nl00ol0003oa/KJolK6fP04olK6fP03o`000?oEaL_o000000Cog=GA00?o0000onGGaooUelL0
1?oUelL01Ol0003ok^k7onk^aoo^k/Oo000000CokNk80_l000001OoNoM3o0000omKehooFmN?o0000
00?o`]g]00Go0000ojNnj_nW_^[oYkkZo`000004ohjQh@03o`000?mlS=SoO8cH00;oO8cH00?o0000
og5od_maOm800_maOm82o`0000CoE7KH00?o0000ooooooooool07oooool00ol0003oooooooooo`08
ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oPfm7oh=_A00?o00001OoMf]<00ol0003oe]OIomKGf@02
omKGf@03o`000?o6d>;oa]3R00;oa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`04o`000?m<
On;oC7oRo`0000;o7e_A00Go0000o`A5aOl0003o@Eg8o`000005ocmKa`;oB6C<00Go0000ofaaa_m/
LLKoK776o`000006ogR1c`;oSIgN00Go0000oiNNfOnGW]WoUikIo`000004ojW7k`05o`000?n_mO;o
[oGbo`000?o6o/T00_l000001?oYmjOo0000ooOV]Oogi[D2o`0000;oklja00?o0000on6i[ooQ^Jl0
0_oQ^Jl00ol0003oe:V]o`000003o`0000Cob9b[00?o0000okbAZonlTJ/00_nlTJ/00ol0003o[hNZ
ojn7ZP03ojn7ZP03o`000?nROJ_oXWf[00;oXWf[00KoTW>/o`000?l0003o0000oi9b[?l00003ogeV
[P03o`000?mPEk7oH5Na00;oH5Na0_lb@;401_lhAkGo0000o`0T[Ol09:go0000o`0BX0;o00000_ln
UO400ol0003oWko_oinok`02oinok`03o`000?o6a][oa/KJ00Coa/KJ00?o0000omcEdOoLeM400ooL
eM400ol0003oiMO7onGGa`04onGGa`03o`000?o^k/Ook^k700;ok^k700Go0000ong^b?o]k/SokNk8
o`000002omkmd004o`000?oFmN?oe_GSo`0000;o`]g]00Go0000ojNnj_nW_^[oYkkZo`000005ohjQ
h@03o`000?mlS=SoO8cH00;oO8cH0_l00004og5odP;o00000omDM]P00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0eooooo`?o00000_oPfm400ol0003ogM[ComgJd`03omgJd`03
o`000?oFemWoe]OI00?oe]OI00Go0000olK@h_o6d>;oa]3Ro`000003ojW0jP05o`000?moY>_oOjC[
ognTjol000000om<On800ol0003o7e_AoamKd@02o`A5a@;o00001?loFlL01ol0003oB6C<odQTc?m8
I<co0000ofaaa_l000001_mhPLl01ol0003oSIgNohfMg_n=WMko0000oiNNfOl000001?nYanl01Ol0
003o[oGbojoel_l0003oa_k900Co00000oogi[D01Ol0003okljaono>/Oo_c[7o000000?ohKV_00?o
0000omBY[OoDZJd00ooDZJd4o`000003olRLZol0003o_96[00?o_96[00?o0000ojn7Z_n_QjX00on_
QjX01?l0003oXWf[oj9mZonROJ/2o`0000CoTW:/00?o0000ogeV[_mmIZh00_mmIZh01?l0003oH5Na
of1G/OmPEk42o`0000;o>4Ne00Co0000o`0T[Ol9?;co00000_l0Cld01?l0003o?YGaocjElOl00004
oinok`07o`000?o6a][oa/KJolK6f_l0003ob=3Oo`000006omcEd@03o`000?oUelOoiMO700;oiMO7
0_l00004onk^a`07o`000?o]k/SokNk8ong^b?l0003og_g@o`000002omKeh`05o`000?o2gNgo`]g]
ol;MkOl000000onW_^X00ol0003oSZ7QohjQh@02ohjQh@03o`000?mlS=SoO8cH00;oO8cH00?o0000
og5od_l000001?maOm82ofekc`04o`000?mDM]SoE7KHo`00027ooooo00?o0000ooooooooool02?oo
ool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`03ooooo`?o0000<oooool4
o`0000Goh=_A00?o0000omgJdooMf]<00ooMf]<00ol0003oe]OIomKGf@02omKGf@05o`000?o6d>;o
a]3RolK@h_l000001?nY`>X01?l0003oOjC[ognTjol00003odaohP04o`000?lOFm7o7e_Ao`0000;o
14G500?o0000ocmKaoloFlL00_loFlL00ol0003oB6C<odQTc002odQTc003o`000?mhPLooN87?00Co
N87?00?o0000ohfMg_n=WMh00on=WMh3o`0000;oZLO_1?l000001_o6o/Wo0000o`000?l0003ojONW
o`0000?omnJe00Go0000ono>/Oo_c[7okljao`000003on6i[`03o`000?oDZJgoe:V]00?oe:V]00Co
0000olRLZoo8W:_ob9b[1Ol000000onlTJ_o0000ojn7ZP04ojn7ZPCo000000?oXWf[o`000?nBLZ`0
1?nBLZ`01Ol0003oOFJ^ogeV[_mmIZko000000CoH5Na00So0000ocQ7]OlhAkGo>4Neo`0T[Ol0003o
2Cblo`0000;o04o=00Co0000ocjElOlnUO7o00001?nO_nl00ol0003oa/KJo`000003olS@g`03o`00
0?oLeM7og=GA00?og=GA00Oo0000onGGaooUelOoiMO7o`000?o[kLgo000000Cok^k700Co0000ong^
b?o]k/So00000_oNoM001?l0003oe_GSomKehol00002ol;Mk@03o`000?nW_^[oYkkZ00;oYkkZ00?o
0000ohjQhOn>XN400_n>XN400ol0003oO8cHogb<f002ogb<f004o`000?maOm;oLGoBo`0000;oLGoB
00Oo0000ofekcom]NlooKG_?o`000?mDM]So0000027ooooo00?o0000ooooooooool02?ooool000?o
oooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0<Oooool2o`0000Cooooo00?o0000on3KdOoPfm400_oPfm400ol0003ogM[ComgJd`03omgJ
d`03o`000?oFemWoe]OI00;oe]OI00?o0000olK@h_o6d>800_o6d>800ol0003oZL3Zo`000004o`00
0005ognTjol0003oC7oRodaoh_l000000_lOFm401?l0003o14G5o`A5aOl00004ocmKa`03o`000?m8
I<coB6C<00;oB6C<00?oGW[Go`000?mhPLl00omhPLl00ol0003oSIgNohfMgP04ohfMgP03o`000?n[
ankoZlO^00?o00000_o6l^h01?l0003oa_k9o`000?oZn[T2o`0000?omnJe00Go0000ong>]?l0003o
kljao`000004on6i[`03o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00_o8W:/01?l0003o
_96ZokbAZ_nlTJX8o`0000CoXWf[00?o0000oi9b[?nBLZ`00onBLZ`00ol0003oOFJ^ogeV[P02ogeV
[P03o`000?mPEk7oH5Na00;o00000olhAkD01Ol0003o02B]o`Tl_?l9?;co000000;o04o=1?l00002
oinok`?o00001?o8d=l00ol0003og=GAomcEd@04omcEd@03o`000?oUelOo000000;ojng=00?o0000
onk^aoo^k/L00_o^k/L01_l0003okNk8o`000?l0003og_g@o`0000;oe_GS00Go0000ol;MkOo2gNgo
`]g]o`000003ojNnjP03o`000?n>XN7oSZ7Q00;oSZ7Q00?o0000ogb<f?mlS=P00omlS=P01ol0003o
LGoBog5od_maOm;o0000og5od_l000001?m]Nll2o`00027ooooo00?o0000ooooooooool02?ooool0
00?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02kooooo0ol00006ooooo`03o`000?oPfm7oh=_A00?oh=_A00?o0000omgJdooMf]<00_oMf]<00ol0
003oe]OIomKGf@03omKGf@03o`000?o6d>;o000000?o00000_nZ_nT00ol0003oMJSbogFXlP03o`00
0003odaoh_l0003o7e_A00;o7e_A00Co0000o`A5aOl0003o00000oloFlL00ol0003oB6C<odQTc002
odQTc0;oGW[G00Go0000ogR1comhPLooN87?o`000005ohfMgP03o`000?n[ankoZlO^00;oZlO^00?o
0000olKbk_o6l^h00ol00002on[j^@05o`000?ogi[GomnJeooOV]Ol000000_o]c[@00ol0003oklja
o`000003on6i[`03o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96Z
okbAZP02okbAZP03o`000?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/
oi9b[002oi9b[003o`000?mmIZkoOFJ^00;oOFJ^00?o0000of1G/Ol000000_mSFk<01_l0003o>4Ne
ocQ7]OlhAkGo02B]o`0000;o2Cbl00?o0000o`1?cOl000000_mDT^d3o`0000;oWkg^00?o0000olS@
goo8d=l00oo8d=l00ol0003og=GAomcEd@03omcEd@;o00000oo[kLd00ol0003ok^k7onk^a`02onk^
a`?o00000_oNoM001?l0003oe_GSomKehol00003ol;Mk@05o`000?nW_^[oYkkZojNnj_l000001?n>
XN400ol0003oO8cHogb<f002ogb<f003o`000?maOm;oLGoB00?oLGoB00?o0000ofekcom]Nll01?m]
Nll00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00001?nHV9SooooooiRHV?mg
MgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool3o`0000Wooooo00?o
0000on3KdOoPfm400ooPfm400ol0003ogM[ComgJd`03omgJd`04o`000?oFemWoe]OIomKGf@?o0000
0_o5b=`00ol0003oZ[oYojZoj@02ojZoj@08o`000?meZ?;oMJSbo`000?lVNNCo0000odaoh_l00002
oamKd@05o`000?l4ALGo14G5o`11`_l000000_loFlL01Ol0003oB6C<odQTc?m8I<co000000?oGW[G
00?o0000ogR1col000001On=WMh00ol0003oZlO^oj_7kP02oj_7kP03o`000?o6l^koa_;^00;o0000
00GoiOSBo`000?oZn[Woj_Zio`000002ooOV]@03o`000?o]c[CokLjd00;okLjd0_l00003on6i[`03
o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96ZokbAZP02okbAZP03
o`000?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/oi9b[003oi9b[003
o`000?mmIZkoOFJ^00;oOFJ^00Go0000of=K/omSFk?oHe^co`000004ocQ7]@07o`000?l9?;co2Cbl
o`Tl_?l0003o04o=o`000002oeBBk@03o`000?nO_NkoWkg^00;oWkg^00?o0000olS@goo8d=l00_o8
d=l00ol0003og=GAomcEd@02omcEd@03o`000?oPj=So000000?ojng=00Co0000onk^aoo^k/Ook^k7
0_l000001OoNo/;o0000omkmd?oNoM3o000000;oe_GS1_l00002ojNnjP05o`000?n>XN7oSZ7QohjQ
hOl000001OmlS=P00ol0003oLGoBog5odP03og5odP03o`000?m]NlooKG_?00CoKG_?00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`07ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`00
00Gooooo00?o0000ooooooooool0:?ooool3o`0000gooooo00?o0000on3KdOoPfm400_oPfm400ol0
003ogM[ComgJd`03omgJd`06o`000?oFemWoe]OIo`000?oBb];o00001?o5b=`00ol0003oZ[oYojZo
j@02ojZoj@04o`000?meZ?;oMJSbo`0000;o9WWT0_l000001_lOFm7o0000o`A5aOl4ALGo0000o`11
`P;o00001?m8I<`00ol0003oGW[Goeije`02oeije`;o00001?n=WMh00ol0003oZlO^oj_7kP02oj_7
kP05o`000?o6l^koa_;^olKbk_l000000_oUn=801?l0003oj_Zio`000?l00002ooOV]@03o`000?o]
c[CokLjd00;okLjd00?o0000on2j/Ol000000_oQ^Jl00ol0003oe:V]omBY[@03omBY[@03o`000?o8
W:_ob9b[00?ob9b[00?o0000okbAZ_nlTJX00_nlTJX00ol0003o[hNZojn7ZP03ojn7ZP03o`000?nR
OJ_oXWf[00?oXWf[00?o0000oi9b[?nBLZ`00onBLZ`01?l0003oOFJ^ogeV[_mmIZh2o`0000CoHe^c
00Go0000ocQ7]OlhAkGo>4Neo`000003o`Tl_003oc9QdOl0Clgo000000?oE9;]00Go0000oinmk_nO
_NkoWkg^o`000005olS@g`04o`000?oLeM7og=GAo`0000;oh>SH00Go0000on_]cOo[kLgojng=o`00
0002onk^a`04o`000?oNoKoo0000o`0000;og_g@00?o0000omKehol000000_l00002ok_Tl`03o`00
0?nW_NWoYkgY00?o00000on>XN400ol0003oO8cHogb<f002ogb<f003o`000?maOm;oLGoB00?oLGoB
00?o0000ofekcol000001?m]Nll00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
000Iooooo`;o00009_ooool3o`00013ooooo00?o0000on3KdOoPfm400ooPfm400ol0003ogM[ComgJ
d`02omgJd`03o`000?oFemWo000000?od/[B00?o0000olG8g?o5b=`00_o5b=`00ol0003oZ[oYojZo
j@02ojZoj@07o`000?meZ?;oMJSbo`000?lVNNCo0000o`11`P02o`0000;o14G500Co0000o`11`_l0
@L;o00001?m8I<`00ol0003oGW[Goeije`02oeije`;oPYgT00Go0000ohfMg_n=WMkoSIgNo`000004
oj_7kP04o`000?o6l^koa_;^o`0000?oiOSB0_l00002oo;V_P;o00001?o]c[@01?l0003oh;Zaon2j
/OoP^[42o`0000Koe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96ZokbAZP02okbAZP03o`00
0?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/oi9b[003oi9b[004o`00
0?mmIZkoOFJ^o`0000;oOfVa00?o0000of=K/omSFk<00_mSFk<2ocQ7]@03o`000?m5EKko000000;o
2Cbl00Co0000oc9QdOl0Clgo00000omDT^d01Ol0003oWkg^oinmk_nO_Nko000000Cob=3O00?o0000
omcEdOl000000ooPj=P02ol0003ojng=on_]cOo[kLgo0000onk^aol0003og_foo`000?oNo/;o0000
00;og_g@0_l000001Oo1oNCo0000ok_Tlonki??o000000CoYkgY00Ko0000oiFPfol0003o0000ohjQ
hOl00004ogb<f003o`000?maOm;oLGoB00?oLGoB00Co0000ofekcom]Nloo00000om]Nll00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo02?ooooo
0ol0000Cooooo`03o`000?oPfm7oh=_A00?oh=_A00?o0000omgJdooMf]<00ooMf]<00ol0003od/[B
om;:dP03om;:dP03o`000?o5b=coaLSL00;oaLSL00?o0000ojZojOnZ_nT00_nZ_nT02Ol0003oMJSb
ogFXl_l0003o9WWTo`000?l0@L;o7e_Ao`000002o`A5a@04o`000?l0@L;o4E3<o`0000?oB6C<00?o
0000oeijeomNN]L00_mNN]L3oh:Mi003o`000?n=WMko000000CoZlO^1?l00003onGhdP03o`000?oZ
n[Wo000000;ol^Jn00?o0000ong>]?o]c[@00oo]c[@00ol0003oh;Zaon2j/@02on2j/@?o00001?oD
ZJd00ol0003ob9b[olRLZ`02olRLZ`03o`000?nlTJ[o_96Z00?o_96Z00?o0000ojn7Z_n_QjX01?n_
QjX00ol0003oXWf[oj9mZ`02oj9mZ`03o`000?nBLZcoTW:/00CoTW:/00?oOFJ^o`000?moJK400_mo
JK400ol0003oHe^cof=K/`02of=K/`03o`000?lhAkGo000000;oAEFn0_l9?;`01?l0003o<V7Aoc9Q
dOl00003oeBBk@03o`000?nO_NkoWkg^00;oWkg^00Co0000olS@goo8d=oob=3O0_l00004on3Xf004
o`000?o[kLgojng=on_]c@;o00000_oNoKl00ol0003og_k2o`000002o`0000;o`OgT00Co0000ok_T
lonki??o00001?nW_NT00ol0003oUJ3KoiFPf`02oiFPf`;o00000omlS=P00ol0003oLGoBog5odP03
og5odP03o`000?m]NlooKG_?00;oKG_?00?o0000ofekcol000009?ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Pooooo`?o00005oooool00ol0003oh=_Aon3Kd@03on3K
d@04o`000?oMf]?ogM[ComgJd`;o00001_oBb]800ol0003oaLSLolG8g002olG8g003o`000?nZ_nWo
Z[oY00;oZ[oY00Oo0000ogFXl_meZ?;o0000obIii?l0003o047200;o000000Ko14G5o`000?l0@L;o
0472oa5@c?l00002odQTc003o`000?mNN]OoGW[G00;oGW[G00Co0000oh:Mi?n2WNCoPYgT1ol00002
om7XiP04o`000?oUn=;oiOSBonGhdP;o00000oobi[h00ol0003okLjdong>]002ong>]003o`000?oP
^[7oh;Za00?oh;Za00?o0000om>[[ooCZjl01?l00005olRLZ`03o`000?nlTJ[o_96Z00?o_96Z00?o
0000ojn7Z_n_QjX01?n_QjX00ol0003oXWf[oj9mZ`03oj9mZ`03o`000?nBLZcoTW:/00;oTW:/0_l0
0005ogmY/@03o`000?mSFk?oHe^c00;oHe^c00Oo0000odEE__m5EKkoAEFno`000?l9?;co000000?o
<V7A1Ol00003oinmkP06o`000?o8d=oo0000o`000?o9f^Ko00001?oPj=P01Ol0003ojng=on_]cOo[
kLgo000000;og_fo00So0000omkn`_l0003o0000ojof^_l0003o`OgTo`0000;o^nCc00?o0000ojNm
jOnW_NT00_nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7o000000;oO8cH00?o0000og5o
d_maOm800omaOm800ol0003oKG_?ofekc`02ofekc`03o`000?m]Nloo000002Cooooo00?o0000oooo
ooooool01oooool001Sooooo00?o0000ooooooooool07Oooool3o`0001[ooooo00?o0000on3KdOoP
fm400ooPfm401?l0003ogM[ComgJdol00002omW;c003o`000?oBb];od/[B00?od/[B00?o0000olG8
g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb00?o0000obIii?l000000_l07ZD2
o`0000;o04720_lAD<`2o`0000GoGW[G00Go0000oh:Mi?n2WNCoPYgTo`000004ojc6k@05o`000?oA
j>KodNSVom7Xi_l000000_oUn=82o`0000?ol^Jn00?o0000onW?^ol000000oo]c[@00ol0003oh;Za
on2j/@02on2j/@03o`000?oCZjoodj^_00Codj^_0ol00003olRLZ`03o`000?nlTJ[o_96Z00?o_96Z
00?o0000ojn7Z_n_QjX01?n_QjX00ol0003oXWf[oj9mZ`03oj9mZ`03o`000?nBLZco000000;o0000
00?oTgF^o`000?moJK401?moJK400ol0003oHe^cof=K/`02of=K/`03o`000?m5EKkoAEFn00;oAEFn
00?o2Cblo`000?lbHM400_lbHM44ofV@i@Ko00000oo9f^H00ol0003oh>SHon3Xf002on3Xf003o`00
0?o[kLgojng=00;o00000_oNoKl01ol0003og_k2o`000?n_m[[o0000ol7mi?l000000_nki?<00ol0
003oYkgYojNmj@02ojNmj@03o`000?nEX=_oUJ3K00?oUJ3K00Oo0000ohV=dOn9SM7oRHgAo`000?ml
S=So000000GoLGoB00?o0000ofekcom]Nll00om]Nll00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Oooooo000Hooooo`03o`000?oooooooooo01[ooooo0ol0000Mooooo`03o`000?oPfm7o
h=_A00?oh=_A00?o0000omgJdol000001?oIbl`00ol0003od/[Bom;:dP03om;:dP03o`000?o5b=co
aLSL00?oaLSL00Go0000ojZojOnZ_nWoZ[oYo`000003ogFXlP03o`000?lVNNCo000000;o01jU00Co
14G5o`000?l0@L;o00000_lAD<`2o`0000?oGW[G00?o0000oh:Mi?n2WN@00_n2WN@00ol0003o[<K]
ojc6k@02ojc6k@09o`000?oAj>KodNSVom7Xi_l0003oiOSBo`000?oXi<go000000?ol^Jn00Ko0000
onW?^ooYck_o0000ong>]?l00005on2j/@03o`000?oCZjoodj^_00Codj^_00?o0000olNM[Oo7WJd0
1?l00005okbAZP03o`000?n_Qj[o[hNZ00Co[hNZ00?o0000oj9mZonROJ/01Ol00005oi=e[P03o`00
0?moJK7oOfVa00;oOfVa00Oo0000of=K/omSFk?oHe^co`000?mZIK[o000000CoAEFn0_l00002oc9Q
d@03o`000?mYT>GoJI3U00;oJI3U1?nP_>d01Ol0003obM[VolWJi_o9f^Ko000000Coh>SH00Co0000
on_]cOl0003o00000ooNoKl2o`000004ojof^_l0003o`OgTo`0000;o^nCc00?o0000ojNmjOnW_NT0
0_nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00?oRHgA00?o0000og5od_maOm80
0omaOm800ol0003oKG_?ofekc`04ofekc`;o00009?ooool00ol0003oooooooooo`07ooooo`006?oo
ool2o`0001Sooooo0ol0000Qooooo`03o`000?oPfm7oh=_A00;oh=_A0_l00006omW;c003o`000?oB
b];od/[B00?od/[B00?o0000olG8g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb
0_l000001?l0@L;o01jUo`0NYOl00002o`11`P;o4E3<0_lkL]d2o`000003oeijeol0003oPYgT00?o
PYgT00?o0000ojc6kOn/a^d00_n/a^d01_l0003odNSVom7Xi_l0003oiOSBo`0000;oj>C=00Co0000
oo;V__obi[ko00000ooYck/00ol0003okLjdo`000005on2j/@03o`000?oCZjoodj^_00?odj^_00?o
0000olNM[Oo7WJd01?o7WJd4o`0000;o_96Z00Co0000ojn7Z_n_Qj[o[hNZ1_l00003oj9o[@03o`00
0?nCMJkoTgF^00CoTgF^00?o0000ogmY/OmoJK400omoJK400ol0003oHe^co`000002ofYU^P03o`00
0?m5EKkoAEFn00;oAEFn0_mKKL`00ol0003o<V7Ao`000004ofV@i@05o`000?nP_>goX;c]oj2lkOl0
00000oo9f^H00ol0003oh>SHon3Xf002on3Xf0;o000000Cog_k9o`000?oNoKoog_fo1?l000001Oo1
oNCo0000ok_Tlonki??o000000CoYkgY00?o0000oiFPfonEX=/00onEX=/00ol0003oRHgAohV=d@04
ohV=d@03oh>3bol0003oLGoB00?oLGoB00?o0000ofekcom]Nll00om]Nll01?l0003oooooooooool0
000Tooooo`03o`000?oooooooooo00Kooooo000Hooooo`03o`000?oooooooooo01Cooooo0ol0000T
ooooo`07o`000?oPfm7oh=_Aon3KdOl0003ofl_9o`000007omW;c003o`000?oBb];od/[B00?od/[B
00?o0000olG8g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb0_l000001_l0@L;o
01jUo`0HWol0003o0472o`0000;o4E3<0olkL]d2o`0000?oPYgT00?o0000ojc6kOn/a^d00_n/a^d0
1?l0003odNSVom7Xi_oAj>H2o`0000Coj>C=0_l00005onW?^`;o00001?oP^[400ol0003odj^_om>[
[`04om>[[`03o`000?o7WJgoaif]00Coaif]00Co0000okbB[?nlTZco_9:/1_l00003ojn8[003o`00
0?nROjgoXWn]00?oXWn]00?o0000oi=e[_nCMJh01?nCMJh00ol0003oOfVaogmY/@03ogmY/@03o`00
0?mSFk?o000000?oJVFj00Co0000odEE__m5EKko00000omKKL`00ol0003o<V7Ao`000003ofV@i@05
o`000?nP_>goX;c]oj2lkOl000001?o9f^H00ol0003oh>SHon3Xf002o`0000;og_k900?o0000omkm
_ooNoKl00ol000001Oo1oNCo0000ok_Tlonki??o000000CoYkgY00?o0000oiFPfonEX=/00onEX=/0
0ol0003oRHgAohV=d@04ohV=d@04o`000?n3Pl_oPh?;o`0000;oLGoB00?o0000ofekcom]Nll01?m]
Nll01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oo
oooooooo01;ooooo0ol0000Wooooo`04o`000?oPfm7oh=_Ao`0000?ofl_900?o0000omW;c?oIbl`0
1OoIbl`00ol0003od/[Bom;:dP03om;:dP03o`000?o5b=coaLSL00?oaLSL00?o0000ojZojOnZ_nT0
1ol000000ol0@L;o01jUo`0HW`02o`0000;o4E3<00Co0000oc]bgOlkL]go>g;M0_l00002oh:Mi003
o`000?n/a^go[<K]00;o[<K]00?o0000om7Xi_oAj>H00_l00005onSTc@;o00001OoYck/01?l0003o
g[bgo`000?l00002on2j/@03o`000?oCZjoodj^_00Codj^_00?o0000olNM[Oo7WJd01?o7WJd00ol0
003o_9:/okbB[003okbB[003o`000?n_R:co[hR/00Co[hR/00?o0000oj9o[OnROjd01?nROjd00ol0
003oTgF^oi=e[P04oi=e[P03o`000?moJK7oOfVa00;oOfVa0_l00005ofYU^P03o`000?m5EKko0000
00CoFfg<00?o<V7Ao`000?mYT>D00_mYT>D00ol0003oX;c]oj2lk@02oj2lk@0;o`000?o9f^KobM[V
olWJi_l0003oh>SHo`000?oJnMgo0000omknbOl000000_oNoKl3o`000005ol7mi?l0003o^nCcok_T
lol000001?nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00CoRHgA00?o0000oh>3
bon3Pl/00_n3Pl/00ol0003oLGoBo`000006ofekc`05o`000?ooooooooooooooool000008oooool0
0ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000:oooool2o`00
00Gofl_900?o0000omW;c?oIbl`01OoIbl`00ol0003od/[Bom;:dP02om;:dP03o`000?o5b=coaLSL
00?oaLSL0ol00003ojZoj@0<o`000?m][_SoKJkhoff^n?l0003o0472o`0NYOl069oo0472o`000?lA
D<co00000olkL]d2ogFOk0?o00001?n/a^d3o`000003om?Kg_l0003oj>C=00Coj>C=00?o0000onW?
^ooYck/00ooYck/00ol0003og[bgomjl]`02omjl]`03o`000?oP^[7o000000Godj^_00?o0000olNM
[Oo7WJd01?o7WJd00ol0003o_9:/okbB[004okbB[003o`000?n_R:co[hR/00Co[hR/00?o0000oj9o
[OnROjd01?nROjd00ol0003oTgF^oi=e[P04oi=e[P03o`000?moJK7oOfVa00;o000000?oPg2fo`00
0?mZIKX01?mZIKX00ol0003oAEFno`000005oe]]c0;o00000_mYT>D00ol0003oX;c]oj2lk@02oj2l
k@04o`000?o9f^KobM[VolWJiP;o000000Kof_WMo`000?oNo/Wog_k9o`000?oNoKl3o`000005ol7m
i?l0003o^nCcok_Tlol000001?nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00Co
RHgA00?o0000oh>3bon3Pl/01?n3Pl/2o`0000GoKG_?00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00cooooo
0ol0000^ooooo`03o`000?oKblWofl_900Gofl_900?o0000omW;c?oIbl`01?oIbl`00ol0003od/[B
om;:dP03om;:dP05o`000?o5b=coaLSLolG8g?l000000oo2`=P4ojZoj@;o00000_m][_P2o`000003
o`0NYOl069oo000000;o4E3<00Co0000oc]bgOlkL]go00000omeWn`6o`0000Codm_N00?o0000onST
cOoXi<d00_oXi<d00ol0003ojLnkonW?^`03onW?^`03o`000?oN_;Oog[bg00?og[bg0_l00005om>[
[`03o`000?o7WJgoaif]00Coaif]00?o0000okbB[?nlTZ`01?nlTZ`00ol0003o[hR/ojn8[004ojn8
[003o`000?nROjgoXWn]00CoXWn]00?o0000oi=e[_nCMJh01?nCMJh00ol0003oOfVao`000004oh=`
]P03o`000?mZIK[oJVFj00?oJVFj00?o0000oe]]c?mKKL`01?mKKL`2ogZ@g003o`000?mYT>Go0000
00CoX;c]00?o0000olWJi_l000000_l00002om[ig@03o`000?oNo/Wog_k900[o00000onW_NT00ol0
003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00CoRHgA00?o0000oh>3bon3Pl/01On3Pl/2oh5o
b003o`000?m]NlooKG_?00;oKG_?00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Kooooo000Gooooo`;o00002_ooool3o`00037ooooo00?o0000om_;bOoK
blT01_oKblT00ol0003ofL_<omW;c004omW;c003o`000?oBb];od/[B00?od/[B00?o0000olG8g?l0
00001Oo2`=P00ol0003oZ[oYojZoj@02ojZoj@03o`000?m][_SoKJkh00;o000000Go01ROo`0`]?l0
003o4E3<o`000003oc]bg@04o`000?meWncoMIo/o`0000Co[LG/00?o0000om?Kg_oCfmh00_oCfmh0
1ol0003oj>C=onSTcOoXi<go0000on7@a_l000000ooYck/00ol0003og[bgomjl]`04omjl]`04o`00
0?oB[K?o0000o`0000?odj^_00?o0000olNM[Oo7WJd01?o7WJd00ol0003o_9:/okbB[004okbB[003
o`000?n_R:co[hR/00Go[hR/00?o0000oj9o[OnROjd00onROjd00ol0003oTgF^oi=e[P04oi=e[P;o
00001On3L;H00ol0003oJVFjofYU^P03ofYU^P03ogIfaOl0003oFfg<00?oFfg<00?o0000ogZ@g?mj
T=`00_mjT=`7o`0000;oa^?]00Go0000om[igOoJnMgo0000omknb@05o`0000;o[nKi00Oo0000ojNm
jOnW_NWoYkgYo`000?nW_NWo000000GoUJ3K00?o0000ohV=dOn9SM401?n9SM400ol0003oPh?;oh>3
b`05oh>3b`05o`000?n1OlSoPGo8oh5ob?l000000_m]Nll00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_oo
ool3o`0003Gooooo00?o0000om_;bOoKblT01OoKblT00ol0003ofL_<omW;c005omW;c003o`000?oB
b];od/[B00?od/[B00?o0000ol;0f?o2`=P01_o2`=P01Ol0003oZ[oYojZojOnZ_nWo000000?oKJkh
00?o0000o`0HWol0<;@00_l00003oc]bg@04o`000?meWncoMIo/o`0000Co[LG/00?o0000om?Kg_oC
fmh00_oCfmh01?l0003oj>C=onSTcOl00003on7@aP03o`000?oYck_o000000Kog[bg00?o0000om:]
/ooB[K<00_oB[K<3o`0000Ooaif]00?o0000okbB[?nlTZ`01?nlTZ`00ol0003o[hR/ojn8[005ojn8
[003o`000?nROjgoXWn]00?oXWn]00Co0000oi=e[_nCMJkoTgF^0ol000000onEN[?o0000oh=`]P05
oh=`]P05o`000?mZIK[oJVFjofYU^_l000000_mfM/D01Ol0003oFfg<oe]]c?mKKLco000000CoNY3L
00?o0000oj6kjonQ^n/00_nQ^n/01?l0003oa^?]olKSkOl00002om[ig@03o`000?oNo/Wo000000Co
000000?o[nKio`000?l000001?nW_NT3o`0000CoUJ3K00?o0000ohV=dOn9SM401?n9SM400ol0003o
Ph?;oh>3b`05oh>3b`03o`000?n1OlSoPGo800?oPGo800?o0000ofekcol000002?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo
0ol0000iooooo`03o`000?oKblWofl_900Gofl_900?o0000omW;c?oIbl`01OoIbl`01Ol0003od/[B
om;:d_oBb];o000000;ocKk<2?o2`=P01?l0003oZ[oYojZojOnZ_nT2o`0000;oKJkh00Go0000o`0H
Wol0<;Co4E3<o`000002oc]bg@05o`000?meWncoMIo/ogFOk?l000000on]aN`00ol0003odm_Nom?K
gP03om?KgP;o00001?oQd<H00ol0003ojLnko`000006omjl]`03o`000?oB[K?odZfc00CodZfc0ol0
0005olNM[@03o`000?nlTZco_9:/00Co_9:/00?o0000ojn8[?n_R:`01On_R:`00ol0003oXWn]oj9o
[@04oj9o[@?o00001OnEN[<00ol0003oPg2foh=`]P03oh=`]P04o`000?mZIK[oJVFjo`0000CoMWK5
00Co0000oe]]c?mKKLco00001?mjT=`01Ol0003oXK_[oj6kjonQ^n_o000000?oa^?]00?o0000om[i
gOoJnMd00_l000000onVkZ_o0000o`000002ojoVn@03o`000?nW_NWoYkgY00?oYkgY00Co0000oibP
eonLX=OoW:3G0_l000000onEX=_o0000ohV=d@05ohV=d@03o`000?n3Pl_oPh?;00GoPh?;00?o0000
oh5ob?n1OlP01On1OlP00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool001Kooooo00Co0000oooooooooooooooo0ol0000mooooo`03o`000?oKblWo
fl_900Gofl_900?o0000omW;c?oIbl`01OoIbl`00ol0003od/[Bo`000004olfnc0;o00001_o2`=P2
o`0000?oZ[oY00?o0000off^n?m][_P00_l000001Ol0<;Co0000o`000?lkL]go000000?oMIo/00?o
0000ojg5k?n]aN`00_n]aN`01?l0003odm_Nom?Kg_oCfmh2o`0000KohM360_l00006omjl]`03o`00
0?oB[K?odZfc00CodZfc00?o0000olNP/Oo7X;400ol000000oo7WJgo0000okbB[006okbB[003o`00
0?n_R:co[hR/00Go[hR/00Co0000oj9o[OnROjgoXWn]1?l00007oiEj/`03o`000?n3L;KoPg2f00?o
Pg2f00?o0000ofYU^_l000001_mfM/D2o`0000CoNY3L00?o0000oj6kjonQ^n/00_nQ^n/01Ol0003o
a^?]olKSkOo6hngo000000;of_WM00Go0000ojK^Zol0003o0000ojoVn@02o`0000CoYkgY0_l00005
oibPe`;o00001_n9SM400ol0003oPh?;oh>3b`05oh>3b`03o`000?n1OlSoPGo800GoPGo800?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Foooo
o`Co0000@Oooool00ol0003ofl_9om_;b@05om_;b@03o`000?oIblcofL_<00GofL_<00?o0000olfn
c?o=_/`01Oo=_/`00ol0003o`/3Hol;0f005ol;0f004o`000?nZ_nWoZ[oYojZoj@;o00000_m][_P2
o`000004o`YVf_l0003o>g;Mo`0000;oMIo/00?o0000ojg5k?n]aN`00_n]aN`4o`000003om7>eol0
003ohM3600GohM3600?o0000omRo`Ol000001?oN_;L00ol0003odZfcom:]/`05om:]/`03o`000?o7
X;7oaj2a00?oaj2a1_l00003okbB[004o`000?n_R:co[hR/ojn8[0So00000onSPk400ol0003oUGZc
oiEj/`05oiEj/`03o`000?n3L;KoPg2f00?oPg2f0_l00008ogIfa@;o00000omjT=`00ol0003oXK_[
oj6kj`02oj6kj`05o`000?o6hngoa^?]o`000?oJnMd00_l000000onVkZ_o0000ojoVn@02o`0000Go
YkgY00?o0000oibPeonLX=L01?nLX=L00ol0003oUI3;o`000005ohV=d@03o`000?n3Pl_oPh?;00Go
Ph?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01Oooool001Kooooo0ol00013ooooo`03o`000?oKblWofl_900Cofl_9
00?o0000omW;c?oIbl`01OoIbl`00ol0003od[g6olfnc006olfnc0;o00001_o2`=P2o`0000?oZ[oY
00?o0000off^n?l069l00_l00002o`YVfP?o000000?oMIo/o`000?n]aN`00ol00005om7>e`03o`00
0?oQd<KohM3600;ohM3600Co0000omRo`OoH_l7of;o10_l00002omjl]`03o`000?oB[K?odZfc00Co
dZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/002ok^F/0Oo00001?n`S;000ol0003o
Xh>aoj>3/@04oj>3/@03o`000?nEN[?oUGZc00KoUGZc00Oo0000oh=`]_n3L;KoPg2fo`000?n9OKoo
000000OoMWK500Co0000ohRAeOn8TMGo00000_mjT=`01Ol0003oXK_[oj6kjonQ^n_o000000?oa^?]
0_l000001OnloMSo0000o`000?n_i_Wo000000GoYkgY0_l00005oibPe`;o00000onET</01Ol0003o
RHgAohV=dOn9SM7o000000OoPh?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool000cooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000om_;bOoKblT01?oKblT00ol0003o
fL_<omW;c003omW;c005o`000?oB_LKod[g6om:ma_l000001oo=_/`00ol0003o`/3Hol;0f005ol;0
f00;o`000?nZ_nWoZ[oYojZojOl0003oKJkho`000?l0<;Co0000o`YVf_l000000_mWX_83o`0000;o
[LCZ00?o0000om7>eooAc]L01?oAc]L01?l0003ohM36on7@a_l00006omRo`@03o`000?oN_;Oo0000
00KodZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/005ok^F/003o`000?n`S;3o/8b`
00Go/8b`00?o0000oj>3/OnSPk401OnSPk400ol0003oUGZcoiEj/`05oiEj/`04o`000?n3L;KoPg2f
o`0000?oRGfo00?o0000ogIfaOmfM/D00omfM/D00ol0003oR97EohRAe@02ohRAe@;o00001?nQ^n/0
1_l0003oa^?]olKSkOo6hngo0000okcmf0Co00001?nW_NT2o`0000GoW:3G0_l00006oiF@b`03o`00
0?n9SM7o000000OoPh?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oKblWofl_900Gofl_900Go0000omW;c?oIblcofL_<
o`000005om:maP;o00001_o=_/`2o`0000Ko`/3H00?o0000ojZojOnZ_nT01?l000001?l0<;Co0000
o`YVf_l00002ofNRlP03o`000?n]a>[o[LCZ00;o[LCZ00?o0000om7>eooAc]L01?oAc]L00ol0003o
hM36o`000007omRo`@;o00001_oB[K<00ol0003oaj2aolNP/@05olNP/@03o`000?nkU[3o^iJ`00Go
^iJ`00?o0000ok2</?n`S;001On`S;000ol0003oXh>aoj>3/@05oj>3/@03o`000?nEN[?oUGZc00Go
UGZc00?o0000oh=`]_l000001On9OKl01Ol0003oMWK5ogIfaOmfM/Go000000KoR97E0ol00002oj6k
j`Co000000Co_?gHo`000?l0003o00001OnW_NT00ol0003oW:3GoibPe`04oibPe`03o`000?nET<_o
UI3;00KoUI3;0_l00007oh>3b`03o`000?n1OlSoPGo800GoPGo800?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0@Oooool00ol0003ofl_9om_;b@05om_;b@03o`000?oIblco0000
00Sod[g600?o0000olfnc?o=_/`01Oo=_/`00ol0003o`/3Hol;0f004ol;0f0;o00000onY_nT4o`00
0005o`YVf_l0003oIj;bofNRl_l000001?n]a>X00ol0003odLkGom7>e`03om7>e`?o00001ooH_l40
0ol0003oc[6lo`000002o`0000?odZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/005
ok^F/003o`000?n`S;3o/8b`00Go/8b`00?o0000oj>3/OnSPk401OnSPk400ol0003oUGZcoiEj/`05
oiEj/`;o00001on9OKl00ol0003oMWK5o`000007ohRAe@03o`000?nS^n[oXk_Z00?o00000_nljo@5
o`0000?oYkgY0_l00005oibPe`;o00002?nET</01?l0003oTHO5oi67aOl00005oh>3b`03o`000?n1
OlSoPGo800GoPGo800?o0000ooooooooool04_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00[ooooo0_l00012ooooo`03o`000?oKblWo
fl_900Gofl_900?o0000om:ma_oB_LH02?oB_LH2o`0000KocKk<0_l00003ol;0f003o`000?no^MCo
_kWD00;o00000onY_nT3o`000005o`YVf_l0003oIj;bofNRl_l000001?n]a>X01Ol0003odLkGom7>
eooAc]Oo000000?oc<;A00?o0000omRo`OoH_l400ooH_l400ol0003oc[6lolja_003olja_0?o0000
1oo7X;400ol0003o^iJ`ok^F/006ok^F/003o`000?n`S;3o/8b`00Ko/8b`00?o0000oj>3/OnSPk40
1?nSPk400ol0003oUGZcoiEj/`02oiEj/`?o000000?oVHBlo`000?n9OKl01_n9OKl2o`0000OoR97E
00Go0000oj>kj_nS^n[oXk_Zo`000003okc[m0?o00000onX_NT00ol0003oYkgYo`000006oibPe`03
o`000?nET<_oUI3;00KoUI3;0_l00004oi67a@05o`000?n3Pl_oPh?;oh>3bol000001on1OlP00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`03o`000?oKblWofl_900?o
fl_900Co0000om>la?oC_<Co00002_oB_LH00ol0003ocKk<olfnc005olfnc003o`000?o2`=So0000
00Go_kWD0_l00003ojVoj@03oh800?l0003o000000?oIj;b00?o0000ojg4j_n]a>X00_n]a>X00ol0
003odLkGo`000005olc2d@03o`000?oH_l7of;o100;of;o100?o0000olja_?o>/K`01Oo>/K`3o`00
00Goaj2a00?o0000ok^F/?nkU[001_nkU[000ol0003o/8b`ok2</006ok2</003o`000?nSPk7oXh>a
00GoXh>a1?l00005oiV4_003o`000?n9OKooRGfo00?oRGfo00Co0000oiBCd?nDTm3o00001On8TMD0
1Ol0003oXk_Zoj>kj_nS^n[o000000?o_>_d0_l00005ojRmj@;o00001OnLX=L2o`0000OoUI3;0_l0
0007oi67a@03o`000?n3Pl_o000000OoPGo800?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@?ooool01Ol0003ofl_9om_;bOoKblWo000000Codkc40_l00009om:maP03o`000?o=
_/cocKk<00GocKk<00?o0000oknie?no^M@01_no^M@2o`0000?oZKoY00GoPP00o`000?mWX_;oIj;b
o`000004ojg4jP;o00001oo<`]401?l0003of;o1omRo`Ol00008olja_003o`000?o5Y[[oaJJj00Co
000000?oaj2ao`000?nkU[001onkU[000ol0003o/8b`ok2</006ok2</004o`000?nSPk7oXh>aoj>3
/@Go00002OnIQ;`00ol0003oRGfoohUm_`02o`0000CoU9?@00Go0000ohRAeOn8TMGoR97Eo`000003
oj>kjP04o`000?nljoCo_>_dokc[m0;o00000onX_NT3o`000003oj>Re?l0003oW:3G00;oW:3G0_l0
0008oiF@b`03o`000?nAQlGoTHO500OoTHO50_l00007oh5ob003o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo043ooooo00?o0000om_;bOl000001ooC_<@00ol0003od[g6om:maP07
om:maP;o00001Oo=_/`00ol0003oakC8o`000008oknie0?o000000?oZKoYoh800?l000000ol00000
0on]a>[o0000o`000003ojg2j@03o`000?o<`]7oc<;A00Coc<;A00?o0000omRo`Ol000001oo>/K`0
0ol0003oaJJjolFV^P05olFV^POo00000onkU[000ol0003o/8b`ok2</002ok2</0So00001?nUS;X0
0ol0003oVHBloiV4_007oiV4_003o`000?n9OKoo000000OoU9?@00?o0000ohRAeOl000000onS^nX0
1?l0003o_>_dokc[m?nljo@2o`0000;oZ;gY0_l00005oj>Re003o`000?nLX=Oo000000SoUI3;0_l0
0009oi67a@03o`000?n@Q<?o000000KoPGo800?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Cooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00011
ooooo`;o00002?oC_<@2o`0000Wod[g600Go0000olfnc?o=_/cocKk<o`000004olNdb0?o00001ono
^M@4o`000003oeZWn?l0003o000000Ko[L;Y0_l00005olc2d@03o`000?o>/Kcoc[6l00Koc[6l00?o
0000olFV^_o5Y[X01_o5Y[X00ol0003o^ibiok^L^@03ok^L^@So00001?n`TkT00ol0003oYHbjojF<
^P06ojF<^P03o`000?nIQ;coVHBl00KoVHBl0_l00008oiBCd0Co000000?oXk_Zo`000?nljo@00_nl
jo@00ol0003oZ;gYo`000002o`0000OoXj;D0_l00008oiF@b`03o`000?nAQlGoTHO500OoTHO50_l0
0003oi24``03o`000?n1OlSoPGo800;oPGo800?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo043ooooo00?o0000
om>la?oC_<@01ooC_<@00ol0003od[g6om:maP07om:maP03o`000?o=_/co000000SoakC80_l00007
oknie0;o000000GoPP00o`000?mJYoSoFZOho`000006ojg2j@05o`000?o<`]7oc<;Aolc2dOl00000
0_o6^<d3o`0000Coc[6l00?o0000olFV^_o5Y[X01_o5Y[X00ol0003o^ibiok^L^@06ok^L^@03o`00
0?n`TkWo/9>i00Ko/9>i00?o0000ojF<^_nUS;X01_nUS;X00ol0003oVHBloiV4_004oiV4_0;o0000
00?oWYO<o`000?nDTm001OnDTm02o`0000?oY;[Y2?l00007oj>Re0?o000000?oWi?8o`000?nET</0
1OnET</2o`0000WoTHO500?o0000oi24`on@Q<<01?n@Q<<01?l0003oPGo8oh5ob?l0000Oooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002?ooooo00?o0000ooooooooool0
@?ooool2o`0000Sodkc400?o0000om:ma_oB_LH01ooB_LH00ol0003oakC8olNdb009olNdb0;o0000
1ono^M@01Ol0003oPP00o`000?l0003oFZOh00;o00001On]`^T00ol0003oc<;Ao`000006olJhc@Co
00002Oo5Y[X00ol0003o^ibiok^L^@06ok^L^@03o`000?n`TkWo/9>i00Ko/9>i00?o0000ojF<^_nU
S;X01_nUS;X01?l0003oVHBloiV4_?nIQ;`3o`0000CoWYO<00Co0000oiBCd?nDTm3oU9?@0_l00004
ojBjj@04o`000?n/kOSo[>ghojc]n0;o00002?nSX]@2o`0000GoWi?800Co0000oiF@bonET<_oUI3;
0_l00009oi67a@;o00001on@Q<<00ol0003oPGo8o`00000Pooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool002Cooooo0_l00012ooooo`03o`000?oC_<Codkc400Kodkc40_l0
0007om:maP04o`000?o://;o0000o`0000[oakC80_l00007oknie0Co000000?oFZOho`000?l00000
1?n]`^T00ol0003oa[S=olJhc@08olJhc@?o00001_o5Y[X00ol0003o^ibiok^L^@07ok^L^@03o`00
0?n`TkWo/9>i00Oo/9>i00?o0000ojF<^_nUS;X01_nUS;X3o`0000OoWYO<00Co0000oiBCd?l0003o
00001?nT^^T2o`0000;o[>gh0_l00007oj>Re0?o00002?nOTlP00ol0003oUI3;o`000009oi67a@;o
00002On@Q<<2o`0002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00
9_ooool00ol0003oooooooooo`10ooooo`03o`000?oC_<Codkc400Oodkc400?o0000om:ma_oB_LH0
0ooB_LH00ol0003ob[;2olZb`P03olZb`P;o00002Oo7]<P3o`0000Co_kWD00?o0000okZcd_l00000
0_l00002oeZWn003o`000?n]`^Wo000000?o[L7X0_l00007olJhc@03o`000?no[l[o_jo:00Go0000
00?oaJJjo`000?nkW;T02?nkW;T00ol0003o/9>iok2C^@07ok2C^@03o`000?nUS;[oYHbj00CoYHbj
0ol00009oijGc0?o00000onT^^T2o`0000?o[>gh00?o0000oj>Re?nSX]@01?nSX]@3o`0000_oWi?8
0_l00009oi67a@03o`000?n@Q<?oT8C300SoT8C300?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Wooooo`03o`000?oooooooooo043ooooo0_l0
0008om>la0;o00000_oB_LH00ol0003ob[;2olZb`P06olZb`P;o00002_o7]<P2o`000003oknie?l0
003o^[?B00?o^[?B00?oE`00o`000?l000000_l00006ojg1j0?o00000oo6^<d00ol0003o_jo:okn_
bP06okn_bPOo00001?nkW;T00ol0003o/9>iok2C^@07ok2C^@03o`000?nUS;[o000000Co00000_nX
VlT00ol0003oWYO<oijGc005oijGc0;o00000onV^nP00ol0003oY;[Yo`000003ojc]n0;o00001OnS
X]@2o`0000_oWi?80ol000000onMS<7o0000oi67a@06oi67a@;o00002On@Q<<2o`0002Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0003oooooooooo`11
ooooo`03o`000?oC_<Codkc400Oodkc400?o0000om:ma_l000002_o://83o`0000WoakC800?o0000
okZcd_nj/m801Onj/m801?mG003oD:kjoe2^n_m@[_X2o`0000Ko[L7X0_l000000oo6^<go0000okn_
bP08okn_bP03o`000?nhYlSo^:O800?o^:O84?l00008ojRKb@04o`000?nNUlcoWYO<oijGc0?o0000
1OnV^nP4o`000006ojc]n?l0003oZJGBojVUd_l0003oXj;D0ol0000;oinCb0;o00001OnMS<400ol0
003oTHO5oi67a@03oi67a@03o`000?n@Q<?oT8C300SoT8C300?o0000ooooooooool09oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Yooooo`;o0000@_ooool2o`0000So
dkc400?o0000olZb`_o://803?o://82o`0000OoakC800?o0000ol2/a_o0[<H00ol00004okZcdP04
oeL00?l0003oD:kjoe2^nP;o00001_n]`NP00ol0003o_jo:okn_bP08okn_bP03o`000?nhYlSo^:O8
00Oo^:O800?o0000ok2Qb?n`XLP01on`XLP00ol0003oZ9_9ojRKb@07ojRKb@04o`000?nNUlco0000
o`0000GoY[_X0ol00003oiCXnP;o00000_nYYM83o`0000coWi?80_l00008oif<`@03o`000?nAQlGo
THO500;o00002On@Q<<2o`0002_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03
ooooo`00:oooool00ol0003oooooooooo`11ooooo`03o`000?oC_<Codkc400Godkc400?o0000ol^a
`?l000000_l0000<olZb`P;o00001?o7]<P00ol0003o`:c6ol2/aP05ol2/aPCo00000_nj/m801?l0
003oD:kjoe2^n_l00004ojg1j004o`000?n/_nOo[;oWojboi`?o00001?no[lX00ol0003o^:O8okRW
b008okRWb003o`000?n`XLSo/:7800Oo/:7800?o0000ojRKbOnXVlT01_nXVlT3o`0000GoY[_X0_l0
0003oiCXnPOo00000_nXV<D00ol0003oWi?8oinCb007oinCb0?o00002_nMS<400ol0003oTHO5o`00
0009oi24``;o0000;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000/
ooooo`03o`000?oooooooooo047ooooo00?o0000om>la?oC_<@00ooC_<@00ol0003obk70ol^a`003
ol^a`0;o00003?o://83o`000003olNdb?l0003o`:c600[o`:c61Ol000001Om@[_[o0000o`000?n]
`NSo000000Oo[;oW0ol000000ono[l[o0000okRWb009okRWb003o`000?n`XLSo/:7800So/:7800?o
0000ojRKbOnXVlT01Ol00003ojRki`03o`000?nV^nSo000000;o00000_nDj?X6o`0000OoZ9S500?o
0000oinCb?nOTlP01?nOTlP2o`0000goWHc10_l00009oi24``03o`000?oooooooooo02oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003oooooooooo`11
ooooo`;o00000_oC_<@00ol0003obk70ol^a`006ol^a`0?o00003?o://800ol0003o`:c6ol2/aP0>
ol2/aPGo00002on/_nL8o`0000Co^:O800?o0000ok2Qb?n`XLP00on`XLP8o`0000OoZ;_W1?l00000
0onDj?[o0000o`000002o`0000coZ9S500?o0000oinCb?nOTlP00_nOTlP2o`0000coWHc10ol00000
0onLRKoo0000oi24``06oi24``;o0000<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo000^ooooo`;o0000@oooool00ol0003odkc4o`00000;ol^a`0;o00002_o://800ol0
003o`ZRool:X_`04o`0000ko`:c60ol000000om<]oWo0000o`000004o`0000?o[;oW00?o0000oj^m
ion[_NL01?n[_NL:o`0000GoZKcW00?o0000ojRkionX^nL00onX^nL4o`000003og[MnOl0003o0000
00;o00004?nXV<D00ol0003oWi?8o`000002o`0000coWHc10_l00005oib9_`03o`000?n@Q<?oT8C3
00?oT8C300?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000ol^a`?o;/L003?o;/L03o`0000Ko
b[;200?o0000ol:X_oo2Z;l01Oo2Z;l5o`0000[o`:c600?o0000okRTa?nhY<@00_nhY<@7o`0000Go
ZkgW00?o0000oj^mion[_NL00on[_NL00ol0003oZKcWojVli`09ojVli`03o`000?nX^nOo000000Oo
00004_nXV<D4o`0000coWHc10ol00008oib9_`03o`000?n@Q<?oT8C300;o0000=oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000aooooo`03o`000?oooooooooo04;ooooo
0ol0000=ol^a`0;o00001?o://800ol0003o`ZRool:X_`0:ol:X_`Co00001_o0[<H00ol0003o^:C4
okRTa006okRTa0;o00001omB`_LEo`000005oa@00?naW/Co/Ik4ok6Na?l000003_nXV<D5o`0000?o
Yi:o00?o0000oif<`OnMS<402?nMS<42o`0000_oW8Vo00?o0000oi24`ol00000>Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03o`000?oooooooooo04Cooooo
0ol0000<ol^a`0?o000000?ob[;2o`000?o2Z;l03oo2Z;l4o`000003ol2/a_l0003o^:C4017o^:C4
3?l0000=ok6Na003o`000?nXV<GoZ9S500KoZ9S51_l00009ojNB_`03o`000?nMS<7oWHc100CoWHc1
0ol0000=oib9_`;o0000>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
000cooooo`;o0000Aoooool2o`0000gobk7000?o0000ol:X_oo2Z;l04oo2Z;l2o`0000Go^:C400?o
0000okRTa?nhY<@03_nhY<@00ol0003o/Ik4ok6Na00Cok6Na003o`000?nXV<GoZ9S500Go00003onW
T[l00ol0003oWHc1oif<`@02oif<`@;o00003OnLRKl3o`0003kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`16ooooo`?o00002_o;/L00
0ol0003o`jJmol>V_@05o`0000oo`ZRo00?o0000okZO__njWkh01?njWkh;o`0000Go^:C400?o0000
ok6Na?naW/@02?naW/@>o`0001CoYi:o00?o0000oif<`Ol000000_l0000<oib9_`?o0000@_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo
04Sooooo0_l00007ol^a`003o`000?o3Y[go`jJm00Ko`jJm1?l0000;ol:X_`03o`000?njWkko^Ynn
00oo^Ynn4?l0000;ok6H_P03o`000?nWT[ooYi:o01;oYi:o1?l0000<oib9_`?o0000AOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000gooooo`03o`000?oooooooooo04Wo
oooo0ol00004ol^a`003o`000?o3Y[go`jJm00[o`jJm1?l00006ol:X_`03o`000?njWkko^Ynn01Go
^Ynn00?o0000ok6H__naV;h04onaV;h00ol0003oYi:oojNB_`0<ojNB_`Ko00000onWT;d00ol0003o
W8Vooib9_`08oib9_`;o0000BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007o
oooo000hooooo`;o0000C?ooool3o`000003ol^a`?l0003o`jJm00oo`jJm1Ol000000oo2Z;oo0000
okZO_P0FokZO_P03o`000?naV;ko/IRn01Co/IRn00?o0000ojNB_onWT[l01_nWT[l5o`0000WoYi2m
00?o0000oib9_onLRKl01OnLRKl3o`0004cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`00>_ooool00ol0003oooooooooo`1<ooooo`03o`000?o3Y[go`jJm01Co`jJm0_l0
0003okZO_P?o00004?njWkh00ol0003o/IRnok6H_P0Eok6H_P03o`000?nWT[ooYi:o00Ko00003onW
T;d01?l0003oW8Vooib9_onLRKl3o`00053ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00>oooool00ol0003oooooooooo`1>ooooo`Co00004Oo3Y[d00ol0003o^YjlokZN
_004okZN_0_o00001OnjWkh00ol0003o/IRnok6H_P09ok6H_Poo00005OnWT;d4o`0005?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool2o`0005;ooooo1?l0000=
ol>V_@03o`000?njW[co^Yjl00oo^Yjl4Ol0000<ok6F_003o`000?nWT;goYi2m01?oYi2m0ol0001G
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003kooooo00?o0000oooo
ooooool0Doooool3o`0000[o`jJm00?o0000okZN_?njW[`05?njW[`00ol0003o/IJlok6F_00Eok6F
_003o`000?nWT;goYi2m00koYi2m1Ol0001Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool003oooooo00?o0000ooooooooool0Doooool00ol0003oooooo`000003o`0000Go
`jJm00?o0000okZN_?njW[`05OnjW[`00ol0003o/IJlok6F_00Eok6F_003o`000?nWT;goYi2m00Wo
Yi2m1Ol0001Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0043ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`Co000000?o`jJmo`000?njW[`0
5_njW[`00ol0003o/IJlok6F_00Fok6F_003o`000?nWT;goYi2m00CoYi2m1?l0001Vooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Booooo`03o`000?oo
oooooooo00Oooooo0_l00002okZN_0Co00004OnjW[`00ol0003o/IJlok6F_00Fok6F_003o`000?nW
T;go000000Co0000Joooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00@oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo3?l00005okZN_003o`000?naU[co
/IJl00[o/IJl3_l0001aooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0014oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool06ooooolBo`00083ooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2]ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`;o0000
COooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0018ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00Boooool2o`0004Sooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0/oooool01Ol0003ooooooooooooooooo0000007ooooo001@
ooooo`;o0000@oooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`00007ooooo001B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]Oooool00ol0003oooooo`000001
ooooo`00Doooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool00Ol0000005Cooooo0_l0000oooooo`03o`000?oooooooooo0;Kooooo0Ol00001ooooo`7o
0000001Fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0]oooool2o`000000Eooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;Kooooo0ol0000005Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2booooo`Co00000oooool005Wooooo0_l0000joooo
o`03o`000?oooooooooo0:kooooo1?l00007ooooo`00Foooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo0:[ooooo1?l0000;ooooo`00G?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Kooooo1?l0000?ooooo`00GOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo0:;ooooo1?l0000Cooooo`00G_ooool2o`0003Gooooo00?o0000ooooooooool0W_ooool4
o`0001Oooooo001Pooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0V_ooool4o`00
01_ooooo001Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool3o`0001oo
oooo001Rooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002;ooooo
001Sooooo`;o0000;oooool00ol0003oooooooooo`2@ooooo`Co00009_ooool006Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`2<ooooo`Co0000:_ooool006Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`28ooooo`Co0000;_ooool006Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`24ooooo`Co0000<_ooool006Sooooo0_l0000Zooooo`03o`00
0?oooooooooo083ooooo1?l0000fooooo`00J_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo07cooooo1?l0000jooooo`00Joooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0000nooooo`00K?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l00012ooooo`00KOooool2o`0002Gooooo00?o0000ooooooooool0L?ooool4o`0004Ko
oooo001_ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0K?ooool4o`0004[ooooo
001`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J?ooool4o`0004kooooo001a
ooooo`;o00008Oooool00ol0003oooooooooo`1Tooooo`Co0000D_ooool007?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000E_ooool007Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Looooo`Co0000F_ooool007Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Iooooo`?o0000G_ooool007Kooooo0_l0000Looooo`03o`000?oo
oooooooo05Gooooo1?l0001Qooooo`00N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo057ooooo1?l0001Uooooo`00NOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04gooooo1?l0001Yooooo`00N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo1?l0001]ooooo`00Noooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`00077ooooo
001mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0007Gooooo001n
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool4o`0007Wooooo001ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool4o`0007gooooo0020ooooo`;o
00004_ooool00ol0003oooooooooo`0eooooo`Co0000POooool008;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0aooooo`Co0000QOooool008?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0^ooooo`Co0000ROooool008Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Zooooo`Co0000SOooool008Gooooo0_l0000<ooooo`03o`000?oooooooooo
02Kooooo1?l0002Aooooo`00Qoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo1?l0002Eooooo`00R?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo
1?l0002Iooooo`00ROooool2o`0000Sooooo00?o0000ooooooooool06oooool3o`0009gooooo002;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool4o`000:3ooooo002<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool4o`000:Cooooo002=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool4o`000:Sooooo002>ooooo`;o0000
0oooool00ol0003oooooooooo`0;ooooo`Co0000[?ooool0093ooooo00Co0000oooooooooooo0000
2Oooool4o`000;3ooooo002Aooooo`03o`000?oooooo000000Gooooo1?l0002dooooo`00T_ooool2
o`000003ooooool0003o000000;o0000^?ooool009?ooooo0_l0002looooo`00oooooomBooooo`00
oooooomBooooo`00oooooomBooooo`00\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .63846 m .51694 .65827 L .43899 .65168 L p .73 .604 .716 r
F P
0 g
s
.51694 .65827 m .51727 .63846 L .59237 .63426 L p .692 .572 .716 r
F P
0 g
s
.59237 .63426 m .59527 .65394 L .51694 .65827 L p .692 .572 .716 r
F P
0 g
s
.43899 .65168 m .44256 .63206 L .51727 .63846 L p .73 .604 .716 r
F P
0 g
s
.51761 .61977 m .51727 .63846 L .44256 .63206 L p .729 .61 .725 r
F P
0 g
s
.51727 .63846 m .51761 .61977 L .58948 .6157 L p .692 .579 .724 r
F P
0 g
s
.58948 .6157 m .59237 .63426 L .51727 .63846 L p .692 .579 .724 r
F P
0 g
s
.44256 .63206 m .44611 .61357 L .51761 .61977 L p .729 .61 .725 r
F P
0 g
s
.51794 .60376 m .51761 .61977 L .44611 .61357 L p .726 .628 .749 r
F P
0 g
s
.51761 .61977 m .51794 .60376 L .58665 .59983 L p .692 .6 .749 r
F P
0 g
s
.58665 .59983 m .58948 .6157 L .51761 .61977 L p .692 .6 .749 r
F P
0 g
s
.44611 .61357 m .44959 .59778 L .51794 .60376 L p .726 .628 .749 r
F P
0 g
s
.51826 .59172 m .51794 .60376 L .44959 .59778 L p .715 .667 .801 r
F P
0 g
s
.51794 .60376 m .51826 .59172 L .58387 .58794 L p .69 .646 .801 r
F P
0 g
s
.58387 .58794 m .58665 .59983 L .51794 .60376 L p .69 .646 .801 r
F P
0 g
s
.59527 .65394 m .59237 .63426 L .66417 .61958 L p .65 .543 .72 r
F P
0 g
s
.66417 .61958 m .67023 .63881 L .59527 .65394 L p .65 .543 .72 r
F P
0 g
s
.59237 .63426 m .58948 .6157 L .65815 .60149 L p .652 .552 .728 r
F P
0 g
s
.65815 .60149 m .66417 .61958 L .59237 .63426 L p .652 .552 .728 r
F P
0 g
s
.58948 .6157 m .58665 .59983 L .65224 .58612 L p .657 .576 .753 r
F P
0 g
s
.65224 .58612 m .65815 .60149 L .58948 .6157 L p .657 .576 .753 r
F P
0 g
s
.44256 .63206 m .43899 .65168 L .36521 .63435 L p .767 .64 .721 r
F P
0 g
s
.36521 .63435 m .37191 .61525 L .44256 .63206 L p .767 .64 .721 r
F P
0 g
s
.44611 .61357 m .44256 .63206 L .37191 .61525 L p .765 .645 .729 r
F P
0 g
s
.37191 .61525 m .37855 .5973 L .44611 .61357 L p .765 .645 .729 r
F P
0 g
s
.44959 .59778 m .44611 .61357 L .37855 .5973 L p .758 .66 .754 r
F P
0 g
s
.58665 .59983 m .58387 .58794 L .64646 .57475 L p .663 .629 .805 r
F P
0 g
s
.64646 .57475 m .65224 .58612 L .58665 .59983 L p .663 .629 .805 r
F P
0 g
s
.44959 .59778 m .453 .58597 L .51826 .59172 L p .715 .667 .801 r
F P
0 g
s
.51858 .58451 m .51826 .59172 L .453 .58597 L p .664 .743 .909 r
F P
0 g
s
.51826 .59172 m .51858 .58451 L .58116 .58088 L p .662 .742 .909 r
F P
0 g
s
.58116 .58088 m .58387 .58794 L .51826 .59172 L p .662 .742 .909 r
F P
0 g
s
.37855 .5973 m .38508 .58208 L .44959 .59778 L p .758 .66 .754 r
F P
0 g
s
.453 .58597 m .44959 .59778 L .38508 .58208 L p .737 .691 .806 r
F P
0 g
s
.58387 .58794 m .58116 .58088 L .64083 .56826 L p .66 .741 .91 r
F P
0 g
s
.64083 .56826 m .64646 .57475 L .58387 .58794 L p .66 .741 .91 r
F P
0 g
s
.38508 .58208 m .39146 .57087 L .453 .58597 L p .737 .691 .806 r
F P
0 g
s
.45633 .57899 m .453 .58597 L .39146 .57087 L p .665 .745 .91 r
F P
0 g
s
.453 .58597 m .45633 .57899 L .51858 .58451 L p .664 .743 .909 r
F P
0 g
s
.51889 .58243 m .51858 .58451 L .45633 .57899 L p .305 .751 .962 r
F P
0 g
s
.45958 .57717 m .51889 .58243 L p .47423 .57998 L .305 .751 .962 r
F P
0 g
s
.45633 .57899 m .45958 .57717 L p .47423 .57998 L .305 .751 .962 r
F P
0 g
s
.45958 .57717 m .45633 .57899 L .39768 .56454 L p .282 .705 .97 r
F P
0 g
s
.40376 .56339 m .45958 .57717 L p .41546 .56817 L .282 .705 .97 r
F P
0 g
s
.39768 .56454 m .40376 .56339 L p .41546 .56817 L .282 .705 .97 r
F P
0 g
s
.35455 .54164 m .40376 .56339 L p .36258 .54795 L .299 .671 .974 r
F P
0 g
s
.34589 .5417 m .35455 .54164 L p .36258 .54795 L .299 .671 .974 r
F P
0 g
s
.35455 .54164 m .31502 .51284 L p .34195 .53173 L 0 .252 .697 r
F P
0 g
s
.40376 .56339 m .35455 .54164 L p .38543 .55592 L .429 0 0 r
F P
0 g
s
.40376 .56339 m .39768 .56454 L .34589 .5417 L p .299 .671 .974 r
F P
0 g
s
.36305 .54652 m .40973 .56715 L p .3654 .54666 L .429 0 0 r
F P
0 g
s
.35455 .54164 m .36305 .54652 L p .3654 .54666 L .429 0 0 r
F P
0 g
s
.36305 .54652 m .35455 .54164 L p .34195 .53173 L 0 .252 .697 r
F P
0 g
s
.35455 .54164 m .34589 .5417 L .30417 .51141 L p .343 .644 .965 r
F P
0 g
s
.30417 .51141 m .31502 .51284 L .35455 .54164 L p .343 .644 .965 r
F P
0 g
s
.32565 .51926 m .36305 .54652 L p .3245 .51949 L 0 .252 .697 r
F P
0 g
s
.31502 .51284 m .32565 .51926 L p .3245 .51949 L 0 .252 .697 r
F P
0 g
s
.32565 .51926 m .30028 .48669 L p .32717 .51896 L 0 .069 .602 r
F P
0 g
s
.36305 .54652 m .32565 .51926 L p .35994 .54635 L .635 .094 0 r
F P
0 g
s
.33702 .54699 m .34589 .5417 L .39768 .56454 L p .666 .747 .91 r
F P
0 g
s
.33617 .52976 m .37146 .55545 L p .3311 .52356 L .635 .094 0 r
F P
0 g
s
.32565 .51926 m .33617 .52976 L p .3311 .52356 L .635 .094 0 r
F P
0 g
s
.3279 .55721 m .33702 .54699 L .39146 .57087 L p .758 .719 .816 r
F P
0 g
s
.39768 .56454 m .39146 .57087 L .33702 .54699 L p .666 .747 .91 r
F P
0 g
s
.37989 .56694 m .37146 .55545 L .33617 .52976 L p .746 .23 0 r
F P
0 g
s
.34589 .5417 m .33702 .54699 L .29302 .51528 L p .666 .748 .912 r
F P
0 g
s
.29302 .51528 m .30417 .51141 L .34589 .5417 L p .666 .748 .912 r
F P
0 g
s
.34669 .54285 m .37989 .56694 L p .33726 .53069 L .746 .23 0 r
F P
0 g
s
.33617 .52976 m .34669 .54285 L p .33726 .53069 L .746 .23 0 r
F P
0 g
s
.34669 .54285 m .33617 .52976 L p .34209 .53699 L 0 0 .457 r
F P
0 g
s
.32439 .51417 m .34669 .54285 L p .3132 .50022 L 0 0 .457 r
F P
0 g
s
.31234 .49912 m .32439 .51417 L p .3132 .50022 L 0 0 .457 r
F P
0 g
s
.32439 .51417 m .315 .48254 L p .33603 .52867 L 0 .117 .668 r
F P
0 g
s
.34669 .54285 m .32439 .51417 L p .35651 .55551 L .56 .103 0 r
F P
0 g
s
.32439 .51417 m .33657 .52987 L .35734 .55658 L p .56 .103 0 r
F P
0 g
s
.33657 .52987 m .32439 .51417 L p .33603 .52867 L 0 .117 .668 r
F P
0 g
s
.35734 .55658 m .34669 .54285 L p .35651 .55551 L .56 .103 0 r
F P
0 g
s
.33617 .52976 m .31234 .49912 L p .34209 .53699 L 0 0 .457 r
F P
0 g
s
.33617 .52976 m .32565 .51926 L p .32717 .51896 L 0 .069 .602 r
F P
0 g
s
.37146 .55545 m .36305 .54652 L p .35994 .54635 L .635 .094 0 r
F P
0 g
s
.40973 .56715 m .40376 .56339 L p .38543 .55592 L .429 0 0 r
F P
0 g
s
.45958 .57717 m .40376 .56339 L p .43672 .57279 L .467 0 0 r
F P
0 g
s
.46278 .58022 m .45958 .57717 L p .43672 .57279 L .467 0 0 r
F P
0 g
s
.51889 .58243 m .45958 .57717 L p .49279 .58165 L .423 0 0 r
F P
0 g
s
.51858 .58451 m .51889 .58243 L p .53566 .58293 L .372 .808 .961 r
F P
0 g
s
.57852 .57897 m .58116 .58088 L .55732 .58226 L p .372 .808 .961 r
F P
0 g
s
.55732 .58226 m .51858 .58451 L p .57852 .57897 L .372 .808 .961 r
F P
0 g
s
.58116 .58088 m .57852 .57897 L .63532 .56693 L p .471 .867 .968 r
F P
0 g
s
.63532 .56693 m .64083 .56826 L .61801 .57308 L p .471 .867 .968 r
F P
0 g
s
.61801 .57308 m .58116 .58088 L p .63532 .56693 L .471 .867 .968 r
F P
0 g
s
.64083 .56826 m .63532 .56693 L .68616 .54677 L p .583 .913 .974 r
F P
0 g
s
.68616 .54677 m .69431 .54709 L .67379 .55521 L p .583 .913 .974 r
F P
0 g
s
.67379 .55521 m .64083 .56826 L p .68616 .54677 L .583 .913 .974 r
F P
0 g
s
.67816 .55139 m .68616 .54677 L .63532 .56693 L p 0 0 0 r
F P
0 g
s
.68616 .54677 m .67816 .55139 L .71124 .52966 L p .437 .844 .658 r
F P
0 g
s
.71124 .52966 m .71771 .52541 L p .68616 .54677 L .437 .844 .658 r
F P
0 g
s
.63532 .56693 m .62991 .57051 L .67029 .55451 L p 0 0 0 r
F P
0 g
s
.67029 .55451 m .67816 .55139 L p .63532 .56693 L 0 0 0 r
F P
0 g
s
.57852 .57897 m .57591 .58193 L .62113 .57236 L p .151 0 0 r
F P
0 g
s
.62113 .57236 m .62991 .57051 L p .57852 .57897 L .151 0 0 r
F P
0 g
s
.51919 .58522 m .51889 .58243 L p .49279 .58165 L .423 0 0 r
F P
0 g
s
.51889 .58243 m .57852 .57897 L p .53566 .58293 L .372 .808 .961 r
F P
0 g
s
.67023 .63881 m .66417 .61958 L .72896 .59487 L p .604 .516 .728 r
F P
0 g
s
.66417 .61958 m .65815 .60149 L .72002 .5776 L p .608 .526 .737 r
F P
0 g
s
.72002 .5776 m .72896 .59487 L .66417 .61958 L p .608 .526 .737 r
F P
0 g
s
.72896 .59487 m .73799 .61332 L .67023 .63881 L p .604 .516 .728 r
F P
0 g
s
.65815 .60149 m .65224 .58612 L .71123 .56309 L p .617 .555 .762 r
F P
0 g
s
.71123 .56309 m .72002 .5776 L .65815 .60149 L p .617 .555 .762 r
F P
0 g
s
.39146 .57087 m .39768 .56454 L .45633 .57899 L p .665 .745 .91 r
F P
0 g
s
.65224 .58612 m .64646 .57475 L .70266 .55263 L p .635 .615 .813 r
F P
0 g
s
.70266 .55263 m .71123 .56309 L .65224 .58612 L p .635 .615 .813 r
F P
0 g
s
.29943 .6068 m .30904 .58855 L .37191 .61525 L p .803 .682 .73 r
F P
0 g
s
.37191 .61525 m .36521 .63435 L .29943 .6068 L p .803 .682 .73 r
F P
0 g
s
.37855 .5973 m .37191 .61525 L .30904 .58855 L p .8 .686 .739 r
F P
0 g
s
.30904 .58855 m .31856 .57149 L .37855 .5973 L p .8 .686 .739 r
F P
0 g
s
.38508 .58208 m .37855 .5973 L .31856 .57149 L p .788 .698 .764 r
F P
0 g
s
.51889 .58243 m .51919 .58522 L .57591 .58193 L p .319 0 0 r
F P
0 g
s
.57591 .58193 m .57852 .57897 L .51889 .58243 L p .319 0 0 r
F P
0 g
s
.64646 .57475 m .64083 .56826 L .69431 .54709 L p .658 .74 .91 r
F P
0 g
s
.69431 .54709 m .70266 .55263 L .64646 .57475 L p .658 .74 .91 r
F P
0 g
s
.31856 .57149 m .3279 .55721 L .38508 .58208 L p .788 .698 .764 r
F P
0 g
s
.39146 .57087 m .38508 .58208 L .3279 .55721 L p .758 .719 .816 r
F P
0 g
s
.62991 .57051 m .63532 .56693 L .57852 .57897 L p .151 0 0 r
F P
0 g
s
.45958 .57717 m .46278 .58022 L .51919 .58522 L p .423 0 0 r
F P
0 g
s
.51949 .59198 m .51919 .58522 L .46278 .58022 L p .603 .127 .097 r
F P
0 g
s
.51919 .58522 m .51949 .59198 L .57333 .58888 L p .51 .052 .102 r
F P
0 g
s
.57333 .58888 m .57591 .58193 L .51919 .58522 L p .51 .052 .102 r
F P
0 g
s
.57591 .58193 m .57333 .58888 L .62454 .57808 L p .377 0 .058 r
F P
0 g
s
.62454 .57808 m .62991 .57051 L .57591 .58193 L p .377 0 .058 r
F P
0 g
s
.40376 .56339 m .40973 .56715 L .46278 .58022 L p .467 0 0 r
F P
0 g
s
.46596 .58726 m .46278 .58022 L .40973 .56715 L p .67 .167 .041 r
F P
0 g
s
.46278 .58022 m .46596 .58726 L .51949 .59198 L p .603 .127 .097 r
F P
0 g
s
.72896 .59487 m .72002 .5776 L .77143 .54489 L p .556 .502 .751 r
F P
0 g
s
.72002 .5776 m .71123 .56309 L .76012 .53161 L p .572 .536 .776 r
F P
0 g
s
.76012 .53161 m .77143 .54489 L .72002 .5776 L p .572 .536 .776 r
F P
0 g
s
.71123 .56309 m .70266 .55263 L .7491 .52244 L p .604 .606 .827 r
F P
0 g
s
.7491 .52244 m .76012 .53161 L .71123 .56309 L p .604 .606 .827 r
F P
0 g
s
.73799 .61332 m .72896 .59487 L .78298 .56099 L p .55 .49 .741 r
F P
0 g
s
.77143 .54489 m .78298 .56099 L .72896 .59487 L p .556 .502 .751 r
F P
0 g
s
.78298 .56099 m .79464 .57831 L .73799 .61332 L p .55 .49 .741 r
F P
0 g
s
.70266 .55263 m .69431 .54709 L .73838 .51825 L p .657 .74 .911 r
F P
0 g
s
.73838 .51825 m .7491 .52244 L .70266 .55263 L p .657 .74 .911 r
F P
0 g
s
.25774 .55292 m .26976 .53711 L .31856 .57149 L p .834 .734 .754 r
F P
0 g
s
.31856 .57149 m .30904 .58855 L .25774 .55292 L p .834 .734 .754 r
F P
0 g
s
.3279 .55721 m .31856 .57149 L .26976 .53711 L p .817 .741 .78 r
F P
0 g
s
.26976 .53711 m .28154 .52413 L .3279 .55721 L p .817 .741 .78 r
F P
0 g
s
.33702 .54699 m .3279 .55721 L .28154 .52413 L p .776 .751 .83 r
F P
0 g
s
.51979 .60127 m .51949 .59198 L .46596 .58726 L p .644 .209 .201 r
F P
0 g
s
.51949 .59198 m .51979 .60127 L .57073 .59835 L p .555 .138 .205 r
F P
0 g
s
.57073 .59835 m .57333 .58888 L .51949 .59198 L p .555 .138 .205 r
F P
0 g
s
.24558 .56996 m .25774 .55292 L .30904 .58855 L p .84 .732 .745 r
F P
0 g
s
.30904 .58855 m .29943 .6068 L .24558 .56996 L p .84 .732 .745 r
F P
0 g
s
.62991 .57051 m .62454 .57808 L .67024 .56003 L p .175 0 0 r
F P
0 g
s
.67024 .56003 m .67816 .55139 L .62991 .57051 L p .175 0 0 r
F P
0 g
s
.69431 .54709 m .68616 .54677 L .72794 .51934 L p .68 .932 .968 r
F P
0 g
s
.72794 .51934 m .73838 .51825 L .69431 .54709 L p .68 .932 .968 r
F P
0 g
s
.28154 .52413 m .29302 .51528 L .33702 .54699 L p .776 .751 .83 r
F P
0 g
s
.57333 .58888 m .57073 .59835 L .61915 .5882 L p .437 .032 .171 r
F P
0 g
s
.61915 .5882 m .62454 .57808 L .57333 .58888 L p .437 .032 .171 r
F P
0 g
s
.41565 .57491 m .40973 .56715 L .36305 .54652 L p .701 .166 0 r
F P
0 g
s
.40973 .56715 m .41565 .57491 L .46596 .58726 L p .67 .167 .041 r
F P
0 g
s
.46914 .59683 m .46596 .58726 L .41565 .57491 L p .714 .254 .158 r
F P
0 g
s
.46596 .58726 m .46914 .59683 L .51979 .60127 L p .644 .209 .201 r
F P
0 g
s
.71822 .52572 m .68616 .54677 L p .71771 .52541 L .437 .844 .658 r
F P
0 g
s
.70759 .53555 m .71771 .52541 L .71267 .52872 L p 0 0 0 r
F P
0 g
s
.71267 .52872 m .67816 .55139 L p .70759 .53555 L 0 0 0 r
F P
0 g
s
.70759 .53555 m .69747 .54827 L .70154 .54369 L p 0 0 0 r
F P
0 g
s
.71771 .52541 m .70759 .53555 L .71699 .52496 L p .58 .867 .549 r
F P
0 g
s
.71699 .52496 m .734 .50581 L p .71771 .52541 L .58 .867 .549 r
F P
0 g
s
.71771 .52541 m .72794 .51934 L .71822 .52572 L p .437 .844 .658 r
F P
0 g
s
.72794 .51934 m .71771 .52541 L .74579 .49381 L p .725 .987 .807 r
F P
0 g
s
.734 .50581 m .74579 .49381 L .7422 .49785 L p .58 .867 .549 r
F P
0 g
s
.7422 .49785 m .71771 .52541 L p .734 .50581 L .58 .867 .549 r
F P
0 g
s
.72221 .52043 m .734 .50581 L .73335 .50653 L p 0 0 0 r
F P
0 g
s
.73335 .50653 m .70759 .53555 L p .72221 .52043 L 0 0 0 r
F P
0 g
s
.7103 .53569 m .72221 .52043 L .69747 .54827 L p 0 0 0 r
F P
0 g
s
.72221 .52043 m .7103 .53569 L .7106 .53489 L p .846 .964 .635 r
F P
0 g
s
.70154 .54369 m .72221 .52043 L p .70759 .53555 L 0 0 0 r
F P
0 g
s
.7106 .53489 m .72155 .50669 L p .72221 .52043 L .846 .964 .635 r
F P
0 g
s
.734 .50581 m .72221 .52043 L .72422 .5153 L p .85 .97 .651 r
F P
0 g
s
.72422 .5153 m .73442 .48925 L p .734 .50581 L .85 .97 .651 r
F P
0 g
s
.62454 .57808 m .61915 .5882 L .66229 .57124 L p .26 0 .083 r
F P
0 g
s
.66229 .57124 m .67024 .56003 L .62454 .57808 L p .26 0 .083 r
F P
0 g
s
.5201 .61118 m .51979 .60127 L .46914 .59683 L p .649 .22 .216 r
F P
0 g
s
.51979 .60127 m .5201 .61118 L .56809 .60845 L p .561 .15 .219 r
F P
0 g
s
.56809 .60845 m .57073 .59835 L .51979 .60127 L p .561 .15 .219 r
F P
0 g
s
.36305 .54652 m .37146 .55545 L .41565 .57491 L p .701 .166 0 r
F P
0 g
s
.42159 .58522 m .41565 .57491 L .37146 .55545 L p .763 .27 .055 r
F P
0 g
s
.41565 .57491 m .42159 .58522 L .46914 .59683 L p .714 .254 .158 r
F P
0 g
s
.57073 .59835 m .56809 .60845 L .61368 .59894 L p .445 .046 .186 r
F P
0 g
s
.61368 .59894 m .61915 .5882 L .57073 .59835 L p .445 .046 .186 r
F P
0 g
s
.67816 .55139 m .67024 .56003 L .70759 .53555 L p 0 0 0 r
F P
0 g
s
.47238 .60702 m .46914 .59683 L .42159 .58522 L p .72 .266 .174 r
F P
0 g
s
.46914 .59683 m .47238 .60702 L .5201 .61118 L p .649 .22 .216 r
F P
0 g
s
.77143 .54489 m .76012 .53161 L .79549 .49303 L p .519 .521 .797 r
F P
0 g
s
.76012 .53161 m .7491 .52244 L .78253 .48552 L p .571 .602 .845 r
F P
0 g
s
.78253 .48552 m .79549 .49303 L .76012 .53161 L p .571 .602 .845 r
F P
0 g
s
.78298 .56099 m .77143 .54489 L .80882 .50473 L p .492 .479 .771 r
F P
0 g
s
.79549 .49303 m .80882 .50473 L .77143 .54489 L p .519 .521 .797 r
F P
0 g
s
.7491 .52244 m .73838 .51825 L .76996 .48304 L p .655 .74 .913 r
F P
0 g
s
.76996 .48304 m .78253 .48552 L .7491 .52244 L p .655 .74 .913 r
F P
0 g
s
.79464 .57831 m .78298 .56099 L .82244 .5193 L p .482 .464 .761 r
F P
0 g
s
.80882 .50473 m .82244 .5193 L .78298 .56099 L p .492 .479 .771 r
F P
0 g
s
.61915 .5882 m .61368 .59894 L .65423 .58309 L p .272 0 .102 r
F P
0 g
s
.65423 .58309 m .66229 .57124 L .61915 .5882 L p .272 0 .102 r
F P
0 g
s
.73838 .51825 m .72794 .51934 L .75774 .48591 L p .747 .922 .949 r
F P
0 g
s
.75774 .48591 m .76996 .48304 L .73838 .51825 L p .747 .922 .949 r
F P
0 g
s
.82244 .5193 m .83625 .53514 L .79464 .57831 L p .482 .464 .761 r
F P
0 g
s
.52041 .61953 m .5201 .61118 L .47238 .60702 L p .626 .172 .154 r
F P
0 g
s
.5201 .61118 m .52041 .61953 L .56538 .61698 L p .535 .099 .158 r
F P
0 g
s
.56538 .61698 m .56809 .60845 L .5201 .61118 L p .535 .099 .158 r
F P
0 g
s
.37146 .55545 m .37989 .56694 L .42159 .58522 L p .763 .27 .055 r
F P
0 g
s
.42763 .59616 m .42159 .58522 L .37989 .56694 L p .771 .285 .075 r
F P
0 g
s
.42159 .58522 m .42763 .59616 L .47238 .60702 L p .72 .266 .174 r
F P
0 g
s
.67024 .56003 m .66229 .57124 L .69747 .54827 L p 0 0 0 r
F P
0 g
s
.69747 .54827 m .70759 .53555 L .67024 .56003 L p 0 0 0 r
F P
0 g
s
.23572 .49563 m .24939 .4843 L .28154 .52413 L p .843 .793 .803 r
F P
0 g
s
.28154 .52413 m .26976 .53711 L .23572 .49563 L p .843 .793 .803 r
F P
0 g
s
.29302 .51528 m .28154 .52413 L .24939 .4843 L p .789 .786 .85 r
F P
0 g
s
.24939 .4843 m .26266 .47717 L .29302 .51528 L p .789 .786 .85 r
F P
0 g
s
.30417 .51141 m .29302 .51528 L .26266 .47717 L p .666 .75 .913 r
F P
0 g
s
.22175 .50984 m .23572 .49563 L .26976 .53711 L p .867 .793 .776 r
F P
0 g
s
.26976 .53711 m .25774 .55292 L .22175 .50984 L p .867 .793 .776 r
F P
0 g
s
.56809 .60845 m .56538 .61698 L .60807 .60813 L p .411 0 .119 r
F P
0 g
s
.60807 .60813 m .61368 .59894 L .56809 .60845 L p .411 0 .119 r
F P
0 g
s
.47571 .61566 m .47238 .60702 L .42763 .59616 L p .695 .215 .104 r
F P
0 g
s
.47238 .60702 m .47571 .61566 L .52041 .61953 L p .626 .172 .154 r
F P
0 g
s
.20758 .52532 m .22175 .50984 L .25774 .55292 L p .875 .793 .766 r
F P
0 g
s
.25774 .55292 m .24558 .56996 L .20758 .52532 L p .875 .793 .766 r
F P
0 g
s
.74579 .49381 m .75774 .48591 L .72794 .51934 L p .725 .987 .807 r
F P
0 g
s
.26266 .47717 m .27554 .47509 L .30417 .51141 L p .666 .75 .913 r
F P
0 g
s
.31502 .51284 m .30417 .51141 L .27554 .47509 L p .399 .624 .944 r
F P
0 g
s
.27554 .47509 m .28805 .47837 L .31502 .51284 L p .399 .624 .944 r
F P
0 g
s
.32565 .51926 m .31502 .51284 L .28805 .47837 L p 0 .35 .824 r
F P
0 g
s
.61368 .59894 m .60807 .60813 L .64597 .59338 L p .222 0 .02 r
F P
0 g
s
.64597 .59338 m .65423 .58309 L .61368 .59894 L p .222 0 .02 r
F P
0 g
s
.66229 .57124 m .65423 .58309 L .68721 .56164 L p 0 0 0 r
F P
0 g
s
.68721 .56164 m .69747 .54827 L .66229 .57124 L p 0 0 0 r
F P
0 g
s
.52074 .6241 m .52041 .61953 L .47571 .61566 L p .516 0 0 r
F P
0 g
s
.52041 .61953 m .52074 .6241 L .56258 .62174 L p .417 0 0 r
F P
0 g
s
.56258 .62174 m .56538 .61698 L .52041 .61953 L p .417 0 0 r
F P
0 g
s
.37989 .56694 m .38845 .57907 L .42763 .59616 L p .771 .285 .075 r
F P
0 g
s
.43382 .60553 m .42763 .59616 L .38845 .57907 L p .736 .223 0 r
F P
0 g
s
.42763 .59616 m .43382 .60553 L .47571 .61566 L p .695 .215 .104 r
F P
0 g
s
.56538 .61698 m .56258 .62174 L .60226 .61353 L p .264 0 0 r
F P
0 g
s
.60226 .61353 m .60807 .60813 L .56538 .61698 L p .264 0 0 r
F P
0 g
s
.5137 .40432 m .51752 .37712 L .52439 .3778 L p .734 .578 .679 r
F P
0 g
s
.52439 .3778 m .52403 .40533 L .5137 .40432 L p .734 .578 .679 r
F P
0 g
s
.52475 .35718 m .52439 .3778 L .51752 .37712 L p .731 .608 .721 r
F P
0 g
s
.52403 .40533 m .52439 .3778 L .53131 .37735 L p .688 .539 .679 r
F P
0 g
s
.52439 .3778 m .52475 .35718 L .52821 .35695 L p .691 .575 .721 r
F P
0 g
s
.52821 .35695 m .53131 .37735 L .52439 .3778 L p .691 .575 .721 r
F P
0 g
s
.53131 .37735 m .53443 .40467 L .52403 .40533 L p .688 .539 .679 r
F P
0 g
s
.53443 .40467 m .53131 .37735 L .53782 .37579 L p .637 .502 .682 r
F P
0 g
s
.53131 .37735 m .52821 .35695 L .53147 .35616 L p .648 .545 .725 r
F P
0 g
s
.53147 .35616 m .53782 .37579 L .53131 .37735 L p .648 .545 .725 r
F P
0 g
s
.50411 .40168 m .51115 .37534 L .51752 .37712 L p .779 .62 .683 r
F P
0 g
s
.51752 .37712 m .5137 .40432 L .50411 .40168 L p .779 .62 .683 r
F P
0 g
s
.52131 .35683 m .51752 .37712 L .51115 .37534 L p .769 .646 .726 r
F P
0 g
s
.51752 .37712 m .52131 .35683 L .52475 .35718 L p .731 .608 .721 r
F P
0 g
s
.38845 .57907 m .37989 .56694 L .34669 .54285 L p .76 .249 0 r
F P
0 g
s
.47915 .62051 m .47571 .61566 L .43382 .60553 L p .573 .012 0 r
F P
0 g
s
.47571 .61566 m .47915 .62051 L .52074 .6241 L p .516 0 0 r
F P
0 g
s
.52511 .3445 m .52475 .35718 L .52131 .35683 L closepath p .71 .676 .815 r
F P
0 g
s
.52511 .3445 m .52821 .35695 L .52475 .35718 L closepath p .688 .658 .815 r
F P
0 g
s
.52511 .3445 m .53147 .35616 L .52821 .35695 L closepath p .665 .643 .818 r
F P
0 g
s
.51115 .37534 m .51813 .35593 L .52131 .35683 L p .769 .646 .726 r
F P
0 g
s
.52511 .3445 m .52131 .35683 L .51813 .35593 L closepath p .731 .698 .82 r
F P
0 g
s
.53782 .37579 m .54422 .40236 L .53443 .40467 L p .637 .502 .682 r
F P
0 g
s
.54422 .40236 m .53782 .37579 L .54349 .37323 L p .578 .465 .688 r
F P
0 g
s
.53782 .37579 m .53147 .35616 L .5343 .35486 L p .599 .517 .733 r
F P
0 g
s
.5343 .35486 m .54349 .37323 L .53782 .37579 L p .599 .517 .733 r
F P
0 g
s
.52511 .3445 m .5343 .35486 L .53147 .35616 L closepath p .64 .632 .826 r
F P
0 g
s
.28805 .47837 m .30028 .48669 L .32565 .51926 L p 0 .35 .824 r
F P
0 g
s
.50571 .37259 m .51542 .35454 L .51813 .35593 L p .807 .69 .736 r
F P
0 g
s
.51813 .35593 m .51115 .37534 L .50571 .37259 L p .807 .69 .736 r
F P
0 g
s
.52511 .3445 m .51813 .35593 L .51542 .35454 L closepath p .749 .723 .828 r
F P
0 g
s
.49592 .3976 m .50571 .37259 L .51115 .37534 L p .825 .67 .69 r
F P
0 g
s
.51115 .37534 m .50411 .40168 L .49592 .3976 L p .825 .67 .69 r
F P
0 g
s
.50984 .43677 m .5137 .40432 L .52403 .40533 L p .735 .563 .659 r
F P
0 g
s
.52403 .40533 m .52366 .4381 L .50984 .43677 L p .735 .563 .659 r
F P
0 g
s
.52366 .4381 m .52403 .40533 L .53443 .40467 L p .686 .522 .659 r
F P
0 g
s
.54349 .37323 m .5343 .35486 L .5365 .35315 L p .541 .49 .747 r
F P
0 g
s
.52511 .3445 m .5365 .35315 L .5343 .35486 L closepath p .613 .624 .839 r
F P
0 g
s
.53443 .40467 m .53757 .43723 L .52366 .4381 L p .686 .522 .659 r
F P
0 g
s
.53757 .43723 m .53443 .40467 L .54422 .40236 L p .631 .482 .661 r
F P
0 g
s
.50157 .36903 m .51336 .35275 L .51542 .35454 L p .844 .742 .751 r
F P
0 g
s
.51542 .35454 m .50571 .37259 L .50157 .36903 L p .844 .742 .751 r
F P
0 g
s
.52511 .3445 m .51542 .35454 L .51336 .35275 L closepath p .763 .751 .842 r
F P
0 g
s
.49701 .43331 m .50411 .40168 L .5137 .40432 L p .783 .607 .662 r
F P
0 g
s
.5137 .40432 m .50984 .43677 L .49701 .43331 L p .783 .607 .662 r
F P
0 g
s
.54349 .37323 m .55275 .39855 L .54422 .40236 L p .578 .465 .688 r
F P
0 g
s
.55275 .39855 m .54349 .37323 L .54793 .36983 L p .504 .423 .698 r
F P
0 g
s
.5365 .35315 m .54793 .36983 L .54349 .37323 L p .541 .49 .747 r
F P
0 g
s
.54793 .36983 m .5365 .35315 L .53794 .35112 L p .467 .461 .767 r
F P
0 g
s
.52511 .3445 m .53794 .35112 L .5365 .35315 L closepath p .584 .622 .855 r
F P
0 g
s
.48965 .39232 m .50157 .36903 L .50571 .37259 L p .874 .73 .701 r
F P
0 g
s
.50571 .37259 m .49592 .3976 L .48965 .39232 L p .874 .73 .701 r
F P
0 g
s
.49901 .36492 m .5121 .35068 L .51336 .35275 L p .88 .807 .773 r
F P
0 g
s
.51336 .35275 m .50157 .36903 L .49901 .36492 L p .88 .807 .773 r
F P
0 g
s
.52511 .3445 m .51336 .35275 L .5121 .35068 L closepath p .773 .781 .859 r
F P
0 g
s
.54422 .40236 m .55068 .43419 L .53757 .43723 L p .631 .482 .661 r
F P
0 g
s
.55068 .43419 m .54422 .40236 L .55275 .39855 L p .567 .439 .666 r
F P
0 g
s
.486 .42793 m .49592 .3976 L .50411 .40168 L p .833 .659 .667 r
F P
0 g
s
.50411 .40168 m .49701 .43331 L .486 .42793 L p .833 .659 .667 r
F P
0 g
s
.52511 .3445 m .53487 .34283 L .53692 .34464 L closepath p .474 .677 .954 r
F P
0 g
s
.52511 .3445 m .53215 .34142 L .53487 .34283 L closepath p .461 .71 .976 r
F P
0 g
s
.52511 .3445 m .52895 .3405 L .53215 .34142 L closepath p .466 .749 .991 r
F P
0 g
s
.52511 .3445 m .52548 .34015 L .52895 .3405 L closepath p .492 .791 .998 r
F P
0 g
s
.52511 .3445 m .52199 .34038 L .52548 .34015 L closepath p .539 .831 .999 r
F P
0 g
s
.52511 .3445 m .51871 .34118 L .52199 .34038 L closepath p .6 .864 .993 r
F P
0 g
s
.52511 .3445 m .51587 .3425 L .51871 .34118 L closepath p .661 .882 .98 r
F P
0 g
s
.52511 .3445 m .51367 .34423 L .51587 .3425 L closepath p .714 .883 .959 r
F P
0 g
s
.52511 .3445 m .51226 .34627 L .51367 .34423 L closepath p .75 .868 .934 r
F P
0 g
s
.52511 .3445 m .51172 .34847 L .51226 .34627 L closepath p .77 .843 .907 r
F P
0 g
s
.52511 .3445 m .5121 .35068 L .51172 .34847 L closepath p .777 .813 .882 r
F P
0 g
s
.52511 .3445 m .5385 .34893 L .53794 .35112 L closepath p .555 .625 .877 r
F P
0 g
s
.52511 .3445 m .53816 .34672 L .5385 .34893 L closepath p .525 .635 .901 r
F P
0 g
s
.52511 .3445 m .53692 .34464 L .53816 .34672 L closepath p .497 .652 .928 r
F P
0 g
s
.53794 .35112 m .55083 .36581 L .54793 .36983 L p .467 .461 .767 r
F P
0 g
s
.55083 .36581 m .53794 .35112 L .5385 .34893 L p .366 .429 .794 r
F P
0 g
s
.49822 .36052 m .51172 .34847 L .5121 .35068 L p .907 .884 .799 r
F P
0 g
s
.5121 .35068 m .49901 .36492 L .49822 .36052 L p .907 .884 .799 r
F P
0 g
s
.54793 .36983 m .55946 .3935 L .55275 .39855 L p .504 .423 .698 r
F P
0 g
s
.55946 .3935 m .54793 .36983 L .55083 .36581 L p .402 .372 .711 r
F P
0 g
s
.48576 .38619 m .49901 .36492 L .50157 .36903 L p .923 .807 .714 r
F P
0 g
s
.50157 .36903 m .48965 .39232 L .48576 .38619 L p .923 .807 .714 r
F P
0 g
s
.50594 .47231 m .50984 .43677 L .52366 .4381 L p .735 .556 .65 r
F P
0 g
s
.52366 .4381 m .52329 .47395 L .50594 .47231 L p .735 .556 .65 r
F P
0 g
s
.52329 .47395 m .52366 .4381 L .53757 .43723 L p .685 .514 .65 r
F P
0 g
s
.5385 .34893 m .552 .36144 L .55083 .36581 L p .366 .429 .794 r
F P
0 g
s
.552 .36144 m .5385 .34893 L .53816 .34672 L p .217 .386 .818 r
F P
0 g
s
.60807 .60813 m .60226 .61353 L .63744 .59986 L p .027 0 0 r
F P
0 g
s
.63744 .59986 m .64597 .59338 L .60807 .60813 L p .027 0 0 r
F P
0 g
s
.53757 .43723 m .54075 .47287 L .52329 .47395 L p .685 .514 .65 r
F P
0 g
s
.54075 .47287 m .53757 .43723 L .55068 .43419 L p .629 .473 .652 r
F P
0 g
s
.49926 .35612 m .51226 .34627 L .51172 .34847 L p .9 .965 .821 r
F P
0 g
s
.51172 .34847 m .49822 .36052 L .49926 .35612 L p .9 .965 .821 r
F P
0 g
s
.55275 .39855 m .56213 .42919 L .55068 .43419 L p .567 .439 .666 r
F P
0 g
s
.56213 .42919 m .55275 .39855 L .55946 .3935 L p .485 .39 .673 r
F P
0 g
s
.48981 .46805 m .49701 .43331 L .50984 .43677 L p .785 .602 .653 r
F P
0 g
s
.50984 .43677 m .50594 .47231 L .48981 .46805 L p .785 .602 .653 r
F P
0 g
s
.47756 .42097 m .48965 .39232 L .49592 .3976 L p .886 .723 .674 r
F P
0 g
s
.49592 .3976 m .486 .42793 L .47756 .42097 L p .886 .723 .674 r
F P
0 g
s
.52108 .62293 m .52074 .6241 L .47915 .62051 L p .137 .667 .869 r
F P
0 g
s
.52074 .6241 m .52108 .62293 L .55967 .62074 L p .217 .734 .865 r
F P
0 g
s
.55967 .62074 m .56258 .62174 L .52074 .6241 L p .217 .734 .865 r
F P
0 g
s
.53816 .34672 m .55133 .35702 L .552 .36144 L p .217 .386 .818 r
F P
0 g
s
.55133 .35702 m .53816 .34672 L .53692 .34464 L p 0 .321 .809 r
F P
0 g
s
.65423 .58309 m .64597 .59338 L .67671 .57344 L p 0 0 0 r
F P
0 g
s
.67671 .57344 m .68721 .56164 L .65423 .58309 L p 0 0 0 r
F P
0 g
s
.50208 .35204 m .51367 .34423 L .51226 .34627 L p .794 .998 .797 r
F P
0 g
s
.51226 .34627 m .49926 .35612 L .50208 .35204 L p .794 .998 .797 r
F P
0 g
s
.55083 .36581 m .56388 .38752 L .55946 .3935 L p .402 .372 .711 r
F P
0 g
s
.56388 .38752 m .55083 .36581 L .552 .36144 L p .244 .299 .722 r
F P
0 g
s
.38845 .57907 m .39721 .58964 L .43382 .60553 L p .736 .223 0 r
F P
0 g
s
.44021 .61112 m .43382 .60553 L .39721 .58964 L p .566 0 0 r
F P
0 g
s
.43382 .60553 m .44021 .61112 L .47915 .62051 L p .573 .012 0 r
F P
0 g
s
.55068 .43419 m .55722 .46914 L .54075 .47287 L p .629 .473 .652 r
F P
0 g
s
.55722 .46914 m .55068 .43419 L .56213 .42919 L p .563 .429 .656 r
F P
0 g
s
.48452 .37963 m .49822 .36052 L .49901 .36492 L p .959 .899 .722 r
F P
0 g
s
.49901 .36492 m .48576 .38619 L .48452 .37963 L p .959 .899 .722 r
F P
0 g
s
.53692 .34464 m .54887 .35285 L .55133 .35702 L p 0 .321 .809 r
F P
0 g
s
.54887 .35285 m .53692 .34464 L .53487 .34283 L p 0 .223 .7 r
F P
0 g
s
.47595 .46142 m .486 .42793 L .49701 .43331 L p .836 .654 .657 r
F P
0 g
s
.49701 .43331 m .48981 .46805 L .47595 .46142 L p .836 .654 .657 r
F P
0 g
s
.79549 .49303 m .78253 .48552 L .80002 .44373 L p .535 .604 .869 r
F P
0 g
s
.78253 .48552 m .76996 .48304 L .78629 .44329 L p .654 .741 .914 r
F P
0 g
s
.78629 .44329 m .80002 .44373 L .78253 .48552 L p .654 .741 .914 r
F P
0 g
s
.5065 .34856 m .51587 .3425 L .51367 .34423 L p .515 .88 .662 r
F P
0 g
s
.51367 .34423 m .50208 .35204 L .5065 .34856 L p .515 .88 .662 r
F P
0 g
s
.56258 .62174 m .55967 .62074 L .59625 .61317 L p .349 .822 .891 r
F P
0 g
s
.59625 .61317 m .60226 .61353 L .56258 .62174 L p .349 .822 .891 r
F P
0 g
s
.30028 .48669 m .31234 .49912 L .33617 .52976 L p 0 .069 .602 r
F P
0 g
s
.80882 .50473 m .79549 .49303 L .8142 .44928 L p .454 .509 .826 r
F P
0 g
s
.80002 .44373 m .8142 .44928 L .79549 .49303 L p .535 .604 .869 r
F P
0 g
s
.55946 .3935 m .57116 .42252 L .56213 .42919 L p .485 .39 .673 r
F P
0 g
s
.57116 .42252 m .55946 .3935 L .56388 .38752 L p .367 .325 .68 r
F P
0 g
s
.53487 .34283 m .54477 .34922 L .54887 .35285 L p 0 .223 .7 r
F P
0 g
s
.54477 .34922 m .53487 .34283 L .53215 .34142 L p .454 0 0 r
F P
0 g
s
.48272 .61961 m .47915 .62051 L .44021 .61112 L p .119 .627 .898 r
F P
0 g
s
.47915 .62051 m .48272 .61961 L .52108 .62293 L p .137 .667 .869 r
F P
0 g
s
.5122 .34592 m .51871 .34118 L .51587 .3425 L p 0 0 0 r
F P
0 g
s
.51587 .3425 m .5065 .34856 L .5122 .34592 L p 0 0 0 r
F P
0 g
s
.47228 .41287 m .48576 .38619 L .48965 .39232 L p .94 .803 .681 r
F P
0 g
s
.48965 .39232 m .47756 .42097 L .47228 .41287 L p .94 .803 .681 r
F P
0 g
s
.76996 .48304 m .75774 .48591 L .77297 .44824 L p .783 .891 .921 r
F P
0 g
s
.77297 .44824 m .78629 .44329 L .76996 .48304 L p .783 .891 .921 r
F P
0 g
s
.34669 .54285 m .35734 .55658 L .38845 .57907 L p .76 .249 0 r
F P
0 g
s
.39721 .58964 m .38845 .57907 L .35734 .55658 L p .697 .167 0 r
F P
0 g
s
.552 .36144 m .56568 .381 L .56388 .38752 L p .244 .299 .722 r
F P
0 g
s
.56568 .381 m .552 .36144 L .55133 .35702 L p 0 .179 .7 r
F P
0 g
s
.502 .50845 m .50594 .47231 L .52329 .47395 L p .735 .556 .65 r
F P
0 g
s
.52329 .47395 m .52291 .51038 L .502 .50845 L p .735 .556 .65 r
F P
0 g
s
.52291 .51038 m .52329 .47395 L .54075 .47287 L p .684 .514 .65 r
F P
0 g
s
.53215 .34142 m .5393 .34639 L .54477 .34922 L p .454 0 0 r
F P
0 g
s
.5393 .34639 m .53215 .34142 L .52895 .3405 L p .499 0 0 r
F P
0 g
s
.51881 .34431 m .52199 .34038 L .51871 .34118 L p .142 0 0 r
F P
0 g
s
.51871 .34118 m .5122 .34592 L .51881 .34431 L p .142 0 0 r
F P
0 g
s
.48605 .37306 m .49926 .35612 L .49822 .36052 L p .919 .971 .684 r
F P
0 g
s
.49822 .36052 m .48452 .37963 L .48605 .37306 L p .919 .971 .684 r
F P
0 g
s
.82244 .5193 m .80882 .50473 L .82883 .45908 L p .408 .456 .798 r
F P
0 g
s
.8142 .44928 m .82883 .45908 L .80882 .50473 L p .454 .509 .826 r
F P
0 g
s
.54075 .47287 m .54396 .50911 L .52291 .51038 L p .684 .514 .65 r
F P
0 g
s
.54396 .50911 m .54075 .47287 L .55722 .46914 L p .629 .472 .651 r
F P
0 g
s
.52895 .3405 m .53285 .34455 L .5393 .34639 L p .499 0 0 r
F P
0 g
s
.53285 .34455 m .52895 .3405 L .52548 .34015 L p .448 0 0 r
F P
0 g
s
.52585 .34384 m .52548 .34015 L .52199 .34038 L p .332 0 0 r
F P
0 g
s
.52199 .34038 m .51881 .34431 L .52585 .34384 L p .332 0 0 r
F P
0 g
s
.52548 .34015 m .52585 .34384 L .53285 .34455 L p .448 0 0 r
F P
0 g
s
.56213 .42919 m .57163 .46297 L .55722 .46914 L p .563 .429 .656 r
F P
0 g
s
.57163 .46297 m .56213 .42919 L .57116 .42252 L p .477 .376 .661 r
F P
0 g
s
.48254 .50341 m .48981 .46805 L .50594 .47231 L p .785 .601 .652 r
F P
0 g
s
.50594 .47231 m .502 .50845 L .48254 .50341 L p .785 .601 .652 r
F P
0 g
s
.46529 .45283 m .47756 .42097 L .486 .42793 L p .891 .719 .662 r
F P
0 g
s
.486 .42793 m .47595 .46142 L .46529 .45283 L p .891 .719 .662 r
F P
0 g
s
.55133 .35702 m .56472 .3744 L .56568 .381 L p 0 .179 .7 r
F P
0 g
s
.56472 .3744 m .55133 .35702 L .54887 .35285 L p 0 0 .55 r
F P
0 g
s
.56388 .38752 m .57713 .41462 L .57116 .42252 L p .367 .325 .68 r
F P
0 g
s
.57713 .41462 m .56388 .38752 L .56568 .381 L p .175 .226 .676 r
F P
0 g
s
.55722 .46914 m .56383 .5047 L .54396 .50911 L p .629 .472 .651 r
F P
0 g
s
.56383 .5047 m .55722 .46914 L .57163 .46297 L p .562 .428 .655 r
F P
0 g
s
.75774 .48591 m .74579 .49381 L .75998 .45828 L p .862 .983 .85 r
F P
0 g
s
.75998 .45828 m .77297 .44824 L .75774 .48591 L p .862 .983 .85 r
F P
0 g
s
.49027 .36694 m .50208 .35204 L .49926 .35612 L p .641 .865 .494 r
F P
0 g
s
.49926 .35612 m .48605 .37306 L .49027 .36694 L p .641 .865 .494 r
F P
0 g
s
.69747 .54827 m .68721 .56164 L .7103 .53569 L p 0 0 0 r
F P
0 g
s
.83625 .53514 m .82244 .5193 L .84383 .4718 L p .391 .436 .787 r
F P
0 g
s
.82883 .45908 m .84383 .4718 L .82244 .5193 L p .408 .456 .798 r
F P
0 g
s
.47055 .40417 m .48452 .37963 L .48576 .38619 L p .978 .898 .671 r
F P
0 g
s
.48576 .38619 m .47228 .41287 L .47055 .40417 L p .978 .898 .671 r
F P
0 g
s
.46579 .49557 m .47595 .46142 L .48981 .46805 L p .836 .654 .656 r
F P
0 g
s
.48981 .46805 m .48254 .50341 L .46579 .49557 L p .836 .654 .656 r
F P
0 g
s
.23448 .43978 m .24881 .43467 L .26266 .47717 L p .794 .823 .874 r
F P
0 g
s
.26266 .47717 m .24939 .4843 L .23448 .43978 L p .794 .823 .874 r
F P
0 g
s
.27554 .47509 m .26266 .47717 L .24881 .43467 L p .666 .752 .914 r
F P
0 g
s
.52143 .61459 m .52108 .62293 L .48272 .61961 L p .671 .739 .901 r
F P
0 g
s
.52108 .62293 m .52143 .61459 L .55666 .61259 L p .665 .734 .901 r
F P
0 g
s
.55666 .61259 m .55967 .62074 L .52108 .62293 L p .665 .734 .901 r
F P
0 g
s
.60226 .61353 m .59625 .61317 L .62862 .60057 L p .506 .904 .927 r
F P
0 g
s
.62862 .60057 m .63744 .59986 L .60226 .61353 L p .506 .904 .927 r
F P
0 g
s
.21969 .44914 m .23448 .43978 L .24939 .4843 L p .861 .852 .832 r
F P
0 g
s
.24939 .4843 m .23572 .49563 L .21969 .44914 L p .861 .852 .832 r
F P
0 g
s
.49805 .54258 m .502 .50845 L .52291 .51038 L p .735 .561 .656 r
F P
0 g
s
.52291 .51038 m .52254 .5448 L .49805 .54258 L p .735 .561 .656 r
F P
0 g
s
.52254 .5448 m .52291 .51038 L .54396 .50911 L p .685 .519 .656 r
F P
0 g
s
.24881 .43467 m .26268 .43468 L .27554 .47509 L p .666 .752 .914 r
F P
0 g
s
.28805 .47837 m .27554 .47509 L .26268 .43468 L p .454 .611 .915 r
F P
0 g
s
.54887 .35285 m .56105 .36815 L .56472 .3744 L p 0 0 .55 r
F P
0 g
s
.56105 .36815 m .54887 .35285 L .54477 .34922 L p .703 .193 0 r
F P
0 g
s
.57116 .42252 m .58303 .45475 L .57163 .46297 L p .477 .376 .661 r
F P
0 g
s
.58303 .45475 m .57116 .42252 L .57713 .41462 L p .351 .304 .665 r
F P
0 g
s
.54396 .50911 m .54718 .54334 L .52254 .5448 L p .685 .519 .656 r
F P
0 g
s
.54718 .54334 m .54396 .50911 L .56383 .5047 L p .63 .479 .658 r
F P
0 g
s
.49692 .36171 m .5065 .34856 L .50208 .35204 L p 0 0 0 r
F P
0 g
s
.50208 .35204 m .49027 .36694 L .49692 .36171 L p 0 0 0 r
F P
0 g
s
.55967 .62074 m .55666 .61259 L .59003 .60564 L p .657 .729 .903 r
F P
0 g
s
.59003 .60564 m .59625 .61317 L .55967 .62074 L p .657 .729 .903 r
F P
0 g
s
.47524 .5368 m .48254 .50341 L .502 .50845 L p .784 .606 .659 r
F P
0 g
s
.502 .50845 m .49805 .54258 L .47524 .5368 L p .784 .606 .659 r
F P
0 g
s
.39721 .58964 m .40625 .5964 L .44021 .61112 L p .566 0 0 r
F P
0 g
s
.44684 .61095 m .44021 .61112 L .40625 .5964 L p .157 .607 .933 r
F P
0 g
s
.44021 .61112 m .44684 .61095 L .48272 .61961 L p .119 .627 .898 r
F P
0 g
s
.45856 .44281 m .47228 .41287 L .47756 .42097 L p .947 .8 .665 r
F P
0 g
s
.47756 .42097 m .46529 .45283 L .45856 .44281 L p .947 .8 .665 r
F P
0 g
s
.64597 .59338 m .63744 .59986 L .66589 .58142 L p 0 0 0 r
F P
0 g
s
.66589 .58142 m .67671 .57344 L .64597 .59338 L p 0 0 0 r
F P
0 g
s
.48642 .61154 m .48272 .61961 L .44684 .61095 L p .677 .746 .903 r
F P
0 g
s
.48272 .61961 m .48642 .61154 L .52143 .61459 L p .671 .739 .901 r
F P
0 g
s
.20452 .46145 m .21969 .44914 L .23572 .49563 L p .892 .863 .804 r
F P
0 g
s
.23572 .49563 m .22175 .50984 L .20452 .46145 L p .892 .863 .804 r
F P
0 g
s
.84383 .4718 m .85906 .48583 L .83625 .53514 L p .391 .436 .787 r
F P
0 g
s
.56568 .381 m .57962 .406 L .57713 .41462 L p .175 .226 .676 r
F P
0 g
s
.57962 .406 m .56568 .381 L .56472 .3744 L p 0 .053 .612 r
F P
0 g
s
.57163 .46297 m .58124 .49741 L .56383 .5047 L p .562 .428 .655 r
F P
0 g
s
.58124 .49741 m .57163 .46297 L .58303 .45475 L p .476 .374 .66 r
F P
0 g
s
.54477 .34922 m .55487 .3627 L .56105 .36815 L p .703 .193 0 r
F P
0 g
s
.55487 .3627 m .54477 .34922 L .5393 .34639 L p .761 .255 0 r
F P
0 g
s
.47255 .39545 m .48605 .37306 L .48452 .37963 L p .9 .942 .58 r
F P
0 g
s
.48452 .37963 m .47055 .40417 L .47255 .39545 L p .9 .942 .58 r
F P
0 g
s
.50554 .35773 m .5122 .34592 L .5065 .34856 L p .188 0 .03 r
F P
0 g
s
.5065 .34856 m .49692 .36171 L .50554 .35773 L p .188 0 .03 r
F P
0 g
s
.26268 .43468 m .27612 .4401 L .28805 .47837 L p .454 .611 .915 r
F P
0 g
s
.30028 .48669 m .28805 .47837 L .27612 .4401 L p .195 .416 .849 r
F P
0 g
s
.45284 .48539 m .46529 .45283 L .47595 .46142 L p .891 .718 .661 r
F P
0 g
s
.47595 .46142 m .46579 .49557 L .45284 .48539 L p .891 .718 .661 r
F P
0 g
s
.74579 .49381 m .734 .50581 L .74718 .47246 L p .868 .991 .734 r
F P
0 g
s
.74718 .47246 m .75998 .45828 L .74579 .49381 L p .868 .991 .734 r
F P
0 g
s
.56383 .5047 m .57046 .53828 L .54718 .54334 L p .63 .479 .658 r
F P
0 g
s
.57046 .53828 m .56383 .5047 L .58124 .49741 L p .566 .436 .662 r
F P
0 g
s
.49411 .5723 m .49805 .54258 L .52254 .5448 L p .735 .572 .672 r
F P
0 g
s
.52254 .5448 m .52216 .5748 L .49411 .5723 L p .735 .572 .672 r
F P
0 g
s
.52216 .5748 m .52254 .5448 L .54718 .54334 L p .687 .533 .672 r
F P
0 g
s
.35734 .55658 m .36824 .56874 L .39721 .58964 L p .697 .167 0 r
F P
0 g
s
.40625 .5964 m .39721 .58964 L .36824 .56874 L p .436 0 0 r
F P
0 g
s
.52179 .59845 m .52143 .61459 L .48642 .61154 L p .725 .641 .765 r
F P
0 g
s
.52143 .61459 m .52179 .59845 L .55356 .59663 L p .691 .613 .764 r
F P
0 g
s
.55356 .59663 m .55666 .61259 L .52143 .61459 L p .691 .613 .764 r
F P
0 g
s
.5393 .34639 m .54661 .35844 L .55487 .3627 L p .761 .255 0 r
F P
0 g
s
.54661 .35844 m .5393 .34639 L .53285 .34455 L p .717 .243 .122 r
F P
0 g
s
.45555 .52778 m .46579 .49557 L .48254 .50341 L p .834 .658 .664 r
F P
0 g
s
.48254 .50341 m .47524 .5368 L .45555 .52778 L p .834 .658 .664 r
F P
0 g
s
.51555 .3553 m .51881 .34431 L .5122 .34592 L p .402 0 .138 r
F P
0 g
s
.5122 .34592 m .50554 .35773 L .51555 .3553 L p .402 0 .138 r
F P
0 g
s
.54718 .54334 m .55039 .57315 L .52216 .5748 L p .687 .533 .672 r
F P
0 g
s
.55039 .57315 m .54718 .54334 L .57046 .53828 L p .635 .495 .674 r
F P
0 g
s
.18911 .47507 m .20452 .46145 L .22175 .50984 L p .903 .866 .793 r
F P
0 g
s
.22175 .50984 m .20758 .52532 L .18911 .47507 L p .903 .866 .793 r
F P
0 g
s
.57713 .41462 m .59062 .44498 L .58303 .45475 L p .351 .304 .665 r
F P
0 g
s
.59062 .44498 m .57713 .41462 L .57962 .406 L p .144 .192 .654 r
F P
0 g
s
.53285 .34455 m .53684 .35567 L .54661 .35844 L p .717 .243 .122 r
F P
0 g
s
.53684 .35567 m .53285 .34455 L .52585 .34384 L p .64 .194 .175 r
F P
0 g
s
.46795 .56579 m .47524 .5368 L .49805 .54258 L p .781 .616 .675 r
F P
0 g
s
.49805 .54258 m .49411 .5723 L .46795 .56579 L p .781 .616 .675 r
F P
0 g
s
.52623 .3546 m .52585 .34384 L .51881 .34431 L p .54 .113 .179 r
F P
0 g
s
.51881 .34431 m .51555 .3553 L .52623 .3546 L p .54 .113 .179 r
F P
0 g
s
.55666 .61259 m .55356 .59663 L .58362 .5903 L p .654 .588 .769 r
F P
0 g
s
.58362 .5903 m .59003 .60564 L .55666 .61259 L p .654 .588 .769 r
F P
0 g
s
.52585 .34384 m .52623 .3546 L .53684 .35567 L p .64 .194 .175 r
F P
0 g
s
.56472 .3744 m .5784 .39723 L .57962 .406 L p 0 .053 .612 r
F P
0 g
s
.5784 .39723 m .56472 .3744 L .56105 .36815 L p 0 0 .371 r
F P
0 g
s
.59625 .61317 m .59003 .60564 L .6195 .5941 L p .649 .726 .905 r
F P
0 g
s
.6195 .5941 m .62862 .60057 L .59625 .61317 L p .649 .726 .905 r
F P
0 g
s
.49022 .59568 m .49411 .5723 L .52216 .5748 L p .733 .595 .703 r
F P
0 g
s
.52216 .5748 m .52179 .59845 L .49022 .59568 L p .733 .595 .703 r
F P
0 g
s
.52179 .59845 m .52216 .5748 L .55039 .57315 L p .69 .559 .702 r
F P
0 g
s
.44684 .61095 m .4537 .6036 L .48642 .61154 L p .677 .746 .903 r
F P
0 g
s
.49022 .59568 m .48642 .61154 L .4537 .6036 L p .757 .674 .77 r
F P
0 g
s
.48642 .61154 m .49022 .59568 L .52179 .59845 L p .725 .641 .765 r
F P
0 g
s
.4563 .43202 m .47055 .40417 L .47228 .41287 L p .984 .895 .646 r
F P
0 g
s
.47228 .41287 m .45856 .44281 L .4563 .43202 L p .984 .895 .646 r
F P
0 g
s
.55039 .57315 m .55356 .59663 L .52179 .59845 L p .69 .559 .702 r
F P
0 g
s
.47817 .38731 m .49027 .36694 L .48605 .37306 L p 0 0 0 r
F P
0 g
s
.48605 .37306 m .47255 .39545 L .47817 .38731 L p 0 0 0 r
F P
0 g
s
.68721 .56164 m .67671 .57344 L .69813 .54937 L p .528 .815 .47 r
F P
0 g
s
.69813 .54937 m .7103 .53569 L .68721 .56164 L p .528 .815 .47 r
F P
0 g
s
.55356 .59663 m .55039 .57315 L .57708 .56745 L p .642 .526 .706 r
F P
0 g
s
.57046 .53828 m .57708 .56745 L .55039 .57315 L p .635 .495 .674 r
F P
0 g
s
.58303 .45475 m .59506 .48767 L .58124 .49741 L p .476 .374 .66 r
F P
0 g
s
.59506 .48767 m .58303 .45475 L .59062 .44498 L p .35 .303 .664 r
F P
0 g
s
.57708 .56745 m .58362 .5903 L .55356 .59663 L p .642 .526 .706 r
F P
0 g
s
.40625 .5964 m .41561 .59738 L .44684 .61095 L p .157 .607 .933 r
F P
0 g
s
.4537 .6036 m .44684 .61095 L .41561 .59738 L p .681 .754 .906 r
F P
0 g
s
.27612 .4401 m .28923 .4506 L .30028 .48669 L p .195 .416 .849 r
F P
0 g
s
.31234 .49912 m .30028 .48669 L .28923 .4506 L p 0 .239 .751 r
F P
0 g
s
.46075 .58845 m .46795 .56579 L .49411 .5723 L p .775 .636 .707 r
F P
0 g
s
.49411 .5723 m .49022 .59568 L .46075 .58845 L p .775 .636 .707 r
F P
0 g
s
.57708 .56745 m .57046 .53828 L .59091 .5299 L p .574 .455 .68 r
F P
0 g
s
.58124 .49741 m .59091 .5299 L .57046 .53828 L p .566 .436 .662 r
F P
0 g
s
.4537 .6036 m .46075 .58845 L .49022 .59568 L p .757 .674 .77 r
F P
0 g
s
.59091 .5299 m .58124 .49741 L .59506 .48767 L p .482 .385 .669 r
F P
0 g
s
.44463 .4735 m .45856 .44281 L .46529 .45283 L p .948 .8 .664 r
F P
0 g
s
.46529 .45283 m .45284 .48539 L .44463 .4735 L p .948 .8 .664 r
F P
0 g
s
.63744 .59986 m .62862 .60057 L .65472 .58361 L p .648 .951 .948 r
F P
0 g
s
.65472 .58361 m .66589 .58142 L .63744 .59986 L p .648 .951 .948 r
F P
0 g
s
.44533 .55563 m .45555 .52778 L .47524 .5368 L p .829 .667 .682 r
F P
0 g
s
.47524 .5368 m .46795 .56579 L .44533 .55563 L p .829 .667 .682 r
F P
0 g
s
.44029 .51606 m .45284 .48539 L .46579 .49557 L p .888 .722 .67 r
F P
0 g
s
.46579 .49557 m .45555 .52778 L .44029 .51606 L p .888 .722 .67 r
F P
0 g
s
.73442 .48925 m .74718 .47246 L .734 .50581 L p .85 .97 .651 r
F P
0 g
s
.56105 .36815 m .57351 .38892 L .5784 .39723 L p 0 0 .371 r
F P
0 g
s
.57351 .38892 m .56105 .36815 L .55487 .3627 L p .819 .343 0 r
F P
0 g
s
.36824 .56874 m .35734 .55658 L .33657 .52987 L p 0 0 .53 r
F P
0 g
s
.59003 .60564 m .58362 .5903 L .61013 .57981 L p .613 .567 .779 r
F P
0 g
s
.61013 .57981 m .6195 .5941 L .59003 .60564 L p .613 .567 .779 r
F P
0 g
s
.48709 .38033 m .49692 .36171 L .49027 .36694 L p 0 0 .007 r
F P
0 g
s
.49027 .36694 m .47817 .38731 L .48709 .38033 L p 0 0 .007 r
F P
0 g
s
.57962 .406 m .59384 .43429 L .59062 .44498 L p .144 .192 .654 r
F P
0 g
s
.59384 .43429 m .57962 .406 L .5784 .39723 L p 0 0 .568 r
F P
0 g
s
.58362 .5903 m .57708 .56745 L .60057 .55801 L p .588 .493 .714 r
F P
0 g
s
.59091 .5299 m .60057 .55801 L .57708 .56745 L p .574 .455 .68 r
F P
0 g
s
.36824 .56874 m .37946 .57708 L .40625 .5964 L p .436 0 0 r
F P
0 g
s
.41561 .59738 m .40625 .5964 L .37946 .57708 L p .233 .596 .949 r
F P
0 g
s
.45873 .42117 m .47255 .39545 L .47055 .40417 L p .884 .921 .528 r
F P
0 g
s
.47055 .40417 m .4563 .43202 L .45873 .42117 L p .884 .921 .528 r
F P
0 g
s
.41561 .59738 m .42528 .59118 L .4537 .6036 L p .681 .754 .906 r
F P
0 g
s
.46075 .58845 m .4537 .6036 L .42528 .59118 L p .788 .713 .781 r
F P
0 g
s
.60057 .55801 m .61013 .57981 L .58362 .5903 L p .588 .493 .714 r
F P
0 g
s
.43521 .57716 m .44533 .55563 L .46795 .56579 L p .817 .683 .716 r
F P
0 g
s
.46795 .56579 m .46075 .58845 L .43521 .57716 L p .817 .683 .716 r
F P
0 g
s
.55487 .3627 m .56523 .38166 L .57351 .38892 L p .819 .343 0 r
F P
0 g
s
.56523 .38166 m .55487 .3627 L .54661 .35844 L p .817 .363 .152 r
F P
0 g
s
.42528 .59118 m .43521 .57716 L .46075 .58845 L p .788 .713 .781 r
F P
0 g
s
.59062 .44498 m .60432 .47608 L .59506 .48767 L p .35 .303 .664 r
F P
0 g
s
.60432 .47608 m .59062 .44498 L .59384 .43429 L p .141 .189 .652 r
F P
0 g
s
.4987 .37502 m .50554 .35773 L .49692 .36171 L p .282 0 .177 r
F P
0 g
s
.49692 .36171 m .48709 .38033 L .4987 .37502 L p .282 0 .177 r
F P
0 g
s
.60057 .55801 m .59091 .5299 L .60719 .51868 L p .496 .411 .689 r
F P
0 g
s
.59506 .48767 m .60719 .51868 L .59091 .5299 L p .482 .385 .669 r
F P
0 g
s
.28923 .4506 m .30214 .46526 L .31234 .49912 L p 0 .239 .751 r
F P
0 g
s
.32439 .51417 m .31234 .49912 L .30214 .46526 L p 0 .135 .681 r
F P
0 g
s
.60719 .51868 m .59506 .48767 L .60432 .47608 L p .361 .318 .675 r
F P
0 g
s
.62862 .60057 m .6195 .5941 L .64319 .57858 L p .64 .725 .91 r
F P
0 g
s
.64319 .57858 m .65472 .58361 L .62862 .60057 L p .64 .725 .91 r
F P
0 g
s
.44178 .46066 m .4563 .43202 L .45856 .44281 L p .984 .894 .643 r
F P
0 g
s
.45856 .44281 m .44463 .4735 L .44178 .46066 L p .984 .894 .643 r
F P
0 g
s
.67671 .57344 m .66589 .58142 L .68562 .55919 L p .676 .957 .72 r
F P
0 g
s
.68562 .55919 m .69813 .54937 L .67671 .57344 L p .676 .957 .72 r
F P
0 g
s
.42772 .54239 m .44029 .51606 L .45555 .52778 L p .879 .729 .691 r
F P
0 g
s
.45555 .52778 m .44533 .55563 L .42772 .54239 L p .879 .729 .691 r
F P
0 g
s
.54661 .35844 m .55412 .37597 L .56523 .38166 L p .817 .363 .152 r
F P
0 g
s
.55412 .37597 m .54661 .35844 L .53684 .35567 L p .754 .331 .244 r
F P
0 g
s
.5784 .39723 m .59239 .42339 L .59384 .43429 L p 0 0 .568 r
F P
0 g
s
.59239 .42339 m .5784 .39723 L .57351 .38892 L p .668 .265 0 r
F P
0 g
s
.5122 .37177 m .51555 .3553 L .50554 .35773 L p .463 .096 .256 r
F P
0 g
s
.50554 .35773 m .4987 .37502 L .5122 .37177 L p .463 .096 .256 r
F P
0 g
s
.43053 .50233 m .44463 .4735 L .45284 .48539 L p .943 .802 .675 r
F P
0 g
s
.45284 .48539 m .44029 .51606 L .43053 .50233 L p .943 .802 .675 r
F P
0 g
s
.72155 .50669 m .73442 .48925 L .72221 .52043 L p .846 .964 .635 r
F P
0 g
s
.46577 .41103 m .47817 .38731 L .47255 .39545 L p 0 0 0 r
F P
0 g
s
.47255 .39545 m .45873 .42117 L .46577 .41103 L p 0 0 0 r
F P
0 g
s
.37946 .57708 m .39105 .57961 L .41561 .59738 L p .233 .596 .949 r
F P
0 g
s
.42528 .59118 m .41561 .59738 L .39105 .57961 L p .684 .762 .911 r
F P
0 g
s
.53684 .35567 m .54094 .37226 L .55412 .37597 L p .754 .331 .244 r
F P
0 g
s
.54094 .37226 m .53684 .35567 L .52623 .3546 L p .676 .277 .282 r
F P
0 g
s
.52662 .37083 m .52623 .3546 L .51555 .3553 L p .584 .203 .285 r
F P
0 g
s
.51555 .3553 m .5122 .37177 L .52662 .37083 L p .584 .203 .285 r
F P
0 g
s
.61013 .57981 m .60057 .55801 L .61933 .54535 L p .521 .458 .727 r
F P
0 g
s
.60719 .51868 m .61933 .54535 L .60057 .55801 L p .496 .411 .689 r
F P
0 g
s
.52623 .3546 m .52662 .37083 L .54094 .37226 L p .676 .277 .282 r
F P
0 g
s
.33657 .52987 m .349 .54397 L .36824 .56874 L p 0 0 .53 r
F P
0 g
s
.37946 .57708 m .36824 .56874 L .349 .54397 L p 0 .246 .751 r
F P
0 g
s
.6195 .5941 m .61013 .57981 L .63136 .56572 L p .566 .549 .794 r
F P
0 g
s
.63136 .56572 m .64319 .57858 L .6195 .5941 L p .566 .549 .794 r
F P
0 g
s
.41526 .56242 m .42772 .54239 L .44533 .55563 L p .86 .741 .73 r
F P
0 g
s
.44533 .55563 m .43521 .57716 L .41526 .56242 L p .86 .741 .73 r
F P
0 g
s
.61933 .54535 m .63136 .56572 L .61013 .57981 L p .521 .458 .727 r
F P
0 g
s
.8142 .44928 m .80002 .44373 L .79921 .39957 L p .497 .612 .897 r
F P
0 g
s
.80002 .44373 m .78629 .44329 L .7852 .40138 L p .653 .742 .915 r
F P
0 g
s
.7852 .40138 m .79921 .39957 L .80002 .44373 L p .653 .742 .915 r
F P
0 g
s
.59384 .43429 m .60832 .46336 L .60432 .47608 L p .141 .189 .652 r
F P
0 g
s
.60832 .46336 m .59384 .43429 L .59239 .42339 L p 0 0 .563 r
F P
0 g
s
.39105 .57961 m .403 .57493 L .42528 .59118 L p .684 .762 .911 r
F P
0 g
s
.43521 .57716 m .42528 .59118 L .403 .57493 L p .816 .758 .798 r
F P
0 g
s
.78629 .44329 m .77297 .44824 L .77165 .40863 L p .796 .851 .892 r
F P
0 g
s
.77165 .40863 m .7852 .40138 L .78629 .44329 L p .796 .851 .892 r
F P
0 g
s
.30214 .46526 m .315 .48254 L .32439 .51417 L p 0 .135 .681 r
F P
0 g
s
.403 .57493 m .41526 .56242 L .43521 .57716 L p .816 .758 .798 r
F P
0 g
s
.57351 .38892 m .58628 .41304 L .59239 .42339 L p .668 .265 0 r
F P
0 g
s
.58628 .41304 m .57351 .38892 L .56523 .38166 L p .851 .394 .028 r
F P
0 g
s
.61933 .54535 m .60719 .51868 L .61816 .50531 L p .387 .354 .7 r
F P
0 g
s
.60432 .47608 m .61816 .50531 L .60719 .51868 L p .361 .318 .675 r
F P
0 g
s
.66589 .58142 m .65472 .58361 L .67272 .56319 L p .747 .952 .943 r
F P
0 g
s
.67272 .56319 m .68562 .55919 L .66589 .58142 L p .747 .952 .943 r
F P
0 g
s
.44462 .44772 m .45873 .42117 L .4563 .43202 L p .882 .919 .523 r
F P
0 g
s
.4563 .43202 m .44178 .46066 L .44462 .44772 L p .882 .919 .523 r
F P
0 g
s
.82883 .45908 m .8142 .44928 L .81373 .40293 L p .37 .501 .86 r
F P
0 g
s
.79921 .39957 m .81373 .40293 L .8142 .44928 L p .497 .612 .897 r
F P
0 g
s
.47699 .40231 m .48709 .38033 L .47817 .38731 L p .025 0 .076 r
F P
0 g
s
.47817 .38731 m .46577 .41103 L .47699 .40231 L p .025 0 .076 r
F P
0 g
s
.61816 .50531 m .60432 .47608 L .60832 .46336 L p .164 .214 .669 r
F P
0 g
s
.77297 .44824 m .75998 .45828 L .75845 .42099 L p .89 .912 .834 r
F P
0 g
s
.75845 .42099 m .77165 .40863 L .77297 .44824 L p .89 .912 .834 r
F P
0 g
s
.4164 .52685 m .43053 .50233 L .44029 .51606 L p .93 .807 .702 r
F P
0 g
s
.44029 .51606 m .42772 .54239 L .4164 .52685 L p .93 .807 .702 r
F P
0 g
s
.42707 .48747 m .44178 .46066 L .44463 .4735 L p .98 .897 .662 r
F P
0 g
s
.44463 .4735 m .43053 .50233 L .42707 .48747 L p .98 .897 .662 r
F P
0 g
s
.7103 .53569 m .69813 .54937 L .70843 .52253 L p .861 .982 .694 r
F P
0 g
s
.70843 .52253 m .72155 .50669 L .7103 .53569 L p .861 .982 .694 r
F P
0 g
s
.349 .54397 m .36177 .55422 L .37946 .57708 L p 0 .246 .751 r
F P
0 g
s
.39105 .57961 m .37946 .57708 L .36177 .55422 L p .321 .587 .94 r
F P
0 g
s
.84383 .4718 m .82883 .45908 L .82873 .41058 L p .292 .43 .829 r
F P
0 g
s
.81373 .40293 m .82873 .41058 L .82883 .45908 L p .37 .501 .86 r
F P
0 g
s
.56523 .38166 m .57588 .40397 L .58628 .41304 L p .851 .394 .028 r
F P
0 g
s
.57588 .40397 m .56523 .38166 L .55412 .37597 L p .832 .398 .204 r
F P
0 g
s
.25362 .39038 m .26756 .39266 L .26268 .43468 L p .665 .753 .916 r
F P
0 g
s
.26268 .43468 m .24881 .43467 L .25362 .39038 L p .665 .753 .916 r
F P
0 g
s
.27612 .4401 m .26268 .43468 L .26756 .39266 L p .505 .605 .887 r
F P
0 g
s
.23917 .39326 m .25362 .39038 L .24881 .43467 L p .788 .86 .903 r
F P
0 g
s
.24881 .43467 m .23448 .43978 L .23917 .39326 L p .788 .86 .903 r
F P
0 g
s
.63136 .56572 m .61933 .54535 L .63205 .53022 L p .433 .419 .744 r
F P
0 g
s
.61816 .50531 m .63205 .53022 L .61933 .54535 L p .387 .354 .7 r
F P
0 g
s
.75998 .45828 m .74718 .47246 L .74548 .43752 L p .936 .934 .773 r
F P
0 g
s
.74548 .43752 m .75845 .42099 L .75998 .45828 L p .936 .934 .773 r
F P
0 g
s
.49166 .39566 m .4987 .37502 L .48709 .38033 L p .313 0 .227 r
F P
0 g
s
.48709 .38033 m .47699 .40231 L .49166 .39566 L p .313 0 .227 r
F P
0 g
s
.65472 .58361 m .64319 .57858 L .65944 .55994 L p .632 .726 .915 r
F P
0 g
s
.65944 .55994 m .67272 .56319 L .65472 .58361 L p .632 .726 .915 r
F P
0 g
s
.60667 .45037 m .60832 .46336 L p .59516 .43035 L 0 0 .563 r
F P
0 g
s
.62298 .4906 m .60832 .46336 L .60667 .45037 L p 0 .033 .597 r
F P
0 g
s
.62116 .47553 m .62298 .4906 L p .6116 .46255 L 0 .033 .597 r
F P
0 g
s
.60667 .45037 m .62116 .47553 L p .6116 .46255 L 0 .033 .597 r
F P
0 g
s
.60667 .45037 m .59936 .43799 L p .61761 .46941 L .624 .219 0 r
F P
0 g
s
.62116 .47553 m .60667 .45037 L p .61761 .46941 L .624 .219 0 r
F P
0 g
s
.61266 .46114 m .62116 .47553 L p .60595 .44934 L .624 .219 0 r
F P
0 g
s
.59936 .43799 m .61266 .46114 L p .60595 .44934 L .624 .219 0 r
F P
0 g
s
.61266 .46114 m .59793 .44848 L p .61864 .47165 L .758 .259 0 r
F P
0 g
s
.62116 .47553 m .61266 .46114 L p .62966 .48708 L 0 0 .478 r
F P
0 g
s
.62611 .48001 m .63578 .49641 L p .62243 .47605 L 0 0 .478 r
F P
0 g
s
.61266 .46114 m .62611 .48001 L p .62243 .47605 L 0 0 .478 r
F P
0 g
s
.63578 .49641 m .62116 .47553 L p .62966 .48708 L 0 0 .478 r
F P
0 g
s
.60832 .46336 m .62298 .4906 L .61816 .50531 L p .164 .214 .669 r
F P
0 g
s
.63773 .51354 m .62298 .4906 L .62116 .47553 L p 0 .129 .667 r
F P
0 g
s
.62116 .47553 m .63578 .49641 L .63773 .51354 L p 0 .129 .667 r
F P
0 g
s
.65039 .51099 m .63578 .49641 L .62611 .48001 L p 0 .163 .698 r
F P
0 g
s
.63959 .49256 m .65039 .51099 L p .64032 .49814 L 0 .163 .698 r
F P
0 g
s
.62611 .48001 m .63959 .49256 L p .64032 .49814 L 0 .163 .698 r
F P
0 g
s
.62611 .48001 m .6092 .46554 L p .62915 .48329 L .522 0 0 r
F P
0 g
s
.63959 .49256 m .62611 .48001 L p .62915 .48329 L .522 0 0 r
F P
0 g
s
.62611 .48001 m .61266 .46114 L p .61864 .47165 L .758 .259 0 r
F P
0 g
s
.59793 .44848 m .6092 .46554 L .62611 .48001 L p .758 .259 0 r
F P
0 g
s
.62053 .47626 m .63959 .49256 L p .62696 .48134 L .522 0 0 r
F P
0 g
s
.6092 .46554 m .62053 .47626 L p .62696 .48134 L .522 0 0 r
F P
0 g
s
.62053 .47626 m .6092 .46554 L .58612 .45411 L p .651 .094 0 r
F P
0 g
s
.59439 .46336 m .62053 .47626 L p .60621 .46704 L .651 .094 0 r
F P
0 g
s
.58612 .45411 m .59439 .46336 L p .60621 .46704 L .651 .094 0 r
F P
0 g
s
.56302 .45491 m .59439 .46336 L p .57942 .45639 L .642 .109 0 r
F P
0 g
s
.55847 .44664 m .56302 .45491 L p .57942 .45639 L .642 .109 0 r
F P
0 g
s
.56302 .45491 m .52874 .45163 L p .5508 .45381 L .083 0 0 r
F P
0 g
s
.59439 .46336 m .56302 .45491 L p .58557 .46061 L 0 .472 .754 r
F P
0 g
s
.59439 .46336 m .58612 .45411 L .55847 .44664 L p .642 .109 0 r
F P
0 g
s
.56755 .45547 m .60264 .46492 L p .59947 .46412 L 0 .472 .754 r
F P
0 g
s
.56302 .45491 m .56755 .45547 L p .59947 .46412 L 0 .472 .754 r
F P
0 g
s
.56755 .45547 m .56302 .45491 L p .5508 .45381 L .083 0 0 r
F P
0 g
s
.56302 .45491 m .55847 .44664 L .5283 .44373 L p .573 .069 .017 r
F P
0 g
s
.5283 .44373 m .52874 .45163 L .56302 .45491 L p .573 .069 .017 r
F P
0 g
s
.52917 .45179 m .56755 .45547 L p .56444 .45516 L .083 0 0 r
F P
0 g
s
.52874 .45163 m .52917 .45179 L p .56444 .45516 L .083 0 0 r
F P
0 g
s
.49417 .45379 m .49788 .44564 L .46953 .45221 L p .308 0 0 r
F P
0 g
s
.46953 .45221 m .46698 .45526 L p .49417 .45379 L .308 0 0 r
F P
0 g
s
.46698 .45526 m .46199 .46121 L .49417 .45379 L p .308 0 0 r
F P
0 g
s
.49047 .45421 m .49417 .45379 L .46199 .46121 L p .202 .727 .737 r
F P
0 g
s
.49417 .45379 m .49047 .45421 L .51675 .45257 L p 0 0 0 r
F P
0 g
s
.51675 .45257 m .52917 .45179 L p .49417 .45379 L 0 0 0 r
F P
0 g
s
.49788 .44564 m .49417 .45379 L .52874 .45163 L p .467 0 .023 r
F P
0 g
s
.52917 .45179 m .52874 .45163 L .49417 .45379 L p 0 0 0 r
F P
0 g
s
.52917 .45179 m .49047 .45421 L p .5074 .44972 L .633 .779 .951 r
F P
0 g
s
.52787 .42944 m .5283 .44373 L .55847 .44664 L p .657 .231 .223 r
F P
0 g
s
.52874 .45163 m .5283 .44373 L .49788 .44564 L p .467 0 .023 r
F P
0 g
s
.5296 .44382 m .52917 .45179 L p .5074 .44972 L .633 .779 .951 r
F P
0 g
s
.56755 .45547 m .52917 .45179 L p .54776 .45011 L .625 .772 .951 r
F P
0 g
s
.55396 .43197 m .55847 .44664 L .58612 .45411 L p .734 .282 .177 r
F P
0 g
s
.57204 .4479 m .56755 .45547 L p .54776 .45011 L .625 .772 .951 r
F P
0 g
s
.60264 .46492 m .59439 .46336 L p .58557 .46061 L 0 .472 .754 r
F P
0 g
s
.62053 .47626 m .59439 .46336 L p .61571 .47247 L 0 .476 .842 r
F P
0 g
s
.63179 .47933 m .62053 .47626 L p .61571 .47247 L 0 .476 .842 r
F P
0 g
s
.63959 .49256 m .62053 .47626 L p .63904 .48839 L .091 .492 .899 r
F P
0 g
s
.65295 .49751 m .63959 .49256 L p .63904 .48839 L .091 .492 .899 r
F P
0 g
s
.59239 .42339 m .60667 .45037 L p .59516 .43035 L 0 0 .563 r
F P
0 g
s
.60667 .45037 m .59239 .42339 L .58628 .41304 L p .674 .272 0 r
F P
0 g
s
.26756 .39266 m .28105 .4004 L .27612 .4401 L p .505 .605 .887 r
F P
0 g
s
.28923 .4506 m .27612 .4401 L .28105 .4004 L p .351 .457 .829 r
F P
0 g
s
.40233 .54508 m .4164 .52685 L .42772 .54239 L p .903 .813 .749 r
F P
0 g
s
.42772 .54239 m .41526 .56242 L .40233 .54508 L p .903 .813 .749 r
F P
0 g
s
.22422 .40045 m .23917 .39326 L .23448 .43978 L p .86 .916 .867 r
F P
0 g
s
.23448 .43978 m .21969 .44914 L .22422 .40045 L p .86 .916 .867 r
F P
0 g
s
.315 .48254 m .32797 .50046 L .33657 .52987 L p 0 .117 .668 r
F P
0 g
s
.349 .54397 m .33657 .52987 L .32797 .50046 L p 0 .187 .717 r
F P
0 g
s
.45307 .43558 m .46577 .41103 L .45873 .42117 L p 0 0 0 r
F P
0 g
s
.45873 .42117 m .44462 .44772 L .45307 .43558 L p 0 0 0 r
F P
0 g
s
.64319 .57858 m .63136 .56572 L .64585 .54884 L p .51 .534 .816 r
F P
0 g
s
.63205 .53022 m .64585 .54884 L .63136 .56572 L p .433 .419 .744 r
F P
0 g
s
.55412 .37597 m .56185 .39684 L .57588 .40397 L p .832 .398 .204 r
F P
0 g
s
.56185 .39684 m .55412 .37597 L .54094 .37226 L p .765 .36 .285 r
F P
0 g
s
.64585 .54884 m .65944 .55994 L .64319 .57858 L p .51 .534 .816 r
F P
0 g
s
.36177 .55422 m .37494 .55863 L .39105 .57961 L p .321 .587 .94 r
F P
0 g
s
.403 .57493 m .39105 .57961 L .37494 .55863 L p .684 .77 .916 r
F P
0 g
s
.85906 .48583 m .84383 .4718 L .84415 .42121 L p .261 .402 .816 r
F P
0 g
s
.82873 .41058 m .84415 .42121 L .84383 .4718 L p .292 .43 .829 r
F P
0 g
s
.50875 .39159 m .5122 .37177 L .4987 .37502 L p .483 .132 .295 r
F P
0 g
s
.4987 .37502 m .49166 .39566 L .50875 .39159 L p .483 .132 .295 r
F P
0 g
s
.63205 .53022 m .61816 .50531 L .62298 .4906 L p .215 .271 .705 r
F P
0 g
s
.28105 .4004 m .29417 .41326 L .28923 .4506 L p .351 .457 .829 r
F P
0 g
s
.30214 .46526 m .28923 .4506 L .29417 .41326 L p .238 .346 .772 r
F P
0 g
s
.38848 .55578 m .40233 .54508 L .41526 .56242 L p .84 .811 .822 r
F P
0 g
s
.41526 .56242 m .403 .57493 L .38848 .55578 L p .84 .811 .822 r
F P
0 g
s
.74718 .47246 m .73442 .48925 L .73258 .45668 L p .953 .937 .733 r
F P
0 g
s
.73258 .45668 m .74548 .43752 L .74718 .47246 L p .953 .937 .733 r
F P
0 g
s
.54094 .37226 m .54517 .39221 L .56185 .39684 L p .765 .36 .285 r
F P
0 g
s
.54517 .39221 m .54094 .37226 L .52662 .37083 L p .687 .305 .318 r
F P
0 g
s
.69813 .54937 m .68562 .55919 L .69498 .53447 L p .868 .993 .813 r
F P
0 g
s
.69498 .53447 m .70843 .52253 L .69813 .54937 L p .868 .993 .813 r
F P
0 g
s
.37494 .55863 m .38848 .55578 L .403 .57493 L p .684 .77 .916 r
F P
0 g
s
.52703 .39041 m .52662 .37083 L .5122 .37177 L p .597 .233 .321 r
F P
0 g
s
.5122 .37177 m .50875 .39159 L .52703 .39041 L p .597 .233 .321 r
F P
0 g
s
.20884 .41063 m .22422 .40045 L .21969 .44914 L p .894 .94 .835 r
F P
0 g
s
.21969 .44914 m .20452 .46145 L .20884 .41063 L p .894 .94 .835 r
F P
0 g
s
.41226 .50999 m .42707 .48747 L .43053 .50233 L p .967 .901 .703 r
F P
0 g
s
.43053 .50233 m .4164 .52685 L .41226 .50999 L p .967 .901 .703 r
F P
0 g
s
.43029 .47245 m .44462 .44772 L .44178 .46066 L p .894 .935 .562 r
F P
0 g
s
.44178 .46066 m .42707 .48747 L .43029 .47245 L p .894 .935 .562 r
F P
0 g
s
.52662 .37083 m .52703 .39041 L .54517 .39221 L p .687 .305 .318 r
F P
0 g
s
.58628 .41304 m .59936 .43799 L .60667 .45037 L p .674 .272 0 r
F P
0 g
s
.59936 .43799 m .58628 .41304 L .57588 .40397 L p .854 .398 .034 r
F P
0 g
s
.84415 .42121 m .85986 .43317 L .85906 .48583 L p .261 .402 .816 r
F P
0 g
s
.46664 .42513 m .47699 .40231 L .46577 .41103 L p .029 0 .082 r
F P
0 g
s
.46577 .41103 m .45307 .43558 L .46664 .42513 L p .029 0 .082 r
F P
0 g
s
.32797 .50046 m .34117 .51676 L .349 .54397 L p 0 .187 .717 r
F P
0 g
s
.36177 .55422 m .349 .54397 L .34117 .51676 L p .112 .352 .818 r
F P
0 g
s
.29417 .41326 m .30706 .43029 L .30214 .46526 L p .238 .346 .772 r
F P
0 g
s
.315 .48254 m .30214 .46526 L .30706 .43029 L p .177 .284 .736 r
F P
0 g
s
.19318 .42214 m .20884 .41063 L .20452 .46145 L p .905 .947 .821 r
F P
0 g
s
.20452 .46145 m .18911 .47507 L .19318 .42214 L p .905 .947 .821 r
F P
0 g
s
.64585 .54884 m .63205 .53022 L .63773 .51354 L p .303 .368 .765 r
F P
0 g
s
.62298 .4906 m .63773 .51354 L .63205 .53022 L p .215 .271 .705 r
F P
0 g
s
.68562 .55919 m .67272 .56319 L .68114 .54054 L p .798 .919 .92 r
F P
0 g
s
.68114 .54054 m .69498 .53447 L .68562 .55919 L p .798 .919 .92 r
F P
0 g
s
.73442 .48925 m .72155 .50669 L .7196 .47647 L p .956 .938 .726 r
F P
0 g
s
.7196 .47647 m .73258 .45668 L .73442 .48925 L p .956 .938 .726 r
F P
0 g
s
.3975 .52621 m .41226 .50999 L .4164 .52685 L p .934 .899 .768 r
F P
0 g
s
.4164 .52685 m .40233 .54508 L .3975 .52621 L p .934 .899 .768 r
F P
0 g
s
.57588 .40397 m .58679 .42712 L .59936 .43799 L p .854 .398 .034 r
F P
0 g
s
.58679 .42712 m .57588 .40397 L .56185 .39684 L p .833 .4 .209 r
F P
0 g
s
.65944 .55994 m .64585 .54884 L .65242 .5302 L p .44 .522 .845 r
F P
0 g
s
.63773 .51354 m .65242 .5302 L .64585 .54884 L p .303 .368 .765 r
F P
0 g
s
.34117 .51676 m .35471 .52916 L .36177 .55422 L p .112 .352 .818 r
F P
0 g
s
.37494 .55863 m .36177 .55422 L .35471 .52916 L p .402 .582 .913 r
F P
0 g
s
.44014 .45834 m .45307 .43558 L .44462 .44772 L p 0 0 0 r
F P
0 g
s
.44462 .44772 m .43029 .47245 L .44014 .45834 L p 0 0 0 r
F P
0 g
s
.48443 .41715 m .49166 .39566 L .47699 .40231 L p .316 0 .231 r
F P
0 g
s
.47699 .40231 m .46664 .42513 L .48443 .41715 L p .316 0 .231 r
F P
0 g
s
.67272 .56319 m .65944 .55994 L .66693 .53931 L p .625 .729 .921 r
F P
0 g
s
.66693 .53931 m .68114 .54054 L .67272 .56319 L p .625 .729 .921 r
F P
0 g
s
.41583 .49291 m .43029 .47245 L .42707 .48747 L p .912 .963 .644 r
F P
0 g
s
.42707 .48747 m .41226 .50999 L .41583 .49291 L p .912 .963 .644 r
F P
0 g
s
.30706 .43029 m .31987 .44995 L .315 .48254 L p .177 .284 .736 r
F P
0 g
s
.32797 .50046 m .315 .48254 L .31987 .44995 L p .166 .273 .73 r
F P
0 g
s
.65242 .5302 m .66693 .53931 L .65944 .55994 L p .44 .522 .845 r
F P
0 g
s
.38292 .5349 m .3975 .52621 L .40233 .54508 L p .854 .872 .852 r
F P
0 g
s
.40233 .54508 m .38848 .55578 L .38292 .5349 L p .854 .872 .852 r
F P
0 g
s
.72155 .50669 m .70843 .52253 L .7064 .49461 L p .945 .937 .754 r
F P
0 g
s
.7064 .49461 m .7196 .47647 L .72155 .50669 L p .945 .937 .754 r
F P
0 g
s
.35471 .52916 m .36864 .53568 L .37494 .55863 L p .402 .582 .913 r
F P
0 g
s
.38848 .55578 m .37494 .55863 L .36864 .53568 L p .682 .777 .922 r
F P
0 g
s
.56185 .39684 m .56978 .41857 L .58679 .42712 L p .833 .4 .209 r
F P
0 g
s
.56978 .41857 m .56185 .39684 L .54517 .39221 L p .765 .362 .288 r
F P
0 g
s
.5052 .41225 m .50875 .39159 L .49166 .39566 L p .484 .135 .298 r
F P
0 g
s
.49166 .39566 m .48443 .41715 L .5052 .41225 L p .484 .135 .298 r
F P
0 g
s
.36864 .53568 m .38292 .5349 L .38848 .55578 L p .682 .777 .922 r
F P
0 g
s
.61266 .46114 m .59936 .43799 L .58679 .42712 L p .831 .362 0 r
F P
0 g
s
.54517 .39221 m .54951 .41299 L .56978 .41857 L p .765 .362 .288 r
F P
0 g
s
.54951 .41299 m .54517 .39221 L .52703 .39041 L p .688 .307 .321 r
F P
0 g
s
.79921 .39957 m .7852 .40138 L .76556 .36018 L p .652 .744 .917 r
F P
0 g
s
.7852 .40138 m .77165 .40863 L .75276 .36978 L p .792 .81 .866 r
F P
0 g
s
.75276 .36978 m .76556 .36018 L .7852 .40138 L p .792 .81 .866 r
F P
0 g
s
.52744 .41083 m .52703 .39041 L .50875 .39159 L p .598 .235 .324 r
F P
0 g
s
.50875 .39159 m .5052 .41225 L .52744 .41083 L p .598 .235 .324 r
F P
0 g
s
.77165 .40863 m .75845 .42099 L .74033 .38452 L p .873 .836 .807 r
F P
0 g
s
.74033 .38452 m .75276 .36978 L .77165 .40863 L p .873 .836 .807 r
F P
0 g
s
.65242 .5302 m .63773 .51354 L .63578 .49641 L p .097 .291 .77 r
F P
0 g
s
.31987 .44995 m .33276 .47023 L .32797 .50046 L p .166 .273 .73 r
F P
0 g
s
.34117 .51676 m .32797 .50046 L .33276 .47023 L p .207 .315 .755 r
F P
0 g
s
.52703 .39041 m .52744 .41083 L .54951 .41299 L p .688 .307 .321 r
F P
0 g
s
.81373 .40293 m .79921 .39957 L .77882 .35607 L p .458 .629 .927 r
F P
0 g
s
.76556 .36018 m .77882 .35607 L .79921 .39957 L p .652 .744 .917 r
F P
0 g
s
.45607 .44616 m .46664 .42513 L .45307 .43558 L p 0 0 .033 r
F P
0 g
s
.45307 .43558 m .44014 .45834 L .45607 .44616 L p 0 0 .033 r
F P
0 g
s
.70843 .52253 m .69498 .53447 L .6929 .50882 L p .909 .924 .814 r
F P
0 g
s
.6929 .50882 m .7064 .49461 L .70843 .52253 L p .909 .924 .814 r
F P
0 g
s
.40137 .50706 m .41583 .49291 L .41226 .50999 L p .912 .98 .765 r
F P
0 g
s
.41226 .50999 m .3975 .52621 L .40137 .50706 L p .912 .98 .765 r
F P
0 g
s
.75845 .42099 m .74548 .43752 L .72814 .40343 L p .914 .843 .76 r
F P
0 g
s
.72814 .40343 m .74033 .38452 L .75845 .42099 L p .914 .843 .76 r
F P
0 g
s
.82873 .41058 m .81373 .40293 L .79259 .35714 L p .263 .497 .893 r
F P
0 g
s
.77882 .35607 m .79259 .35714 L .81373 .40293 L p .458 .629 .927 r
F P
0 g
s
.42706 .47681 m .44014 .45834 L .43029 .47245 L p .586 .811 .414 r
F P
0 g
s
.43029 .47245 m .41583 .49291 L .42706 .47681 L p .586 .811 .414 r
F P
0 g
s
.27811 .34743 m .29108 .35202 L .26756 .39266 L p .664 .754 .917 r
F P
0 g
s
.26756 .39266 m .25362 .39038 L .27811 .34743 L p .664 .754 .917 r
F P
0 g
s
.28105 .4004 m .26756 .39266 L .29108 .35202 L p .55 .605 .861 r
F P
0 g
s
.29108 .35202 m .30359 .36209 L .28105 .4004 L p .55 .605 .861 r
F P
0 g
s
.29417 .41326 m .28105 .4004 L .30359 .36209 L p .458 .487 .801 r
F P
0 g
s
.66693 .53931 m .65242 .5302 L .65039 .51099 L p .349 .512 .878 r
F P
0 g
s
.63578 .49641 m .65039 .51099 L .65242 .5302 L p .097 .291 .77 r
F P
0 g
s
.33276 .47023 m .34585 .48885 L .34117 .51676 L p .207 .315 .755 r
F P
0 g
s
.35471 .52916 m .34117 .51676 L .34585 .48885 L p .307 .416 .81 r
F P
0 g
s
.58679 .42712 m .59793 .44848 L .61266 .46114 L p .831 .362 0 r
F P
0 g
s
.59793 .44848 m .58679 .42712 L .56978 .41857 L p .823 .376 .171 r
F P
0 g
s
.74548 .43752 m .73258 .45668 L .71604 .42497 L p .931 .843 .734 r
F P
0 g
s
.71604 .42497 m .72814 .40343 L .74548 .43752 L p .931 .843 .734 r
F P
0 g
s
.69498 .53447 m .68114 .54054 L .67904 .51709 L p .813 .871 .889 r
F P
0 g
s
.67904 .51709 m .6929 .50882 L .69498 .53447 L p .813 .871 .889 r
F P
0 g
s
.26464 .34804 m .27811 .34743 L .25362 .39038 L p .765 .891 .933 r
F P
0 g
s
.25362 .39038 m .23917 .39326 L .26464 .34804 L p .765 .891 .933 r
F P
0 g
s
.30359 .36209 m .31573 .37731 L .29417 .41326 L p .458 .487 .801 r
F P
0 g
s
.30706 .43029 m .29417 .41326 L .31573 .37731 L p .398 .41 .756 r
F P
0 g
s
.47704 .43683 m .48443 .41715 L .46664 .42513 L p .294 0 .195 r
F P
0 g
s
.46664 .42513 m .45607 .44616 L .47704 .43683 L p .294 0 .195 r
F P
0 g
s
.38705 .51363 m .40137 .50706 L .3975 .52621 L p .845 .934 .885 r
F P
0 g
s
.3975 .52621 m .38292 .5349 L .38705 .51363 L p .845 .934 .885 r
F P
0 g
s
.68114 .54054 m .66693 .53931 L .66484 .51801 L p .62 .733 .928 r
F P
0 g
s
.65039 .51099 m .66484 .51801 L .66693 .53931 L p .349 .512 .878 r
F P
0 g
s
.66484 .51801 m .67904 .51709 L .68114 .54054 L p .62 .733 .928 r
F P
0 g
s
.84415 .42121 m .82873 .41058 L .80687 .36256 L p .127 .396 .848 r
F P
0 g
s
.79259 .35714 m .80687 .36256 L .82873 .41058 L p .263 .497 .893 r
F P
0 g
s
.34585 .48885 m .35925 .50353 L .35471 .52916 L p .307 .416 .81 r
F P
0 g
s
.36864 .53568 m .35471 .52916 L .35925 .50353 L p .471 .581 .883 r
F P
0 g
s
.25066 .35299 m .26464 .34804 L .23917 .39326 L p .818 .97 .898 r
F P
0 g
s
.23917 .39326 m .22422 .40045 L .25066 .35299 L p .818 .97 .898 r
F P
0 g
s
.31573 .37731 m .32764 .3967 L .30706 .43029 L p .398 .41 .756 r
F P
0 g
s
.31987 .44995 m .30706 .43029 L .32764 .3967 L p .367 .371 .732 r
F P
0 g
s
.73258 .45668 m .7196 .47647 L .70389 .4471 L p .934 .843 .73 r
F P
0 g
s
.70389 .4471 m .71604 .42497 L .73258 .45668 L p .934 .843 .73 r
F P
0 g
s
.37299 .51226 m .38705 .51363 L .38292 .5349 L p .678 .783 .929 r
F P
0 g
s
.38292 .5349 m .36864 .53568 L .37299 .51226 L p .678 .783 .929 r
F P
0 g
s
.56978 .41857 m .57789 .43849 L .59793 .44848 L p .823 .376 .171 r
F P
0 g
s
.57789 .43849 m .56978 .41857 L .54951 .41299 L p .758 .342 .259 r
F P
0 g
s
.35925 .50353 m .37299 .51226 L .36864 .53568 L p .471 .581 .883 r
F P
0 g
s
.50157 .43111 m .5052 .41225 L .48443 .41715 L p .471 .109 .27 r
F P
0 g
s
.48443 .41715 m .47704 .43683 L .50157 .43111 L p .471 .109 .27 r
F P
0 g
s
.44535 .46288 m .45607 .44616 L .44014 .45834 L p 0 0 0 r
F P
0 g
s
.44014 .45834 m .42706 .47681 L .44535 .46288 L p 0 0 0 r
F P
0 g
s
.41395 .48896 m .42706 .47681 L .41583 .49291 L p .725 .954 .664 r
F P
0 g
s
.41583 .49291 m .40137 .50706 L .41395 .48896 L p .725 .954 .664 r
F P
0 g
s
.85986 .43317 m .84415 .42121 L .82158 .37098 L p .072 .354 .826 r
F P
0 g
s
.80687 .36256 m .82158 .37098 L .84415 .42121 L p .127 .396 .848 r
F P
0 g
s
.23626 .36095 m .25066 .35299 L .22422 .40045 L p .831 .996 .847 r
F P
0 g
s
.22422 .40045 m .20884 .41063 L .23626 .36095 L p .831 .996 .847 r
F P
0 g
s
.54951 .41299 m .55396 .43197 L .57789 .43849 L p .758 .342 .259 r
F P
0 g
s
.55396 .43197 m .54951 .41299 L .52744 .41083 L p .68 .287 .295 r
F P
0 g
s
.32764 .3967 m .33945 .41871 L .31987 .44995 L p .367 .371 .732 r
F P
0 g
s
.33276 .47023 m .31987 .44995 L .33945 .41871 L p .362 .364 .727 r
F P
0 g
s
.52787 .42944 m .52744 .41083 L .5052 .41225 L p .589 .214 .299 r
F P
0 g
s
.5052 .41225 m .50157 .43111 L .52787 .42944 L p .589 .214 .299 r
F P
0 g
s
.7196 .47647 m .7064 .49461 L .69157 .46755 L p .923 .843 .748 r
F P
0 g
s
.69157 .46755 m .70389 .4471 L .7196 .47647 L p .923 .843 .748 r
F P
0 g
s
.52744 .41083 m .52787 .42944 L .55396 .43197 L p .68 .287 .295 r
F P
0 g
s
.66484 .51801 m .65039 .51099 L .63959 .49256 L p .231 .504 .904 r
F P
0 g
s
.6092 .46554 m .59793 .44848 L .57789 .43849 L p .788 .303 .065 r
F P
0 g
s
.33945 .41871 m .3513 .44132 L .33276 .47023 L p .362 .364 .727 r
F P
0 g
s
.34585 .48885 m .33276 .47023 L .3513 .44132 L p .382 .391 .744 r
F P
0 g
s
.7064 .49461 m .6929 .50882 L .67899 .48401 L p .89 .841 .791 r
F P
0 g
s
.67899 .48401 m .69157 .46755 L .7064 .49461 L p .89 .841 .791 r
F P
0 g
s
.82158 .37098 m .8366 .38074 L .85986 .43317 L p .072 .354 .826 r
F P
0 g
s
.40094 .49349 m .41395 .48896 L .40137 .50706 L p .787 .979 .907 r
F P
0 g
s
.40137 .50706 m .38705 .51363 L .40094 .49349 L p .787 .979 .907 r
F P
0 g
s
.46953 .45221 m .47704 .43683 L .45607 .44616 L p .232 0 .096 r
F P
0 g
s
.45607 .44616 m .44535 .46288 L .46953 .45221 L p .232 0 .096 r
F P
0 g
s
.22154 .37026 m .23626 .36095 L .20884 .41063 L p .831 .999 .821 r
F P
0 g
s
.20884 .41063 m .19318 .42214 L .22154 .37026 L p .831 .999 .821 r
F P
0 g
s
.67904 .51709 m .66484 .51801 L .65295 .49751 L p .616 .739 .934 r
F P
0 g
s
.63959 .49256 m .65295 .49751 L .66484 .51801 L p .231 .504 .904 r
F P
0 g
s
.6929 .50882 m .67904 .51709 L .66611 .49446 L p .809 .822 .861 r
F P
0 g
s
.66611 .49446 m .67899 .48401 L .6929 .50882 L p .809 .822 .861 r
F P
0 g
s
.76556 .36018 m .75276 .36978 L .71664 .33474 L p .779 .77 .845 r
F P
0 g
s
.75276 .36978 m .74033 .38452 L .70599 .35169 L p .841 .77 .783 r
F P
0 g
s
.70599 .35169 m .71664 .33474 L .75276 .36978 L p .841 .77 .783 r
F P
0 g
s
.4346 .47326 m .44535 .46288 L .42706 .47681 L p 0 0 0 r
F P
0 g
s
.42706 .47681 m .41395 .48896 L .4346 .47326 L p 0 0 0 r
F P
0 g
s
.3513 .44132 m .36331 .46223 L .34585 .48885 L p .382 .391 .744 r
F P
0 g
s
.35925 .50353 m .34585 .48885 L .36331 .46223 L p .434 .458 .786 r
F P
0 g
s
.65295 .49751 m .66611 .49446 L .67904 .51709 L p .616 .739 .934 r
F P
0 g
s
.77882 .35607 m .76556 .36018 L .72762 .32294 L p .652 .745 .918 r
F P
0 g
s
.71664 .33474 m .72762 .32294 L .76556 .36018 L p .779 .77 .845 r
F P
0 g
s
.74033 .38452 m .72814 .40343 L .69557 .37281 L p .87 .764 .742 r
F P
0 g
s
.69557 .37281 m .70599 .35169 L .74033 .38452 L p .87 .764 .742 r
F P
0 g
s
.38812 .49003 m .40094 .49349 L .38705 .51363 L p .671 .787 .935 r
F P
0 g
s
.38705 .51363 m .37299 .51226 L .38812 .49003 L p .671 .787 .935 r
F P
0 g
s
.57789 .43849 m .58612 .45411 L .6092 .46554 L p .788 .303 .065 r
F P
0 g
s
.58612 .45411 m .57789 .43849 L .55396 .43197 L p .734 .282 .177 r
F P
0 g
s
.36331 .46223 m .37558 .47914 L .35925 .50353 L p .434 .458 .786 r
F P
0 g
s
.37299 .51226 m .35925 .50353 L .37558 .47914 L p .528 .585 .856 r
F P
0 g
s
.49788 .44564 m .50157 .43111 L .47704 .43683 L p .431 .038 .19 r
F P
0 g
s
.47704 .43683 m .46953 .45221 L .49788 .44564 L p .431 .038 .19 r
F P
0 g
s
.79259 .35714 m .77882 .35607 L .73903 .31664 L p .423 .655 .956 r
F P
0 g
s
.72762 .32294 m .73903 .31664 L .77882 .35607 L p .652 .745 .918 r
F P
0 g
s
.37558 .47914 m .38812 .49003 L .37299 .51226 L p .528 .585 .856 r
F P
0 g
s
.72814 .40343 m .71604 .42497 L .68526 .39654 L p .883 .759 .721 r
F P
0 g
s
.68526 .39654 m .69557 .37281 L .72814 .40343 L p .883 .759 .721 r
F P
0 g
s
.33263 .31601 m .3431 .32823 L .30359 .36209 L p .59 .611 .841 r
F P
0 g
s
.30359 .36209 m .29108 .35202 L .33263 .31601 L p .59 .611 .841 r
F P
0 g
s
.31573 .37731 m .30359 .36209 L .3431 .32823 L p .536 .514 .778 r
F P
0 g
s
.3431 .32823 m .35325 .34559 L .31573 .37731 L p .536 .514 .778 r
F P
0 g
s
.32764 .3967 m .31573 .37731 L .35325 .34559 L p .502 .456 .738 r
F P
0 g
s
.32174 .30929 m .33263 .31601 L .29108 .35202 L p .662 .754 .918 r
F P
0 g
s
.29108 .35202 m .27811 .34743 L .32174 .30929 L p .662 .754 .918 r
F P
0 g
s
.55847 .44664 m .55396 .43197 L .52787 .42944 L p .657 .231 .223 r
F P
0 g
s
.5283 .44373 m .52787 .42944 L .50157 .43111 L p .56 .153 .227 r
F P
0 g
s
.50157 .43111 m .49788 .44564 L .5283 .44373 L p .56 .153 .227 r
F P
0 g
s
.71604 .42497 m .70389 .4471 L .67492 .42084 L p .885 .758 .717 r
F P
0 g
s
.67492 .42084 m .68526 .39654 L .71604 .42497 L p .885 .758 .717 r
F P
0 g
s
.35325 .34559 m .36318 .36713 L .32764 .3967 L p .502 .456 .738 r
F P
0 g
s
.33945 .41871 m .32764 .3967 L .36318 .36713 L p .486 .428 .718 r
F P
0 g
s
.80687 .36256 m .79259 .35714 L .7509 .31555 L p .134 .493 .905 r
F P
0 g
s
.73903 .31664 m .7509 .31555 L .79259 .35714 L p .423 .655 .956 r
F P
0 g
s
.31041 .30779 m .32174 .30929 L .27811 .34743 L p .719 .908 .961 r
F P
0 g
s
.27811 .34743 m .26464 .34804 L .31041 .30779 L p .719 .908 .961 r
F P
0 g
s
.42389 .47599 m .4346 .47326 L .41395 .48896 L p .649 .968 .892 r
F P
0 g
s
.41395 .48896 m .40094 .49349 L .42389 .47599 L p .649 .968 .892 r
F P
0 g
s
.46199 .46121 m .46953 .45221 L .44535 .46288 L p .057 0 0 r
F P
0 g
s
.44535 .46288 m .44171 .4664 L p .46199 .46121 L .057 0 0 r
F P
0 g
s
.46199 .46121 m .45447 .46252 L .47889 .45689 L p .202 .727 .737 r
F P
0 g
s
.47889 .45689 m .49047 .45421 L p .46199 .46121 L .202 .727 .737 r
F P
0 g
s
.44171 .4664 m .4346 .47326 L .46199 .46121 L p .057 0 0 r
F P
0 g
s
.70389 .4471 m .69157 .46755 L .66445 .4434 L p .877 .762 .731 r
F P
0 g
s
.66445 .4434 m .67492 .42084 L .70389 .4471 L p .877 .762 .731 r
F P
0 g
s
.36318 .36713 m .37301 .39127 L .33945 .41871 L p .486 .428 .718 r
F P
0 g
s
.3513 .44132 m .33945 .41871 L .37301 .39127 L p .483 .423 .714 r
F P
0 g
s
.66611 .49446 m .65295 .49751 L .63179 .47933 L p .614 .747 .94 r
F P
0 g
s
.62053 .47626 m .63179 .47933 L .65295 .49751 L p .091 .492 .899 r
F P
0 g
s
.29863 .31065 m .31041 .30779 L .26464 .34804 L p .703 .98 .902 r
F P
0 g
s
.26464 .34804 m .25066 .35299 L .29863 .31065 L p .703 .98 .902 r
F P
0 g
s
.69157 .46755 m .67899 .48401 L .65379 .46191 L p .853 .769 .768 r
F P
0 g
s
.65379 .46191 m .66445 .4434 L .69157 .46755 L p .853 .769 .768 r
F P
0 g
s
.82158 .37098 m .80687 .36256 L .76323 .31882 L p 0 .345 .811 r
F P
0 g
s
.7509 .31555 m .76323 .31882 L .80687 .36256 L p .134 .493 .905 r
F P
0 g
s
.37301 .39127 m .38286 .41598 L .3513 .44132 L p .483 .423 .714 r
F P
0 g
s
.36331 .46223 m .3513 .44132 L .38286 .41598 L p .494 .442 .728 r
F P
0 g
s
.41333 .47066 m .42389 .47599 L .40094 .49349 L p .663 .789 .941 r
F P
0 g
s
.40094 .49349 m .38812 .49003 L .41333 .47066 L p .663 .789 .941 r
F P
0 g
s
.67899 .48401 m .66611 .49446 L .64289 .47436 L p .793 .776 .838 r
F P
0 g
s
.63179 .47933 m .64289 .47436 L .66611 .49446 L p .614 .747 .94 r
F P
0 g
s
.64289 .47436 m .65379 .46191 L .67899 .48401 L p .793 .776 .838 r
F P
0 g
s
.38286 .41598 m .39282 .43894 L .36331 .46223 L p .494 .442 .728 r
F P
0 g
s
.37558 .47914 m .36331 .46223 L .39282 .43894 L p .522 .492 .764 r
F P
0 g
s
.40297 .45784 m .41333 .47066 L .38812 .49003 L p .576 .594 .834 r
F P
0 g
s
.38812 .49003 m .37558 .47914 L .40297 .45784 L p .576 .594 .834 r
F P
0 g
s
.39282 .43894 m .40297 .45784 L .37558 .47914 L p .522 .492 .764 r
F P
0 g
s
.45447 .46252 m .46199 .46121 L .4346 .47326 L p .433 .873 .824 r
F P
0 g
s
.4346 .47326 m .42389 .47599 L .45447 .46252 L p .433 .873 .824 r
F P
0 g
s
.28646 .31652 m .29863 .31065 L .25066 .35299 L p .64 .96 .791 r
F P
0 g
s
.25066 .35299 m .23626 .36095 L .28646 .31652 L p .64 .96 .791 r
F P
0 g
s
.71664 .33474 m .70599 .35169 L .65733 .32532 L p .805 .715 .765 r
F P
0 g
s
.70599 .35169 m .69557 .37281 L .64961 .34826 L p .825 .7 .727 r
F P
0 g
s
.64961 .34826 m .65733 .32532 L .70599 .35169 L p .825 .7 .727 r
F P
0 g
s
.72762 .32294 m .71664 .33474 L .66523 .30654 L p .761 .735 .829 r
F P
0 g
s
.65733 .32532 m .66523 .30654 L .71664 .33474 L p .805 .715 .765 r
F P
0 g
s
.8366 .38074 m .82158 .37098 L .77597 .32511 L p 0 .28 .761 r
F P
0 g
s
.76323 .31882 m .77597 .32511 L .82158 .37098 L p 0 .345 .811 r
F P
0 g
s
.69557 .37281 m .68526 .39654 L .64198 .37378 L p .833 .692 .708 r
F P
0 g
s
.64198 .37378 m .64961 .34826 L .69557 .37281 L p .833 .692 .708 r
F P
0 g
s
.73903 .31664 m .72762 .32294 L .67339 .29291 L p .652 .747 .919 r
F P
0 g
s
.66523 .30654 m .67339 .29291 L .72762 .32294 L p .761 .735 .829 r
F P
0 g
s
.64289 .47436 m .63179 .47933 L .60264 .46492 L p .615 .755 .945 r
F P
0 g
s
.59439 .46336 m .60264 .46492 L .63179 .47933 L p 0 .476 .842 r
F P
0 g
s
.39729 .3018 m .40451 .32089 L .35325 .34559 L p .596 .54 .762 r
F P
0 g
s
.35325 .34559 m .3431 .32823 L .39729 .3018 L p .596 .54 .762 r
F P
0 g
s
.36318 .36713 m .35325 .34559 L .40451 .32089 L p .578 .495 .725 r
F P
0 g
s
.68526 .39654 m .67492 .42084 L .63435 .39985 L p .834 .691 .705 r
F P
0 g
s
.63435 .39985 m .64198 .37378 L .68526 .39654 L p .834 .691 .705 r
F P
0 g
s
.38982 .28786 m .39729 .3018 L .3431 .32823 L p .625 .621 .827 r
F P
0 g
s
.3431 .32823 m .33263 .31601 L .38982 .28786 L p .625 .621 .827 r
F P
0 g
s
.40451 .32089 m .41156 .34414 L .36318 .36713 L p .578 .495 .725 r
F P
0 g
s
.37301 .39127 m .36318 .36713 L .41156 .34414 L p .569 .473 .706 r
F P
0 g
s
.44703 .45573 m .45447 .46252 L .42389 .47599 L p .653 .788 .946 r
F P
0 g
s
.42389 .47599 m .41333 .47066 L .44703 .45573 L p .653 .788 .946 r
F P
0 g
s
.7509 .31555 m .73903 .31664 L .68188 .28478 L p .399 .69 .978 r
F P
0 g
s
.67339 .29291 m .68188 .28478 L .73903 .31664 L p .652 .747 .919 r
F P
0 g
s
.38205 .27942 m .38982 .28786 L .33263 .31601 L p .66 .754 .919 r
F P
0 g
s
.33263 .31601 m .32174 .30929 L .38205 .27942 L p .66 .754 .919 r
F P
0 g
s
.67492 .42084 m .66445 .4434 L .62664 .42414 L p .829 .696 .718 r
F P
0 g
s
.62664 .42414 m .63435 .39985 L .67492 .42084 L p .829 .696 .718 r
F P
0 g
s
.27399 .32374 m .28646 .31652 L .23626 .36095 L p .604 .935 .733 r
F P
0 g
s
.23626 .36095 m .22154 .37026 L .27399 .32374 L p .604 .935 .733 r
F P
0 g
s
.41156 .34414 m .41854 .36997 L .37301 .39127 L p .569 .473 .706 r
F P
0 g
s
.38286 .41598 m .37301 .39127 L .41854 .36997 L p .567 .469 .703 r
F P
0 g
s
.65379 .46191 m .64289 .47436 L .61078 .45839 L p .771 .736 .821 r
F P
0 g
s
.60264 .46492 m .61078 .45839 L .64289 .47436 L p .615 .755 .945 r
F P
0 g
s
.77597 .32511 m .78901 .33274 L .8366 .38074 L p 0 .28 .761 r
F P
0 g
s
.66445 .4434 m .65379 .46191 L .61879 .44433 L p .814 .711 .752 r
F P
0 g
s
.61879 .44433 m .62664 .42414 L .66445 .4434 L p .814 .711 .752 r
F P
0 g
s
.61078 .45839 m .61879 .44433 L .65379 .46191 L p .771 .736 .821 r
F P
0 g
s
.41854 .36997 m .42551 .39634 L .38286 .41598 L p .567 .469 .703 r
F P
0 g
s
.39282 .43894 m .38286 .41598 L .42551 .39634 L p .573 .484 .716 r
F P
0 g
s
.43972 .44139 m .44703 .45573 L .41333 .47066 L p .618 .608 .818 r
F P
0 g
s
.41333 .47066 m .40297 .45784 L .43972 .44139 L p .618 .608 .818 r
F P
0 g
s
.37395 .2762 m .38205 .27942 L .32174 .30929 L p .649 .905 .982 r
F P
0 g
s
.32174 .30929 m .31041 .30779 L .37395 .2762 L p .649 .905 .982 r
F P
0 g
s
.42551 .39634 m .43256 .42092 L .39282 .43894 L p .573 .484 .716 r
F P
0 g
s
.40297 .45784 m .39282 .43894 L .43256 .42092 L p .588 .523 .749 r
F P
0 g
s
.43256 .42092 m .43972 .44139 L .40297 .45784 L p .588 .523 .749 r
F P
0 g
s
.76323 .31882 m .7509 .31555 L .69073 .28188 L p .01 .491 .87 r
F P
0 g
s
.68188 .28478 m .69073 .28188 L .7509 .31555 L p .399 .69 .978 r
F P
0 g
s
.61078 .45839 m .60264 .46492 L .56755 .45547 L p .619 .764 .949 r
F P
0 g
s
.4868 .44651 m .49047 .45421 L .45447 .46252 L p .643 .785 .949 r
F P
0 g
s
.45447 .46252 m .44703 .45573 L .4868 .44651 L p .643 .785 .949 r
F P
0 g
s
.66523 .30654 m .65733 .32532 L .59777 .30785 L p .768 .669 .754 r
F P
0 g
s
.65733 .32532 m .64961 .34826 L .59349 .33202 L p .78 .649 .717 r
F P
0 g
s
.59349 .33202 m .59777 .30785 L .65733 .32532 L p .78 .649 .717 r
F P
0 g
s
.64961 .34826 m .64198 .37378 L .58927 .35876 L p .784 .638 .7 r
F P
0 g
s
.58927 .35876 m .59349 .33202 L .64961 .34826 L p .784 .638 .7 r
F P
0 g
s
.36552 .27734 m .37395 .2762 L .31041 .30779 L p .502 .909 .857 r
F P
0 g
s
.31041 .30779 m .29863 .31065 L .36552 .27734 L p .502 .909 .857 r
F P
0 g
s
.67339 .29291 m .66523 .30654 L .60215 .28784 L p .739 .704 .819 r
F P
0 g
s
.59777 .30785 m .60215 .28784 L .66523 .30654 L p .768 .669 .754 r
F P
0 g
s
.61879 .44433 m .61078 .45839 L .57204 .4479 L p .745 .701 .81 r
F P
0 g
s
.56755 .45547 m .57204 .4479 L .61078 .45839 L p .619 .764 .949 r
F P
0 g
s
.64198 .37378 m .63435 .39985 L .58505 .38601 L p .785 .637 .697 r
F P
0 g
s
.58505 .38601 m .58927 .35876 L .64198 .37378 L p .785 .637 .697 r
F P
0 g
s
.46219 .28534 m .46577 .30552 L .40451 .32089 L p .646 .568 .752 r
F P
0 g
s
.40451 .32089 m .39729 .3018 L .46219 .28534 L p .646 .568 .752 r
F P
0 g
s
.41156 .34414 m .40451 .32089 L .46577 .30552 L p .637 .53 .716 r
F P
0 g
s
.46577 .30552 m .46927 .32985 L .41156 .34414 L p .637 .53 .716 r
F P
0 g
s
.41854 .36997 m .41156 .34414 L .46927 .32985 L p .633 .513 .699 r
F P
0 g
s
.49047 .45421 m .4868 .44651 L .5296 .44382 L p .633 .779 .951 r
F P
0 g
s
.4832 .43122 m .4868 .44651 L .44703 .45573 L p .654 .625 .808 r
F P
0 g
s
.44703 .45573 m .43972 .44139 L .4832 .43122 L p .654 .625 .808 r
F P
0 g
s
.77597 .32511 m .76323 .31882 L .69994 .28333 L p 0 .284 .682 r
F P
0 g
s
.69073 .28188 m .69994 .28333 L .76323 .31882 L p .01 .491 .87 r
F P
0 g
s
.63435 .39985 m .62664 .42414 L .58078 .41146 L p .782 .644 .709 r
F P
0 g
s
.58078 .41146 m .58505 .38601 L .63435 .39985 L p .782 .644 .709 r
F P
0 g
s
.45848 .2703 m .46219 .28534 L .39729 .3018 L p .657 .636 .817 r
F P
0 g
s
.39729 .3018 m .38982 .28786 L .45848 .2703 L p .657 .636 .817 r
F P
0 g
s
.68188 .28478 m .67339 .29291 L .60668 .27297 L p .653 .749 .92 r
F P
0 g
s
.60215 .28784 m .60668 .27297 L .67339 .29291 L p .739 .704 .819 r
F P
0 g
s
.62664 .42414 m .61879 .44433 L .57645 .43276 L p .773 .662 .741 r
F P
0 g
s
.57204 .4479 m .57645 .43276 L .61879 .44433 L p .745 .701 .81 r
F P
0 g
s
.46927 .32985 m .47272 .35675 L .41854 .36997 L p .633 .513 .699 r
F P
0 g
s
.42551 .39634 m .41854 .36997 L .47272 .35675 L p .632 .51 .696 r
F P
0 g
s
.57645 .43276 m .58078 .41146 L .62664 .42414 L p .773 .662 .741 r
F P
0 g
s
.52917 .45179 m .5296 .44382 L .57204 .4479 L p .625 .772 .951 r
F P
0 g
s
.47272 .35675 m .47617 .38417 L .42551 .39634 L p .632 .51 .696 r
F P
0 g
s
.43256 .42092 m .42551 .39634 L .47617 .38417 L p .635 .522 .707 r
F P
0 g
s
.47966 .40977 m .4832 .43122 L .43972 .44139 L p .642 .554 .739 r
F P
0 g
s
.43972 .44139 m .43256 .42092 L .47966 .40977 L p .642 .554 .739 r
F P
0 g
s
.47617 .38417 m .47966 .40977 L .43256 .42092 L p .635 .522 .707 r
F P
0 g
s
.45462 .26077 m .45848 .2703 L .38982 .28786 L p .658 .753 .92 r
F P
0 g
s
.38982 .28786 m .38205 .27942 L .45462 .26077 L p .658 .753 .92 r
F P
0 g
s
.57645 .43276 m .57204 .4479 L .5296 .44382 L p .717 .672 .804 r
F P
0 g
s
.35678 .28151 m .36552 .27734 L .29863 .31065 L p .327 .785 .648 r
F P
0 g
s
.29863 .31065 m .28646 .31652 L .35678 .28151 L p .327 .785 .648 r
F P
0 g
s
.69073 .28188 m .68188 .28478 L .61141 .2636 L p .397 .733 .991 r
F P
0 g
s
.60668 .27297 m .61141 .2636 L .68188 .28478 L p .653 .749 .92 r
F P
0 g
s
.53002 .42826 m .5296 .44382 L .4868 .44651 L p .687 .646 .804 r
F P
0 g
s
.4868 .44651 m .4832 .43122 L .53002 .42826 L p .687 .646 .804 r
F P
0 g
s
.59777 .30785 m .59349 .33202 L .53166 .32568 L p .735 .605 .713 r
F P
0 g
s
.59349 .33202 m .58927 .35876 L .53125 .35289 L p .736 .593 .696 r
F P
0 g
s
.53125 .35289 m .53166 .32568 L .59349 .33202 L p .736 .593 .696 r
F P
0 g
s
.60215 .28784 m .59777 .30785 L .53207 .30103 L p .73 .631 .748 r
F P
0 g
s
.53166 .32568 m .53207 .30103 L .59777 .30785 L p .735 .605 .713 r
F P
0 g
s
.5296 .44382 m .53002 .42826 L .57645 .43276 L p .717 .672 .804 r
F P
0 g
s
.58927 .35876 m .58505 .38601 L .53085 .38061 L p .737 .59 .693 r
F P
0 g
s
.53085 .38061 m .53125 .35289 L .58927 .35876 L p .737 .59 .693 r
F P
0 g
s
.58078 .41146 m .57645 .43276 L .53002 .42826 L p .732 .622 .735 r
F P
0 g
s
.53207 .30103 m .53166 .32568 L .46927 .32985 L p .688 .566 .712 r
F P
0 g
s
.46927 .32985 m .46577 .30552 L .53207 .30103 L p .688 .566 .712 r
F P
0 g
s
.47272 .35675 m .46927 .32985 L .53166 .32568 L p .687 .552 .695 r
F P
0 g
s
.53249 .28052 m .53207 .30103 L .46577 .30552 L p .69 .597 .748 r
F P
0 g
s
.46577 .30552 m .46219 .28534 L .53249 .28052 L p .69 .597 .748 r
F P
0 g
s
.60668 .27297 m .60215 .28784 L .53249 .28052 L p .714 .678 .813 r
F P
0 g
s
.53207 .30103 m .53249 .28052 L .60215 .28784 L p .73 .631 .748 r
F P
0 g
s
.45058 .25645 m .45462 .26077 L .38205 .27942 L p .566 .878 .993 r
F P
0 g
s
.38205 .27942 m .37395 .2762 L .45058 .25645 L p .566 .878 .993 r
F P
0 g
s
.69994 .28333 m .70948 .28781 L .77597 .32511 L p 0 .284 .682 r
F P
0 g
s
.78901 .33274 m .77597 .32511 L .70948 .28781 L p .371 0 0 r
F P
0 g
s
.58505 .38601 m .58078 .41146 L .53044 .40651 L p .736 .599 .704 r
F P
0 g
s
.53044 .40651 m .53085 .38061 L .58505 .38601 L p .736 .599 .704 r
F P
0 g
s
.53166 .32568 m .53125 .35289 L .47272 .35675 L p .687 .552 .695 r
F P
0 g
s
.47617 .38417 m .47272 .35675 L .53125 .35289 L p .687 .549 .693 r
F P
0 g
s
.53044 .40651 m .53002 .42826 L .4832 .43122 L p .689 .586 .735 r
F P
0 g
s
.4832 .43122 m .47966 .40977 L .53044 .40651 L p .689 .586 .735 r
F P
0 g
s
.53002 .42826 m .53044 .40651 L .58078 .41146 L p .732 .622 .735 r
F P
0 g
s
.53125 .35289 m .53085 .38061 L .47617 .38417 L p .687 .549 .693 r
F P
0 g
s
.47966 .40977 m .47617 .38417 L .53085 .38061 L p .688 .559 .704 r
F P
0 g
s
.53292 .26516 m .53249 .28052 L .46219 .28534 L p .687 .655 .813 r
F P
0 g
s
.46219 .28534 m .45848 .2703 L .53292 .26516 L p .687 .655 .813 r
F P
0 g
s
.53085 .38061 m .53044 .40651 L .47966 .40977 L p .688 .559 .704 r
F P
0 g
s
.61141 .2636 m .60668 .27297 L .53292 .26516 L p .655 .751 .92 r
F P
0 g
s
.53249 .28052 m .53292 .26516 L .60668 .27297 L p .714 .678 .813 r
F P
0 g
s
.69994 .28333 m .69073 .28188 L .61634 .25945 L p 0 .499 .798 r
F P
0 g
s
.61141 .2636 m .61634 .25945 L .69073 .28188 L p .397 .733 .991 r
F P
0 g
s
.53338 .2553 m .53292 .26516 L .45848 .2703 L p .656 .752 .92 r
F P
0 g
s
.45848 .2703 m .45462 .26077 L .53338 .2553 L p .656 .752 .92 r
F P
0 g
s
.34782 .287 m .35678 .28151 L .28646 .31652 L p 0 0 0 r
F P
0 g
s
.28646 .31652 m .27399 .32374 L .34782 .287 L p 0 0 0 r
F P
0 g
s
.44638 .25649 m .45058 .25645 L .37395 .2762 L p .268 .774 .783 r
F P
0 g
s
.37395 .2762 m .36552 .27734 L .44638 .25649 L p .268 .774 .783 r
F P
0 g
s
.53292 .26516 m .53338 .2553 L .61141 .2636 L p .655 .751 .92 r
F P
0 g
s
.61634 .25945 m .61141 .2636 L .53338 .2553 L p .425 .783 .996 r
F P
0 g
s
.70948 .28781 m .71927 .29362 L .78901 .33274 L p .371 0 0 r
F P
0 g
s
.53385 .25065 m .53338 .2553 L .45462 .26077 L p .485 .834 .996 r
F P
0 g
s
.45462 .26077 m .45058 .25645 L .53385 .25065 L p .485 .834 .996 r
F P
0 g
s
.61634 .25945 m .62147 .25966 L .69994 .28333 L p 0 .499 .798 r
F P
0 g
s
.70948 .28781 m .69994 .28333 L .62147 .25966 L p .35 0 0 r
F P
0 g
s
.53338 .2553 m .53385 .25065 L .61634 .25945 L p .425 .783 .996 r
F P
0 g
s
.44202 .25955 m .44638 .25649 L .36552 .27734 L p 0 0 0 r
F P
0 g
s
.36552 .27734 m .35678 .28151 L .44202 .25955 L p 0 0 0 r
F P
0 g
s
.62147 .25966 m .61634 .25945 L .53385 .25065 L p 0 .543 .738 r
F P
0 g
s
.53435 .25037 m .53385 .25065 L .45058 .25645 L p .075 .637 .732 r
F P
0 g
s
.45058 .25645 m .44638 .25649 L .53435 .25037 L p .075 .637 .732 r
F P
0 g
s
.53385 .25065 m .53435 .25037 L .62147 .25966 L p 0 .543 .738 r
F P
0 g
s
.71927 .29362 m .70948 .28781 L .6268 .26289 L p .438 0 0 r
F P
0 g
s
.62147 .25966 m .6268 .26289 L .70948 .28781 L p .35 0 0 r
F P
0 g
s
.43754 .26392 m .44202 .25955 L .35678 .28151 L p .059 0 0 r
F P
0 g
s
.35678 .28151 m .34782 .287 L .43754 .26392 L p .059 0 0 r
F P
0 g
s
.6268 .26289 m .62147 .25966 L .53435 .25037 L p .315 0 0 r
F P
0 g
s
.53486 .25309 m .53435 .25037 L .44638 .25649 L p .191 0 0 r
F P
0 g
s
.44638 .25649 m .44202 .25955 L .53486 .25309 L p .191 0 0 r
F P
0 g
s
.53435 .25037 m .53486 .25309 L .6268 .26289 L p .315 0 0 r
F P
0 g
s
.6268 .26289 m .63227 .26744 L .71927 .29362 L p .438 0 0 r
F P
0 g
s
.63227 .26744 m .6268 .26289 L .53486 .25309 L p .394 0 0 r
F P
0 g
s
.53539 .25714 m .53486 .25309 L .44202 .25955 L p .269 0 0 r
F P
0 g
s
.44202 .25955 m .43754 .26392 L .53539 .25714 L p .269 0 0 r
F P
0 g
s
.53486 .25309 m .53539 .25714 L .63227 .26744 L p .394 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`0008gooooo3Ol0000^ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0;_ooool002Gooooo0_l00003ooooo`03o`000?oooooooooo07cooooo9?l0
000Uooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool002Gooooo00?o0000
ooooool00000N?oooolfo`0001cooooo00?o0000ooooooooool0:oooool2o`0002oooooo000Koooo
o`Co000000?o410@ooooooooool00oooool01?l0003oooooooooool0001coooooa[o00002?nW`>/0
0ol0003oYl3[ojO0j`03ojO0jaSo00005_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo02cooooo000Mooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00001^
ooooo`oo00005_nW`>/00ol0003oYl3[ojO0j`0?ojO0ja3o00004oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo02_ooooo000Booooo`Ko00001Oooool00ol0003oooooooooo`04oooo
o`;o00001?ooool00ol0003oooooooooo`1Vooooo`co00001onX`>/00ol0003oYl3[ojO0j`09ojO0
j`co00006?nW`>/00ol0003oYko[ojNoj`0:o`0000oooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0[ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0HOooool<o`0000WoZ<3[0ol00002ojO0j`Wo00002on_Ym000ol0003o
]Zg@okJ]d004okJ]d0co00001OnW`>/00ol0003oYko[ojNoj`04ojNoj`04o`000?mU^ogoIK_mofFk
o@Oo00002oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02[ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Looooo`[o
000000?oT>3no`000?l000002OnX`>/3o`0000;oZ:;A00?o0000ojnWd?n_Ym005?n_Ym000ol0003o
]Zg@okJ]d00@okJ]d0Ko00002OnW_n/2o`0000;oIK_m1ol00008ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05Sooooo2Ol00002oi3PoP03o`000?nX`>_oZ<3[00OoZ<3[
1?l00005ojRRd@03o`000?n_Ym3o[jO@01Co[jO@00?o0000okJ]d?nf[M005Onf[M001?l0003o_KCA
okfddOl00009ojNoj`?o000000?oIK_mo`000?l000001_l00004ooooo`03o`000?oooooooooo02oo
oooo0_l0000[ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003ooooo
ooooo`1Eooooo`Wo000000?oT>3nojS0jonX`>/02?nX`>/3o`0000[oZ:;A00?o0000ojnWd?n_Ym00
3_n_Ym06o`0001Ko]Zg@00?o0000okfddOnm]=401?nm]=43o`0000OoYko[0ol000000omU^ogo0000
o`000006o`000003ooooool0003ooooo03;ooooo00?o0000ooooooooool0:?ooool001_ooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05;ooooo1Ol0
0002ojKWn`;o00000_nX`N/00ol0003oZ<3[ojS0j`05ojS0j`?o00003OnXX]400ol0003o[jO@ojnW
d003ojnWd0_o00001On`V;l00ol0003o^Z6ookZQ_`02okZQ_`Oo00002onf[M000ol0003o_KCAokfd
d@07okfdd@Co00001_nW_n/3o`000003ofFkoOl0003o000000Ko0000<_ooool00ol0003ooooooooo
o`0Xooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo1Ol00002
ojKWn`;o00001OnX`N/01?l0003oZ<3[ojS0jonX`>/2o`0000ooZ:;A0ol000000on_Ym3o0000o`00
0002o`00013o/9Ro00?o0000okZQ_onjXKl02OnjXKl7o`0000Co]Zg@00?o0000okfddOnm]=402onm
]=43o`0000KoYko[0ol000000omV/?[o0000o`000005o`00037ooooo00?o0000ooooooooool09ooo
ool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1<ooooo`Go00000_nVio/2
o`0000OoZ<7[0ol0000>ojRRd@Co00000_nUTL000ol0003o/9Rook2H_`0Cok2H_`03o`000?njXKoo
^Z6o013o^Z6o1?l0000Aokfdd@?o00000_nW_n/01?l0003oY[o[ojJojonV_n/4ofJ`nPKo0000<?oo
ool00ol0003oooooooooo`0Vooooo`008oooool2o`0000gooooo00?o0000ooooooooool0BOooool5
o`000004ojKWnol0003o0000o`0000OoZ<7[0_l000000onOW]?o0000ojRRd@0:ojRRd@Co00001_nU
TL000ol0003o/9Rook2H_`0Cok2H_`03o`000?njXKoo^Z6o01?o^Z6o00?o0000olB[`Oo4Zl400ol0
000?okfdd@;o00001_nV_n/01Ol0003oI[3jofJ`n_l0003oI[3j00Co0000;oooool00ol0003ooooo
ooooo`0Vooooo`008oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Kooooo0ol0
00001On0j=_o0000ojKWnonVio_o000000SoZ<7[0_l00004oinNd`03o`000?nXX]7oZ:;A00CoZ:;A
1?l0000:ojFA`003o`000?n`V;oo/9Ro01?o/9Ro00?o0000okZQ_onjXKl04onjXKl00ol0003oa:_1
olB[`@03olB[`@?o00003Onm]=400ol0003o`[cDojJoj`06ojJoj`;o00000omV/?X01?l2OMko0000
o`000?l0000]ooooo`;o00009oooool002?ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`13ooooo`?o000000GoP>SKo`000?nVio_oY^Oko`000008ojS1j`;o00001_nOW]<01?l0003o
Z:;AojRRdOnXX]43o`0000ooYI7000?o0000ok2H_on`V;l04_n`V;l00ol0003o^Z6ookZQ_`0CokZQ
_`03o`000?o4Zl7oa:_100Koa:_11?l00008okfdd@03o`000?o2_=Co`[cD00;o`[cD00?o0000ojJo
jonV_n/00onV_n/2o`0000CoI[3j00Co0WgNo`000?l0003o0000;Oooool00ol0003oooooooooo`0T
ooooo`008oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo043ooooo0ol000001On0
j=_o0000ojKWnonVio_o000000SoZ<7[0_l00008oinNd`?o00004onUTL000ol0003o/9Rook2H_`08
ok2H_`_o00000_njXKl3o`0000oo^Z6o00?o0000olB[`Oo4Zl402oo4Zl43o`0000Go_KCA00?o0000
ol:le?o2_=@00oo2_=@2o`0000?oY[o[00Co0000ojJojol0003o00000omV/?X5o`0002_ooooo00?o
0000ooooooooool09?ooool002;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0n
ooooo`;o00000_n0j=/3ojKWn`SoZ<7[0_l00008oinNd`;o000000?oV8[3o`000?nUTL004OnUTL0=
o`0000[o/92f00?o0000okbJ]_nlV[H00onlV[H;o`0000Co^Z6o00?o0000olB[`Oo4Zl403_o4Zl43
o`0000;o_KCA00?o0000ol:le?o2_=@01Oo2_=@4o`0000?oY[o[0_l00003ofJ`nPGo0000:_ooool0
0ol0003oooooooooo`0Sooooo`008_ooool2o`0001?ooooo00?o0000ooooooooool0>oooool8o`00
00OoZ<7[0_l00008oinNd`;o00001?nHR/<00ol0003oYI70ojFA`00;ojFA`0Co00000_nSQkL00ol0
003o/92fok2@]P0Bok2@]P03o`000?nlV[Ko_9Zf00ko_9Zf1Ol0000ColB[`@;o00001oo2_=@5o`00
00GoY[o[0_l00003ofJ`nPCo0000:_ooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo03Sooooo1?l00002okSXmP05o`000?nY`N_oZL7[ojW1
jol000001?nX`N/2o`0000SoWikC0_l00006oiR:``03o`000?nUTL3oYI7000OoYI701?l00006oj>7
]`03o`000?n`T;Ko/92f01;o/92f00?o0000okbJ]_nlV[H04_nlV[H00ol0003oajJgolNV]`03o`00
00ooa:_100?o0000oljg`ol000000_o2_=@3o`0000Co`[cD0_l00006ojJoj`03o`000?mV/?[oI[3j
00;oI[3j1?l0000Xooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0=Oooool2o`0000;o/o[V00Co0000okSXm_nhj?Ko00001OnY`N/01?l0
003oZ<7[ojS1jol00007oinNd`?o00002?nHR/<00ol0003oYI70ojFA`004ojFA`0?o00002_nSQkL0
0ol0003o/92fok2@]P0Bok2@]P03o`000?nlV[Ko_9Zf01;o_9Zf00?o0000olNV]oo7Y[L00oo7Y[L4
o`0000[oa:_100?o0000oljg`oo>]l<01?l00008ol:le0;o00001OnV_n/2o`0000;oI[3j1_l0000V
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0booooo`?o00000_ncn^H01?l0003o^>SfokSXm_l00006ojW1j`;o00001onOW]<2o`0000coV8[3
00?o0000ojFA`?l000000ol0000=oj>7]`03o`000?n`T;Ko/92f01;o/92f00?o0000okbJ]_nlV[H0
4OnlV[H00ol0003oajJgolNV]`08olNV]`Co00001Oo4Zl44o`0000Coc[O30_l00007ol:le0;o0000
1OnV_n/3o`0000?oK:Od00?o0000ob9niol000000_l0000Vooooo`03o`000?oooooooooo00Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`00
8Oooool3o`0001Oooooo00?o0000ooooooooool0;oooool2o`000005oj?eb_l0003o/o[Vok?ji_l0
00000_nhj?H00ol0003oZL7[ojW1j`04ojW1j`04o`000?nGW=OoUicGo`0000CoWikC0_l0000=oiR:
``?o00004_nSQkL00ol0003o/92fok2@]P0Aok2@]P03o`000?nlV[Ko_9Zf017o_9Zf00?o0000olNV
]oo7Y[L03?o7Y[L6o`0000Woc[O30_l00005ol:le005o`000?o2_=Co0000o`000?nV_n/00_l00003
ojJnj`CoK:Od00?o0000ob9niol000000ol0000Tooooo`03o`000?oooooooooo00Gooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooo
oooo01Sooooo0_l0000]ooooo`?o000000GoXoG:o`000?ncn^Ko/o[Vo`000002okSXmP03o`000?nY
`N_oZL7[00CoZL7[00?o0000oiNLeonGW=L00_nGW=L01?l0003oWikCoinNdol0000=oiR:``;o0000
00?oTgjio`000?nSQkL04_nSQkL00ol0003o/92fok2@]P0Aok2@]P03o`000?nlV[Ko_9Zf017o_9Zf
00?o0000olNV]oo7Y[L03?o7Y[L5o`0000coc[O30_l00004ol:le004o`000?o2_=Co`[cDo`0000Ko
Y[k[1?m/Yo@01?l0003o8WkWo`000?l0F<l3o`0002?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`05o`000?nJkk_o0000oj?eb_l00000
0_ncn^H01?l0003o^>SfokSXm_l00006ojW1j`03o`000?nGW=OoUicG00?oUicG0_l0000=oiR:``;o
00000onCO[T00ol0003oXhNgoj>7]`0Aoj>7]`03o`000?n`T;Ko/92f00Oo/92f2ol000000onlV[Ko
0000o`000002o`0000ko_9Zf00?o0000olNV]oo7Y[L02Oo7Y[L3o`0000CoajJg00Co0000om>c^_l0
003o00002oo>]l<2o`0000?o`[cD0_l00002olO5f0KoY[k[00So0000ofbWm?m/YoCoK:Odo`000?lR
O^Oo0000o`1Hc`?o00008oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02Oooooo00Go0000oi[_^ol0003oXoG:o`000002ok?jiP?o^>Sf1onY`N/0
0ol0003oUicGoiNLe`03oiNLe`03o`000?n9PlOo000000_oV8[30_l00006oi=n^@03o`000?nSQkOo
XhNg00koXhNg3?l0000:ojn=/@03o`000?nlUk;o_9Nb00?o_9Nb2Ol00004okbJ]P03o`000?o7Y[Oo
ajJg00OoajJg0ol00007olNV]`05o`000?oC/k[odk>jom>c^_l000003?o>]l<2o`000003ol:le?l0
003o000000?oalGH00?o0000ojJnjonV_^/00onV_^/02?l0003oK:OdofbWm?m/YoCo0000ob9niol0
003o05S?0ol0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo02Gooooo00Co0000
oi[_^ol0003oXoG:0oncn^H3okSXmPKoZL7[0_l00005oiNLe`05o`000?n9PlOoRH?7ohV3aol00000
2?nHR/<2o`0000SoTgji00?o0000oj>7]onSQkL02OnSQkL5o`0000;oXX>b00?o0000ojn=/On_SK40
4On_SK400ol0003o_9NbokbG/P0<okbG/POo00001?o7Y[L3o`0000WoajJg00?o0000om>c^_oC/kX0
0ooC/kX2o`0000coc[O300?o0000olO5f?l000001?o7aMP00ol0003oY[k[ojJnj`03ojJnj`0;o`00
0?m/YoCoK:OdofbWm?l0003o8WkWo`000?l0F<oo0000o`17`_l000008?ooool3o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0007ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool08oooool01?l0003oV^nko`000?nSmLX3ok?jiP?o^>Sf1_nY`N/00ol0003o
UicGoiNLe`04oiNLe`03o`000?n9PlOoRH?700;oRH?700?o0000oiR:`onHR/<01?nHR/<2o`0000[o
Tgji00?o0000oj>7]onSQkL01OnSQkL4o`0000OoXX>b00?o0000ojn=/On_SK404On_SK400ol0003o
_9NbokbG/P0@okbG/P03o`000?o8Xk?ob:>c00Co00003?o7Y[L00ol0003odk>jom>c^P05om>c^P;o
00002_o>]l<2o`000003olO5f?l0003oalGH00?oalGH00?o0000ojJnjonV_^/00onV_^/02ol0003o
K:OdofbWm?m/YoCo0000ob9niol0003o05S?o`000?l0Al;o0000027ooooo00?o0000ooooooooool0
0_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`001oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool08Oooool01?l0003oV^nko`000?nSmLX3ok?jiP?o^>Sf1_nY`N/0
0ol0003oUicGoiNLe`04oiNLe`03o`000?n9PlOoRH?700CoRH?700Co0000oiR:`onHR/?oV8[30_l0
000=oi=n^@03o`000?nSQkOo000000Co00003?nRPk800ol0003o[hfaojn=/@0@ojn=/@03o`000?nl
Uk;o_9Nb013o_9Nb1?l00002olRS/`Co00002Oo7Y[L00ol0003odk>jom>c^P07om>c^P;o00001oo>
]l<01_l0003oelG8omO5b?l0003oalGHo`0000CoalGH00?o0000ojJnjonV_^/00onV_^/02ol0003o
K:OdofbWm?m/YoCo0000ob9niol0003o05S?o`000?l0Al;o0000027ooooo00?o0000ooooooooool0
7?ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`04o`000?nJkk_oXoG:oj?ebP?o
/o[V0onhj?H6ojW1j`03o`000?nGW=OoUicG00?oUicG0_l00007ohV3a`04o`000?nHR/?o0000o`00
00koTgji0ol0000Aoj:3/P03o`000?n_SK7o[hfa013o[hfa00?o0000okbG/_nlUk803_nlUk83o`00
00Wob:>c1?l00005olNV]`03o`000?oC/k[odk>j00Wodk>j0_l00005oljg``04o`000?oGaLSoelG8
omO5b0;o00001Oo7aMP00ol0003oY[k[ojJnj`03ojJnj`0;o`000?m/YoCoK:OdofbWm?l0003o8WkW
o`000?l0F<oo0000o`17`_l000008Oooool00ol0003oooooooooo`0Kooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01gooooo00Co0000oi[_^onSmL[oXoG:0oncn^H4o`0000GoZL7[00?o0000
oiNLeonGW=L00onGW=L00ol0003oRH?7ohV3a`07ohV3a`;o00003_nCO[T2o`000003oi5i]?l0003o
XX>b017oXX>b00?o0000ojn=/On_SK404?n_SK400ol0003o_9NbokbG/P0;okbG/P?o00000_nlUk80
0ol0003ob:>colRS/`0;olRS/`?o000000?oajJgo`000?oC/kX03OoC/kX01Ol0003oc[O3oljg`oo>
]l?o000000GoelG80_l00005olO5f003o`000?nV_^_oY[k[00?oY[k[00_o0000ofbWm?m/YoCoK:Od
o`000?lRO^Oo0000o`1Hcol0003o04O2o`00000Pooooo`03o`000?oooooooooo01_ooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Sooooo`03o`000?oooooo
oooo01_ooooo00Co0000oi[_^onSmL[oXoG:1?l00002ol?TkP03o`000?nY`N[o000000;o00000_nY
`N/5oiNLe`03o`000?n9PlOoRH?700OoRH?700?o0000oh1d_?l000003?nCO[T2o`0000CoTGVd00?o
0000oj:3/_nRPk803onRPk800ol0003o[hfaojn=/@0@ojn=/@03o`000?nlUk;o_9Nb00So_9Nb0ol0
0004okbG/P03o`000?o8Xk?ob:>c00oob:>c0ol0000>om>c^P;o000000?oc[O3o`000?oGaLP01OoG
aLP2o`0000GoalGH00?o0000ojJnjonV_^/00onV_^/02ol0003oK:OdofbWm?m/YoCo0000ob9niol0
003o05S?o`000?l0Al;o0000023ooooo00?o0000ooooooooool06_ooool0023ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?nJkk_o000000;o00000_oAn>D01?l0
003o`nC^ol?Tk_l00005ojW1jP03o`000?nGW=OoUicG00?oUicG00?o0000ohV3aon9PlL01on9PlL0
1Ol0003oP7Bloh1d_?n0M;co000000WoTgji0_l00006oi5i]003o`000?nRPk;oXX>b013oXX>b00?o
0000ojn=/On_SK401_n_SK4?o`0000;o_9Nb0ol00007okbG/P03o`000?o8Xk?ob:>c013ob:>c00Co
0000omFa]Ol0003o00003_oC/kX00ol0003oelG8omO5b006omO5b0;o00001Oo7aMP00ol0003oY[k[
ojJnj`03ojJnj`0;o`000?m/YoCoK:OdofbWm?l0003o8WkWo`000?l0F<oo0000o`17`_l000007_oo
ool00ol0003oooooo`00000Kooooo`008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo01Oooooo00Go0000oi[_^ol0003oe?kHo`000002om7hi@05o`000?o3i>ko`nC^ol?Tk_l00000
1OnY`NX00on<V]co0000oiNLe`02oiNLe`03o`000?n9PlOoRH?700OoRH?700?o0000oh1d_?n0M;`0
0_n0M;`00ol0003oTgjioi=n^@06oi=n^@03o`000?nANKCoTGVd00KoTGVd00?o0000oj:3/_nRPk80
3_nRPk8;o`0000Wo[hba00?o0000okbG/OnlUk400_nlUk4:o`0000?o_9Nb00?o0000olRS/oo8Xk<0
4?o8Xk<01?l0003oeK6eomFa]OoE/KD2o`0000codk>j0_l00008omO5b003o`000?o7aMSoalGH00Co
alGH00Co0000ojJnjonV_^_oY[k[2Ol000001?l0F<oo0000o`17`_l0000Oooooo`03o`000?oooooo
oooo01Wooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05Oooool01Ol0
003oV^nkomCnf?oDo]So000000?odOSU00Co0000ol?Tk_o3i>ko00001OnY`NX01_l0003oS9[LohbJ
g?l0003oUicGo`0000WoRH?700?o0000oh1d_?n0M;`01?n0M;`00ol0003oTgjioi=n^@03oi=n^@;o
00002_nANK@00ol0003oXX>boj:3/P09oj:3/PCo00000_nQP[800ol0003o[hbaojn</@0?ojn</@03
o`000?nlUk7o000000;o00002_nlUk46o`0000oob:>c00?o0000omFa]OoE/KD01?oE/KD2o`0000Wo
dk>j00Co0000omk3_OoN`kgo00002?oGaLP00ol0003oalGHolO5f003olO5f0Co00000_nV_^X4ogFQ
k@;o@goT0_l000001?l0F<oo0000o`17`_l0000Oooooo`03o`000?oooooooooo01Sooooo000Ooooo
o`;o0000:?ooool00ol0003oooooooooo`0Cooooo`;o00000ooDo]P01?l0003odOSUom7hiOl00003
ol?TkP03o`000?nY`N[oZL7Z00;oZL7Z00?o0000ohbJg?n<V]`00_n<V]`00ol0003oRH?7ohV3a`06
ohV3a`;o00001on0M;`01?l0003oTgjioi=n^OnCO[T2o`0000coTGVd00?o0000oj:3/_nRPk801?nR
Pk85o`0000KoXH:b00?o0000ojn</On_S;403_n_S;43o`00013o_9Na00?o0000olRS/_o8Xk800ol0
000<olRS/`03o`000?oE/KGoeK6e00KoeK6e0_l00006om>c^P03o`000?oN`kgog/>m00;og/>m00?o
0000omO5b?oGaLP01_oGaLP01_l0003oalGHolO5f?o7aMSo0000ol[?g@KoY[kZ1?meXNd3od=oi0?o
000000?o04O2o`000?ooool07_ooool00ol0003oooooooooo`0Gooooo`007oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo017ooooo00?o0000omCod_l000000_oDo]P01?l0003odOSU
om7hiOl00003ol?TkP03o`000?nY`N[oZL7Z00?oZL7Z00?o0000ohbJg?n<V]`00_n<V]`00ol0003o
RH?7ohV3a`05ohV3a`03o`000?n0M;coP7Bl00OoP7Bl00Co0000oi=n^Ol0003o00003_nANK@00ol0
003oXX>boj:3/P04o`0000_oXH:b00?o0000ojn</On_S;403?n_S;42o`000003ojn</Ol0003o_9Na
013o_9Na00?o0000olRS/_o8Xk800oo8Xk84o`0000Sob:>c00?o0000omFa]OoE/KD02?oE/KD2o`00
00Codk>j00?o0000omk3_OoN`kd00ooN`kd00ol0003oelG8omO5b006omO5b003o`000?o7aMSo0000
00?ob/oM1OnV_^X01Ol0003oMJ7]ogFQkOmeXNgo000000;o@goT0_lPIMT2o`000003o`17`_l0003o
oooo01gooooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oDom;o000000?oe?kH00Co0000om7hiOoAn>Go00000oo3i>h0
0ol0003oZL7ZojW1jP02ojW1jP03o`000?n<V]coS9[L00;oS9[L00?o0000ogElcOl000001On9PlL0
0ol0003oP7Bloh1d_008oh1d_0;o00004?nANK@3o`0000ooXH:b00?o0000ojn</On_S;402On_S;43
o`0000?o[hba00?o0000okbG/OnlUk403onlUk400ol0003ob:>bolRS/P07olRS/P?o00001Oo8Xk<0
0ol0003oeK6eomFa]@0:omFa]@;o000000?odk>jo`000?oN`kd01_oN`kd00ol0003oelG8omO5b005
omO5b0;o00001?o:cmd00ol0003oY[kZojJnjP03ojJnjP?oMJ7]00Co0000od=oi?m3OnCo@goT0olP
IMT00ol0003o04O2o`00000Mooooo`;o00006?ooool001oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0=ooooo`04o`000?oDom;oe?oBo`0000;oe?kH00Co0000om7hiOoAn>Go0000
0oo3i>h00ol0003oZL7ZojW1jP03ojW1jP03o`000?n<V]coS9[L00;oS9[L00Co0000ogElcOmeO<go
00000on9PlL00ol0003oP7Bloh1d_008oh1d_003o`000?mlKKOo000000koTGVd0_l000000onAN;?o
0000oj62/P0@oj62/P03o`000?n_S;7o[hba00Go[hba0ol00006ojn</@03o`000?nlUk7o_9Na00oo
_9Na00?o0000olRS/_o8Xk802_o8Xk83o`000003olRS/ol0003oeK6e00koeK6e0_l00008omk3_@03
o`000?oGaLSoelG800GoelG800?o0000ol[?gOo:cmd00oo:cmd00ol0003oY[kZojJnjP02ojJnjP05
o`000?meXNgoMJ7]ogFQkOl000000_m3On@01?l0003o86GIob1UfOlPIMT3o`0001kooooo00?o0000
ooooooooool05Oooool001oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<oooo
o`03o`000?oDom;o000000?oe?kH00Co0000om7hiOoAn>Go00000oo3i>h00ol0003oZL7ZojW1jP02
ojW1jP03o`000?n<V]coS9[L00;oS9[L00?o0000ogElcOmeO<d00_meO<d00ol0003oRH?7o`00000:
oh1d_005o`000?mlKKOoO6fgoga]]ol000002onANK@2o`0000?oTGRc00?o0000oj62/_nQP[803onQ
P[800ol0003o[hbaojn</@02ojn</@?o00002On_S;400ol0003o_9NaokbG/@0>okbG/@03o`000?o8
Xk;ob:>b00kob:>b0ol0000>omFa]@03o`000?oR`[So000000Sog/>m00?o0000omO5b?oGaLP00ooG
aLP00ol0003ogmK>o`000004ol[?g@03o`000?nV_^[oY[kZ00;oY[kZ00Go0000ogFQkOmeXNgoMJ7]
o`000003od=oi0?o86GI0_lBF]<2o`0001gooooo00?o0000ooooooooool05Oooool001oooooo0_l0
000]ooooo`03o`000?oooooooooo00[ooooo00Co0000omCod_oDom;o00000_oDo]P01?l0003odOSU
om7hiOl00003ol?TkP03o`000?nY`N[oZL7Z00;oZL7Z00?o0000ohbJg?n<V]`00_n<V]`00ol0003o
MGc=ogElc@04ogElc@03o`000?n0M;coP7Bl00SoP7Bl00?o0000oga]]omlKKL00_mlKKL00ol0003o
TGVdoi5i]006oi5i]0?o00001_nAN;<00ol0003oXH:boj62/P0>oj62/P03o`000?n_S;7o000000;o
00003?n_S;400ol0003o_9NaokbG/@0>okbG/@03o`000?o8Xk;ob:>b00oob:>b00Co0000omF`]?l0
003o00002ooE/KD01Ol0003oh/:hon;2^?oR`[So000000Sog/>m00Go0000omO5b?oGaLSoelG8o`00
0002omoFcP;o00001?o:cmd00ol0003oY[kZojJnjP02ojJnjP05o`000?meXNgoMJ7]ogFQkOl00000
0_m3On@01?l0003o86GIob1UfOlPIMT3oa9Jd`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool05?ooool001kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oDom;o000000;oe?kH00Go0000om7hiOoAn>GodOSUo`000003ol?TkP03o`000?nY`N[oZL7Z00;o
ZL7Z00?o0000ohbJg?n<V]`00_n<V]`00ol0003oMGc=ogElc@04ogElc@03o`000?n0M;coP7Bl00Ko
P7Bl0_l00006oga]]`03o`000?nANKCoTGVd00?oTGVd0_l00009oi5h/`03o`000?nQP[;oXH:b00go
XH:b0ol00007ojn</@go00003?nlUk400ol0003ob:>bolRS/P0>olRS/P03o`000?oE/;CoeK2d00;o
eK2d0_l00009omFa]@03o`000?oR`[Soh/:h00;oh/:h00?o0000omk3_OoN`kd01_oN`kd00ol0003o
elG8o`000004omoFcP03o`000?o:cmgob/oM00?ob/oM00Go0000ojJnj_nV_^[oY[kZo`000003ogFQ
k@04o`000?m3OnCo@goTod=oi0?o86GI00Go0000oa9JdolBF]?o4U[Co`00000Mooooo`03o`000?oo
oooooooo01?ooooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool0
1?l0003oe?oBomCod_l00002omCnf004o`000?oAn>GodOSUo`0000?o`nC^00?o0000ojW1j_nY`NX0
0_nY`NX00ol0003oS9[LohbJg002ohbJg003o`000?meO<goMGc=00CoMGc=00?o0000ofEX`Ol00000
1_n0M;`00ol0003oO6fgoga]]`06oga]]`04o`000?nANKCoTGVdoi5i]0;o00002onAN;<00ol0003o
XH:boj62/P0:oj62/Pgo00002?n`Sk@00ol0003o_9VdokbI]002okbI]0Wo00000onlUk400ol0003o
b:>bolRS/P0>olRS/P03o`000?oE/;CoeK2d00CoeK2d0_l00007omFa]@03o`000?oR`[Soh/:h00?o
h/:h00?o0000omk3_OoN`kd01_oN`kd00ol0003ogmK>omoFcP03omoFcP;o00001?o:cmd00ol0003o
Y[kZojJnjP02ojJnjP04o`000?meXNgoMJ7]o`0000?o@goT00Co0000ob1UfOlPIMWo86GI0olBF]<0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool01Oooool01?l0003oe?oBomCod_l00002omCnf004o`000?oAn>Go
dOSUo`0000Co`nC^00?o0000ojW1j_nY`NX00_nY`NX00ol0003oS9[LohbJg002ohbJg003o`000?me
O<goMGc=00CoMGc=00Co0000ofEX`OmUJ<7o00001?n0M;`00ol0003oO6fgoga]]`07oga]]`04o`00
0?nANKCo0000o`0000goTGRc00?o0000oj62/_nQP[801onQP[85o`0000;oXXFd00?o0000ok2?]?n`
Sk@03_n`Sk@00ol0003o_9VdokbI]00;okbI]0Ko00003_o8Xk800ol0003oeK2domF`]006omF`]003
o`000?oE/KGoeK6e00?oeK6e00?o0000on;2^?oR`[P01OoR`[P00ol0003og/>momk3_@05omk3_@03
o`000?oOe/kogmK>00CogmK>0_l00004ol[?g@05o`000?nV_^[oY[kZojJnj_l000000omeXNd01Ol0
003o@goTod=oi?m3OnCo000000;o86GI00Go0000oa9JdolBF]?o4U[Co`00000Kooooo`03o`000?oo
oooo000001Cooooo000Nooooo`?o0000<Oooool2o`0000Gooooo00?o0000omCod_l000000ooDo]P0
1Ol0003odOSUom7hiOl0003o`nC^00Go00000_nY`NX00ol0003oS9[LohbJg002ohbJg003o`000?me
O<goMGc=00CoMGc=00Go0000ofEX`OmUJ<7oIFS1o`000003oh1d_003o`000?mlKKOoO6fg00SoO6fg
0_l0000?oi5h/`03o`000?nQP[;oXH:b00CoXH:b1?l00006oj:5]003o`000?n`SkCo/8nd00ko/8nd
00?o0000okbI]?nlVK@03_nlVK@00ol0003ob:BeolRT]@04o`0000Wob:>b00?o0000omF`]?oE/;@0
2?oE/;@2o`0000?oeK6e00?o0000on;2^?oR`[P01_oR`[P00ol0003og/>momk3_@03omk3_@03o`00
0?oYel;o000000GogmK>00?o0000ol[?gOl000000oo:cmd00ol0003oY[kZojJnjP02ojJnjP04o`00
0?meXNgoMJ7]o`0000?o@goT00Co0000ob1UfOlPIMWo00000olBF]<00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo017ooooo000Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooo
ooooooooo`000002omCodP05o`000?oDo]Soe?kHo`000?oAn>D01?l00002olWLi`03o`000?nZ`>[o
Z/3Z00?o00000on<V]`00ol0003oMGc=ogElc@05ogElc@03o`000?mUJ<7oIFS100;oIFS100?o0000
oh1d_?l000002_mlKKL00ol0003oNfbfo`00000@oi5h/`03o`000?nQP[;o000000?o00002_nRQK@0
0ol0003o/8ndok2?]00>ok2?]003o`000?nlVKCo_9Vd00ko_9Vd00?o0000olRT]Oo8Y;D01?o8Y;D3
o`0000Kob:>b00?o0000omF`]?oE/;@02_oE/;@2o`000003omFa]Ol0003oh/:h00Soh/:h00?o0000
omk3_OoN`kd00_oN`kd00ol0003ojMO2o`000005omoFcP03o`000?o:cmgo000000Cob/oM00Go0000
ojJnj_nV_^[oY[kZo`000003ogFQk@04o`000?m3OnCo@goTo`0000?o86GI00Go0000oa9JdolBF]?o
4U[Co`00000Mooooo`03o`000?oooooooooo017ooooo000Cooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0dooooo`06o`000?ooooooooooo`000?oDom;o00000ooDo]P2
o`000003omcZgOl0003obMcW00?obMcW00Co0000oj[0j_nZ`>[oZ/3Z0_n1V^<2o`000003ohbJg?l0
003oMGc=00GoMGc=00?o0000ofEX`OmUJ<401?mUJ<400ol0003oO6fgoga]]`08oga]]`05o`000?mk
K;KoNfbfog]/]_l000003_nAN;<4o`0000goXXFd00?o0000ok2?]?n`Sk@03_n`Sk@00ol0003o_9Vd
okbI]00=okbI]003o`000?o8Y;Gob:Be00Sob:Be1?l00002olRS/P03o`000?oE/;CoeK2d00coeK2d
0_l0000:on;2^004o`000?oN`kgog/>mo`0000?ojMO200?o0000omoFc_oOe/h00ooOe/h00ol0003o
b/oMo`000003ol[?g@05o`000?nV_^[oY[kZojJnj_l000000omeXNd01Ol0003o@goTod=oi?m3OnCo
000000;o86GI00Go0000oa9JdolBF]?o4U[Co`00000Nooooo`03o`000?oooooooooo013ooooo000C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`;o00000_oD
om801?l0003oe?kHo`000?l00003omcZg@03o`000?o9g>OobMcW00;obMcW00Co0000oj[0j_nZ`>[o
Z/3Z1?n1V^<2o`0000GoMGc=00?o0000ofEX`OmUJ<401OmUJ<400ol0003oO6fgoga]]`07oga]]`03
o`000?mkK;KoNfbf00;oNfbf00?o0000oi5h/onAN;<02OnAN;<5o`00013oXXFd00?o0000ok2?]?n`
Sk@03On`Sk@00ol0003o_9VdokbI]00=okbI]003o`000?o8Y;Gob:Be00cob:Be0ol0000>omF`]003
o`000?oR`[Oo000000[oh/:h00?o0000omk3_Ol000000ooYel800ol0003ogmK>omoFcP03omoFcP04
o`000?o:cmgob/oMo`0000;ob/oM2Ol00003od=oi005o`000?lPIMWo86GIob1UfOl000000_lBF]<0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`02
ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0=oooool0
0ol0003oe?oBo`000002o`000003onC`eOl0003og>[M00;og>[M00Go0000olWLioo9g>OobMcWo`00
0004oj[0jP04o`000?n1V^?oPI[Soh6Jh`;oFGCD00?o0000ogElcOmeO<d00_meO<d00ol0003oIFS1
ofEX`@04ofEX`@03o`000?mMG[_o000000OoO6fg00?o0000og]/]_mkK;H00omkK;H00ol0003oTGRc
oi5h/`07oi5h/`?o00000onBNkL00ol0003oXXFdoj:5]00>oj:5]003o`000?n`SkCo/8nd00go/8nd
00?o0000okbI]?nlVK@03OnlVK@00ol0003ob:BeolRT]@0=olRT]@04o`000?oD/[Oo0000o`0000_o
eK2d00Go0000on;2]ooR`[Ooh/:go`00000:on;2^003o`000?oYel;ojMO200?ojMO200?o0000omoF
c_oOe/h00ooOe/h00ol0003ob/oMol[?g@02o`000003ol_Ii?l0003oYkgZ00;oYkgZ0omoW>D3o`00
00;o@goT00Co0000ob1UfOlPIMWo00000olBF]<00ol0003oooooooooo`0Kooooo`;o00002_ooool0
0ol0003oooooooooo`04ooooo`004oooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000g
ooooo`04o`000?oDom;oe?oBo`0000?oi?3E00Go0000omcZgOoLj]gog>[Mo`000003olWLi`03o`00
0?nZ`>[oZ/3Z00;oZ/3Z00Co0000oh6Jhon1V^?oPI[S0omIM=@01?l0003oMGc=ogElcOl00006ofEX
`@04o`000?mMG[_oGEjko`0000KoO6fg00?o0000og]/]_mkK;H01OmkK;H00ol0003oTGRcoi5h/`03
oi5h/`?o00001onBNkL00ol0003oXXFdoj:5]00=oj:5]003o`000?n`SkCo/8nd00Go/8nd4Ol00006
okbI]003o`000?o8Y;Gob:Be00kob:Be00Co0000omBb]ooD/[Ooe;:g0_l00009omF`]003o`000?oR
`[Ooh/:g00;oh/:g00?o0000on;2^?oR`[P01ooR`[P00ol0003ojMO2onWG`P04onWG`P03o`000?oO
e/kogmK>00;ogmK>00Co0000ol[?gOl0003o00000_o;fN@01Ol0003oYkgZojNmj_nW_N[o000000?o
OicU0_mNP=`3o`0000?o86GI00Co0000oa9JdolBF]?o00007oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo000Cooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0fooooo`?o00001?oTl=D01Ol0003og>[MomcZgOoLj]go000000?obMcW00?o0000
oj[0j_nZ`>X00_nZ`>X01?l0003oPI[Soh6Jhon1V^<4oeUde003o`000?meO<go000000KoIFS100Go
0000oeeN^omMG[_oGEjko`000004oga]]`03o`000?mkK;KoNfbf00KoNfbf00?o0000oi5h/onAN;<0
1?l00009oi9k]`03o`000?nRQKCoXXFd00_oXXFd2_l00008ok2F_003o`000?nkWkco^inl00Ko^inl
2Ol0000=olRT]@03o`000?oD/[Ooe;:g00Coe;:g0ol00005omF`]003o`000?oR`[Ooh/:g00Coh/:g
00?o0000on;2^?oR`[P01OoR`[P00ol0003ok]Nko`000005onWG`P03o`000?oOe/kogmK>00;ogmK>
0_l00002ol_Ii003o`000?o;fNCo000000?oYkgZ00Co0000ognLiOmoW>GoOicU1OmNP=`2o`000003
ob1UfOl0003o4U[C00;o4U[C00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo000Cooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0eooooo`;o000000?oio;Bo`000?oTl=D00ooTl=D01Ol0003og>[MomcZgOoLj]go0000
00?obMcW00?o0000oj[0j_nZ`>X00_nZ`>X01Ol0003oPI[Soh6Jhon1V^?o000000CoFGCD00?o0000
ofEX`OmUJ<401?mUJ<400ol0003oGEjkoeeN^`03oeeN^`04o`000?mlKKOoO6fgo`0000WoNfbf1?l0
000<oi9k]`03o`000?nRQKCoXXFd00KoXXFd1Ol00002ojB=_@03o`000?n`U[co/9Jl00go/9Jl00?o
0000ok^O_?nkWk`03?nkWk`00ol0003oaJVmolFY_@04o`0000Wob:Be00?o0000omBb]ooD/[L01ooD
/[L2o`0000?oeK2d00?o0000on;2]ooR`[L01OoR`[L00ol0003oh/:hon;2^004on;2^003o`000?o^
ek_o000000KojMO200Ko0000omoFc_oOe/ko0000on?YeOl00003ol_Ii0;o00000onW_NX01Ol0003o
OicUognLiOmoW>Go000000CoGX3L0_m:K]@2o`0000?o4U[C00?o0000ooooooooool07Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0dooooo`;o00000_oWl]801Ol0003oi?3EonC`eOoTl=Go
000000Cog>[M00Go0000olWLioo9g>OobMcWo`000003oj[0jP03o`000?n1V^?oPI[S00;oPI[S00?o
0000oeUde?mIM=@00_mIM=@00ol0003oIFS1ofEX`@04ofEX`@03o`000?mMG[_oGEjk00?oGEjk00?o
0000oga]]ol000001omkK;H5o`0000ooTW^g00?o0000oj:5]?nRQK@01Ol00007ojB=_@03o`000?n`
U[co/9Jl00go/9Jl00?o0000ok^O_?nkWk`03?nkWk`00ol0003oaJVmolFY_@04olFY_@?o00001_o8
Y;D00ol0003oe;:gomBb]`09omBb]`;o000000?oeK2do`000?oR`[L01ooR`[L00ol0003oh/:hon;2
^002on;2^005o`000?o^ek_ok]NkonkG^ol000001OoYel800ol0003ogmK>o`000002on?Ye@04o`00
0?o;fNCobmWTol_Ii0;o00000onW_NX01Ol0003oOicUognLiOmoW>Go000000CoGX3L0om:K]@00olP
IMWo0000oa9Jd`02oa9Jd`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0000eoooo
o`05o`000?oWl];oio;BonObd_l000000ooTl=D01Ol0003og>[MomcZgOoLj]go000000CobMcW00Go
0000oj[0j_nZ`>[oZ/3Zo`000004oh6Jh`03o`000?mIM=CoFGCD00;oFGCD00?o?5S5o`000?mUJ<40
0omUJ<400ol0003oGEjkoeeN^`05oeeN^`03o`000?mkK;KoNfbf00?oNfbf0ol00002og]/]P03o`00
0?mnLK[o000000koTW^g1?l0000<ojB=_@03o`000?n`U[co/9Jl00co/9Jl00?o0000ok^O_?nkWk`0
3OnkWk`00ol0003oaJVmolFY_@07olFY_@Co000000?ob:Beo`000?oD/[L03OoD/[L00ol0003oh/:g
on;2]`08on;2]`04o`000?oR`[Soh/:ho`0000Cok]Nk00?o0000onWG`_oYel801?oYel801Ol0003o
hnWEon?YeOoSjMGo000000CobmWT00Go0000ojNmj_nW_N[oYkgZo`000003ognLi@03o`000?mNP=co
GX3L00;oGX3L00Go0000odY^e?m:K]CoBVkDo`000003oa9Jd`03o`000?oooooooooo01_ooooo0ol0
0007ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000
onObd_oWl]800_oWl]801Ol0003oi?3EonC`eOoTl=Go000000?og>[M00?o0000olWLioo9g>L00_o9
g>L01Ol0003oZ/3Zoj[0j_nZ`>[o000000?oPI[S00?o0000oeUde?mIM=@00omIM=@2ocaHa@04o`00
0?mUJ<7oIFS1o`0000SoGEjk00?o0000og]/]_mkK;H00ol00004og]/]P05o`000?mnLK[oOW6jogia
^_l000002onBNkL2o`000003oiJ5_ol0003oY8fm00koY8fm00?o0000ok2F_?n`U[`02on`U[`00ol0
003o^inlok^O_00<ok^O_003o`000?o5ZKgoaJVm00coaJVm0ol0000=omBb]`;o00002_oR`[L00ol0
003oh/:ho`000005onkG^`03o`000?oYel;ojMO200?ojMO200Go0000on?YeOoSjMGohnWEo`000004
ol_Ii0;o00000_nW_NX01Ol0003oOicUognLiOmoW>Go000000CoGX3L00?o0000odY^e?m:K]@00_m:
K]@2o`000003oa9Jdol0003ooooo01oooooo00?o0000ooooooooool00_ooool00omEEEGoIVIVo`00
0006ooooo`007?ooool00ol0003oooooooooo`0dooooo`05o`000?oWl];oio;BonObd_l000001?oT
l=D01Ol0003og>[MomcZgOoLj]go000000?obMcW00?o0000oj[0j_nZ`>X00_nZ`>X01Ol0003oPI[S
oh6Jhon1V^?o000000CoFGCD00Oo0000ocaHaOllF<Go?5S5o`000?mUJ<7o000000OoGEjk00Co0000
oeaM^_l0003o00001_mkK;H00ol0003oOW6jogia^P02ogia^P03o`000?nBNkOoTW^g00OoTW^g0_l0
0003oiJ5_`03o`000?nTSKgoY8fm00goY8fm00?o0000ok2F_?n`U[`02on`U[`00ol0003o^inlok^O
_00<ok^O_003o`000?o5ZKgoaJVm00goaJVm00Co0000om2f`?l0003o00002_oD/[L01?l0003oh<>k
on33^ol0000:on;2]`03o`000?o^ek_ok]Nk00Cok]Nk00?o0000onWG`_oYel800_oYel82o`0000?o
hnWE00?o0000ol_Ii?o;fN@00_o;fN@01Ol0003oYkgZo`000?nW_N[o000000?oOicU00?o0000oej0
g?mNP=`00_mNP=`00ol0003oBVkDodY^e002odY^e0;o@VK@00?o0000oa9Jdol000007_ooool3o`00
00cooooo000Looooo`03o`000?oooooooooo03Cooooo00Go0000onObd_oWl];oio;Bo`000004onC`
e@05o`000?oLj]gog>[MomcZgOl000000oo9g>L00ol0003oZ/3Zoj[0jP02oj[0jP05o`000?n1V^?o
PI[Soh6Jhol000001?mIM=@00ol0003o?5S5ocaHa@02ocaHa@03o`000?mMG[_oGEjk00GoGEjk1?l0
0005og]/]P;o00001_mnLKX00ol0003oTW^goi9k]`03oi9k]`?o00001_nFQKl00ol0003oY8fmojB=
_@0<ojB=_@03o`000?n`U[co/9Jl00Co/9Jl4?l00006ok^O_003o`000?o5ZKgoaJVm00coaJVm00?o
0000om2f`?o@]/000_o@]/000ol0003oe;:gomBb]`07omBb]`05o`000?oP`k_oh<>kon33^ol00000
2OoR`[L00ol0003ok]NkonkG^`04onkG^`07o`000?oYel;ojMO2onWG`_l0003okno5o`000003on?Y
e@03o`000?o;fNCobmWT00;obmWT00Go0000ojNmj_l0003oYkgZo`000004ognLi@05o`000?mNP=co
GX3Loej0g?l000001?m:K]@4od9Vd003o`000?oooooooooo01Wooooo0ol00002ooooo`03o`000?oo
oooooooo00[ooooo000Looooo`03o`000?oooooooooo03Cooooo00Go0000onObd_oWl];oio;Bo`00
0004onC`e@05o`000?oLj]gog>[MomcZgOl000000oo9g>L00ol0003oZ/3Zoj[0jP02oj[0jP05o`00
0?n1V^?oPI[Soh6Jhol000001?mIM=@00ol0003o?5S5ocaHa@02ocaHa@03o`000?mMG[_oGEjk00;o
GEjk1?l00003oeaM^P05o`000?mkK;KoNfbfog]/]_l000002?mnLKX01?l0003oTW^goi9k]onBNkL2
o`0000WoUXFo00?o0000ojB=_OnTSKd02_nTSKd9o`0000Oo[jG=00?o0000okN/cOng[<d01_ng[<d7
o`0000koaJVm00?o0000om2f`?o@]/000oo@]/02o`0000Ooe;:g00?o0000on33^ooP`k/00_oP`k/0
0ol0003oh/:gon;2]`05on;2]`03o`000?o_ek[o000000Kok]Nk00Ko0000onWG`_oYel;o0000ono_
aOl00004on?Ye@05o`000?o;fNCobmWTol_Ii?l000000_nW_NX2o`0000CoOicU00Go0000oej0g?mN
P=coGX3Lo`000004odY^e003o`000?m2I]3o@VK@00;o@VK@00?o0000ooooooooool05Oooool3o`00
00Gooooo00?o0000ooooooooool02_ooool001cooooo0_l0000eooooo`05o`000?oWl];oio;BonOb
d_l000001?oTl=D01_l0003og>[MomcZgOoLj]go0000olWLi`[o000000?oPI[So`000?mIM=@00omI
M=@00ol0003o?5S5ocaHa@02ocaHa@03obe8_?l0003o000000;o00000_mMG[/00ol0003oG5fjoeaM
^P02oeaM^P04o`000?mkK;KoNfbfo`0000WoOW6j00Co0000oi9k]ol0003o00002onFQKl00ol0003o
Y8fmojB=_@05ojB=_@Go00000_nWWlh00ol0003o[jG=ojnUc@0;ojnUc@03o`000?ng[<go]jc=00co
]jc=00?o0000okjcconn/ll00ol00008olFY_@03o`000?o@]/3od;K000Kod;K00_l00004omBb]`03
o`000?oP`k_oh<>k00Coh<>k00?o0000on;2]ooR`[L01?oR`[L00ol0003okmNjo`000006onkG^`03
o`000?oYel;o000000;okno500?o0000on?YeOoSjMD00_oSjMD01Ol0003obmWTol_Ii?o;fNCo0000
00?oYkgZ00?o0000ognLiOmoW>D00_moW>D01Ol0003oGX3Loej0g?mNP=co000000CoBVkD00?o0000
od9Vd?m2I]000_m2I]000ol0003oooooooooo`0Booooo`?o00002?ooool00ol0003oooooooooo`0:
ooooo`007?ooool00ol0003oooooooooo`0dooooo`05o`000?oWl];oio;BonObd_l000000ooTl=D0
1?l0003og>[MomcZgOoLj]d3o`0000;obm;O1OnZ`>T3ogBLjP;o00001?mIM=@01?l0003o?5S5ocaH
aOllF<D3o`0000GoGEjk00?o0000oeaM^_mLGKX00_mLGKX00ol0003oNfbfo`00000:ogia^P;o0000
3_nFQKl00ol0003oY8fmo`000004o`0000OoYio>00?o0000ojnUcOn_YLd02on_YLd00ol0003o]jc=
okN/c@0<okN/c@03o`000?nn/loo_[??00?o_[??0ol00005olFY_@03o`000?o@]/3od;K000Sod;K0
00Go0000omBb]ooD/[Ooe;:go`000007on33^`03o`000?oR`[Ooh/:g00;oh/:g00Go0000onoG^_o_
ek[okmNjo`000006onkG^`05o`000?o_klGokno5ono_aOl000001?oSjMD01Ol0003obmWTol_Ii?o;
fNCo000000?oYkgZ0_l00003ognLi@05o`000?mNP=coGX3Loej0g?l000001?m:K]@00ol0003o@VK@
od9Vd002od9Vd003o`000?oooooooooo00kooooo1?l0000;ooooo`03o`000?oooooooooo00[ooooo
000Kooooo`03o`000?oooooooooo03Gooooo00Go0000onObd_oWl];oio;Bo`000003onC`e@06o`00
0?oLj]go0000o`000?oLf]Co00001?o;d]l5oj[0j@?oM9cZ00?o<F[Io`000?mIM=@00_mIM=@5o`00
00;o;DRl00Go0000oeeN^omMG[_oGEjko`000006oeaM^P03o`000?mnLK[oOW6j00SoOW6j00?o0000
ohEm`ol000003OnFQKl3o`0000goYio>00?o0000ojnUcOn_YLd02_n_YLd00ol0003o]jc=okN/c@0;
okN/c@03o`000?nn/loo_[??00Oo_[??0ol00002olFY_@03o`000?o@]/3od;K000Wod;K00_l00000
0ooD/[Oo0000on33^`07on33^`04o`000?oR`[Ooh/:go`0000CokmNj00?o0000onkG^oo^ek/01?o^
ek/00ol0003okno5ono_a@02ono_a@05o`000?oSjMGohnWEon?YeOl000000_o;fN@4o`000003ojNm
j_l0003o000000?oOicU00Go0000oej0g?mNP=coGX3Lo`000004odY^e003o`000?m2I]3o@VK@00;o
@VK@00?o0000ooooooooool02oooool3o`00013ooooo00?o0000ooooooooool02Oooool001_ooooo
00?o0000ooooooooool0=Oooool01Ol0003oio;BonObd_oWl];o000000?oi?3E0_l00003omcJe003
o`000?o;d]oobm;O00;obm;O00?o0000oj[0jOnZ`>T00_nZ`>T01Ol0003oM9cZogBLj_mdW>[o<F[I
00Co00000ollF<D01ol0003o;DRlobe8_?l]B;co0000oeeN^ol000001omLGKX00ol0003oOW6jogia
^P07ogia^P05o`000?n5OL?oQGg3ohEm`ol000002_nFQKl2o`000003oijKdOl0003oYio>00_oYio>
4?l000000ong[<go0000o`000004o`0000Ko]jc=00?o0000okjcconn/ll02_nn/ll3o`0000god;K0
0_l00009on33^`03o`000?oR`[Oo000000GokmNj00?o0000onkG^oo^ek/00_o^ek/2o`0000Cokno5
00Co0000on?YeOoSjMGohnWE0ol000001?o8i>_o0000ojNmjOnW_NT5o`000003ognLiOl0003oGX3L
00;oGX3L00?o0000odY^e?m:K]@00_m:K]@00ol0003o@VK@od9Vd002od9Vd003o`000?oooooooooo
00Sooooo0ol0000Cooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Go
oooo00Go0000onObd_oWl];oio;Bo`000002onC`e@;o00001OoLf]@01Ol0003obm;Ool_Bgoo;d]oo
000000CoZ/3Y00?o0000ogBLj_mdW>X01Ol00004ocaHa@07o`000?l]B;co;DRlobe8_?l0003oGEjk
o`000006oeaM^P03o`000?mQI;ko000000KoOW6j0_l00005ohEm``03o`000?nFQKooUXFo00CoUXFo
0ol00004oijKd@03o`000?nWWlkoYio>00CoYio>1Ol00002ojC8lP03o`000?nRao?oX/Oc00[oX/Oc
00?o0000oio5lonOaO<01OnOaO<7o`0000go_[??00Co0000olFld_l0003o00002oo@]/000ol0003o
f/C4o`000009on33^`03o`000?o_ek[okmNj00CokmNj00Oo0000onkG^oo^ek_ok]Nko`000?ockk_o
000000Cokno500?o0000on?YeOoSjMD00_l00002olSTj`03o`000?nW_NWoYkgY00;oYkgY0on8V]h4
o`0000;oGX3L00?o0000odY^e?m:K]@00_m:K]@00ol0003o@VK@od9Vd002od9Vd003o`000?oooooo
oooo00Gooooo0ol0000Fooooo`03o`000?oooooooooo00Wooooo000Kooooo`;o0000=Oooool01Ol0
003oio;BonObd_oWl];o000000;oi?3E00?o0000onCLcOl000001OoLf]@00ol0003obm;Ool_Bg`02
ol_Bg`04o`000?nZ`>WoZ/3Yoj[0j@?o000000GoM9cZo`000?laJ]Wo<F[Io`000004ocaHa@03o`00
0?l]B;co;DRl00;o;DRl00?o0000oeaM^_mLGKX01OmLGKX01?l0003oHFBnof5T__l00004ogia^P03
o`000?n5OL?oQGg300GoQGg300?o0000oiJ5_onFQKl00_nFQKl2o`0000OoWY_A00Co0000ojNOc_nW
WlkoYio>0ol00008ojC8lP03o`000?nRao?oX/Oc00?oX/Oc1?l00002oj;7l`03o`000?nOaO?oWlGc
00CoWlGc0onB4@@3oio5l`04o`000?nN`o;oW/?boik3lPCo00001_nn/ll00ol0003oaKcBolFldP02
olFldP?o00001oo@]/001Ol0003of/C4om[4a?oJa<Co000000Soh<>k00?o0000onoG^_o_ekX01Oo_
ekX01_l0003ok]NkonkG^ol0003olnnko`0000Cokno500Go0000on?YeOl0003og?_Io`000002olST
j`05o`000?nW_NWoYkgYojNmjOl000001?n8V]h01_l0003oM8;CogB2dol0003oGX3Lo`0000CoBVkD
00?o0000od9Vd?m2I]000_m2I]000ol0003oooooooooo`02ooooo`?o00006Oooool00ol0003ooooo
ooooo`09ooooo`006oooool00ol0003oooooooooo`0dooooo`07o`000?oWl];oio;BonObd_l0003o
i?3Eo`000003onCLc@03o`000?oLf]Cog=[D00;og=[D00?o0000ol_Bgoo;d]l00_o;d]l4o`000003
oj[0jOl0003oM9cZ00;oM9cZ0_laJ]T00ol0?L3o0000ocaHa@02ocaHa@03o`000?l]B;co;DRl00;o
;DRl00?o0000oeaM^_mLGKX01?mLGKX01Ol0003oHFBnof5T__mQI;ko000000?oOW6j00?o0000ohEm
`on5OL<01on5OL<01?l0003oUXFoo`000?l00009oijKd@?o00002_nTb?83o`000003oj;7lol0003o
000000?o00000onlSZH00ol0003o[h>Vojn3YP02ojn3YP04o`000?nQNJKo5@00oaD000?o00000_nO
aO<00ol0003oW/?boik3lP06oik3lPCo00000_nn/ll00ol0003oaKcBolFldP05olFldP;o00001?o@
]/000ol0003of/C4om[4a003om[4a003o`000?oP`k_oh<>k00Coh<>k00?o0000oncG_ol000001_o_
ekX00ol0003ok]Nko`000002oo?_^`03o`000?o_klGokno500;okno50_l000000ooLnmWo0000olST
j`02olSTj`05o`000?nW_NWoYkgYojNmjOl000001?n8V]h01?l0003oM8;CogB2domdP]<2o`0000Co
BVkD00?o0000od9Vd?m2I]000_m2I]05o`0001cooooo00?o0000ooooooooool02Oooool001_ooooo
00?o0000ooooooooool0=?ooool01?l0003oio;BonObd_oWl]82o`0000Coi=c=00?o0000omcJe?oL
f]@00ooLf]@00ol0003obm;Oo`000003o`0000?oZ/3Y00_o0000ogBLj_mdW>[oM9cZo`000?laJ]Wo
0000o`0m`?l0003o?5S5o`000005obe8_003obY5^_l0003oG5fj00?oG5fj00?o0000of5T__mQI;h0
0omQI;h00ol0003oOW6jo`00000:ohEm``;o00002OnNVm42o`0000;oYlWb00?o0000ojC8l_nTb?80
1?nTb?85o`0000;oeZNX00Go0000olRJYoo8VZOob9ZWo`000004okb>YP03o`000?n_PjKo[h>V00?o
[h>V00Go0000oj5iY_nQNJKoXGVVo`000004oi1]Y`03o`000?l0N<7o000000?o00001_nN`o82o`00
00[oaKcB0_l000000oo@]/3o0000om[4a006om[4a003o`000?oP`k_oh<>k00;oh<>k00Co0000oncG
_oo/ekoo00001oo_ekX00ol0003olnnkoo?_^`02oo?_^`05o`000?o_klGokno5ono_aOl000000_oL
nmT01?l0003ob>C[olSTjol00004ojNmj@03o`000?n8V]koR9[N00;oR9[N0_l00003ogB2d`;o0000
0om:K]@00ol0003o@VK@od9Vd002od9Vd003o`000?oooooooooo01kooooo00?o0000ooooooooool0
2Oooool001[ooooo00?o0000ooooooooool0=Oooool01Ol0003oio;BonObd_oWl];o000000Goi=c=
00?o0000omcJe?oLf]@00_oLf]@3o`0000?obm;O00?o0000oj[0jOnZ`>T00_nZ`>T01?l0003oM9cZ
ogBLj_l00002oc5Zf@;o03g00_l00004obe8_004o`000?lZAK[o:TFjo`0000?oG5fj00?o0000of5T
__mQI;h01?mQI;h00ol0003oQGg3ohEm``08ohEm``03o`000?nCV=Go000000OoWY_A0_l00005ojO9
lP03o`000?nTb?;oY<Sb00?o00000_oT]jT2o`0000;oeZNX00?o0000olRJYoo8VZL00_o8VZL00ol0
003o_8jVokb>YP02okb>YP03o`000?n_PjKo[h>V00?o[h>V00Go0000oj5iY_nQNJKoXGVVo`000005
oi1]Y`05ogYPZOl0003oNEnXo`000?l0N<400ol00002oik3lP04o`000?nM`O7oWL7aoig1l@;o0000
2Oo5_=82o`0000Sof/C400Go0000on33^ooP`k_oh<>ko`000003oncG_`03o`000?o_ek[okmNj00Co
kmNj00?o0000oo?_^oockk/00_ockk/01Ol0003okno5ono_aOo_klGo000000;og?_I00Co0000olST
joo8i>_o00000onW_NT00ol0003oR9[NohRJgP02ohRJgP04o`000?mdP]?oM8;Co`0000;oM8;C0_mX
M<`01?l0003oBVkDodY^e?l00004od9Vd003o`000?oooooooooo01kooooo00?o0000ooooooooool0
2Oooool001[ooooo0ol0000eooooo`03o`000?oWl];oio;B00;o00001_oTg<d4o`000003omcJe?l0
003obm;O00?obm;O00?o0000oj[0jOnZ`>T00_nZ`>T01ol0003oM9cZogBLj_mdW>[o0000oc5ZfOl0
00000_l0?L000ol0003o;DRlobe8_002obe8_004o`000?lZAK[o:TFjo`0000;oG5fj00?o0000of5T
__mQI;h01OmQI;h00ol0003oQGg3ohEm``07ohEm``05o`000?nCV=GoTiSEoi>HeOl000001?nNVm42
o`0000OoYlWb1?l00004onBgZ@03o`000?oFYjOo000000;o00001?o8VZL00ol0003o_8jVokb>YP02
okb>YP03o`000?n_PjKo[h>V00?o[h>V00?o0000oj5iY_nQNJH00_nQNJH01?l0003oT6fWoi1]Yon@
KJL2o`0000?oNEnX00?o0000oeU=ZOl000000ol00006oig1l@;o00001oo5_=800ol0003oblKFo`00
0008om[4a003o`000?oP`k_o000000Gok=No00?o0000onoG^_o_ekX00_o_ekX2o`0000Colnnk00Co
0000ono_aOo_klGo00000_oLnmT01?l0003ob>C[olSTjol00004ojNmj@03o`000?n8V]koR9[N00;o
R9[N00Co0000ogB2domdP]?oM8;C0_l00003ofQdc003o`000?m:K]Co000000Co@VK@00?o0000oooo
ooooool07oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003oooooooooo`0eooooo`03
o`000?oWl];o000000;oimg;00Co0000onCLcOoTg<goi=c=0ol00004omcJe003o`000?o;d]oobm;O
00?obm;O00Go0000oj[0jOnZ`>WoZ/3Yo`000003ogBLjP03o`000?laJ]Wo000000;o03g000?o0000
obe8_?l]B;`00_l]B;`01ol0003o:TFjobY5^_lZAK[o0000oeaM^_l000001_mQI;h00ol0003oKgG9
o`000006ohEm``;o00001OnCV=D01?l0003oWY_AoijKdOl00006ojO9lP?o00000_obc:T00ol0003o
i;NYonBgZ@02onBgZ@03o`000?oFYjOoeZNW00;oeZNW0_l00003olRJY`03o`000?nlSZKo_8jV00;o
_8jV00?o0000ojn3Y_n_PjH00on_PjH00ol0003oXGVVoj5iYP02oj5iYP06oi1]Yol0003o0000o`00
0?n?KJOo00000omiGjP01Ol0003oFDfYoeU=ZOmICJWo000000;o07WG00?o0000oig1lOnM`O401?nM
`O42o`0000CoaKcB00Go0000ol_6e_o;a]KoblKFo`000008om[4a003o`000?o/ekook=No00Cok=No
00Oo0000onoG^_o_ek[okmNjo`000?odl;Wo000000Colnnk00Co0000ono_aOl0003o00000_oLnmT0
1?l0003ob>C[olSTjol00003ojNmj@03o`000?n8V]koR9[N00?oR9[N00Co0000ogB2domdP]?oM8;C
0_l00004ofQdc0;o00001?m2I]000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo
00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool0=Oooool2o`0000?oimg;1?l00002onCLc@03o`000?oLf]Cog=[D00?o
g=[D00?o0000ol_Bgoo;d]l00_o;d]l00ol0003oZ/3Yoj[0j@02oj[0j@04o`000?mdW>[oM9cZo`00
00;o<F[I00Co0000o`0m`?l0003o00000ol]B;`00ol0003o:TFjobY5^P02obY5^P03o`000?mQI;ko
HFBn00GoHFBn00Co0000ofmebOm_MLWo00001?n5OL<00ol0003oTiSEoi>He@05oi>He@?o00001OnW
bO82o`000003ofkOd_l0003o000000;ol/bY00?o0000onBgZOoT]jT00_oT]jT00ol0003oeZNWomJW
Y`02omJWY`03o`000?o8VJKo000000?o00001?nlSZH00ol0003o[h>Vojn3YP03ojn3YP03o`000?nQ
NJKoXGVV00?o00001?n?KJL00ol0003oNEnXogUOZ002ogUOZ004o`000?mICJWoFDfYoeU=Z@;o932V
0_l0NML2o`0000GoWL7a0_l000000oo5_=;o0000ol_6eP04ol_6eP03o`000?oJa<Cof/C400Gof/C4
00?o0000oncG_oo/ekl01Oo/ekl01_l0003okmNjonoG^_l0003om?2io`0000Colnnk0ol00002omck
f@05o`000?o8i>_ob>C[olSTjol000000onW_NT00ol0003oR9[NohRJgP02ohRJgP03o`000?mdP]?o
M8;C00?oM8;C00?o0000ofQdc?mXM<`00omXM<`00ol0003o@VK@od9Vd002od9Vd003o`000?oooooo
oooo01oooooo00?o0000ooooooooool02?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=Oooool00ol0003oimg;onOMb`03
o`0000Koi=c=00?o0000omcJe?oLf]@00_oLf]@00ol0003obm;Ool_Bg`02ol_Bg`03o`000?nZ`>Wo
Z/3Y00Go000000CoM9cZo`000?laJ]Wo00000_l0?L001Ol08Zko0000obe8_?l]B;co000000Co:TFj
00?o0000of5T__mQI;h01?mQI;h01Ol0003oKgG9ofmebOm_MLWo000000?oQGg300?o0000oi>HeOnC
V=D01OnCV=D01Ol0003oZLW`ojW9l?nYbO3o000000;oYlWb0ol00002oo[UZ@05o`000?obc:Wol/bY
oo;<ZOl000001?oT]jT00ol0003oeZNWomJWY`02omJWY`03o`000?o8VJKob9VV00;ob9VV3_l00002
oj5hYP03o`000?n?KJOoSffW00?oSffW00Go0000ogUOZ?miGjSoNEnXo`000003oeU=Z@;o00000_lY
=Z/00ol0003o07WGo`000006oig1l@03o`000?o;a]KoblKF00GoblKF00?o0000om[4a?oJa<@00ooJ
a<@00ol0003ohmO:o`000006oncG_`03o`000?o_ek[o000000;om?2i00?o0000oo?_^oockk/00_oc
kk/00ol0003og_fko`000002omckf@04o`000?o8i>_ob>C[o`0000CoYkgY00?o0000ohRJg_n8V]h0
0_n8V]h00ol0003oM8;CogB2d`02ogB2d`03o`000?mXM<co000000CoJ7C<00?oI6o9o`000?m2I]00
0_m2I]000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0003ooooo`03oa0@4?oo
oooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0eooooo`?o00000ooW
gL/00ol0003oi=c=onCLc@03onCLc@03o`000?oLf]Cog=[D00;og=[D00?o0000ol_Bgoo;d]l00_o;
d]l3o`0000;oZ[oY00?o0000ofJOlOmVWo400_l000001?laJ]Wo0000o`0m`?l0?L02o`000003obe8
_?l0003o:TFj00Co:TFj00?o=531o`000?mQI;h00omQI;h00ol0003oKgG9ofmeb@03ofmeb@03o`00
0?n5OL?o000000OoTiSE00?o0000ojW9l?nYbO000_nYbO05o`0000?on^FY00Co0000oo;<ZOobc:Wo
00001?oT]jT00ol0003oeZNWomJWY`03omJWY`03o`000?o8VJKob9VV00;ob9VV00?o0000okb>Y_nl
SZH00_nlSZH00ol0003o[h>Vojn3YP03ojn3YP03o`000?nQN:KoXGRV00;oXGRV00?o0000ohm]Yon?
KJL00on?KJL00ol0003oNEnXogUOZ002ogUOZ0CoFDfY00Go0000obTfZolY=Z_o0000o`08V003o`00
0003oig1lOl0003o000000;oWKo`00?o0000ol_6e_o;a]H01Oo;a]H01Ol0003of/C4om[4a?oJa<Co
000000;ohmO:00?o0000oncG_oo/ekl01Oo/ekl00ol0003om?2iooC`^@02ooC`^@04o`000?ockk_o
lnnkoo?_^`;o00000_oLnmT01Ol0003ob>C[olSTjoo8i>_o000000?oYkgY00?o0000ohRJg_n8V]h0
0_n8V]h00ol0003oM8;CogB2d`03ogB2d`03o`000?mXM<co000000?oJ7C<00Co0000ofA_bOmTKlWo
00000_m2I]000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo0003ooooo`03o`00
0?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool3o`0003?ooooo1?l00005onOMb`03o`00
0?oTg<goi=c=00?oi=c=00?o0000omcJe?oLf]@00ooLf]@4o`000003olW9fOl0003oZ[oY00?oZ[oY
00Co0000ofJOlOmVWo7o05WB0_l00002o`0m`004o`000?l08Zko0000o`0000Co:TFj00Co0000ocA@
`OldD<7o00000omQI;h00ol0003oKgG9ofmeb@04ofmeb@;o00001OnCV=D2o`0000CoZLW`00?o0000
ojKgi?l000000ol00002oo[UZ@05o`000?oacJco0000oo;<ZOl000001?oT]jT00ol0003oeZNWomJW
Y`02omJWY`03o`000?o8VJKob9VV00?ob9VV00?o0000okb>Y_nlSZH00_nlSZH00ol0003o[h>Vojn3
YP03ojn3YP03o`000?nQN:KoXGRV00;oXGRV00?o0000ohm]Yon?KJL00on?KJL00ol0003oNEnXogUO
Z002ogUOZ003o`000?mICJWoFDfY00;o00000olY=Z/2o`000003o`00N_lGONKo000000GoWKo`00?o
0000ol_6e_o;a]H01Oo;a]H00ol0003of/C4o`000004on?GbP03o`000?o/ekook=No00Cok=No00?o
0000ooC`^Oodl;T00_odl;T01_l0003olnnkoo?_^ol0003og_fko`0000;og?_I00Go0000olSTjoo8
i>_ob>C[o`000003ojNmj@03o`000?n8V]koR9[N00;oR9[N00?o0000ogB2domdP]<00_mdP]<01Ol0
003oJ7C<ofQdc?mXM<co000000;oJ7C<00Oo0000ofA_bOmTKlWoI6o9o`000?m2I]3o0000027ooooo
00?o0000ooooooooool02?ooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo00?o0000onOMbooWgL/0
0ooWgL/00ol0003oi=c=onCLc@03onCLc@03o`000?oLf]Cog=[D00;og=[D00?o0000olW9fOo9bMT0
0oo9bMT00ol0003oZ[oYojZoj@02ojZoj@06o`000?mVWo7oIYoao`1Id_laJ]Wo00000_l0?L02o`0R
[P03o`000?lZAK[o:TFj00;o:TFj00Co0000ocA@`OldD<7o00000_mQI;h00ol0003oKgG9ofmeb@05
ofmeb@;oQiGK00Go0000oi>HeOnCV=GoTiSEo`000004ojW9l0;o00000_nVmn@3o`0000?on^FY00Go
0000oo7=[?l0003ol/bYo`000004onBgZ@03o`000?oFYjOoeZNW00;oeZNW00?o0000olRIY_o8VJH0
0oo8VJH00ol0003o_8jVokb>YP02okb>YP03o`000?n_PjKo[h>V00?o[h>V00?o0000oj5hY_nQN:H0
0onQN:H00ol0003oSffWohm]Y`03ohm]Y`07o`000?miGjSoNEnXogUOZ?l0003oFDfYo`000002oeaA
[003o`000?lY=Z_o:CJ[00?o000000?o02Vbo`000?lGONH01OnM_o000ol0003oblKFol_6eP05ol_6
eP03o`000?oSel[ohmO:00CohmO:00?o0000oncG_oo/ekl00_o/ekl2o`0000Com?2i00Ko0000oo?_
^ol0003o0000omkm^ol00002omckf@Ko00000_nW_NT01Ol0003oR9[NohRJg_n8V]ko000000GoM8;C
00?o0000ofQdc?mXM<`00_mXM<`2o`0000GoI6o90_l0000Qooooo`03o`000?oooooooooo00Sooooo
0003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0^ooooo`?o00001_ooool00ol0003oimg;onOMb`03onOMb`03o`000?oTg<goi=c=00?oi=c=00Co
0000omcJe?oLf]Cog=[D0_l00006olW9f@03o`000?nZ_nWoZ[oY00;oZ[oY00Go0000ofJOlOmVWo7o
05WBo`000002o`0m`003o`000?l08Zko000000Co:TFj00Oo0000ocA@`OldD<7o=531o`000?mQI;ko
000000KoKgG900Oo0000ohNEfon7UM_oQiGKo`000?nCV=Go000000CoZLW`00Co0000ojKgi?nVmnCo
Y_OT0ol00003oo[UZ@04o`000?oacJcolLf/oo7=[0;o00000ooT]jT00ol0003oeZNWomJWY`03omJW
Y`03o`000?o8VJKob9VV00?ob9VV00?o0000okb>Y_nlSZH00_nlSZH00ol0003o[h>Vojn3YP03ojn3
YP03o`000?nQN:KoXGRV00?oXGRV00?o0000ohm]Yon?KJL00on?KJL01?l0003oNEnXogUOZ?miGjP2
o`0000?oG56/00_o0000obTfZolY=Z_o:CJ[o`000?l08J[o0000o`0Y/_l0003o5ggVo`000004oifo
l003o`000?o;a]KoblKF00?oblKF0_l00006on?GbP07o`000?o/ekook=NooncG_ol0003olNo1o`00
0004ooC`^@?o000000?og_fko`000?oLnmT00ol00002oko/lP03o`000?nW_NWoYkgY00?o00000on8
V]h00ol0003oM8;CogB2d`03ogB2d`03o`000?mXM<coJ7C<00?oJ7C<00?o0000ofA_bOmTKlT01?mT
KlT00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00001?nHV9SooooooiRHV?mg
MgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool3o`0000Wooooo00?o
0000onOMbooWgL/00ooWgL/00ol0003oi=c=onCLc@03onCLc@04o`000?oLf]Cog=[Do`0000;oel_=
00?o0000olW9fOo9bMT01?o9bMT01Ol0003oZ[oYojZojOnZ_nWo000000?oIYoa00Go016Jo`000?l0
?L3o0000o`0R[P02o`0000?o:TFj00?o0000ocA@`OldD<400_ldD<400ol0003oKgG9ofmeb@04ofme
b@03o`000?n7UM_oQiGK00?oQiGK0ol00002ojW9l0Co000000Co^OBYo`000?oYmZCo00000_ojiJT0
0ol0003olLf/oo7=[002oo7=[003o`000?oS^:_o000000;oi;NY00?o0000omJWYooFYjL00ooFYjL0
0ol0003ob9VVolRIYP03olRIYP03o`000?nlSZKo_8jV00;o_8jV00?o0000ojn3Y_n_PjH00on_PjH0
0ol0003oXGRVoj5hYP03oj5hYP03o`000?n?KJOoSffW00?oSffW00Ko0000ogUOZ?miGjSo0000og]R
Zol00004oeaA[00<o`000?lY=Z_o:CJ[obTfZol0003o026Zo`000?l0:K;o0000oooooolGONKo0000
0onM_o001Ol0003oblKFol_6e_o;a]Ko000000;ocm;L00?o0000on?Gb_oSelX01?oSelX01_l0003o
k=NooncG_ol0003olNo1o`0000Com?2i00Co0000omWhY_l0003og_fk0_l000001Onio<ko0000oko/
l_nok?;o000000?oYkgY00?o0000oi:Jf?nBV]P00_l000000on8V]ko0000ogB2d`03ogB2d`03o`00
0?mXM<coJ7C<00?oJ7C<0_l00006ofA_b@03o`000?oooooooooo023ooooo00?o0000ooooooooool0
1oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo
0ol0000=ooooo`03o`000?oWgL_oimg;00?oimg;00?o0000onCLcOoTg<d00ooTg<d2o`0000Coel_=
00?o0000olW9fOo9bMT00oo9bMT00ol0003oZ[oYojZoj@02ojZoj@05o`000?mVWo7oIYoao`000?l0
4IX00_l00002o`0R[P05o`0MZol0003o:TFjobY5^_l000001?ldD<400om>J/oo0000ofmeb@03ofme
b@03o`000?n7UM_oQiGK00CoQiGK00?o0000oj_9kon[bNl00ol00002olWjj0;o000000?ojOJTo`00
0?l000000_ojiJT01Ol0003olLf/oo7=[?oacJco000000?ohkR[00?o0000onBgZOl000001OoFYjL0
0ol0003ob9VVolRIYP02olRIYP03o`000?nlSZKo_8jV00?o_8jV00?o0000ojn3Y_n_PjH01?n_PjH0
0ol0003oXGRVoj5hYP02oj5hYP03o`000?n?KJOoSffW00CoSffW00?oNEnXo`000?mkHZ/00_mkHZ/0
1Ol0003oG56/oeaA[?mLDJco000000?o:CJ[00?o0000o`0QZ_l08JX00_l0:K84o`0000?oWKo`00?o
0000ol_6e_l000001?o?d]`00ol0003ohmO:on?GbP03on?GbP03o`000?o/ekoo000000?olNo100Co
0000ooC`^Oodl;Wom?2i0_l000001OoNoK_o0000okWlc_nio<ko000000;o_ncb00Go0000ojNmjOnW
_NWoYkgYo`000005oi:Jf003o`000?mdP]?oM8;C00?oM8;C00?o0000ofQdc?mXM<`00omXM<`00ol0
003oI6o9o`000004ofA_b@03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool001Wo
oooo0_l0000Vooooo`?o00004?ooool00ol0003oimg;onOMb`03onOMb`03o`000?oTg<goi=c=00?o
i=c=00?o0000omO;cOoGbld01?oGbld00ol0003obLWIolW9f@03olW9f@03o`000?nZ_nWoZ[oY00;o
Z[oY00[o0000ofJOlOmVWo7o0000o`0AV_l0?L3o0000o`0R[_l0003o01f[0_l00005ocA@`@;oCV[?
00Go0000ofmebOm_MLWoKgG9o`000005ohNEf`03o`000?n[bNooZlW_00;oZlW_00Wo0000olWjj?o9
n^So0000onWj`ol0003ojOJTo`000?ogi[<00_l00004oo7=[003o`000?oS^:_ohkR[00;ohkR[0ol0
0003omJWY`03o`000?o8VJKob9VV00?ob9VV00?o0000okb>Y_nlSZH00onlSZH00ol0003o[h>Vojn3
YP04ojn3YP03o`000?nQN:KoXGRV00;oXGRV00?o0000ohm]Yon?KJL00on?KJL2o`0000CoNf:[00Go
0000oeaA[?mLDJcoG56/o`000002obTfZ`03o`000?lgAKCo000000;o026Z0_l00002oc^1i`Ko0000
1Oo?d]`00ol0003ohmO:on?GbP04on?GbP03o`000?oakl7olNo100;olNo100Go0000ooC`^Oodl;Wo
0000omWhYP02o`0000;o^Oc>00Co0000oko/l_nok?;o00000onW_NT00ol0003oTY[Hoi:Jf004oi:J
f003ohB5c?l0003oM8;C00;oM8;C00?o0000ofQdc?mXM<`00omXM<`01Ol0003oI6o9ofA_bOmTKlWo
000000?oI6o900?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0
003oooooooooo`0Sooooo`?o00004oooool00ol0003oimg;onOMb`04onOMb`04o`000?oTg<goi=c=
onCLc@;o00001ooGbld00ol0003obLWIolW9f@03olW9f@03o`000?nZ_nWoZ[oY00;oZ[oY00So0000
ofJOlOmVWo7o0000o`0AV_l0003o02:^o`0000;o01f[00?o0000ocA@`OldD<400_ldD<401ol0003o
CV[?odiZcom>J/oo0000ofmebOl000001On7UM/00ol0003oZlW_oj_9k`02oj_9k`04o`000?o9n^So
bO[Xo`0000;ojO[30_l00002ooOV/`;o00000ooacJ`00ol0003ohkR[on>hZ`03on>hZ`03o`000?oE
Z:WoeJRY00Co00001Oo8VJH00ol0003o_8jVokb>YP03okb>YP03o`000?n_PjKo[h>V00Co[h>V00?o
0000oj5hY_nQN:H00onQN:H00ol0003oSffWohm]Y`02o`000003oi1_ZOl0003oNf:[00?oNf:[00?o
0000oeaA[?mLDJ`00_mLDJ`2obTfZ`03o`000?lgAKCo000000;o026Z00?o0000o`0Y/_l000000_lk
PNL01Ol0003oWKg_oifmkonM_Noo000000Kocm;L00?o0000on?Gb_oSelX00_oSelX2o`0000ColNo1
00?o0000ooC`^Ol000001?l000001Onio<ko0000oko/l_nok?;o000000?oYkgY00?o0000oi:Jf?nB
V]P01?nBV]P01?l0003oQ8G<ohB5c?l00002ogB2d`03o`000?mXM<coJ7C<00?oJ7C<00?o0000ofA_
bOmTKlT00_mTKlT00ol0003oI6o9o`00000Tooooo`03o`000?oooooooooo00Oooooo000Hooooo`03
o`000?oooooooooo023ooooo0ol0000Gooooo`03o`000?oWgL_oimg;00?oimg;00Co0000onCLcOoT
g<go00000_oMblH00ol0003oel_=omO;c@05omO;c@03o`000?o9bMWobLWI00?obLWI00Go0000ojZo
jOnZ_nWoZ[oYo`000002ofJOl@03o`000?l0FM;o000000;o02:^00?o0000o`0MZol000001?ldD<40
0ol0003oCV[?odiZc`02odiZc`;o00001?n7UM/00ol0003oZlW_oj_9k`03oj_9k`03o`000?o9n^So
000000;ojO[30_l00003ooOV/`03o`000?oacJcolLf/00;olLf/00?o0000on>hZooS^:/00ooS^:/0
0ol0003oeJRYomFXZ@03omFXZ@?o00000oo8VJH00ol0003o_8jVokb>YP03okb>YP03o`000?n_PjKo
[h>V00Co[h>V00?o0000oj5hY_nQN:H00onQN:H3o`0000?oT6nY00?o0000og]RZomkHZ/00omkHZ/0
1ol0003oG56/oeaA[?mLDJco0000obTfZol000000_lgAK@00ol0003o026Zo`000002o`0000?o>h7W
00Go0000oifmkonM_NooWKg_o`000005oloBg007o`000?oSel[ohmO:on?Gb_l0003oj>c@o`000004
oo7_`@;o000000Kof?JRo`000?l0003o0000okWlc_l00002oko/lP05o`000?nW_NWoYkgYojNmjOl0
00001_nBV]P00ol0003oQ8G<ohB5c002ohB5c003o`000?mdP]?o000000GoJ7C<00?o0000ofA_bOmT
KlT00_mTKlT00ol0003oI6o9o`00000Tooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`00
0?oooooooooo01gooooo0ol0000Jooooo`03o`000?oWgL_oimg;00?oimg;00?o0000onCLcOl00000
1?oMblH00ol0003oel_=omO;c@05omO;c@03o`000?o9bMWobLWI00;obLWI00?o0000ojZojOnZ_nT0
0_nZ_nT00ol0003oIYoaofJOl@03o`000003o`0R[_l0003o01f[00;o00000oldD<400ol0003oCV[?
odiZc`02odiZc`;oN9CR00Go0000ohNEfon7UM_oQiGKo`000004oj_9k`?o00000ooYn/<2o`0000?o
mnJc00?o0000oo7=[?oacJ`00_oacJ`00ol0003ohkR[on>hZ`02on>hZ`03o`000?oEZ:WoeJRY00Co
eJRY00?o0000olRKZ?o8VjP01?l00005okb>YP03o`000?n_PjKo[h>V00Co[h>V00?o0000oj5hY_nQ
N:H01?l00006oi1_Z@03o`000?mkHZ_oNf:[00;oNf:[00?o0000oeaA[?mLDJ`00_mLDJ`02?l0003o
=dFdocM5]?lgAKCo0000o`0QZ_l0003o64[50_l00002oc^1i`05o`000?nM_NooWKg_oifmkol00000
1_o?d]`00ol0003ohmO:o`000002onS/d003o`000?oakl7olNo100;olNo100?o0000omSfX_l00000
0_l000001Onio<ko0000oko/l_nok?;o000000?oYkgY00?o0000oi:Jf?nBV]P01?nBV]P00ol0003o
Q8G<ohB5c004ohB5c003o`000?mXM<coJ7C<00?oJ7C<00?o0000ofA_bOmTKlT01?mTKlT00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01[ooooo
0ol0000Mooooo`03o`000?oWgL_oimg;00Coimg;00?o0000omg;a_oMblH01?oMblH00ol0003oel_=
omO;c@04omO;c@03o`000?o9bMWobLWI00?obLWI00?o0000ojZojOnZ_nT00_nZ_nT00ol0003oIYoa
ofJOl@04o`0000;o01f[00Go02ngo`000?ldD<7o=531o`000004odiZc`?oN9CR00?o0000ohNEfol0
00001?n[bNl2o`000003omS_h_l0003ojO[300;ojO[300Oo0000ooOV/oogi[?omnJco`000?o^c[?o
000000;olLf/00?o0000on>hZooS^:/00ooS^:/00ol0003oeJRYomFXZ@04omFXZ@03o`000?o8VjSo
b9^X00?ob9^X1?l00002okb>YP04o`000?n_PjKo[h>Vojn3YPKo00000onQNZP00ol0003oT6nYoi1_
Z@04oi1_Z@03o`000?mkHZ_oNf:[00?oNf:[00Go0000oeaA[?mLDJcoG56/o`000004ocM5]0;o0000
0_lHB/D01Ol0003o>h7Woc^1iolkPNOo000000?oWKg_00?o0000oloBg?o?d]`00oo?d]`2o`0000?o
j>c@00Co0000oo7_`Ooakl7olNo10_l000001OoHmZ;o0000o`000?nio<ko000000;o_ncb00Go0000
ojNmjOnW_NWoYkgYo`000006oi:Jf003o`000?n4QLcoQ8G<00CoQ8G<00?o0000ogejaOl000001?mX
M<`00ol0003oI6o9ofA_b@04ofA_b@;o00009?ooool00ol0003oooooooooo`07ooooo`006?ooool2
o`0001Sooooo0ol0000Qooooo`03o`000?oWgL_oimg;00;oimg;0_l00007omg;aP03o`000?oGblgo
el_=00Coel_=00?o0000olW9fOo9bMT00oo9bMT00ol0003oZ[oYojZoj@06o`000004o`0AV_l08Zko
0000o`0MZ`;o00000_ldD<400ol0003oCV[?odiZc`02odiZc`04o`000?mhU>;oN9CRogRDhPCo0000
0_n[bNl01?l0003of>oRomS_h_l00002onWj``;o00000oogi[<01_l0003ok/jconk>/ol0003olLf/
o`0000GohkR[00?o0000omFXZOoEZ:T00ooEZ:T00ol0003ob9^XolRKZ004olRKZ004o`000?nlSjOo
_8nWokb?Y`Ko00000on_Q:L00ol0003oXGZXoj5jZ003oj5jZ003o`000?n@KjWoT6nY00CoT6nY00?o
0000og]RZomkHZ/00omkHZ/01_l0003oG56/oeaA[?l0003oHeZco`0000?o=dFd0_l00003oaQ:a@;o
00000_lkPNL01Ol0003oWKg_oifmkonM_Noo000000;ocm;L0_l000000oo@g^?o0000onS/d002onS/
d003o`000?oakl7olNo100;o000000Gof?JRo`000?l0003o^Oc>o`000002oko/lP05o`000?nW_NWo
YkgYojNmjOl000001_nBV]P00ol0003oQ8G<ohB5c004ohB5c005o`000?mmN/GoOG[5ogejaOl00000
0_mXM<`00ol0003oI6o9ofA_b@04ofA_b@04o`000?ooooooooooo`0002Cooooo00?o0000oooooooo
ool01_ooool001Sooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00Go0000onOMbooWgL_o
img;o`000002omo;a003o`000?oMblKogL_600GogL_600?o0000omO;cOoGbld01?oGbld00ol0003o
bLWIolW9f@03olW9f@;o00001?nZ_nT02?l0003oEjCgoeNTmol04I[o0000o`0MZol0003o02ng0_l0
0005odiZc`05o`000?mhU>;oN9CRogRDh_l000000on]b>d2o`0000?of>oR00Go0000onWj`ol0003o
knK4o`000002ooOV/`03o`000?o^c[?ok/jc00;ok/jc0_l00004on>hZ`03o`000?oEZ:WoeJRY00Co
eJRY00?o0000olRKZ?o8VjP01?o8VjP00ol0003o_8nWokb?Y`03okb?Y`03o`000?n_Q:Oo[hBW00Co
[hBW00?o0000oj5jZ?nQNZP01?nQNZP00ol0003oT6nYoi1_Z@04oi1_Z@03o`000?mkHZ_oNf:[00;o
Nf:[00?o0000oeaA[?l000000_mSF[<00ol0003o=dFdocM5]002ocM5]004o`000?lHB/Go64[5oaQ:
a@;oFH?P0ol00003oifmk`03o`000?o?d]co000000?od=kS00go0000onS/d?oXk=3oj>c@o`000?oa
kl7o0000omck/Ol0003of?JRo`000?nio<ko000000;o_ncb00Go0000ojNmjOnW_NWoYkgYo`000006
oi:Jf003o`000?n4QLcoQ8G<00CoQ8G<00?o0000ogejaOmmN/D00ommN/D00ol0003oJ7C<o`000006
ofA_b@04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000
ooooooooool04_ooool3o`0002Oooooo00Co0000onOMbooWgL_o00001?oObl@00ol0003ogL_6omg;
aP05omg;aP03o`000?oGblgoel_=00Coel_=00Go0000olW9fOo9bMWobLWIo`000002olK0e003o`00
0?nZ_nWoZ[oY00;oZ[oY0_l000001_mGY?Oo0000o`0MZol07J_o0000o`0_]`;o00000om>J/l00ol0
003oN9CRogRDhP02ogRDhP03o`000?n]b>go[LS]00;o[LS]00Ko0000omS_h_oHkn;o0000onWj`ol0
0002onoVa004o`000?ogi[?omnJco`0000Cok/jc00?o0000on6j/?l000000ooS^:/00ol0003oeJRY
omFXZ@04omFXZ@03o`000?o8VjSob9^X00Cob9^X00?o0000okb?YonlSjL00onlSjL00ol0003o[hBW
ojn4Y`04ojn4Y`03o`000?nQNZSoXGZX00CoXGZX00?o0000oi1_ZOn@KjT01?n@KjT00ol0003oNf:[
og]RZ`02og]RZ`;o00001?mSF[<01_l0003o=dFdocM5]?lgAKCoCEk3o`0000;o64[500?o0000oeV3
h?mIPn000_mIPn05o`0000Cod=kS00Co0000onS/d?oXk=3oj>c@0_l000001?oLnk7o0000omSfX_oH
mZ87o`000003ojNmjOl0003oTY[H00GoTY[H00?o0000ohB5c?n4QL`01?n4QL`00ol0003oOG[5ogej
a@05ogeja@03o`000?mTKlWoI6o900GoI6o900Go0000ooooooooooooooooo`00000Sooooo`03o`00
0?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00oooooo0ol0000[ooooo`;o00001_oO
bl@00ol0003ogL_6omg;aP04omg;aP03o`000?oGblgoel_=00Goel_=00?o0000olW9fOl000001?o6
`=@2o`0000CoZ[oY00Ko0000oeNTmol0003o01f[o`000?l0;kL2oaaJd@;o000000?oCV[?o`000?mh
U>800omhU>801Ol0003o[LS]ojg8kOn]b>go000000?of>oR0_l00004onoVa0;o00001?o^c[<01Ol0
003ohKZ`on6j/?oQ^[3o000000;ohkR[00?o0000omFXZOoEZ:T00ooEZ:T00ol0003ob9^XolRKZ004
olRKZ003o`000?nlSjOo_8nW00Co_8nW00?o0000ojn4Yon_Q:L01?n_Q:L00ol0003oXGZXoj5jZ004
oj5jZ003o`000?n@KjWoT6nY00CoT6nY00Oo0000og]RZomkHZ_oNf:[o`000?mnJK3o000000CoHeZc
00Co0000ocM5]?lgAKCo00000_m=G/<00ol0003o64[5o`000004oeV3h0CoW[_]00?o0000om3Nhoo@
g^<00_o@g^<01Ol0003oj>c@onS/d?oXk=3o000000;og?^a00?o0000omSfX_l000000_n^k_L01?l0
003oZ;gYojRmjOnX_NT3o`0000GoTY[H00?o0000ohB5c?n4QL`01?n4QL`00ol0003oOG[5ogeja@06
ogeja@03og]f`_l0003oI6o900CoI6o900?o0000ooooooooool00oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00cooooo0ol0000^oooo
o`03o`000?oOblCogl_400Kogl_400?o0000omg;a_oMblH01?oMblH00ol0003oel_=omO;c@05omO;
c@03o`000?o6`=Coa/3D00Goa/3D00?o0000ojZojOnZ_nT00_nZ_nT4o`0000;o02ng0olLF]42o`00
00?oN9CR00?o0000ojg8kOn]b>d00_n]b>d00ol0003of>oRomS_hP02o`0000GoknK40_l00004onk>
/`03o`000?oQ^[3ohKZ`00;ohKZ`0_l00006omFXZ@03o`000?o8VjSob9^X00Cob9^X00?o0000okb?
YonlSjL01?nlSjL00ol0003o[hBWojn4Y`04ojn4Y`03o`000?nQNZSoXGZX00CoXGZX00?o0000oi1_
ZOn@KjT01?n@KjT01?l0003oNf:[og]RZol00003ogiY/003o`000?mSF[?oHeZc00;oHeZc00?o0000
ocM5]?l000000om=G/<00ol0003o64[5o`000003oeV3h005o`000?nN^ngoW[_]oijkkOl000001?o@
g^<00ol0003oj>c@onS/d002o`0000;og?^a00?o0000omSfX_n^k_L00_l00003ojRmj@05o`000?nJ
Vm?oVY_CoiZKdol000000onBV]P00ol0003oQ8G<ohB5c004ohB5c003o`000?mmN/GoOG[500KoOG[5
00Co0000og]f`_mkM/;o00001?mTKlT00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Oooooo0_l0000:ooooo`?o0000<Oooool00ol0003ogl_4
omo;a006omo;a003o`000?oMblKogL_600GogL_600?o0000omO;cOoGbld00ooGbld00ol0003odKg7
om6ma`07olK0e003o`000?nZ_nWoZ[oY00?oZ[oY00Go0000o`0MZol0003o02ngo`000003oaaJd@;o
00000_mhU>800ol0003o[LS]ojg8k@02ojg8k@?o000000?of]oJo`000?o_i/@01?o_i/@00ol0003o
k/jconk>/`02onk>/`03o`000?oQ^[3ohKZ`00CohKZ`0_l00005omFXZ@03o`000?o8VjSob9^X00Co
b9^X00?o0000okb?YonlSjL01?nlSjL00ol0003o[hBWojn4Y`05ojn4Y`03o`000?nQNZSoXGZX00?o
XGZX00?o0000oi1_ZOn@KjT01On@KjT00omkHZ_o0000ogiY/003ogiY/003o`000?mSF[?oHeZc00;o
HeZc00?o0000ocM5]?l000001?m=G/<00olHB/Go0000oeV3h002oeV3h005o`000?nN^ngoW[_]oijk
kOl000001?o@g^<01?l0003oj>c@o`000?l00002omck/@04o`000?oHmZ;o[^kgo`0000?oZ;gY0_l0
0005oiZKd`03o`000?nBV]So000000KoQ8G<00?o0000ogejaOmmN/D01_mmN/D00ol0003oNgK2og]f
`P02og]f`P04o`000?mTKlWoI6o9o`0000Oooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`005oooool00ol0003oooooooooo`06ooooo`?o0000=Oooool00ol0003ogl_4omo;
a006omo;a003o`000?oMblKogL_600GogL_600Go0000omO;cOoGblgoel_=o`000004om6ma`;o0000
1Oo6`=@2o`0000CoZ[oY00CoSaX0o`000?l0;kOo00000olLF]42ofJDj@?o00000on]b>d2o`0000?o
f]oJ00?o0000onoVa?o_i/@00_o_i/@2o`0000Cok/jc00?o0000on6j/?oQ^[001?oQ^[001?l0003o
e:Z^o`000?l00003omFXZ@03o`000?o8VjSob9^X00Cob9^X00?o0000okb?YonlSjL01?nlSjL00ol0
003o[hBWojn4Y`05ojn4Y`03o`000?nQNZSoXGZX00CoXGZX00?o0000oi1_ZOn@KjT00_n@KjT3o`00
00GoOVV`00?o0000of=J/omSF[<00omSF[<00ol0003oCEk3odeN``04odeN``;o00000_mIPn000ol0
003oW[_]oijkk@02oijkk@04o`000?o@g^?od=kSom3Nh`;o000000Cog_k@o`000?oLnk7og?^a0ol0
0003ojRmj@03o`000?nJVm?oVY_C00GoVY_C0_l00006ohB5c003o`000?mmN/GoOG[500KoOG[500?o
0000og]f`_mkM/801?mkM/800ol0003oI6o9o`000008ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool00oooool3o`0003Wooooo00?o0000
omo;a?oObl@01_oObl@00ol0003ogL_6omg;aP05omg;aP03o`000?oGblgo000000OodKg700?o0000
olK0e?o6`=@01?o6`=@00ol0003oZ[oYojZoj@02ojZoj@04o`00Qol0003o02ngo`0000;o75[A00Co
0000ofJDjOmVU>WoIYCY1Ol00004om[OfP05o`000?o_i/CoknK4onoVa?l000000_oWd;l01Ol0003o
k/jconk>/oo^c[?o000000GohKZ`00?o0000omBZ[_oDZZh00_oDZZh3o`0000Oob9^X00?o0000okb?
YonlSjL01?nlSjL00ol0003o[hBWojn4Y`05ojn4Y`03o`000?nQNZSoXGZX00CoXGZX00?o0000oi1_
ZOl000000_l00002oi9d[P03o`000?mnJK3oOVV`00CoOVV`00Co0000of=J/omSF[?oHeZc0_l00006
odeN``;oL8GH00?o0000oeV3h?l000001?nN^nd00ol0003od=kSom3Nh`02o`0000;og_k@00Co0000
omck/Ol0003o00001?nX_NT00ol0003oVY_CoiZKd`05oiZKd`03o`000?nBRLKo000000GoQ8G<00?o
0000ogejaOmmN/D01_mmN/D00ol0003oNgK2og]f`P06og]f`P03o`000?oooooooooo00Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`005_ooool01?l0003ooooooooooooo
ool3o`0003gooooo00?o0000omo;a?oObl@01_oObl@00ol0003ogL_6omg;aP05omg;aP03o`000?oA
_LOodKg700OodKg700?o0000olK0e?o6`=@01?o6`=@2o`0000?oZ[oY00?o0027o`000?l000000olL
F]400ol0003oIYCYofJDj@04ojk6k003o`000?oJgm[of]oJ00?of]oJ00?o0000onoVa?l000001?oW
d;l00ol0003ok/jco`000006on6j/003o`000?oDZZkoe:Z^00Coe:Z^0ol00004olRKZ003o`000?nl
SjOo_8nW00Go_8nW00?o0000ojn4Yon_Q:L01On_Q:L00ol0003oXGZXoj5jZ002oj5jZ0Co00001_nB
M:h00ol0003oOVV`ogiY/003ogiY/004o`000?mSF[?oHeZco`0000;oKV^n00?o0000odeN`om=G/<0
0_m=G/<01_l0003oL8GHog25f?m`QMSoFH?Po`0000CoW[_]0ol000001?o<jn_o0000omknd?l00002
omck/@04o`000?nX_NWoZ;gYojRmj@;o00001_nJVm<2o`0000?oTXW600Go0000ohB5c?n4QLcoQ8G<
o`000008ogeja@03o`000?mkM/;oNgK200KoNgK200?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Fooooo`Co0000@Oooool00ol0003ogl_4omo;
a005omo;a003o`000?oMblKogL_600GogL_600?o0000omFk`Ol000002?oA_LL2o`0000Koa/3D00Ko
0000ojZojOnZ_nWoZ[oYo`00Qol00003oaaJd@04o`000?mVU>WoIYCYo`0000?o[/K/00?o0000om[O
f_oJgmX00ooJgmX2o`0000Goim2o00?o0000onk>/ol000001_oQ^[000ol0003oe:Z^omBZ[P04omBZ
[P03o`000?o7WJcoaif/00?o000000?ob9^Xo`000?nlSjL01_nlSjL00ol0003o[hBWojn4Y`05ojn4
Y`03o`000?nQNZSo000000;o00000_nROZ`00ol0003oTWB^oi9d[P05oi9d[P03o`000?mnJK3oOVV`
00?oOVV`00?o0000of=J/ol000001?m^Jkh01Ol0003oCEk3odeN`om=G/?o000000CoL8GH1_l00002
olc[j`06o`000?oNo]3og_k@o`000?oLnk7o00000onX_NT00ol0003oVY_CoiZKd`04oiZKd`;o0000
1_nBRLH00ol0003oQ8G<o`000008ogeja@03o`000?mkM/;oNgK200KoNgK200?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Fooooo`?o0000@ooo
ool00ol0003ogl_4omo;a005omo;a003o`000?oMblKogL_600?ogL_600Go0000omFk`OoE^l7oeK_1
o`000009om6ma`03o`000?o6`=Coa/3D00Coa/3D00Go0000ojZojOl0003oZ[oXo`00Q`02o`000003
oaaJdOl0003oIYCY00;oIYCY00Go0000ojk6k?n^a^co[/K/o`000004om[OfP03o`000?oWd;ooim2o
00Goim2o0_l00005on6j/003o`000?oDZZkoe:Z^00Goe:Z^00?o0000olNM[?o7WJ`00oo7WJ`Co`00
00GoXWj/00?o0000oi9d[_nBM:h01OnBM:h00ol0003oOVV`ogiY/003ogiY/0;o00001_m^Jkh01?l0
003oCEk3odeN`ol00004og25f003o`000?nO^^_oWk[[00;oWk[[00Co0000olc[joo<jn_o00000_oN
o]02o`0000;oZ;gY0_l00006oiZKd`03o`000?nBRLKoTXW600KoTXW60_l00008ogeja@03o`000?mk
M/;oNgK200KoNgK200?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00Gooooo000<ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`12
ooooo`03o`000?oOblCogl_400Gogl_400Go0000omg;a_oMblKogL_6o`000005omFk`@;o00002?oA
_LL2o`0000Goa/3D0_l000001_nZ_nSo0000o`0n`?l0?/3o75[Ao`0000?oIYCY00Go0000ojk6k?n^
a^co[/K/o`000003om[OfP;o00001ooWd;l00ol0003og;fjo`000004on6j/003o`000?oDZZkoe:Z^
00Coe:Z^00?o0000olNM[?o7WJ`01Oo7WJ`00ol0003o_9:/okbB[005okbB[003o`000?n_R:co[hR/
00Go[hR/00?o0000oj9n[?nROZ`01OnROZ`00ol0003oTWB^oi9d[P05oi9d[P07o`000?mnJK3oOVV`
ogiY/?l0003oQGFjo`000007ofi[_P;o00001?m`QMP00ol0003oWk[[oinjj`02oinjj`06o`000?o<
jn_oc>_[olc[jol0003og_k@0_l00002ojRmj@03o`000?nJVm?oVY_C00CoVY_C0_l00008oi:9aP03
o`000?n>P<3o000000OoOG[500?o0000og]f`_mkM/801_mkM/800ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`11ooooo`03o`000?oOblCogl_400Kogl_400?o0000omg;a_l00000
2?oE^l400ol0003odKg7om6ma`07om6ma`05o`000?o6`=Coa/3DolK0e?l000000_o2^=03o`0000;o
03k000Go75[Ao`000?mVU>WoIYCYo`000003ojk6k004o`000?oJgm[of]oJo`0000;oeloB00?o0000
onO@_ooWd;l00ooWd;l01?l0003og;fjombm^_oL_KX2o`0000;ohKZ`00?o0000omBZ[_oDZZh01?oD
ZZh00ol0003oaif/olNM[005olNM[003o`000?nlTZco_9:/00Go_9:/00?o0000ojn8[?n_R:`01On_
R:`00ol0003oXWj/oj9n[005oj9n[003o`000?nBM:koTWB^00GoTWB^00Co0000ogiY/?mnJK3o0000
0on5MKX00ol0003oKV^nofi[_P05ofi[_P;o00000om`QMP00ol0003oWk[[oinjj`02oinjj`05o`00
0?o<jn_oc>_[o`000?oNo]000ol000000onX_NWo0000oiZKd`05oiZKd`03o`000?nBRLKoTXW600Ko
TXW60_l00003ohj0`003o`000?mmN/GoOG[500?oOG[500?o0000og]f`_mkM/801_mkM/800ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`11ooooo`03o`000?oOblCogl_400Kogl_4
0_l00009omFk`@;o00002?oA_LL00ol0003oa/3Do`000006ol:hd003o`00Qol0?/3o03k000;o0000
00?oIYCYo`000?n^a^`00on^a^`2o`0000CoeloB00Go0000onO@_ooWd;ooim2oo`000006ombm^P;o
00001ooDZZh00ol0003oaif/olNM[005olNM[003o`000?nlTZco_9:/00Go_9:/00?o0000ojn8[?n_
R:`01On_R:`00ol0003oXWj/oj9n[005oj9n[003o`000?nBM:koTWB^00GoTWB^00?o0000ogiY/?l0
00001?n5MKX00ol0003oKV^nofi[_P04ofi[_P04o`000?n2R=3oPXS@o`0000;oL8GH00Go0000oinj
jonO^^_oWk[[o`000003olc[j`Ko00001OnJVm<2o`0000SoTXW600?o0000ohj0`?n>P<001?n>P<00
1Ol0003oOG[5ogejaOmmN/Go000000SoNgK200?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00[ooooo0_l00012
ooooo`03o`000?oOblCogl_400Gogl_400?o0000omNk__l000002_oE^l400ol0003odKg7om6ma`06
om6ma`;o00001oo2^=002?l008Oo03k0o`000?mBU_3o0000ofJDjOl0003o[/K/0ol00005omO?dP05
o`000?oWd;ooim2oonO@_ol000001ooL_KX2o`0000Koe:Z^00?o0000olNM[?o7WJ`01Oo7WJ`00ol0
003o_9:/okbB[005okbB[003o`000?n_R:co[hR/00Go[hR/00?o0000oj9n[?nROZ`01OnROZ`00ol0
003oTWB^oi9d[P05oi9d[P;o00001_n5MKX00ol0003oKV^nofi[_P02ofi[_P03o`000?n2R=3oPXS@
00;oPXS@0_l00004oinjj`04o`000?o<jn_oc>_[olc[j`Co000000?oXYg@o`000?nJVm<00_nJVm<2
o`0000SoTXW60_l00008ohj0`003o`000?mmN/Go000000SoNgK200?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0@?ooool00ol0003ogl_4omo;a003omo;a004o`000?oG^kkoek^n
omNk_P;o00002OoE^l400ol0003odKg7om6ma`05om6ma`04o`000?o9//?o0000o`0000Ko`[S@00?o
0000o`0n`?l000000_mBU_02o`0000;o[lGZ00?o0000omO?d_oGcm801?oGcm800ol0003oim2oo`00
0008ombm^P03o`000?oA[[Oo000000;o00000ooDZZh00ol0003oaif/olNM[004olNM[003o`000?nl
TZco_9:/00Ko_9:/00?o0000ojn8[?n_R:`01_n_R:`00ol0003oXWj/oj9n[004oj9n[003o`000?nB
M:koTWB^00;oTWB^0ol000000onFO[Ko0000ohEe^P06ohEe^P04o`000?m^JkkoKV^no`0000KoPXS@
0ol00002oinjj`Ko00001?nRWM000ol0003oVY_Co`000009oi:9aP03o`000?n>P<3oSX3000SoSX30
0_l00008og]f`P03o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`04ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo043ooooo00Go
0000omo;a?oOblCogl_4o`000006omNk_P03o`000?oE^l7oeK_100OoeK_10_l00004om6ma`03o`00
0?o9//?obK;300;obK;30ol00004ol:hd005o`000?l0?/3o0000oe:Fl?l000001?n_aNX00ol0003o
eloBomO?dP04omO?dP;o00001ooL_KX00ol0003odJjgom6^]`03om6^]`?o00001oo7WJ`00ol0003o
_9:/okbB[006okbB[003o`000?n_R:co[hR/00Ko[hR/00?o0000oj9n[?nROZ`01OnROZ`4o`0000Go
UWjf00?o0000ohEe^_n5MKX01?n5MKX00ol0003oKV^no`000007oh:8d003o`000?nQ^N[oXKWZ00?o
00000_nolo42o`0000GoXYg@0_l00009oi:9aP03o`000?n>P<3oSX3000SoSX3000?o0000oham_Ol0
00001omkM/800ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01?ooool000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`10ooooo`03o`00
0?oOblCo000000Soek^n0_l00009omFk`@04o`000?oA_LOodKg7o`0000SobK;30_l00003ol:hd005
o`000?l0?/3o0000oe:Fl?l000001?n_aNX00ol0003oeloBomO?dP03omO?dP04o`000?o@`/co0000
o`0000Gog;fj00?o0000om6^]ooA[[L01OoA[[L3o`0000Goaif/00?o0000okbB[?nlTZ`01_nlTZ`0
0ol0003o[hR/ojn8[006ojn8[003o`000?nROZcoXWj/00?oXWj/0ol00008oiIn]P03o`000?n5MK[o
QGFj00CoQGFj0_l00007oh:8d003o`000?nQ^N[oXKWZ00;oXKWZ00Co0000okoclOnolo7o00001?nR
WM03o`000003oif>`ol0003oTXW600KoTXW60_l00009ohj0`0;o00000on<OKd00ol0003oNgK2og]f
`P03og]f`P03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`04ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000@Oooool2o`0000[oek^n00?o0000
omFk`OoE^l401ooE^l400ol0003odKg7o`00000:olVb``;o00000_o2^=02o`0000;oDYK`00?o0000
ojo5j_n_aNX00_n_aNX01Ol0003oeloBomO?d_oGcm;o000000Cod<;<00Go0000ombm^_oL_K[og;fj
o`000008om6^]`03o`000?o6X[CoaZ:d00Co000000?oaif/o`000?nlTZ`01onlTZ`00ol0003o[hR/
ojn8[006ojn8[003o`000?nROZco000000?o00000_nTQ[@00ol0003oUWjfoiIn]P07oiIn]P03o`00
0?n5MK[oQGFj00;oQGFj00Co0000oi2<bon@S<_o00001On2R=000ol0003oXKWZoj6ijP02oj6ijP04
o`000?nolo7o_o?ao`0000?oXYg@0_l00005oif>``03o`000?nBRLKoTXW600?oTXW600?o0000ohj0
`?n>P<002?n>P<000ol0003oS7fmoham_@03oham_@03o`000?mkM/;oNgK200;oNgK200?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000Rooooo`03
o`000?oooooooooo043ooooo00?o0000omNk__oG^kh02?oG^kh00ol0003oeK_1omFk`@07omFk`@03
o`000?o9//?obK;300_obK;30_l00002ol:hd004o`000?mBU_3oDYK`o`0000Co[lGZ00?o0000omO?
d_l000001_o@`/`2o`000003ombm^_l0003odJjg00OodJjg00?o0000olJR]?o6X[@01?o6X[@7o`00
00?o_9:/00?o0000ojn8[?n_R:`00_n_R:`6o`0000KoY8Jd00?o0000oiIn]_nFO[H01onFO[H00ol0
003oQGFjohEe^P02o`0000CoT8c;00Go0000oh:8d?n2R=3oPXS@o`000004oj6ijP05o`000?nolo7o
_o?ao`000?nRWM000ol00008oif>``03o`000?nBRLKoTXW600;o00002On>P<02o`0000OoS7fm00Co
0000og]f`_mkM/;o00007oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
000Sooooo`03o`000?oooooooooo043ooooo0_l00009omNk_P;o00001ooE^l400ol0003oc:nmo`00
0002o`0000_obK;31ol00002ojo5jP?o00002Oo@`/`2o`0000OodJjg00?o0000olJR]?o6X[@01_o6
X[@00ol0003o^iRcok^H/`03ok^H/`So00001?n`Sk<00ol0003oY8JdojB6]006ojB6]003o`000?nF
O[KoUWjf00KoUWjf00?o0000ohEe^_l000001on@S</00ol0003oPXS@o`000004oj6ijP03o`000?no
lo7o_o?a00?o00002onMS/<00ol0003oTXW6o`000009ohj0`0;o00002On<OKd00ol0003oNgK2o`00
000Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002Cooooo0_l00012
ooooo`03o`000?oG^kkoek^n00Soek^n00?o0000omFk`OoE^l400ooE^l400ol0003oc:nmolb__@03
olb__@;o00003?o9//<2o`000004oc^Hl_l0003o0000o`0000Co[l?Y00?o0000om32c?o@`/`01Oo@
`/`01?l0003obKK7o`000?l00005om6^]`03o`000?o6X[CoaZ:d00KoaZ:d00?o0000ok^H/onkV;<0
1_nkV;<00ol0003o/8ncok2?/`06ok2?/`03o`000?nTQ[CoY8Jd00KoY8Jd00?o0000oiIn]_nFO[H0
1_nFO[H2o`0000SoT8c;1?l00002oj6ijP04o`000?nolo7o_o?ao`0000koWHk30_l00009ohj0`003
o`000?n<OKgoS7fm00WoS7fm0_l0000Rooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01?ooool002Kooooo00?o0000ooooooooool0@?ooool00ol0003oek^nomNk_P08omNk_P;o0000
0_oE^l400ol0003oc:nmolb__@06olb__@;o00003?o9//<2o`0000;o>iSb1On_`nT2o`0000Cod<;<
00?o0000olVfaoo9]/L00_o9]/L2o`0000?odJjg00?o0000olJR]?o6X[@01_o6X[@00ol0003o^iRc
ok^H/`06ok^H/`03o`000?n`Sk?o/8nc00Ko/8nc00?o0000ojB6]?nTQ[@01_nTQ[@00ol0003oUWjf
oiIn]P04oiIn]P;o000000?oW977o`000?n@S</01_n@S</00ol0003oXkWXoj>ij002oj>ij0Go0000
3?nMS/<3o`000003oi^6_?l0003oSX3000KoSX300_l0000;oham_@03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`009oooool00ol0003ooooooooo
o`10ooooo`;o00002_oG^kh00ol0003oeK_1o`00000:olb__@?o00002Oo9//<00ol0003o`ZS1ol:X
`@02oc^HlP03o`000?n_`nWo[l?Y00?o[l?Y00Co0000om32c?o@`/co00001oo9]/L3o`0000SoaZ:d
00?o0000ok^H/onkV;<01onkV;<00ol0003o/8ncok2?/`06ok2?/`03o`000?nTQ[CoY8Jd00KoY8Jd
00Co0000oiIn]_nFO[KoUWjf0ol00004oibAa`03o`000?n@S<_oT8c;00;oT8c;0_l00004oj>ij004
o`000?nUlo;oYO?bo`0000_oWHk30ol00005oi^6_003o`000?n>P<3oSX3000?oSX3000?o0000oham
_On<OKd02On<OKd2o`0002Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03oooo
o`00:?ooool00ol0003oooooooooo`11ooooo`03o`000?oG^kkoek^n00Soek^n00?o0000olb__Oo<
[kd03?o<[kd2o`0000KobK;300?o0000ol:X`Oo2Z<400_o2Z<401?l0003o>iSbo`000?l00004ojo3
j@03o`000?o@`/co000000WobKK70ol00006olJR]003o`000?nkV;?o^iRc00Oo^iRc00?o0000ok2?
/on`Sk<01on`Sk<00ol0003oY8JdojB6]006ojB6]0?o00002?nLTLL01?l0003oT8c;oi2<bol00004
oj>ij0;o000000?oYO?bo`000?l000002OnMS/<3o`0000WoVhJl00?o0000ohj0`?n>P<000_l0000;
oham_@03o`000?oooooooooo02Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`00:Oooool2o`0004;ooooo0_l00008omNk_P03o`000?o=[[[o000000;o00003?o<[kd2o`00
00CobK;300?o0000ol:X`Oo2Z<401?o2Z<400ol0003o>iSbo`000003ojo3j@;o00002_o9]/L00ol0
003o`Jc5ol6/a@05o`000003olJR]?l0003o^iRc00So^iRc00?o0000ok2?/on`Sk<01on`Sk<00ol0
003oY8JdojB6]004ojB6]0?o00002_nLTLL00ol0003oT8c;o`000004oj>ij006o`000?nUlo;oYO?b
o`000?nXTl3o00001onMS/<2o`0000coVhJl00?o0000ohj0`?l000002on<OKd2o`0002_ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`11
ooooo`03o`000?oG^kkoek^n00Coek^n00?o0000olf^^_o=[[X00oo=[[X2o`0000coc:nm0ol00000
0oo9//?o0000ol:X`@06ol:X`@05o`000?lkV?;o0000ojo3jOl000000on^`NL2o`0000KobKK700?o
0000ol6/aOo1[<D01_o1[<D7o`0000Co^iRc00?o0000ok2?/on`Sk<01on`Sk<00ol0003oY8Jdo`00
0004o`0000;oYiK400?o0000oibAaonLTLL01onLTLL3o`0000?oXkWX0_l000000onUlo;o0000o`00
0002ojRC`003o`000?nMS/?oWHk300;oWHk30ol0000>oi^6_0;o00002_n<OKd2o`0002kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`11
ooooo`03o`000?oG^kkoek^n00?oek^n00?o0000olf^^_o=[[X01Oo=[[X3o`0000coc:nm00?o0000
ol:X`Oo2Z<402?o2Z<400olXVnko0000ojk1i`05ojk1i`?o00000oo9]/L00ol0003o`Jc5ol6/a@07
ol6/a@03o`000?niY<?o^JC300?o^JC34?l00008ojNFa003o`000?nLTLOoW97700?oW9770ol00003
ojJii`03o`000?nS^NSo000000;oYO?b00?o0000ojRC`?nXTl000_nXTl000ol0003oWHk3o`000002
o`0000koVhJl0ol000000onJQ;[o0000oham_@08oham_@03o`000?oooooooooo02oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003oooooooooo`11oooo
o`;o00000_oG^kh00ol0003ocJjjolf^^P09olf^^P;o00002_o<[kd00ol0003o`jFjol>U^P04o`00
00Ko`ZS10ol00006ojk1i`;o000000?obKK7o`000?o1[<D02?o1[<D00ol0003o^JC3okVT``07okVT
``03o`000?n`W<?o/9c300Oo/9c300?o0000ojNFa?nWU/@01onWU/@00ol0003oW977oibAa`03o`00
00KoY[WW1Ol00004ojRC`0?o00003onKQ[`2o`0000GoVXBj00?o0000oham_On<OKd01?n<OKd2o`00
03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;_ooool2o`0004?o
oooo00?o0000omNk__l000003Oo=[[X3o`0000Koc:nm00?o0000ol>U^_o3YKX01Oo3YKX5o`0000?o
`ZS11?l00005ojk1i`04o`000?o1[<Go0000o`0000Ko`Jc500?o0000okVT`oniY<<02?niY<<00ol0
003o/9c3ok2L``07ok2L``03o`000?nWU/CoYiK400KoYiK41?l00006ojJii`Ko000000?oZ9?0o`00
0?l000000ol00002ojJ=^P03o`000?nKQ[coVhJl00[oVhJl0ol00007oiZ4^P03o`000?n<OKgoS7fm
00?oS7fm00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo000`ooooo`03o`000?oooooooooo047ooooo0_l0000@olf^^P;o00001?o<[kd00ol0003o
`jFjol>U^P0:ol>U^PCo000000?o`ZS1o`000?lXVnh00_l000000on^`NOo0000ojfni`04ojfni`Go
000000?o`Jc5o`000?niY<<02OniY<<00ol0003o/9c3ok2L``08ok2L``03o`000?nWU/CoYiK400;o
YiK40ol00002ojRji`03o`000?nV^NOoY[WW00?oY[WW2Ol00008ojJ=^P03o`000?nKQ[coVhJl00Oo
VhJl0_l0000;oiZ4^P03o`000?n<OKgoS7fm00;o0000=oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo000aooooo`03o`000?oooooooooo04;ooooo0ol0000?olf^^P?o0000
00?oc:nmo`000?o3YKX03oo3YKX6o`0000_o[KkW2?l00004okVT``03o`000?n`W<?o/9c300So/9c3
00?o0000ojNFa?l000000_l00006ojRji`03o`000?nV^NOo000000Oo00003?nVSKX00ol0003oVhJl
oi^6_004oi^6_0?o00003OnJQ;X00ol0003oS7fmo`00000iooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool003;ooooo00?o0000ooooooooool0A?ooool3o`0000oocJjj00?o
0000ol>U^_o3YKX04oo3YKX2o`0000;o7Z3U1?l00006ojfni`03o`000?n[_NKoZkgV00CoZkgV4Ol0
0007ojRji`So00004?nVSKX00ol0003oVhJloi^6_002oi^6_0;o00004?nJQ;X2o`0003_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00<oooool2o`0004Oooooo0_l0000=
olf^^P03o`000?o4XkSoa:>h00Co00004?o3YKX00ol0003o^YbiokZL^@03okZL^@03oajPiOl0003o
000000;o000000?o[KkWo`000?n[_NH02_n[_NH00ol0003oZ[_VojZkiP08ojZkiP04o`000?nX^^Oo
Z;[WojRji`So00005_nVSKX4o`0000ooVXBj0ol0000nooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0A_ooool3o`0000WocJjj00?o0000
olBS^?o4XkP01Oo4XkP3o`0000go`jFj00?o0000okZL^OnjW;T01onjW;T3o`0000;oZkgV1?l00005
oj^miP03o`000?nZ^nKoZ[_V00?oZ[_V2_l00005ok6D^@03o`000?nVSK[oYXfj01;oYXfj1?l0000?
oiZ4^P?o0000@_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000foooo
o`03o`000?oooooooooo04Sooooo0_l00007olf^^P03o`000?o4XkSoa:>h00Soa:>h1?l00009ol>U
^P03o`000?njW;Wo^Ybi013o^Ybi3?l0000>ok6D^@03o`000?nVSK[oYXfj00coYXfj1_l00003ojJ;
^003o`000?nJQ;[oVXBj00[oVXBj0ol00015ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool003Oooooo00?o0000ooooooooool0BOooool3o`0000CocJjj00?o0000olBS^?o4
XkP03?o4XkP4o`0000Co`jFj00?o0000okZL^OnjW;T05OnjW;T00ol0003o/IBiok6D^@0Dok6D^@03
o`000?nVSK[oYXfj00KoYXfj1Ol00009ojJ;^003o`000?nJQ;[oVXBj00SoVXBj0_l00019ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool003Sooooo0_l0001<ooooo`Co0000
4oo4XkP3o`000003ol>U^_l0003o^Ybi01Ko^Ybi00?o0000ok6D^OnaU;T05?naU;T00ol0003oYXfj
ojJ=^P06o`0000koYX^h00?o0000oiZ4^_nJQ;X01OnJQ;X3o`0004cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`01ooooo`00>_ooool00ol0003oooooooooo`1<ooooo`03o`000?o4
XkSoa:>h01Coa:>h0_l00002okZL^@Co00004?njW;T00ol0003o/IBiok6D^@0?ok6D^@Wo00005OnV
RkP01?l0003oVXBjoiZ4^_nJQ;X3o`00053ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00>oooool00ol0003oooooooooo`1>ooooo`Co00004Oo4XkP00ol0003o^YZgokZJ
]`04okZJ]`_o00001OnjW;T00ol0003o/IBiok6D^@03ok6D^@co00001_naT[L00ol0003oYX^hojJ;
^00EojJ;^0Co0000Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000l
ooooo`;o0000D_ooool4o`0000goa:>h00?o0000okZJ]onjV[L03onjV[L;o`0001;o/I:g00?o0000
ojJ;^?nVRkP04onVRkP3o`0005Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01
ooooo`00?_ooool00ol0003oooooooooo`1Cooooo`?o00002_o4XkP00ol0003o^YZgokZJ]`0DokZJ
]`03o`000?naT[Oo/I:g01Go/I:g00?o0000ojJ;^?nVRkP03_nVRkP5o`0005_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooo000000?o00001Oo4XkP00ol0003o^YZgokZJ]`0EokZJ]`03o`000?naT[Oo/I:g01Ko
/I:g00?o0000ojJ;^?nVRkP02?nVRkP5o`00067ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00?ooooo
1?l000000oo4XkSo0000okZJ]`0FokZJ]`03o`000?naT[Oo/I:g01Ko/I:g00?o0000ojJ;^?nVRkP0
1?nVRkP4o`0006Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Ooo
ool2o`0005;ooooo00?o0000ooooooooool01oooool2o`0000;o^YZg1?l0000AokZJ]`03o`000?na
T[Oo/I:g01Ko/I:g00?o0000ojJ;^?l000001?l0001[ooooo`03o`000?oooooooooo00Sooooo0Ol0
0001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03oooool<
o`0000Go^YZg00?o0000ok6B]onaT[L02_naT[L>o`00077ooooo00?o0000ooooooooool01oooool1
o`00007ooooo0Oooool004Cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Koooo
oa;o0000P?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00AOooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01_ooool1o`00007o
oooo0Oooool004Kooooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0
1Oooool1o`00007ooooo0Oooool004Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`2_ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`00B_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0;3ooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo001;ooooo`;o0000B?ooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`00COooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001>ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`02ooooo`7o00000Ooo
ool004oooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2cooooo`05o`000?oooooo
ooooooooool000000Oooool0053ooooo0_l00013ooooo`03o`000?oooooooooo0;Cooooo00Co0000
oooooooooooo00000Oooool005;ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2e
ooooo`03o`000?oooooo0000007ooooo001Cooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0]Oooool00ol0003oooooooooo`01o`000000E?ooool2o`0003oooooo00?o0000oooooooo
ool0]_ooool1o`00007ooooo0Ol0000005Kooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`2gooooo`;o0000001Gooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0]_oo
ool3o`000000F?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0;;ooooo1?l00003
ooooo`00FOooool2o`0003[ooooo00?o0000ooooooooool0[_ooool4o`0000Oooooo001Kooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo001Looooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0Y_ooool4o`0000oooooo001Mooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0X_ooool4o`0001?ooooo001Nooooo`;o0000=Oooool0
0ol0003oooooooooo`2Nooooo`Co00005oooool0063ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`2Jooooo`Co00006oooool0067ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`2Hooooo`?o00007oooool006;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2Dooooo`Co00008_ooool006?ooooo0_l0000_ooooo`03o`000?oooooooooo093ooooo1?l0
000Vooooo`00IOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08cooooo1?l0000Z
ooooo`00I_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Sooooo1?l0000^oooo
o`00Ioooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Cooooo1?l0000booooo`00
J?ooool2o`0002[ooooo00?o0000ooooooooool0P?ooool4o`0003Kooooo001Zooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0O?ooool4o`0003[ooooo001[ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0N?ooool4o`0003kooooo001/ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0M?ooool4o`0004;ooooo001]ooooo`;o00009Oooool00ol0003o
ooooooooo`1`ooooo`Co0000A_ooool006oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`1/ooooo`Co0000B_ooool0073ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1Xooooo`Co0000C_ooool0077ooooo0_l0000Qooooo`03o`000?oooooooooo06Cooooo1?l0001B
ooooo`00Loooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo063ooooo1?l0001Foooo
o`00M?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05cooooo1?l0001Jooooo`00
MOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Wooooo0ol0001Nooooo`00M_oo
ool2o`0001cooooo00?o0000ooooooooool0EOooool4o`00067ooooo001hooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0DOooool4o`0006Gooooo001iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0COooool4o`0006Wooooo001jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0BOooool4o`0006gooooo001kooooo`;o00005oooool00ol0003ooooo
ooooo`15ooooo`Co0000LOooool007gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`11ooooo`Co0000MOooool007kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0m
ooooo`Co0000NOooool007oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0ioooo
o`Co0000OOooool0083ooooo0_l0000Booooo`03o`000?oooooooooo03Gooooo1?l00021ooooo`00
P_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo1?l00025ooooo`00Pooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo1?l00029ooooo`00Q?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo1?l0002=ooooo`00QOooool2o`00
00cooooo00?o0000ooooooooool09_ooool4o`00097ooooo0027ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08_ooool4o`0009Gooooo0028ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07_ooool4o`0009Wooooo0029ooooo`;o00002?ooool00ol0003ooooooooo
o`0Kooooo`?o0000WOooool008_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0G
ooooo`Co0000X?ooool008cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Coooo
o`Co0000Y?ooool008gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`Co
0000Z?ooool008kooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo1?l0002/ooooo`00T?oo
ool01?l0003oooooooooool00009ooooo`Co0000/?ooool0097ooooo00?o0000ooooool000001Ooo
ool4o`000;Cooooo002Booooo`;o000000?oooooo`000?l000000_l0002hooooo`00Toooool2o`00
0;cooooo003ooooooe;ooooo003ooooooe;ooooo003ooooooe;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .64096 m .51694 .65827 L .43899 .65168 L p .728 .619 .736 r
F P
0 g
s
.51694 .65827 m .51727 .64096 L .59242 .63676 L p .692 .589 .736 r
F P
0 g
s
.59242 .63676 m .59527 .65394 L .51694 .65827 L p .692 .589 .736 r
F P
0 g
s
.43899 .65168 m .4425 .63457 L .51727 .64096 L p .728 .619 .736 r
F P
0 g
s
.5176 .62453 m .51727 .64096 L .4425 .63457 L p .727 .625 .745 r
F P
0 g
s
.51727 .64096 m .5176 .62453 L .58957 .62047 L p .692 .596 .744 r
F P
0 g
s
.58957 .62047 m .59242 .63676 L .51727 .64096 L p .692 .596 .744 r
F P
0 g
s
.4425 .63457 m .44599 .61834 L .5176 .62453 L p .727 .625 .745 r
F P
0 g
s
.51793 .61026 m .5176 .62453 L .44599 .61834 L p .722 .643 .769 r
F P
0 g
s
.5176 .62453 m .51793 .61026 L .58677 .60633 L p .692 .618 .769 r
F P
0 g
s
.58677 .60633 m .58957 .62047 L .5176 .62453 L p .692 .618 .769 r
F P
0 g
s
.59527 .65394 m .59242 .63676 L .66427 .62209 L p .654 .563 .74 r
F P
0 g
s
.66427 .62209 m .67023 .63881 L .59527 .65394 L p .654 .563 .74 r
F P
0 g
s
.59242 .63676 m .58957 .62047 L .65834 .60628 L p .656 .571 .748 r
F P
0 g
s
.65834 .60628 m .66427 .62209 L .59242 .63676 L p .656 .571 .748 r
F P
0 g
s
.4425 .63457 m .43899 .65168 L .36521 .63435 L p .762 .652 .741 r
F P
0 g
s
.44599 .61834 m .44945 .60429 L .51793 .61026 L p .722 .643 .769 r
F P
0 g
s
.51825 .59919 m .51793 .61026 L .44945 .60429 L p .71 .679 .819 r
F P
0 g
s
.51793 .61026 m .51825 .59919 L .584 .59542 L p .688 .661 .818 r
F P
0 g
s
.584 .59542 m .58677 .60633 L .51793 .61026 L p .688 .661 .818 r
F P
0 g
s
.58957 .62047 m .58677 .60633 L .65249 .59265 L p .659 .596 .773 r
F P
0 g
s
.65249 .59265 m .65834 .60628 L .58957 .62047 L p .659 .596 .773 r
F P
0 g
s
.36521 .63435 m .37179 .61777 L .4425 .63457 L p .762 .652 .741 r
F P
0 g
s
.44599 .61834 m .4425 .63457 L .37179 .61777 L p .759 .658 .75 r
F P
0 g
s
.37179 .61777 m .37834 .6021 L .44599 .61834 L p .759 .658 .75 r
F P
0 g
s
.44945 .60429 m .44599 .61834 L .37834 .6021 L p .751 .672 .774 r
F P
0 g
s
.58677 .60633 m .584 .59542 L .64673 .58226 L p .664 .646 .822 r
F P
0 g
s
.64673 .58226 m .65249 .59265 L .58677 .60633 L p .664 .646 .822 r
F P
0 g
s
.44945 .60429 m .45284 .59345 L .51825 .59919 L p .71 .679 .819 r
F P
0 g
s
.51856 .59203 m .51825 .59919 L .45284 .59345 L p .662 .745 .911 r
F P
0 g
s
.51825 .59919 m .51856 .59203 L .58129 .58842 L p .661 .744 .911 r
F P
0 g
s
.58129 .58842 m .584 .59542 L .51825 .59919 L p .661 .744 .911 r
F P
0 g
s
.37834 .6021 m .38481 .58862 L .44945 .60429 L p .751 .672 .774 r
F P
0 g
s
.45284 .59345 m .44945 .60429 L .38481 .58862 L p .729 .701 .823 r
F P
0 g
s
.584 .59542 m .58129 .58842 L .64109 .57582 L p .659 .743 .912 r
F P
0 g
s
.64109 .57582 m .64673 .58226 L .584 .59542 L p .659 .743 .912 r
F P
0 g
s
.38481 .58862 m .39116 .57839 L .45284 .59345 L p .729 .701 .823 r
F P
0 g
s
.45618 .58653 m .45284 .59345 L .39116 .57839 L p .663 .746 .912 r
F P
0 g
s
.45284 .59345 m .45618 .58653 L .51856 .59203 L p .662 .745 .911 r
F P
0 g
s
.51887 .58904 m .51856 .59203 L .45618 .58653 L p .427 .787 .996 r
F P
0 g
s
.45945 .58379 m .51887 .58904 L p .47411 .58725 L .427 .787 .996 r
F P
0 g
s
.45618 .58653 m .45945 .58379 L p .47411 .58725 L .427 .787 .996 r
F P
0 g
s
.40352 .57004 m .45945 .58379 L p .41522 .57547 L .403 .746 .993 r
F P
0 g
s
.39739 .57211 m .40352 .57004 L p .41522 .57547 L .403 .746 .993 r
F P
0 g
s
.40352 .57004 m .35421 .54833 L p .3852 .56154 L 0 .39 .745 r
F P
0 g
s
.45945 .58379 m .40352 .57004 L p .43657 .57839 L .234 0 0 r
F P
0 g
s
.45945 .58379 m .45618 .58653 L .39739 .57211 L p .403 .746 .993 r
F P
0 g
s
.40956 .57193 m .46269 .58499 L p .41512 .57297 L .234 0 0 r
F P
0 g
s
.40352 .57004 m .40956 .57193 L p .41512 .57297 L .234 0 0 r
F P
0 g
s
.40956 .57193 m .40352 .57004 L p .3852 .56154 L 0 .39 .745 r
F P
0 g
s
.40352 .57004 m .39739 .57211 L .34548 .54932 L p .406 .711 .985 r
F P
0 g
s
.34548 .54932 m .35421 .54833 L .40352 .57004 L p .406 .711 .985 r
F P
0 g
s
.36281 .55134 m .40956 .57193 L p .3651 .55297 L 0 .39 .745 r
F P
0 g
s
.35421 .54833 m .36281 .55134 L p .3651 .55297 L 0 .39 .745 r
F P
0 g
s
.32536 .52411 m .36281 .55134 L p .32411 .52586 L 0 .435 .853 r
F P
0 g
s
.31459 .51958 m .32536 .52411 L p .32411 .52586 L 0 .435 .853 r
F P
0 g
s
.32536 .52411 m .29994 .49158 L p .327 .52182 L 0 .256 .759 r
F P
0 g
s
.36281 .55134 m .32536 .52411 L p .3598 .54919 L .421 0 0 r
F P
0 g
s
.36281 .55134 m .35421 .54833 L .31459 .51958 L p 0 .435 .853 r
F P
0 g
s
.33605 .53193 m .37136 .5576 L p .33083 .52809 L .421 0 0 r
F P
0 g
s
.32536 .52411 m .33605 .53193 L p .33083 .52809 L .421 0 0 r
F P
0 g
s
.33659 .55456 m .34548 .54932 L .39739 .57211 L p .664 .748 .912 r
F P
0 g
s
.37994 .56592 m .37136 .5576 L .33605 .53193 L p .588 .042 0 r
F P
0 g
s
.33605 .53193 m .3122 .50131 L p .34212 .5364 L 0 .118 .646 r
F P
0 g
s
.34675 .54182 m .37994 .56592 L p .33714 .53278 L .588 .042 0 r
F P
0 g
s
.33605 .53193 m .34675 .54182 L p .33714 .53278 L .588 .042 0 r
F P
0 g
s
.35421 .54833 m .34548 .54932 L .30365 .5191 L p .428 .681 .969 r
F P
0 g
s
.30365 .5191 m .31459 .51958 L .35421 .54833 L p .428 .681 .969 r
F P
0 g
s
.39739 .57211 m .39116 .57839 L .33659 .55456 L p .664 .748 .912 r
F P
0 g
s
.38862 .57473 m .37994 .56592 L .34675 .54182 L p .612 .068 0 r
F P
0 g
s
.34675 .54182 m .35756 .55221 L .38862 .57473 L p .612 .068 0 r
F P
0 g
s
.34675 .54182 m .32446 .51314 L p .35673 .55122 L 0 .094 .625 r
F P
0 g
s
.35756 .55221 m .34675 .54182 L p .35673 .55122 L 0 .094 .625 r
F P
0 g
s
.34675 .54182 m .33605 .53193 L p .34212 .5364 L 0 .118 .646 r
F P
0 g
s
.33605 .53193 m .32536 .52411 L p .327 .52182 L 0 .256 .759 r
F P
0 g
s
.37136 .5576 m .36281 .55134 L p .3598 .54919 L .421 0 0 r
F P
0 g
s
.40956 .57193 m .36281 .55134 L p .40228 .57057 L .555 0 0 r
F P
0 g
s
.39116 .57839 m .39739 .57211 L .45618 .58653 L p .663 .746 .912 r
F P
0 g
s
.41558 .57705 m .40956 .57193 L p .40228 .57057 L .555 0 0 r
F P
0 g
s
.46269 .58499 m .45945 .58379 L p .43657 .57839 L .234 0 0 r
F P
0 g
s
.51887 .58904 m .45945 .58379 L p .49274 .58723 L .21 0 0 r
F P
0 g
s
.51856 .59203 m .51887 .58904 L p .53568 .59019 L .477 .83 .996 r
F P
0 g
s
.51918 .58997 m .51887 .58904 L p .49274 .58723 L .21 0 0 r
F P
0 g
s
.51887 .58904 m .57862 .58559 L p .53568 .59019 L .477 .83 .996 r
F P
0 g
s
.57862 .58559 m .58129 .58842 L .55739 .58979 L p .477 .83 .996 r
F P
0 g
s
.58129 .58842 m .57862 .58559 L .63554 .57357 L p .546 .869 .994 r
F P
0 g
s
.57862 .58559 m .57598 .5867 L .62127 .57714 L p 0 0 0 r
F P
0 g
s
.63554 .57357 m .64109 .57582 L .61822 .58064 L p .546 .869 .994 r
F P
0 g
s
.61822 .58064 m .58129 .58842 L p .63554 .57357 L .546 .869 .994 r
F P
0 g
s
.63006 .57528 m .63554 .57357 L .62238 .57635 L p 0 0 0 r
F P
0 g
s
.62238 .57635 m .57862 .58559 L p .63006 .57528 L 0 0 0 r
F P
0 g
s
.64109 .57582 m .63554 .57357 L .68648 .55345 L p .62 .895 .988 r
F P
0 g
s
.63006 .57528 m .62461 .58022 L .64095 .57377 L p .014 0 0 r
F P
0 g
s
.63554 .57357 m .63006 .57528 L .67049 .55931 L p .311 .792 .719 r
F P
0 g
s
.67049 .55931 m .67838 .55619 L p .63554 .57357 L .311 .792 .719 r
F P
0 g
s
.68648 .55345 m .69469 .5547 L .64109 .57582 L p .62 .895 .988 r
F P
0 g
s
.67838 .55619 m .68648 .55345 L .67466 .55812 L p .311 .792 .719 r
F P
0 g
s
.67466 .55812 m .63554 .57357 L p .67838 .55619 L .311 .792 .719 r
F P
0 g
s
.68648 .55345 m .67838 .55619 L .718 .53025 L p .569 .938 .835 r
F P
0 g
s
.67838 .55619 m .67033 .56219 L .68366 .55346 L p 0 0 0 r
F P
0 g
s
.68366 .55346 m .70771 .53772 L p .67838 .55619 L 0 0 0 r
F P
0 g
s
.64095 .57377 m .67033 .56219 L p .63006 .57528 L .014 0 0 r
F P
0 g
s
.62127 .57714 m .63006 .57528 L p .57862 .58559 L 0 0 0 r
F P
0 g
s
.55739 .58979 m .51856 .59203 L p .57862 .58559 L .477 .83 .996 r
F P
0 g
s
.67023 .63881 m .66427 .62209 L .72912 .5974 L p .612 .539 .748 r
F P
0 g
s
.72912 .5974 m .73799 .61332 L .67023 .63881 L p .612 .539 .748 r
F P
0 g
s
.66427 .62209 m .65834 .60628 L .7203 .58242 L p .615 .549 .757 r
F P
0 g
s
.7203 .58242 m .72912 .5974 L .66427 .62209 L p .615 .549 .757 r
F P
0 g
s
.65834 .60628 m .65249 .59265 L .7116 .56967 L p .624 .578 .782 r
F P
0 g
s
.7116 .56967 m .7203 .58242 L .65834 .60628 L p .624 .578 .782 r
F P
0 g
s
.37179 .61777 m .36521 .63435 L .29943 .6068 L p .795 .692 .751 r
F P
0 g
s
.65249 .59265 m .64673 .58226 L .70306 .56019 L p .64 .635 .83 r
F P
0 g
s
.70306 .56019 m .7116 .56967 L .65249 .59265 L p .64 .635 .83 r
F P
0 g
s
.29943 .6068 m .30888 .59109 L .37179 .61777 L p .795 .692 .751 r
F P
0 g
s
.37834 .6021 m .37179 .61777 L .30888 .59109 L p .791 .696 .76 r
F P
0 g
s
.30888 .59109 m .31826 .57633 L .37834 .6021 L p .791 .696 .76 r
F P
0 g
s
.38481 .58862 m .37834 .6021 L .31826 .57633 L p .778 .706 .784 r
F P
0 g
s
.51887 .58904 m .51918 .58997 L .57598 .5867 L p .109 0 0 r
F P
0 g
s
.57598 .5867 m .57862 .58559 L .51887 .58904 L p .109 0 0 r
F P
0 g
s
.31826 .57633 m .32751 .5638 L .38481 .58862 L p .778 .706 .784 r
F P
0 g
s
.39116 .57839 m .38481 .58862 L .32751 .5638 L p .747 .725 .832 r
F P
0 g
s
.64673 .58226 m .64109 .57582 L .69469 .5547 L p .658 .742 .912 r
F P
0 g
s
.69469 .5547 m .70306 .56019 L .64673 .58226 L p .658 .742 .912 r
F P
0 g
s
.32751 .5638 m .33659 .55456 L .39116 .57839 L p .747 .725 .832 r
F P
0 g
s
.45945 .58379 m .46269 .58499 L .51918 .58997 L p .21 0 0 r
F P
0 g
s
.51949 .59411 m .51918 .58997 L .46269 .58499 L p .509 0 0 r
F P
0 g
s
.51918 .58997 m .51949 .59411 L .57336 .59101 L p .409 0 0 r
F P
0 g
s
.57336 .59101 m .57598 .5867 L .51918 .58997 L p .409 0 0 r
F P
0 g
s
.57598 .5867 m .57336 .59101 L .62461 .58022 L p .254 0 0 r
F P
0 g
s
.62461 .58022 m .63006 .57528 L .57598 .5867 L p .254 0 0 r
F P
0 g
s
.46592 .58939 m .46269 .58499 L .40956 .57193 L p .565 .001 0 r
F P
0 g
s
.46269 .58499 m .46592 .58939 L .51949 .59411 L p .509 0 0 r
F P
0 g
s
.73799 .61332 m .72912 .5974 L .78317 .56355 L p .563 .518 .763 r
F P
0 g
s
.72912 .5974 m .7203 .58242 L .7718 .54976 L p .569 .53 .772 r
F P
0 g
s
.7718 .54976 m .78317 .56355 L .72912 .5974 L p .569 .53 .772 r
F P
0 g
s
.78317 .56355 m .79464 .57831 L .73799 .61332 L p .563 .518 .763 r
F P
0 g
s
.7203 .58242 m .7116 .56967 L .76059 .53825 L p .584 .563 .796 r
F P
0 g
s
.76059 .53825 m .7718 .54976 L .7203 .58242 L p .584 .563 .796 r
F P
0 g
s
.7116 .56967 m .70306 .56019 L .74962 .53007 L p .613 .628 .842 r
F P
0 g
s
.74962 .53007 m .76059 .53825 L .7116 .56967 L p .613 .628 .842 r
F P
0 g
s
.70306 .56019 m .69469 .5547 L .73888 .52593 L p .656 .742 .913 r
F P
0 g
s
.73888 .52593 m .74962 .53007 L .70306 .56019 L p .656 .742 .913 r
F P
0 g
s
.51979 .60026 m .51949 .59411 L .46592 .58939 L p .585 .094 .055 r
F P
0 g
s
.51949 .59411 m .51979 .60026 L .57072 .59734 L p .489 .017 .06 r
F P
0 g
s
.57072 .59734 m .57336 .59101 L .51949 .59411 L p .489 .017 .06 r
F P
0 g
s
.24558 .56996 m .25753 .55549 L .30888 .59109 L p .827 .738 .767 r
F P
0 g
s
.30888 .59109 m .29943 .6068 L .24558 .56996 L p .827 .738 .767 r
F P
0 g
s
.31826 .57633 m .30888 .59109 L .25753 .55549 L p .821 .74 .776 r
F P
0 g
s
.25753 .55549 m .26939 .542 L .31826 .57633 L p .821 .74 .776 r
F P
0 g
s
.32751 .5638 m .31826 .57633 L .26939 .542 L p .803 .746 .8 r
F P
0 g
s
.26939 .542 m .28105 .53078 L .32751 .5638 L p .803 .746 .8 r
F P
0 g
s
.33659 .55456 m .32751 .5638 L .28105 .53078 L p .761 .753 .845 r
F P
0 g
s
.67033 .56219 m .67838 .55619 L .63006 .57528 L p .014 0 0 r
F P
0 g
s
.57336 .59101 m .57072 .59734 L .61913 .58719 L p .352 0 .012 r
F P
0 g
s
.61913 .58719 m .62461 .58022 L .57336 .59101 L p .352 0 .012 r
F P
0 g
s
.69469 .5547 m .68648 .55345 L .72836 .52607 L p .686 .902 .973 r
F P
0 g
s
.72836 .52607 m .73888 .52593 L .69469 .5547 L p .686 .902 .973 r
F P
0 g
s
.28105 .53078 m .29248 .52292 L .33659 .55456 L p .761 .753 .845 r
F P
0 g
s
.34548 .54932 m .33659 .55456 L .29248 .52292 L p .665 .749 .913 r
F P
0 g
s
.40956 .57193 m .41558 .57705 L .46592 .58939 L p .565 .001 0 r
F P
0 g
s
.46916 .59582 m .46592 .58939 L .41558 .57705 L p .65 .131 0 r
F P
0 g
s
.46592 .58939 m .46916 .59582 L .51979 .60026 L p .585 .094 .055 r
F P
0 g
s
.29248 .52292 m .30365 .5191 L .34548 .54932 L p .665 .749 .913 r
F P
0 g
s
.718 .53025 m .72836 .52607 L .68648 .55345 L p .569 .938 .835 r
F P
0 g
s
.52011 .60688 m .51979 .60026 L .46916 .59582 L p .594 .111 .076 r
F P
0 g
s
.51979 .60026 m .52011 .60688 L .56804 .60414 L p .5 .035 .081 r
F P
0 g
s
.56804 .60414 m .57072 .59734 L .51979 .60026 L p .5 .035 .081 r
F P
0 g
s
.62461 .58022 m .61913 .58719 L .66225 .57023 L p .139 0 0 r
F P
0 g
s
.66225 .57023 m .67033 .56219 L .62461 .58022 L p .139 0 0 r
F P
0 g
s
.57072 .59734 m .56804 .60414 L .61357 .59463 L p .365 0 .035 r
F P
0 g
s
.61357 .59463 m .61913 .58719 L .57072 .59734 L p .365 0 .035 r
F P
0 g
s
.36281 .55134 m .37136 .5576 L .41558 .57705 L p .555 0 0 r
F P
0 g
s
.42162 .58421 m .41558 .57705 L .37136 .5576 L p .672 .123 0 r
F P
0 g
s
.41558 .57705 m .42162 .58421 L .46916 .59582 L p .65 .131 0 r
F P
0 g
s
.47245 .60272 m .46916 .59582 L .42162 .58421 L p .66 .15 .018 r
F P
0 g
s
.46916 .59582 m .47245 .60272 L .52011 .60688 L p .594 .111 .076 r
F P
0 g
s
.69741 .54725 m .70771 .53772 L .70681 .53831 L p 0 0 0 r
F P
0 g
s
.70681 .53831 m .67033 .56219 L p .69741 .54725 L 0 0 0 r
F P
0 g
s
.687 .55728 m .69741 .54725 L .66225 .57023 L p 0 0 0 r
F P
0 g
s
.69741 .54725 m .687 .55728 L .68763 .55656 L p .596 .883 .575 r
F P
0 g
s
.71295 .53356 m .67838 .55619 L p .70771 .53772 L 0 0 0 r
F P
0 g
s
.67033 .56219 m .66225 .57023 L .69741 .54725 L p 0 0 0 r
F P
0 g
s
.68763 .55656 m .71005 .53129 L p .69741 .54725 L .596 .883 .575 r
F P
0 g
s
.70771 .53772 m .69741 .54725 L .70148 .54267 L p .61 .897 .599 r
F P
0 g
s
.70148 .54267 m .72215 .5194 L p .70771 .53772 L .61 .897 .599 r
F P
0 g
s
.70771 .53772 m .718 .53025 L .71295 .53356 L p 0 0 0 r
F P
0 g
s
.78317 .56355 m .7718 .54976 L .80925 .50966 L p .514 .513 .793 r
F P
0 g
s
.7718 .54976 m .76059 .53825 L .79605 .49974 L p .539 .553 .817 r
F P
0 g
s
.79605 .49974 m .80925 .50966 L .7718 .54976 L p .539 .553 .817 r
F P
0 g
s
.61913 .58719 m .61357 .59463 L .65406 .57876 L p .157 0 0 r
F P
0 g
s
.65406 .57876 m .66225 .57023 L .61913 .58719 L p .157 0 0 r
F P
0 g
s
.76059 .53825 m .74962 .53007 L .78314 .49322 L p .585 .626 .859 r
F P
0 g
s
.78314 .49322 m .79605 .49974 L .76059 .53825 L p .585 .626 .859 r
F P
0 g
s
.52043 .6122 m .52011 .60688 L .47245 .60272 L p .552 .037 0 r
F P
0 g
s
.52011 .60688 m .52043 .6122 L .5653 .60965 L p .454 0 0 r
F P
0 g
s
.5653 .60965 m .56804 .60414 L .52011 .60688 L p .454 0 0 r
F P
0 g
s
.79464 .57831 m .78317 .56355 L .82268 .5219 L p .504 .499 .784 r
F P
0 g
s
.80925 .50966 m .82268 .5219 L .78317 .56355 L p .514 .513 .793 r
F P
0 g
s
.74962 .53007 m .73888 .52593 L .77055 .49079 L p .655 .742 .914 r
F P
0 g
s
.77055 .49079 m .78314 .49322 L .74962 .53007 L p .655 .742 .914 r
F P
0 g
s
.82268 .5219 m .83625 .53514 L .79464 .57831 L p .504 .499 .784 r
F P
0 g
s
.37136 .5576 m .37994 .56592 L .42162 .58421 L p .672 .123 0 r
F P
0 g
s
.42775 .59184 m .42162 .58421 L .37994 .56592 L p .687 .145 0 r
F P
0 g
s
.42162 .58421 m .42775 .59184 L .47245 .60272 L p .66 .15 .018 r
F P
0 g
s
.56804 .60414 m .5653 .60965 L .60789 .60077 L p .308 0 0 r
F P
0 g
s
.60789 .60077 m .61357 .59463 L .56804 .60414 L p .308 0 0 r
F P
0 g
s
.47582 .60832 m .47245 .60272 L .42775 .59184 L p .613 .071 0 r
F P
0 g
s
.47245 .60272 m .47582 .60832 L .52043 .6122 L p .552 .037 0 r
F P
0 g
s
.73888 .52593 m .72836 .52607 L .75823 .4927 L p .733 .891 .952 r
F P
0 g
s
.75823 .4927 m .77055 .49079 L .73888 .52593 L p .733 .891 .952 r
F P
0 g
s
.23529 .50057 m .24882 .49103 L .28105 .53078 L p .823 .792 .822 r
F P
0 g
s
.28105 .53078 m .26939 .542 L .23529 .50057 L p .823 .792 .822 r
F P
0 g
s
.29248 .52292 m .28105 .53078 L .24882 .49103 L p .771 .783 .863 r
F P
0 g
s
.22151 .51244 m .23529 .50057 L .26939 .542 L p .848 .793 .798 r
F P
0 g
s
.26939 .542 m .25753 .55549 L .22151 .51244 L p .848 .793 .798 r
F P
0 g
s
.24882 .49103 m .26204 .48489 L .29248 .52292 L p .771 .783 .863 r
F P
0 g
s
.30365 .5191 m .29248 .52292 L .26204 .48489 L p .665 .75 .914 r
F P
0 g
s
.20758 .52532 m .22151 .51244 L .25753 .55549 L p .856 .793 .789 r
F P
0 g
s
.25753 .55549 m .24558 .56996 L .20758 .52532 L p .856 .793 .789 r
F P
0 g
s
.72836 .52607 m .718 .53025 L .74612 .49869 L p .754 .989 .891 r
F P
0 g
s
.74612 .49869 m .75823 .4927 L .72836 .52607 L p .754 .989 .891 r
F P
0 g
s
.26204 .48489 m .27494 .48286 L .30365 .5191 L p .665 .75 .914 r
F P
0 g
s
.31459 .51958 m .30365 .5191 L .27494 .48286 L p .46 .658 .947 r
F P
0 g
s
.61357 .59463 m .60789 .60077 L .6457 .58599 L p .081 0 0 r
F P
0 g
s
.6457 .58599 m .65406 .57876 L .61357 .59463 L p .081 0 0 r
F P
0 g
s
.52075 .61444 m .52043 .6122 L .47582 .60832 L p .355 0 0 r
F P
0 g
s
.52043 .6122 m .52075 .61444 L .56247 .61207 L p .252 0 0 r
F P
0 g
s
.56247 .61207 m .5653 .60965 L .52043 .6122 L p .252 0 0 r
F P
0 g
s
.37994 .56592 m .38862 .57473 L .42775 .59184 L p .687 .145 0 r
F P
0 g
s
.43402 .59817 m .42775 .59184 L .38862 .57473 L p .62 .053 0 r
F P
0 g
s
.42775 .59184 m .43402 .59817 L .47582 .60832 L p .613 .071 0 r
F P
0 g
s
.5653 .60965 m .56247 .61207 L .60204 .60384 L p .079 0 0 r
F P
0 g
s
.60204 .60384 m .60789 .60077 L .5653 .60965 L p .079 0 0 r
F P
0 g
s
.66225 .57023 m .65406 .57876 L .687 .55728 L p 0 0 0 r
F P
0 g
s
.27494 .48286 m .28755 .48517 L .31459 .51958 L p .46 .658 .947 r
F P
0 g
s
.32536 .52411 m .31459 .51958 L .28755 .48517 L p .149 .473 .894 r
F P
0 g
s
.47928 .61084 m .47582 .60832 L .43402 .59817 L p .391 0 0 r
F P
0 g
s
.47582 .60832 m .47928 .61084 L .52075 .61444 L p .355 0 0 r
F P
0 g
s
.718 .53025 m .70771 .53772 L .73413 .508 L p .685 .962 .729 r
F P
0 g
s
.73413 .508 m .74612 .49869 L .718 .53025 L p .685 .962 .729 r
F P
0 g
s
.28755 .48517 m .29994 .49158 L .32536 .52411 L p .149 .473 .894 r
F P
0 g
s
.60789 .60077 m .60204 .60384 L .63712 .59013 L p 0 0 0 r
F P
0 g
s
.63712 .59013 m .6457 .58599 L .60789 .60077 L p 0 0 0 r
F P
0 g
s
.52109 .61205 m .52075 .61444 L .47928 .61084 L p .322 .758 .968 r
F P
0 g
s
.52075 .61444 m .52109 .61205 L .55956 .60986 L p .384 .811 .967 r
F P
0 g
s
.55956 .60986 m .56247 .61207 L .52075 .61444 L p .384 .811 .967 r
F P
0 g
s
.38862 .57473 m .39749 .58223 L .43402 .59817 L p .62 .053 0 r
F P
0 g
s
.44046 .60142 m .43402 .59817 L .39749 .58223 L p .34 0 0 r
F P
0 g
s
.43402 .59817 m .44046 .60142 L .47928 .61084 L p .391 0 0 r
F P
0 g
s
.56247 .61207 m .55956 .60986 L .59602 .60226 L p .477 .866 .973 r
F P
0 g
s
.59602 .60226 m .60204 .60384 L .56247 .61207 L p .477 .866 .973 r
F P
0 g
s
.72215 .5194 m .73413 .508 L .70771 .53772 L p .61 .897 .599 r
F P
0 g
s
.65406 .57876 m .6457 .58599 L .67637 .566 L p 0 0 0 r
F P
0 g
s
.67637 .566 m .687 .55728 L .65406 .57876 L p 0 0 0 r
F P
0 g
s
.48286 .60872 m .47928 .61084 L .44046 .60142 L p .3 .715 .974 r
F P
0 g
s
.47928 .61084 m .48286 .60872 L .52109 .61205 L p .322 .758 .968 r
F P
0 g
s
.51363 .42286 m .51746 .39918 L .52438 .39986 L p .733 .592 .699 r
F P
0 g
s
.52438 .39986 m .52402 .42387 L .51363 .42286 L p .733 .592 .699 r
F P
0 g
s
.52475 .38146 m .52438 .39986 L .51746 .39918 L p .728 .624 .742 r
F P
0 g
s
.52402 .42387 m .52438 .39986 L .53136 .39941 L p .689 .556 .698 r
F P
0 g
s
.52438 .39986 m .52475 .38146 L .52824 .38124 L p .692 .593 .741 r
F P
0 g
s
.52824 .38124 m .53136 .39941 L .52438 .39986 L p .692 .593 .741 r
F P
0 g
s
.53136 .39941 m .53448 .42321 L .52402 .42387 L p .689 .556 .698 r
F P
0 g
s
.53448 .42321 m .53136 .39941 L .53791 .39786 L p .642 .522 .702 r
F P
0 g
s
.53136 .39941 m .52824 .38124 L .53152 .38045 L p .652 .566 .746 r
F P
0 g
s
.53152 .38045 m .53791 .39786 L .53136 .39941 L p .652 .566 .746 r
F P
0 g
s
.50399 .42024 m .51105 .39741 L .51746 .39918 L p .775 .633 .703 r
F P
0 g
s
.51746 .39918 m .51363 .42286 L .50399 .42024 L p .775 .633 .703 r
F P
0 g
s
.52128 .38112 m .51746 .39918 L .51105 .39741 L p .763 .659 .747 r
F P
0 g
s
.51746 .39918 m .52128 .38112 L .52475 .38146 L p .728 .624 .742 r
F P
0 g
s
.50977 .45079 m .51363 .42286 L .52402 .42387 L p .735 .576 .677 r
F P
0 g
s
.52402 .42387 m .52365 .45211 L .50977 .45079 L p .735 .576 .677 r
F P
0 g
s
.52365 .45211 m .52402 .42387 L .53448 .42321 L p .688 .537 .677 r
F P
0 g
s
.39749 .58223 m .38862 .57473 L .35756 .55221 L p .51 0 0 r
F P
0 g
s
.53448 .42321 m .53763 .45124 L .52365 .45211 L p .688 .537 .677 r
F P
0 g
s
.53763 .45124 m .53448 .42321 L .54433 .42091 L p .636 .5 .68 r
F P
0 g
s
.53791 .39786 m .54433 .42091 L .53448 .42321 L p .642 .522 .702 r
F P
0 g
s
.49688 .44733 m .50399 .42024 L .51363 .42286 L p .78 .619 .681 r
F P
0 g
s
.51363 .42286 m .50977 .45079 L .49688 .44733 L p .78 .619 .681 r
F P
0 g
s
.54433 .42091 m .53791 .39786 L .54362 .39531 L p .587 .489 .709 r
F P
0 g
s
.53791 .39786 m .53152 .38045 L .53437 .37916 L p .608 .542 .755 r
F P
0 g
s
.53437 .37916 m .54362 .39531 L .53791 .39786 L p .608 .542 .755 r
F P
0 g
s
.49574 .41617 m .50557 .39466 L .51105 .39741 L p .818 .68 .712 r
F P
0 g
s
.51105 .39741 m .50399 .42024 L .49574 .41617 L p .818 .68 .712 r
F P
0 g
s
.51808 .38022 m .51105 .39741 L .50557 .39466 L p .797 .7 .757 r
F P
0 g
s
.51105 .39741 m .51808 .38022 L .52128 .38112 L p .763 .659 .747 r
F P
0 g
s
.29994 .49158 m .3122 .50131 L .33605 .53193 L p 0 .256 .759 r
F P
0 g
s
.52511 .36958 m .52475 .38146 L .52128 .38112 L closepath p .705 .688 .831 r
F P
0 g
s
.52511 .36958 m .52824 .38124 L .52475 .38146 L closepath p .686 .672 .831 r
F P
0 g
s
.52511 .36958 m .53152 .38045 L .52824 .38124 L closepath p .665 .659 .834 r
F P
0 g
s
.52511 .36958 m .52128 .38112 L .51808 .38022 L closepath p .723 .707 .835 r
F P
0 g
s
.52511 .36958 m .53437 .37916 L .53152 .38045 L closepath p .643 .65 .841 r
F P
0 g
s
.50557 .39466 m .51534 .37884 L .51808 .38022 L p .797 .7 .757 r
F P
0 g
s
.52511 .36958 m .51808 .38022 L .51534 .37884 L closepath p .738 .729 .843 r
F P
0 g
s
.54433 .42091 m .55079 .44822 L .53763 .45124 L p .636 .5 .68 r
F P
0 g
s
.55079 .44822 m .54433 .42091 L .55292 .41712 L p .576 .462 .686 r
F P
0 g
s
.54362 .39531 m .55292 .41712 L .54433 .42091 L p .587 .489 .709 r
F P
0 g
s
.50589 .48115 m .50977 .45079 L .52365 .45211 L p .735 .569 .668 r
F P
0 g
s
.52365 .45211 m .52328 .48279 L .50589 .48115 L p .735 .569 .668 r
F P
0 g
s
.52328 .48279 m .52365 .45211 L .53763 .45124 L p .687 .529 .667 r
F P
0 g
s
.52144 .60387 m .52109 .61205 L .48286 .60872 L p .669 .742 .905 r
F P
0 g
s
.52109 .61205 m .52144 .60387 L .55656 .60187 L p .663 .737 .905 r
F P
0 g
s
.55656 .60187 m .55956 .60986 L .52109 .61205 L p .663 .737 .905 r
F P
0 g
s
.48583 .44197 m .49574 .41617 L .50399 .42024 L p .827 .669 .688 r
F P
0 g
s
.50399 .42024 m .49688 .44733 L .48583 .44197 L p .827 .669 .688 r
F P
0 g
s
.55292 .41712 m .54362 .39531 L .54809 .39192 L p .52 .454 .722 r
F P
0 g
s
.54362 .39531 m .53437 .37916 L .53659 .37746 L p .557 .52 .77 r
F P
0 g
s
.53659 .37746 m .54809 .39192 L .54362 .39531 L p .557 .52 .77 r
F P
0 g
s
.52511 .36958 m .53659 .37746 L .53437 .37916 L closepath p .62 .644 .852 r
F P
0 g
s
.53763 .45124 m .5408 .48171 L .52328 .48279 L p .687 .529 .667 r
F P
0 g
s
.5408 .48171 m .53763 .45124 L .55079 .44822 L p .634 .49 .67 r
F P
0 g
s
.5014 .39113 m .51327 .37706 L .51534 .37884 L p .83 .748 .774 r
F P
0 g
s
.51534 .37884 m .50557 .39466 L .5014 .39113 L p .83 .748 .774 r
F P
0 g
s
.52511 .36958 m .51534 .37884 L .51327 .37706 L closepath p .749 .753 .855 r
F P
0 g
s
.48944 .41092 m .5014 .39113 L .50557 .39466 L p .862 .738 .725 r
F P
0 g
s
.50557 .39466 m .49574 .41617 L .48944 .41092 L p .862 .738 .725 r
F P
0 g
s
.79605 .49974 m .78314 .49322 L .80068 .45152 L p .556 .629 .88 r
F P
0 g
s
.78314 .49322 m .77055 .49079 L .78692 .45112 L p .654 .743 .915 r
F P
0 g
s
.78692 .45112 m .80068 .45152 L .78314 .49322 L p .654 .743 .915 r
F P
0 g
s
.80925 .50966 m .79605 .49974 L .81481 .45607 L p .486 .547 .845 r
F P
0 g
s
.80068 .45152 m .81481 .45607 L .79605 .49974 L p .556 .629 .88 r
F P
0 g
s
.48971 .4769 m .49688 .44733 L .50977 .45079 L p .782 .613 .671 r
F P
0 g
s
.50977 .45079 m .50589 .48115 L .48971 .4769 L p .782 .613 .671 r
F P
0 g
s
.60204 .60384 m .59602 .60226 L .62828 .58962 L p .58 .909 .978 r
F P
0 g
s
.62828 .58962 m .63712 .59013 L .60204 .60384 L p .58 .909 .978 r
F P
0 g
s
.54809 .39192 m .53659 .37746 L .53804 .37544 L p .493 .499 .791 r
F P
0 g
s
.52511 .36958 m .53804 .37544 L .53659 .37746 L closepath p .597 .643 .867 r
F P
0 g
s
.55956 .60986 m .55656 .60187 L .58982 .59489 L p .657 .733 .906 r
F P
0 g
s
.58982 .59489 m .59602 .60226 L .55956 .60986 L p .657 .733 .906 r
F P
0 g
s
.49882 .38704 m .512 .375 L .51327 .37706 L p .859 .806 .797 r
F P
0 g
s
.51327 .37706 m .5014 .39113 L .49882 .38704 L p .859 .806 .797 r
F P
0 g
s
.52511 .36958 m .51327 .37706 L .512 .375 L closepath p .757 .778 .871 r
F P
0 g
s
.82268 .5219 m .80925 .50966 L .8293 .46407 L p .445 .499 .821 r
F P
0 g
s
.81481 .45607 m .8293 .46407 L .80925 .50966 L p .486 .547 .845 r
F P
0 g
s
.77055 .49079 m .75823 .4927 L .7735 .4551 L p .761 .867 .926 r
F P
0 g
s
.7735 .4551 m .78692 .45112 L .77055 .49079 L p .761 .867 .926 r
F P
0 g
s
.55292 .41712 m .56229 .44323 L .55079 .44822 L p .576 .462 .686 r
F P
0 g
s
.56229 .44323 m .55292 .41712 L .55966 .41209 L p .501 .419 .696 r
F P
0 g
s
.54809 .39192 m .55966 .41209 L .55292 .41712 L p .52 .454 .722 r
F P
0 g
s
.55079 .44822 m .55731 .47799 L .5408 .48171 L p .634 .49 .67 r
F P
0 g
s
.55731 .47799 m .55079 .44822 L .56229 .44323 L p .572 .45 .675 r
F P
0 g
s
.55966 .41209 m .54809 .39192 L .55101 .38792 L p .431 .413 .739 r
F P
0 g
s
.53804 .37544 m .55101 .38792 L .54809 .39192 L p .493 .499 .791 r
F P
0 g
s
.71005 .53129 m .72215 .5194 L .69741 .54725 L p .596 .883 .575 r
F P
0 g
s
.39749 .58223 m .4066 .58666 L .44046 .60142 L p .34 0 0 r
F P
0 g
s
.44709 .60003 m .44046 .60142 L .4066 .58666 L p .315 .681 .977 r
F P
0 g
s
.44046 .60142 m .44709 .60003 L .48286 .60872 L p .3 .715 .974 r
F P
0 g
s
.48654 .60082 m .48286 .60872 L .44709 .60003 L p .673 .747 .906 r
F P
0 g
s
.48286 .60872 m .48654 .60082 L .52144 .60387 L p .669 .742 .905 r
F P
0 g
s
.50198 .51191 m .50589 .48115 L .52328 .48279 L p .735 .569 .667 r
F P
0 g
s
.52328 .48279 m .52291 .51385 L .50198 .51191 L p .735 .569 .667 r
F P
0 g
s
.52291 .51385 m .52328 .48279 L .5408 .48171 L p .686 .529 .667 r
F P
0 g
s
.55101 .38792 m .53804 .37544 L .53861 .37326 L p .411 .479 .82 r
F P
0 g
s
.52511 .36958 m .53861 .37326 L .53804 .37544 L closepath p .573 .647 .886 r
F P
0 g
s
.47735 .43504 m .48944 .41092 L .49574 .41617 L p .876 .731 .698 r
F P
0 g
s
.49574 .41617 m .48583 .44197 L .47735 .43504 L p .876 .731 .698 r
F P
0 g
s
.48552 .40482 m .49882 .38704 L .5014 .39113 L p .905 .81 .743 r
F P
0 g
s
.5014 .39113 m .48944 .41092 L .48552 .40482 L p .905 .81 .743 r
F P
0 g
s
.47582 .47028 m .48583 .44197 L .49688 .44733 L p .83 .664 .677 r
F P
0 g
s
.49688 .44733 m .48971 .4769 L .47582 .47028 L p .83 .664 .677 r
F P
0 g
s
.52511 .36958 m .53495 .36719 L .53701 .36899 L closepath p .515 .696 .951 r
F P
0 g
s
.52511 .36958 m .53221 .36579 L .53495 .36719 L closepath p .509 .725 .97 r
F P
0 g
s
.52511 .36958 m .52898 .36488 L .53221 .36579 L closepath p .517 .757 .983 r
F P
0 g
s
.52511 .36958 m .52548 .36453 L .52898 .36488 L closepath p .539 .791 .991 r
F P
0 g
s
.52511 .36958 m .52196 .36476 L .52548 .36453 L closepath p .575 .822 .991 r
F P
0 g
s
.52511 .36958 m .51866 .36556 L .52196 .36476 L closepath p .62 .845 .986 r
F P
0 g
s
.52511 .36958 m .5158 .36686 L .51866 .36556 L closepath p .665 .858 .973 r
F P
0 g
s
.52511 .36958 m .51358 .36859 L .5158 .36686 L closepath p .705 .859 .956 r
F P
0 g
s
.52511 .36958 m .51216 .37062 L .51358 .36859 L closepath p .734 .848 .934 r
F P
0 g
s
.52511 .36958 m .51162 .3728 L .51216 .37062 L closepath p .751 .828 .912 r
F P
0 g
s
.52511 .36958 m .512 .375 L .51162 .3728 L closepath p .758 .804 .89 r
F P
0 g
s
.52511 .36958 m .53826 .37106 L .53861 .37326 L closepath p .55 .657 .907 r
F P
0 g
s
.52511 .36958 m .53701 .36899 L .53826 .37106 L closepath p .529 .674 .929 r
F P
0 g
s
.49803 .38265 m .51162 .3728 L .512 .375 L p .88 .874 .826 r
F P
0 g
s
.512 .375 m .49882 .38704 L .49803 .38265 L p .88 .874 .826 r
F P
0 g
s
.6457 .58599 m .63712 .59013 L .66548 .57163 L p .486 .885 .73 r
F P
0 g
s
.66548 .57163 m .67637 .566 L .6457 .58599 L p .486 .885 .73 r
F P
0 g
s
.5408 .48171 m .54398 .51257 L .52291 .51385 L p .686 .529 .667 r
F P
0 g
s
.54398 .51257 m .5408 .48171 L .55731 .47799 L p .633 .49 .669 r
F P
0 g
s
.4825 .50688 m .48971 .4769 L .50589 .48115 L p .782 .613 .67 r
F P
0 g
s
.50589 .48115 m .50198 .51191 L .4825 .50688 L p .782 .613 .67 r
F P
0 g
s
.83625 .53514 m .82268 .5219 L .84408 .47443 L p .429 .481 .812 r
F P
0 g
s
.8293 .46407 m .84408 .47443 L .82268 .5219 L p .445 .499 .821 r
F P
0 g
s
.53861 .37326 m .55219 .38357 L .55101 .38792 L p .411 .479 .82 r
F P
0 g
s
.55219 .38357 m .53861 .37326 L .53826 .37106 L p .299 .458 .851 r
F P
0 g
s
.49908 .37828 m .51216 .37062 L .51162 .3728 L p .874 .947 .857 r
F P
0 g
s
.51162 .3728 m .49803 .38265 L .49908 .37828 L p .874 .947 .857 r
F P
0 g
s
.55101 .38792 m .5641 .40613 L .55966 .41209 L p .431 .413 .739 r
F P
0 g
s
.5641 .40613 m .55101 .38792 L .55219 .38357 L p .299 .361 .758 r
F P
0 g
s
.5218 .58942 m .52144 .60387 L .48654 .60082 L p .72 .656 .785 r
F P
0 g
s
.52144 .60387 m .5218 .58942 L .55349 .58759 L p .69 .631 .785 r
F P
0 g
s
.55349 .58759 m .55656 .60187 L .52144 .60387 L p .69 .631 .785 r
F P
0 g
s
.75823 .4927 m .74612 .49869 L .76034 .46321 L p .839 .958 .888 r
F P
0 g
s
.76034 .46321 m .7735 .4551 L .75823 .4927 L p .839 .958 .888 r
F P
0 g
s
.55966 .41209 m .57136 .43659 L .56229 .44323 L p .501 .419 .696 r
F P
0 g
s
.57136 .43659 m .55966 .41209 L .5641 .40613 L p .396 .366 .708 r
F P
0 g
s
.53826 .37106 m .55152 .37918 L .55219 .38357 L p .299 .458 .851 r
F P
0 g
s
.55152 .37918 m .53826 .37106 L .53701 .36899 L p .143 .431 .869 r
F P
0 g
s
.48428 .39828 m .49803 .38265 L .49882 .38704 L p .937 .897 .762 r
F P
0 g
s
.49882 .38704 m .48552 .40482 L .48428 .39828 L p .937 .897 .762 r
F P
0 g
s
.49806 .54096 m .50198 .51191 L .52291 .51385 L p .735 .574 .674 r
F P
0 g
s
.52291 .51385 m .52254 .54318 L .49806 .54096 L p .735 .574 .674 r
F P
0 g
s
.52254 .54318 m .52291 .51385 L .54398 .51257 L p .687 .535 .674 r
F P
0 g
s
.56229 .44323 m .57176 .47183 L .55731 .47799 L p .572 .45 .675 r
F P
0 g
s
.57176 .47183 m .56229 .44323 L .57136 .43659 L p .492 .404 .684 r
F P
0 g
s
.50192 .37422 m .51358 .36859 L .51216 .37062 L p .805 .994 .868 r
F P
0 g
s
.51216 .37062 m .49908 .37828 L .50192 .37422 L p .805 .994 .868 r
F P
0 g
s
.55731 .47799 m .56387 .50817 L .54398 .51257 L p .633 .49 .669 r
F P
0 g
s
.56387 .50817 m .55731 .47799 L .57176 .47183 L p .571 .449 .674 r
F P
0 g
s
.35756 .55221 m .36859 .56129 L .39749 .58223 L p .51 0 0 r
F P
0 g
s
.4066 .58666 m .39749 .58223 L .36859 .56129 L p 0 .325 .762 r
F P
0 g
s
.47205 .42697 m .48552 .40482 L .48944 .41092 L p .925 .808 .711 r
F P
0 g
s
.48944 .41092 m .47735 .43504 L .47205 .42697 L p .925 .808 .711 r
F P
0 g
s
.3122 .50131 m .32446 .51314 L .34675 .54182 L p 0 .118 .646 r
F P
0 g
s
.23386 .44658 m .24814 .44247 L .26204 .48489 L p .774 .813 .884 r
F P
0 g
s
.26204 .48489 m .24882 .49103 L .23386 .44658 L p .774 .813 .884 r
F P
0 g
s
.27494 .48286 m .26204 .48489 L .24814 .44247 L p .664 .752 .915 r
F P
0 g
s
.84408 .47443 m .85906 .48583 L .83625 .53514 L p .429 .481 .812 r
F P
0 g
s
.54398 .51257 m .54717 .54172 L .52254 .54318 L p .687 .535 .674 r
F P
0 g
s
.54717 .54172 m .54398 .51257 L .56387 .50817 L p .635 .497 .676 r
F P
0 g
s
.46512 .46171 m .47735 .43504 L .48583 .44197 L p .881 .727 .686 r
F P
0 g
s
.48583 .44197 m .47582 .47028 L .46512 .46171 L p .881 .727 .686 r
F P
0 g
s
.55656 .60187 m .55349 .58759 L .58346 .58125 L p .657 .609 .789 r
F P
0 g
s
.58346 .58125 m .58982 .59489 L .55656 .60187 L p .657 .609 .789 r
F P
0 g
s
.21921 .45415 m .23386 .44658 L .24882 .49103 L p .836 .843 .851 r
F P
0 g
s
.24882 .49103 m .23529 .50057 L .21921 .45415 L p .836 .843 .851 r
F P
0 g
s
.46572 .49905 m .47582 .47028 L .48971 .4769 L p .831 .664 .676 r
F P
0 g
s
.48971 .4769 m .4825 .50688 L .46572 .49905 L p .831 .664 .676 r
F P
0 g
s
.53701 .36899 m .54904 .37503 L .55152 .37918 L p .143 .431 .869 r
F P
0 g
s
.54904 .37503 m .53701 .36899 L .53495 .36719 L p 0 .389 .835 r
F P
0 g
s
.47526 .53518 m .4825 .50688 L .50198 .51191 L p .781 .617 .677 r
F P
0 g
s
.50198 .51191 m .49806 .54096 L .47526 .53518 L p .781 .617 .677 r
F P
0 g
s
.50636 .37076 m .5158 .36686 L .51358 .36859 L p .619 .956 .817 r
F P
0 g
s
.51358 .36859 m .50192 .37422 L .50636 .37076 L p .619 .956 .817 r
F P
0 g
s
.59602 .60226 m .58982 .59489 L .6192 .58331 L p .65 .731 .908 r
F P
0 g
s
.6192 .58331 m .62828 .58962 L .59602 .60226 L p .65 .731 .908 r
F P
0 g
s
.44709 .60003 m .45393 .59285 L .48654 .60082 L p .673 .747 .906 r
F P
0 g
s
.49032 .58664 m .48654 .60082 L .45393 .59285 L p .749 .686 .791 r
F P
0 g
s
.48654 .60082 m .49032 .58664 L .5218 .58942 L p .72 .656 .785 r
F P
0 g
s
.24814 .44247 m .26204 .44252 L .27494 .48286 L p .664 .752 .915 r
F P
0 g
s
.28755 .48517 m .27494 .48286 L .26204 .44252 L p .497 .643 .921 r
F P
0 g
s
.55219 .38357 m .56592 .39965 L .5641 .40613 L p .299 .361 .758 r
F P
0 g
s
.56592 .39965 m .55219 .38357 L .55152 .37918 L p .09 .28 .762 r
F P
0 g
s
.49417 .56638 m .49806 .54096 L .52254 .54318 L p .734 .587 .691 r
F P
0 g
s
.52254 .54318 m .52217 .56888 L .49417 .56638 L p .734 .587 .691 r
F P
0 g
s
.52217 .56888 m .52254 .54318 L .54717 .54172 L p .689 .549 .691 r
F P
0 g
s
.53495 .36719 m .54491 .37142 L .54904 .37503 L p 0 .389 .835 r
F P
0 g
s
.54491 .37142 m .53495 .36719 L .53221 .36579 L p 0 .337 .719 r
F P
0 g
s
.52217 .56888 m .5218 .58942 L .49032 .58664 L p .731 .611 .724 r
F P
0 g
s
.5218 .58942 m .52217 .56888 L .55035 .56723 L p .691 .577 .723 r
F P
0 g
s
.55035 .56723 m .55349 .58759 L .5218 .58942 L p .691 .577 .723 r
F P
0 g
s
.20426 .46408 m .21921 .45415 L .23529 .50057 L p .867 .855 .828 r
F P
0 g
s
.23529 .50057 m .22151 .51244 L .20426 .46408 L p .867 .855 .828 r
F P
0 g
s
.51211 .36813 m .51866 .36556 L .5158 .36686 L p .332 .797 .689 r
F P
0 g
s
.5158 .36686 m .50636 .37076 L .51211 .36813 L p .332 .797 .689 r
F P
0 g
s
.48582 .39173 m .49908 .37828 L .49803 .38265 L p .916 .979 .757 r
F P
0 g
s
.49803 .38265 m .48428 .39828 L .48582 .39173 L p .916 .979 .757 r
F P
0 g
s
.4066 .58666 m .41597 .58641 L .44709 .60003 L p .315 .681 .977 r
F P
0 g
s
.45393 .59285 m .44709 .60003 L .41597 .58641 L p .677 .754 .909 r
F P
0 g
s
.53221 .36579 m .5394 .3686 L .54491 .37142 L p 0 .337 .719 r
F P
0 g
s
.5394 .3686 m .53221 .36579 L .52898 .36488 L p .292 0 0 r
F P
0 g
s
.49032 .58664 m .49417 .56638 L .52217 .56888 L p .731 .611 .724 r
F P
0 g
s
.54717 .54172 m .55035 .56723 L .52217 .56888 L p .689 .549 .691 r
F P
0 g
s
.55035 .56723 m .54717 .54172 L .57044 .53666 L p .64 .514 .694 r
F P
0 g
s
.56387 .50817 m .57044 .53666 L .54717 .54172 L p .635 .497 .676 r
F P
0 g
s
.51876 .36652 m .52196 .36476 L .51866 .36556 L p 0 0 0 r
F P
0 g
s
.51866 .36556 m .51211 .36813 L .51876 .36652 L p 0 0 0 r
F P
0 g
s
.5641 .40613 m .57736 .42872 L .57136 .43659 L p .396 .366 .708 r
F P
0 g
s
.57736 .42872 m .5641 .40613 L .56592 .39965 L p .233 .289 .717 r
F P
0 g
s
.55349 .58759 m .55035 .56723 L .57699 .56153 L p .647 .547 .727 r
F P
0 g
s
.57699 .56153 m .58346 .58125 L .55349 .58759 L p .647 .547 .727 r
F P
0 g
s
.52898 .36488 m .5329 .36677 L .5394 .3686 L p .292 0 0 r
F P
0 g
s
.5329 .36677 m .52898 .36488 L .52548 .36453 L p .263 0 0 r
F P
0 g
s
.46806 .55986 m .47526 .53518 L .49806 .54096 L p .778 .628 .695 r
F P
0 g
s
.49806 .54096 m .49417 .56638 L .46806 .55986 L p .778 .628 .695 r
F P
0 g
s
.52586 .36606 m .52548 .36453 L .52196 .36476 L p .147 0 0 r
F P
0 g
s
.52196 .36476 m .51876 .36652 L .52586 .36606 L p .147 0 0 r
F P
0 g
s
.57044 .53666 m .56387 .50817 L .5813 .50089 L p .575 .458 .682 r
F P
0 g
s
.57176 .47183 m .5813 .50089 L .56387 .50817 L p .571 .449 .674 r
F P
0 g
s
.52548 .36453 m .52586 .36606 L .5329 .36677 L p .263 0 0 r
F P
0 g
s
.74612 .49869 m .73413 .508 L .74733 .47466 L p .869 .992 .816 r
F P
0 g
s
.74733 .47466 m .76034 .46321 L .74612 .49869 L p .869 .992 .816 r
F P
0 g
s
.5813 .50089 m .57176 .47183 L .58319 .46363 L p .491 .402 .683 r
F P
0 g
s
.57136 .43659 m .58319 .46363 L .57176 .47183 L p .492 .404 .684 r
F P
0 g
s
.58319 .46363 m .57136 .43659 L .57736 .42872 L p .38 .344 .693 r
F P
0 g
s
.45393 .59285 m .46093 .57939 L .49032 .58664 L p .749 .686 .791 r
F P
0 g
s
.49417 .56638 m .49032 .58664 L .46093 .57939 L p .77 .649 .729 r
F P
0 g
s
.57044 .53666 m .57699 .56153 L .55035 .56723 L p .64 .514 .694 r
F P
0 g
s
.47031 .4183 m .48428 .39828 L .48552 .40482 L p .962 .901 .716 r
F P
0 g
s
.48552 .40482 m .47205 .42697 L .47031 .4183 L p .962 .901 .716 r
F P
0 g
s
.687 .55728 m .67637 .566 L .69774 .54187 L p .65 .933 .668 r
F P
0 g
s
.69774 .54187 m .71005 .53129 L .687 .55728 L p .65 .933 .668 r
F P
0 g
s
.26204 .44252 m .27559 .44697 L .28755 .48517 L p .497 .643 .921 r
F P
0 g
s
.29994 .49158 m .28755 .48517 L .27559 .44697 L p .297 .497 .883 r
F P
0 g
s
.45559 .52616 m .46572 .49905 L .4825 .50688 L p .828 .668 .684 r
F P
0 g
s
.4825 .50688 m .47526 .53518 L .45559 .52616 L p .828 .668 .684 r
F P
0 g
s
.18911 .47507 m .20426 .46408 L .22151 .51244 L p .878 .859 .818 r
F P
0 g
s
.22151 .51244 m .20758 .52532 L .18911 .47507 L p .878 .859 .818 r
F P
0 g
s
.55152 .37918 m .56496 .39307 L .56592 .39965 L p .09 .28 .762 r
F P
0 g
s
.56496 .39307 m .55152 .37918 L .54904 .37503 L p 0 .146 .685 r
F P
0 g
s
.63712 .59013 m .62828 .58962 L .65429 .57259 L p .672 .927 .972 r
F P
0 g
s
.65429 .57259 m .66548 .57163 L .63712 .59013 L p .672 .927 .972 r
F P
0 g
s
.46093 .57939 m .46806 .55986 L .49417 .56638 L p .77 .649 .729 r
F P
0 g
s
.45838 .45172 m .47205 .42697 L .47735 .43504 L p .934 .806 .695 r
F P
0 g
s
.47735 .43504 m .46512 .46171 L .45838 .45172 L p .934 .806 .695 r
F P
0 g
s
.45276 .48888 m .46512 .46171 L .47582 .47028 L p .882 .726 .685 r
F P
0 g
s
.47582 .47028 m .46572 .49905 L .45276 .48888 L p .882 .726 .685 r
F P
0 g
s
.49006 .38564 m .50192 .37422 L .49908 .37828 L p .725 .95 .65 r
F P
0 g
s
.49908 .37828 m .48582 .39173 L .49006 .38564 L p .725 .95 .65 r
F P
0 g
s
.58982 .59489 m .58346 .58125 L .6099 .57072 L p .621 .591 .799 r
F P
0 g
s
.6099 .57072 m .6192 .58331 L .58982 .59489 L p .621 .591 .799 r
F P
0 g
s
.57699 .56153 m .57044 .53666 L .59088 .52828 L p .583 .479 .701 r
F P
0 g
s
.5813 .50089 m .59088 .52828 L .57044 .53666 L p .575 .458 .682 r
F P
0 g
s
.41597 .58641 m .4256 .58039 L .45393 .59285 L p .677 .754 .909 r
F P
0 g
s
.46093 .57939 m .45393 .59285 L .4256 .58039 L p .775 .721 .801 r
F P
0 g
s
.36859 .56129 m .37989 .56728 L .4066 .58666 L p 0 .325 .762 r
F P
0 g
s
.41597 .58641 m .4066 .58666 L .37989 .56728 L p .355 .655 .969 r
F P
0 g
s
.54904 .37503 m .56126 .38685 L .56496 .39307 L p 0 .146 .685 r
F P
0 g
s
.56126 .38685 m .54904 .37503 L .54491 .37142 L p .541 .018 0 r
F P
0 g
s
.56592 .39965 m .57986 .42012 L .57736 .42872 L p .233 .289 .717 r
F P
0 g
s
.57986 .42012 m .56592 .39965 L .56496 .39307 L p 0 .162 .689 r
F P
0 g
s
.44547 .54968 m .45559 .52616 L .47526 .53518 L p .822 .677 .703 r
F P
0 g
s
.47526 .53518 m .46806 .55986 L .44547 .54968 L p .822 .677 .703 r
F P
0 g
s
.49675 .38043 m .50636 .37076 L .50192 .37422 L p 0 0 0 r
F P
0 g
s
.50192 .37422 m .49006 .38564 L .49675 .38043 L p 0 0 0 r
F P
0 g
s
.32446 .51314 m .33682 .52546 L .35756 .55221 L p 0 .094 .625 r
F P
0 g
s
.36859 .56129 m .35756 .55221 L .33682 .52546 L p 0 .189 .706 r
F P
0 g
s
.58346 .58125 m .57699 .56153 L .60043 .55207 L p .598 .518 .736 r
F P
0 g
s
.60043 .55207 m .6099 .57072 L .58346 .58125 L p .598 .518 .736 r
F P
0 g
s
.59088 .52828 m .60043 .55207 L .57699 .56153 L p .583 .479 .701 r
F P
0 g
s
.47231 .40961 m .48582 .39173 L .48428 .39828 L p .916 .969 .67 r
F P
0 g
s
.48428 .39828 m .47031 .4183 L .47231 .40961 L p .916 .969 .67 r
F P
0 g
s
.59088 .52828 m .5813 .50089 L .59514 .49116 L p .498 .414 .692 r
F P
0 g
s
.58319 .46363 m .59514 .49116 L .5813 .50089 L p .491 .402 .683 r
F P
0 g
s
.27559 .44697 m .28887 .45554 L .29994 .49158 L p .297 .497 .883 r
F P
0 g
s
.3122 .50131 m .29994 .49158 L .28887 .45554 L p .122 .358 .82 r
F P
0 g
s
.57736 .42872 m .5908 .45388 L .58319 .46363 L p .38 .344 .693 r
F P
0 g
s
.5908 .45388 m .57736 .42872 L .57986 .42012 L p .201 .256 .696 r
F P
0 g
s
.4256 .58039 m .43545 .56807 L .46093 .57939 L p .775 .721 .801 r
F P
0 g
s
.46806 .55986 m .46093 .57939 L .43545 .56807 L p .808 .694 .738 r
F P
0 g
s
.43545 .56807 m .44547 .54968 L .46806 .55986 L p .808 .694 .738 r
F P
0 g
s
.73413 .508 m .72215 .5194 L .73435 .48821 L p .871 .994 .758 r
F P
0 g
s
.73435 .48821 m .74733 .47466 L .73413 .508 L p .871 .994 .758 r
F P
0 g
s
.54491 .37142 m .55505 .38142 L .56126 .38685 L p .541 .018 0 r
F P
0 g
s
.55505 .38142 m .54491 .37142 L .5394 .3686 L p .666 .114 0 r
F P
0 g
s
.59514 .49116 m .58319 .46363 L .5908 .45388 L p .378 .342 .692 r
F P
0 g
s
.44033 .51443 m .45276 .48888 L .46572 .49905 L p .878 .729 .694 r
F P
0 g
s
.46572 .49905 m .45559 .52616 L .44033 .51443 L p .878 .729 .694 r
F P
0 g
s
.50542 .37647 m .51211 .36813 L .50636 .37076 L p .068 0 0 r
F P
0 g
s
.50636 .37076 m .49675 .38043 L .50542 .37647 L p .068 0 0 r
F P
0 g
s
.62828 .58962 m .6192 .58331 L .64281 .56774 L p .643 .73 .912 r
F P
0 g
s
.64281 .56774 m .65429 .57259 L .62828 .58962 L p .643 .73 .912 r
F P
0 g
s
.45611 .44095 m .47031 .4183 L .47205 .42697 L p .971 .901 .693 r
F P
0 g
s
.47205 .42697 m .45838 .45172 L .45611 .44095 L p .971 .901 .693 r
F P
0 g
s
.44454 .477 m .45838 .45172 L .46512 .46171 L p .934 .806 .694 r
F P
0 g
s
.46512 .46171 m .45276 .48888 L .44454 .477 L p .934 .806 .694 r
F P
0 g
s
.5394 .3686 m .54674 .37718 L .55505 .38142 L p .666 .114 0 r
F P
0 g
s
.54674 .37718 m .5394 .3686 L .5329 .36677 L p .653 .126 0 r
F P
0 g
s
.51549 .37406 m .51876 .36652 L .51211 .36813 L p .318 0 0 r
F P
0 g
s
.51211 .36813 m .50542 .37647 L .51549 .37406 L p .318 0 0 r
F P
0 g
s
.67637 .566 m .66548 .57163 L .68514 .54934 L p .735 .992 .844 r
F P
0 g
s
.68514 .54934 m .69774 .54187 L .67637 .566 L p .735 .992 .844 r
F P
0 g
s
.56496 .39307 m .57864 .41138 L .57986 .42012 L p 0 .162 .689 r
F P
0 g
s
.57864 .41138 m .56496 .39307 L .56126 .38685 L p 0 0 .524 r
F P
0 g
s
.60043 .55207 m .59088 .52828 L .60715 .51706 L p .512 .441 .713 r
F P
0 g
s
.59514 .49116 m .60715 .51706 L .59088 .52828 L p .498 .414 .692 r
F P
0 g
s
.5329 .36677 m .53691 .37442 L .54674 .37718 L p .653 .126 0 r
F P
0 g
s
.53691 .37442 m .5329 .36677 L .52586 .36606 L p .583 .084 .036 r
F P
0 g
s
.52624 .37335 m .52586 .36606 L .51876 .36652 L p .476 0 .042 r
F P
0 g
s
.51876 .36652 m .51549 .37406 L .52624 .37335 L p .476 0 .042 r
F P
0 g
s
.47796 .4015 m .49006 .38564 L .48582 .39173 L p .619 .845 .465 r
F P
0 g
s
.48582 .39173 m .47231 .40961 L .47796 .4015 L p .619 .845 .465 r
F P
0 g
s
.37989 .56728 m .39149 .56858 L .41597 .58641 L p .355 .655 .969 r
F P
0 g
s
.4256 .58039 m .41597 .58641 L .39149 .56858 L p .679 .76 .913 r
F P
0 g
s
.52586 .36606 m .52624 .37335 L .53691 .37442 L p .583 .084 .036 r
F P
0 g
s
.4279 .53641 m .44033 .51443 L .45559 .52616 L p .868 .736 .716 r
F P
0 g
s
.45559 .52616 m .44547 .54968 L .4279 .53641 L p .868 .736 .716 r
F P
0 g
s
.28887 .45554 m .30199 .46747 L .3122 .50131 L p .122 .358 .82 r
F P
0 g
s
.32446 .51314 m .3122 .50131 L .30199 .46747 L p .017 .271 .771 r
F P
0 g
s
.6192 .58331 m .6099 .57072 L .63107 .5566 L p .58 .577 .814 r
F P
0 g
s
.63107 .5566 m .64281 .56774 L .6192 .58331 L p .58 .577 .814 r
F P
0 g
s
.6099 .57072 m .60043 .55207 L .61916 .53939 L p .538 .49 .75 r
F P
0 g
s
.60715 .51706 m .61916 .53939 L .60043 .55207 L p .512 .441 .713 r
F P
0 g
s
.57986 .42012 m .59403 .44321 L .5908 .45388 L p .201 .256 .696 r
F P
0 g
s
.59403 .44321 m .57986 .42012 L .57864 .41138 L p 0 .104 .649 r
F P
0 g
s
.33682 .52546 m .3494 .53647 L .36859 .56129 L p 0 .189 .706 r
F P
0 g
s
.37989 .56728 m .36859 .56129 L .3494 .53647 L p .04 .4 .855 r
F P
0 g
s
.60715 .51706 m .59514 .49116 L .60441 .47957 L p .39 .359 .703 r
F P
0 g
s
.5908 .45388 m .60441 .47957 L .59514 .49116 L p .378 .342 .692 r
F P
0 g
s
.61916 .53939 m .63107 .5566 L .6099 .57072 L p .538 .49 .75 r
F P
0 g
s
.56126 .38685 m .57373 .4031 L .57864 .41138 L p 0 0 .524 r
F P
0 g
s
.57373 .4031 m .56126 .38685 L .55505 .38142 L p .724 .217 0 r
F P
0 g
s
.72215 .5194 m .71005 .53129 L .72128 .50226 L p .87 .992 .747 r
F P
0 g
s
.72128 .50226 m .73435 .48821 L .72215 .5194 L p .87 .992 .747 r
F P
0 g
s
.45854 .43013 m .47231 .40961 L .47031 .4183 L p .908 .957 .624 r
F P
0 g
s
.47031 .4183 m .45611 .44095 L .45854 .43013 L p .908 .957 .624 r
F P
0 g
s
.60441 .47957 m .5908 .45388 L .59403 .44321 L p .199 .253 .694 r
F P
0 g
s
.39149 .56858 m .4034 .56408 L .4256 .58039 L p .679 .76 .913 r
F P
0 g
s
.43545 .56807 m .4256 .58039 L .4034 .56408 L p .799 .761 .818 r
F P
0 g
s
.41556 .55328 m .4279 .53641 L .44547 .54968 L p .846 .747 .754 r
F P
0 g
s
.44547 .54968 m .43545 .56807 L .41556 .55328 L p .846 .747 .754 r
F P
0 g
s
.48692 .39454 m .49675 .38043 L .49006 .38564 L p 0 0 0 r
F P
0 g
s
.49006 .38564 m .47796 .4015 L .48692 .39454 L p 0 0 0 r
F P
0 g
s
.43058 .5007 m .44454 .477 L .45276 .48888 L p .928 .807 .706 r
F P
0 g
s
.45276 .48888 m .44033 .51443 L .43058 .5007 L p .928 .807 .706 r
F P
0 g
s
.4034 .56408 m .41556 .55328 L .43545 .56807 L p .799 .761 .818 r
F P
0 g
s
.44169 .46417 m .45611 .44095 L .45838 .45172 L p .972 .9 .691 r
F P
0 g
s
.45838 .45172 m .44454 .477 L .44169 .46417 L p .972 .9 .691 r
F P
0 g
s
.66548 .57163 m .65429 .57259 L .67222 .55211 L p .737 .918 .954 r
F P
0 g
s
.67222 .55211 m .68514 .54934 L .66548 .57163 L p .737 .918 .954 r
F P
0 g
s
.55505 .38142 m .56541 .39586 L .57373 .4031 L p .724 .217 0 r
F P
0 g
s
.56541 .39586 m .55505 .38142 L .54674 .37718 L p .771 .272 .022 r
F P
0 g
s
.49858 .38925 m .50542 .37647 L .49675 .38043 L p .206 0 .054 r
F P
0 g
s
.49675 .38043 m .48692 .39454 L .49858 .38925 L p .206 0 .054 r
F P
0 g
s
.61916 .53939 m .60715 .51706 L .61812 .50367 L p .416 .396 .728 r
F P
0 g
s
.60441 .47957 m .61812 .50367 L .60715 .51706 L p .39 .359 .703 r
F P
0 g
s
.30199 .46747 m .31507 .4815 L .32446 .51314 L p .017 .271 .771 r
F P
0 g
s
.33682 .52546 m .32446 .51314 L .31507 .4815 L p 0 .255 .761 r
F P
0 g
s
.57864 .41138 m .59258 .43234 L .59403 .44321 L p 0 .104 .649 r
F P
0 g
s
.59258 .43234 m .57864 .41138 L .57373 .4031 L p 0 0 .442 r
F P
0 g
s
.3494 .53647 m .36226 .54435 L .37989 .56728 L p .04 .4 .855 r
F P
0 g
s
.39149 .56858 m .37989 .56728 L .36226 .54435 L p .406 .636 .949 r
F P
0 g
s
.4656 .42 m .47796 .4015 L .47231 .40961 L p 0 0 0 r
F P
0 g
s
.47231 .40961 m .45854 .43013 L .4656 .42 L p 0 0 0 r
F P
0 g
s
.41659 .52085 m .43058 .5007 L .44033 .51443 L p .913 .811 .732 r
F P
0 g
s
.44033 .51443 m .4279 .53641 L .41659 .52085 L p .913 .811 .732 r
F P
0 g
s
.54674 .37718 m .55425 .39019 L .56541 .39586 L p .771 .272 .022 r
F P
0 g
s
.55425 .39019 m .54674 .37718 L .53691 .37442 L p .723 .257 .142 r
F P
0 g
s
.51214 .38601 m .51549 .37406 L .50542 .37647 L p .413 .008 .157 r
F P
0 g
s
.50542 .37647 m .49858 .38925 L .51214 .38601 L p .413 .008 .157 r
F P
0 g
s
.71005 .53129 m .69774 .54187 L .70801 .51498 L p .871 .995 .789 r
F P
0 g
s
.70801 .51498 m .72128 .50226 L .71005 .53129 L p .871 .995 .789 r
F P
0 g
s
.65429 .57259 m .64281 .56774 L .659 .54905 L p .637 .731 .916 r
F P
0 g
s
.659 .54905 m .67222 .55211 L .65429 .57259 L p .637 .731 .916 r
F P
0 g
s
.81481 .45607 m .80068 .45152 L .79989 .40745 L p .527 .639 .904 r
F P
0 g
s
.80068 .45152 m .78692 .45112 L .78585 .40929 L p .653 .744 .916 r
F P
0 g
s
.78585 .40929 m .79989 .40745 L .80068 .45152 L p .653 .744 .916 r
F P
0 g
s
.78692 .45112 m .7735 .4551 L .77218 .41555 L p .772 .836 .901 r
F P
0 g
s
.77218 .41555 m .78585 .40929 L .78692 .45112 L p .772 .836 .901 r
F P
0 g
s
.61812 .50367 m .60441 .47957 L .60841 .46687 L p .221 .278 .71 r
F P
0 g
s
.59403 .44321 m .60841 .46687 L .60441 .47957 L p .199 .253 .694 r
F P
0 g
s
.60841 .46687 m .59403 .44321 L .59258 .43234 L p 0 .099 .646 r
F P
0 g
s
.53691 .37442 m .54101 .3865 L .55425 .39019 L p .723 .257 .142 r
F P
0 g
s
.54101 .3865 m .53691 .37442 L .52624 .37335 L p .646 .207 .192 r
F P
0 g
s
.63107 .5566 m .61916 .53939 L .63185 .52423 L p .462 .461 .771 r
F P
0 g
s
.61812 .50367 m .63185 .52423 L .61916 .53939 L p .416 .396 .728 r
F P
0 g
s
.52663 .38507 m .52624 .37335 L .51549 .37406 L p .548 .128 .197 r
F P
0 g
s
.51549 .37406 m .51214 .38601 L .52663 .38507 L p .548 .128 .197 r
F P
0 g
s
.8293 .46407 m .81481 .45607 L .81435 .4098 L p .422 .548 .878 r
F P
0 g
s
.79989 .40745 m .81435 .4098 L .81481 .45607 L p .527 .639 .904 r
F P
0 g
s
.52624 .37335 m .52663 .38507 L .54101 .3865 L p .646 .207 .192 r
F P
0 g
s
.7735 .4551 m .76034 .46321 L .75881 .42597 L p .859 .895 .86 r
F P
0 g
s
.75881 .42597 m .77218 .41555 L .7735 .4551 L p .859 .895 .86 r
F P
0 g
s
.44453 .45124 m .45854 .43013 L .45611 .44095 L p .908 .956 .619 r
F P
0 g
s
.45611 .44095 m .44169 .46417 L .44453 .45124 L p .908 .956 .619 r
F P
0 g
s
.42712 .48583 m .44169 .46417 L .44454 .477 L p .965 .901 .708 r
F P
0 g
s
.44454 .477 m .43058 .5007 L .42712 .48583 L p .965 .901 .708 r
F P
0 g
s
.64281 .56774 m .63107 .5566 L .64551 .53967 L p .534 .568 .835 r
F P
0 g
s
.64551 .53967 m .659 .54905 L .64281 .56774 L p .534 .568 .835 r
F P
0 g
s
.36226 .54435 m .37544 .54753 L .39149 .56858 L p .406 .636 .949 r
F P
0 g
s
.4034 .56408 m .39149 .56858 L .37544 .54753 L p .679 .766 .917 r
F P
0 g
s
.63185 .52423 m .64551 .53967 L .63107 .5566 L p .462 .461 .771 r
F P
0 g
s
.40267 .5359 m .41659 .52085 L .4279 .53641 L p .882 .813 .776 r
F P
0 g
s
.4279 .53641 m .41556 .55328 L .40267 .5359 L p .882 .813 .776 r
F P
0 g
s
.57373 .4031 m .58646 .42201 L .59258 .43234 L p 0 0 .442 r
F P
0 g
s
.58646 .42201 m .57373 .4031 L .56541 .39586 L p .78 .289 0 r
F P
0 g
s
.31507 .4815 m .32823 .49601 L .33682 .52546 L p 0 .255 .761 r
F P
0 g
s
.3494 .53647 m .33682 .52546 L .32823 .49601 L p .07 .316 .798 r
F P
0 g
s
.84408 .47443 m .8293 .46407 L .82922 .41563 L p .355 .488 .855 r
F P
0 g
s
.81435 .4098 m .82922 .41563 L .8293 .46407 L p .422 .548 .878 r
F P
0 g
s
.47686 .4113 m .48692 .39454 L .47796 .4015 L p 0 0 0 r
F P
0 g
s
.47796 .4015 m .4656 .42 L .47686 .4113 L p 0 0 0 r
F P
0 g
s
.76034 .46321 m .74733 .47466 L .74563 .43975 L p .908 .922 .815 r
F P
0 g
s
.74563 .43975 m .75881 .42597 L .76034 .46321 L p .908 .922 .815 r
F P
0 g
s
.37544 .54753 m .38893 .54487 L .4034 .56408 L p .679 .766 .917 r
F P
0 g
s
.41556 .55328 m .4034 .56408 L .38893 .54487 L p .818 .807 .841 r
F P
0 g
s
.38893 .54487 m .40267 .5359 L .41556 .55328 L p .818 .807 .841 r
F P
0 g
s
.25294 .39827 m .26692 .40059 L .26204 .44252 L p .663 .753 .917 r
F P
0 g
s
.26204 .44252 m .24814 .44247 L .25294 .39827 L p .663 .753 .917 r
F P
0 g
s
.27559 .44697 m .26204 .44252 L .26692 .40059 L p .534 .634 .896 r
F P
0 g
s
.69774 .54187 m .68514 .54934 L .69447 .52454 L p .852 .976 .867 r
F P
0 g
s
.69447 .52454 m .70801 .51498 L .69774 .54187 L p .852 .976 .867 r
F P
0 g
s
.23854 .40015 m .25294 .39827 L .24814 .44247 L p .767 .843 .909 r
F P
0 g
s
.24814 .44247 m .23386 .44658 L .23854 .40015 L p .767 .843 .909 r
F P
0 g
s
.63185 .52423 m .61812 .50367 L .62293 .48896 L p .272 .334 .744 r
F P
0 g
s
.60841 .46687 m .62293 .48896 L .61812 .50367 L p .221 .278 .71 r
F P
0 g
s
.26692 .40059 m .28051 .40734 L .27559 .44697 L p .534 .634 .896 r
F P
0 g
s
.28887 .45554 m .27559 .44697 L .28051 .40734 L p .408 .514 .854 r
F P
0 g
s
.59258 .43234 m .60675 .45389 L .60841 .46687 L p 0 .099 .646 r
F P
0 g
s
.60675 .45389 m .59258 .43234 L .58646 .42201 L p 0 0 .435 r
F P
0 g
s
.85906 .48583 m .84408 .47443 L .84442 .42387 L p .329 .464 .845 r
F P
0 g
s
.82922 .41563 m .84442 .42387 L .84408 .47443 L p .355 .488 .855 r
F P
0 g
s
.22374 .40552 m .23854 .40015 L .23386 .44658 L p .833 .896 .885 r
F P
0 g
s
.23386 .44658 m .21921 .45415 L .22374 .40552 L p .833 .896 .885 r
F P
0 g
s
.56541 .39586 m .57602 .41296 L .58646 .42201 L p .78 .289 0 r
F P
0 g
s
.57602 .41296 m .56541 .39586 L .55425 .39019 L p .799 .324 .096 r
F P
0 g
s
.41247 .50396 m .42712 .48583 L .43058 .5007 L p .947 .901 .746 r
F P
0 g
s
.43058 .5007 m .41659 .52085 L .41247 .50396 L p .947 .901 .746 r
F P
0 g
s
.49157 .40467 m .49858 .38925 L .48692 .39454 L p .251 0 .125 r
F P
0 g
s
.48692 .39454 m .47686 .4113 L .49157 .40467 L p .251 0 .125 r
F P
0 g
s
.62293 .48896 m .60841 .46687 L .60675 .45389 L p 0 .142 .676 r
F P
0 g
s
.45299 .43911 m .4656 .42 L .45854 .43013 L p 0 0 0 r
F P
0 g
s
.45854 .43013 m .44453 .45124 L .45299 .43911 L p 0 0 0 r
F P
0 g
s
.74733 .47466 m .73435 .48821 L .73251 .45563 L p .929 .932 .785 r
F P
0 g
s
.73251 .45563 m .74563 .43975 L .74733 .47466 L p .929 .932 .785 r
F P
0 g
s
.32823 .49601 m .3416 .5092 L .3494 .53647 L p .07 .316 .798 r
F P
0 g
s
.36226 .54435 m .3494 .53647 L .3416 .5092 L p .232 .449 .865 r
F P
0 g
s
.28051 .40734 m .29381 .41825 L .28887 .45554 L p .408 .514 .854 r
F P
0 g
s
.30199 .46747 m .28887 .45554 L .29381 .41825 L p .312 .419 .811 r
F P
0 g
s
.43033 .47081 m .44453 .45124 L .44169 .46417 L p .913 .966 .655 r
F P
0 g
s
.44169 .46417 m .42712 .48583 L .43033 .47081 L p .913 .966 .655 r
F P
0 g
s
.20858 .41329 m .22374 .40552 L .21921 .45415 L p .867 .922 .862 r
F P
0 g
s
.21921 .45415 m .20426 .46408 L .20858 .41329 L p .867 .922 .862 r
F P
0 g
s
.68514 .54934 m .67222 .55211 L .68062 .52938 L p .774 .89 .928 r
F P
0 g
s
.68062 .52938 m .69447 .52454 L .68514 .54934 L p .774 .89 .928 r
F P
0 g
s
.55425 .39019 m .56195 .40585 L .57602 .41296 L p .799 .324 .096 r
F P
0 g
s
.56195 .40585 m .55425 .39019 L .54101 .3865 L p .742 .299 .201 r
F P
0 g
s
.84442 .42387 m .85986 .43317 L .85906 .48583 L p .329 .464 .845 r
F P
0 g
s
.64551 .53967 m .63185 .52423 L .63752 .50752 L p .356 .427 .797 r
F P
0 g
s
.62293 .48896 m .63752 .50752 L .63185 .52423 L p .272 .334 .744 r
F P
0 g
s
.5087 .40061 m .51214 .38601 L .49858 .38925 L p .443 .059 .214 r
F P
0 g
s
.49858 .38925 m .49157 .40467 L .5087 .40061 L p .443 .059 .214 r
F P
0 g
s
.39786 .51698 m .41247 .50396 L .41659 .52085 L p .908 .892 .802 r
F P
0 g
s
.41659 .52085 m .40267 .5359 L .39786 .51698 L p .908 .892 .802 r
F P
0 g
s
.54101 .3865 m .54522 .40122 L .56195 .40585 L p .742 .299 .201 r
F P
0 g
s
.54522 .40122 m .54101 .3865 L .52663 .38507 L p .664 .247 .244 r
F P
0 g
s
.29381 .41825 m .30691 .43252 L .30199 .46747 L p .312 .419 .811 r
F P
0 g
s
.31507 .4815 m .30199 .46747 L .30691 .43252 L p .257 .365 .783 r
F P
0 g
s
.52703 .39943 m .52663 .38507 L .51214 .38601 L p .569 .171 .248 r
F P
0 g
s
.51214 .38601 m .5087 .40061 L .52703 .39943 L p .569 .171 .248 r
F P
0 g
s
.67222 .55211 m .659 .54905 L .66646 .52835 L p .631 .733 .921 r
F P
0 g
s
.66646 .52835 m .68062 .52938 L .67222 .55211 L p .631 .733 .921 r
F P
0 g
s
.59944 .44152 m .60675 .45389 L p .58999 .42756 L 0 0 .435 r
F P
0 g
s
.62112 .47389 m .60675 .45389 L .59944 .44152 L p 0 0 .496 r
F P
0 g
s
.61262 .45949 m .62112 .47389 L p .606 .45132 L 0 0 .496 r
F P
0 g
s
.59944 .44152 m .61262 .45949 L p .606 .45132 L 0 0 .496 r
F P
0 g
s
.60675 .45389 m .62112 .47389 L .62293 .48896 L p 0 .142 .676 r
F P
0 g
s
.63558 .49036 m .62112 .47389 L .61262 .45949 L p 0 .074 .626 r
F P
0 g
s
.62592 .47393 m .63558 .49036 L p .62233 .47255 L 0 .074 .626 r
F P
0 g
s
.61262 .45949 m .62592 .47393 L p .62233 .47255 L 0 .074 .626 r
F P
0 g
s
.62592 .47393 m .61262 .45949 L p .6185 .46675 L .623 .101 0 r
F P
0 g
s
.60905 .45944 m .62592 .47393 L p .60973 .45827 L .623 .101 0 r
F P
0 g
s
.59789 .44682 m .60905 .45944 L p .60973 .45827 L .623 .101 0 r
F P
0 g
s
.60905 .45944 m .586 .44799 L p .60848 .4604 L .479 0 0 r
F P
0 g
s
.62592 .47393 m .60905 .45944 L p .62889 .47508 L 0 .202 .674 r
F P
0 g
s
.61262 .45949 m .59789 .44682 L p .6185 .46675 L .623 .101 0 r
F P
0 g
s
.62025 .4669 m .63926 .48325 L p .62671 .47336 L 0 .202 .674 r
F P
0 g
s
.60905 .45944 m .62025 .4669 L p .62671 .47336 L 0 .202 .674 r
F P
0 g
s
.62025 .4669 m .60905 .45944 L p .60848 .4604 L .479 0 0 r
F P
0 g
s
.59419 .45397 m .62025 .4669 L p .60601 .45904 L .479 0 0 r
F P
0 g
s
.586 .44799 m .59419 .45397 L p .60601 .45904 L .479 0 0 r
F P
0 g
s
.59419 .45397 m .586 .44799 L .55841 .44051 L p .516 0 0 r
F P
0 g
s
.56291 .4455 m .59419 .45397 L p .57928 .44836 L .516 0 0 r
F P
0 g
s
.55841 .44051 m .56291 .4455 L p .57928 .44836 L .516 0 0 r
F P
0 g
s
.52872 .44221 m .56291 .4455 L p .54846 .4422 L .464 0 0 r
F P
0 g
s
.52829 .4376 m .52872 .44221 L p .54846 .4422 L .464 0 0 r
F P
0 g
s
.49794 .43951 m .49426 .44438 L .52872 .44221 L p .351 0 0 r
F P
0 g
s
.52872 .44221 m .49426 .44438 L p .51407 .44222 L .238 .747 .878 r
F P
0 g
s
.52872 .44221 m .52829 .4376 L .49794 .43951 L p .351 0 0 r
F P
0 g
s
.52916 .44057 m .52872 .44221 L p .51407 .44222 L .238 .747 .878 r
F P
0 g
s
.56291 .4455 m .52872 .44221 L p .55072 .44337 L .151 .673 .881 r
F P
0 g
s
.56291 .4455 m .55841 .44051 L .52829 .4376 L p .464 0 0 r
F P
0 g
s
.56741 .44426 m .56291 .4455 L p .55072 .44337 L .151 .673 .881 r
F P
0 g
s
.59419 .45397 m .56291 .4455 L p .58538 .45019 L .13 .626 .909 r
F P
0 g
s
.60905 .45944 m .59789 .44682 L .57786 .43683 L p .716 .183 0 r
F P
0 g
s
.57786 .43683 m .586 .44799 L .60905 .45944 L p .716 .183 0 r
F P
0 g
s
.60237 .45373 m .59419 .45397 L p .58538 .45019 L .13 .626 .909 r
F P
0 g
s
.62025 .4669 m .59419 .45397 L p .61542 .46208 L .169 .6 .938 r
F P
0 g
s
.63142 .46819 m .62025 .4669 L p .61542 .46208 L .169 .6 .938 r
F P
0 g
s
.63926 .48325 m .62592 .47393 L p .62889 .47508 L 0 .202 .674 r
F P
0 g
s
.59944 .44152 m .58686 .43066 L p .60841 .45478 L .745 .243 0 r
F P
0 g
s
.61262 .45949 m .59944 .44152 L p .60841 .45478 L .745 .243 0 r
F P
0 g
s
.58646 .42201 m .59944 .44152 L p .58999 .42756 L 0 0 .435 r
F P
0 g
s
.59944 .44152 m .58646 .42201 L .57602 .41296 L p .785 .295 0 r
F P
0 g
s
.3416 .5092 m .35523 .51922 L .36226 .54435 L p .232 .449 .865 r
F P
0 g
s
.37544 .54753 m .36226 .54435 L .35523 .51922 L p .459 .622 .922 r
F P
0 g
s
.73435 .48821 m .72128 .50226 L .71933 .472 L p .933 .933 .779 r
F P
0 g
s
.71933 .472 m .73251 .45563 L .73435 .48821 L p .933 .933 .779 r
F P
0 g
s
.19318 .42214 m .20858 .41329 L .20426 .46408 L p .879 .93 .852 r
F P
0 g
s
.20426 .46408 m .18911 .47507 L .19318 .42214 L p .879 .93 .852 r
F P
0 g
s
.659 .54905 m .64551 .53967 L .65207 .52098 L p .478 .563 .863 r
F P
0 g
s
.63752 .50752 m .65207 .52098 L .64551 .53967 L p .356 .427 .797 r
F P
0 g
s
.52663 .38507 m .52703 .39943 L .54522 .40122 L p .664 .247 .244 r
F P
0 g
s
.65207 .52098 m .66646 .52835 L .659 .54905 L p .478 .563 .863 r
F P
0 g
s
.46657 .42867 m .47686 .4113 L .4656 .42 L p 0 0 0 r
F P
0 g
s
.4656 .42 m .45299 .43911 L .46657 .42867 L p 0 0 0 r
F P
0 g
s
.63752 .50752 m .62293 .48896 L .62112 .47389 L p .037 .235 .737 r
F P
0 g
s
.3834 .52392 m .39786 .51698 L .40267 .5359 L p .827 .858 .87 r
F P
0 g
s
.40267 .5359 m .38893 .54487 L .3834 .52392 L p .827 .858 .87 r
F P
0 g
s
.35523 .51922 m .36917 .52451 L .37544 .54753 L p .459 .622 .922 r
F P
0 g
s
.38893 .54487 m .37544 .54753 L .36917 .52451 L p .677 .772 .922 r
F P
0 g
s
.36917 .52451 m .3834 .52392 L .38893 .54487 L p .677 .772 .922 r
F P
0 g
s
.41603 .48685 m .43033 .47081 L .42712 .48583 L p .917 .979 .726 r
F P
0 g
s
.42712 .48583 m .41247 .50396 L .41603 .48685 L p .917 .979 .726 r
F P
0 g
s
.30691 .43252 m .31994 .4489 L .31507 .4815 L p .257 .365 .783 r
F P
0 g
s
.32823 .49601 m .31507 .4815 L .31994 .4489 L p .248 .356 .778 r
F P
0 g
s
.44018 .45669 m .45299 .43911 L .44453 .45124 L p .599 .824 .434 r
F P
0 g
s
.44453 .45124 m .43033 .47081 L .44018 .45669 L p .599 .824 .434 r
F P
0 g
s
.72128 .50226 m .70801 .51498 L .70598 .487 L p .919 .928 .801 r
F P
0 g
s
.70598 .487 m .71933 .472 L .72128 .50226 L p .919 .928 .801 r
F P
0 g
s
.57602 .41296 m .58686 .43066 L .59944 .44152 L p .785 .295 0 r
F P
0 g
s
.58686 .43066 m .57602 .41296 L .56195 .40585 L p .801 .329 .102 r
F P
0 g
s
.48439 .4207 m .49157 .40467 L .47686 .4113 L p .254 0 .131 r
F P
0 g
s
.47686 .4113 m .46657 .42867 L .48439 .4207 L p .254 0 .131 r
F P
0 g
s
.65207 .52098 m .63752 .50752 L .63558 .49036 L p .199 .381 .819 r
F P
0 g
s
.62112 .47389 m .63558 .49036 L .63752 .50752 L p .037 .235 .737 r
F P
0 g
s
.31994 .4489 m .33302 .46575 L .32823 .49601 L p .248 .356 .778 r
F P
0 g
s
.3416 .5092 m .32823 .49601 L .33302 .46575 L p .285 .393 .798 r
F P
0 g
s
.70801 .51498 m .69447 .52454 L .69238 .49882 L p .877 .908 .847 r
F P
0 g
s
.69238 .49882 m .70598 .487 L .70801 .51498 L p .877 .908 .847 r
F P
0 g
s
.56195 .40585 m .56983 .42212 L .58686 .43066 L p .801 .329 .102 r
F P
0 g
s
.56983 .42212 m .56195 .40585 L .54522 .40122 L p .743 .303 .206 r
F P
0 g
s
.40172 .49778 m .41603 .48685 L .41247 .50396 L p .896 .971 .821 r
F P
0 g
s
.41247 .50396 m .39786 .51698 L .40172 .49778 L p .896 .971 .821 r
F P
0 g
s
.50518 .41581 m .5087 .40061 L .49157 .40467 L p .445 .063 .218 r
F P
0 g
s
.49157 .40467 m .48439 .4207 L .50518 .41581 L p .445 .063 .218 r
F P
0 g
s
.4561 .4445 m .46657 .42867 L .45299 .43911 L p 0 0 0 r
F P
0 g
s
.45299 .43911 m .44018 .45669 L .4561 .4445 L p 0 0 0 r
F P
0 g
s
.79989 .40745 m .78585 .40929 L .76617 .36817 L p .653 .745 .917 r
F P
0 g
s
.78585 .40929 m .77218 .41555 L .75327 .37677 L p .771 .802 .878 r
F P
0 g
s
.75327 .37677 m .76617 .36817 L .78585 .40929 L p .771 .802 .878 r
F P
0 g
s
.66646 .52835 m .65207 .52098 L .65003 .50172 L p .411 .564 .896 r
F P
0 g
s
.63558 .49036 m .65003 .50172 L .65207 .52098 L p .199 .381 .819 r
F P
0 g
s
.77218 .41555 m .75881 .42597 L .74067 .38954 L p .847 .829 .83 r
F P
0 g
s
.74067 .38954 m .75327 .37677 L .77218 .41555 L p .847 .829 .83 r
F P
0 g
s
.54522 .40122 m .54954 .41654 L .56983 .42212 L p .743 .303 .206 r
F P
0 g
s
.54954 .41654 m .54522 .40122 L .52703 .39943 L p .665 .251 .248 r
F P
0 g
s
.69447 .52454 m .68062 .52938 L .67851 .50585 L p .787 .853 .9 r
F P
0 g
s
.67851 .50585 m .69238 .49882 L .69447 .52454 L p .787 .853 .9 r
F P
0 g
s
.52745 .41438 m .52703 .39943 L .5087 .40061 L p .571 .174 .252 r
F P
0 g
s
.5087 .40061 m .50518 .41581 L .52745 .41438 L p .571 .174 .252 r
F P
0 g
s
.33302 .46575 m .34627 .48123 L .3416 .5092 L p .285 .393 .798 r
F P
0 g
s
.35523 .51922 m .3416 .5092 L .34627 .48123 L p .371 .48 .841 r
F P
0 g
s
.42724 .47073 m .41427 .47963 L .4238 .47235 L p .478 .855 .633 r
F P
0 g
s
.42724 .47073 m .44018 .45669 L .43193 .46852 L p .684 .913 .58 r
F P
0 g
s
.44018 .45669 m .42724 .47073 L .44551 .45678 L p 0 0 0 r
F P
0 g
s
.4238 .47235 m .43486 .4639 L p .42724 .47073 L .478 .855 .633 r
F P
0 g
s
.43193 .46852 m .43033 .47081 L p .42724 .47073 L .684 .913 .58 r
F P
0 g
s
.43033 .47081 m .41603 .48685 L .42724 .47073 L p .684 .913 .58 r
F P
0 g
s
.81435 .4098 m .79989 .40745 L .77947 .36402 L p .499 .656 .93 r
F P
0 g
s
.76617 .36817 m .77947 .36402 L .79989 .40745 L p .653 .745 .917 r
F P
0 g
s
.52703 .39943 m .52745 .41438 L .54954 .41654 L p .665 .251 .248 r
F P
0 g
s
.75881 .42597 m .74563 .43975 L .72828 .40568 L p .888 .84 .791 r
F P
0 g
s
.72828 .40568 m .74067 .38954 L .75881 .42597 L p .888 .84 .791 r
F P
0 g
s
.68062 .52938 m .66646 .52835 L .66437 .50698 L p .627 .737 .926 r
F P
0 g
s
.65003 .50172 m .66437 .50698 L .66646 .52835 L p .411 .564 .896 r
F P
0 g
s
.66437 .50698 m .67851 .50585 L .68062 .52938 L p .627 .737 .926 r
F P
0 g
s
.38752 .50259 m .40172 .49778 L .39786 .51698 L p .818 .909 .902 r
F P
0 g
s
.39786 .51698 m .3834 .52392 L .38752 .50259 L p .818 .909 .902 r
F P
0 g
s
.82922 .41563 m .81435 .4098 L .79319 .36408 L p .347 .557 .913 r
F P
0 g
s
.77947 .36402 m .79319 .36408 L .81435 .4098 L p .499 .656 .93 r
F P
0 g
s
.34627 .48123 m .35976 .49352 L .35523 .51922 L p .371 .48 .841 r
F P
0 g
s
.36917 .52451 m .35523 .51922 L .35976 .49352 L p .508 .616 .894 r
F P
0 g
s
.74563 .43975 m .73251 .45563 L .71598 .42391 L p .907 .842 .769 r
F P
0 g
s
.71598 .42391 m .72828 .40568 L .74563 .43975 L p .907 .842 .769 r
F P
0 g
s
.58686 .43066 m .59789 .44682 L .61262 .45949 L p .745 .243 0 r
F P
0 g
s
.59789 .44682 m .58686 .43066 L .56983 .42212 L p .782 .291 .049 r
F P
0 g
s
.29048 .36002 m .30309 .36909 L .28051 .40734 L p .569 .631 .873 r
F P
0 g
s
.28051 .40734 m .26692 .40059 L .29048 .36002 L p .569 .631 .873 r
F P
0 g
s
.29381 .41825 m .28051 .40734 L .30309 .36909 L p .491 .53 .825 r
F P
0 g
s
.37351 .50102 m .38752 .50259 L .3834 .52392 L p .674 .777 .927 r
F P
0 g
s
.3834 .52392 m .36917 .52451 L .37351 .50102 L p .674 .777 .927 r
F P
0 g
s
.27748 .35539 m .29048 .36002 L .26692 .40059 L p .662 .753 .918 r
F P
0 g
s
.26692 .40059 m .25294 .39827 L .27748 .35539 L p .662 .753 .918 r
F P
0 g
s
.35976 .49352 m .37351 .50102 L .36917 .52451 L p .508 .616 .894 r
F P
0 g
s
.47706 .43517 m .48439 .4207 L .46657 .42867 L p .223 0 .08 r
F P
0 g
s
.46657 .42867 m .4561 .4445 L .47706 .43517 L p .223 0 .08 r
F P
0 g
s
.30309 .36909 m .3154 .38234 L .29381 .41825 L p .491 .53 .825 r
F P
0 g
s
.30691 .43252 m .29381 .41825 L .3154 .38234 L p .437 .46 .786 r
F P
0 g
s
.65003 .50172 m .63558 .49036 L .62592 .47393 L p 0 .309 .801 r
F P
0 g
s
.26406 .35499 m .27748 .35539 L .25294 .39827 L p .746 .867 .935 r
F P
0 g
s
.25294 .39827 m .23854 .40015 L .26406 .35499 L p .746 .867 .935 r
F P
0 g
s
.84442 .42387 m .82922 .41563 L .80733 .36766 L p .238 .479 .886 r
F P
0 g
s
.79319 .36408 m .80733 .36766 L .82922 .41563 L p .347 .557 .913 r
F P
0 g
s
.73251 .45563 m .71933 .472 L .70364 .4426 L p .91 .842 .765 r
F P
0 g
s
.70364 .4426 m .71598 .42391 L .73251 .45563 L p .91 .842 .765 r
F P
0 g
s
.41427 .47963 m .42724 .47073 L .41603 .48685 L p .776 .994 .786 r
F P
0 g
s
.41603 .48685 m .40172 .49778 L .41427 .47963 L p .776 .994 .786 r
F P
0 g
s
.3154 .38234 m .3275 .39895 L .30691 .43252 L p .437 .46 .786 r
F P
0 g
s
.31994 .4489 m .30691 .43252 L .3275 .39895 L p .408 .423 .764 r
F P
0 g
s
.25022 .35811 m .26406 .35499 L .23854 .40015 L p .8 .942 .92 r
F P
0 g
s
.23854 .40015 m .22374 .40552 L .25022 .35811 L p .8 .942 .92 r
F P
0 g
s
.44551 .45678 m .4561 .4445 L .44018 .45669 L p 0 0 0 r
F P
0 g
s
.56983 .42212 m .57786 .43683 L .59789 .44682 L p .782 .291 .049 r
F P
0 g
s
.57786 .43683 m .56983 .42212 L .54954 .41654 L p .73 .272 .164 r
F P
0 g
s
.50159 .42944 m .50518 .41581 L .48439 .4207 L p .424 .026 .178 r
F P
0 g
s
.48439 .4207 m .47706 .43517 L .50159 .42944 L p .424 .026 .178 r
F P
0 g
s
.71933 .472 m .70598 .487 L .69118 .45989 L p .898 .841 .781 r
F P
0 g
s
.69118 .45989 m .70364 .4426 L .71933 .472 L p .898 .841 .781 r
F P
0 g
s
.3275 .39895 m .33951 .41765 L .31994 .4489 L p .408 .423 .764 r
F P
0 g
s
.33302 .46575 m .31994 .4489 L .33951 .41765 L p .403 .417 .761 r
F P
0 g
s
.66437 .50698 m .65003 .50172 L .63926 .48325 L p .332 .571 .927 r
F P
0 g
s
.62592 .47393 m .63926 .48325 L .65003 .50172 L p 0 .309 .801 r
F P
0 g
s
.85986 .43317 m .84442 .42387 L .82183 .37367 L p .192 .446 .872 r
F P
0 g
s
.80733 .36766 m .82183 .37367 L .84442 .42387 L p .238 .479 .886 r
F P
0 g
s
.54954 .41654 m .55394 .43031 L .57786 .43683 L p .73 .272 .164 r
F P
0 g
s
.55394 .43031 m .54954 .41654 L .52745 .41438 L p .653 .222 .211 r
F P
0 g
s
.52787 .42778 m .52745 .41438 L .50518 .41581 L p .556 .144 .215 r
F P
0 g
s
.50518 .41581 m .50159 .42944 L .52787 .42778 L p .556 .144 .215 r
F P
0 g
s
.23601 .36365 m .25022 .35811 L .22374 .40552 L p .821 .977 .891 r
F P
0 g
s
.22374 .40552 m .20858 .41329 L .23601 .36365 L p .821 .977 .891 r
F P
0 g
s
.52745 .41438 m .52787 .42778 L .55394 .43031 L p .653 .222 .211 r
F P
0 g
s
.40136 .48239 m .41427 .47963 L .40172 .49778 L p .776 .949 .932 r
F P
0 g
s
.40172 .49778 m .38752 .50259 L .40136 .48239 L p .776 .949 .932 r
F P
0 g
s
.70598 .487 m .69238 .49882 L .67852 .47394 L p .863 .835 .818 r
F P
0 g
s
.67852 .47394 m .69118 .45989 L .70598 .487 L p .863 .835 .818 r
F P
0 g
s
.33951 .41765 m .35154 .43681 L .33302 .46575 L p .403 .417 .761 r
F P
0 g
s
.34627 .48123 m .33302 .46575 L .35154 .43681 L p .422 .442 .776 r
F P
0 g
s
.67851 .50585 m .66437 .50698 L .65252 .48641 L p .624 .742 .932 r
F P
0 g
s
.63926 .48325 m .65252 .48641 L .66437 .50698 L p .332 .571 .927 r
F P
0 g
s
.69238 .49882 m .67851 .50585 L .66562 .48316 L p .785 .813 .874 r
F P
0 g
s
.66562 .48316 m .67852 .47394 L .69238 .49882 L p .785 .813 .874 r
F P
0 g
s
.46964 .44609 m .47706 .43517 L .4561 .4445 L p .131 0 0 r
F P
0 g
s
.4561 .4445 m .44551 .45678 L .46964 .44609 L p .131 0 0 r
F P
0 g
s
.65252 .48641 m .66562 .48316 L .67851 .50585 L p .624 .742 .932 r
F P
0 g
s
.82183 .37367 m .8366 .38074 L .85986 .43317 L p .192 .446 .872 r
F P
0 g
s
.35154 .43681 m .3637 .45456 L .34627 .48123 L p .422 .442 .776 r
F P
0 g
s
.35976 .49352 m .34627 .48123 L .3637 .45456 L p .47 .505 .812 r
F P
0 g
s
.3886 .47871 m .40136 .48239 L .38752 .50259 L p .668 .78 .933 r
F P
0 g
s
.38752 .50259 m .37351 .50102 L .3886 .47871 L p .668 .78 .933 r
F P
0 g
s
.43486 .4639 m .44551 .45678 L .42724 .47073 L p .478 .855 .633 r
F P
0 g
s
.22154 .37026 m .23601 .36365 L .20858 .41329 L p .827 .987 .874 r
F P
0 g
s
.20858 .41329 m .19318 .42214 L .22154 .37026 L p .827 .987 .874 r
F P
0 g
s
.3637 .45456 m .37604 .46906 L .35976 .49352 L p .47 .505 .812 r
F P
0 g
s
.37351 .50102 m .35976 .49352 L .37604 .46906 L p .551 .615 .87 r
F P
0 g
s
.37604 .46906 m .3886 .47871 L .37351 .50102 L p .551 .615 .87 r
F P
0 g
s
.586 .44799 m .57786 .43683 L .55394 .43031 L p .686 .184 .043 r
F P
0 g
s
.49794 .43951 m .50159 .42944 L .47706 .43517 L p .362 0 .062 r
F P
0 g
s
.47706 .43517 m .46964 .44609 L .49794 .43951 L p .362 0 .062 r
F P
0 g
s
.76617 .36817 m .75327 .37677 L .71707 .34178 L p .762 .77 .859 r
F P
0 g
s
.75327 .37677 m .74067 .38954 L .70629 .35675 L p .822 .772 .806 r
F P
0 g
s
.70629 .35675 m .71707 .34178 L .75327 .37677 L p .822 .772 .806 r
F P
0 g
s
.74067 .38954 m .72828 .40568 L .6957 .37507 L p .852 .768 .769 r
F P
0 g
s
.6957 .37507 m .70629 .35675 L .74067 .38954 L p .852 .768 .769 r
F P
0 g
s
.65252 .48641 m .63926 .48325 L .62025 .4669 L p .246 .583 .945 r
F P
0 g
s
.77947 .36402 m .76617 .36817 L .72815 .33099 L p .653 .746 .919 r
F P
0 g
s
.71707 .34178 m .72815 .33099 L .76617 .36817 L p .762 .77 .859 r
F P
0 g
s
.72828 .40568 m .71598 .42391 L .6852 .39547 L p .866 .765 .749 r
F P
0 g
s
.6852 .39547 m .6957 .37507 L .72828 .40568 L p .866 .765 .749 r
F P
0 g
s
.55394 .43031 m .55841 .44051 L .586 .44799 L p .686 .184 .043 r
F P
0 g
s
.55841 .44051 m .55394 .43031 L .52787 .42778 L p .612 .139 .105 r
F P
0 g
s
.42424 .46483 m .43486 .4639 L .41427 .47963 L p .685 .959 .946 r
F P
0 g
s
.41427 .47963 m .40136 .48239 L .42424 .46483 L p .685 .959 .946 r
F P
0 g
s
.52829 .4376 m .52787 .42778 L .50159 .42944 L p .509 .056 .11 r
F P
0 g
s
.50159 .42944 m .49794 .43951 L .52829 .4376 L p .509 .056 .11 r
F P
0 g
s
.79319 .36408 m .77947 .36402 L .73958 .32465 L p .477 .681 .955 r
F P
0 g
s
.72815 .33099 m .73958 .32465 L .77947 .36402 L p .653 .746 .919 r
F P
0 g
s
.71598 .42391 m .70364 .4426 L .6747 .4163 L p .868 .764 .745 r
F P
0 g
s
.6747 .4163 m .6852 .39547 L .71598 .42391 L p .868 .764 .745 r
F P
0 g
s
.46217 .45182 m .46964 .44609 L .44551 .45678 L p 0 0 0 r
F P
0 g
s
.44551 .45678 m .43486 .4639 L .46217 .45182 L p 0 0 0 r
F P
0 g
s
.52787 .42778 m .52829 .4376 L .55841 .44051 L p .612 .139 .105 r
F P
0 g
s
.33212 .32407 m .34269 .33528 L .30309 .36909 L p .602 .634 .856 r
F P
0 g
s
.30309 .36909 m .29048 .36002 L .33212 .32407 L p .602 .634 .856 r
F P
0 g
s
.3154 .38234 m .30309 .36909 L .34269 .33528 L p .554 .548 .801 r
F P
0 g
s
.34269 .33528 m .35297 .35066 L .3154 .38234 L p .554 .548 .801 r
F P
0 g
s
.3275 .39895 m .3154 .38234 L .35297 .35066 L p .524 .493 .765 r
F P
0 g
s
.66562 .48316 m .65252 .48641 L .63142 .46819 L p .623 .748 .936 r
F P
0 g
s
.62025 .4669 m .63142 .46819 L .65252 .48641 L p .246 .583 .945 r
F P
0 g
s
.32121 .31732 m .33212 .32407 L .29048 .36002 L p .661 .753 .919 r
F P
0 g
s
.29048 .36002 m .27748 .35539 L .32121 .31732 L p .661 .753 .919 r
F P
0 g
s
.35297 .35066 m .36307 .3694 L .3275 .39895 L p .524 .493 .765 r
F P
0 g
s
.33951 .41765 m .3275 .39895 L .36307 .3694 L p .508 .466 .745 r
F P
0 g
s
.70364 .4426 m .69118 .45989 L .66412 .43569 L p .859 .767 .759 r
F P
0 g
s
.66412 .43569 m .6747 .4163 L .70364 .4426 L p .859 .767 .759 r
F P
0 g
s
.80733 .36766 m .79319 .36408 L .75141 .32255 L p .265 .573 .939 r
F P
0 g
s
.73958 .32465 m .75141 .32255 L .79319 .36408 L p .477 .681 .955 r
F P
0 g
s
.36307 .3694 m .37306 .39021 L .33951 .41765 L p .508 .466 .745 r
F P
0 g
s
.35154 .43681 m .33951 .41765 L .37306 .39021 L p .505 .461 .742 r
F P
0 g
s
.41373 .45928 m .42424 .46483 L .40136 .48239 L p .662 .781 .937 r
F P
0 g
s
.40136 .48239 m .3886 .47871 L .41373 .45928 L p .662 .781 .937 r
F P
0 g
s
.67852 .47394 m .66562 .48316 L .64248 .463 L p .774 .775 .854 r
F P
0 g
s
.63142 .46819 m .64248 .463 L .66562 .48316 L p .623 .748 .936 r
F P
0 g
s
.69118 .45989 m .67852 .47394 L .65338 .45179 L p .834 .772 .793 r
F P
0 g
s
.65338 .45179 m .66412 .43569 L .69118 .45989 L p .834 .772 .793 r
F P
0 g
s
.30992 .3148 m .32121 .31732 L .27748 .35539 L p .711 .881 .96 r
F P
0 g
s
.27748 .35539 m .26406 .35499 L .30992 .3148 L p .711 .881 .96 r
F P
0 g
s
.64248 .463 m .65338 .45179 L .67852 .47394 L p .774 .775 .854 r
F P
0 g
s
.37306 .39021 m .38306 .41144 L .35154 .43681 L p .505 .461 .742 r
F P
0 g
s
.3637 .45456 m .35154 .43681 L .38306 .41144 L p .516 .48 .755 r
F P
0 g
s
.49426 .44438 m .49794 .43951 L .46964 .44609 L p .169 0 0 r
F P
0 g
s
.46964 .44609 m .46217 .45182 L .49426 .44438 L p .169 0 0 r
F P
0 g
s
.40335 .4477 m .41373 .45928 L .3886 .47871 L p .59 .62 .85 r
F P
0 g
s
.3886 .47871 m .37604 .46906 L .40335 .4477 L p .59 .62 .85 r
F P
0 g
s
.38306 .41144 m .39314 .43122 L .3637 .45456 L p .516 .48 .755 r
F P
0 g
s
.37604 .46906 m .3637 .45456 L .39314 .43122 L p .542 .528 .789 r
F P
0 g
s
.39314 .43122 m .40335 .4477 L .37604 .46906 L p .542 .528 .789 r
F P
0 g
s
.45471 .45132 m .46217 .45182 L .43486 .4639 L p .543 .92 .933 r
F P
0 g
s
.43486 .4639 m .42424 .46483 L .45471 .45132 L p .543 .92 .933 r
F P
0 g
s
.29825 .31581 m .30992 .3148 L .26406 .35499 L p .719 .962 .942 r
F P
0 g
s
.26406 .35499 m .25022 .35811 L .29825 .31581 L p .719 .962 .942 r
F P
0 g
s
.82183 .37367 m .80733 .36766 L .76363 .32398 L p .094 .469 .891 r
F P
0 g
s
.75141 .32255 m .76363 .32398 L .80733 .36766 L p .265 .573 .939 r
F P
0 g
s
.64248 .463 m .63142 .46819 L .60237 .45373 L p .624 .755 .94 r
F P
0 g
s
.59419 .45397 m .60237 .45373 L .63142 .46819 L p .169 .6 .938 r
F P
0 g
s
.28625 .31925 m .29825 .31581 L .25022 .35811 L p .693 .981 .886 r
F P
0 g
s
.25022 .35811 m .23601 .36365 L .28625 .31925 L p .693 .981 .886 r
F P
0 g
s
.44731 .44431 m .45471 .45132 L .42424 .46483 L p .654 .781 .941 r
F P
0 g
s
.42424 .46483 m .41373 .45928 L .44731 .44431 L p .654 .781 .941 r
F P
0 g
s
.8366 .38074 m .82183 .37367 L .77619 .32783 L p .021 .42 .862 r
F P
0 g
s
.76363 .32398 m .77619 .32783 L .82183 .37367 L p .094 .469 .891 r
F P
0 g
s
.71707 .34178 m .70629 .35675 L .65754 .3304 L p .792 .723 .788 r
F P
0 g
s
.70629 .35675 m .6957 .37507 L .6497 .35053 L p .813 .71 .752 r
F P
0 g
s
.6497 .35053 m .65754 .3304 L .70629 .35675 L p .813 .71 .752 r
F P
0 g
s
.6957 .37507 m .6852 .39547 L .64194 .37271 L p .822 .703 .734 r
F P
0 g
s
.64194 .37271 m .6497 .35053 L .6957 .37507 L p .822 .703 .734 r
F P
0 g
s
.49059 .443 m .49426 .44438 L .46217 .45182 L p .38 .839 .902 r
F P
0 g
s
.46217 .45182 m .45471 .45132 L .49059 .443 L p .38 .839 .902 r
F P
0 g
s
.72815 .33099 m .71707 .34178 L .66555 .31362 L p .747 .74 .845 r
F P
0 g
s
.65754 .3304 m .66555 .31362 L .71707 .34178 L p .792 .723 .788 r
F P
0 g
s
.65338 .45179 m .64248 .463 L .61048 .44698 L p .757 .741 .838 r
F P
0 g
s
.60237 .45373 m .61048 .44698 L .64248 .463 L p .624 .755 .94 r
F P
0 g
s
.6852 .39547 m .6747 .4163 L .63419 .39529 L p .823 .702 .73 r
F P
0 g
s
.63419 .39529 m .64194 .37271 L .6852 .39547 L p .823 .702 .73 r
F P
0 g
s
.6747 .4163 m .66412 .43569 L .62639 .41639 L p .817 .707 .743 r
F P
0 g
s
.62639 .41639 m .63419 .39529 L .6747 .4163 L p .817 .707 .743 r
F P
0 g
s
.73958 .32465 m .72815 .33099 L .67378 .301 L p .653 .748 .919 r
F P
0 g
s
.66555 .31362 m .67378 .301 L .72815 .33099 L p .747 .74 .845 r
F P
0 g
s
.66412 .43569 m .65338 .45179 L .61849 .43416 L p .8 .72 .775 r
F P
0 g
s
.61048 .44698 m .61849 .43416 L .65338 .45179 L p .757 .741 .838 r
F P
0 g
s
.39699 .30889 m .40431 .32598 L .35297 .35066 L p .606 .568 .785 r
F P
0 g
s
.35297 .35066 m .34269 .33528 L .39699 .30889 L p .606 .568 .785 r
F P
0 g
s
.36307 .3694 m .35297 .35066 L .40431 .32598 L p .589 .524 .749 r
F P
0 g
s
.43999 .43121 m .44731 .44431 L .41373 .45928 L p .625 .63 .835 r
F P
0 g
s
.41373 .45928 m .40335 .4477 L .43999 .43121 L p .625 .63 .835 r
F P
0 g
s
.61849 .43416 m .62639 .41639 L .66412 .43569 L p .8 .72 .775 r
F P
0 g
s
.40431 .32598 m .41148 .34641 L .36307 .3694 L p .589 .524 .749 r
F P
0 g
s
.37306 .39021 m .36307 .3694 L .41148 .34641 L p .581 .502 .731 r
F P
0 g
s
.56291 .4455 m .56741 .44426 L .60237 .45373 L p .13 .626 .909 r
F P
0 g
s
.38946 .29596 m .39699 .30889 L .34269 .33528 L p .632 .642 .842 r
F P
0 g
s
.34269 .33528 m .33212 .32407 L .38946 .29596 L p .632 .642 .842 r
F P
0 g
s
.41148 .34641 m .41857 .3689 L .37306 .39021 L p .581 .502 .731 r
F P
0 g
s
.38306 .41144 m .37306 .39021 L .41857 .3689 L p .579 .499 .728 r
F P
0 g
s
.49426 .44438 m .49059 .443 L .52916 .44057 L p .238 .747 .878 r
F P
0 g
s
.27399 .32374 m .28625 .31925 L .23601 .36365 L p .674 .977 .851 r
F P
0 g
s
.23601 .36365 m .22154 .37026 L .27399 .32374 L p .674 .977 .851 r
F P
0 g
s
.41857 .3689 m .42565 .39177 L .38306 .41144 L p .579 .499 .728 r
F P
0 g
s
.39314 .43122 m .38306 .41144 L .42565 .39177 L p .585 .513 .74 r
F P
0 g
s
.43278 .41317 m .43999 .43121 L .40335 .4477 L p .599 .552 .772 r
F P
0 g
s
.40335 .4477 m .39314 .43122 L .43278 .41317 L p .599 .552 .772 r
F P
0 g
s
.77619 .32783 m .78901 .33274 L .8366 .38074 L p .021 .42 .862 r
F P
0 g
s
.61048 .44698 m .60237 .45373 L .56741 .44426 L p .627 .762 .943 r
F P
0 g
s
.52872 .44221 m .52916 .44057 L .56741 .44426 L p .151 .673 .881 r
F P
0 g
s
.42565 .39177 m .43278 .41317 L .39314 .43122 L p .585 .513 .74 r
F P
0 g
s
.75141 .32255 m .73958 .32465 L .68229 .29285 L p .466 .713 .976 r
F P
0 g
s
.67378 .301 m .68229 .29285 L .73958 .32465 L p .653 .748 .919 r
F P
0 g
s
.38167 .28749 m .38946 .29596 L .33212 .32407 L p .659 .753 .92 r
F P
0 g
s
.33212 .32407 m .32121 .31732 L .38167 .28749 L p .659 .753 .92 r
F P
0 g
s
.48694 .43506 m .49059 .443 L .45471 .45132 L p .646 .778 .944 r
F P
0 g
s
.45471 .45132 m .44731 .44431 L .48694 .43506 L p .646 .778 .944 r
F P
0 g
s
.3736 .28325 m .38167 .28749 L .32121 .31732 L p .66 .879 .98 r
F P
0 g
s
.32121 .31732 m .30992 .3148 L .3736 .28325 L p .66 .879 .98 r
F P
0 g
s
.61849 .43416 m .61048 .44698 L .57187 .43646 L p .735 .711 .828 r
F P
0 g
s
.56741 .44426 m .57187 .43646 L .61048 .44698 L p .627 .762 .943 r
F P
0 g
s
.57187 .43646 m .56741 .44426 L .52916 .44057 L p .632 .768 .945 r
F P
0 g
s
.76363 .32398 m .75141 .32255 L .69111 .28892 L p .19 .597 .944 r
F P
0 g
s
.68229 .29285 m .69111 .28892 L .75141 .32255 L p .466 .713 .976 r
F P
0 g
s
.48333 .42102 m .48694 .43506 L .44731 .44431 L p .657 .644 .826 r
F P
0 g
s
.44731 .44431 m .43999 .43121 L .48333 .42102 L p .657 .644 .826 r
F P
0 g
s
.52958 .43237 m .52916 .44057 L .49059 .443 L p .639 .774 .945 r
F P
0 g
s
.49059 .443 m .48694 .43506 L .52958 .43237 L p .639 .774 .945 r
F P
0 g
s
.62639 .41639 m .61849 .43416 L .57629 .42256 L p .765 .676 .764 r
F P
0 g
s
.57187 .43646 m .57629 .42256 L .61849 .43416 L p .735 .711 .828 r
F P
0 g
s
.52916 .44057 m .52958 .43237 L .57187 .43646 L p .632 .768 .945 r
F P
0 g
s
.65754 .3304 m .6497 .35053 L .59354 .3343 L p .773 .662 .741 r
F P
0 g
s
.6497 .35053 m .64194 .37271 L .58924 .35769 L p .778 .652 .724 r
F P
0 g
s
.58924 .35769 m .59354 .3343 L .6497 .35053 L p .778 .652 .724 r
F P
0 g
s
.64194 .37271 m .63419 .39529 L .58496 .38144 L p .779 .65 .721 r
F P
0 g
s
.58496 .38144 m .58924 .35769 L .64194 .37271 L p .779 .65 .721 r
F P
0 g
s
.66555 .31362 m .65754 .3304 L .59789 .31296 L p .76 .682 .776 r
F P
0 g
s
.59354 .3343 m .59789 .31296 L .65754 .3304 L p .773 .662 .741 r
F P
0 g
s
.63419 .39529 m .62639 .41639 L .58065 .40369 L p .775 .657 .732 r
F P
0 g
s
.57629 .42256 m .58065 .40369 L .62639 .41639 L p .765 .676 .764 r
F P
0 g
s
.58065 .40369 m .58496 .38144 L .63419 .39529 L p .775 .657 .732 r
F P
0 g
s
.47977 .40199 m .48333 .42102 L .43999 .43121 L p .647 .577 .762 r
F P
0 g
s
.43999 .43121 m .43278 .41317 L .47977 .40199 L p .647 .577 .762 r
F P
0 g
s
.36524 .28254 m .3736 .28325 L .30992 .3148 L p .584 .934 .941 r
F P
0 g
s
.30992 .3148 m .29825 .31581 L .36524 .28254 L p .584 .934 .941 r
F P
0 g
s
.67378 .301 m .66555 .31362 L .60233 .29495 L p .729 .713 .835 r
F P
0 g
s
.59789 .31296 m .60233 .29495 L .66555 .31362 L p .76 .682 .776 r
F P
0 g
s
.46567 .31063 m .46923 .33214 L .41148 .34641 L p .643 .554 .739 r
F P
0 g
s
.41148 .34641 m .40431 .32598 L .46567 .31063 L p .643 .554 .739 r
F P
0 g
s
.41857 .3689 m .41148 .34641 L .46923 .33214 L p .639 .536 .722 r
F P
0 g
s
.47624 .37959 m .47977 .40199 L .43278 .41317 L p .641 .545 .731 r
F P
0 g
s
.43278 .41317 m .42565 .39177 L .47624 .37959 L p .641 .545 .731 r
F P
0 g
s
.46923 .33214 m .47274 .35568 L .41857 .3689 L p .639 .536 .722 r
F P
0 g
s
.42565 .39177 m .41857 .3689 L .47274 .35568 L p .638 .533 .719 r
F P
0 g
s
.47274 .35568 m .47624 .37959 L .42565 .39177 L p .638 .533 .719 r
F P
0 g
s
.57629 .42256 m .57187 .43646 L .52958 .43237 L p .711 .684 .822 r
F P
0 g
s
.46204 .29245 m .46567 .31063 L .40431 .32598 L p .65 .591 .775 r
F P
0 g
s
.40431 .32598 m .39699 .30889 L .46204 .29245 L p .65 .591 .775 r
F P
0 g
s
.53001 .41805 m .52958 .43237 L .48694 .43506 L p .685 .662 .822 r
F P
0 g
s
.48694 .43506 m .48333 .42102 L .53001 .41805 L p .685 .662 .822 r
F P
0 g
s
.77619 .32783 m .76363 .32398 L .70024 .28852 L p 0 .456 .841 r
F P
0 g
s
.69111 .28892 m .70024 .28852 L .76363 .32398 L p .19 .597 .944 r
F P
0 g
s
.4583 .27843 m .46204 .29245 L .39699 .30889 L p .659 .654 .834 r
F P
0 g
s
.39699 .30889 m .38946 .29596 L .4583 .27843 L p .659 .654 .834 r
F P
0 g
s
.52958 .43237 m .53001 .41805 L .57629 .42256 L p .711 .684 .822 r
F P
0 g
s
.68229 .29285 m .67378 .301 L .6069 .2811 L p .654 .749 .92 r
F P
0 g
s
.60233 .29495 m .6069 .2811 L .67378 .301 L p .729 .713 .835 r
F P
0 g
s
.58065 .40369 m .57629 .42256 L .53001 .41805 L p .728 .638 .758 r
F P
0 g
s
.53042 .39873 m .53001 .41805 L .48333 .42102 L p .69 .606 .758 r
F P
0 g
s
.48333 .42102 m .47977 .40199 L .53042 .39873 L p .69 .606 .758 r
F P
0 g
s
.45443 .26887 m .4583 .27843 L .38946 .29596 L p .658 .753 .92 r
F P
0 g
s
.38946 .29596 m .38167 .28749 L .45443 .26887 L p .658 .753 .92 r
F P
0 g
s
.58496 .38144 m .58065 .40369 L .53042 .39873 L p .733 .616 .727 r
F P
0 g
s
.53001 .41805 m .53042 .39873 L .58065 .40369 L p .728 .638 .758 r
F P
0 g
s
.35663 .28425 m .36524 .28254 L .29825 .31581 L p .472 .893 .824 r
F P
0 g
s
.29825 .31581 m .28625 .31925 L .35663 .28425 L p .472 .893 .824 r
F P
0 g
s
.58924 .35769 m .58496 .38144 L .53084 .37603 L p .735 .607 .716 r
F P
0 g
s
.53042 .39873 m .53084 .37603 L .58496 .38144 L p .733 .616 .727 r
F P
0 g
s
.59354 .3343 m .58924 .35769 L .53125 .35182 L p .734 .609 .719 r
F P
0 g
s
.53084 .37603 m .53125 .35182 L .58924 .35769 L p .735 .607 .716 r
F P
0 g
s
.53084 .37603 m .53042 .39873 L .47977 .40199 L p .689 .579 .727 r
F P
0 g
s
.47977 .40199 m .47624 .37959 L .53084 .37603 L p .689 .579 .727 r
F P
0 g
s
.59789 .31296 m .59354 .3343 L .53166 .32796 L p .732 .622 .736 r
F P
0 g
s
.53125 .35182 m .53166 .32796 L .59354 .3343 L p .734 .609 .719 r
F P
0 g
s
.53125 .35182 m .53084 .37603 L .47624 .37959 L p .688 .569 .715 r
F P
0 g
s
.47624 .37959 m .47274 .35568 L .53125 .35182 L p .688 .569 .715 r
F P
0 g
s
.69111 .28892 m .68229 .29285 L .61164 .2717 L p .47 .751 .991 r
F P
0 g
s
.6069 .2811 m .61164 .2717 L .68229 .29285 L p .654 .749 .92 r
F P
0 g
s
.53166 .32796 m .53125 .35182 L .47274 .35568 L p .689 .571 .718 r
F P
0 g
s
.47274 .35568 m .46923 .33214 L .53166 .32796 L p .689 .571 .718 r
F P
0 g
s
.60233 .29495 m .59789 .31296 L .53208 .30613 L p .726 .647 .77 r
F P
0 g
s
.53166 .32796 m .53208 .30613 L .59789 .31296 L p .732 .622 .736 r
F P
0 g
s
.53208 .30613 m .53166 .32796 L .46923 .33214 L p .689 .586 .735 r
F P
0 g
s
.46923 .33214 m .46567 .31063 L .53208 .30613 L p .689 .586 .735 r
F P
0 g
s
.78901 .33274 m .77619 .32783 L .70965 .29055 L p 0 .387 .781 r
F P
0 g
s
.70024 .28852 m .70965 .29055 L .77619 .32783 L p 0 .456 .841 r
F P
0 g
s
.5325 .28764 m .53208 .30613 L .46567 .31063 L p .689 .617 .77 r
F P
0 g
s
.46567 .31063 m .46204 .29245 L .5325 .28764 L p .689 .617 .77 r
F P
0 g
s
.6069 .2811 m .60233 .29495 L .5325 .28764 L p .708 .69 .83 r
F P
0 g
s
.53208 .30613 m .5325 .28764 L .60233 .29495 L p .726 .647 .77 r
F P
0 g
s
.45041 .26353 m .45443 .26887 L .38167 .28749 L p .6 .862 .993 r
F P
0 g
s
.38167 .28749 m .3736 .28325 L .45041 .26353 L p .6 .862 .993 r
F P
0 g
s
.53294 .2733 m .5325 .28764 L .46204 .29245 L p .685 .67 .83 r
F P
0 g
s
.46204 .29245 m .4583 .27843 L .53294 .2733 L p .685 .67 .83 r
F P
0 g
s
.34782 .287 m .35663 .28425 L .28625 .31925 L p .414 .855 .757 r
F P
0 g
s
.28625 .31925 m .27399 .32374 L .34782 .287 L p .414 .855 .757 r
F P
0 g
s
.70024 .28852 m .69111 .28892 L .61655 .26653 L p .152 .631 .924 r
F P
0 g
s
.61164 .2717 m .61655 .26653 L .69111 .28892 L p .47 .751 .991 r
F P
0 g
s
.61164 .2717 m .6069 .2811 L .53294 .2733 L p .655 .751 .92 r
F P
0 g
s
.5325 .28764 m .53294 .2733 L .6069 .2811 L p .708 .69 .83 r
F P
0 g
s
.5334 .26341 m .53294 .2733 L .4583 .27843 L p .656 .752 .92 r
F P
0 g
s
.4583 .27843 m .45443 .26887 L .5334 .26341 L p .656 .752 .92 r
F P
0 g
s
.70965 .29055 m .71927 .29362 L .78901 .33274 L p 0 .387 .781 r
F P
0 g
s
.44624 .26171 m .45041 .26353 L .3736 .28325 L p .419 .859 .918 r
F P
0 g
s
.3736 .28325 m .36524 .28254 L .44624 .26171 L p .419 .859 .918 r
F P
0 g
s
.53294 .2733 m .5334 .26341 L .61164 .2717 L p .655 .751 .92 r
F P
0 g
s
.61655 .26653 m .61164 .2717 L .5334 .26341 L p .496 .792 .998 r
F P
0 g
s
.53387 .25774 m .5334 .26341 L .45443 .26887 L p .541 .831 .999 r
F P
0 g
s
.45443 .26887 m .45041 .26353 L .53387 .25774 L p .541 .831 .999 r
F P
0 g
s
.70965 .29055 m .70024 .28852 L .62164 .26488 L p 0 .455 .752 r
F P
0 g
s
.61655 .26653 m .62164 .26488 L .70024 .28852 L p .152 .631 .924 r
F P
0 g
s
.5334 .26341 m .53387 .25774 L .61655 .26653 L p .496 .792 .998 r
F P
0 g
s
.44195 .2623 m .44624 .26171 L .36524 .28254 L p .22 .739 .734 r
F P
0 g
s
.36524 .28254 m .35663 .28425 L .44195 .2623 L p .22 .739 .734 r
F P
0 g
s
.62164 .26488 m .61655 .26653 L .53387 .25774 L p .177 .686 .901 r
F P
0 g
s
.53436 .25559 m .53387 .25774 L .45041 .26353 L p .271 .766 .898 r
F P
0 g
s
.45041 .26353 m .44624 .26171 L .53436 .25559 L p .271 .766 .898 r
F P
0 g
s
.62164 .26488 m .62689 .26564 L .70965 .29055 L p 0 .455 .752 r
F P
0 g
s
.71927 .29362 m .70965 .29055 L .62689 .26564 L p .222 0 0 r
F P
0 g
s
.53387 .25774 m .53436 .25559 L .62164 .26488 L p .177 .686 .901 r
F P
0 g
s
.43754 .26392 m .44195 .2623 L .35663 .28425 L p 0 0 0 r
F P
0 g
s
.35663 .28425 m .34782 .287 L .43754 .26392 L p 0 0 0 r
F P
0 g
s
.62689 .26564 m .62164 .26488 L .53436 .25559 L p .097 0 0 r
F P
0 g
s
.53487 .25585 m .53436 .25559 L .44624 .26171 L p 0 0 0 r
F P
0 g
s
.44624 .26171 m .44195 .2623 L .53487 .25585 L p 0 0 0 r
F P
0 g
s
.62689 .26564 m .63227 .26744 L .71927 .29362 L p .222 0 0 r
F P
0 g
s
.53436 .25559 m .53487 .25585 L .62689 .26564 L p .097 0 0 r
F P
0 g
s
.63227 .26744 m .62689 .26564 L .53487 .25585 L p .196 0 0 r
F P
0 g
s
.53539 .25714 m .53487 .25585 L .44195 .2623 L p .075 0 0 r
F P
0 g
s
.44195 .2623 m .43754 .26392 L .53539 .25714 L p .075 0 0 r
F P
0 g
s
.53487 .25585 m .53539 .25714 L .63227 .26744 L p .196 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`000003oa<00?m5a>GoR]Co00GoR]Co00?o0000
ogk:oomnb_l00_mnb_l<o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/
ooooo`007Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:
o`000004oa<00?l0003oALCUodG4i@goR]Co1ol0000=ogk:o`go00006Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo02_ooooo000Booooo`Ko00001Oooool00ol0003oooooooooo`04
ooooo`;o00001?ooool00ol0003oooooooooo`1/ooooo`Wo00000_nIg?h00ol0003oR]Cooh[Do`07
oh[Do`[o00001_nW`>/00ol0003oYl3[ojO0j`02ojO0j`So00002_mnb_l;o`0001;ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0[ooooo`007Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool9o`0000GoVMcn0ol00002oh[D
o`?o00004_nW`>/00ol0003oYl3[ojO0j`0;ojO0j`So00001?mnb_l01Ol0003oN<3mogS0oOmh`?go
9Z7/00;o07C00_lh0003o`0000oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Z
ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0H_ooool9o`0000GoVMcn1?l00002ojS0j`03o`000?nW`>_oYl3[00ooYl3[1ol0000EojO0
j`Co00001omh`?d00ol0003o07C0o`1d`002ocP000?o00003?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1Mooooo`Ko00000_m[fn/6oiWLoPCo00001onX`>/00ol0003o
Yl3[ojO0j`04ojO0j`[o00001_n_Zm@00ol0003o]K3DokF`e002okF`e0So00003?nW`>/01?l0003o
Yko[ojNojol00007ogS0o@03o`000?lVXNco07C000;o>0000ol00009ooooo`03o`000?oooooooooo
02oooooo0_l0000[ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003o
ooooooooo`1Hooooo`Oo000000?oJm_[oiWLo_nIg?h01OnIg?h3o`0000WoZ<3[0ol000000onW`>_o
0000o`000002o`00017o[j_D00?o0000okF`e?ne/=@02_ne/=@8o`0000?oYl3[00?o0000ojNojonW
_n/01OnW_n/2o`0000KoN<3m00Co0000o`1d`?lh003o>0000ol00006ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0:?ooool001_ooooo00?oEEEEofIVI_l000001_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05?ooooo1ol000000om[fn_oVMcnoiWLoP06oiWLoP?o
00001onX`>/5o`0000;oZ:OE00?o0000ojn[e?n_Zm@05?n_Zm@00ol0003o]K3DokF`e00BokF`e0Co
00002_nW_n/4o`0000CoN<3m0_l000000ol0M<3o>000o`000002o`0000Cooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Xooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo04oooooo2?l00003ojSQnP03o`000?nIg?koVMcn00;oVMcn0_l00007ojS0j`Co0000
1onXYmD00ol0003o[j_Dojn[e00Dojn[e003o`000?ne/=Co]K3D01Go]K3D00?o0000okZfeOnj]]D0
0_l0000:ojNoj`Co00000omh`?d2o`000003o`1d`?lh003o000000;o000000?oooooo`000?ooool0
<_ooool00ol0003oooooooooo`0Wooooo`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04cooooo0_l000000omYf/7o0000o`000003o`0000GoZ>7j0ol00007ojS0j`Co00003?nX
YmD00ol0003o[j_Dojn[e008ojn[e0co00001One/=@00ol0003o]K3DokF`e00>okF`e003o`000?nj
]]Go^[KE00Co^[KE1?l00009ojNoj`?o00000omh`?d3o`000004ocP00?l0003o0000o`0003?ooooo
00?o0000ooooooooool09_ooool002?ooooo0_l0000=ooooo`03o`000?oooooooooo04Wooooo0_l0
00000omYf/7o0000o`000003o`0000GoZ>7j0_l00002ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[0ol0
000>ojRWe@?o000000?o[j_Do`000?l000001ol0000;ok2Ma@03o`000?niYLGo^JG500Co^JG52ol0
0005okF`e003o`000?nj]]Go^[KE00So^[KE0ol00009ojNoj`?o00000omg]_T2oc2Hl@03o`000?lh
003o000000;o0000<?ooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Kooooo0_l000001_mYf/7o0000o`000?l0003oUNo`o`0000GoZ>7j
0_l00004ojS0j`?o00003onXYmD4o`0000;oYYO600?o0000ok2MaOn`WLD04on`WLD00ol0003o^JG5
okVUa@0?okVUa@Go00003_nj]]D4o`0000KoYko[00?o0000ojNojomg]_T01?mg]_T01Ol0003o<9Sa
oc2HlOl0M=Oo>00000;o0000;_ooool2o`0002Oooooo000Sooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0@oooool2o`000006ofWJ`Ol0003o0000ogSTd_nEko3o00001OnXhOX2o`00
00CoZ<3[0_l000000onQY=Oo0000ojRWe@0;ojRWe@Co00001_nVUlH00ol0003o/9g5ok2Ma@0Cok2M
a@03o`000?niYLGo^JG501?o^JG500?o0000ol:^a_o2[/H00ol0000=okZfe@?o00000_nW_n/00ol0
003oYko[ojNoj`02ojNoj`?oMkKi0_l00003oc2Hl@04o`1deol0HlOo0000o`0002kooooo00?o0000
ooooooooool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10oooo
o`;o000000KoJM[1o`000?l0003oN>CBoiG_l?l00004ojSQnP?o00001?nX`>/2o`0000CoXJCG00?o
0000ojRWeOnXYmD01OnXYmD4o`0000[oYYO600?o0000ok2MaOn`WLD04on`WLD00ol0003o^JG5okVU
a@0CokVUa@03o`000?o2[/Ko`Zk600?o`Zk60ol0000=okZfe@;o00001onW_n/2o`0000;oMkKi00Ko
0000oc2HlOl`V?7o0000o`1deol0HlL2o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`05o`000?mYf/7o0000o`000?mh
i=800_l00004ojSQnP;o00001OnX`>/2o`0000OoXJCG00Co0000ojRWeOnXYmGoZ:OE0ol0000?ojJG
aP03o`000?n`WLGo/9g500go/9g51_l00003okVUa@03o`000?niYLGo^JG500oo^JG500?o0000ol:^
a_o2[/H01_o2[/H4o`0000[o^[KE00?o0000oknmf?nW_n/01OnW_n/3o`0000?oMkKi00Oo0000oc2H
lOl`V?7o0000o`1deol0HlOo000002cooooo00?o0000ooooooooool08oooool002;ooooo0_l0000C
ooooo`03o`000?oooooooooo03_ooooo0_l000000omYf/7o0000ogSTdP02o`0000CoZ>7j0_l00005
ojS0j`;o00002OnQY=L3o`0001?oYYO600?o0000ok2MaOn`WLD00_n`WLD;o`0000Go/9Jl00?o0000
ok^O_?nkWk`00_nkWk`7o`0000Wo^JG500?o0000ol:^a_o2[/H02oo2[/H3o`0000Ko^[KE00?o0000
oknmf?no_MP00_no_MP4o`000003ojNojol0003oYko[00;o00000omg]_T01Ol0003o<9Saoc2HlOl0
003o07CG00;o0000:oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03Sooooo0_l000001OmYf/7o0000ogSTd_l0003oUNo`00GoZ>7j00?o
0000ojS0jonX`>/00onX`>/2o`0000WoXJCG0_l000000onKTLSo0000ojJGaP0AojJGaP?o000000Co
/9g5o`000?l0003o00004?n`U[`00ol0003o^inlok^O_009ok^O_0Oo00000_niYLD00ol0003o`Zk6
ol:^aP0>ol:^aP?o00000_nj]]D01?l0003o_kgHoknmf?no_MP3o`000003oknmf?l0003o000000;o
Yko[00?o0000ojNojonW_n/00_l00002ogNfn@;o00000_l`V?401?l0003o07CGo`000?l0000Yoooo
o`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0=Oooool2o`000004ofWJ`Ol0003oN>CBogSTdP?o00000onXhOX00ol0003oZ<3[ojS0j`03ojS0
j`;o00002OnQY=L2o`0000CoVi7800?o0000ojJGa_nVUlH02onVUlH4o`0000;oY8fm00?o0000ok2F
_?n`U[`04_n`U[`00ol0003o^inlok^O_00@ok^O_0?o00004oo2[/H2o`000004oknmf?l0003o0000
o`0000Ko_kgH0_l000000onW_n_o0000ojNoj`02ojNoj`;o00000_mg]_T2o`0000;o<9Sa1?l0000W
ooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0booooo`;o00000_mYf/43o`0000Co]^7e0ol00005ojS0j`03o`000?nQY=OoXJCG00OoXJCG0_l0
0006oi^Ab003o`000?nVUlKoYYO600OoYYO61?l00006ojB=_@03o`000?n`U[co/9Jl01;o/9Jl00?o
0000ok^O_?nkWk`04_nkWk`00ol0003oaJVmolFY_@03o`0000ko`Zk61?l0000:oknmf003o`000?nW
_n_o000000CoYko[00Go0000ogNfnOmg]_WoMkKio`000002oc2Hl@;o000000?o06?7o`000?l00000
9oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool0027ooooo0ol0000Gooooo`03o`000?oooooooooo02oooooo
1_l000000onhm_7o0000okKQm@03okKQm@05o`000?nY`>_oZL3[ojW0jol000000_nX`>/00ol0003o
XJCGoj6Te`07oj6Te`;o00002?nKTLP00ol0003oYYO6ojJGaP04ojJGaP?o00002_nTSKd00ol0003o
/9Jlok2F_00Bok2F_003o`000?nkWkco^inl017o^inl00?o0000olFY_Oo5ZKd01?o5ZKd4o`0000Oo
`Zk61?l00004olZib@03o`000?no_MSo_kgH00Oo_kgH0_l00005ojNoj`;o00000_mg]_T2o`0000;o
<9Sa0_l000000ol0HlOo0000o`00000Uooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo01So
oooo0_l0000]ooooo`Co00000_nann800ol0003o^?KaokSfl@04okKQm@03o`000?nY`>_oZL3[00;o
ZL3[0_l0000:oj6Te`03o`000?nKTLSoVi7800WoVi7800?o0000ojJGa_l000000ol0000>ojB=_@03
o`000?n`U[co/9Jl017o/9Jl00?o0000ok^O_?nkWk`04OnkWk`00ol0003oaJVmolFY_@08olFY_@Oo
00000_o2[/H00ol0003ob[W9olZib@04olZib@;o00002Ono_MP2o`0000CoYko[2ol000000ol0HlOo
0000ooooo`0Tooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:Oooool01?l0003o[?[IojcjfOl00002ok7khP03o`000?nhm_7o^?Ka00Co]^7e00?o
0000ojW0jonY`>/00_nY`>/01?l0003oVZ;KoiZRfol00007oj6Te`;o00002onKTLP3o`0001;oY8fm
00?o0000ok2F_?n`U[`03?n`U[`6o`0000;o^inl0ol0000>ok^O_003o`000?o5ZKgoaJVm00WoaJVm
1_l00002ol:^aP03o`000?o:^LWob[W900Kob[W90_l00008oknmf0?o000000GoYko[o`000?nW_^_o
Ykk[o`000003ogZ^m004o`000?m3T_3o@i;`o`0000;o67ST0ol0000Tooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09oooool01?l0003o[?[Iojcj
fOl00002ok7khP03o`000?nhm_7o^?Ka00Co]^7e00?o0000ojW0jonY`>/00_nY`>/00ol0003oVZ;K
oiZRf`02oiZRf`03o`000?nQY=OoXJCG00;oXJCG0_l0000;oi^Ab0;o000000?oUXJoo`000?nTSKd0
4_nTSKd00ol0003o/9Jlok2F_002ok2F_0[o00001On`T[L00ol0003o^i^hok^K^003ok^K^0Wo0000
1?nkWk`00ol0003oaJVmolFY_@07olFY_@?o00001_o5ZKd2o`0000_ob[W90_l00007oknmf003o`00
0?no_MSo000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl005o`000?lHN>Co67STo`00
0?l5Jm`00_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo02Gooooo00Co0000
ojcjfOn/n]Wo00000_nann800ol0003o^?KaokSfl@04okKQm@03o`000?nY`>_oZL3[00;oZL3[00?o
0000oiZRfonJX]/01?nJX]/01?l0003oXJCGoj6Teol0000:oi^Ab0?o00001?nFQ[l00ol0003oY8fm
ojB=_@0>ojB=_@Oo00003on`T[L00ol0003o^i^hok^K^00<ok^K^0Go00001_o5ZKd3o`0000[oaJVm
00?o0000om2e`?l000002oo:^LT2o`0000Go_kgH0_l000000oo3aM_o0000ojNnj`03ojNnj`05o`00
0?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003o`000?oooooooooo
01kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02?ooooo00Co0000ojcjfOn/n]Wo00000_na
nn800ol0003o^?KaokSfl@03okKQm@;o00001?nY`>/00ol0003oVZ;KoiZRf`05oiZRf`;o00002_nK
TLP2o`0000OoUXJo00?o0000ojB=_OnTSKd02OnTSKd5o`0000;oXhVh00?o0000ok2B]on`T[L04On`
T[L00ol0003o^i^hok^K^00@ok^K^003o`000?o7Y[WoajJi00Co00003?o5ZKd00ol0003od;G0om2e
`002om2e`0;o00002_o:^LT00ol0003o_kgHoknmf002oknmf0;o00000_o3aM/00ol0003oYkk[ojNn
j`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003
o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00006ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08Oooool0
1?l0003o[?[IojcjfOl00002ok7khP?o^?Ka0onfhOD00ol0003oZL3[ojW0j`02ojW0j`;o00001onJ
X]/00ol0003oSHc=o`000008oi^Ab0;o00002OnFQ[l00ol0003oY8fmojB=_@05ojB=_@Co00001onS
RKP00ol0003o/9:gok2B]`0Aok2B]`03o`000?nkVkSo^i^h013o^i^h1?l00002olNV^@Co00002Oo5
ZKd00ol0003od;G0om2e`004om2e`0;o00002Oo:^LT2o`000005oknmf?l0003o`lGKol?5fol00000
0_o3aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o
67SToaQhi?l00002o`E[g003o`000?oooooooooo01oooooo00?o0000ooooooooool07?ooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Oooooo`04o`000?n/n]Wo[?[Io`0000;o/O_R0onhm_43
okKQm@03o`000?nY`>_oZL3[00;oZL3[00?o0000oiZRfonJX]/01_nJX]/01Ol0003oSHc=ohf<cOn=
S<go000000CoVi780ol0000<oiJ6_`03o`000?nTSKgo000000Co00003?nSRKP00ol0003o/9:gok2B
]`0@ok2B]`03o`000?nkVkSo^i^h00ko^i^h0ol00009olNV^@Co00001Oo5ZKd00ol0003od;G0om2e
`006om2e`0;o00002Oo:^LT01Ol0003o`lGKol?5foo3aM_o000000?o`lGK00?o0000ojNnjonW_^/0
0_nW_^/01Ol0003oNZkdogZ^m?mj[_Co000000;o@i;`00Co0000oaQhi?lHN>Co00000_l5Jm`00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07Oooool00ol0003o[?[Iojcjf@03ok7khP?o^?Ka0onfhOD00ol0003oZL3[ojW0j`02ojW0
j`03o`000?nJX]_oVZ;K00GoVZ;K0_l00005ohf<c@04o`000?nKTLSo0000o`0000koUXJo0ol0000A
oj>9^003o`000?n`T[Oo/9:g013o/9:g00?o0000ok^K^?nkVkP02onkVkP3o`0000;o^i^h00?o0000
olNV^Oo7Y[T02oo7Y[T3o`000003olFY_Ol0003od;G000[od;G00_l00007olZib@;o00000oo3aM/0
1Ol0003o`lGKol?5foo3aM_o000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl004o`00
0?lHN>Co67STo`0000;o1F_L00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`;o00008oooool00ol0003o
ooooooooo`0Kooooo`03o`000?n/n]Wo[?[I00?o/O_R0onhm_44okKQm@CoZL3[00?o0000oiZRfonJ
X]/01OnJX]/00ol0003oSHc=ohf<c@05ohf<c@;o00003_nFQ[l2o`000003oiB0^ol0003oXhVh017o
XhVh00?o0000ok2B]on`T[L04?n`T[L00ol0003o^i^hok^K^008ok^K^0?o00001?nkVkP00ol0003o
ajJiolNV^@0?olNV^@?o00003?o@]L02o`0000Cob[W900Co0000om;5c_oBaLko00000oo3aM/01Ol0
003o`lGKol?5foo3aM_o000000CoYkk[00Go0000ogZ^m?mj[_CoNZkdo`000002od>Bl004o`000?lH
N>Co67STo`0000;o1F_L00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`008?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Wooooo00?o0000ojcjfOn/n]T00ona
nn83okSfl@Co]^7e1OnY`>/7oiZRf`03o`000?n=S<goSHc=00GoSHc=00?o0000ohIn`ol000003?nF
Q[l2o`0000CoU82k00?o0000oj>9^?nSRKP04?nSRKP00ol0003o/9:gok2B]`06ok2B]`[o000000?o
^i^ho`000?l000000_l00002ok^K^0?o00001onkVkP00ol0003oajJiolNV^@0@olNV^@04o`000?oB
/k_o0000o`0000cod;G00_l000000oo:^LWo0000om;5cP03om;5cP05o`000?o3aM_o`lGKol?5fol0
00000oo3aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0
003o67SToaQhi?l00002o`E[g003o`000?oooooooooo01cooooo00?o0000ooooool000006oooool0
023ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Gooooo`03o`000?n/n]Wo[?[I
00?o/O_R2Ol00003ojW0j`OoVZ;K00?o0000ohf<cOn=S<d01On=S<d01Ol0003oQWk3ohIn`on6O/?o
000000SoUXJo0ol00006oiB0^`03o`000?nSRKSoXhVh00koXhVh2ol00009ok2A]`03o`000?nlVkOo
_9^g00;o_9^g2_l00003ok^K^003o`000?o7Y[WoajJi013oajJi00Go0000om:c^ooB/k_od[>ko`00
000=om2e`003o`000?oBaLkod/G>00Cod/G>00Co0000ol?5foo3aM_o00001?o3aM/00ol0003oYkk[
ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[
g003o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Eooooo`04o`000?n/n]Wo[?[Iok7khP?o00000_o<lN/01Ol0
003o_]g_okkMkonngNoo000000;oZL3[0ol00005oiZRf`;o00001on=S<d00ol0003oQWk3ohIn``02
ohIn``03o`000?nFQ[ooUXJo00CoUXJo0_l0000:oiB0^`03o`000?nSRKSoXhVh00WoXhVh1?l00002
oj>8^003o`000?n`TKOo/96g00oo/96g00?o0000okbK]ol000000_l0000:okbK]`Ko00003oo7Y[T0
0ol0003od[>kom:c^`03om:c^`;o00002oo@]L02o`0000Kod/G>00Co0000ol?5foo3aM_o00001?o3
aM/00ol0003oYkk[ojNnj`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67ST
oaQhi?l00002o`E[g003o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool001oooooo
0_l0000Xooooo`03o`000?oooooooooo01?ooooo00?o0000ojcjfOn/n]T00_l000001OoBn^Co0000
olcajoo<lN_o000000?o_]g_00?o0000ojW0jonY`>/00_nY`>/00ol0003oTJ7Oo`000003oiZRf`03
o`000?n=S<goSHc=00KoSHc=00?o0000ohIn`on6O/<01?n6O/<01?l0003oUXJooiJ6_onFQ[l2o`00
00coU82k00?o0000oj>9^?nSRKP01?nSRKP5o`0000KoXhRh00?o0000ok2A]on`TKL03_n`TKL3o`00
013o_9^g00?o0000olNV^?o7Y[P01?l0000;olNV^@03o`000?oB/k_od[>k00God[>k0_l00008om2e
`004o`000?oJa<Cof/C4o`0000Kod/G>00Co0000ol?5foo3aM_o00001?o3aM/00ol0003oYkk[ojNn
j`02ojNnj`05o`000?mj[_CoNZkdogZ^m?l000000_m3T_001?l0003o67SToaQhi?l00002o`E[g003
o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Aooooo`?o00000ooBn^@01Ol0003oc?7[olcajoo<lN_o000000?o
_]g_00Go0000ojW0jonY`>_oZL3[o`000003oi6Qg`03o`000?nJX]_o000000OoSHc=0_l00007ohIn
``04o`000?nFQ[oo0000o`0000koU82k00?o0000oj>9^?nSRKP01?l0000;oj>8^003o`000?n`TKOo
/96g00co/96g0_l000000on`TKOo0000okbK]`0@okbK]`03o`000?o7Y[SoajJh00CoajJh1Ol00006
olNV^@03o`000?oB/k_od[>k00Ood[>k0_l00005om2e`003o`000?oJa<Cof/C400;of/C400?o0000
om;5c_oBaLh01?oBaLh01?l0003o`lGKol?5fol00004ol?5f`03o`000?nW_^_oYkk[00[o00000_lH
N>@01?l0003o1F_Lo`E[g?l0000Nooooo`03o`000?oooooooooo01Oooooo000Oooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool03oooool2o`000005om?lgol0003od_[Tom;ji?l00000
0oo<lN/01Ol0003o_]g_okkMkonngNoo000000CoZL3[00?o0000oi6QgonAXMl00_nAXMl00ol0003o
SHc=ohf<c@05ohf<c@03o`000?n6O/?oQWk300OoQWk30_l0000@oiB0^`?o00003onSR;P00ol0003o
/96gok2A]`09ok2A]`?o00000on`TKL00ol0003o_9^gokbK]`0?okbK]`03o`000?o7Y[SoajJh00Wo
ajJh1?l000000oo7Y[Wo0000om:c^`0;om:c^`03o`000?o@]L3od;G000;od;G000?o0000om[4a?oJ
a<@00ooJa<@00ol0003od/G>om;5cP04om;5cP03o`000?o3aM_o000000Co`lGK0ol00002ojNnjPCo
OjO^0omHS^T3o`000005oaQhi?l0003o1F_Lo`E[g?l000007Oooool2o`0001Sooooo000Oooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool01?l0003odocOom?lgol00003om;j
i004o`000?o<lN_oc?7[o`0000Co_]g_00Go0000ojW0jonY`>_oZL3[o`000005oi6Qg`03ogf7dol0
003oSHc=00CoSHc=00?o0000ohIn`on6O/<01on6O/<00ol0003oPWNno`00000>oiB0^`;o000000?o
U7njo`000?nSR;P04?nSR;P00ol0003o/96gok2A]`05ok2A]`?o00001_n`TKL00ol0003o_9^gokbK
]`0>okbK]`03o`000?o7Y[SoajJh00koajJh0ol0000<om:c^`;o000000?od;G0o`000?oJa<@01_oJ
a<@00ol0003od/G>om;5cP04om;5cP04o`000?o3aM_o0000ol?5f`;o000000?oaLgPojNnj_nW_^X0
0onW_^X4ognWkP?oF8kY0_llN^83o`0000;o1F_L00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Eooooo`007oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00Co
0000om?lgooCo=oo00000_oBn^@01Ol0003oc?7[olcajoo<lN_o000000?o_]g_00?o0000ojW0jonY
`>/00_nY`>/00ol0003oTJ7Ooi6Qg`02oi6Qg`04o`000?mmQm?oOHOCo`0000?oSHc=00?o0000ohIn
`on6O/<01on6O/<01Ol0003oPWNnoh9g__n2Mkko000000_oU82k0_l00003oiAo^P03o`000?nSR;So
XhRh00ooXhRh00?o0000ok2A]on`TKL00_n`TKL3o`0000Go/96g1Ol000001?nlVkOo0000o`000?l0
000<okbK]`03o`000?o7Y[SoajJh00ooajJh00Co0000om:c^_l0003o00003?oB/k/2o`0000Sof/C4
00?o0000om;5c_oBaLh01?oBaLh00ol0003o`lGKo`000004olG=h0CoYkkZ00Go0000ognWk_moYnko
OjO^o`000003oeR>j@Co?7[R0_l000000ol5Jmco0000ooooo`0Looooo`03o`000?oooooooooo01Go
oooo000Oooooo`;o0000;Oooool00ol0003oooooooooo`0:ooooo`04o`000?oCo=oodocOo`0000?o
d_[T00Co0000olcajoo<lN_o00000onngNl00ol0003oZL3[ojW0j`02ojW0j`03o`000?nAXMooTJ7O
00?oTJ7O00Oo0000ogf7dommQm?oOHOCo`000?n=S<go000000WoQWk300?o0000oh9g__n2Mkh00_n2
Mkh00ol0003oU82koiB0^`06oiB0^`?o00001_nDOkX00ol0003oXhRhoj>8^00>oj>8^003o`000?n`
TKOo000000[o00001?n`U;X00ol0003o^ifjok^M^P02ok^M^PWo00000onlVkL00ol0003oajJholNV
^00>olNV^003o`000?oB/k[od[>j00;od[>j0_l0000:om:c^`03o`000?oM`koo000000Sof/C400?o
0000om;5c_oBaLh01?oBaLh00ol0003oaLgPo`000003olG=h003o`000?nW_^[oYkkZ00;oYkkZ00Co
0000ognWk_moYnkoOjO^0omHS^T01?l0003o?7[Rocajh_llN^82oc5bg`?o00007Oooool00ol0003o
ooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo
00Co0000om?lgooCo=oo00000_oBn^@01Ol0003oc?7[olcajoo<lN_o000000?o_]g_00Go0000ojW0
jonY`>_oZL3[o`000005oi6Qg`03o`000?mmQm?oOHOC00?oOHOC00?o0000ohIn`on6O/<01on6O/<0
0ol0003oPWNnoh9g_P04oh9g_P03o`000?nDP;_oU82k00?oU82k0_l00009oiAo^P03o`000?nSR;So
XhRh00_oXhRh1ol0000=ok2D^P03o`000?nkWK[o^ifj00_o^ifj1_l0000>olNV^003o`000?oB/k[o
d[>j00Cod[>j0_l00007om:c^`05o`000?oM`koogL>oomg3_ol000002?oJa<@00ol0003od/G>om;5
cP03om;5cP03o`000?o5cN3o000000CoaLgP00Go0000ojNnj_nW_^[oYkkZo`000003ognWkP04o`00
0?mHS^WoF8kYoeR>j@Co?7[R1?laL]l00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?o
oooo000Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool01?l0003odocO
om?lgol00002om;ji005o`000?o<lN_oc?7[olcajol000000onngNl00ol0003oZL3[ojW0j`02ojW0
j`03o`000?nAXMooTJ7O00;oTJ7O00?o0000ogf7dommQm<01?mmQm<00ol0003oQWk3ohIn``06ohIn
``03o`000?n2MkkoPWNn00GoPWNn00Co0000oiB0^onDP;_oU82k0_l0000;oiAo^P03o`000?nSR;So
XhRh00KoXhRh1ol000000onTRk_o0000ok2D^P0?ok2D^P03o`000?nkWK[o^ifj00ko^ifj00?o0000
olJX^oo6Z;/01?l00009olNV^003o`000?oB/k[od[>j00Ood[>j00?o0000om:c^ooB/k/01?oB/k/0
0ol0003ogL>oomg3_`02omg3_`03o`000?oJa<Cof/C400Kof/C400Wo0000om;5c_oBaLkod/G>o`00
0?oHe=Co0000olG=h?l000000oo5cN000ol0003oYkkZojNnjP02ojNnjP05o`000?moYnkoOjO^ognW
k_l000000_mHS^T01Ol0003o?7[Rocajh_llN^;o000000?o<G;O00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Gooooo00Go0000om?lgooCo=oodocOo`000002om;ji005o`000?o<lN_oc?7[olcajol000000onn
gNl01Ol0003oZL3[ojW0jonY`>_o000000GoTJ7O00?o0000ogf7dommQm<00ommQm<00ol0003oKgG9
o`000006ohIn``03o`000?n2MkkoPWNn00KoPWNn00Co0000oiB0^ol0003o00003_nDOkX00ol0003o
XhRhoj>8^005o`000004ojB;^ol0003o0000o`0000CoY8^k00?o0000ok2D^_n`U;X03_n`U;X00ol0
003o^ifjok^M^P0>ok^M^P03o`000?o6Z;_oaZRk00CoaZRk0ol00006olNV^003o`000?oB/k[od[>j
00Sod[>j0_l00003om:c^`03o`000?oM`koogL>o00CogL>o00?o0000om[4a?oJa<@01_oJa<@00ol0
003od/G>o`000002omSDe004o`000?o5cN3oaLgPo`0000?oaLgP00Go0000ojNnj_nW_^[oYkkZo`00
0003ognWkP05o`000?mHS^WoF8kYoeR>jOl000000ollN^84oc5bg`03o`000?oooooooooo01Wooooo
00?o0000ooooool000005?ooool001kooooo0ol0000aooooo`;o00001Oooool01?l0003odocOom?l
gol00002om;ji005o`000?o<lN_oc?7[olcajol000000onngNl00ol0003oZL3[ojW0j`02ojW0j`03
o`000?nAXMooTJ7O00;oTJ7O00?o0000ogf7dommQm<01?mmQm<01?l0003oKgG9ofmebOl00004ohIn
``03o`000?n2MkkoPWNn00OoPWNn0_l0000?oiAo^PCo00000onTRk/3o`0000OoY8^k00?o0000ok2D
^_n`U;X03_n`U;X00ol0003o^ifjok^M^P0=ok^M^P03o`000?o6Z;_oaZRk00SoaZRk1?l00002olNV
^003o`000?oB/k[od[>j00[od[>j0_l000000ooB/k_o0000omg3_`06omg3_`03o`000?oJa<Cof/C4
00Kof/C400?o0000omSDe?oHe=@00_oHe=@01?l0003oaLgPolG=h?l00002olG=h005o`000?nW_^[o
YkkZojNnj_l000001?moYnh01?l0003oF8kYoeR>jOl00003ocajhP05o`000?laL]oo<G;Ooc5bgol0
00007_ooool00ol0003oooooooooo`0Aooooo`007_ooool00ol0003oooooooooo`0cooooo`05o`00
0?ooooooooooooooool000000_oCo=l01Ol0003od_[Tom;ji?oBn^Co000000;oc?7[00?o0000okkM
konngNl00_nngNl01Ol0003oZL3[ojW0jonY`>_o000000GoTJ7O00?o0000ogf7dommQm<00ommQm<0
1Ol0003oKgG9ofmebOm_MLWo000000?oQWk300?o0000oh9g__n2Mkh01on2Mkh00ol0003oPGJmo`00
000<oiAo^P?o000000CoUH>mo`000?nTRk_oY8^k0ol0000;ojB;^`03o`000?n`U;[o/9Bj00go/9Bj
00?o0000ok^M^_nkWKX03OnkWKX00ol0003oaZRkolJX^`0<olJX^`?o00003_oB/kX2o`0000SogL>o
00?o0000om[4a?oJa<@01OoJa<@00ol0003of=CDomSDe002omSDe004o`000?o5cN3oaLgPo`0000;o
aLgP00?o0000ojNnj_nW_^X00_nW_^X01Ol0003oOjO^ognWk_moYnko000000?oF8kY00Go0000ocaj
h_llN^;o?7[Ro`000003oc5bg`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool0
01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Cooooo00Co0000
oooooooooooo00000_oCo=l01?l0003od_[Tom;ji?l00003olcaj`03o`000?nngNoo000000Co0000
0_nY`>/00ol0003oTJ7Ooi6Qg`02oi6Qg`03o`000?mmQm?oOHOC00?oOHOC00?o0000ofmebOm_MLT0
0om_MLT00ol0003oQWk3o`000009oh9g_P05o`000?n1M[goPGJmoh5f_Ol000002OnDOkX2o`0000Co
UH>m0ol0000>ojB;^`03o`000?n`U;[o/9Bj00go/9Bj00?o0000ok^M^_nkWKX03OnkWKX00ol0003o
aZRkolJX^`0=olJX^`04o`000?oA];ko0000o`0000cod[>j00?o0000omk3__l000002?oM`kl00ol0
003of/C4om[4a003om[4a003o`000?oSel[o000000Cof=CD00Co0000olG=h?o5cN3o00000_o5cN00
1Ol0003oYkkZojNnj_nW_^[o000000CoOjO^00Co0000oeR>jOmHS^Wo00000ollN^801Ol0003o<G;O
oc5bgolaL]oo000001kooooo00?o0000ooooooooool04?ooool001?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo03Kooooo0_l00002om?lg`04o`000?oBn^Cod_[To`00
00;oc?7[1?l00002olCGj003o`000?nY`>[oZL3Z00?o00000onAXMl00ol0003oOHOCogf7d`04ogf7
d`03o`000?m_MLWoKgG900CoKgG900?o0000oh9g__n2Mkh01on2Mkh00ol0003oPGJmoh5f_@02oh5f
_@03o`000?nDOk[oU7nj00GoU7nj0_l00003oiF3_@?o000000?oUH>mo`000?nTRk/03_nTRk/00ol0
003o/9Bjok2D^P05ok2D^Q7o00001_nkWKX00ol0003oaZRkolJX^`0>olJX^`04o`000?oA];kodKBn
om6d_P;o00002OoB/kX01Ol0003og/>nomk3__oN`kko000000SogL>o00Go0000om[4a?oJa<Cof/C4
o`000002on?GbP03o`000?oHe=Cof=CD00;of=CD00Oo0000olG=h?o5cN3oaLgPo`000?o5cN3o0000
00CoYkkZ00Go0000ognWk_moYnkoOjO^o`000002oeR>j@03o`000?llN^;o?7[R00;o?7[R00Co0000
oc5bgolaL]oo00007_ooool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool00_oo
ool001?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Oooooo00Co
0000om?lgooCo=oo00000_oBn^@3o`000003omGUh_l0003oa=OX00?oa=OX00Co0000ojW0j_nY`>[o
ZL3Z0_n8X^D2o`000003oi6Qgol0003oOHOC00CoOHOC00?o0000ofmebOm_MLT01Om_MLT00ol0003o
PWNnoh9g_P05oh9g_P;o00001_n1M[d01?l0003oU7njoiAo^_nDOkX3o`0000;oUH>m0ol00004oiF3
_@03o`000?nTRk_oY8^k00_oY8^k2_l00008ok2K`P03o`000?njXl;o^Z?200Ko^Z?21ol0000?olJX
^`03o`000?oA];kodKBn00CodKBn0_l00007om:c^P03o`000?oN`kkog/>n00;og/>n00?o0000omg3
_ooM`kl01_oM`kl00ol0003of/C4o`000004on?GbP03o`000?oHe=Cof=CD00;of=CD00Oo0000olG=
h?o5cN3oaLgPo`000?o5cN3o000000?oYkkZ00?o0000ognWk_moYnh00_moYnh01?l0003oF8kYoeR>
jOl00003ocajhP05o`000?laL]oo<G;Ooc5bgol000007Oooool2o`0000[ooooo00?o0000oooooooo
ool01?ooool001?ooooo00Go0000ooooooooooooooooo`000005ooooo`;o0000=oooool01Ol0003o
docOom?lgol0003od_[T00;o00001?oEiN800ol0003oa=OXolCGj002olCGj004o`000?nY`>[oZL3Z
ojW0jPCoR:;U00?o0000ogf7dommQm<01?mmQm<00ol0003oKgG9ofmeb@04ofmeb@03o`000?mXK<?o
000000GoPWNn00?o0000oh5f_On1M[d01_n1M[d01?l0003oU7njo`000?l00002oiF3_@?o00001onE
Pkd00ol0003oY8^kojB;^`06ojB;^`Go00000_nUTl<00ol0003o/9_2ok2K`P0=ok2K`P03o`000?nj
Xl;o^Z?200co^Z?200?o0000ol>]`oo3[L<01?l00009olJX^`03o`000?oA];kodKBn00KodKBn00?o
0000om:c^_oB/kX00ooB/kX00ol0003og/>nomk3_P04omk3_P03o`000?oM`koogL>o00KogL>o00?o
0000on?Gb_oSelX00ooSelX00ol0003of=CDomSDe002omSDe007o`000?o5cN3oaLgPolG=h?l0003o
aLgPo`000002ojNnjPOo00000_mHS^T01Ol0003o?7[Rocajh_llN^;o000000?o<G;O00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0fooooo`03o`000?oCo=oodocO
00;o000000?ogNcLo`000?oEiN800ooEiN801Ol0003oa=OXolCGj?o4enSo000000CoZL3Z00Ko0000
ohRRiOn8X^GoR:;UofR3f_l00004ogf7d`03o`000?m_MLWoKgG900CoKgG900Go0000ofQ/`omXK<?o
J6c3o`000003oh9g_P03o`000?n1M[goPGJm00OoPGJm0_l000001?nEPkgo0000o`000?l0000;oiF3
_@03o`000?nTRk_oY8^k00Go00001onUTl<00ol0003o/9_2ok2K`P0=ok2K`P03o`000?njXl;o^Z?2
00co^Z?200?o0000ol>]`oo3[L<01?o3[L<3o`0000KoaZRk00?o0000om6d__oA];h01ooA];h2o`00
00?od[>j00?o0000omk3__oN`kh01OoN`kh00ol0003ogL>oomg3_`05omg3_`03o`000?oSel[ohmO:
00CohmO:00?o0000omSDe?oHe=@00_oHe=@01?l0003oaLgPolG=h?o5cN04o`0000;oYkkZ1?n6XnL3
o`000003oeR>jOl0003o?7[R00;o?7[R00Go0000oc5bgolaL]oo<G;Oo`00000Nooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool001?ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo03Gooooo00Co0000om?lgol0003o00000ooMk=`00ol0003oeNGR
omGUhP02omGUhP05o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@;o
J8?J00Co0000ogf7dommQm?o00001om_MLT00ol0003oJ6c3ofQ/``02ofQ/``03o`000?n2Mkko0000
00WoPGJm1?l0000=oiF3_@Co00003OnUTl<00ol0003o/9_2ok2K`P0;ok2K`P03o`000?njXl;o^Z?2
00go^Z?200?o0000ol>]`oo3[L<01oo3[L<4o`000003olJX^ol0003odKBn00_odKBn0_l000000ooB
/k[o0000omk3_P07omk3_P03o`000?oM`koogL>o00?ogL>o00?o0000onSGa?l000001OoSelX00ol0
003of=CDomSDe002omSDe003o`000?o5cN3o000000Co00000onW_^X00ol0003oQZ?WohJSi`02ohJS
i`;oK8cP0_l00003ocajhP05o`000?laL]oo<G;Ooc5bgol000007oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`0dooooo`?o000000?ohNkJo`000?oMk=`00_oMk=`00ol0003oeNGRomGUhP02
omGUhP05o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@06o`000?mX
Pm[oJ8?Jo`000?mmQm?o00001_m_MLT00ol0003oJ6c3ofQ/``04ofQ/``03o`000?n1M[goPGJm00Ko
PGJm0ol00002ohAj`@03o`000?nEPkgoUH>m00WoUH>m0_l000000onISLGo0000ojFC``0>ojFC``03
o`000?n`Vl;o/9_200_o/9_200?o0000okZS`_njXl803?njXl800ol0003o`jg3ol>]``0<ol>]``?o
00003OoA];h2o`0000Wog/>n00Go0000omg3_ooM`koogL>oo`000002onSGa003o`000?oSel[ohmO:
00?ohmO:00?o0000omSDe?oHe=@00_oHe=@2o`0000?oaMKV0_l00003ojNnjP03o`000?n6XnOoQZ?W
00;oQZ?W1?m/S>02o`0000;o?7[R00Go0000oc5bgolaL]oo<G;Oo`00000Oooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o0000=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oE
iN801Ol0003oa=OXolCGj?o4enSo000000?oZL3Z00?o0000ohRRiOn8X^D00_n8X^D01?l0003oJ8?J
ofR3f_mXPmX2o`0000KoKgG900?o0000ofQ/`omXK<<01?mXK<<00ol0003oPGJmoh5f_@03oh5f_@Co
00001?n4N/400ol0003oUH>moiF3_@07oiF3_@;o00001?nISLD00ol0003oYI?3ojFC``0:ojFC`a7o
000000?o^Z?2o`000?l000001Ol00006okZS`P03o`000?o3[L?o`jg300go`jg300Co0000olbha_l0
003o00002ooA];h00ol0003oflC2o`000009omk3_P03o`000?oM`koo000000Coj=O400?o0000on?G
b_oSelX00ooSelX01_l0003of=CDomSDe?l0003ofnGLo`0000CoaMKV00Go0000ojNnj_nW_^[oYkkZ
o`000004ohJSi`04o`000?m/S>3oK8cPofb<h0;oFWcJ0ol00003oc5bg`03o`000?oooooooooo01_o
oooo0ol00007ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo
00?o0000on7^f_oQk]X00_oQk]X01Ol0003ogNcLomg/g?oMk=co000000CoeNGR00Go0000olCGj?o4
enSoa=OXo`000003ojW0jP03o`000?n8X^GoR:;U00;oR:;U00Co0000ofR3f_mXPm[oJ8?J0_m?Jll0
0ol0003oKgG9ofmeb@02ofmeb@03o`000?mXK<?oJ6c300CoJ6c300Co0000ofMZ`_l0003oPGJm0ol0
0002oh5f_@03o`000?n4N/7oQ7[100CoQ7[100?o0000oiF3_OnEPkd01?nEPkd2o`0000KoVHg500?o
0000ojFC`onUTl<01onUTl<3o`0000;oZ:CC00?o0000ojnYd_n_ZM802on_ZM800ol0003o]ZoBokJ_
dP06okJ_dPOo00003_o3[L<00ol0003oc;S6olbhaP02olbhaP;o00002?oA];h01Ol0003oflC2om_4
`_oKa<;o000000Wog/>n00?o0000onSGa?oXel@00ooXel@00ol0003ohmO:on?GbP03on?GbP03o`00
0?oHe=Co000000;ofnGL00?o0000olGFi_o5e^H00_o5e^H2o`0000;oYkkZ00?o0000ohJSion6XnL0
0_n6XnL01?l0003oK8cPofb<h?m/S>05oeYlfP;o000000?o<G;Oo`000?ooool07oooool00ol0003o
ooooooooo`02ooooo`03oeEEEOmVIVKo000000Kooooo000Looooo`03o`000?oooooooooo03Cooooo
00?o0000on7^f_oQk]X00_oQk]X01Ol0003ogNcLomg/g?oMk=co000000?oeNGR00?o0000olCGj?o4
enP00_o4enP01Ol0003oZL3ZojW0j_nY`>[o000000CoR:;U00Co0000ofR3f_mXPm[oJ8?J0om?Jll0
1?l0003oKgG9ofmebOl00006ofQ/``03o`000?mWJ/;oIf[200;o00001?n1M[d00ol0003oQ7[1ohAj
`@06ohAj`@04o`000?nEPkgoUH>moiF3_@;o00002?nISLD00ol0003oYI?3ojFC``03ojFC``Co0000
1OnXY=<00ol0003o[jWBojnYdP0;ojnYdP03o`000?nf[m;o]ZoB00co]ZoB00?o0000okbfdonl]]<0
0ol00009ol>]``03o`000?o<^<Koc;S600Coc;S60_l00006om6d_P03o`000?oKa<;oflC200;oflC2
00?o0000omk3__oN`kh01_oN`kh00ol0003oj=O4onSGa004onSGa003o`000?oSel[ohmO:00?ohmO:
00Go0000om_Ug?oKiMcofnGLo`000004olGFiP05o`000?nW_^[o0000ojNnj_l000001?n6XnL01Ol0
003oK8cPofb<h?m/S>3o000000CoFWcJ0_mDM]P00ol0003o<G;Oo`00000Nooooo`?o00003?ooool0
01cooooo00?o0000ooooooooool0=?ooool01Ol0003ohNkJon7^f_oQk][o000000CogNcL00Go0000
omGUh_oEiN;oeNGRo`000004olCGj005o`000?nY`>[oZL3ZojW0j_l000000on8X^D00ol0003oJ8?J
ofR3fP02ofR3fP07o`000?m?JlooCf_?odm[col0003oKgG9o`000006ofQ/``?o000000?oIf[2o`00
0?n1M[d00_n1M[d00ol0003oQ7[1ohAj`@07ohAj`@04o`000?nEPkgo0000o`0000_oVHg500?o0000
ojFC`ol000000_l0000:ojRTd`03o`000?n_ZM;o[jWB00[o[jWB00?o0000okJ_d_nf[m803?nf[m80
0ol0003o_;KCokbfd`03okbfd`?o00001Oo3[L<00ol0003oc;S6olbhaP07olbhaP;o00000ooA];h0
0ol0003oflC2om_4`P04om_4`P03o`000?oN`kkog/>n00Cog/>n00?o0000onSG`ol000001OoXel@0
0ol0003ohmO:on?GbP02on?GbP;o00000ooKiM`00ol0003oaMKVolGFiP02olGFiP05o`000?nW_^[o
0000ojNnj_l000001?n6XnL01Ol0003oK8cPofb<h?m/S>3o000000CoFWcJ1?mDM]P00ol0003ooooo
ooooo`0Iooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003ooooooooo
o`0dooooo`05o`000?oQk][ohNkJon7^f_l000000ooMk=`00ol0003oeNGRomGUhP02omGUhP05o`00
0?o4enSoa=OXolCGj?l000001?nY`>X01Ol0003oR:;UohRRiOn8X^Go000000CoJ8?J00?o0000odm[
com?Jll00_m?Jll00ol0003oJ6c3ofQ/``02ofQ/``?o00001OmWJ/800ol0003oPGJmo`00000:ohAj
`@;o00003?nISLD3o`0000goZ:CC00?o0000ojnYd_n_ZM801?n_ZM87o`0000;o]ZoB1Ol00006okJ_
dP03o`000?nl]]?o_;KC00Oo_;KC0ol00002ol>]``03o`000?o<^<Koc;S600Woc;S60_l000000ooA
];ko0000om_4`P06om_4`P03o`000?oN`kkog/>n00;og/>n00Co0000onSG`ooXel?o00001_oXel@0
1_l0003ohmO:on?Gb_l0003oj>c@o`0000?ofnGL00?o0000olGFi_o5e^H00_o5e^H00ol0003oYkkZ
ojNnjP02o`0000CoQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;o
E7KH00?o0000ooooooooool05Oooool3o`0000Gooooo00?o0000ooooooooool02_ooool001cooooo
0_l0000eooooo`05o`000?oQk][ohNkJon7^f_l000000ooMk=`00ol0003oeNGRomGUhP02omGUhP05
o`000?o4enSoa=OXolCGj?l000000onY`>X00ol0003oR:;UohRRi@02ohRRi@03o`000?mXPm[oJ8?J
00;oJ8?J00?o0000odm[com?Jll00_m?Jll00ol0003oJ6c3o`000002o`0000;oJ6c300?o0000ofMZ
`_mWJ/801?mWJ/800ol0003oQ7[1ohAj`@08ohAj`@03o`000?n:QlWo000000[oVHg50_l000000onO
XMGo0000ojRTd`0;ojRTd`Wo00001_nSa_400ol0003oXLCaoj74l@05oj74l@Oo00003?nl]]<2o`00
00koc;S600?o0000om_4`_oKa<801ooKa<801Ol0003og/>nomk3__oN`kko000000?oj=O300?o0000
onSGa?oXel@00ooXel@00ol0003ohmO:o`000002onS/d005o`000?oKiMcofnGLom_Ug?l000001?o5
e^H01Ol0003oYkkZojNnj_nW_^[o000000CoQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03
o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool04_ooool3o`0000Sooooo00?o0000oooooooo
ool02_ooool001cooooo00?o0000ooooooooool0=?ooool01Ol0003ohNkJon7^f_oQk][o000000?o
gNcL00?o0000omGUh_oEiN800_oEiN801Ol0003oa=OXolCGj?o4enSo000000?oZL3Z00?o0000ohRR
iOn8X^D00_n8X^D01Ol0003oJ8?JofR3f_mXPm[o000000CoCf_?0ol00004ofQ/``03o`000?mWJ/;o
If[200GoIf[200?o0000ohAj`On4N/401_n4N/42o`0000?oRXO900?o0000oiV=aOnISLD01?nISLD3
o`0000CoWj7E00?o0000ojRTdonXY=<01OnXY=<4o`0000;oYLOa00?o0000oj?6lOnSa_402_nSa_40
0ol0003oXLCaoj74l@0;oj74l@03o`000?nP`o7oX<?a00?o00002?nl]]<01?l0003o`KgFo`000?l0
000;olbhaP;o00002OoKa<800ol0003og/>no`000004onSG``03o`000?oXelCoj=O400Coj=O400Go
0000onS/d?oXk=3oj>c@o`000004om_Ug005o`000?o5e^KoaMKVolGFi_l000000onW_^X2o`0000?o
QZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000oooo
ooooool03_ooool4o`0000_ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000oooooooo
ool0=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oEiN800ol0
003oa=OXolCGj007o`0000?oR:;U00Ko0000ofR3f_mXPm[oJ8?Jo`000?m?Jll3o`000004odm[com1
GLSo@Eg8o`0000;oJ6c300?o0000ofMZ`_mWJ/801OmWJ/800ol0003oK776o`000006ohAj`@03o`00
0?n:QlWoRXO900CoRXO900Co0000oiV=aOnISLGoVHg50_l00008oinQe@03o`000?nXY=?oZ:CC00Co
00001OnUao43o`000003oj?6lOl0003o000000Wo00000onQa?43o`0000KoXLCa00?o0000oj33lOnP
`o401?nP`o43o`0000Co_;KC00?o0000ol6me_o1_MH00_o1_MH3o`0000Ooc;S600Co0000omG5booE
aL_o00002OoKa<800ol0003oj=O3onSG``04onSG``03o`000?oXelCoj=O400?oj=O400Go0000onS/
d?oXk=3oj>c@o`000004om_Ug005o`000?o5e^KoaMKVolGFi_l000000onW_^X2o`0000?oQZ?W00Go
0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool0
2oooool3o`00013ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Ooo
ool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00?o0000omGUh_oEiN800_oEiN83o`000003olK@
h_nY`>[oZL3Z00;oZL3Z0_moY>/4o`0000;oJ8?J0ol00003odm[c`07o`000?m1GLSo@Eg8od5Mb?l0
003oJ6c3o`000006ofMZ`P04o`000?m/LLKoK776o`0000GoQ7[100?o0000ohZ7bOn:QlT01On:QlT0
1?l0003oVHg5oiV=aOl0000:oinQe@?o00001OnUao44o`000004of7Fi_l0003o0000o`0000Go?;oP
0onlTjd00ol0003o/8V]ok29[@02ok29[@04o`000?nROjko9ZcQobJ/h@Ko00002_nP`o43o`000003
okbfdol0003o`KgF00Ko`KgF0_l00004olbhaP03o`000?oEaL_oeLG;00;oeLG;00?o0000om_4`_oK
a<801_oKa<800ol0003oj=O3onSG``04onSG``03o`000?oXelCoj=O400;oj=O40_l00003onS/d003
o`000?oKiMcofnGL00;ofnGL00Go0000olGFi_o5e^KoaMKVo`000003ojNnjP03o`000?n6XnOo0000
00;oQZ?W00Go0000ofb<h?m/S>3oK8cPo`000004oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000
ooooooooool02?ooool3o`0001?ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000oooo
ooooool0=Oooool01Ol0003ohNkJon7^f_oQk][o000000?ogNcL00Co0000omGUh_oEiN;oeNGR0_l0
0003olK@hP05o`000?nY`>[oZL3ZojW0j_l000001?moY>/3o`000003ofR3f_l0003oCf_?00?oCf_?
00?o0000od5Mb?m1GLP00_m1GLP00ol0003oIf[2ofMZ`P05ofMZ`P05o`000?m/LLKoK776ofaaa_l0
00000_n4N/42o`0000SoRXO90_l00009oinQe@?o00000_nWao001?l0003oYLOaojG7lOnUao42o`00
00;oHMKV0ol00003omBY[@?o000000?oaij^o`000?nlTjd00_nlTjd00ol0003o/8V]ok29[@02ok29
[@;oXWn^0ol00004oi9c[003o`000?mmIjoo8J3X00Co00001onP`o400ol0003o`KgFol6meP08ol6m
eP;o000000?oc;S6o`000?oEaL/01OoEaL/00ol0003oflC2om_4`P04om_4`P03o`000?oUelOo0000
00Koj=O300Ko0000onSGa?oXelCo0000ong^b?l00004onS/d005o`000?oKiMcofnGLom_Ug?l00000
0oo5e^H01Ol0003oYkkZojNnj_nW_^[o000000;oQZ?W00?o0000ohJSiol000000om/S>000ol0003o
FWcJoeYlfP02oeYlfP03o`000?mDM]SoE7KH00;oE7KH00?o0000ooooooooool01Oooool3o`0001Ko
oooo00?o0000ooooooooool02Oooool001_ooooo0_l0000eooooo`03o`000?oQk][ohNkJ00;ohNkJ
00Co0000omg/g?oMk=cogNcL1?l000000ooFemWo0000olK@hP03olK@hP05o`000?nY`>[oZL3ZojW0
j_moY>/00ol00002odaohP?o00001?m?Jll00ol0003o@Eg8od5Mb002od5Mb003o`000?mWJ/;oIf[2
00CoIf[200?o0000ofaaa_m/LLH00_m/LLH00ol0003oQ7[1o`000009ohZ7b@04o`000?nGW]WoUikI
o`0000GoWj7E0ol00005ojO7l0Co000000?oHMKVo`000?l000000ooQ^Zl01Ol0003oe:V]omBY[OoD
ZJgo000000;ob9b[3?l00002oj9mZ`03o`000?nBLjcoTW>/00;oTW>/00Oo0000ogeW[ommIjoo0000
of5H/Ol0003o8J3X00?o00000_nP`o401?l0003oWl7`oio1l?nO`O02o`0000Wo`KgF0_l00007omG5
b`03o`000?oKa<;oflC200;oflC200Co0000onGGaooUelOo00001_oXel<00ol0003oj=O4o`000002
ong^b003o`000?oXk=3oj>c@00;oj>c@00Ko0000om_Ug?oKiMcofnGLo`000?o5e^H<o`0000?oK8cP
00?o0000oeYlf_mJO=X00_mJO=X00ol0003oE7KHoeAff002oeAff003o`000?oooooooooo00;ooooo
0ol0000Iooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Cooooo00Go
0000on7^f_oQk][ohNkJo`000003omg/g0;o00001?oFemT00ol0003oa]3RolK@hP02olK@hP03o`00
0?nY`>[o000000;o00000omoY>/01Ol0003oC7oRodaoh_m<On;o000000CoCf_?00?o0000od5Mb?m1
GLP00_m1GLP00oloFlOo0000ofMZ`P04ofMZ`P03o`000?m/LLKoK77600?oK77600?o0000ohZ7bOn:
QlT01on:QlT00ol0003oUikIoiNNf@02oiNNf@03o`000?nOXMGoWj7E00;o00001OnWao06o`0000;o
klja00Go0000on6j[ooQ^ZoohKZ_o`000004omBY[@05o`000?o8W:_ob9b[olRLZol000000onlTJ/0
0ol0003o[hNZojn7ZP02ojn7ZP05o`000?nROJ_oXWf[oj9mZol000001?nBLj`01?l0003oOFN_ogeW
[ol00004of5H/@Co00001_nO`O02o`0000Oo`KgF00?o0000olK6f_l000001ooEaL/01Ol0003oflC2
om_4`_oKa<;o000000?oiMO700?o0000onSG`ooXel<01?oXel<01Ol0003okNk8ong^b?o]k/So0000
00Coj>c@00?o0000om_Ug?oKiM`00ol00002ol;Mk@04o`000?nW_^[oYkkZojNnjPCoSZ7Q0ol00002
ofb<h003o`000?mJO=[oFWcJ00;oFWcJ00?o0000oeAff?mDM]P00_mDM]P5o`0001cooooo00?o0000
ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01_l0003ohNkJon7^f_oQk][o
0000omg/g0;o000000?ogM[Co`000?oFemT01?oFemT00ol0003oa]3RolK@hP03o`0000;oZL3Z00?o
0000ognTjomoY>/00_moY>/3odaohP03oamKdOl0003oCf_?00;oCf_?00Go0000od5Mb?m1GLSo@Eg8
o`000002ocmKa`05o`000?mWJ/;oIf[2ofMZ`_l000001_m/LLH00ol0003oRXO9ohZ7b@05ohZ7b@;o
00001OnGW]T3o`0000GoYlO`0_l00002oh_[kP07o`000?ohi[3o0000ono>/Ol0003okljao`000003
on6j[`05o`000?oDZJgoe:V]omBY[Ol000001?o8W:/01Ol0003o_96[okbAZonlTJ_o000000Co[hNZ
00?o0000oj9mZonROJ/00_nROJ/00ol0003oTW>/oi9c[002oi9c[004o`000?mmIjooOFN_o`0000;o
HERa0_l00002oc90/@;o:iW`00?o0000oio1l?nO`O001?nO`O02o`0000Co`KgF00Go0000olK6f_o6
a][oa/KJo`000007omG5b`03o`000?oKa<;o000000GoiMO700?o0000onSG`ooXel<00ooXel<00ol0
003okNk8ong^b002ong^b009o`000?oXk=3oj>c@onS/d?l0003ofnGLo`000?oFmN?o000000;o`]g]
00Go0000ojNnj_nW_^[oYkkZo`000005ohjQh@05o`000?mlS=So0000ofb<h?l000001?mJO=X00ol0
003oE7KHoeAff002oeAff003o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool001[o
oooo00?o0000ooooooooool0=Oooool01?l0003ohNkJon7^f_oQk]X2o`0000CogM[C00?o0000omKG
fOoFemT00_oFemT3o`0000;oa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`08o`000?m<On;o
C7oRo`000?lOFm7o0000odm[col00004od5Mb004o`000?loFlOo?e_7o`0000;oIf[200?o0000ofaa
a_m/LLH01?m/LLH00ol0003oN87?o`000005ohZ7b@03o`000?nGW]WoUikI00CoUikI00Go0000ojW7
konYanooZLO_o`000002ojO7l0;o00000_n;jnh2o`0000;on>J`00Co0000ono>/Oo_c[7o00001?oQ
^Zl01Ol0003oe:V]omBY[OoDZJgo000000Cob9b[00Go0000okbAZonlTJ_o_96[o`000004ojn7ZP03
o`000?nROJ_oXWf[00;oXWf[00?o0000oi9c[?nBLj`00_nBLj`01_l0003oOFN_ogeW[ol0003oHERa
o`0000;oH5Na00Ko0000oc90/Olb@;7o01VUo`000?l[VO03o`0000CoWl7`0_l000000oo1_MKo0000
olK6fP04olK6fP03o`000?oEaL_oeLG;00GoeLG;00?o0000onGGaooUelL01?oUelL00ol0003oj=O3
onSG``02onSG``;o00001?o]k/P01?l0003oj>c@onS/d?oXk=02o`000003omKehol0003o`]g]00;o
`]g]00Go0000ojNnj_nW_^[oYkkZo`000004ohjQh@04o`000?mlS=So0000ogb<f0;o00001?mJO=X0
0ol0003oE7KHoeAff002oeAff003o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool0
01[ooooo0ol0000eooooo`03o`000?oQk][ohNkJ00;o00001OoMf]<00ol0003oe]OIo`000003o`00
00Coa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`04o`000?m<On;oC7oRodaohP;o7e_A0_l0
0004od5Mb007o`000?loFlOo?e_7ocmKaol0003oIf[2o`000005ofaaaP05o`000?mhPLooN87?ogR1
col000000on:QlT00ol0003oUikIoiNNf@04oiNNf@03o`000?nYanooZLO_00;oZLO_1_l000001OoY
mjOo0000ooSV/?ohi[3o000000?oklja0_l00002on6j[`03o`000?oDZJgoe:V]00;oe:V]00?o0000
olRLZoo8W:/00_o8W:/01Ol0003o_96[okbAZonlTJ_o000000Co[hNZ00?o0000oj9mZonROJ/00_nR
OJ/00ol0003oTW>/oi9c[002oi9c[003o`000?mmIjooOFN_00;o00000omPEk401ol0003o<T2aoc90
/Ol06JGo0000o`0BX?l000000_l[VO02o`0000;oWl7`00?o0000oio1l?l000001oo6a]X00ol0003o
eLG;omG5b`03omG5b`;o00001ooUelL01_l0003oj=O3onSG`ol0003ok^k7o`0000CokNk800?o0000
onS/d?oXk=000_l00002omKeh`05o`000?o2gNgo`]g]ol;MkOl000000onW_^X00ol0003oSZ7QohjQ
h@02ohjQh@05o`000?mlS=SoO8cHo`000?mlS=P00_l00003oeYlfP03o`000?mDM]SoE7KH00;oE7KH
00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`006_ooool00ol0003ooooooooo
o`0eooooo`05o`000?oQk][o0000on3KdOl000001?oMf]<3o`0000Coe]OI00Go0000olK@h_o6d>;o
a]3Ro`000003ojW0jP05o`000?moY>_oOjC[ognTjol000000om<On801?l0003o7e_AoamKdOl00004
od5Mb003o`000?loFlOo?e_700;o?e_700?o0000ofaaa_m/LLH01?m/LLH00ol0003oN87?ogR1c`02
ogR1c`03o`000?n:QlWo000000KoUikI00?o0000ojW7konYanl00_nYanl01?l0003o[oGbojoel_n_
mO82o`0000;ojONW00Co0000ooSV/?ohi[3o00000_o_c[401_l0003ohKV_on6i[ol0003ohKZ_o`00
00Coe:V]00Go0000olRLZoo8W:_ob9b[o`000004okbAZ`03o`000?n_Qj[o[hNZ00;o[hNZ00?o0000
oj9mZonROJ/00_nROJ/00ol0003oTW>/oi9c[003oi9c[004ogeW[ol0003oOFJ^o`0000CoH5Na00Oo
0000oc90/Olb@;7o0000o`0T[Ol04Z3o03>/00Go00001?nO_nl00ol0003oa/KJolK6fP04olK6fP05
o`000?oEaL_oeLG;omG5bol000000_oLeM400ol0003oiMO7onGGa`04onGGa`03o`000?oXel?o0000
00;ok^k700?o0000ong^b?o]k/P00_o]k/P01Ol0003oj>c@o`000?oNoM3o000000;oe_GS00Co0000
ol;MkOo2gNgo00000onW_^X00ol0003oSZ7QohjQh@02ohjQh@06o`000?mlS=SoO8cHogb<f?l0003o
O8cH0_maOm82o`000003oeYlf_l0003oE7KH00?oE7KH00?o0000ooooooooool07oooool00ol0003o
ooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Gooooo0_l00003on3Kd@Co00000_oMf]<00ol0
003oe]OIomKGf@02omKGf@05o`000?o6d>;oa]3RolK@h_l000001?nY`>X01Ol0003oOjC[ognTjomo
Y>_o000000;oC7oR00Go0000oamKdOlOFm7o14G5o`000003od5Mb003o`000?loFlOo?e_700;o?e_7
00?oB6C<o`000?m/LLH00om/LLH00ol0003oN87?ogR1c`04ogR1c`;o00001OnGW]T00ol0003oZLO_
ojW7k`02ojW7k`03o`000?n_mO;o[oGb00?o00000_oYmjL2o`000003ooSV/?l0003oklja00;oklja
00Co0000on6i[ooQ^JoohKV_0_l00004omBY[@05o`000?o8W:_ob9b[olRLZol000001?nlTJ/00ol0
003o[hNZojn7ZP03ojn7ZP05o`000?nROJ_oXWf[oj9mZol000001?nBLj`2o`0000?oOFJ^00Go0000
of1G/OmPEk7oH5Nao`000002oc90/@03o`000?l09:go02B]00;o01:P00Co03>/ocjElOlnUO7o?YGa
1OnO_nl00ol0003oa/KJolK6fP04olK6fP03o`000?oEaL_o000000Cog=GA00?o0000onGGaooUelL0
1?oUelL01Ol0003ok^k7onk^aoo^k/Oo000000CokNk80_l000001OoNoM3o0000omKehooFmN?o0000
00?o`]g]00Go0000ojNnj_nW_^[oYkkZo`000004ohjQh@03o`000?mlS=SoO8cH00;oO8cH00?o0000
og5od_maOm800_maOm82o`0000CoE7KH00?o0000ooooooooool07oooool00ol0003oooooooooo`08
ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`0eooooo`03o`000?oPfm7oh=_A00?o00001OoMf]<00ol0003oe]OIomKGf@02
omKGf@03o`000?o6d>;oa]3R00;oa]3R00Go0000ojW0j_nY`>[oZL3Zo`000003ognTj`04o`000?m<
On;oC7oRo`0000;o7e_A00Go0000o`A5aOl0003o@Eg8o`000005ocmKa`;oB6C<00Go0000ofaaa_m/
LLKoK776o`000006ogR1c`;oSIgN00Go0000oiNNfOnGW]WoUikIo`000004ojW7k`05o`000?n_mO;o
[oGbo`000?o6o/T00_l000001?oYmjOo0000ooOV]Oogi[D2o`0000;oklja00?o0000on6i[ooQ^Jl0
0_oQ^Jl00ol0003oe:V]o`000003o`0000Cob9b[00?o0000okbAZonlTJ/00_nlTJ/00ol0003o[hNZ
ojn7ZP03ojn7ZP03o`000?nROJ_oXWf[00;oXWf[00KoTW>/o`000?l0003o0000oi9b[?l00003ogeV
[P03o`000?mPEk7oH5Na00;oH5Na0_lb@;401_lhAkGo0000o`0T[Ol09:go0000o`0BX0;o00000_ln
UO400ol0003oWko_oinok`02oinok`03o`000?o6a][oa/KJ00Coa/KJ00?o0000omcEdOoLeM400ooL
eM400ol0003oiMO7onGGa`04onGGa`03o`000?o^k/Ook^k700;ok^k700Go0000ong^b?o]k/SokNk8
o`000002omkmd004o`000?oFmN?oe_GSo`0000;o`]g]00Go0000ojNnj_nW_^[oYkkZo`000005ohjQ
h@03o`000?mlS=SoO8cH00;oO8cH0_l00004og5odP;o00000omDM]P00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0eooooo`?o00000_oPfm400ol0003ogM[ComgJd`03omgJd`03
o`000?oFemWoe]OI00?oe]OI00Go0000olK@h_o6d>;oa]3Ro`000003ojW0jP05o`000?moY>_oOjC[
ognTjol000000om<On800ol0003o7e_AoamKd@02o`A5a@;o00001?loFlL01ol0003oB6C<odQTc?m8
I<co0000ofaaa_l000001_mhPLl01ol0003oSIgNohfMg_n=WMko0000oiNNfOl000001?nYanl01Ol0
003o[oGbojoel_l0003oa_k900Co00000oogi[D01Ol0003okljaono>/Oo_c[7o000000?ohKV_00?o
0000omBY[OoDZJd00ooDZJd4o`000003olRLZol0003o_96[00?o_96[00?o0000ojn7Z_n_QjX00on_
QjX01?l0003oXWf[oj9mZonROJ/2o`0000CoTW:/00?o0000ogeV[_mmIZh00_mmIZh01?l0003oH5Na
of1G/OmPEk42o`0000;o>4Ne00Co0000o`0T[Ol9?;co00000_l0Cld01?l0003o?YGaocjElOl00004
oinok`07o`000?o6a][oa/KJolK6f_l0003ob=3Oo`000006omcEd@03o`000?oUelOoiMO700;oiMO7
0_l00004onk^a`07o`000?o]k/SokNk8ong^b?l0003og_g@o`000002omKeh`05o`000?o2gNgo`]g]
ol;MkOl000000onW_^X00ol0003oSZ7QohjQh@02ohjQh@03o`000?mlS=SoO8cH00;oO8cH00?o0000
og5od_l000001?maOm82ofekc`04o`000?mDM]SoE7KHo`00027ooooo00?o0000ooooooooool02?oo
ool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`03ooooo`?o0000<oooool4
o`0000Goh=_A00?o0000omgJdooMf]<00ooMf]<00ol0003oe]OIomKGf@02omKGf@05o`000?o6d>;o
a]3RolK@h_l000001?nY`>X01?l0003oOjC[ognTjol00003odaohP04o`000?lOFm7o7e_Ao`0000;o
14G500?o0000ocmKaoloFlL00_loFlL00ol0003oB6C<odQTc002odQTc003o`000?mhPLooN87?00Co
N87?00?o0000ohfMg_n=WMh00on=WMh3o`0000;oZLO_1?l000001_o6o/Wo0000o`000?l0003ojONW
o`0000?omnJe00Go0000ono>/Oo_c[7okljao`000003on6i[`03o`000?oDZJgoe:V]00?oe:V]00Co
0000olRLZoo8W:_ob9b[1Ol000000onlTJ_o0000ojn7ZP04ojn7ZPCo000000?oXWf[o`000?nBLZ`0
1?nBLZ`01Ol0003oOFJ^ogeV[_mmIZko000000CoH5Na00So0000ocQ7]OlhAkGo>4Neo`0T[Ol0003o
2Cblo`0000;o04o=00Co0000ocjElOlnUO7o00001?nO_nl00ol0003oa/KJo`000003olS@g`03o`00
0?oLeM7og=GA00?og=GA00Oo0000onGGaooUelOoiMO7o`000?o[kLgo000000Cok^k700Co0000ong^
b?o]k/So00000_oNoM001?l0003oe_GSomKehol00002ol;Mk@03o`000?nW_^[oYkkZ00;oYkkZ00?o
0000ohjQhOn>XN400_n>XN400ol0003oO8cHogb<f002ogb<f004o`000?maOm;oLGoBo`0000;oLGoB
00Oo0000ofekcom]NlooKG_?o`000?mDM]So0000027ooooo00?o0000ooooooooool02?ooool000?o
oooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0<Oooool2o`0000Cooooo00?o0000on3KdOoPfm400_oPfm400ol0003ogM[ComgJd`03omgJ
d`03o`000?oFemWoe]OI00;oe]OI00?o0000olK@h_o6d>800_o6d>800ol0003oZL3Zo`000004o`00
0005ognTjol0003oC7oRodaoh_l000000_lOFm401?l0003o14G5o`A5aOl00004ocmKa`03o`000?m8
I<coB6C<00;oB6C<00?oGW[Go`000?mhPLl00omhPLl00ol0003oSIgNohfMgP04ohfMgP03o`000?n[
ankoZlO^00?o00000_o6l^h01?l0003oa_k9o`000?oZn[T2o`0000?omnJe00Go0000ong>]?l0003o
kljao`000004on6i[`03o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00_o8W:/01?l0003o
_96ZokbAZ_nlTJX8o`0000CoXWf[00?o0000oi9b[?nBLZ`00onBLZ`00ol0003oOFJ^ogeV[P02ogeV
[P03o`000?mPEk7oH5Na00;o00000olhAkD01Ol0003o02B]o`Tl_?l9?;co000000;o04o=1?l00002
oinok`?o00001?o8d=l00ol0003og=GAomcEd@04omcEd@03o`000?oUelOo000000;ojng=00?o0000
onk^aoo^k/L00_o^k/L01_l0003okNk8o`000?l0003og_g@o`0000;oe_GS00Go0000ol;MkOo2gNgo
`]g]o`000003ojNnjP03o`000?n>XN7oSZ7Q00;oSZ7Q00?o0000ogb<f?mlS=P00omlS=P01ol0003o
LGoBog5od_maOm;o0000og5od_l000001?m]Nll2o`00027ooooo00?o0000ooooooooool02?ooool0
00?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02kooooo0ol00006ooooo`03o`000?oPfm7oh=_A00?oh=_A00?o0000omgJdooMf]<00_oMf]<00ol0
003oe]OIomKGf@03omKGf@03o`000?o6d>;o000000?o00000_nZ_nT00ol0003oMJSbogFXlP03o`00
0003odaoh_l0003o7e_A00;o7e_A00Co0000o`A5aOl0003o00000oloFlL00ol0003oB6C<odQTc002
odQTc0;oGW[G00Go0000ogR1comhPLooN87?o`000005ohfMgP03o`000?n[ankoZlO^00;oZlO^00?o
0000olKbk_o6l^h00ol00002on[j^@05o`000?ogi[GomnJeooOV]Ol000000_o]c[@00ol0003oklja
o`000003on6i[`03o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96Z
okbAZP02okbAZP03o`000?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/
oi9b[002oi9b[003o`000?mmIZkoOFJ^00;oOFJ^00?o0000of1G/Ol000000_mSFk<01_l0003o>4Ne
ocQ7]OlhAkGo02B]o`0000;o2Cbl00?o0000o`1?cOl000000_mDT^d3o`0000;oWkg^00?o0000olS@
goo8d=l00oo8d=l00ol0003og=GAomcEd@03omcEd@;o00000oo[kLd00ol0003ok^k7onk^a`02onk^
a`?o00000_oNoM001?l0003oe_GSomKehol00003ol;Mk@05o`000?nW_^[oYkkZojNnj_l000001?n>
XN400ol0003oO8cHogb<f002ogb<f003o`000?maOm;oLGoB00?oLGoB00?o0000ofekcom]Nll01?m]
Nll00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00001?nHV9SooooooiRHV?mg
MgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:oooool3o`0000Wooooo00?o
0000on3KdOoPfm400ooPfm400ol0003ogM[ComgJd`03omgJd`04o`000?oFemWoe]OIomKGf@?o0000
0_o5b=`00ol0003oZ[oYojZoj@02ojZoj@08o`000?meZ?;oMJSbo`000?lVNNCo0000odaoh_l00002
oamKd@05o`000?l4ALGo14G5o`11`_l000000_loFlL01Ol0003oB6C<odQTc?m8I<co000000?oGW[G
00?o0000ogR1col000001On=WMh00ol0003oZlO^oj_7kP02oj_7kP03o`000?o6l^koa_;^00;o0000
00GoiOSBo`000?oZn[Woj_Zio`000002ooOV]@03o`000?o]c[CokLjd00;okLjd0_l00003on6i[`03
o`000?oDZJgoe:V]00?oe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96ZokbAZP02okbAZP03
o`000?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/oi9b[003oi9b[003
o`000?mmIZkoOFJ^00;oOFJ^00Go0000of=K/omSFk?oHe^co`000004ocQ7]@07o`000?l9?;co2Cbl
o`Tl_?l0003o04o=o`000002oeBBk@03o`000?nO_NkoWkg^00;oWkg^00?o0000olS@goo8d=l00_o8
d=l00ol0003og=GAomcEd@02omcEd@03o`000?oPj=So000000?ojng=00Co0000onk^aoo^k/Ook^k7
0_l000001OoNo/;o0000omkmd?oNoM3o000000;oe_GS1_l00002ojNnjP05o`000?n>XN7oSZ7QohjQ
hOl000001OmlS=P00ol0003oLGoBog5odP03og5odP03o`000?m]NlooKG_?00CoKG_?00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`07ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`00
00Gooooo00?o0000ooooooooool0:?ooool3o`0000gooooo00?o0000on3KdOoPfm400_oPfm400ol0
003ogM[ComgJd`03omgJd`06o`000?oFemWoe]OIo`000?oBb];o00001?o5b=`00ol0003oZ[oYojZo
j@02ojZoj@04o`000?meZ?;oMJSbo`0000;o9WWT0_l000001_lOFm7o0000o`A5aOl4ALGo0000o`11
`P;o00001?m8I<`00ol0003oGW[Goeije`02oeije`;o00001?n=WMh00ol0003oZlO^oj_7kP02oj_7
kP05o`000?o6l^koa_;^olKbk_l000000_oUn=801?l0003oj_Zio`000?l00002ooOV]@03o`000?o]
c[CokLjd00;okLjd00?o0000on2j/Ol000000_oQ^Jl00ol0003oe:V]omBY[@03omBY[@03o`000?o8
W:_ob9b[00?ob9b[00?o0000okbAZ_nlTJX00_nlTJX00ol0003o[hNZojn7ZP03ojn7ZP03o`000?nR
OJ_oXWf[00?oXWf[00?o0000oi9b[?nBLZ`00onBLZ`01?l0003oOFJ^ogeV[_mmIZh2o`0000CoHe^c
00Go0000ocQ7]OlhAkGo>4Neo`000003o`Tl_003oc9QdOl0Clgo000000?oE9;]00Go0000oinmk_nO
_NkoWkg^o`000005olS@g`04o`000?oLeM7og=GAo`0000;oh>SH00Go0000on_]cOo[kLgojng=o`00
0002onk^a`04o`000?oNoKoo0000o`0000;og_g@00?o0000omKehol000000_l00002ok_Tl`03o`00
0?nW_NWoYkgY00?o00000on>XN400ol0003oO8cHogb<f002ogb<f003o`000?maOm;oLGoB00?oLGoB
00?o0000ofekcol000001?m]Nll00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
000Iooooo`;o00009_ooool3o`00013ooooo00?o0000on3KdOoPfm400ooPfm400ol0003ogM[ComgJ
d`02omgJd`03o`000?oFemWo000000?od/[B00?o0000olG8g?o5b=`00_o5b=`00ol0003oZ[oYojZo
j@02ojZoj@07o`000?meZ?;oMJSbo`000?lVNNCo0000o`11`P02o`0000;o14G500Co0000o`11`_l0
@L;o00001?m8I<`00ol0003oGW[Goeije`02oeije`;oPYgT00Go0000ohfMg_n=WMkoSIgNo`000004
oj_7kP04o`000?o6l^koa_;^o`0000?oiOSB0_l00002oo;V_P;o00001?o]c[@01?l0003oh;Zaon2j
/OoP^[42o`0000Koe:V]00?o0000olRLZoo8W:/00oo8W:/00ol0003o_96ZokbAZP02okbAZP03o`00
0?n_Qj[o[hNZ00?o[hNZ00?o0000oj9mZonROJ/00onROJ/00ol0003oTW:/oi9b[003oi9b[004o`00
0?mmIZkoOFJ^o`0000;oOfVa00?o0000of=K/omSFk<00_mSFk<2ocQ7]@03o`000?m5EKko000000;o
2Cbl00Co0000oc9QdOl0Clgo00000omDT^d01Ol0003oWkg^oinmk_nO_Nko000000Cob=3O00?o0000
omcEdOl000000ooPj=P02ol0003ojng=on_]cOo[kLgo0000onk^aol0003og_foo`000?oNo/;o0000
00;og_g@0_l000001Oo1oNCo0000ok_Tlonki??o000000CoYkgY00Ko0000oiFPfol0003o0000ohjQ
hOl00004ogb<f003o`000?maOm;oLGoB00?oLGoB00Co0000ofekcom]Nloo00000om]Nll00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo02?ooooo
0ol0000Cooooo`03o`000?oPfm7oh=_A00?oh=_A00?o0000omgJdooMf]<00ooMf]<00ol0003od/[B
om;:dP03om;:dP03o`000?o5b=coaLSL00;oaLSL00?o0000ojZojOnZ_nT00_nZ_nT02Ol0003oMJSb
ogFXl_l0003o9WWTo`000?l0@L;o7e_Ao`000002o`A5a@04o`000?l0@L;o4E3<o`0000?oB6C<00?o
0000oeijeomNN]L00_mNN]L3oh:Mi003o`000?n=WMko000000CoZlO^1?l00003onGhdP03o`000?oZ
n[Wo000000;ol^Jn00?o0000ong>]?o]c[@00oo]c[@00ol0003oh;Zaon2j/@02on2j/@?o00001?oD
ZJd00ol0003ob9b[olRLZ`02olRLZ`03o`000?nlTJ[o_96Z00?o_96Z00?o0000ojn7Z_n_QjX01?n_
QjX00ol0003oXWf[oj9mZ`02oj9mZ`03o`000?nBLZcoTW:/00CoTW:/00?oOFJ^o`000?moJK400_mo
JK400ol0003oHe^cof=K/`02of=K/`03o`000?lhAkGo000000;oAEFn0_l9?;`01?l0003o<V7Aoc9Q
dOl00003oeBBk@03o`000?nO_NkoWkg^00;oWkg^00Co0000olS@goo8d=oob=3O0_l00004on3Xf004
o`000?o[kLgojng=on_]c@;o00000_oNoKl00ol0003og_k2o`000002o`0000;o`OgT00Co0000ok_T
lonki??o00001?nW_NT00ol0003oUJ3KoiFPf`02oiFPf`;o00000omlS=P00ol0003oLGoBog5odP03
og5odP03o`000?m]NlooKG_?00;oKG_?00?o0000ofekcol000009?ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Pooooo`?o00005oooool00ol0003oh=_Aon3Kd@03on3K
d@04o`000?oMf]?ogM[ComgJd`;o00001_oBb]800ol0003oaLSLolG8g002olG8g003o`000?nZ_nWo
Z[oY00;oZ[oY00Oo0000ogFXl_meZ?;o0000obIii?l0003o047200;o000000Ko14G5o`000?l0@L;o
0472oa5@c?l00002odQTc003o`000?mNN]OoGW[G00;oGW[G00Co0000oh:Mi?n2WNCoPYgT1ol00002
om7XiP04o`000?oUn=;oiOSBonGhdP;o00000oobi[h00ol0003okLjdong>]002ong>]003o`000?oP
^[7oh;Za00?oh;Za00?o0000om>[[ooCZjl01?l00005olRLZ`03o`000?nlTJ[o_96Z00?o_96Z00?o
0000ojn7Z_n_QjX01?n_QjX00ol0003oXWf[oj9mZ`03oj9mZ`03o`000?nBLZcoTW:/00;oTW:/0_l0
0005ogmY/@03o`000?mSFk?oHe^c00;oHe^c00Oo0000odEE__m5EKkoAEFno`000?l9?;co000000?o
<V7A1Ol00003oinmkP06o`000?o8d=oo0000o`000?o9f^Ko00001?oPj=P01Ol0003ojng=on_]cOo[
kLgo000000;og_fo00So0000omkn`_l0003o0000ojof^_l0003o`OgTo`0000;o^nCc00?o0000ojNm
jOnW_NT00_nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7o000000;oO8cH00?o0000og5o
d_maOm800omaOm800ol0003oKG_?ofekc`02ofekc`03o`000?m]Nloo000002Cooooo00?o0000oooo
ooooool01oooool001Sooooo00?o0000ooooooooool07Oooool3o`0001[ooooo00?o0000on3KdOoP
fm400ooPfm401?l0003ogM[ComgJdol00002omW;c003o`000?oBb];od/[B00?od/[B00?o0000olG8
g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb00?o0000obIii?l000000_l07ZD2
o`0000;o04720_lAD<`2o`0000GoGW[G00Go0000oh:Mi?n2WNCoPYgTo`000004ojc6k@05o`000?oA
j>KodNSVom7Xi_l000000_oUn=82o`0000?ol^Jn00?o0000onW?^ol000000oo]c[@00ol0003oh;Za
on2j/@02on2j/@03o`000?oCZjoodj^_00Codj^_0ol00003olRLZ`03o`000?nlTJ[o_96Z00?o_96Z
00?o0000ojn7Z_n_QjX01?n_QjX00ol0003oXWf[oj9mZ`03oj9mZ`03o`000?nBLZco000000;o0000
00?oTgF^o`000?moJK401?moJK400ol0003oHe^cof=K/`02of=K/`03o`000?m5EKkoAEFn00;oAEFn
00?o2Cblo`000?lbHM400_lbHM44ofV@i@Ko00000oo9f^H00ol0003oh>SHon3Xf002on3Xf003o`00
0?o[kLgojng=00;o00000_oNoKl01ol0003og_k2o`000?n_m[[o0000ol7mi?l000000_nki?<00ol0
003oYkgYojNmj@02ojNmj@03o`000?nEX=_oUJ3K00?oUJ3K00Oo0000ohV=dOn9SM7oRHgAo`000?ml
S=So000000GoLGoB00?o0000ofekcom]Nll00om]Nll00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo00Oooooo000Hooooo`03o`000?oooooooooo01[ooooo0ol0000Mooooo`03o`000?oPfm7o
h=_A00?oh=_A00?o0000omgJdol000001?oIbl`00ol0003od/[Bom;:dP03om;:dP03o`000?o5b=co
aLSL00?oaLSL00Go0000ojZojOnZ_nWoZ[oYo`000003ogFXlP03o`000?lVNNCo000000;o01jU00Co
14G5o`000?l0@L;o00000_lAD<`2o`0000?oGW[G00?o0000oh:Mi?n2WN@00_n2WN@00ol0003o[<K]
ojc6k@02ojc6k@09o`000?oAj>KodNSVom7Xi_l0003oiOSBo`000?oXi<go000000?ol^Jn00Ko0000
onW?^ooYck_o0000ong>]?l00005on2j/@03o`000?oCZjoodj^_00Codj^_00?o0000olNM[Oo7WJd0
1?l00005okbAZP03o`000?n_Qj[o[hNZ00Co[hNZ00?o0000oj9mZonROJ/01Ol00005oi=e[P03o`00
0?moJK7oOfVa00;oOfVa00Oo0000of=K/omSFk?oHe^co`000?mZIK[o000000CoAEFn0_l00002oc9Q
d@03o`000?mYT>GoJI3U00;oJI3U1?nP_>d01Ol0003obM[VolWJi_o9f^Ko000000Coh>SH00Co0000
on_]cOl0003o00000ooNoKl2o`000004ojof^_l0003o`OgTo`0000;o^nCc00?o0000ojNmjOnW_NT0
0_nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00?oRHgA00?o0000og5od_maOm80
0omaOm800ol0003oKG_?ofekc`04ofekc`;o00009?ooool00ol0003oooooooooo`07ooooo`006?oo
ool2o`0001Sooooo0ol0000Qooooo`03o`000?oPfm7oh=_A00;oh=_A0_l00006omW;c003o`000?oB
b];od/[B00?od/[B00?o0000olG8g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb
0_l000001?l0@L;o01jUo`0NYOl00002o`11`P;o4E3<0_lkL]d2o`000003oeijeol0003oPYgT00?o
PYgT00?o0000ojc6kOn/a^d00_n/a^d01_l0003odNSVom7Xi_l0003oiOSBo`0000;oj>C=00Co0000
oo;V__obi[ko00000ooYck/00ol0003okLjdo`000005on2j/@03o`000?oCZjoodj^_00?odj^_00?o
0000olNM[Oo7WJd01?o7WJd4o`0000;o_96Z00Co0000ojn7Z_n_Qj[o[hNZ1_l00003oj9o[@03o`00
0?nCMJkoTgF^00CoTgF^00?o0000ogmY/OmoJK400omoJK400ol0003oHe^co`000002ofYU^P03o`00
0?m5EKkoAEFn00;oAEFn0_mKKL`00ol0003o<V7Ao`000004ofV@i@05o`000?nP_>goX;c]oj2lkOl0
00000oo9f^H00ol0003oh>SHon3Xf002on3Xf0;o000000Cog_k9o`000?oNoKoog_fo1?l000001Oo1
oNCo0000ok_Tlonki??o000000CoYkgY00?o0000oiFPfonEX=/00onEX=/00ol0003oRHgAohV=d@04
ohV=d@03oh>3bol0003oLGoB00?oLGoB00?o0000ofekcom]Nll00om]Nll01?l0003oooooooooool0
000Tooooo`03o`000?oooooooooo00Kooooo000Hooooo`03o`000?oooooooooo01Cooooo0ol0000T
ooooo`07o`000?oPfm7oh=_Aon3KdOl0003ofl_9o`000007omW;c003o`000?oBb];od/[B00?od/[B
00?o0000olG8g?o5b=`00oo5b=`01Ol0003oZ[oYojZojOnZ_nWo000000?oMJSb0_l000001_l0@L;o
01jUo`0HWol0003o0472o`0000;o4E3<0olkL]d2o`0000?oPYgT00?o0000ojc6kOn/a^d00_n/a^d0
1?l0003odNSVom7Xi_oAj>H2o`0000Coj>C=0_l00005onW?^`;o00001?oP^[400ol0003odj^_om>[
[`04om>[[`03o`000?o7WJgoaif]00Coaif]00Co0000okbB[?nlTZco_9:/1_l00003ojn8[003o`00
0?nROjgoXWn]00?oXWn]00?o0000oi=e[_nCMJh01?nCMJh00ol0003oOfVaogmY/@03ogmY/@03o`00
0?mSFk?o000000?oJVFj00Co0000odEE__m5EKko00000omKKL`00ol0003o<V7Ao`000003ofV@i@05
o`000?nP_>goX;c]oj2lkOl000001?o9f^H00ol0003oh>SHon3Xf002o`0000;og_k900?o0000omkm
_ooNoKl00ol000001Oo1oNCo0000ok_Tlonki??o000000CoYkgY00?o0000oiFPfonEX=/00onEX=/0
0ol0003oRHgAohV=d@04ohV=d@04o`000?n3Pl_oPh?;o`0000;oLGoB00?o0000ofekcom]Nll01?m]
Nll01?l0003oooooooooool0000Tooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oo
oooooooo01;ooooo0ol0000Wooooo`04o`000?oPfm7oh=_Ao`0000?ofl_900?o0000omW;c?oIbl`0
1OoIbl`00ol0003od/[Bom;:dP03om;:dP03o`000?o5b=coaLSL00?oaLSL00?o0000ojZojOnZ_nT0
1ol000000ol0@L;o01jUo`0HW`02o`0000;o4E3<00Co0000oc]bgOlkL]go>g;M0_l00002oh:Mi003
o`000?n/a^go[<K]00;o[<K]00?o0000om7Xi_oAj>H00_l00005onSTc@;o00001OoYck/01?l0003o
g[bgo`000?l00002on2j/@03o`000?oCZjoodj^_00Codj^_00?o0000olNM[Oo7WJd01?o7WJd00ol0
003o_9:/okbB[003okbB[003o`000?n_R:co[hR/00Co[hR/00?o0000oj9o[OnROjd01?nROjd00ol0
003oTgF^oi=e[P04oi=e[P03o`000?moJK7oOfVa00;oOfVa0_l00005ofYU^P03o`000?m5EKko0000
00CoFfg<00?o<V7Ao`000?mYT>D00_mYT>D00ol0003oX;c]oj2lk@02oj2lk@0;o`000?o9f^KobM[V
olWJi_l0003oh>SHo`000?oJnMgo0000omknbOl000000_oNoKl3o`000005ol7mi?l0003o^nCcok_T
lol000001?nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00CoRHgA00?o0000oh>3
bon3Pl/00_n3Pl/00ol0003oLGoBo`000006ofekc`05o`000?ooooooooooooooool000008oooool0
0ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000:oooool2o`00
00Gofl_900?o0000omW;c?oIbl`01OoIbl`00ol0003od/[Bom;:dP02om;:dP03o`000?o5b=coaLSL
00?oaLSL0ol00003ojZoj@0<o`000?m][_SoKJkhoff^n?l0003o0472o`0NYOl069oo0472o`000?lA
D<co00000olkL]d2ogFOk0?o00001?n/a^d3o`000003om?Kg_l0003oj>C=00Coj>C=00?o0000onW?
^ooYck/00ooYck/00ol0003og[bgomjl]`02omjl]`03o`000?oP^[7o000000Godj^_00?o0000olNM
[Oo7WJd01?o7WJd00ol0003o_9:/okbB[004okbB[003o`000?n_R:co[hR/00Co[hR/00?o0000oj9o
[OnROjd01?nROjd00ol0003oTgF^oi=e[P04oi=e[P03o`000?moJK7oOfVa00;o000000?oPg2fo`00
0?mZIKX01?mZIKX00ol0003oAEFno`000005oe]]c0;o00000_mYT>D00ol0003oX;c]oj2lk@02oj2l
k@04o`000?o9f^KobM[VolWJiP;o000000Kof_WMo`000?oNo/Wog_k9o`000?oNoKl3o`000005ol7m
i?l0003o^nCcok_Tlol000001?nW_NT00ol0003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00Co
RHgA00?o0000oh>3bon3Pl/01?n3Pl/2o`0000GoKG_?00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00cooooo
0ol0000^ooooo`03o`000?oKblWofl_900Gofl_900?o0000omW;c?oIbl`01?oIbl`00ol0003od/[B
om;:dP03om;:dP05o`000?o5b=coaLSLolG8g?l000000oo2`=P4ojZoj@;o00000_m][_P2o`000003
o`0NYOl069oo000000;o4E3<00Co0000oc]bgOlkL]go00000omeWn`6o`0000Codm_N00?o0000onST
cOoXi<d00_oXi<d00ol0003ojLnkonW?^`03onW?^`03o`000?oN_;Oog[bg00?og[bg0_l00005om>[
[`03o`000?o7WJgoaif]00Coaif]00?o0000okbB[?nlTZ`01?nlTZ`00ol0003o[hR/ojn8[004ojn8
[003o`000?nROjgoXWn]00CoXWn]00?o0000oi=e[_nCMJh01?nCMJh00ol0003oOfVao`000004oh=`
]P03o`000?mZIK[oJVFj00?oJVFj00?o0000oe]]c?mKKL`01?mKKL`2ogZ@g003o`000?mYT>Go0000
00CoX;c]00?o0000olWJi_l000000_l00002om[ig@03o`000?oNo/Wog_k900[o00000onW_NT00ol0
003oUJ3KoiFPf`03oiFPf`03o`000?n9SM7oRHgA00CoRHgA00?o0000oh>3bon3Pl/01On3Pl/2oh5o
b003o`000?m]NlooKG_?00;oKG_?00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Kooooo000Gooooo`;o00002_ooool3o`00037ooooo00?o0000om_;bOoK
blT01_oKblT00ol0003ofL_<omW;c004omW;c003o`000?oBb];od/[B00?od/[B00?o0000olG8g?l0
00001Oo2`=P00ol0003oZ[oYojZoj@02ojZoj@03o`000?m][_SoKJkh00;o000000Go01ROo`0`]?l0
003o4E3<o`000003oc]bg@04o`000?meWncoMIo/o`0000Co[LG/00?o0000om?Kg_oCfmh00_oCfmh0
1ol0003oj>C=onSTcOoXi<go0000on7@a_l000000ooYck/00ol0003og[bgomjl]`04omjl]`04o`00
0?oB[K?o0000o`0000?odj^_00?o0000olNM[Oo7WJd01?o7WJd00ol0003o_9:/okbB[004okbB[003
o`000?n_R:co[hR/00Go[hR/00?o0000oj9o[OnROjd00onROjd00ol0003oTgF^oi=e[P04oi=e[P;o
00001On3L;H00ol0003oJVFjofYU^P03ofYU^P03ogIfaOl0003oFfg<00?oFfg<00?o0000ogZ@g?mj
T=`00_mjT=`7o`0000;oa^?]00Go0000om[igOoJnMgo0000omknb@05o`0000;o[nKi00Oo0000ojNm
jOnW_NWoYkgYo`000?nW_NWo000000GoUJ3K00?o0000ohV=dOn9SM401?n9SM400ol0003oPh?;oh>3
b`05oh>3b`05o`000?n1OlSoPGo8oh5ob?l000000_m]Nll00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_oo
ool3o`0003Gooooo00?o0000om_;bOoKblT01OoKblT00ol0003ofL_<omW;c005omW;c003o`000?oB
b];od/[B00?od/[B00?o0000ol;0f?o2`=P01_o2`=P01Ol0003oZ[oYojZojOnZ_nWo000000?oKJkh
00?o0000o`0HWol0<;@00_l00003oc]bg@04o`000?meWncoMIo/o`0000Co[LG/00?o0000om?Kg_oC
fmh00_oCfmh01?l0003oj>C=onSTcOl00003on7@aP03o`000?oYck_o000000Kog[bg00?o0000om:]
/ooB[K<00_oB[K<3o`0000Ooaif]00?o0000okbB[?nlTZ`01?nlTZ`00ol0003o[hR/ojn8[005ojn8
[003o`000?nROjgoXWn]00?oXWn]00Co0000oi=e[_nCMJkoTgF^0ol000000onEN[?o0000oh=`]P05
oh=`]P05o`000?mZIK[oJVFjofYU^_l000000_mfM/D01Ol0003oFfg<oe]]c?mKKLco000000CoNY3L
00?o0000oj6kjonQ^n/00_nQ^n/01?l0003oa^?]olKSkOl00002om[ig@03o`000?oNo/Wo000000Co
000000?o[nKio`000?l000001?nW_NT3o`0000CoUJ3K00?o0000ohV=dOn9SM401?n9SM400ol0003o
Ph?;oh>3b`05oh>3b`03o`000?n1OlSoPGo800?oPGo800?o0000ofekcol000002?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo
0ol0000iooooo`03o`000?oKblWofl_900Gofl_900?o0000omW;c?oIbl`01OoIbl`01Ol0003od/[B
om;:d_oBb];o000000;ocKk<2?o2`=P01?l0003oZ[oYojZojOnZ_nT2o`0000;oKJkh00Go0000o`0H
Wol0<;Co4E3<o`000002oc]bg@05o`000?meWncoMIo/ogFOk?l000000on]aN`00ol0003odm_Nom?K
gP03om?KgP;o00001?oQd<H00ol0003ojLnko`000006omjl]`03o`000?oB[K?odZfc00CodZfc0ol0
0005olNM[@03o`000?nlTZco_9:/00Co_9:/00?o0000ojn8[?n_R:`01On_R:`00ol0003oXWn]oj9o
[@04oj9o[@?o00001OnEN[<00ol0003oPg2foh=`]P03oh=`]P04o`000?mZIK[oJVFjo`0000CoMWK5
00Co0000oe]]c?mKKLco00001?mjT=`01Ol0003oXK_[oj6kjonQ^n_o000000?oa^?]00?o0000om[i
gOoJnMd00_l000000onVkZ_o0000o`000002ojoVn@03o`000?nW_NWoYkgY00?oYkgY00Co0000oibP
eonLX=OoW:3G0_l000000onEX=_o0000ohV=d@05ohV=d@03o`000?n3Pl_oPh?;00GoPh?;00?o0000
oh5ob?n1OlP01On1OlP00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool001Kooooo00Co0000oooooooooooooooo0ol0000mooooo`03o`000?oKblWo
fl_900Gofl_900?o0000omW;c?oIbl`01OoIbl`00ol0003od/[Bo`000004olfnc0;o00001_o2`=P2
o`0000?oZ[oY00?o0000off^n?m][_P00_l000001Ol0<;Co0000o`000?lkL]go000000?oMIo/00?o
0000ojg5k?n]aN`00_n]aN`01?l0003odm_Nom?Kg_oCfmh2o`0000KohM360_l00006omjl]`03o`00
0?oB[K?odZfc00CodZfc00?o0000olNP/Oo7X;400ol000000oo7WJgo0000okbB[006okbB[003o`00
0?n_R:co[hR/00Go[hR/00Co0000oj9o[OnROjgoXWn]1?l00007oiEj/`03o`000?n3L;KoPg2f00?o
Pg2f00?o0000ofYU^_l000001_mfM/D2o`0000CoNY3L00?o0000oj6kjonQ^n/00_nQ^n/01Ol0003o
a^?]olKSkOo6hngo000000;of_WM00Go0000ojK^Zol0003o0000ojoVn@02o`0000CoYkgY0_l00005
oibPe`;o00001_n9SM400ol0003oPh?;oh>3b`05oh>3b`03o`000?n1OlSoPGo800GoPGo800?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Foooo
o`Co0000@Oooool00ol0003ofl_9om_;b@05om_;b@03o`000?oIblcofL_<00GofL_<00?o0000olfn
c?o=_/`01Oo=_/`00ol0003o`/3Hol;0f005ol;0f004o`000?nZ_nWoZ[oYojZoj@;o00000_m][_P2
o`000004o`YVf_l0003o>g;Mo`0000;oMIo/00?o0000ojg5k?n]aN`00_n]aN`4o`000003om7>eol0
003ohM3600GohM3600?o0000omRo`Ol000001?oN_;L00ol0003odZfcom:]/`05om:]/`03o`000?o7
X;7oaj2a00?oaj2a1_l00003okbB[004o`000?n_R:co[hR/ojn8[0So00000onSPk400ol0003oUGZc
oiEj/`05oiEj/`03o`000?n3L;KoPg2f00?oPg2f0_l00008ogIfa@;o00000omjT=`00ol0003oXK_[
oj6kj`02oj6kj`05o`000?o6hngoa^?]o`000?oJnMd00_l000000onVkZ_o0000ojoVn@02o`0000Go
YkgY00?o0000oibPeonLX=L01?nLX=L00ol0003oUI3;o`000005ohV=d@03o`000?n3Pl_oPh?;00Go
Ph?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01Oooool001Kooooo0ol00013ooooo`03o`000?oKblWofl_900Cofl_9
00?o0000omW;c?oIbl`01OoIbl`00ol0003od[g6olfnc006olfnc0;o00001_o2`=P2o`0000?oZ[oY
00?o0000off^n?l069l00_l00002o`YVfP?o000000?oMIo/o`000?n]aN`00ol00005om7>e`03o`00
0?oQd<KohM3600;ohM3600Co0000omRo`OoH_l7of;o10_l00002omjl]`03o`000?oB[K?odZfc00Co
dZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/002ok^F/0Oo00001?n`S;000ol0003o
Xh>aoj>3/@04oj>3/@03o`000?nEN[?oUGZc00KoUGZc00Oo0000oh=`]_n3L;KoPg2fo`000?n9OKoo
000000OoMWK500Co0000ohRAeOn8TMGo00000_mjT=`01Ol0003oXK_[oj6kjonQ^n_o000000?oa^?]
0_l000001OnloMSo0000o`000?n_i_Wo000000GoYkgY0_l00005oibPe`;o00000onET</01Ol0003o
RHgAohV=dOn9SM7o000000OoPh?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool000cooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00?o0000om_;bOoKblT01?oKblT00ol0003o
fL_<omW;c003omW;c005o`000?oB_LKod[g6om:ma_l000001oo=_/`00ol0003o`/3Hol;0f005ol;0
f00;o`000?nZ_nWoZ[oYojZojOl0003oKJkho`000?l0<;Co0000o`YVf_l000000_mWX_83o`0000;o
[LCZ00?o0000om7>eooAc]L01?oAc]L01?l0003ohM36on7@a_l00006omRo`@03o`000?oN_;Oo0000
00KodZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/005ok^F/003o`000?n`S;3o/8b`
00Go/8b`00?o0000oj>3/OnSPk401OnSPk400ol0003oUGZcoiEj/`05oiEj/`04o`000?n3L;KoPg2f
o`0000?oRGfo00?o0000ogIfaOmfM/D00omfM/D00ol0003oR97EohRAe@02ohRAe@;o00001?nQ^n/0
1_l0003oa^?]olKSkOo6hngo0000okcmf0Co00001?nW_NT2o`0000GoW:3G0_l00006oiF@b`03o`00
0?n9SM7o000000OoPh?;00?o0000oh5ob?n1OlP01On1OlP00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oKblWofl_900Gofl_900Go0000omW;c?oIblcofL_<
o`000005om:maP;o00001_o=_/`2o`0000Ko`/3H00?o0000ojZojOnZ_nT01?l000001?l0<;Co0000
o`YVf_l00002ofNRlP03o`000?n]a>[o[LCZ00;o[LCZ00?o0000om7>eooAc]L01?oAc]L00ol0003o
hM36o`000007omRo`@;o00001_oB[K<00ol0003oaj2aolNP/@05olNP/@03o`000?nkU[3o^iJ`00Go
^iJ`00?o0000ok2</?n`S;001On`S;000ol0003oXh>aoj>3/@05oj>3/@03o`000?nEN[?oUGZc00Go
UGZc00?o0000oh=`]_l000001On9OKl01Ol0003oMWK5ogIfaOmfM/Go000000KoR97E0ol00002oj6k
j`Co000000Co_?gHo`000?l0003o00001OnW_NT00ol0003oW:3GoibPe`04oibPe`03o`000?nET<_o
UI3;00KoUI3;0_l00007oh>3b`03o`000?n1OlSoPGo800GoPGo800?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0@Oooool00ol0003ofl_9om_;b@05om_;b@03o`000?oIblco0000
00Sod[g600?o0000olfnc?o=_/`01Oo=_/`00ol0003o`/3Hol;0f004ol;0f0;o00000onY_nT4o`00
0005o`YVf_l0003oIj;bofNRl_l000001?n]a>X00ol0003odLkGom7>e`03om7>e`?o00001ooH_l40
0ol0003oc[6lo`000002o`0000?odZfc00?o0000olNP/Oo7X;401Oo7X;400ol0003o^iJ`ok^F/005
ok^F/003o`000?n`S;3o/8b`00Go/8b`00?o0000oj>3/OnSPk401OnSPk400ol0003oUGZcoiEj/`05
oiEj/`;o00001on9OKl00ol0003oMWK5o`000007ohRAe@03o`000?nS^n[oXk_Z00?o00000_nljo@5
o`0000?oYkgY0_l00005oibPe`;o00002?nET</01?l0003oTHO5oi67aOl00005oh>3b`03o`000?n1
OlSoPGo800GoPGo800?o0000ooooooooool04_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00[ooooo0_l00012ooooo`03o`000?oKblWo
fl_900Gofl_900?o0000om:ma_oB_LH02?oB_LH2o`0000KocKk<0_l00003ol;0f003o`000?no^MCo
_kWD00;o00000onY_nT3o`000005o`YVf_l0003oIj;bofNRl_l000001?n]a>X01Ol0003odLkGom7>
eooAc]Oo000000?oc<;A00?o0000omRo`OoH_l400ooH_l400ol0003oc[6lolja_003olja_0?o0000
1oo7X;400ol0003o^iJ`ok^F/006ok^F/003o`000?n`S;3o/8b`00Ko/8b`00?o0000oj>3/OnSPk40
1?nSPk400ol0003oUGZcoiEj/`02oiEj/`?o000000?oVHBlo`000?n9OKl01_n9OKl2o`0000OoR97E
00Go0000oj>kj_nS^n[oXk_Zo`000003okc[m0?o00000onX_NT00ol0003oYkgYo`000006oibPe`03
o`000?nET<_oUI3;00KoUI3;0_l00004oi67a@05o`000?n3Pl_oPh?;oh>3bol000001on1OlP00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`03o`000?oKblWofl_900?o
fl_900Co0000om>la?oC_<Co00002_oB_LH00ol0003ocKk<olfnc005olfnc003o`000?o2`=So0000
00Go_kWD0_l00003ojVoj@03oh800?l0003o000000?oIj;b00?o0000ojg4j_n]a>X00_n]a>X00ol0
003odLkGo`000005olc2d@03o`000?oH_l7of;o100;of;o100?o0000olja_?o>/K`01Oo>/K`3o`00
00Goaj2a00?o0000ok^F/?nkU[001_nkU[000ol0003o/8b`ok2</006ok2</003o`000?nSPk7oXh>a
00GoXh>a1?l00005oiV4_003o`000?n9OKooRGfo00?oRGfo00Co0000oiBCd?nDTm3o00001On8TMD0
1Ol0003oXk_Zoj>kj_nS^n[o000000?o_>_d0_l00005ojRmj@;o00001OnLX=L2o`0000OoUI3;0_l0
0007oi67a@03o`000?n3Pl_o000000OoPGo800?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Cooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0@?ooool01Ol0003ofl_9om_;bOoKblWo000000Codkc40_l00009om:maP03o`000?o=
_/cocKk<00GocKk<00?o0000oknie?no^M@01_no^M@2o`0000?oZKoY00GoPP00o`000?mWX_;oIj;b
o`000004ojg4jP;o00001oo<`]401?l0003of;o1omRo`Ol00008olja_003o`000?o5Y[[oaJJj00Co
000000?oaj2ao`000?nkU[001onkU[000ol0003o/8b`ok2</006ok2</004o`000?nSPk7oXh>aoj>3
/@Go00002OnIQ;`00ol0003oRGfoohUm_`02o`0000CoU9?@00Go0000ohRAeOn8TMGoR97Eo`000003
oj>kjP04o`000?nljoCo_>_dokc[m0;o00000onX_NT3o`000003oj>Re?l0003oW:3G00;oW:3G0_l0
0008oiF@b`03o`000?nAQlGoTHO500OoTHO50_l00007oh5ob003o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo043ooooo00?o0000om_;bOl000001ooC_<@00ol0003od[g6om:maP07
om:maP;o00001Oo=_/`00ol0003oakC8o`000008oknie0?o000000?oZKoYoh800?l000000ol00000
0on]a>[o0000o`000003ojg2j@03o`000?o<`]7oc<;A00Coc<;A00?o0000omRo`Ol000001oo>/K`0
0ol0003oaJJjolFV^P05olFV^POo00000onkU[000ol0003o/8b`ok2</002ok2</0So00001?nUS;X0
0ol0003oVHBloiV4_007oiV4_003o`000?n9OKoo000000OoU9?@00?o0000ohRAeOl000000onS^nX0
1?l0003o_>_dokc[m?nljo@2o`0000;oZ;gY0_l00005oj>Re003o`000?nLX=Oo000000SoUI3;0_l0
0009oi67a@03o`000?n@Q<?o000000KoPGo800?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Cooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00011
ooooo`;o00002?oC_<@2o`0000Wod[g600Go0000olfnc?o=_/cocKk<o`000004olNdb0?o00001ono
^M@4o`000003oeZWn?l0003o000000Ko[L;Y0_l00005olc2d@03o`000?o>/Kcoc[6l00Koc[6l00?o
0000olFV^_o5Y[X01_o5Y[X00ol0003o^ibiok^L^@03ok^L^@So00001?n`TkT00ol0003oYHbjojF<
^P06ojF<^P03o`000?nIQ;coVHBl00KoVHBl0_l00008oiBCd0Co000000?oXk_Zo`000?nljo@00_nl
jo@00ol0003oZ;gYo`000002o`0000OoXj;D0_l00008oiF@b`03o`000?nAQlGoTHO500OoTHO50_l0
0003oi24``03o`000?n1OlSoPGo800;oPGo800?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo043ooooo00?o0000
om>la?oC_<@01ooC_<@00ol0003od[g6om:maP07om:maP03o`000?o=_/co000000SoakC80_l00007
oknie0;o000000GoPP00o`000?mJYoSoFZOho`000006ojg2j@05o`000?o<`]7oc<;Aolc2dOl00000
0_o6^<d3o`0000Coc[6l00?o0000olFV^_o5Y[X01_o5Y[X00ol0003o^ibiok^L^@06ok^L^@03o`00
0?n`TkWo/9>i00Ko/9>i00?o0000ojF<^_nUS;X01_nUS;X00ol0003oVHBloiV4_004oiV4_0;o0000
00?oWYO<o`000?nDTm001OnDTm02o`0000?oY;[Y2?l00007oj>Re0?o000000?oWi?8o`000?nET</0
1OnET</2o`0000WoTHO500?o0000oi24`on@Q<<01?n@Q<<01?l0003oPGo8oh5ob?l0000Oooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002?ooooo00?o0000ooooooooool0
@?ooool2o`0000Sodkc400?o0000om:ma_oB_LH01ooB_LH00ol0003oakC8olNdb009olNdb0;o0000
1ono^M@01Ol0003oPP00o`000?l0003oFZOh00;o00001On]`^T00ol0003oc<;Ao`000006olJhc@Co
00002Oo5Y[X00ol0003o^ibiok^L^@06ok^L^@03o`000?n`TkWo/9>i00Ko/9>i00?o0000ojF<^_nU
S;X01_nUS;X01?l0003oVHBloiV4_?nIQ;`3o`0000CoWYO<00Co0000oiBCd?nDTm3oU9?@0_l00004
ojBjj@04o`000?n/kOSo[>ghojc]n0;o00002?nSX]@2o`0000GoWi?800Co0000oiF@bonET<_oUI3;
0_l00009oi67a@;o00001on@Q<<00ol0003oPGo8o`00000Pooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool002Cooooo0_l00012ooooo`03o`000?oC_<Codkc400Kodkc40_l0
0007om:maP04o`000?o://;o0000o`0000[oakC80_l00007oknie0Co000000?oFZOho`000?l00000
1?n]`^T00ol0003oa[S=olJhc@08olJhc@?o00001_o5Y[X00ol0003o^ibiok^L^@07ok^L^@03o`00
0?n`TkWo/9>i00Oo/9>i00?o0000ojF<^_nUS;X01_nUS;X3o`0000OoWYO<00Co0000oiBCd?l0003o
00001?nT^^T2o`0000;o[>gh0_l00007oj>Re0?o00002?nOTlP00ol0003oUI3;o`000009oi67a@;o
00002On@Q<<2o`0002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00
9_ooool00ol0003oooooooooo`10ooooo`03o`000?oC_<Codkc400Oodkc400?o0000om:ma_oB_LH0
0ooB_LH00ol0003ob[;2olZb`P03olZb`P;o00002Oo7]<P3o`0000Co_kWD00?o0000okZcd_l00000
0_l00002oeZWn003o`000?n]`^Wo000000?o[L7X0_l00007olJhc@03o`000?no[l[o_jo:00Go0000
00?oaJJjo`000?nkW;T02?nkW;T00ol0003o/9>iok2C^@07ok2C^@03o`000?nUS;[oYHbj00CoYHbj
0ol00009oijGc0?o00000onT^^T2o`0000?o[>gh00?o0000oj>Re?nSX]@01?nSX]@3o`0000_oWi?8
0_l00009oi67a@03o`000?n@Q<?oT8C300SoT8C300?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Wooooo`03o`000?oooooooooo043ooooo0_l0
0008om>la0;o00000_oB_LH00ol0003ob[;2olZb`P06olZb`P;o00002_o7]<P2o`000003oknie?l0
003o^[?B00?o^[?B00?oE`00o`000?l000000_l00006ojg1j0?o00000oo6^<d00ol0003o_jo:okn_
bP06okn_bPOo00001?nkW;T00ol0003o/9>iok2C^@07ok2C^@03o`000?nUS;[o000000Co00000_nX
VlT00ol0003oWYO<oijGc005oijGc0;o00000onV^nP00ol0003oY;[Yo`000003ojc]n0;o00001OnS
X]@2o`0000_oWi?80ol000000onMS<7o0000oi67a@06oi67a@;o00002On@Q<<2o`0002Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0003oooooooooo`11
ooooo`03o`000?oC_<Codkc400Oodkc400?o0000om:ma_l000002_o://83o`0000WoakC800?o0000
okZcd_nj/m801Onj/m801?mG003oD:kjoe2^n_m@[_X2o`0000Ko[L7X0_l000000oo6^<go0000okn_
bP08okn_bP03o`000?nhYlSo^:O800?o^:O84?l00008ojRKb@04o`000?nNUlcoWYO<oijGc0?o0000
1OnV^nP4o`000006ojc]n?l0003oZJGBojVUd_l0003oXj;D0ol0000;oinCb0;o00001OnMS<400ol0
003oTHO5oi67a@03oi67a@03o`000?n@Q<?oT8C300SoT8C300?o0000ooooooooool09oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Yooooo`;o0000@_ooool2o`0000So
dkc400?o0000olZb`_o://803?o://82o`0000OoakC800?o0000ol2/a_o0[<H00ol00004okZcdP04
oeL00?l0003oD:kjoe2^nP;o00001_n]`NP00ol0003o_jo:okn_bP08okn_bP03o`000?nhYlSo^:O8
00Oo^:O800?o0000ok2Qb?n`XLP01on`XLP00ol0003oZ9_9ojRKb@07ojRKb@04o`000?nNUlco0000
o`0000GoY[_X0ol00003oiCXnP;o00000_nYYM83o`0000coWi?80_l00008oif<`@03o`000?nAQlGo
THO500;o00002On@Q<<2o`0002_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03
ooooo`00:oooool00ol0003oooooooooo`11ooooo`03o`000?oC_<Codkc400Godkc400?o0000ol^a
`?l000000_l0000<olZb`P;o00001?o7]<P00ol0003o`:c6ol2/aP05ol2/aPCo00000_nj/m801?l0
003oD:kjoe2^n_l00004ojg1j004o`000?n/_nOo[;oWojboi`?o00001?no[lX00ol0003o^:O8okRW
b008okRWb003o`000?n`XLSo/:7800Oo/:7800?o0000ojRKbOnXVlT01_nXVlT3o`0000GoY[_X0_l0
0003oiCXnPOo00000_nXV<D00ol0003oWi?8oinCb007oinCb0?o00002_nMS<400ol0003oTHO5o`00
0009oi24``;o0000;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000/
ooooo`03o`000?oooooooooo047ooooo00?o0000om>la?oC_<@00ooC_<@00ol0003obk70ol^a`003
ol^a`0;o00003?o://83o`000003olNdb?l0003o`:c600[o`:c61Ol000001Om@[_[o0000o`000?n]
`NSo000000Oo[;oW0ol000000ono[l[o0000okRWb009okRWb003o`000?n`XLSo/:7800So/:7800?o
0000ojRKbOnXVlT01Ol00003ojRki`03o`000?nV^nSo000000;o00000_nDj?X6o`0000OoZ9S500?o
0000oinCb?nOTlP01?nOTlP2o`0000goWHc10_l00009oi24``03o`000?oooooooooo02oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003oooooooooo`11
ooooo`;o00000_oC_<@00ol0003obk70ol^a`006ol^a`0?o00003?o://800ol0003o`:c6ol2/aP0>
ol2/aPGo00002on/_nL8o`0000Co^:O800?o0000ok2Qb?n`XLP00on`XLP8o`0000OoZ;_W1?l00000
0onDj?[o0000o`000002o`0000coZ9S500?o0000oinCb?nOTlP00_nOTlP2o`0000coWHc10ol00000
0onLRKoo0000oi24``06oi24``;o0000<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00?ooooo000^ooooo`;o0000@oooool00ol0003odkc4o`00000;ol^a`0;o00002_o://800ol0
003o`ZRool:X_`04o`0000ko`:c60ol000000om<]oWo0000o`000004o`0000?o[;oW00?o0000oj^m
ion[_NL01?n[_NL:o`0000GoZKcW00?o0000ojRkionX^nL00onX^nL4o`000003og[MnOl0003o0000
00;o00004?nXV<D00ol0003oWi?8o`000002o`0000coWHc10_l00005oib9_`03o`000?n@Q<?oT8C3
00?oT8C300?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000ol^a`?o;/L003?o;/L03o`0000Ko
b[;200?o0000ol:X_oo2Z;l01Oo2Z;l5o`0000[o`:c600?o0000okRTa?nhY<@00_nhY<@7o`0000Go
ZkgW00?o0000oj^mion[_NL00on[_NL00ol0003oZKcWojVli`09ojVli`03o`000?nX^nOo000000Oo
00004_nXV<D4o`0000coWHc10ol00008oib9_`03o`000?n@Q<?oT8C300;o0000=oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000aooooo`03o`000?oooooooooo04;ooooo
0ol0000=ol^a`0;o00001?o://800ol0003o`ZRool:X_`0:ol:X_`Co00001_o0[<H00ol0003o^:C4
okRTa006okRTa0;o00001omB`_LEo`000005oa@00?naW/Co/Ik4ok6Na?l000003_nXV<D5o`0000?o
Yi:o00?o0000oif<`OnMS<402?nMS<42o`0000_oW8Vo00?o0000oi24`ol00000>Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03o`000?oooooooooo04Cooooo
0ol0000<ol^a`0?o000000?ob[;2o`000?o2Z;l03oo2Z;l4o`000003ol2/a_l0003o^:C4017o^:C4
3?l0000=ok6Na003o`000?nXV<GoZ9S500KoZ9S51_l00009ojNB_`03o`000?nMS<7oWHc100CoWHc1
0ol0000=oib9_`;o0000>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
000cooooo`;o0000Aoooool2o`0000gobk7000?o0000ol:X_oo2Z;l04oo2Z;l2o`0000Go^:C400?o
0000okRTa?nhY<@03_nhY<@00ol0003o/Ik4ok6Na00Cok6Na003o`000?nXV<GoZ9S500Go00003onW
T[l00ol0003oWHc1oif<`@02oif<`@;o00003OnLRKl3o`0003kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`16ooooo`?o00002_o;/L00
0ol0003o`jJmol>V_@05o`0000oo`ZRo00?o0000okZO__njWkh01?njWkh;o`0000Go^:C400?o0000
ok6Na?naW/@02?naW/@>o`0001CoYi:o00?o0000oif<`Ol000000_l0000<oib9_`?o0000@_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo
04Sooooo0_l00007ol^a`003o`000?o3Y[go`jJm00Ko`jJm1?l0000;ol:X_`03o`000?njWkko^Ynn
00oo^Ynn4?l0000;ok6H_P03o`000?nWT[ooYi:o01;oYi:o1?l0000<oib9_`?o0000AOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000gooooo`03o`000?oooooooooo04Wo
oooo0ol00004ol^a`003o`000?o3Y[go`jJm00[o`jJm1?l00006ol:X_`03o`000?njWkko^Ynn01Go
^Ynn00?o0000ok6H__naV;h04onaV;h00ol0003oYi:oojNB_`0<ojNB_`Ko00000onWT;d00ol0003o
W8Vooib9_`08oib9_`;o0000BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007o
oooo000hooooo`;o0000C?ooool3o`000003ol^a`?l0003o`jJm00oo`jJm1Ol000000oo2Z;oo0000
okZO_P0FokZO_P03o`000?naV;ko/IRn01Co/IRn00?o0000ojNB_onWT[l01_nWT[l5o`0000WoYi2m
00?o0000oib9_onLRKl01OnLRKl3o`0004cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`00>_ooool00ol0003oooooooooo`1<ooooo`03o`000?o3Y[go`jJm01Co`jJm0_l0
0003okZO_P?o00004?njWkh00ol0003o/IRnok6H_P0Eok6H_P03o`000?nWT[ooYi:o00Ko00003onW
T;d01?l0003oW8Vooib9_onLRKl3o`00053ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00>oooool00ol0003oooooooooo`1>ooooo`Co00004Oo3Y[d00ol0003o^YjlokZN
_004okZN_0_o00001OnjWkh00ol0003o/IRnok6H_P09ok6H_Poo00005OnWT;d4o`0005?ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool2o`0005;ooooo1?l0000=
ol>V_@03o`000?njW[co^Yjl00oo^Yjl4Ol0000<ok6F_003o`000?nWT;goYi2m01?oYi2m0ol0001G
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003kooooo00?o0000oooo
ooooool0Doooool3o`0000[o`jJm00?o0000okZN_?njW[`05?njW[`00ol0003o/IJlok6F_00Eok6F
_003o`000?nWT;goYi2m00koYi2m1Ol0001Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool003oooooo00?o0000ooooooooool0Doooool00ol0003oooooo`000003o`0000Go
`jJm00?o0000okZN_?njW[`05OnjW[`00ol0003o/IJlok6F_00Eok6F_003o`000?nWT;goYi2m00Wo
Yi2m1Ol0001Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0043ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03ooooo`Co000000?o`jJmo`000?njW[`0
5_njW[`00ol0003o/IJlok6F_00Fok6F_003o`000?nWT;goYi2m00CoYi2m1?l0001Vooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Booooo`03o`000?oo
oooooooo00Oooooo0_l00002okZN_0Co00004OnjW[`00ol0003o/IJlok6F_00Fok6F_003o`000?nW
T;go000000Co0000Joooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00@oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo3?l00005okZN_003o`000?naU[co
/IJl00[o/IJl3_l0001aooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0014oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool06ooooolBo`00083ooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2]ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`;o0000
COooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0018ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00Boooool2o`0004Sooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0/oooool01Ol0003ooooooooooooooooo0000007ooooo001@
ooooo`;o0000@oooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`00007ooooo001B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]Oooool00ol0003oooooo`000001
ooooo`00Doooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool00Ol0000005Cooooo0_l0000oooooo`03o`000?oooooooooo0;Kooooo0Ol00001ooooo`7o
0000001Fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0]oooool2o`000000Eooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;Kooooo0ol0000005Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2booooo`Co00000oooool005Wooooo0_l0000joooo
o`03o`000?oooooooooo0:kooooo1?l00007ooooo`00Foooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo0:[ooooo1?l0000;ooooo`00G?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Kooooo1?l0000?ooooo`00GOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo0:;ooooo1?l0000Cooooo`00G_ooool2o`0003Gooooo00?o0000ooooooooool0W_ooool4
o`0001Oooooo001Pooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0V_ooool4o`00
01_ooooo001Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool3o`0001oo
oooo001Rooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002;ooooo
001Sooooo`;o0000;oooool00ol0003oooooooooo`2@ooooo`Co00009_ooool006Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`2<ooooo`Co0000:_ooool006Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`28ooooo`Co0000;_ooool006Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`24ooooo`Co0000<_ooool006Sooooo0_l0000Zooooo`03o`00
0?oooooooooo083ooooo1?l0000fooooo`00J_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo07cooooo1?l0000jooooo`00Joooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0000nooooo`00K?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l00012ooooo`00KOooool2o`0002Gooooo00?o0000ooooooooool0L?ooool4o`0004Ko
oooo001_ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0K?ooool4o`0004[ooooo
001`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J?ooool4o`0004kooooo001a
ooooo`;o00008Oooool00ol0003oooooooooo`1Tooooo`Co0000D_ooool007?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000E_ooool007Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Looooo`Co0000F_ooool007Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Iooooo`?o0000G_ooool007Kooooo0_l0000Looooo`03o`000?oo
oooooooo05Gooooo1?l0001Qooooo`00N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo057ooooo1?l0001Uooooo`00NOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04gooooo1?l0001Yooooo`00N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo1?l0001]ooooo`00Noooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`00077ooooo
001mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0007Gooooo001n
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool4o`0007Wooooo001ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool4o`0007gooooo0020ooooo`;o
00004_ooool00ol0003oooooooooo`0eooooo`Co0000POooool008;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0aooooo`Co0000QOooool008?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0^ooooo`Co0000ROooool008Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Zooooo`Co0000SOooool008Gooooo0_l0000<ooooo`03o`000?oooooooooo
02Kooooo1?l0002Aooooo`00Qoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo1?l0002Eooooo`00R?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo
1?l0002Iooooo`00ROooool2o`0000Sooooo00?o0000ooooooooool06oooool3o`0009gooooo002;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool4o`000:3ooooo002<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool4o`000:Cooooo002=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool4o`000:Sooooo002>ooooo`;o0000
0oooool00ol0003oooooooooo`0;ooooo`Co0000[?ooool0093ooooo00Co0000oooooooooooo0000
2Oooool4o`000;3ooooo002Aooooo`03o`000?oooooo000000Gooooo1?l0002dooooo`00T_ooool2
o`000003ooooool0003o000000;o0000^?ooool009?ooooo0_l0002looooo`00oooooomBooooo`00
oooooomBooooo`00oooooomBooooo`00\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .64752 m .51694 .65827 L .43899 .65168 L p .709 .682 .822 r
F P
0 g
s
.51694 .65827 m .51725 .64752 L .59255 .64333 L p .687 .663 .821 r
F P
0 g
s
.59255 .64333 m .59527 .65394 L .51694 .65827 L p .687 .663 .821 r
F P
0 g
s
.59527 .65394 m .59255 .64333 L .66454 .6287 L p .664 .649 .825 r
F P
0 g
s
.66454 .6287 m .67023 .63881 L .59527 .65394 L p .664 .649 .825 r
F P
0 g
s
.43899 .65168 m .44234 .64114 L .51725 .64752 L p .709 .682 .822 r
F P
0 g
s
.51757 .63706 m .51725 .64752 L .44234 .64114 L p .706 .686 .828 r
F P
0 g
s
.51725 .64752 m .51757 .63706 L .58981 .63301 L p .686 .669 .828 r
F P
0 g
s
.58981 .63301 m .59255 .64333 L .51725 .64752 L p .686 .669 .828 r
F P
0 g
s
.44234 .64114 m .43899 .65168 L .36521 .63435 L p .728 .703 .826 r
F P
0 g
s
.59255 .64333 m .58981 .63301 L .65884 .61888 L p .664 .656 .832 r
F P
0 g
s
.65884 .61888 m .66454 .6287 L .59255 .64333 L p .664 .656 .832 r
F P
0 g
s
.44234 .64114 m .4457 .6309 L .51757 .63706 L p .706 .686 .828 r
F P
0 g
s
.51789 .62738 m .51757 .63706 L .4457 .6309 L p .7 .699 .846 r
F P
0 g
s
.51757 .63706 m .51789 .62738 L .58708 .62348 L p .683 .685 .846 r
F P
0 g
s
.58708 .62348 m .58981 .63301 L .51757 .63706 L p .683 .685 .846 r
F P
0 g
s
.36521 .63435 m .37149 .62438 L .44234 .64114 L p .728 .703 .826 r
F P
0 g
s
.4457 .6309 m .44234 .64114 L .37149 .62438 L p .725 .707 .833 r
F P
0 g
s
.58981 .63301 m .58708 .62348 L .65314 .60987 L p .665 .674 .849 r
F P
0 g
s
.65314 .60987 m .65884 .61888 L .58981 .63301 L p .665 .674 .849 r
F P
0 g
s
.4457 .6309 m .44906 .62145 L .51789 .62738 L p .7 .699 .846 r
F P
0 g
s
.51821 .6189 m .51789 .62738 L .44906 .62145 L p .686 .72 .875 r
F P
0 g
s
.51789 .62738 m .51821 .6189 L .58435 .61515 L p .675 .711 .875 r
F P
0 g
s
.58435 .61515 m .58708 .62348 L .51789 .62738 L p .675 .711 .875 r
F P
0 g
s
.37149 .62438 m .37779 .61472 L .4457 .6309 L p .725 .707 .833 r
F P
0 g
s
.44906 .62145 m .4457 .6309 L .37779 .61472 L p .715 .716 .85 r
F P
0 g
s
.58708 .62348 m .58435 .61515 L .64745 .60208 L p .664 .704 .877 r
F P
0 g
s
.64745 .60208 m .65314 .60987 L .58708 .62348 L p .664 .704 .877 r
F P
0 g
s
.67023 .63881 m .66454 .6287 L .72952 .60406 L p .639 .638 .833 r
F P
0 g
s
.72952 .60406 m .73799 .61332 L .67023 .63881 L p .639 .638 .833 r
F P
0 g
s
.37779 .61472 m .38409 .60587 L .44906 .62145 L p .715 .716 .85 r
F P
0 g
s
.45242 .6132 m .44906 .62145 L .38409 .60587 L p .695 .731 .878 r
F P
0 g
s
.44906 .62145 m .45242 .6132 L .51821 .6189 L p .686 .72 .875 r
F P
0 g
s
.51852 .61189 m .51821 .6189 L .45242 .6132 L p .658 .749 .917 r
F P
0 g
s
.51821 .6189 m .51852 .61189 L .58162 .6083 L p .658 .748 .917 r
F P
0 g
s
.58162 .6083 m .58435 .61515 L .51821 .6189 L p .658 .748 .917 r
F P
0 g
s
.66454 .6287 m .65884 .61888 L .72104 .59513 L p .641 .646 .839 r
F P
0 g
s
.72104 .59513 m .72952 .60406 L .66454 .6287 L p .641 .646 .839 r
F P
0 g
s
.37149 .62438 m .36521 .63435 L .29943 .6068 L p .746 .727 .835 r
F P
0 g
s
.58435 .61515 m .58162 .6083 L .64178 .59578 L p .657 .748 .917 r
F P
0 g
s
.64178 .59578 m .64745 .60208 L .58435 .61515 L p .657 .748 .917 r
F P
0 g
s
.38409 .60587 m .39037 .59823 L .45242 .6132 L p .695 .731 .878 r
F P
0 g
s
.45577 .60643 m .45242 .6132 L .39037 .59823 L p .659 .749 .917 r
F P
0 g
s
.45242 .6132 m .45577 .60643 L .51852 .61189 L p .658 .749 .917 r
F P
0 g
s
.65884 .61888 m .65314 .60987 L .71257 .58702 L p .645 .666 .855 r
F P
0 g
s
.71257 .58702 m .72104 .59513 L .65884 .61888 L p .645 .666 .855 r
F P
0 g
s
.29943 .6068 m .30845 .59776 L .37149 .62438 L p .746 .727 .835 r
F P
0 g
s
.37779 .61472 m .37149 .62438 L .30845 .59776 L p .741 .73 .841 r
F P
0 g
s
.51884 .60645 m .51852 .61189 L .45577 .60643 L p .606 .78 .964 r
F P
0 g
s
.51852 .61189 m .51884 .60645 L .5789 .60302 L p .62 .792 .964 r
F P
0 g
s
.5789 .60302 m .58162 .6083 L .51852 .61189 L p .62 .792 .964 r
F P
0 g
s
.58162 .6083 m .5789 .60302 L .63612 .59107 L p .638 .802 .961 r
F P
0 g
s
.63612 .59107 m .64178 .59578 L .58162 .6083 L p .638 .802 .961 r
F P
0 g
s
.30845 .59776 m .31747 .58906 L .37779 .61472 L p .741 .73 .841 r
F P
0 g
s
.38409 .60587 m .37779 .61472 L .31747 .58906 L p .727 .735 .857 r
F P
0 g
s
.65314 .60987 m .64745 .60208 L .70413 .58015 L p .651 .7 .882 r
F P
0 g
s
.70413 .58015 m .71257 .58702 L .65314 .60987 L p .651 .7 .882 r
F P
0 g
s
.39037 .59823 m .39663 .5921 L .45577 .60643 L p .659 .749 .917 r
F P
0 g
s
.45911 .60123 m .45577 .60643 L .39663 .5921 L p .595 .765 .961 r
F P
0 g
s
.45577 .60643 m .45911 .60123 L .51884 .60645 L p .606 .78 .964 r
F P
0 g
s
.51916 .60249 m .51884 .60645 L .45911 .60123 L p .515 .796 .997 r
F P
0 g
s
.51884 .60645 m .51916 .60249 L .57617 .59923 L p .549 .826 .997 r
F P
0 g
s
.57617 .59923 m .5789 .60302 L .51884 .60645 L p .549 .826 .997 r
F P
0 g
s
.31747 .58906 m .32648 .58118 L .38409 .60587 L p .727 .735 .857 r
F P
0 g
s
.39037 .59823 m .38409 .60587 L .32648 .58118 L p .702 .743 .883 r
F P
0 g
s
.64745 .60208 m .64178 .59578 L .69572 .5748 L p .657 .748 .917 r
F P
0 g
s
.69572 .5748 m .70413 .58015 L .64745 .60208 L p .657 .748 .917 r
F P
0 g
s
.5789 .60302 m .57617 .59923 L .63045 .58786 L p .593 .85 .993 r
F P
0 g
s
.63045 .58786 m .63612 .59107 L .5789 .60302 L p .593 .85 .993 r
F P
0 g
s
.39663 .5921 m .40288 .58756 L .45911 .60123 L p .595 .765 .961 r
F P
0 g
s
.46246 .59752 m .45911 .60123 L .40288 .58756 L p .495 .765 .991 r
F P
0 g
s
.45911 .60123 m .46246 .59752 L .51916 .60249 L p .515 .796 .997 r
F P
0 g
s
.32648 .58118 m .33545 .57455 L .39037 .59823 L p .702 .743 .883 r
F P
0 g
s
.39663 .5921 m .39037 .59823 L .33545 .57455 L p .659 .75 .917 r
F P
0 g
s
.64178 .59578 m .63612 .59107 L .68734 .57106 L p .656 .807 .956 r
F P
0 g
s
.68734 .57106 m .69572 .5748 L .64178 .59578 L p .656 .807 .956 r
F P
0 g
s
.51948 .59971 m .51916 .60249 L .46246 .59752 L p .393 .78 .99 r
F P
0 g
s
.51916 .60249 m .51948 .59971 L .57344 .59661 L p .447 .826 .99 r
F P
0 g
s
.57344 .59661 m .57617 .59923 L .51916 .60249 L p .447 .826 .99 r
F P
0 g
s
.73799 .61332 m .72952 .60406 L .7837 .57028 L p .613 .631 .845 r
F P
0 g
s
.7837 .57028 m .79464 .57831 L .73799 .61332 L p .613 .631 .845 r
F P
0 g
s
.57617 .59923 m .57344 .59661 L .62477 .58584 L p .524 .87 .99 r
F P
0 g
s
.62477 .58584 m .63045 .58786 L .57617 .59923 L p .524 .87 .99 r
F P
0 g
s
.33545 .57455 m .34439 .56945 L .39663 .5921 L p .659 .75 .917 r
F P
0 g
s
.40288 .58756 m .39663 .5921 L .34439 .56945 L p .59 .751 .954 r
F P
0 g
s
.72952 .60406 m .72104 .59513 L .77275 .56259 L p .617 .64 .851 r
F P
0 g
s
.77275 .56259 m .7837 .57028 L .72952 .60406 L p .617 .64 .851 r
F P
0 g
s
.40288 .58756 m .40913 .58452 L .46246 .59752 L p .495 .765 .991 r
F P
0 g
s
.46582 .595 m .46246 .59752 L .40913 .58452 L p .37 .738 .989 r
F P
0 g
s
.46246 .59752 m .46582 .595 L .51948 .59971 L p .393 .78 .99 r
F P
0 g
s
.63612 .59107 m .63045 .58786 L .67896 .56884 L p .64 .864 .983 r
F P
0 g
s
.67896 .56884 m .68734 .57106 L .63612 .59107 L p .64 .864 .983 r
F P
0 g
s
.72104 .59513 m .71257 .58702 L .76184 .55576 L p .625 .662 .865 r
F P
0 g
s
.76184 .55576 m .77275 .56259 L .72104 .59513 L p .625 .662 .865 r
F P
0 g
s
.30845 .59776 m .29943 .6068 L .24558 .56996 L p .759 .754 .848 r
F P
0 g
s
.5198 .59763 m .51948 .59971 L .46582 .595 L p .293 .746 .956 r
F P
0 g
s
.51948 .59971 m .5198 .59763 L .57068 .59471 L p .359 .803 .955 r
F P
0 g
s
.57068 .59471 m .57344 .59661 L .51948 .59971 L p .359 .803 .955 r
F P
0 g
s
.24558 .56996 m .25699 .56223 L .30845 .59776 L p .759 .754 .848 r
F P
0 g
s
.31747 .58906 m .30845 .59776 L .25699 .56223 L p .753 .755 .854 r
F P
0 g
s
.34439 .56945 m .3533 .56597 L .40288 .58756 L p .59 .751 .954 r
F P
0 g
s
.40913 .58452 m .40288 .58756 L .3533 .56597 L p .49 .736 .981 r
F P
0 g
s
.71257 .58702 m .70413 .58015 L .75099 .5502 L p .639 .698 .888 r
F P
0 g
s
.75099 .5502 m .76184 .55576 L .71257 .58702 L p .639 .698 .888 r
F P
0 g
s
.57344 .59661 m .57068 .59471 L .61905 .58455 L p .46 .864 .964 r
F P
0 g
s
.61905 .58455 m .62477 .58584 L .57344 .59661 L p .46 .864 .964 r
F P
0 g
s
.25699 .56223 m .26839 .55486 L .31747 .58906 L p .753 .755 .854 r
F P
0 g
s
.32648 .58118 m .31747 .58906 L .26839 .55486 L p .737 .756 .868 r
F P
0 g
s
.40913 .58452 m .4154 .58268 L .46582 .595 L p .37 .738 .989 r
F P
0 g
s
.4692 .59319 m .46582 .595 L .4154 .58268 L p .27 .701 .966 r
F P
0 g
s
.46582 .595 m .4692 .59319 L .5198 .59763 L p .293 .746 .956 r
F P
0 g
s
.63045 .58786 m .62477 .58584 L .67058 .56784 L p .608 .901 .986 r
F P
0 g
s
.67058 .56784 m .67896 .56884 L .63045 .58786 L p .608 .901 .986 r
F P
0 g
s
.70413 .58015 m .69572 .5748 L .74019 .54619 L p .656 .748 .917 r
F P
0 g
s
.74019 .54619 m .75099 .5502 L .70413 .58015 L p .656 .748 .917 r
F P
0 g
s
.26839 .55486 m .27975 .54834 L .32648 .58118 L p .737 .756 .868 r
F P
0 g
s
.33545 .57455 m .32648 .58118 L .27975 .54834 L p .707 .755 .89 r
F P
0 g
s
.3533 .56597 m .36219 .564 L .40913 .58452 L p .49 .736 .981 r
F P
0 g
s
.4154 .58268 m .40913 .58452 L .36219 .564 L p .376 .702 .984 r
F P
0 g
s
.52012 .59567 m .5198 .59763 L .4692 .59319 L p .272 .737 .947 r
F P
0 g
s
.5198 .59763 m .52012 .59567 L .5679 .59293 L p .341 .796 .946 r
F P
0 g
s
.5679 .59293 m .57068 .59471 L .5198 .59763 L p .341 .796 .946 r
F P
0 g
s
.69572 .5748 m .68734 .57106 L .72945 .54382 L p .673 .808 .948 r
F P
0 g
s
.72945 .54382 m .74019 .54619 L .69572 .5748 L p .673 .808 .948 r
F P
0 g
s
.27975 .54834 m .29105 .54309 L .33545 .57455 L p .707 .755 .89 r
F P
0 g
s
.34439 .56945 m .33545 .57455 L .29105 .54309 L p .659 .75 .918 r
F P
0 g
s
.57068 .59471 m .5679 .59293 L .61327 .58338 L p .447 .861 .956 r
F P
0 g
s
.61327 .58338 m .61905 .58455 L .57068 .59471 L p .447 .861 .956 r
F P
0 g
s
.62477 .58584 m .61905 .58455 L .66214 .56758 L p .574 .913 .972 r
F P
0 g
s
.66214 .56758 m .67058 .56784 L .62477 .58584 L p .574 .913 .972 r
F P
0 g
s
.4154 .58268 m .42171 .58156 L .4692 .59319 L p .27 .701 .966 r
F P
0 g
s
.47263 .5915 m .4692 .59319 L .42171 .58156 L p .25 .693 .959 r
F P
0 g
s
.4692 .59319 m .47263 .5915 L .52012 .59567 L p .272 .737 .947 r
F P
0 g
s
.29105 .54309 m .30228 .53941 L .34439 .56945 L p .659 .75 .918 r
F P
0 g
s
.3533 .56597 m .34439 .56945 L .30228 .53941 L p .589 .737 .946 r
F P
0 g
s
.36219 .564 m .3711 .56326 L .4154 .58268 L p .376 .702 .984 r
F P
0 g
s
.42171 .58156 m .4154 .58268 L .3711 .56326 L p .289 .668 .972 r
F P
0 g
s
.68734 .57106 m .67896 .56884 L .71874 .543 L p .683 .867 .969 r
F P
0 g
s
.71874 .543 m .72945 .54382 L .68734 .57106 L p .683 .867 .969 r
F P
0 g
s
.52045 .59316 m .52012 .59567 L .47263 .5915 L p .347 .767 .977 r
F P
0 g
s
.52012 .59567 m .52045 .59316 L .56507 .59059 L p .407 .818 .977 r
F P
0 g
s
.56507 .59059 m .5679 .59293 L .52012 .59567 L p .407 .818 .977 r
F P
0 g
s
.5679 .59293 m .56507 .59059 L .60742 .58166 L p .495 .869 .98 r
F P
0 g
s
.60742 .58166 m .61327 .58338 L .5679 .59293 L p .495 .869 .98 r
F P
0 g
s
.30228 .53941 m .31345 .53737 L .3533 .56597 L p .589 .737 .946 r
F P
0 g
s
.36219 .564 m .3533 .56597 L .31345 .53737 L p .498 .71 .965 r
F P
0 g
s
.61905 .58455 m .61327 .58338 L .65363 .56745 L p .567 .913 .967 r
F P
0 g
s
.65363 .56745 m .66214 .56758 L .61905 .58455 L p .567 .913 .967 r
F P
0 g
s
.42171 .58156 m .42808 .58058 L .47263 .5915 L p .25 .693 .959 r
F P
0 g
s
.4761 .58925 m .47263 .5915 L .42808 .58058 L p .324 .723 .981 r
F P
0 g
s
.47263 .5915 m .4761 .58925 L .52045 .59316 L p .347 .767 .977 r
F P
0 g
s
.67896 .56884 m .67058 .56784 L .70803 .54341 L p .681 .912 .974 r
F P
0 g
s
.70803 .54341 m .71874 .543 L .67896 .56884 L p .681 .912 .974 r
F P
0 g
s
.3711 .56326 m .38005 .56326 L .42171 .58156 L p .289 .668 .972 r
F P
0 g
s
.42808 .58058 m .42171 .58156 L .38005 .56326 L p .272 .66 .968 r
F P
0 g
s
.79464 .57831 m .7837 .57028 L .82329 .5287 L p .585 .629 .861 r
F P
0 g
s
.82329 .5287 m .83625 .53514 L .79464 .57831 L p .585 .629 .861 r
F P
0 g
s
.7837 .57028 m .77275 .56259 L .81037 .52264 L p .591 .638 .866 r
F P
0 g
s
.81037 .52264 m .82329 .5287 L .7837 .57028 L p .591 .638 .866 r
F P
0 g
s
.31345 .53737 m .32459 .53688 L .36219 .564 L p .498 .71 .965 r
F P
0 g
s
.3711 .56326 m .36219 .564 L .32459 .53688 L p .403 .673 .97 r
F P
0 g
s
.52079 .58942 m .52045 .59316 L .4761 .58925 L p .477 .795 .999 r
F P
0 g
s
.52045 .59316 m .52079 .58942 L .5622 .58703 L p .518 .83 1 r
F P
0 g
s
.5622 .58703 m .56507 .59059 L .52045 .59316 L p .518 .83 1 r
F P
0 g
s
.77275 .56259 m .76184 .55576 L .79751 .51745 L p .605 .661 .878 r
F P
0 g
s
.79751 .51745 m .81037 .52264 L .77275 .56259 L p .605 .661 .878 r
F P
0 g
s
.56507 .59059 m .5622 .58703 L .60147 .57873 L p .573 .86 .996 r
F P
0 g
s
.60147 .57873 m .60742 .58166 L .56507 .59059 L p .573 .86 .996 r
F P
0 g
s
.67058 .56784 m .66214 .56758 L .69727 .54458 L p .674 .934 .968 r
F P
0 g
s
.69727 .54458 m .70803 .54341 L .67058 .56784 L p .674 .934 .968 r
F P
0 g
s
.61327 .58338 m .60742 .58166 L .64501 .56679 L p .593 .908 .981 r
F P
0 g
s
.64501 .56679 m .65363 .56745 L .61327 .58338 L p .593 .908 .981 r
F P
0 g
s
.76184 .55576 m .75099 .5502 L .78475 .51356 L p .627 .699 .896 r
F P
0 g
s
.78475 .51356 m .79751 .51745 L .76184 .55576 L p .627 .699 .896 r
F P
0 g
s
.42808 .58058 m .43453 .57904 L .4761 .58925 L p .324 .723 .981 r
F P
0 g
s
.47962 .58579 m .4761 .58925 L .43453 .57904 L p .456 .76 .995 r
F P
0 g
s
.4761 .58925 m .47962 .58579 L .52079 .58942 L p .477 .795 .999 r
F P
0 g
s
.38005 .56326 m .38909 .56341 L .42808 .58058 L p .272 .66 .968 r
F P
0 g
s
.43453 .57904 m .42808 .58058 L .38909 .56341 L p .336 .687 .98 r
F P
0 g
s
.25699 .56223 m .24558 .56996 L .20758 .52532 L p .769 .784 .865 r
F P
0 g
s
.75099 .5502 m .74019 .54619 L .77209 .51125 L p .656 .748 .918 r
F P
0 g
s
.77209 .51125 m .78475 .51356 L .75099 .5502 L p .656 .748 .918 r
F P
0 g
s
.32459 .53688 m .33572 .53763 L .3711 .56326 L p .403 .673 .97 r
F P
0 g
s
.38005 .56326 m .3711 .56326 L .33572 .53763 L p .335 .643 .966 r
F P
0 g
s
.20758 .52532 m .22088 .51927 L .25699 .56223 L p .769 .784 .865 r
F P
0 g
s
.26839 .55486 m .25699 .56223 L .22088 .51927 L p .761 .782 .87 r
F P
0 g
s
.22088 .51927 m .23413 .51358 L .26839 .55486 L p .761 .782 .87 r
F P
0 g
s
.27975 .54834 m .26839 .55486 L .23413 .51358 L p .742 .778 .882 r
F P
0 g
s
.52113 .58389 m .52079 .58942 L .47962 .58579 L p .592 .785 .972 r
F P
0 g
s
.52079 .58942 m .52113 .58389 L .55927 .58168 L p .61 .8 .972 r
F P
0 g
s
.55927 .58168 m .5622 .58703 L .52079 .58942 L p .61 .8 .972 r
F P
0 g
s
.74019 .54619 m .72945 .54382 L .75951 .51062 L p .687 .804 .938 r
F P
0 g
s
.75951 .51062 m .77209 .51125 L .74019 .54619 L p .687 .804 .938 r
F P
0 g
s
.66214 .56758 m .65363 .56745 L .68644 .5459 L p .672 .937 .966 r
F P
0 g
s
.68644 .5459 m .69727 .54458 L .66214 .56758 L p .672 .937 .966 r
F P
0 g
s
.23413 .51358 m .24731 .50878 L .27975 .54834 L p .742 .778 .882 r
F P
0 g
s
.29105 .54309 m .27975 .54834 L .24731 .50878 L p .709 .768 .898 r
F P
0 g
s
.5622 .58703 m .55927 .58168 L .59543 .57401 L p .631 .811 .969 r
F P
0 g
s
.59543 .57401 m .60147 .57873 L .5622 .58703 L p .631 .811 .969 r
F P
0 g
s
.60742 .58166 m .60147 .57873 L .63628 .56492 L p .631 .879 .987 r
F P
0 g
s
.63628 .56492 m .64501 .56679 L .60742 .58166 L p .631 .879 .987 r
F P
0 g
s
.43453 .57904 m .44109 .5763 L .47962 .58579 L p .456 .76 .995 r
F P
0 g
s
.48321 .58053 m .47962 .58579 L .44109 .5763 L p .58 .768 .968 r
F P
0 g
s
.47962 .58579 m .48321 .58053 L .52113 .58389 L p .592 .785 .972 r
F P
0 g
s
.24731 .50878 m .26039 .50528 L .29105 .54309 L p .709 .768 .898 r
F P
0 g
s
.30228 .53941 m .29105 .54309 L .26039 .50528 L p .659 .751 .918 r
F P
0 g
s
.38909 .56341 m .39822 .56301 L .43453 .57904 L p .336 .687 .98 r
F P
0 g
s
.44109 .5763 m .43453 .57904 L .39822 .56301 L p .454 .727 .985 r
F P
0 g
s
.33572 .53763 m .34689 .53915 L .38005 .56326 L p .335 .643 .966 r
F P
0 g
s
.38909 .56341 m .38005 .56326 L .34689 .53915 L p .322 .637 .964 r
F P
0 g
s
.72945 .54382 m .71874 .543 L .74699 .51155 L p .715 .859 .95 r
F P
0 g
s
.74699 .51155 m .75951 .51062 L .72945 .54382 L p .715 .859 .95 r
F P
0 g
s
.26039 .50528 m .27336 .50337 L .30228 .53941 L p .659 .751 .918 r
F P
0 g
s
.31345 .53737 m .30228 .53941 L .27336 .50337 L p .593 .724 .935 r
F P
0 g
s
.52147 .57614 m .52113 .58389 L .48321 .58053 L p .661 .748 .914 r
F P
0 g
s
.52113 .58389 m .52147 .57614 L .5563 .57412 L p .659 .746 .914 r
F P
0 g
s
.5563 .57412 m .55927 .58168 L .52113 .58389 L p .659 .746 .914 r
F P
0 g
s
.65363 .56745 m .64501 .56679 L .6755 .54669 L p .679 .923 .972 r
F P
0 g
s
.6755 .54669 m .68644 .5459 L .65363 .56745 L p .679 .923 .972 r
F P
0 g
s
.55927 .58168 m .5563 .57412 L .58929 .56709 L p .656 .744 .915 r
F P
0 g
s
.58929 .56709 m .59543 .57401 L .55927 .58168 L p .656 .744 .915 r
F P
0 g
s
.60147 .57873 m .59543 .57401 L .62741 .56126 L p .653 .818 .963 r
F P
0 g
s
.62741 .56126 m .63628 .56492 L .60147 .57873 L p .653 .818 .963 r
F P
0 g
s
.71874 .543 m .70803 .54341 L .7345 .51374 L p .735 .901 .953 r
F P
0 g
s
.7345 .51374 m .74699 .51155 L .71874 .543 L p .735 .901 .953 r
F P
0 g
s
.44109 .5763 m .44775 .57177 L .48321 .58053 L p .58 .768 .968 r
F P
0 g
s
.48686 .57306 m .48321 .58053 L .44775 .57177 L p .663 .75 .915 r
F P
0 g
s
.48321 .58053 m .48686 .57306 L .52147 .57614 L p .661 .748 .914 r
F P
0 g
s
.27336 .50337 m .28624 .50313 L .31345 .53737 L p .593 .724 .935 r
F P
0 g
s
.32459 .53688 m .31345 .53737 L .28624 .50313 L p .516 .689 .946 r
F P
0 g
s
.39822 .56301 m .40749 .56141 L .44109 .5763 L p .454 .727 .985 r
F P
0 g
s
.44775 .57177 m .44109 .5763 L .40749 .56141 L p .574 .751 .961 r
F P
0 g
s
.34689 .53915 m .35814 .54081 L .38909 .56341 L p .322 .637 .964 r
F P
0 g
s
.39822 .56301 m .38909 .56341 L .35814 .54081 L p .372 .66 .969 r
F P
0 g
s
.52182 .56599 m .52147 .57614 L .48686 .57306 L p .695 .708 .858 r
F P
0 g
s
.52147 .57614 m .52182 .56599 L .55329 .56415 L p .68 .695 .858 r
F P
0 g
s
.55329 .56415 m .5563 .57412 L .52147 .57614 L p .68 .695 .858 r
F P
0 g
s
.64501 .56679 m .63628 .56492 L .66442 .54628 L p .682 .884 .973 r
F P
0 g
s
.66442 .54628 m .6755 .54669 L .64501 .56679 L p .682 .884 .973 r
F P
0 g
s
.28624 .50313 m .29905 .50447 L .32459 .53688 L p .516 .689 .946 r
F P
0 g
s
.33572 .53763 m .32459 .53688 L .29905 .50447 L p .442 .651 .948 r
F P
0 g
s
.70803 .54341 m .69727 .54458 L .72199 .5167 L p .744 .925 .951 r
F P
0 g
s
.72199 .5167 m .7345 .51374 L .70803 .54341 L p .744 .925 .951 r
F P
0 g
s
.5563 .57412 m .55329 .56415 L .58305 .55776 L p .662 .684 .861 r
F P
0 g
s
.58305 .55776 m .58929 .56709 L .5563 .57412 L p .662 .684 .861 r
F P
0 g
s
.59543 .57401 m .58929 .56709 L .61841 .55541 L p .654 .744 .916 r
F P
0 g
s
.61841 .55541 m .62741 .56126 L .59543 .57401 L p .654 .744 .916 r
F P
0 g
s
.44775 .57177 m .45451 .56503 L .48686 .57306 L p .663 .75 .915 r
F P
0 g
s
.49056 .56319 m .48686 .57306 L .45451 .56503 L p .709 .724 .862 r
F P
0 g
s
.48686 .57306 m .49056 .56319 L .52182 .56599 L p .695 .708 .858 r
F P
0 g
s
.40749 .56141 m .41689 .55803 L .44775 .57177 L p .574 .751 .961 r
F P
0 g
s
.45451 .56503 m .44775 .57177 L .41689 .55803 L p .664 .752 .916 r
F P
0 g
s
.35814 .54081 m .3695 .54195 L .39822 .56301 L p .372 .66 .969 r
F P
0 g
s
.40749 .56141 m .39822 .56301 L .3695 .54195 L p .467 .699 .969 r
F P
0 g
s
.52218 .55349 m .52182 .56599 L .49056 .56319 L p .712 .677 .815 r
F P
0 g
s
.52182 .56599 m .52218 .55349 L .55023 .55184 L p .687 .657 .814 r
F P
0 g
s
.55023 .55184 m .55329 .56415 L .52182 .56599 L p .687 .657 .814 r
F P
0 g
s
.29905 .50447 m .31183 .50707 L .33572 .53763 L p .442 .651 .948 r
F P
0 g
s
.34689 .53915 m .33572 .53763 L .31183 .50707 L p .392 .624 .945 r
F P
0 g
s
.55329 .56415 m .55023 .55184 L .57675 .54611 L p .661 .64 .818 r
F P
0 g
s
.57675 .54611 m .58305 .55776 L .55329 .56415 L p .661 .64 .818 r
F P
0 g
s
.69727 .54458 m .68644 .5459 L .70941 .51982 L p .746 .929 .95 r
F P
0 g
s
.70941 .51982 m .72199 .5167 L .69727 .54458 L p .746 .929 .95 r
F P
0 g
s
.63628 .56492 m .62741 .56126 L .65319 .54409 L p .673 .819 .953 r
F P
0 g
s
.65319 .54409 m .66442 .54628 L .63628 .56492 L p .673 .819 .953 r
F P
0 g
s
.45451 .56503 m .46138 .55589 L .49056 .56319 L p .709 .724 .862 r
F P
0 g
s
.49431 .55098 m .49056 .56319 L .46138 .55589 L p .735 .702 .82 r
F P
0 g
s
.49056 .56319 m .49431 .55098 L .52218 .55349 L p .712 .677 .815 r
F P
0 g
s
.58929 .56709 m .58305 .55776 L .6093 .54717 L p .644 .677 .867 r
F P
0 g
s
.6093 .54717 m .61841 .55541 L .58929 .56709 L p .644 .677 .867 r
F P
0 g
s
.41689 .55803 m .42643 .55245 L .45451 .56503 L p .664 .752 .916 r
F P
0 g
s
.46138 .55589 m .45451 .56503 L .42643 .55245 L p .721 .742 .869 r
F P
0 g
s
.52254 .53896 m .52218 .55349 L .49431 .55098 L p .72 .656 .785 r
F P
0 g
s
.52218 .55349 m .52254 .53896 L .54714 .5375 L p .69 .631 .784 r
F P
0 g
s
.54714 .5375 m .55023 .55184 L .52218 .55349 L p .69 .631 .784 r
F P
0 g
s
.3695 .54195 m .38099 .54189 L .40749 .56141 L p .467 .699 .969 r
F P
0 g
s
.41689 .55803 m .40749 .56141 L .38099 .54189 L p .574 .735 .951 r
F P
0 g
s
.55023 .55184 m .54714 .5375 L .57038 .53243 L p .658 .609 .789 r
F P
0 g
s
.57038 .53243 m .57675 .54611 L .55023 .55184 L p .658 .609 .789 r
F P
0 g
s
.46138 .55589 m .46832 .54443 L .49431 .55098 L p .735 .702 .82 r
F P
0 g
s
.4981 .53674 m .49431 .55098 L .46832 .54443 L p .748 .685 .79 r
F P
0 g
s
.49431 .55098 m .4981 .53674 L .52254 .53896 L p .72 .656 .785 r
F P
0 g
s
.31183 .50707 m .32462 .51044 L .34689 .53915 L p .392 .624 .945 r
F P
0 g
s
.35814 .54081 m .34689 .53915 L .32462 .51044 L p .383 .619 .945 r
F P
0 g
s
.58305 .55776 m .57675 .54611 L .60008 .5366 L p .632 .627 .827 r
F P
0 g
s
.60008 .5366 m .6093 .54717 L .58305 .55776 L p .632 .627 .827 r
F P
0 g
s
.68644 .5459 m .6755 .54669 L .69672 .52242 L p .739 .913 .952 r
F P
0 g
s
.69672 .52242 m .70941 .51982 L .68644 .5459 L p .739 .913 .952 r
F P
0 g
s
.62741 .56126 m .61841 .55541 L .64182 .5397 L p .651 .743 .917 r
F P
0 g
s
.64182 .5397 m .65319 .54409 L .62741 .56126 L p .651 .743 .917 r
F P
0 g
s
.83625 .53514 m .82329 .5287 L .84476 .48133 L p .557 .633 .882 r
F P
0 g
s
.84476 .48133 m .85906 .48583 L .83625 .53514 L p .557 .633 .882 r
F P
0 g
s
.82329 .5287 m .81037 .52264 L .83054 .47721 L p .565 .642 .886 r
F P
0 g
s
.83054 .47721 m .84476 .48133 L .82329 .5287 L p .565 .642 .886 r
F P
0 g
s
.5229 .52295 m .52254 .53896 L .4981 .53674 L p .724 .643 .767 r
F P
0 g
s
.52254 .53896 m .5229 .52295 L .54403 .52168 L p .691 .615 .766 r
F P
0 g
s
.54403 .52168 m .54714 .5375 L .52254 .53896 L p .691 .615 .766 r
F P
0 g
s
.81037 .52264 m .79751 .51745 L .81642 .47399 L p .585 .666 .894 r
F P
0 g
s
.81642 .47399 m .83054 .47721 L .81037 .52264 L p .585 .666 .894 r
F P
0 g
s
.42643 .55245 m .43608 .54449 L .46138 .55589 L p .721 .742 .869 r
F P
0 g
s
.46832 .54443 m .46138 .55589 L .43608 .54449 L p .755 .73 .829 r
F P
0 g
s
.79751 .51745 m .78475 .51356 L .80244 .47209 L p .616 .702 .906 r
F P
0 g
s
.80244 .47209 m .81642 .47399 L .79751 .51745 L p .616 .702 .906 r
F P
0 g
s
.54714 .5375 m .54403 .52168 L .56398 .51728 L p .655 .591 .771 r
F P
0 g
s
.56398 .51728 m .57038 .53243 L .54714 .5375 L p .655 .591 .771 r
F P
0 g
s
.78475 .51356 m .77209 .51125 L .7886 .4718 L p .655 .748 .918 r
F P
0 g
s
.7886 .4718 m .80244 .47209 L .78475 .51356 L p .655 .748 .918 r
F P
0 g
s
.46832 .54443 m .47533 .53095 L .4981 .53674 L p .748 .685 .79 r
F P
0 g
s
.50191 .52102 m .4981 .53674 L .47533 .53095 L p .756 .675 .772 r
F P
0 g
s
.4981 .53674 m .50191 .52102 L .5229 .52295 L p .724 .643 .767 r
F P
0 g
s
.38099 .54189 m .39264 .54005 L .41689 .55803 L p .574 .735 .951 r
F P
0 g
s
.42643 .55245 m .41689 .55803 L .39264 .54005 L p .665 .755 .917 r
F P
0 g
s
.57675 .54611 m .57038 .53243 L .5908 .52404 L p .622 .592 .798 r
F P
0 g
s
.5908 .52404 m .60008 .5366 L .57675 .54611 L p .622 .592 .798 r
F P
0 g
s
.52327 .50615 m .5229 .52295 L .50191 .52102 L p .726 .637 .759 r
F P
0 g
s
.5229 .52295 m .52327 .50615 L .54091 .50508 L p .691 .608 .758 r
F P
0 g
s
.54091 .50508 m .54403 .52168 L .5229 .52295 L p .691 .608 .758 r
F P
0 g
s
.77209 .51125 m .75951 .51062 L .77489 .4732 L p .697 .797 .927 r
F P
0 g
s
.77489 .4732 m .7886 .4718 L .77209 .51125 L p .697 .797 .927 r
F P
0 g
s
.54403 .52168 m .54091 .50508 L .55754 .50138 L p .654 .583 .763 r
F P
0 g
s
.55754 .50138 m .56398 .51728 L .54403 .52168 L p .654 .583 .763 r
F P
0 g
s
.32462 .51044 m .33748 .51397 L .35814 .54081 L p .383 .619 .945 r
F P
0 g
s
.3695 .54195 m .35814 .54081 L .33748 .51397 L p .419 .639 .947 r
F P
0 g
s
.43608 .54449 m .44584 .5342 L .46832 .54443 L p .755 .73 .829 r
F P
0 g
s
.47533 .53095 m .46832 .54443 L .44584 .5342 L p .774 .719 .801 r
F P
0 g
s
.61841 .55541 m .6093 .54717 L .63032 .53294 L p .625 .673 .876 r
F P
0 g
s
.63032 .53294 m .64182 .5397 L .61841 .55541 L p .625 .673 .876 r
F P
0 g
s
.47533 .53095 m .48238 .516 L .50191 .52102 L p .756 .675 .772 r
F P
0 g
s
.50575 .50452 m .50191 .52102 L .48238 .516 L p .758 .67 .764 r
F P
0 g
s
.50191 .52102 m .50575 .50452 L .52327 .50615 L p .726 .637 .759 r
F P
0 g
s
.6755 .54669 m .66442 .54628 L .68391 .52382 L p .721 .874 .953 r
F P
0 g
s
.68391 .52382 m .69672 .52242 L .6755 .54669 L p .721 .874 .953 r
F P
0 g
s
.57038 .53243 m .56398 .51728 L .58146 .51002 L p .616 .571 .781 r
F P
0 g
s
.58146 .51002 m .5908 .52404 L .57038 .53243 L p .616 .571 .781 r
F P
0 g
s
.52364 .48938 m .52327 .50615 L .50575 .50452 L p .726 .638 .76 r
F P
0 g
s
.52327 .50615 m .52364 .48938 L .53777 .48852 L p .691 .609 .759 r
F P
0 g
s
.53777 .48852 m .54091 .50508 L .52327 .50615 L p .691 .609 .759 r
F P
0 g
s
.75951 .51062 m .74699 .51155 L .76128 .47619 L p .736 .842 .93 r
F P
0 g
s
.76128 .47619 m .77489 .4732 L .75951 .51062 L p .736 .842 .93 r
F P
0 g
s
.54091 .50508 m .53777 .48852 L .55109 .48552 L p .654 .584 .764 r
F P
0 g
s
.55109 .48552 m .55754 .50138 L .54091 .50508 L p .654 .584 .764 r
F P
0 g
s
.44584 .5342 m .45568 .52192 L .47533 .53095 L p .774 .719 .801 r
F P
0 g
s
.48238 .516 m .47533 .53095 L .45568 .52192 L p .785 .712 .783 r
F P
0 g
s
.48238 .516 m .48946 .5003 L .50575 .50452 L p .758 .67 .764 r
F P
0 g
s
.50959 .48807 m .50575 .50452 L .48946 .5003 L p .758 .671 .765 r
F P
0 g
s
.50575 .50452 m .50959 .48807 L .52364 .48938 L p .726 .638 .76 r
F P
0 g
s
.39264 .54005 m .40442 .53602 L .42643 .55245 L p .665 .755 .917 r
F P
0 g
s
.43608 .54449 m .42643 .55245 L .40442 .53602 L p .729 .762 .879 r
F P
0 g
s
.56398 .51728 m .55754 .50138 L .5721 .49527 L p .613 .561 .772 r
F P
0 g
s
.5721 .49527 m .58146 .51002 L .56398 .51728 L p .613 .561 .772 r
F P
0 g
s
.20357 .471 m .21796 .46732 L .23413 .51358 L p .763 .81 .89 r
F P
0 g
s
.23413 .51358 m .22088 .51927 L .20357 .471 L p .763 .81 .89 r
F P
0 g
s
.24731 .50878 m .23413 .51358 L .21796 .46732 L p .742 .799 .898 r
F P
0 g
s
.18911 .47507 m .20357 .471 L .22088 .51927 L p .771 .814 .887 r
F P
0 g
s
.22088 .51927 m .20758 .52532 L .18911 .47507 L p .771 .814 .887 r
F P
0 g
s
.21796 .46732 m .23223 .46454 L .24731 .50878 L p .742 .799 .898 r
F P
0 g
s
.26039 .50528 m .24731 .50878 L .23223 .46454 L p .707 .78 .908 r
F P
0 g
s
.6093 .54717 m .60008 .5366 L .61872 .52386 L p .601 .618 .84 r
F P
0 g
s
.61872 .52386 m .63032 .53294 L .6093 .54717 L p .601 .618 .84 r
F P
0 g
s
.524 .47345 m .52364 .48938 L .50959 .48807 L p .723 .645 .77 r
F P
0 g
s
.52364 .48938 m .524 .47345 L .53463 .47279 L p .691 .618 .77 r
F P
0 g
s
.53463 .47279 m .53777 .48852 L .52364 .48938 L p .691 .618 .77 r
F P
0 g
s
.23223 .46454 m .24636 .46309 L .26039 .50528 L p .707 .78 .908 r
F P
0 g
s
.27336 .50337 m .26039 .50528 L .24636 .46309 L p .659 .751 .918 r
F P
0 g
s
.45568 .52192 m .46556 .50819 L .48238 .516 L p .785 .712 .783 r
F P
0 g
s
.48946 .5003 m .48238 .516 L .46556 .50819 L p .79 .709 .775 r
F P
0 g
s
.53777 .48852 m .53463 .47279 L .54463 .47052 L p .656 .595 .774 r
F P
0 g
s
.54463 .47052 m .55109 .48552 L .53777 .48852 L p .656 .595 .774 r
F P
0 g
s
.33748 .51397 m .35043 .51698 L .3695 .54195 L p .419 .639 .947 r
F P
0 g
s
.38099 .54189 m .3695 .54195 L .35043 .51698 L p .491 .677 .948 r
F P
0 g
s
.48946 .5003 m .49656 .48465 L .50959 .48807 L p .758 .671 .765 r
F P
0 g
s
.51345 .47245 m .50959 .48807 L .49656 .48465 L p .754 .677 .776 r
F P
0 g
s
.50959 .48807 m .51345 .47245 L .524 .47345 L p .723 .645 .77 r
F P
0 g
s
.74699 .51155 m .7345 .51374 L .74772 .48045 L p .765 .875 .927 r
F P
0 g
s
.74772 .48045 m .76128 .47619 L .74699 .51155 L p .765 .875 .927 r
F P
0 g
s
.55754 .50138 m .55109 .48552 L .56273 .48058 L p .613 .562 .773 r
F P
0 g
s
.56273 .48058 m .5721 .49527 L .55754 .50138 L p .613 .562 .773 r
F P
0 g
s
.66442 .54628 m .65319 .54409 L .67095 .52343 L p .69 .815 .942 r
F P
0 g
s
.67095 .52343 m .68391 .52382 L .66442 .54628 L p .69 .815 .942 r
F P
0 g
s
.24636 .46309 m .26034 .46325 L .27336 .50337 L p .659 .751 .918 r
F P
0 g
s
.28624 .50313 m .27336 .50337 L .26034 .46325 L p .6 .715 .925 r
F P
0 g
s
.40442 .53602 m .41634 .5296 L .43608 .54449 L p .729 .762 .879 r
F P
0 g
s
.44584 .5342 m .43608 .54449 L .41634 .5296 L p .772 .762 .844 r
F P
0 g
s
.46556 .50819 m .47546 .49373 L .48946 .5003 L p .79 .709 .775 r
F P
0 g
s
.49656 .48465 m .48946 .5003 L .47546 .49373 L p .789 .709 .776 r
F P
0 g
s
.60008 .5366 m .5908 .52404 L .60704 .5128 L p .582 .578 .813 r
F P
0 g
s
.60704 .5128 m .61872 .52386 L .60008 .5366 L p .582 .578 .813 r
F P
0 g
s
.52437 .45908 m .524 .47345 L .51345 .47245 L p .718 .661 .792 r
F P
0 g
s
.524 .47345 m .52437 .45908 L .53147 .45864 L p .69 .637 .792 r
F P
0 g
s
.53147 .45864 m .53463 .47279 L .524 .47345 L p .69 .637 .792 r
F P
0 g
s
.55109 .48552 m .54463 .47052 L .55335 .46678 L p .617 .575 .784 r
F P
0 g
s
.55335 .46678 m .56273 .48058 L .55109 .48552 L p .617 .575 .784 r
F P
0 g
s
.53463 .47279 m .53147 .45864 L .53815 .45711 L p .659 .617 .796 r
F P
0 g
s
.53815 .45711 m .54463 .47052 L .53463 .47279 L p .659 .617 .796 r
F P
0 g
s
.47546 .49373 m .48537 .47934 L .49656 .48465 L p .789 .709 .776 r
F P
0 g
s
.50366 .46986 m .49656 .48465 L .48537 .47934 L p .783 .714 .787 r
F P
0 g
s
.49656 .48465 m .50366 .46986 L .51345 .47245 L p .754 .677 .776 r
F P
0 g
s
.51732 .45841 m .51345 .47245 L .50366 .46986 L p .745 .689 .797 r
F P
0 g
s
.51345 .47245 m .51732 .45841 L .52437 .45908 L p .718 .661 .792 r
F P
0 g
s
.26034 .46325 m .27418 .46511 L .28624 .50313 L p .6 .715 .925 r
F P
0 g
s
.29905 .50447 m .28624 .50313 L .27418 .46511 L p .538 .674 .925 r
F P
0 g
s
.5908 .52404 m .58146 .51002 L .59533 .50031 L p .57 .553 .796 r
F P
0 g
s
.59533 .50031 m .60704 .5128 L .5908 .52404 L p .57 .553 .796 r
F P
0 g
s
.41634 .5296 m .42836 .52088 L .44584 .5342 L p .772 .762 .844 r
F P
0 g
s
.45568 .52192 m .44584 .5342 L .42836 .52088 L p .798 .759 .817 r
F P
0 g
s
.7345 .51374 m .72199 .5167 L .73418 .4855 L p .782 .895 .924 r
F P
0 g
s
.73418 .4855 m .74772 .48045 L .7345 .51374 L p .782 .895 .924 r
F P
0 g
s
.58146 .51002 m .5721 .49527 L .58361 .48711 L p .565 .542 .788 r
F P
0 g
s
.58361 .48711 m .59533 .50031 L .58146 .51002 L p .565 .542 .788 r
F P
0 g
s
.54463 .47052 m .53815 .45711 L .54396 .4546 L p .625 .601 .805 r
F P
0 g
s
.54396 .4546 m .55335 .46678 L .54463 .47052 L p .625 .601 .805 r
F P
0 g
s
.35043 .51698 m .36351 .51879 L .38099 .54189 L p .491 .677 .948 r
F P
0 g
s
.39264 .54005 m .38099 .54189 L .36351 .51879 L p .58 .721 .939 r
F P
0 g
s
.42836 .52088 m .44044 .51018 L .45568 .52192 L p .798 .759 .817 r
F P
0 g
s
.46556 .50819 m .45568 .52192 L .44044 .51018 L p .813 .756 .8 r
F P
0 g
s
.48537 .47934 m .49529 .46584 L .50366 .46986 L p .783 .714 .787 r
F P
0 g
s
.51078 .45667 m .50366 .46986 L .49529 .46584 L p .77 .721 .808 r
F P
0 g
s
.50366 .46986 m .51078 .45667 L .51732 .45841 L p .745 .689 .797 r
F P
0 g
s
.65319 .54409 m .64182 .5397 L .65786 .52085 L p .649 .744 .919 r
F P
0 g
s
.65786 .52085 m .67095 .52343 L .65319 .54409 L p .649 .744 .919 r
F P
0 g
s
.5721 .49527 m .56273 .48058 L .5719 .47401 L p .565 .543 .789 r
F P
0 g
s
.5719 .47401 m .58361 .48711 L .5721 .49527 L p .565 .543 .789 r
F P
0 g
s
.44044 .51018 m .45256 .49804 L .46556 .50819 L p .813 .756 .8 r
F P
0 g
s
.47546 .49373 m .46556 .50819 L .45256 .49804 L p .819 .755 .792 r
F P
0 g
s
.52474 .44687 m .52437 .45908 L .51732 .45841 L p .707 .687 .828 r
F P
0 g
s
.52437 .45908 m .52474 .44687 L .5283 .44665 L p .686 .669 .828 r
F P
0 g
s
.5283 .44665 m .53147 .45864 L .52437 .45908 L p .686 .669 .828 r
F P
0 g
s
.27418 .46511 m .28792 .46855 L .29905 .50447 L p .538 .674 .925 r
F P
0 g
s
.31183 .50707 m .29905 .50447 L .28792 .46855 L p .484 .636 .922 r
F P
0 g
s
.56273 .48058 m .55335 .46678 L .5602 .46181 L p .573 .558 .799 r
F P
0 g
s
.5602 .46181 m .5719 .47401 L .56273 .48058 L p .573 .558 .799 r
F P
0 g
s
.53147 .45864 m .5283 .44665 L .53165 .44588 L p .663 .654 .831 r
F P
0 g
s
.53165 .44588 m .53815 .45711 L .53147 .45864 L p .663 .654 .831 r
F P
0 g
s
.5212 .44653 m .51732 .45841 L .51078 .45667 L p .727 .708 .833 r
F P
0 g
s
.51732 .45841 m .5212 .44653 L .52474 .44687 L p .707 .687 .828 r
F P
0 g
s
.45256 .49804 m .46469 .48521 L .47546 .49373 L p .819 .755 .792 r
F P
0 g
s
.48537 .47934 m .47546 .49373 L .46469 .48521 L p .818 .755 .793 r
F P
0 g
s
.46469 .48521 m .4768 .47247 L .48537 .47934 L p .818 .755 .793 r
F P
0 g
s
.49529 .46584 m .48537 .47934 L .4768 .47247 L p .81 .757 .803 r
F P
0 g
s
.55335 .46678 m .54396 .4546 L .54852 .45126 L p .588 .588 .82 r
F P
0 g
s
.54852 .45126 m .5602 .46181 L .55335 .46678 L p .588 .588 .82 r
F P
0 g
s
.53815 .45711 m .53165 .44588 L .53456 .44461 L p .638 .643 .839 r
F P
0 g
s
.53456 .44461 m .54396 .4546 L .53815 .45711 L p .638 .643 .839 r
F P
0 g
s
.49529 .46584 m .5052 .45397 L .51078 .45667 L p .77 .721 .808 r
F P
0 g
s
.51793 .44565 m .51078 .45667 L .5052 .45397 L p .744 .732 .841 r
F P
0 g
s
.51078 .45667 m .51793 .44565 L .5212 .44653 L p .727 .708 .833 r
F P
0 g
s
.72199 .5167 m .70941 .51982 L .72059 .4907 L p .785 .898 .923 r
F P
0 g
s
.72059 .4907 m .73418 .4855 L .72199 .5167 L p .785 .898 .923 r
F P
0 g
s
.4768 .47247 m .48888 .46065 L .49529 .46584 L p .81 .757 .803 r
F P
0 g
s
.5052 .45397 m .49529 .46584 L .48888 .46065 L p .791 .759 .824 r
F P
0 g
s
.64182 .5397 m .63032 .53294 L .64465 .5159 L p .605 .674 .889 r
F P
0 g
s
.64465 .5159 m .65786 .52085 L .64182 .5397 L p .605 .674 .889 r
F P
0 g
s
.36351 .51879 m .37673 .51881 L .39264 .54005 L p .58 .721 .939 r
F P
0 g
s
.40442 .53602 m .39264 .54005 L .37673 .51881 L p .665 .757 .919 r
F P
0 g
s
.28792 .46855 m .30159 .47327 L .31183 .50707 L p .484 .636 .922 r
F P
0 g
s
.32462 .51044 m .31183 .50707 L .30159 .47327 L p .45 .612 .918 r
F P
0 g
s
.54396 .4546 m .53456 .44461 L .53683 .44293 L p .611 .637 .851 r
F P
0 g
s
.53683 .44293 m .54852 .45126 L .54396 .4546 L p .611 .637 .851 r
F P
0 g
s
.48888 .46065 m .50095 .45048 L .5052 .45397 L p .791 .759 .824 r
F P
0 g
s
.51514 .44429 m .5052 .45397 L .50095 .45048 L p .757 .76 .855 r
F P
0 g
s
.5052 .45397 m .51514 .44429 L .51793 .44565 L p .744 .732 .841 r
F P
0 g
s
.63032 .53294 m .61872 .52386 L .63135 .50864 L p .567 .614 .859 r
F P
0 g
s
.63135 .50864 m .64465 .5159 L .63032 .53294 L p .567 .614 .859 r
F P
0 g
s
.52511 .4372 m .52474 .44687 L .5212 .44653 L closepath p .682 .724 .882 r
F P
0 g
s
.52511 .4372 m .5283 .44665 L .52474 .44687 L closepath p .673 .717 .882 r
F P
0 g
s
.52511 .4372 m .53165 .44588 L .5283 .44665 L closepath p .663 .711 .883 r
F P
0 g
s
.52511 .4372 m .5212 .44653 L .51793 .44565 L closepath p .69 .734 .884 r
F P
0 g
s
.5719 .47401 m .5602 .46181 L .56472 .45593 L p .521 .545 .821 r
F P
0 g
s
.5602 .46181 m .54852 .45126 L .5515 .44732 L p .546 .581 .841 r
F P
0 g
s
.5515 .44732 m .56472 .45593 L .5602 .46181 L p .546 .581 .841 r
F P
0 g
s
.58361 .48711 m .5719 .47401 L .57797 .46621 L p .508 .527 .811 r
F P
0 g
s
.56472 .45593 m .57797 .46621 L .5719 .47401 L p .521 .545 .821 r
F P
0 g
s
.37673 .51881 m .39009 .51665 L .40442 .53602 L p .665 .757 .919 r
F P
0 g
s
.41634 .5296 m .40442 .53602 L .39009 .51665 L p .733 .782 .892 r
F P
0 g
s
.52511 .4372 m .53456 .44461 L .53165 .44588 L closepath p .653 .707 .887 r
F P
0 g
s
.52511 .4372 m .51793 .44565 L .51514 .44429 L closepath p .696 .744 .888 r
F P
0 g
s
.59533 .50031 m .58361 .48711 L .59128 .47742 L p .507 .526 .81 r
F P
0 g
s
.57797 .46621 m .59128 .47742 L .58361 .48711 L p .508 .527 .811 r
F P
0 g
s
.61872 .52386 m .60704 .5128 L .618 .4994 L p .537 .569 .835 r
F P
0 g
s
.618 .4994 m .63135 .50864 L .61872 .52386 L p .537 .569 .835 r
F P
0 g
s
.54852 .45126 m .53683 .44293 L .53831 .44095 L p .583 .635 .868 r
F P
0 g
s
.53831 .44095 m .5515 .44732 L .54852 .45126 L p .583 .635 .868 r
F P
0 g
s
.70941 .51982 m .69672 .52242 L .70692 .49537 L p .773 .885 .926 r
F P
0 g
s
.70692 .49537 m .72059 .4907 L .70941 .51982 L p .773 .885 .926 r
F P
0 g
s
.60704 .5128 m .59533 .50031 L .60463 .48876 L p .517 .539 .818 r
F P
0 g
s
.59128 .47742 m .60463 .48876 L .59533 .50031 L p .507 .526 .81 r
F P
0 g
s
.47143 .46448 m .4849 .45463 L .48888 .46065 L p .832 .807 .827 r
F P
0 g
s
.48888 .46065 m .4768 .47247 L .47143 .46448 L p .832 .807 .827 r
F P
0 g
s
.50095 .45048 m .48888 .46065 L .4849 .45463 L p .808 .801 .846 r
F P
0 g
s
.60463 .48876 m .618 .4994 L .60704 .5128 L p .517 .539 .818 r
F P
0 g
s
.52511 .4372 m .53683 .44293 L .53456 .44461 L closepath p .642 .705 .893 r
F P
0 g
s
.45789 .47527 m .47143 .46448 L .4768 .47247 L p .844 .809 .816 r
F P
0 g
s
.4768 .47247 m .46469 .48521 L .45789 .47527 L p .844 .809 .816 r
F P
0 g
s
.50095 .45048 m .51302 .44254 L .51514 .44429 L p .757 .76 .855 r
F P
0 g
s
.52511 .4372 m .51514 .44429 L .51302 .44254 L closepath p .7 .755 .894 r
F P
0 g
s
.4849 .45463 m .49833 .44644 L .50095 .45048 L p .808 .801 .846 r
F P
0 g
s
.51302 .44254 m .50095 .45048 L .49833 .44644 L p .766 .789 .872 r
F P
0 g
s
.30159 .47327 m .31524 .47877 L .32462 .51044 L p .45 .612 .918 r
F P
0 g
s
.33748 .51397 m .32462 .51044 L .31524 .47877 L p .443 .607 .917 r
F P
0 g
s
.44431 .48619 m .45789 .47527 L .46469 .48521 L p .845 .809 .815 r
F P
0 g
s
.46469 .48521 m .45256 .49804 L .44431 .48619 L p .845 .809 .815 r
F P
0 g
s
.39009 .51665 m .40356 .5121 L .41634 .5296 L p .733 .782 .892 r
F P
0 g
s
.42836 .52088 m .41634 .5296 L .40356 .5121 L p .783 .797 .864 r
F P
0 g
s
.52511 .4372 m .53831 .44095 L .53683 .44293 L closepath p .632 .706 .9 r
F P
0 g
s
.49833 .44644 m .51172 .44051 L .51302 .44254 L p .766 .789 .872 r
F P
0 g
s
.52511 .4372 m .51302 .44254 L .51172 .44051 L closepath p .701 .765 .902 r
F P
0 g
s
.43071 .49643 m .44431 .48619 L .45256 .49804 L p .836 .808 .823 r
F P
0 g
s
.45256 .49804 m .44044 .51018 L .43071 .49643 L p .836 .808 .823 r
F P
0 g
s
.40356 .5121 m .41711 .50525 L .42836 .52088 L p .783 .797 .864 r
F P
0 g
s
.44044 .51018 m .42836 .52088 L .41711 .50525 L p .816 .804 .84 r
F P
0 g
s
.41711 .50525 m .43071 .49643 L .44044 .51018 L p .816 .804 .84 r
F P
0 g
s
.56472 .45593 m .5515 .44732 L .5527 .44303 L p .497 .578 .867 r
F P
0 g
s
.5515 .44732 m .53831 .44095 L .53889 .4388 L p .554 .638 .889 r
F P
0 g
s
.53889 .4388 m .5527 .44303 L .5515 .44732 L p .554 .638 .889 r
F P
0 g
s
.52511 .4372 m .53889 .4388 L .53831 .44095 L closepath p .623 .71 .908 r
F P
0 g
s
.49752 .44213 m .51134 .43835 L .51172 .44051 L p .767 .819 .893 r
F P
0 g
s
.51172 .44051 m .49833 .44644 L .49752 .44213 L p .767 .819 .893 r
F P
0 g
s
.52511 .4372 m .51172 .44051 L .51134 .43835 L closepath p .7 .775 .91 r
F P
0 g
s
.48363 .44816 m .49752 .44213 L .49833 .44644 L p .815 .848 .873 r
F P
0 g
s
.49833 .44644 m .4849 .45463 L .48363 .44816 L p .815 .848 .873 r
F P
0 g
s
.57797 .46621 m .56472 .45593 L .56656 .44952 L p .457 .536 .85 r
F P
0 g
s
.5527 .44303 m .56656 .44952 L .56472 .45593 L p .497 .578 .867 r
F P
0 g
s
.69672 .52242 m .68391 .52382 L .69315 .49884 L p .746 .854 .93 r
F P
0 g
s
.69315 .49884 m .70692 .49537 L .69672 .52242 L p .746 .854 .93 r
F P
0 g
s
.52511 .4372 m .53515 .43282 L .53726 .43459 L closepath p .608 .735 .935 r
F P
0 g
s
.52511 .4372 m .53236 .43144 L .53515 .43282 L closepath p .609 .746 .942 r
F P
0 g
s
.52511 .4372 m .52906 .43054 L .53236 .43144 L closepath p .615 .758 .948 r
F P
0 g
s
.52511 .4372 m .52549 .4302 L .52906 .43054 L closepath p .623 .77 .95 r
F P
0 g
s
.52511 .4372 m .5219 .43042 L .52549 .4302 L closepath p .635 .78 .951 r
F P
0 g
s
.52511 .4372 m .51852 .43121 L .5219 .43042 L closepath p .649 .788 .948 r
F P
0 g
s
.52511 .4372 m .5156 .4325 L .51852 .43121 L closepath p .663 .792 .943 r
F P
0 g
s
.52511 .4372 m .51334 .4342 L .5156 .4325 L closepath p .676 .792 .937 r
F P
0 g
s
.52511 .4372 m .51189 .43619 L .51334 .4342 L closepath p .687 .79 .928 r
F P
0 g
s
.52511 .4372 m .51134 .43835 L .51189 .43619 L closepath p .695 .784 .919 r
F P
0 g
s
.52511 .4372 m .53853 .43663 L .53889 .4388 L closepath p .615 .716 .917 r
F P
0 g
s
.52511 .4372 m .53726 .43459 L .53853 .43663 L closepath p .61 .724 .926 r
F P
0 g
s
.31524 .47877 m .32893 .48443 L .33748 .51397 L p .443 .607 .917 r
F P
0 g
s
.35043 .51698 m .33748 .51397 L .32893 .48443 L p .468 .625 .92 r
F P
0 g
s
.5527 .44303 m .53889 .4388 L .53853 .43663 L p .524 .648 .912 r
F P
0 g
s
.46966 .45589 m .48363 .44816 L .4849 .45463 L p .845 .864 .857 r
F P
0 g
s
.4849 .45463 m .47143 .46448 L .46966 .45589 L p .845 .864 .857 r
F P
0 g
s
.49859 .43782 m .51189 .43619 L .51134 .43835 L p .759 .847 .917 r
F P
0 g
s
.51134 .43835 m .49752 .44213 L .49859 .43782 L p .759 .847 .917 r
F P
0 g
s
.59128 .47742 m .57797 .46621 L .58051 .45769 L p .437 .514 .84 r
F P
0 g
s
.56656 .44952 m .58051 .45769 L .57797 .46621 L p .457 .536 .85 r
F P
0 g
s
.56656 .44952 m .5527 .44303 L .55202 .4387 L p .441 .583 .899 r
F P
0 g
s
.53853 .43663 m .55202 .4387 L .5527 .44303 L p .524 .648 .912 r
F P
0 g
s
.55202 .4387 m .53853 .43663 L .53726 .43459 L p .496 .665 .937 r
F P
0 g
s
.4556 .46457 m .46966 .45589 L .47143 .46448 L p .859 .871 .847 r
F P
0 g
s
.47143 .46448 m .45789 .47527 L .4556 .46457 L p .859 .871 .847 r
F P
0 g
s
.50148 .43381 m .51334 .4342 L .51189 .43619 L p .737 .87 .942 r
F P
0 g
s
.51189 .43619 m .49859 .43782 L .50148 .43381 L p .737 .87 .942 r
F P
0 g
s
.48519 .4417 m .49859 .43782 L .49752 .44213 L p .807 .894 .905 r
F P
0 g
s
.49752 .44213 m .48363 .44816 L .48519 .4417 L p .807 .894 .905 r
F P
0 g
s
.68391 .52382 m .67095 .52343 L .67926 .50051 L p .702 .806 .93 r
F P
0 g
s
.67926 .50051 m .69315 .49884 L .68391 .52382 L p .702 .806 .93 r
F P
0 g
s
.60463 .48876 m .59128 .47742 L .59454 .46682 L p .435 .512 .839 r
F P
0 g
s
.58051 .45769 m .59454 .46682 L .59128 .47742 L p .437 .514 .84 r
F P
0 g
s
.53726 .43459 m .54949 .4346 L .55202 .4387 L p .496 .665 .937 r
F P
0 g
s
.54949 .4346 m .53726 .43459 L .53515 .43282 L p .473 .688 .961 r
F P
0 g
s
.32893 .48443 m .34269 .48956 L .35043 .51698 L p .468 .625 .92 r
F P
0 g
s
.36351 .51879 m .35043 .51698 L .34269 .48956 L p .52 .662 .925 r
F P
0 g
s
.50601 .43039 m .5156 .4325 L .51334 .4342 L p .7 .882 .965 r
F P
0 g
s
.51334 .4342 m .50148 .43381 L .50601 .43039 L p .7 .882 .965 r
F P
0 g
s
.58051 .45769 m .56656 .44952 L .56559 .44302 L p .378 .532 .883 r
F P
0 g
s
.55202 .4387 m .56559 .44302 L .56656 .44952 L p .441 .583 .899 r
F P
0 g
s
.44145 .47339 m .4556 .46457 L .45789 .47527 L p .86 .871 .846 r
F P
0 g
s
.45789 .47527 m .44431 .48619 L .44145 .47339 L p .86 .871 .846 r
F P
0 g
s
.618 .4994 m .60463 .48876 L .60865 .47609 L p .451 .529 .847 r
F P
0 g
s
.59454 .46682 m .60865 .47609 L .60463 .48876 L p .435 .512 .839 r
F P
0 g
s
.53515 .43282 m .54528 .43104 L .54949 .4346 L p .473 .688 .961 r
F P
0 g
s
.54528 .43104 m .53515 .43282 L .53236 .43144 L p .461 .719 .98 r
F P
0 g
s
.51186 .4278 m .51852 .43121 L .5156 .4325 L p .648 .88 .983 r
F P
0 g
s
.5156 .4325 m .50601 .43039 L .51186 .4278 L p .648 .88 .983 r
F P
0 g
s
.56559 .44302 m .55202 .4387 L .54949 .4346 L p .377 .594 .93 r
F P
0 g
s
.47168 .44728 m .48519 .4417 L .48363 .44816 L p .837 .922 .89 r
F P
0 g
s
.48363 .44816 m .46966 .45589 L .47168 .44728 L p .837 .922 .89 r
F P
0 g
s
.67095 .52343 m .65786 .52085 L .66525 .49999 L p .647 .745 .921 r
F P
0 g
s
.66525 .49999 m .67926 .50051 L .67095 .52343 L p .647 .745 .921 r
F P
0 g
s
.48951 .43568 m .50148 .43381 L .49859 .43782 L p .772 .932 .937 r
F P
0 g
s
.49859 .43782 m .48519 .4417 L .48951 .43568 L p .772 .932 .937 r
F P
0 g
s
.53236 .43144 m .53967 .42826 L .54528 .43104 L p .461 .719 .98 r
F P
0 g
s
.53967 .42826 m .53236 .43144 L .52906 .43054 L p .465 .754 .993 r
F P
0 g
s
.51864 .42622 m .5219 .43042 L .51852 .43121 L p .589 .861 .994 r
F P
0 g
s
.51852 .43121 m .51186 .4278 L .51864 .42622 L p .589 .861 .994 r
F P
0 g
s
.63135 .50864 m .618 .4994 L .62281 .48468 L p .483 .564 .862 r
F P
0 g
s
.60865 .47609 m .62281 .48468 L .618 .4994 L p .451 .529 .847 r
F P
0 g
s
.52906 .43054 m .53305 .42646 L .53967 .42826 L p .465 .754 .993 r
F P
0 g
s
.53305 .42646 m .52906 .43054 L .52549 .4302 L p .489 .793 .999 r
F P
0 g
s
.52587 .42576 m .52549 .4302 L .5219 .43042 L p .532 .831 .999 r
F P
0 g
s
.5219 .43042 m .51864 .42622 L .52587 .42576 L p .532 .831 .999 r
F P
0 g
s
.34269 .48956 m .35656 .49348 L .36351 .51879 L p .52 .662 .925 r
F P
0 g
s
.37673 .51881 m .36351 .51879 L .35656 .49348 L p .589 .71 .927 r
F P
0 g
s
.42725 .48154 m .44145 .47339 L .44431 .48619 L p .849 .866 .854 r
F P
0 g
s
.44431 .48619 m .43071 .49643 L .42725 .48154 L p .849 .866 .854 r
F P
0 g
s
.52549 .4302 m .52587 .42576 L .53305 .42646 L p .489 .793 .999 r
F P
0 g
s
.65786 .52085 m .64465 .5159 L .65115 .49708 L p .586 .678 .904 r
F P
0 g
s
.65115 .49708 m .66525 .49999 L .65786 .52085 L p .586 .678 .904 r
F P
0 g
s
.59454 .46682 m .58051 .45769 L .57927 .44904 L p .343 .504 .873 r
F P
0 g
s
.56559 .44302 m .57927 .44904 L .58051 .45769 L p .378 .532 .883 r
F P
0 g
s
.64465 .5159 m .63135 .50864 L .63699 .49186 L p .529 .616 .883 r
F P
0 g
s
.62281 .48468 m .63699 .49186 L .63135 .50864 L p .483 .564 .862 r
F P
0 g
s
.63699 .49186 m .65115 .49708 L .64465 .5159 L p .529 .616 .883 r
F P
0 g
s
.54949 .4346 m .56183 .43687 L .56559 .44302 L p .377 .594 .93 r
F P
0 g
s
.56183 .43687 m .54949 .4346 L .54528 .43104 L p .31 .613 .955 r
F P
0 g
s
.41301 .48828 m .42725 .48154 L .43071 .49643 L p .825 .854 .869 r
F P
0 g
s
.43071 .49643 m .41711 .50525 L .41301 .48828 L p .825 .854 .869 r
F P
0 g
s
.4963 .43053 m .50601 .43039 L .50148 .43381 L p .699 .946 .958 r
F P
0 g
s
.50148 .43381 m .48951 .43568 L .4963 .43053 L p .699 .946 .958 r
F P
0 g
s
.45805 .45381 m .47168 .44728 L .46966 .45589 L p .851 .935 .88 r
F P
0 g
s
.46966 .45589 m .4556 .46457 L .45805 .45381 L p .851 .935 .88 r
F P
0 g
s
.35656 .49348 m .37053 .4956 L .37673 .51881 L p .589 .71 .927 r
F P
0 g
s
.39009 .51665 m .37673 .51881 L .37053 .4956 L p .664 .759 .921 r
F P
0 g
s
.81642 .47399 m .80244 .47209 L .80169 .42824 L p .607 .709 .917 r
F P
0 g
s
.80244 .47209 m .7886 .4718 L .78756 .43018 L p .655 .749 .919 r
F P
0 g
s
.78756 .43018 m .80169 .42824 L .80244 .47209 L p .655 .749 .919 r
F P
0 g
s
.57927 .44904 m .56559 .44302 L .56183 .43687 L p .278 .531 .913 r
F P
0 g
s
.7886 .4718 m .77489 .4732 L .7736 .43383 L p .703 .787 .916 r
F P
0 g
s
.7736 .43383 m .78756 .43018 L .7886 .4718 L p .703 .787 .916 r
F P
0 g
s
.83054 .47721 m .81642 .47399 L .816 .42792 L p .566 .676 .913 r
F P
0 g
s
.80169 .42824 m .816 .42792 L .81642 .47399 L p .607 .709 .917 r
F P
0 g
s
.39879 .49306 m .41301 .48828 L .41711 .50525 L p .787 .833 .888 r
F P
0 g
s
.41711 .50525 m .40356 .5121 L .39879 .49306 L p .787 .833 .888 r
F P
0 g
s
.77489 .4732 m .76128 .47619 L .75977 .43908 L p .746 .819 .909 r
F P
0 g
s
.75977 .43908 m .7736 .43383 L .77489 .4732 L p .746 .819 .909 r
F P
0 g
s
.4774 .43924 m .48951 .43568 L .48519 .4417 L p .788 .967 .918 r
F P
0 g
s
.48519 .4417 m .47168 .44728 L .4774 .43924 L p .788 .967 .918 r
F P
0 g
s
.37053 .4956 m .38462 .49552 L .39009 .51665 L p .664 .759 .921 r
F P
0 g
s
.40356 .5121 m .39009 .51665 L .38462 .49552 L p .732 .802 .907 r
F P
0 g
s
.38462 .49552 m .39879 .49306 L .40356 .5121 L p .732 .802 .907 r
F P
0 g
s
.84476 .48133 m .83054 .47721 L .83049 .42893 L p .539 .652 .908 r
F P
0 g
s
.816 .42792 m .83049 .42893 L .83054 .47721 L p .566 .676 .913 r
F P
0 g
s
.54528 .43104 m .55552 .43151 L .56183 .43687 L p .31 .613 .955 r
F P
0 g
s
.55552 .43151 m .54528 .43104 L .53967 .42826 L p .254 .64 .963 r
F P
0 g
s
.60865 .47609 m .59454 .46682 L .59308 .45601 L p .34 .501 .872 r
F P
0 g
s
.57927 .44904 m .59308 .45601 L .59454 .46682 L p .343 .504 .873 r
F P
0 g
s
.50511 .42662 m .51186 .4278 L .50601 .43039 L p .586 .924 .962 r
F P
0 g
s
.50601 .43039 m .4963 .43053 L .50511 .42662 L p .586 .924 .962 r
F P
0 g
s
.76128 .47619 m .74772 .48045 L .74603 .4456 L p .777 .842 .901 r
F P
0 g
s
.74603 .4456 m .75977 .43908 L .76128 .47619 L p .777 .842 .901 r
F P
0 g
s
.85906 .48583 m .84476 .48133 L .84512 .43086 L p .528 .642 .906 r
F P
0 g
s
.83049 .42893 m .84512 .43086 L .84476 .48133 L p .539 .652 .908 r
F P
0 g
s
.4443 .46049 m .45805 .45381 L .4556 .46457 L p .853 .936 .879 r
F P
0 g
s
.4556 .46457 m .44145 .47339 L .4443 .46049 L p .853 .936 .879 r
F P
0 g
s
.53967 .42826 m .54709 .42732 L .55552 .43151 L p .254 .64 .963 r
F P
0 g
s
.54709 .42732 m .53967 .42826 L .53305 .42646 L p .229 .676 .953 r
F P
0 g
s
.51534 .42423 m .51864 .42622 L .51186 .4278 L p .452 .867 .95 r
F P
0 g
s
.51186 .4278 m .50511 .42662 L .51534 .42423 L p .452 .867 .95 r
F P
0 g
s
.74772 .48045 m .73418 .4855 L .73234 .4529 L p .795 .854 .895 r
F P
0 g
s
.73234 .4529 m .74603 .4456 L .74772 .48045 L p .795 .854 .895 r
F P
0 g
s
.84512 .43086 m .85986 .43317 L .85906 .48583 L p .528 .642 .906 r
F P
0 g
s
.56183 .43687 m .5743 .44083 L .57927 .44904 L p .278 .531 .913 r
F P
0 g
s
.5743 .44083 m .56183 .43687 L .55552 .43151 L p .163 .532 .922 r
F P
0 g
s
.59308 .45601 m .57927 .44904 L .5743 .44083 L p .221 .493 .899 r
F P
0 g
s
.53305 .42646 m .5371 .42459 L .54709 .42732 L p .229 .676 .953 r
F P
0 g
s
.5371 .42459 m .53305 .42646 L .52587 .42576 L p .254 .727 .94 r
F P
0 g
s
.52626 .42354 m .52587 .42576 L .51864 .42622 L p .332 .794 .939 r
F P
0 g
s
.51864 .42622 m .51534 .42423 L .52626 .42354 L p .332 .794 .939 r
F P
0 g
s
.62281 .48468 m .60865 .47609 L .60699 .46313 L p .366 .523 .88 r
F P
0 g
s
.59308 .45601 m .60699 .46313 L .60865 .47609 L p .34 .501 .872 r
F P
0 g
s
.48646 .43234 m .4963 .43053 L .48951 .43568 L p .674 .969 .919 r
F P
0 g
s
.48951 .43568 m .4774 .43924 L .48646 .43234 L p .674 .969 .919 r
F P
0 g
s
.52587 .42576 m .52626 .42354 L .5371 .42459 L p .254 .727 .94 r
F P
0 g
s
.46516 .44375 m .4774 .43924 L .47168 .44728 L p .793 .981 .901 r
F P
0 g
s
.47168 .44728 m .45805 .45381 L .46516 .44375 L p .793 .981 .901 r
F P
0 g
s
.25115 .41911 m .26521 .42153 L .26034 .46325 L p .659 .752 .919 r
F P
0 g
s
.26034 .46325 m .24636 .46309 L .25115 .41911 L p .659 .752 .919 r
F P
0 g
s
.27418 .46511 m .26034 .46325 L .26521 .42153 L p .61 .708 .914 r
F P
0 g
s
.73418 .4855 m .72059 .4907 L .71863 .46034 L p .798 .857 .893 r
F P
0 g
s
.71863 .46034 m .73234 .4529 L .73418 .4855 L p .798 .857 .893 r
F P
0 g
s
.2369 .41831 m .25115 .41911 L .24636 .46309 L p .702 .79 .919 r
F P
0 g
s
.24636 .46309 m .23223 .46454 L .2369 .41831 L p .702 .79 .919 r
F P
0 g
s
.26521 .42153 m .2791 .42566 L .27418 .46511 L p .61 .708 .914 r
F P
0 g
s
.28792 .46855 m .27418 .46511 L .2791 .42566 L p .563 .664 .905 r
F P
0 g
s
.43046 .4665 m .4443 .46049 L .44145 .47339 L p .842 .926 .887 r
F P
0 g
s
.44145 .47339 m .42725 .48154 L .43046 .4665 L p .842 .926 .887 r
F P
0 g
s
.22247 .41885 m .2369 .41831 L .23223 .46454 L p .735 .819 .917 r
F P
0 g
s
.23223 .46454 m .21796 .46732 L .22247 .41885 L p .735 .819 .917 r
F P
0 g
s
.2791 .42566 m .29285 .43138 L .28792 .46855 L p .563 .664 .905 r
F P
0 g
s
.30159 .47327 m .28792 .46855 L .29285 .43138 L p .525 .628 .896 r
F P
0 g
s
.63699 .49186 m .62281 .48468 L .62099 .46958 L p .419 .566 .895 r
F P
0 g
s
.60699 .46313 m .62099 .46958 L .62281 .48468 L p .366 .523 .88 r
F P
0 g
s
.55552 .43151 m .5659 .43365 L .5743 .44083 L p .163 .532 .922 r
F P
0 g
s
.5659 .43365 m .55552 .43151 L .54709 .42732 L p .056 .533 .892 r
F P
0 g
s
.20788 .4203 m .22247 .41885 L .21796 .46732 L p .756 .836 .913 r
F P
0 g
s
.21796 .46732 m .20357 .471 L .20788 .4203 L p .756 .836 .913 r
F P
0 g
s
.72059 .4907 m .70692 .49537 L .70488 .46725 L p .786 .848 .898 r
F P
0 g
s
.70488 .46725 m .71863 .46034 L .72059 .4907 L p .786 .848 .898 r
F P
0 g
s
.49826 .4271 m .50511 .42662 L .4963 .43053 L p .492 .904 .881 r
F P
0 g
s
.4963 .43053 m .48646 .43234 L .49826 .4271 L p .492 .904 .881 r
F P
0 g
s
.60699 .46313 m .59308 .45601 L .58691 .44574 L p .215 .489 .897 r
F P
0 g
s
.5743 .44083 m .58691 .44574 L .59308 .45601 L p .221 .493 .899 r
F P
0 g
s
.29285 .43138 m .30651 .43838 L .30159 .47327 L p .525 .628 .896 r
F P
0 g
s
.31524 .47877 m .30159 .47327 L .30651 .43838 L p .502 .606 .889 r
F P
0 g
s
.19318 .42214 m .20788 .4203 L .20357 .471 L p .764 .843 .911 r
F P
0 g
s
.20357 .471 m .18911 .47507 L .19318 .42214 L p .764 .843 .911 r
F P
0 g
s
.58691 .44574 m .5743 .44083 L .5659 .43365 L p .075 .478 .892 r
F P
0 g
s
.41656 .4711 m .43046 .4665 L .42725 .48154 L p .817 .905 .901 r
F P
0 g
s
.42725 .48154 m .41301 .48828 L .41656 .4711 L p .817 .905 .901 r
F P
0 g
s
.65115 .49708 m .63699 .49186 L .63504 .47463 L p .49 .624 .91 r
F P
0 g
s
.62099 .46958 m .63504 .47463 L .63699 .49186 L p .419 .566 .895 r
F P
0 g
s
.70692 .49537 m .69315 .49884 L .69106 .47293 L p .757 .828 .907 r
F P
0 g
s
.69106 .47293 m .70488 .46725 L .70692 .49537 L p .757 .828 .907 r
F P
0 g
s
.45278 .4484 m .46516 .44375 L .45805 .45381 L p .794 .982 .899 r
F P
0 g
s
.45805 .45381 m .4443 .46049 L .45278 .4484 L p .794 .982 .899 r
F P
0 g
s
.54709 .42732 m .5546 .42803 L .5659 .43365 L p .056 .533 .892 r
F P
0 g
s
.5546 .42803 m .54709 .42732 L .5371 .42459 L p 0 .545 .832 r
F P
0 g
s
.30651 .43838 m .32011 .44615 L .31524 .47877 L p .502 .606 .889 r
F P
0 g
s
.32893 .48443 m .31524 .47877 L .32011 .44615 L p .498 .602 .887 r
F P
0 g
s
.4765 .4351 m .48646 .43234 L .4774 .43924 L p .651 .969 .883 r
F P
0 g
s
.4774 .43924 m .46516 .44375 L .4765 .4351 L p .651 .969 .883 r
F P
0 g
s
.51199 .42389 m .51534 .42423 L .50511 .42662 L p .287 .788 .819 r
F P
0 g
s
.50511 .42662 m .49826 .4271 L .51199 .42389 L p .287 .788 .819 r
F P
0 g
s
.69315 .49884 m .67926 .50051 L .67715 .4768 L p .709 .794 .917 r
F P
0 g
s
.67715 .4768 m .69106 .47293 L .69315 .49884 L p .709 .794 .917 r
F P
0 g
s
.66525 .49999 m .65115 .49708 L .64911 .4777 L p .569 .687 .92 r
F P
0 g
s
.63504 .47463 m .64911 .4777 L .65115 .49708 L p .49 .624 .91 r
F P
0 g
s
.5371 .42459 m .5412 .42437 L .5546 .42803 L p 0 .545 .832 r
F P
0 g
s
.5412 .42437 m .5371 .42459 L .52626 .42354 L p .019 .586 .783 r
F P
0 g
s
.67926 .50051 m .66525 .49999 L .66316 .47845 L p .645 .746 .923 r
F P
0 g
s
.66316 .47845 m .67715 .4768 L .67926 .50051 L p .645 .746 .923 r
F P
0 g
s
.52665 .42296 m .52626 .42354 L .51534 .42423 L p .118 .67 .777 r
F P
0 g
s
.51534 .42423 m .51199 .42389 L .52665 .42296 L p .118 .67 .777 r
F P
0 g
s
.40263 .47373 m .41656 .4711 L .41301 .48828 L p .777 .869 .916 r
F P
0 g
s
.41301 .48828 m .39879 .49306 L .40263 .47373 L p .777 .869 .916 r
F P
0 g
s
.32011 .44615 m .33372 .45408 L .32893 .48443 L p .498 .602 .887 r
F P
0 g
s
.34269 .48956 m .32893 .48443 L .33372 .45408 L p .514 .617 .893 r
F P
0 g
s
.64911 .4777 m .66316 .47845 L .66525 .49999 L p .569 .687 .92 r
F P
0 g
s
.52626 .42354 m .52665 .42296 L .5412 .42437 L p .019 .586 .783 r
F P
0 g
s
.62099 .46958 m .60699 .46313 L .59965 .4508 L p .26 .519 .909 r
F P
0 g
s
.58691 .44574 m .59965 .4508 L .60699 .46313 L p .215 .489 .897 r
F P
0 g
s
.33372 .45408 m .34736 .46145 L .34269 .48956 L p .514 .617 .893 r
F P
0 g
s
.35656 .49348 m .34269 .48956 L .34736 .46145 L p .55 .652 .903 r
F P
0 g
s
.38872 .47403 m .40263 .47373 L .39879 .49306 L p .724 .819 .924 r
F P
0 g
s
.39879 .49306 m .38462 .49552 L .38872 .47403 L p .724 .819 .924 r
F P
0 g
s
.5659 .43365 m .5764 .43674 L .58691 .44574 L p .075 .478 .892 r
F P
0 g
s
.5764 .43674 m .5659 .43365 L .5546 .42803 L p 0 .458 .829 r
F P
0 g
s
.44029 .45236 m .45278 .4484 L .4443 .46049 L p .79 .972 .913 r
F P
0 g
s
.4443 .46049 m .43046 .4665 L .44029 .45236 L p .79 .972 .913 r
F P
0 g
s
.34736 .46145 m .36107 .4676 L .35656 .49348 L p .55 .652 .903 r
F P
0 g
s
.37053 .4956 m .35656 .49348 L .36107 .4676 L p .601 .702 .915 r
F P
0 g
s
.49132 .4285 m .49826 .4271 L .48646 .43234 L p .425 .868 .81 r
F P
0 g
s
.48646 .43234 m .4765 .4351 L .49132 .4285 L p .425 .868 .81 r
F P
0 g
s
.37486 .47193 m .38872 .47403 L .38462 .49552 L p .663 .761 .923 r
F P
0 g
s
.38462 .49552 m .37053 .4956 L .37486 .47193 L p .663 .761 .923 r
F P
0 g
s
.59965 .4508 m .58691 .44574 L .5764 .43674 L p .066 .472 .888 r
F P
0 g
s
.36107 .4676 m .37486 .47193 L .37053 .4956 L p .601 .702 .915 r
F P
0 g
s
.4664 .43798 m .4765 .4351 L .46516 .44375 L p .648 .968 .879 r
F P
0 g
s
.46516 .44375 m .45278 .4484 L .4664 .43798 L p .648 .968 .879 r
F P
0 g
s
.63504 .47463 m .62099 .46958 L .6125 .45517 L p .343 .574 .926 r
F P
0 g
s
.59965 .4508 m .6125 .45517 L .62099 .46958 L p .26 .519 .909 r
F P
0 g
s
.5546 .42803 m .56223 .42968 L .5764 .43674 L p 0 .458 .829 r
F P
0 g
s
.56223 .42968 m .5546 .42803 L .5412 .42437 L p 0 .452 .734 r
F P
0 g
s
.50858 .42446 m .51199 .42389 L .49826 .4271 L p .185 .714 .715 r
F P
0 g
s
.49826 .4271 m .49132 .4285 L .50858 .42446 L p .185 .714 .715 r
F P
0 g
s
.42772 .45491 m .44029 .45236 L .43046 .4665 L p .778 .945 .932 r
F P
0 g
s
.43046 .4665 m .41656 .4711 L .42772 .45491 L p .778 .945 .932 r
F P
0 g
s
.5412 .42437 m .54538 .42507 L .56223 .42968 L p 0 .452 .734 r
F P
0 g
s
.54538 .42507 m .5412 .42437 L .52665 .42296 L p .108 0 0 r
F P
0 g
s
.52705 .42329 m .52665 .42296 L .51199 .42389 L p .001 0 0 r
F P
0 g
s
.51199 .42389 m .50858 .42446 L .52705 .42329 L p .001 0 0 r
F P
0 g
s
.52665 .42296 m .52705 .42329 L .54538 .42507 L p .108 0 0 r
F P
0 g
s
.5764 .43674 m .58704 .43996 L .59965 .4508 L p .066 .472 .888 r
F P
0 g
s
.58704 .43996 m .5764 .43674 L .56223 .42968 L p 0 .45 .822 r
F P
0 g
s
.64911 .4777 m .63504 .47463 L .62543 .45813 L p .449 .64 .938 r
F P
0 g
s
.6125 .45517 m .62543 .45813 L .63504 .47463 L p .343 .574 .926 r
F P
0 g
s
.6125 .45517 m .59965 .4508 L .58704 .43996 L p .135 .515 .913 r
F P
0 g
s
.48427 .43002 m .49132 .4285 L .4765 .4351 L p .418 .863 .802 r
F P
0 g
s
.4765 .4351 m .4664 .43798 L .48427 .43002 L p .418 .863 .802 r
F P
0 g
s
.45619 .44016 m .4664 .43798 L .45278 .4484 L p .667 .97 .909 r
F P
0 g
s
.45278 .4484 m .44029 .45236 L .45619 .44016 L p .667 .97 .909 r
F P
0 g
s
.41509 .45547 m .42772 .45491 L .41656 .4711 L p .75 .897 .944 r
F P
0 g
s
.41656 .4711 m .40263 .47373 L .41509 .45547 L p .75 .897 .944 r
F P
0 g
s
.66316 .47845 m .64911 .4777 L .63841 .4591 L p .554 .701 .938 r
F P
0 g
s
.62543 .45813 m .63841 .4591 L .64911 .4777 L p .449 .64 .938 r
F P
0 g
s
.56223 .42968 m .56996 .43144 L .58704 .43996 L p 0 .45 .822 r
F P
0 g
s
.56996 .43144 m .56223 .42968 L .54538 .42507 L p 0 .442 .723 r
F P
0 g
s
.7736 .43383 m .75977 .43908 L .74157 .40276 L p .747 .794 .891 r
F P
0 g
s
.75977 .43908 m .74603 .4456 L .72866 .41157 L p .776 .806 .877 r
F P
0 g
s
.72866 .41157 m .74157 .40276 L .75977 .43908 L p .776 .806 .877 r
F P
0 g
s
.50512 .42514 m .50162 .42509 L .50599 .42482 L p .079 .64 .74 r
F P
0 g
s
.50512 .42514 m .50858 .42446 L .50419 .42549 L p .175 .705 .704 r
F P
0 g
s
.52745 .42372 m .52705 .42329 L .50858 .42446 L p .012 0 0 r
F P
0 g
s
.50858 .42446 m .50512 .42514 L .52745 .42372 L p .012 0 0 r
F P
0 g
s
.54961 .42588 m .56996 .43144 L p .54965 .42618 L 0 .442 .723 r
F P
0 g
s
.54538 .42507 m .54961 .42588 L p .54965 .42618 L 0 .442 .723 r
F P
0 g
s
.52745 .42372 m .54961 .42588 L p .53096 .42374 L .12 0 0 r
F P
0 g
s
.54961 .42588 m .54538 .42507 L .52705 .42329 L p .12 0 0 r
F P
0 g
s
.54961 .42588 m .52745 .42372 L p .54957 .42559 L 0 .555 .746 r
F P
0 g
s
.5539 .42596 m .54961 .42588 L p .54957 .42559 L 0 .555 .746 r
F P
0 g
s
.52705 .42329 m .52745 .42372 L p .53096 .42374 L .12 0 0 r
F P
0 g
s
.50599 .42482 m .52348 .4237 L p .50512 .42514 L .079 .64 .74 r
F P
0 g
s
.52348 .4237 m .52786 .42343 L p .52413 .42371 L .079 .64 .74 r
F P
0 g
s
.50512 .42514 m .52348 .4237 L .52413 .42371 L .079 .64 .74 r
F
.50419 .42549 m .49132 .4285 L p .50512 .42514 L .175 .705 .704 r
F P
0 g
s
.49132 .4285 m .48427 .43002 L .50512 .42514 L p .175 .705 .704 r
F P
0 g
s
.67715 .4768 m .66316 .47845 L .6514 .45773 L p .644 .748 .925 r
F P
0 g
s
.63841 .4591 m .6514 .45773 L .66316 .47845 L p .554 .701 .938 r
F P
0 g
s
.78756 .43018 m .7736 .43383 L .7546 .39522 L p .706 .775 .906 r
F P
0 g
s
.74157 .40276 m .7546 .39522 L .7736 .43383 L p .747 .794 .891 r
F P
0 g
s
.74603 .4456 m .73234 .4529 L .71581 .42115 L p .792 .812 .868 r
F P
0 g
s
.71581 .42115 m .72866 .41157 L .74603 .4456 L p .792 .812 .868 r
F P
0 g
s
.62543 .45813 m .6125 .45517 L .59779 .44249 L p .262 .589 .947 r
F P
0 g
s
.58704 .43996 m .59779 .44249 L .6125 .45517 L p .135 .515 .913 r
F P
0 g
s
.40245 .45367 m .41509 .45547 L .40263 .47373 L p .709 .832 .941 r
F P
0 g
s
.40263 .47373 m .38872 .47403 L .40245 .45367 L p .709 .832 .941 r
F P
0 g
s
.80169 .42824 m .78756 .43018 L .76779 .38926 L p .655 .749 .919 r
F P
0 g
s
.7546 .39522 m .76779 .38926 L .78756 .43018 L p .706 .775 .906 r
F P
0 g
s
.73234 .4529 m .71863 .46034 L .70299 .43086 L p .795 .813 .867 r
F P
0 g
s
.70299 .43086 m .71581 .42115 L .73234 .4529 L p .795 .813 .867 r
F P
0 g
s
.69106 .47293 m .67715 .4768 L .66436 .45393 L p .712 .78 .905 r
F P
0 g
s
.6514 .45773 m .66436 .45393 L .67715 .4768 L p .644 .748 .925 r
F P
0 g
s
.71863 .46034 m .70488 .46725 L .69016 .44 L p .784 .809 .873 r
F P
0 g
s
.69016 .44 m .70299 .43086 L .71863 .46034 L p .784 .809 .873 r
F P
0 g
s
.59779 .44249 m .58704 .43996 L .56996 .43144 L p .019 .51 .873 r
F P
0 g
s
.70488 .46725 m .69106 .47293 L .67728 .44788 L p .757 .799 .887 r
F P
0 g
s
.67728 .44788 m .69016 .44 L .70488 .46725 L p .757 .799 .887 r
F P
0 g
s
.66436 .45393 m .67728 .44788 L .69106 .47293 L p .712 .78 .905 r
F P
0 g
s
.816 .42792 m .80169 .42824 L .78117 .38502 L p .6 .719 .928 r
F P
0 g
s
.76779 .38926 m .78117 .38502 L .80169 .42824 L p .655 .749 .919 r
F P
0 g
s
.4459 .44091 m .45619 .44016 L .44029 .45236 L p .692 .957 .949 r
F P
0 g
s
.44029 .45236 m .42772 .45491 L .4459 .44091 L p .692 .957 .949 r
F P
0 g
s
.38983 .44945 m .40245 .45367 L .38872 .47403 L p .661 .762 .925 r
F P
0 g
s
.38872 .47403 m .37486 .47193 L .38983 .44945 L p .661 .762 .925 r
F P
0 g
s
.47713 .43083 m .48427 .43002 L .4664 .43798 L p .471 .894 .859 r
F P
0 g
s
.4664 .43798 m .45619 .44016 L .47713 .43083 L p .471 .894 .859 r
F P
0 g
s
.83049 .42893 m .816 .42792 L .79475 .3824 L p .551 .69 .932 r
F P
0 g
s
.78117 .38502 m .79475 .3824 L .816 .42792 L p .6 .719 .928 r
F P
0 g
s
.37724 .44297 m .38983 .44945 L .37486 .47193 L p .615 .698 .903 r
F P
0 g
s
.37486 .47193 m .36107 .4676 L .37724 .44297 L p .615 .698 .903 r
F P
0 g
s
.30179 .38757 m .31452 .39558 L .29285 .43138 L p .589 .66 .887 r
F P
0 g
s
.29285 .43138 m .2791 .42566 L .30179 .38757 L p .589 .66 .887 r
F P
0 g
s
.30651 .43838 m .29285 .43138 L .31452 .39558 L p .563 .626 .873 r
F P
0 g
s
.31452 .39558 m .32713 .40485 L .30651 .43838 L p .563 .626 .873 r
F P
0 g
s
.32011 .44615 m .30651 .43838 L .32713 .40485 L p .548 .606 .863 r
F P
0 g
s
.32713 .40485 m .33967 .41489 L .32011 .44615 L p .548 .606 .863 r
F P
0 g
s
.33372 .45408 m .32011 .44615 L .33967 .41489 L p .545 .603 .862 r
F P
0 g
s
.28889 .38115 m .30179 .38757 L .2791 .42566 L p .622 .704 .904 r
F P
0 g
s
.2791 .42566 m .26521 .42153 L .28889 .38115 L p .622 .704 .904 r
F P
0 g
s
.63841 .4591 m .62543 .45813 L .60863 .44358 L p .411 .664 .964 r
F P
0 g
s
.59779 .44249 m .60863 .44358 L .62543 .45813 L p .262 .589 .947 r
F P
0 g
s
.36469 .43464 m .37724 .44297 L .36107 .4676 L p .579 .649 .883 r
F P
0 g
s
.36107 .4676 m .34736 .46145 L .36469 .43464 L p .579 .649 .883 r
F P
0 g
s
.33967 .41489 m .35218 .42505 L .33372 .45408 L p .545 .603 .862 r
F P
0 g
s
.34736 .46145 m .33372 .45408 L .35218 .42505 L p .556 .617 .868 r
F P
0 g
s
.35218 .42505 m .36469 .43464 L .34736 .46145 L p .556 .617 .868 r
F P
0 g
s
.27581 .37644 m .28889 .38115 L .26521 .42153 L p .658 .752 .919 r
F P
0 g
s
.26521 .42153 m .25115 .41911 L .27581 .37644 L p .658 .752 .919 r
F P
0 g
s
.84512 .43086 m .83049 .42893 L .80854 .38111 L p .516 .669 .932 r
F P
0 g
s
.79475 .3824 m .80854 .38111 L .83049 .42893 L p .551 .69 .932 r
F P
0 g
s
.56996 .43144 m .57779 .43249 L .59779 .44249 L p .019 .51 .873 r
F P
0 g
s
.57779 .43249 m .56996 .43144 L .54961 .42588 L p 0 .516 .802 r
F P
0 g
s
.43554 .43963 m .4459 .44091 L .42772 .45491 L p .7 .911 .968 r
F P
0 g
s
.42772 .45491 m .41509 .45547 L .43554 .43963 L p .7 .911 .968 r
F P
0 g
s
.26252 .37334 m .27581 .37644 L .25115 .41911 L p .692 .797 .93 r
F P
0 g
s
.25115 .41911 m .2369 .41831 L .26252 .37334 L p .692 .797 .93 r
F P
0 g
s
.50162 .42509 m .50512 .42514 L .48427 .43002 L p .254 .765 .787 r
F P
0 g
s
.48427 .43002 m .47713 .43083 L .50162 .42509 L p .254 .765 .787 r
F P
0 g
s
.60863 .44358 m .59779 .44249 L .57779 .43249 L p .19 .609 .945 r
F P
0 g
s
.85986 .43317 m .84512 .43086 L .8225 .38074 L p .501 .659 .932 r
F P
0 g
s
.80854 .38111 m .8225 .38074 L .84512 .43086 L p .516 .669 .932 r
F P
0 g
s
.6514 .45773 m .63841 .4591 L .61954 .44266 L p .545 .719 .954 r
F P
0 g
s
.60863 .44358 m .61954 .44266 L .63841 .4591 L p .411 .664 .964 r
F P
0 g
s
.24903 .37159 m .26252 .37334 L .2369 .41831 L p .719 .834 .936 r
F P
0 g
s
.2369 .41831 m .22247 .41885 L .24903 .37159 L p .719 .834 .936 r
F P
0 g
s
.46991 .43017 m .47713 .43083 L .45619 .44016 L p .557 .923 .941 r
F P
0 g
s
.45619 .44016 m .4459 .44091 L .46991 .43017 L p .557 .923 .941 r
F P
0 g
s
.54961 .42588 m .5539 .42596 L .57779 .43249 L p 0 .516 .802 r
F P
0 g
s
.52786 .42343 m .52745 .42372 L .50512 .42514 L p .079 .64 .74 r
F P
0 g
s
.8225 .38074 m .8366 .38074 L .85986 .43317 L p .501 .659 .932 r
F P
0 g
s
.52745 .42372 m .52786 .42343 L .5539 .42596 L p 0 .555 .746 r
F P
0 g
s
.42514 .43599 m .43554 .43963 L .41509 .45547 L p .685 .839 .957 r
F P
0 g
s
.41509 .45547 m .40245 .45367 L .42514 .43599 L p .685 .839 .957 r
F P
0 g
s
.23536 .37074 m .24903 .37159 L .22247 .41885 L p .736 .857 .937 r
F P
0 g
s
.22247 .41885 m .20788 .4203 L .23536 .37074 L p .736 .857 .937 r
F P
0 g
s
.66436 .45393 m .6514 .45773 L .63047 .43937 L p .644 .75 .926 r
F P
0 g
s
.61954 .44266 m .63047 .43937 L .6514 .45773 L p .545 .719 .954 r
F P
0 g
s
.61954 .44266 m .60863 .44358 L .5857 .43209 L p .385 .696 .982 r
F P
0 g
s
.57779 .43249 m .5857 .43209 L .60863 .44358 L p .19 .609 .945 r
F P
0 g
s
.5857 .43209 m .57779 .43249 L .5539 .42596 L p .153 .638 .921 r
F P
0 g
s
.22154 .37026 m .23536 .37074 L .20788 .4203 L p .743 .866 .937 r
F P
0 g
s
.20788 .4203 m .19318 .42214 L .22154 .37026 L p .743 .866 .937 r
F P
0 g
s
.49807 .42357 m .50162 .42509 L .47713 .43083 L p .4 .848 .915 r
F P
0 g
s
.47713 .43083 m .46991 .43017 L .49807 .42357 L p .4 .848 .915 r
F P
0 g
s
.41474 .42987 m .42514 .43599 L .40245 .45367 L p .658 .762 .927 r
F P
0 g
s
.40245 .45367 m .38983 .44945 L .41474 .42987 L p .658 .762 .927 r
F P
0 g
s
.67728 .44788 m .66436 .45393 L .64141 .43362 L p .71 .765 .895 r
F P
0 g
s
.63047 .43937 m .64141 .43362 L .66436 .45393 L p .644 .75 .926 r
F P
0 g
s
.46265 .42748 m .46991 .43017 L .4459 .44091 L p .627 .904 .985 r
F P
0 g
s
.4459 .44091 m .43554 .43963 L .46265 .42748 L p .627 .904 .985 r
F P
0 g
s
.69016 .44 m .67728 .44788 L .65234 .42559 L p .75 .771 .87 r
F P
0 g
s
.64141 .43362 m .65234 .42559 L .67728 .44788 L p .71 .765 .895 r
F P
0 g
s
.5539 .42596 m .55824 .42457 L .5857 .43209 L p .153 .638 .921 r
F P
0 g
s
.55824 .42457 m .5539 .42596 L .52786 .42343 L p .175 .687 .897 r
F P
0 g
s
.40435 .42147 m .41474 .42987 L .38983 .44945 L p .63 .697 .894 r
F P
0 g
s
.38983 .44945 m .37724 .44297 L .40435 .42147 L p .63 .697 .894 r
F P
0 g
s
.70299 .43086 m .69016 .44 L .66325 .41568 L p .773 .772 .853 r
F P
0 g
s
.65234 .42559 m .66325 .41568 L .69016 .44 L p .75 .771 .87 r
F P
0 g
s
.52828 .42165 m .52786 .42343 L .50162 .42509 L p .262 .76 .894 r
F P
0 g
s
.50162 .42509 m .49807 .42357 L .52828 .42165 L p .262 .76 .894 r
F P
0 g
s
.71581 .42115 m .70299 .43086 L .67415 .40449 L p .782 .773 .845 r
F P
0 g
s
.66325 .41568 m .67415 .40449 L .70299 .43086 L p .773 .772 .853 r
F P
0 g
s
.63047 .43937 m .61954 .44266 L .59367 .42964 L p .543 .741 .968 r
F P
0 g
s
.5857 .43209 m .59367 .42964 L .61954 .44266 L p .385 .696 .982 r
F P
0 g
s
.52786 .42343 m .52828 .42165 L .55824 .42457 L p .175 .687 .897 r
F P
0 g
s
.72866 .41157 m .71581 .42115 L .68506 .39269 L p .779 .773 .847 r
F P
0 g
s
.67415 .40449 m .68506 .39269 L .71581 .42115 L p .782 .773 .845 r
F P
0 g
s
.39396 .41119 m .40435 .42147 L .37724 .44297 L p .608 .65 .867 r
F P
0 g
s
.37724 .44297 m .36469 .43464 L .39396 .41119 L p .608 .65 .867 r
F P
0 g
s
.74157 .40276 m .72866 .41157 L .69602 .38101 L p .766 .772 .857 r
F P
0 g
s
.68506 .39269 m .69602 .38101 L .72866 .41157 L p .779 .773 .847 r
F P
0 g
s
.59367 .42964 m .5857 .43209 L .55824 .42457 L p .38 .735 .991 r
F P
0 g
s
.45534 .42238 m .46265 .42748 L .43554 .43963 L p .656 .838 .97 r
F P
0 g
s
.43554 .43963 m .42514 .43599 L .45534 .42238 L p .656 .838 .97 r
F P
0 g
s
.7546 .39522 m .74157 .40276 L .70706 .37006 L p .741 .769 .875 r
F P
0 g
s
.69602 .38101 m .70706 .37006 L .74157 .40276 L p .766 .772 .857 r
F P
0 g
s
.38359 .39961 m .39396 .41119 L .36469 .43464 L p .593 .621 .849 r
F P
0 g
s
.36469 .43464 m .35218 .42505 L .38359 .39961 L p .593 .621 .849 r
F P
0 g
s
.4945 .41999 m .49807 .42357 L .46991 .43017 L p .543 .875 .991 r
F P
0 g
s
.46991 .43017 m .46265 .42748 L .4945 .41999 L p .543 .875 .991 r
F P
0 g
s
.3732 .38742 m .38359 .39961 L .35218 .42505 L p .587 .609 .841 r
F P
0 g
s
.35218 .42505 m .33967 .41489 L .3732 .38742 L p .587 .609 .841 r
F P
0 g
s
.76779 .38926 m .7546 .39522 L .71822 .36037 L p .704 .762 .897 r
F P
0 g
s
.70706 .37006 m .71822 .36037 L .7546 .39522 L p .741 .769 .875 r
F P
0 g
s
.36276 .37534 m .3732 .38742 L .33967 .41489 L p .588 .612 .843 r
F P
0 g
s
.33967 .41489 m .32713 .40485 L .36276 .37534 L p .588 .612 .843 r
F P
0 g
s
.64141 .43362 m .63047 .43937 L .60168 .42481 L p .645 .753 .928 r
F P
0 g
s
.59367 .42964 m .60168 .42481 L .63047 .43937 L p .543 .741 .968 r
F P
0 g
s
.35224 .36399 m .36276 .37534 L .32713 .40485 L p .598 .63 .854 r
F P
0 g
s
.32713 .40485 m .31452 .39558 L .35224 .36399 L p .598 .63 .854 r
F P
0 g
s
.78117 .38502 m .76779 .38926 L .72954 .35225 L p .655 .75 .92 r
F P
0 g
s
.71822 .36037 m .72954 .35225 L .76779 .38926 L p .704 .762 .897 r
F P
0 g
s
.55824 .42457 m .56262 .42113 L .59367 .42964 L p .38 .735 .991 r
F P
0 g
s
.56262 .42113 m .55824 .42457 L .52828 .42165 L p .406 .781 .993 r
F P
0 g
s
.34159 .35389 m .35224 .36399 L .31452 .39558 L p .614 .661 .872 r
F P
0 g
s
.31452 .39558 m .30179 .38757 L .34159 .35389 L p .614 .661 .872 r
F P
0 g
s
.44802 .41479 m .45534 .42238 L .42514 .43599 L p .655 .762 .928 r
F P
0 g
s
.42514 .43599 m .41474 .42987 L .44802 .41479 L p .655 .762 .928 r
F P
0 g
s
.5287 .41781 m .52828 .42165 L .49807 .42357 L p .463 .83 .993 r
F P
0 g
s
.49807 .42357 m .4945 .41999 L .5287 .41781 L p .463 .83 .993 r
F P
0 g
s
.60168 .42481 m .59367 .42964 L .56262 .42113 L p .549 .765 .978 r
F P
0 g
s
.52828 .42165 m .5287 .41781 L .56262 .42113 L p .406 .781 .993 r
F P
0 g
s
.33079 .34536 m .34159 .35389 L .30179 .38757 L p .635 .703 .895 r
F P
0 g
s
.30179 .38757 m .28889 .38115 L .33079 .34536 L p .635 .703 .895 r
F P
0 g
s
.79475 .3824 m .78117 .38502 L .74105 .34584 L p .597 .731 .938 r
F P
0 g
s
.72954 .35225 m .74105 .34584 L .78117 .38502 L p .655 .75 .92 r
F P
0 g
s
.65234 .42559 m .64141 .43362 L .6097 .41748 L p .704 .75 .888 r
F P
0 g
s
.60168 .42481 m .6097 .41748 L .64141 .43362 L p .645 .753 .928 r
F P
0 g
s
.4909 .41399 m .4945 .41999 L .46265 .42748 L p .623 .829 .979 r
F P
0 g
s
.46265 .42748 m .45534 .42238 L .4909 .41399 L p .623 .829 .979 r
F P
0 g
s
.31981 .33853 m .33079 .34536 L .28889 .38115 L p .658 .752 .92 r
F P
0 g
s
.28889 .38115 m .27581 .37644 L .31981 .33853 L p .658 .752 .92 r
F P
0 g
s
.4407 .40488 m .44802 .41479 L .41474 .42987 L p .645 .7 .886 r
F P
0 g
s
.41474 .42987 m .40435 .42147 L .4407 .40488 L p .645 .7 .886 r
F P
0 g
s
.66325 .41568 m .65234 .42559 L .61772 .40784 L p .738 .744 .857 r
F P
0 g
s
.6097 .41748 m .61772 .40784 L .65234 .42559 L p .704 .75 .888 r
F P
0 g
s
.80854 .38111 m .79475 .3824 L .75276 .34103 L p .541 .71 .95 r
F P
0 g
s
.74105 .34584 m .75276 .34103 L .79475 .3824 L p .597 .731 .938 r
F P
0 g
s
.56262 .42113 m .56702 .41526 L .60168 .42481 L p .549 .765 .978 r
F P
0 g
s
.56702 .41526 m .56262 .42113 L .5287 .41781 L p .566 .79 .983 r
F P
0 g
s
.30863 .33331 m .31981 .33853 L .27581 .37644 L p .679 .801 .94 r
F P
0 g
s
.27581 .37644 m .26252 .37334 L .30863 .33331 L p .679 .801 .94 r
F P
0 g
s
.6097 .41748 m .60168 .42481 L .56702 .41526 L p .646 .756 .929 r
F P
0 g
s
.52912 .41155 m .5287 .41781 L .4945 .41999 L p .592 .812 .984 r
F P
0 g
s
.4945 .41999 m .4909 .41399 L .52912 .41155 L p .592 .812 .984 r
F P
0 g
s
.67415 .40449 m .66325 .41568 L .62575 .39629 L p .756 .739 .837 r
F P
0 g
s
.61772 .40784 m .62575 .39629 L .66325 .41568 L p .738 .744 .857 r
F P
0 g
s
.43337 .39305 m .4407 .40488 L .40435 .42147 L p .634 .657 .854 r
F P
0 g
s
.40435 .42147 m .39396 .41119 L .43337 .39305 L p .634 .657 .854 r
F P
0 g
s
.48729 .40548 m .4909 .41399 L .45534 .42238 L p .653 .761 .929 r
F P
0 g
s
.45534 .42238 m .44802 .41479 L .48729 .40548 L p .653 .761 .929 r
F P
0 g
s
.5287 .41781 m .52912 .41155 L .56702 .41526 L p .566 .79 .983 r
F P
0 g
s
.8225 .38074 m .80854 .38111 L .76467 .33755 L p .498 .692 .955 r
F P
0 g
s
.75276 .34103 m .76467 .33755 L .80854 .38111 L p .541 .71 .95 r
F P
0 g
s
.68506 .39269 m .67415 .40449 L .63378 .38342 L p .762 .737 .829 r
F P
0 g
s
.62575 .39629 m .63378 .38342 L .67415 .40449 L p .756 .739 .837 r
F P
0 g
s
.42603 .37989 m .43337 .39305 L .39396 .41119 L p .627 .631 .835 r
F P
0 g
s
.39396 .41119 m .38359 .39961 L .42603 .37989 L p .627 .631 .835 r
F P
0 g
s
.29725 .32941 m .30863 .33331 L .26252 .37334 L p .695 .842 .953 r
F P
0 g
s
.26252 .37334 m .24903 .37159 L .29725 .32941 L p .695 .842 .953 r
F P
0 g
s
.69602 .38101 m .68506 .39269 L .64184 .36992 L p .761 .737 .831 r
F P
0 g
s
.63378 .38342 m .64184 .36992 L .68506 .39269 L p .762 .737 .829 r
F P
0 g
s
.61772 .40784 m .6097 .41748 L .57144 .40689 L p .696 .736 .882 r
F P
0 g
s
.56702 .41526 m .57144 .40689 L .6097 .41748 L p .646 .756 .929 r
F P
0 g
s
.41867 .3661 m .42603 .37989 L .38359 .39961 L p .624 .62 .826 r
F P
0 g
s
.38359 .39961 m .3732 .38742 L .41867 .3661 L p .624 .62 .826 r
F P
0 g
s
.8366 .38074 m .8225 .38074 L .77677 .33497 L p .479 .684 .956 r
F P
0 g
s
.76467 .33755 m .77677 .33497 L .8225 .38074 L p .498 .692 .955 r
F P
0 g
s
.57144 .40689 m .56702 .41526 L .52912 .41155 L p .648 .758 .93 r
F P
0 g
s
.70706 .37006 m .69602 .38101 L .64994 .3565 L p .751 .74 .843 r
F P
0 g
s
.64184 .36992 m .64994 .3565 L .69602 .38101 L p .761 .737 .831 r
F P
0 g
s
.48368 .39462 m .48729 .40548 L .44802 .41479 L p .659 .705 .881 r
F P
0 g
s
.44802 .41479 m .4407 .40488 L .48368 .39462 L p .659 .705 .881 r
F P
0 g
s
.52954 .40276 m .52912 .41155 L .4909 .41399 L p .65 .76 .93 r
F P
0 g
s
.4909 .41399 m .48729 .40548 L .52954 .40276 L p .65 .76 .93 r
F P
0 g
s
.2857 .3264 m .29725 .32941 L .24903 .37159 L p .704 .869 .959 r
F P
0 g
s
.24903 .37159 m .23536 .37074 L .2857 .3264 L p .704 .869 .959 r
F P
0 g
s
.41126 .35238 m .41867 .3661 L .3732 .38742 L p .624 .623 .828 r
F P
0 g
s
.3732 .38742 m .36276 .37534 L .41126 .35238 L p .624 .623 .828 r
F P
0 g
s
.52912 .41155 m .52954 .40276 L .57144 .40689 L p .648 .758 .93 r
F P
0 g
s
.71822 .36037 m .70706 .37006 L .65812 .34379 L p .731 .745 .863 r
F P
0 g
s
.64994 .3565 m .65812 .34379 L .70706 .37006 L p .751 .74 .843 r
F P
0 g
s
.62575 .39629 m .61772 .40784 L .57587 .39617 L p .722 .72 .848 r
F P
0 g
s
.57144 .40689 m .57587 .39617 L .61772 .40784 L p .696 .736 .882 r
F P
0 g
s
.40379 .33938 m .41126 .35238 L .36276 .37534 L p .629 .638 .84 r
F P
0 g
s
.36276 .37534 m .35224 .36399 L .40379 .33938 L p .629 .638 .84 r
F P
0 g
s
.77677 .33497 m .78901 .33274 L .8366 .38074 L p .479 .684 .956 r
F P
0 g
s
.48006 .38182 m .48368 .39462 L .4407 .40488 L p .659 .667 .846 r
F P
0 g
s
.4407 .40488 m .43337 .39305 L .48006 .38182 L p .659 .667 .846 r
F P
0 g
s
.72954 .35225 m .71822 .36037 L .6664 .33232 L p .699 .749 .89 r
F P
0 g
s
.65812 .34379 m .6664 .33232 L .71822 .36037 L p .731 .745 .863 r
F P
0 g
s
.57587 .39617 m .57144 .40689 L .52954 .40276 L p .685 .724 .879 r
F P
0 g
s
.27399 .32374 m .2857 .3264 L .23536 .37074 L p .708 .879 .961 r
F P
0 g
s
.23536 .37074 m .22154 .37026 L .27399 .32374 L p .708 .879 .961 r
F P
0 g
s
.39621 .3276 m .40379 .33938 L .35224 .36399 L p .637 .666 .861 r
F P
0 g
s
.35224 .36399 m .34159 .35389 L .39621 .3276 L p .637 .666 .861 r
F P
0 g
s
.52997 .39163 m .52954 .40276 L .48729 .40548 L p .673 .713 .879 r
F P
0 g
s
.48729 .40548 m .48368 .39462 L .52997 .39163 L p .673 .713 .879 r
F P
0 g
s
.63378 .38342 m .62575 .39629 L .58029 .38352 L p .735 .709 .827 r
F P
0 g
s
.57587 .39617 m .58029 .38352 L .62575 .39629 L p .722 .72 .848 r
F P
0 g
s
.52954 .40276 m .52997 .39163 L .57587 .39617 L p .685 .724 .879 r
F P
0 g
s
.47643 .36768 m .48006 .38182 L .43337 .39305 L p .657 .644 .826 r
F P
0 g
s
.43337 .39305 m .42603 .37989 L .47643 .36768 L p .657 .644 .826 r
F P
0 g
s
.74105 .34584 m .72954 .35225 L .67482 .3224 L p .655 .75 .92 r
F P
0 g
s
.6664 .33232 m .67482 .3224 L .72954 .35225 L p .699 .749 .89 r
F P
0 g
s
.38852 .31738 m .39621 .3276 L .34159 .35389 L p .647 .705 .889 r
F P
0 g
s
.34159 .35389 m .33079 .34536 L .38852 .31738 L p .647 .705 .889 r
F P
0 g
s
.64184 .36992 m .63378 .38342 L .58473 .36953 L p .74 .705 .818 r
F P
0 g
s
.58029 .38352 m .58473 .36953 L .63378 .38342 L p .735 .709 .827 r
F P
0 g
s
.58029 .38352 m .57587 .39617 L .52997 .39163 L p .703 .699 .843 r
F P
0 g
s
.53039 .37855 m .52997 .39163 L .48368 .39462 L p .682 .681 .843 r
F P
0 g
s
.48368 .39462 m .48006 .38182 L .53039 .37855 L p .682 .681 .843 r
F P
0 g
s
.47279 .35288 m .47643 .36768 L .42603 .37989 L p .657 .635 .817 r
F P
0 g
s
.42603 .37989 m .41867 .3661 L .47279 .35288 L p .657 .635 .817 r
F P
0 g
s
.64994 .3565 m .64184 .36992 L .58919 .35488 L p .738 .706 .821 r
F P
0 g
s
.58473 .36953 m .58919 .35488 L .64184 .36992 L p .74 .705 .818 r
F P
0 g
s
.75276 .34103 m .74105 .34584 L .68339 .31417 L p .598 .745 .947 r
F P
0 g
s
.67482 .3224 m .68339 .31417 L .74105 .34584 L p .655 .75 .92 r
F P
0 g
s
.38067 .30883 m .38852 .31738 L .33079 .34536 L p .657 .752 .92 r
F P
0 g
s
.33079 .34536 m .31981 .33853 L .38067 .30883 L p .657 .752 .92 r
F P
0 g
s
.52997 .39163 m .53039 .37855 L .58029 .38352 L p .703 .699 .843 r
F P
0 g
s
.58473 .36953 m .58029 .38352 L .53039 .37855 L p .711 .684 .822 r
F P
0 g
s
.46912 .33813 m .47279 .35288 L .41867 .3661 L p .657 .637 .819 r
F P
0 g
s
.41867 .3661 m .41126 .35238 L .46912 .33813 L p .657 .637 .819 r
F P
0 g
s
.65812 .34379 m .64994 .3565 L .59367 .34029 L p .731 .712 .833 r
F P
0 g
s
.58919 .35488 m .59367 .34029 L .64994 .3565 L p .738 .706 .821 r
F P
0 g
s
.53082 .36411 m .53039 .37855 L .48006 .38182 L p .686 .662 .821 r
F P
0 g
s
.48006 .38182 m .47643 .36768 L .53082 .36411 L p .686 .662 .821 r
F P
0 g
s
.37268 .30188 m .38067 .30883 L .31981 .33853 L p .663 .8 .948 r
F P
0 g
s
.31981 .33853 m .30863 .33331 L .37268 .30188 L p .663 .8 .948 r
F P
0 g
s
.76467 .33755 m .75276 .34103 L .69212 .30753 L p .538 .734 .965 r
F P
0 g
s
.68339 .31417 m .69212 .30753 L .75276 .34103 L p .598 .745 .947 r
F P
0 g
s
.53039 .37855 m .53082 .36411 L .58473 .36953 L p .711 .684 .822 r
F P
0 g
s
.46541 .32407 m .46912 .33813 L .41126 .35238 L p .658 .651 .831 r
F P
0 g
s
.41126 .35238 m .40379 .33938 L .46541 .32407 L p .658 .651 .831 r
F P
0 g
s
.58919 .35488 m .58473 .36953 L .53082 .36411 L p .714 .677 .813 r
F P
0 g
s
.6664 .33232 m .65812 .34379 L .59821 .3264 L p .717 .723 .855 r
F P
0 g
s
.59367 .34029 m .59821 .3264 L .65812 .34379 L p .731 .712 .833 r
F P
0 g
s
.53124 .34901 m .53082 .36411 L .47643 .36768 L p .687 .654 .812 r
F P
0 g
s
.47643 .36768 m .47279 .35288 L .53124 .34901 L p .687 .654 .812 r
F P
0 g
s
.46165 .31123 m .46541 .32407 L .40379 .33938 L p .66 .675 .854 r
F P
0 g
s
.40379 .33938 m .39621 .3276 L .46165 .31123 L p .66 .675 .854 r
F P
0 g
s
.53082 .36411 m .53124 .34901 L .58919 .35488 L p .714 .677 .813 r
F P
0 g
s
.59367 .34029 m .58919 .35488 L .53124 .34901 L p .714 .679 .815 r
F P
0 g
s
.36453 .29623 m .37268 .30188 L .30863 .33331 L p .663 .841 .968 r
F P
0 g
s
.30863 .33331 m .29725 .32941 L .36453 .29623 L p .663 .841 .968 r
F P
0 g
s
.77677 .33497 m .76467 .33755 L .70102 .3022 L p .49 .722 .974 r
F P
0 g
s
.69212 .30753 m .70102 .3022 L .76467 .33755 L p .538 .734 .965 r
F P
0 g
s
.67482 .3224 m .6664 .33232 L .6028 .31371 L p .692 .737 .885 r
F P
0 g
s
.59821 .3264 m .6028 .31371 L .6664 .33232 L p .717 .723 .855 r
F P
0 g
s
.53167 .33395 m .53124 .34901 L .47279 .35288 L p .686 .656 .815 r
F P
0 g
s
.47279 .35288 m .46912 .33813 L .53167 .33395 L p .686 .656 .815 r
F P
0 g
s
.45783 .29992 m .46165 .31123 L .39621 .3276 L p .66 .71 .884 r
F P
0 g
s
.39621 .3276 m .38852 .31738 L .45783 .29992 L p .66 .71 .884 r
F P
0 g
s
.59821 .3264 m .59367 .34029 L .53167 .33395 L p .709 .688 .828 r
F P
0 g
s
.53124 .34901 m .53167 .33395 L .59367 .34029 L p .714 .679 .815 r
F P
0 g
s
.53211 .31959 m .53167 .33395 L .46912 .33813 L p .685 .668 .827 r
F P
0 g
s
.46912 .33813 m .46541 .32407 L .53211 .31959 L p .685 .668 .827 r
F P
0 g
s
.68339 .31417 m .67482 .3224 L .60748 .30257 L p .655 .751 .92 r
F P
0 g
s
.6028 .31371 m .60748 .30257 L .67482 .3224 L p .692 .737 .885 r
F P
0 g
s
.35623 .29145 m .36453 .29623 L .29725 .32941 L p .66 .868 .978 r
F P
0 g
s
.29725 .32941 m .2857 .3264 L .35623 .29145 L p .66 .868 .978 r
F P
0 g
s
.78901 .33274 m .77677 .33497 L .71008 .29774 L p .468 .715 .977 r
F P
0 g
s
.70102 .3022 m .71008 .29774 L .77677 .33497 L p .49 .722 .974 r
F P
0 g
s
.53167 .33395 m .53211 .31959 L .59821 .3264 L p .709 .688 .828 r
F P
0 g
s
.6028 .31371 m .59821 .3264 L .53211 .31959 L p .7 .704 .851 r
F P
0 g
s
.45393 .29028 m .45783 .29992 L .38852 .31738 L p .657 .752 .92 r
F P
0 g
s
.38852 .31738 m .38067 .30883 L .45393 .29028 L p .657 .752 .92 r
F P
0 g
s
.53255 .30643 m .53211 .31959 L .46541 .32407 L p .681 .688 .85 r
F P
0 g
s
.46541 .32407 m .46165 .31123 L .53255 .30643 L p .681 .688 .85 r
F P
0 g
s
.69212 .30753 m .68339 .31417 L .61225 .2931 L p .604 .76 .953 r
F P
0 g
s
.60748 .30257 m .61225 .2931 L .68339 .31417 L p .655 .751 .92 r
F P
0 g
s
.34782 .287 m .35623 .29145 L .2857 .3264 L p .657 .878 .98 r
F P
0 g
s
.2857 .3264 m .27399 .32374 L .34782 .287 L p .657 .878 .98 r
F P
0 g
s
.53211 .31959 m .53255 .30643 L .6028 .31371 L p .7 .704 .851 r
F P
0 g
s
.71008 .29774 m .71927 .29362 L .78901 .33274 L p .468 .715 .977 r
F P
0 g
s
.60748 .30257 m .6028 .31371 L .53255 .30643 L p .683 .726 .883 r
F P
0 g
s
.44995 .28222 m .45393 .29028 L .38067 .30883 L p .646 .795 .954 r
F P
0 g
s
.38067 .30883 m .37268 .30188 L .44995 .28222 L p .646 .795 .954 r
F P
0 g
s
.533 .29481 m .53255 .30643 L .46165 .31123 L p .672 .717 .882 r
F P
0 g
s
.46165 .31123 m .45783 .29992 L .533 .29481 L p .672 .717 .882 r
F P
0 g
s
.70102 .3022 m .69212 .30753 L .61711 .28521 L p .546 .761 .977 r
F P
0 g
s
.61225 .2931 m .61711 .28521 L .69212 .30753 L p .604 .76 .953 r
F P
0 g
s
.53255 .30643 m .533 .29481 L .60748 .30257 L p .683 .726 .883 r
F P
0 g
s
.61225 .2931 m .60748 .30257 L .533 .29481 L p .655 .751 .92 r
F P
0 g
s
.53346 .28484 m .533 .29481 L .45783 .29992 L p .656 .752 .92 r
F P
0 g
s
.45783 .29992 m .45393 .29028 L .53346 .28484 L p .656 .752 .92 r
F P
0 g
s
.44589 .27545 m .44995 .28222 L .37268 .30188 L p .628 .831 .979 r
F P
0 g
s
.37268 .30188 m .36453 .29623 L .44589 .27545 L p .628 .831 .979 r
F P
0 g
s
.533 .29481 m .53346 .28484 L .61225 .2931 L p .655 .751 .92 r
F P
0 g
s
.71008 .29774 m .70102 .3022 L .62207 .27861 L p .496 .756 .988 r
F P
0 g
s
.61711 .28521 m .62207 .27861 L .70102 .3022 L p .546 .761 .977 r
F P
0 g
s
.61711 .28521 m .61225 .2931 L .53346 .28484 L p .615 .774 .957 r
F P
0 g
s
.53393 .27645 m .53346 .28484 L .45393 .29028 L p .629 .786 .957 r
F P
0 g
s
.45393 .29028 m .44995 .28222 L .53393 .27645 L p .629 .786 .957 r
F P
0 g
s
.44175 .26953 m .44589 .27545 L .36453 .29623 L p .609 .853 .99 r
F P
0 g
s
.36453 .29623 m .35623 .29145 L .44175 .26953 L p .609 .853 .99 r
F P
0 g
s
.53346 .28484 m .53393 .27645 L .61711 .28521 L p .615 .774 .957 r
F P
0 g
s
.71927 .29362 m .71008 .29774 L .62713 .27286 L p .473 .752 .991 r
F P
0 g
s
.62207 .27861 m .62713 .27286 L .71008 .29774 L p .496 .756 .988 r
F P
0 g
s
.62207 .27861 m .61711 .28521 L .53393 .27645 L p .565 .788 .983 r
F P
0 g
s
.5344 .26934 m .53393 .27645 L .44995 .28222 L p .593 .813 .984 r
F P
0 g
s
.44995 .28222 m .44589 .27545 L .5344 .26934 L p .593 .813 .984 r
F P
0 g
s
.43754 .26392 m .44175 .26953 L .35623 .29145 L p .599 .861 .993 r
F P
0 g
s
.35623 .29145 m .34782 .287 L .43754 .26392 L p .599 .861 .993 r
F P
0 g
s
.53393 .27645 m .5344 .26934 L .62207 .27861 L p .565 .788 .983 r
F P
0 g
s
.62713 .27286 m .63227 .26744 L .71927 .29362 L p .473 .752 .991 r
F P
0 g
s
.62713 .27286 m .62207 .27861 L .5344 .26934 L p .52 .792 .995 r
F P
0 g
s
.53489 .26309 m .5344 .26934 L .44589 .27545 L p .559 .826 .996 r
F P
0 g
s
.44589 .27545 m .44175 .26953 L .53489 .26309 L p .559 .826 .996 r
F P
0 g
s
.5344 .26934 m .53489 .26309 L .62713 .27286 L p .52 .792 .995 r
F P
0 g
s
.63227 .26744 m .62713 .27286 L .53489 .26309 L p .498 .792 .998 r
F P
0 g
s
.53539 .25714 m .53489 .26309 L .44175 .26953 L p .542 .83 .998 r
F P
0 g
s
.44175 .26953 m .43754 .26392 L .53539 .25714 L p .542 .83 .998 r
F P
0 g
s
.53489 .26309 m .53539 .25714 L .63227 .26744 L p .498 .792 .998 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000SoR]Co00?o0000ogo:oomob_l00omob_l;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`00013oR]Co2?l0000@
ogo:o`[o00006Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Boooo
o`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`1/oooo
o`Co00000onIg?h00ol0003oR]Cooh[Do`09oh[Do`_o00001on?doh00ol0003oQL[nohG:oP03ohG:
oP[o00002omob_l7o`0001;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[oooo
o`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Ioooool4o`0000KoVMcn0ol00003oh[Do`?o00003on?doh8o`0000ooQL[n2Ol00005ogo:o`04
o`000?mi`?goNL3mogW0o@?o00003oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02[ooooo000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Rooooo`Co00001_nIg?h4o`0000;oVm[m00?o0000ohoCo_n?doh02On?doh:o`0000Oo
Um3k00?o0000oi39non@bO/00on@bO/9o`0000[oQL[n1Ol00007ogW0o@?o00003?ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`Co00001_nIg?h4o`0000GoVm[m
0ol00003ohoCoP?o00003_nGd?/8o`0000koT<Wk2Ol00004ohG:oP04o`000?mn`OcoO/7logk1o0So
NL3m0ol00009ooooo`03o`000?oooooooooo02oooooo0_l0000[ooooo`007Oooool00ol0003ooooo
ooooo`03ooooo`?o00002?ooool00ol0003oooooooooo`1Hooooo`Co00001_nIg?h4o`0000GoVm[m
1?l00002oj3DnP03o`000?nGd?_oUm3k00SoUm3k2_l00007oj79m003o`000?nMa_CoWLKd00;oWLKd
2Ol0000:oi39n`Co00001omn`O`00ol0003oNL3mogW0o@05ogW0o@?o00001_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo02Sooooo000Kooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`Co00001onIg?h3o`0000GoVm[m1?l0
0005oj3DnP?o00000_nGd?/4o`0001CoXLWd00?o0000oig6m?nMa_@02onMa_@9o`0000CoT<Wk00?o
0000oh_2n_n;`_X02?mn`O`2o`0000KoNL3m0ol00004ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0:?ooool002?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?
ooooo`?o00002?nIg?h3o`0000CoVm[m1?l00005oj3DnPCo00000onUbo@00ol0003oXLWdoj79m00;
oj79m0go00005_nMa_@4o`0000KoRl;j0_l00006ogk1o0Co00001?mi`?d3o`000003ooooool0003o
oooo03;ooooo00?o0000ooooooooool09oooool002?ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1<ooooo`;o00000onXh?X00ol0003oVMcnoiWLoP02oiWLoP;o00001OnKf_d2o`00
00KoX=Cj1?l00006ojG;m0?o00000_nQbO@:o`0000coYl3[00?o0000ojO0jonW`>/01?nW`>/<o`00
00KoWLKd00Go0000oi[2lonJ`_?oV/;co`000007oh_2nP?o00001Omn`O`3o`0000CoNL3m0ol0000c
ooooo`03o`000?oooooooooo02Kooooo000Sooooo`;o00003Oooool00ol0003oooooooooo`19oooo
o`;o00001OnXh?X4o`0000GoVm[m00?o0000oj3Dn_nPe?X01?nPe?X4o`0000KoYL_d1?l00002ojS0
j`03o`000?nW`>_oYl3[01GoYl3[00?o0000ojO0jonW`>/04OnW`>/6o`0000OoV/;c0ol00006oh_2
nP?o00001?mn`O`3o`0000;oNL3m00?o0000ogW0oOl000000_l0000`ooooo`03o`000?oooooooooo
02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2o`0000Go
Z>3j0_l00003ojSNnP;o000000?oVm[moj3Dn_nPe?X01OnPe?X3o`0000KoYL_d1?l00006ojS0j`03
o`000?nW`>_oYl3[00ooYl3[1ol0000HojO0j`04o`000?nW`>_oYl3[o`0000OoV/;c1?l00005oh_2
nPCo00000omn`O`3o`0000CoNL3m0_l0000^ooooo`;o00009oooool002?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`13ooooo`;o00001OnXh?X2o`0000?oZ=kj0_l00002ojWGm`03
o`000?nPe?[oX=Cj00;oX=Cj0_l00007ojG;m0?o00002onX`>/00ol0003oYl3[ojO0j`04ojO0j`[o
00001_n/]n400ol0003o[[WRojjihP04ojjihPco00001OnW`>/00ol0003oYl3[ojO0j`04ojO0j`?o
00001_nJ`_<3o`0000KoRl;j0ol00002ogk1o0Co00000omg]oX2o`0002kooooo00?o0000oooooooo
ool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`10ooooo`;o0000
1OnXh?X2o`0000?oZ=kj0_l00004ojWGm`?o00002?nUbo@3o`0000coZ<3[0ol000000onW`>_o0000
o`000002o`00017o[;OQ00?o0000ojjih_n^^N804?n^^N86o`0000WoYl3[1?l00005oi[2l`?o0000
1_n;`_X3o`0000?oOKSi1Omg]oX2o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nXh?[oZ>3j00?oZ>3j0_l0
0003ojSNnP;o00001?nYeoL2o`0000?oZLcb00?o0000ojG;m?nUbo@00_nUbo@2o`0000_oZ<3[1Ol0
0002ojRehP03o`000?n/]n7o[;OQ01Co[;OQ00?o0000ojjih_n^^N805On^^N801?l0003o/KcRok6l
h_l0000:ojO0j`?o00001OnJ`_<3o`0000;oRl;j00Co0000ohVkmol0003o00001Omm^?T5ogNgnP03
o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool002;ooooo0_l0000Cooooo`03o`00
0?oooooooooo03_ooooo0_l00004ojSPnP;o00000onXg_X2o`0000CoZMOg0_l00005ojW<lP?o0000
2onX`>/4o`0000SoZ;GR00?o0000ojbghOn/]n402?n/]n4<o`0000Go[[WR00?o0000ojjih_n^^N80
3_n^^N800ol0003o/KcRok6lhP04ok6lhP?o00002?nW`>/3o`0000GoV/;c1?l000001?n9^oOo0000
ohVkmon9^oL4ogfhn@;o00000omg]oX2o`0002_ooooo00?o0000ooooooooool08_ooool002;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`;o00001?nXh?X2o`0000?oZ=kj
0_l00004ojWGm`;o00001OnYc?82o`000003ojS0jol0003oZ<3[00OoZ<3[1?l0000:ojRehP?o0000
00?o[;OQo`000?l000001ol0000;ojj`f@03o`000?nc]=Wo/kCI00Co/kCI2ol00005ojjihP03o`00
0?na_>;o/KcR00Oo/KcR0ol00008ojO0j`Ko00000_nI__83ohVkm`04o`000?n9^oOoRK_gohVkm`Co
OKSi0_l00003ogNgnP;o0000:Oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03Gooooo0_l00004ojSPnP;o00000onXg_X2o`0000CoZMOg
0_l00005ojW<lP;o00001?nX`>/01?l0003oZ<3[ojS0jonX`>/4o`0000[oZ;GR1?l00002ojR/fP03
o`000?n^/=Wo[[3I01?o[[3I00?o0000ok>dfOnc]=T03onc]=T5o`0000go/KcR0ol00005ojO0j`Go
00001OnI__800ol0003oRK_go`000003ohVkm`;o00000omm^?T2o`0000?oMkOj0_l0000Wooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0boooo
o`;o00001?nXh?X2o`0000?oZ=kj0_l00004ojWGm`;o00001OnYc?82o`0000KoZ<3[0ol0000;ojRe
hPCo00001_nX[=X00ol0003o[[3Iojj`f@0Cojj`f@03o`000?nc]=Wo/kCI01?o/kCI00?o0000okNi
f_ng^MX00_l0000<ok6lhPGo00000onW`>/00ol0003oYko[ojNoj`06oiVnlP;o00001?n9^oL2o`00
00?oOKSi00?o0000ogNgn_mg]oX00_mg]oX2o`0002Oooooo00?o0000ooooooooool01Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo000Qoooo
o`?o00005oooool00ol0003oooooooooo`0_ooooo`;o00001OnXh?X00ol0003oZ=kjojSNnP02ojSN
nP03o`000?nYeoOoZMOg00;oZMOg0_l00005ojW<lP;o00001_nX`>/2o`0000;oYKCS00?o0000ojRe
h_nX]N801OnX]N84o`0000_oZ:cJ00?o0000ojj`fOn^/=T02?n^/=T;o`0001Go/kCI00?o0000okNi
f_ng^MX00ong^MX3o`0000Oo/KcR0ol000001_na_>;o0000o`000?l0003oYl3[o`0000GoYko[00?o
0000oiVnl_nI__800_nI__83o`0000CoRK_g0_l00002ogfhn@;o00001?mg]oX2o`0002Gooooo00?o
0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0oooool0027ooooo00?o0000ooooooooool06?ooool2o`0002gooooo1?l00003ojSPnP03o`000?nX
g_[oZ=kj00;oZ=kj00?o0000ojWGmonYeoL00_nYeoL2o`0000KoZLcb00?o0000ojS0jonX`>/01?nX
`>/2o`0000GoYKCS00?o0000ojReh_nX]N800_nX]N82o`0000goZ:cJ0ol000000on^/=Wo0000o`00
0007o`0000[o[j_C00?o0000okF`done/=<00one/=<;o`0000Co/kCI00?o0000okNif_ng^MX01ong
^MX7o`0000Oo/KcR00?o0000ojNojonW_n/01_nW_n/01ol0003oVKkboiVnl_nI__;o0000oiVnl_l0
00001On9^oL2o`0000;oOKSi0_l00004ogNgnP03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Yooooo`03o`000?nehOKo
]N7f00;o]N7f1?l00002ojSNnP03o`000?nYeoOoZMOg00?oZMOg00?o0000ojW<l_nYc?801?nYc?82
o`0000GoZ<3[0_l00007ojFdh`?o00003OnX[=X4o`0000;oZ:KD00?o0000ojn[don_Zm<04_n_Zm<0
0ol0003o]K3CokF`d`0>okF`d`Go00002_ng^MX6o`0000Ko/KcR00Co0000ok:ohonb_n?o00001onW
_n/2o`0000;oVKkb00Co0000oiVnl_l0003o00001On9^oL01?l0003oOKSiogfhnOmm^?T2o`0000?o
MkOj0_l0000Tooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09oooool00ol0003o]N7fokGQmP02okGQmP04o`000?ndg_Go]=keokCNm@Co00000onY
eoL00ol0003oZLcbojW<lP04ojW<lP;o00001OnX`>/2o`0000OoYKCS0_l000000onSZ]co0000ojR/
fP09ojR/fPCo00001_nXY]@00ol0003o[j_Cojn[d`0Bojn[d`03o`000?ne/=?o]K3C01;o]K3C00?o
0000ok^feOnk]]D00ol00002okNifP?o00001_ng^MX3o`0000;o/KcR00?o0000ok:ohonb_n<00onb
_n<2o`0000KoYko[0_l000001?nI__;o0000oiVnl_nI__82o`0000CoRK_g0_l00003ogfhn@03o`00
0?mg]o[oMkOj00;oMkOj0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`000?oooooooooo02Go
oooo00?o0000okGQm_nehOH00_nehOH01Ol0003o]=keokCNmOndg_Go000000Co/MOc0ol00005ojW<
lP;o00001OnX`>/2o`0000KoYKCS0ol00004oj>Zg003o`000?nX[=[oZ:cJ00CoZ:cJ0ol0000;ojRV
e003o`000?n_Zm?o[j_C00co[j_C1_l00004okF`d`03o`000?ne/=?o]K3C00co]K3C00?o0000ok^f
eOnk]]D00onk]]D6o`0000Wo]kWJ0_l00008ok:oh`;o00001_nW_n/2o`0000CoVKkb0_l00004ohVk
m`;o00000_mm^?T2o`0000;oMkOj0ol0000Pooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01oooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0S
ooooo`03o`000?nehOKo]N7f00;o]N7f00Go0000okCNmOndg_Go]=keo`000004ok7Gl`04o`000?n]
cO3o[Lg`ojg=l0;o00000_nYc?800ol0003oZ<3[ojS0j`03ojS0j`;o00001_nU]><2o`0000OoXj[L
00Co0000ojR/f_nX[=[oZ:cJ0ol0000>ojRVe003o`000?n_Zm?o[j_C00;o[j_C2_l00005ojnWd003
o`000?nf[M3o]Zg@00?o]Zg@2Ol00005okF`d`03o`000?nk]]Go^kKE00?o00001_nk]]D3o`0000Oo
]kWJ00?o0000ok^ng?l000002?nb_n<2o`0000KoYko[0_l00004oiVnlP;o00000_n9^oL8o`0000?o
NZod00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Kooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?nehOKo]N7f00;o]N7f00Go0000okCNmOndg_Go]=keo`000004ok7Gl`03o`000?n]
cO3o[Lg`00?o[Lg`0ol00004ojS0j`;o00001_nU]><2o`0000WoXj[L0ol0000@ojRVe0?o000000Co
[j_Co`000?l0003o00003on_Ym000ol0003o]Zg@okJ]d00<okJ]d0So00003?nk]]D4o`0000;o]kWJ
00?o0000ok^ng?nk_]`00_nk_]`2o`0000Oo/[oS00?o0000ojNojonW_n/01?nW_n/2o`0000CoVKkb
0ol00003ohZel`05o`000?mo/OCoOk7dognam?l000001?mj[o@00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01cooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07oooool00ol0003o
]N7fokGQmP02okGQmP05o`000?ndg_Go]=keokCNmOl000001?naeo<00ol0003o[Lg`ojg=l003ojg=
l005o`000?nX`>_oZ<3[ojS0jol000000_nX`>/00ol0003oYKCSojFdh`04ojFdh`;o00002OnSZ]`2
o`000003oj6Seol0003oZ:KD00_oZ:KD1Ol00002ojRSd@03o`000?n_Ym3o[jO@017o[jO@00?o0000
okJ]d?nf[M003_nf[M03o`0000;o_;CB0ol0000>ok^fe@;o00001onk_]`2o`0000Ko/[oS0_l00004
ojNoj`06o`000?nW_n_o0000o`000?nI__;o00000onH^o04ohZel`05o`000?mo/OCoOk7dognam?l0
00001?mj[o@00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool07Oooool00ol0003o]N7fokGQmP02okGQmP05o`000?ndg_Go]=keokCN
mOl000001?naeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[0ol00004ojFd
h`?o00002OnSZ]`2o`0000CoXJ?G00?o0000ojRVe?nXY]@01OnXY]@4o`0000SoZ:?A00?o0000ojnW
d?n_Ym004?n_Ym000ol0003o]Zg@okJ]d00;okJ]d0?o00000_nf[M000ol0003o_;CBokbddP03okbd
dPCo00002onk]]D00ol0003o`;gGo`000007ok^ng0?o00001Onb_n<2o`0000?oYko[00Co0000ojNo
jol0003o00001OnH^o04ohZel`05o`000?mo/OCoOk7dognam?l000001?mj[o@00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo01_ooooo00Co0000okGQm_nehOKo]N7f
0_l00002okCNm@;o00001?naeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[
00Go0000oj:ciOnR/nGoX[?Uo`000002ojFdh`03o`000?nSZ]coXj[L00SoXj[L0_l00006oj6Se`04
o`000?nXY]CoZ:KDojRVe0Co00003?nXXm400ol0003o[jO@ojnWd007ojnWd0[o00000_nf[M03o`00
00Go]Zg@0ol00004okJ]d003o`000?nl]=;o_;CB00So_;CB1?l00006ok^fe@03o`000?o0_MOo`;gG
00;o`;gG00?o0000ok^ng?nk_]`01_nk_]`2o`0000Go/[oS0_l000000onW_n_o0000o`000002ojNo
j`03o`000?nH^o3oV;_`00?oV;_`1?n:]O<01Ol0003oOk7dognam?mo/OCo000000CoNZod00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`008?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01Wooooo00Go0000okGQm_nehOKo]N7fo`000003okCNm@03o`000?naeo?o
/MOc00?o/MOc00?o0000ojg=l?n]cO000on]cO000ol0003oZ<3[ojS0j`02ojS0j`03o`000?nR/nGo
X[?U00;oX[?U0_l0000:oj>Zg0;o00002?nQXmL3o`00013oZ:?A0ol000000on_Ym3o0000o`000005
o`0000Wo[jO?00?o0000okJ]d?nf[M000onf[M09o`0000?o]Zg@00?o0000okbdd_nl]=803?nl]=83
o`0000;o^kKE00?o0000ol2meoo0_ML01?o0_ML2o`0000So^kkL0_l00005ok:oh`04o`000?nW_n_o
Yko[o`0000;oYko[00?o0000oiRkl?nH^o000onH^o001Ol0003oR[GcohZelon:]O?o000000?oOk7d
00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0Looooo`03o`000?oooooo000001_ooooo
000Pooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05oooool01Ol0003o]N7fokGQ
m_nehOKo000000Co]=ke1Onaeo<00ol0003o[Lg`ojg=l003ojg=l003o`000?nX`>_oZ<3[00;oZ<3[
00?o0000oj:ciOnR/nD00_nR/nD01?l0003oWJWOoifYgol00007oj>Zg0;o00002?nQXmL2o`000003
oinOdol0003oZ:?A00coZ:?A1?l00002ojRRd@03o`000?n_Yloo[jO?00oo[jO?00?o0000okJ]d?nf
[M000_nf[M03o`0000Oo]Zg@1?l0000AokbddP;o00002Oo0_ML2o`0000So^kkL0_l000001onb_n?o
0000okC3iOnd`nGo0000ojNojol000000onW_n/00ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?o
R[GcohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_m003o`000?oooooooooo01gooooo00?o
0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0E
ooooo`05o`000?nehOKo]N7fokGQm_l000001?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`0_l0
0004ojS0j`03o`000?nR/nGoX[?U00;oX[?U00?o0000oifYgonMZMl00_nMZMl00ol0003oXj[Loj>Z
g002oj>Zg0;o00002?nQXmL2o`0000CoWioC00?o0000ojRSdOnXXm401OnXXm45o`0000KoZ:;A00?o
0000ojnWcon_Yll03on_Yll00ol0003o]Zg@o`000002o`0000go]Zg@00?o0000okfddOnm]=401?l0
000<okbddP03o`000?o2_=Co000000Wo`;gG00?o0000ok^ng?nk_]`01onk_]`00ol0003o]<?UokC3
i@02okC3i@03o`000?nW_n_o000000?oYko[00?o0000oiRkl?nH^o000onH^o001Ol0003oR[GcohZe
lon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Sooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Cooooo`03o`000?ne
hOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0jonX`>/00_nX
`>/2o`0000CoX[?U00?o0000oifYgonMZMl01?nMZMl01?l0003oXj[Loj>Zg?l00007oj6Se`?o0000
1onOWm<01?l0003oZ:?AojRSdOnXXm43o`0000coZ:;A00?o0000ojnWcon_Yll03On_Yll3o`00013o
]Zg@00?o0000okfddOnm]=401?nm]=45o`0000Ko_;CB00?o0000ol:le?o2_=@00_o2_=@2o`0000Oo
`;gG0_l00006ok^ng003o`000?nma=oo000000Co]<?U00?o0000ojNojol000000onW_n/00ol0003o
V;_`oiRkl003oiRkl005o`000?n:]O?oR[GcohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_
m003o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool001oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Aooooo`03o`000?nehOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03
o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0jonX`>/00_nX`>/00ol0003oX[?Uoj:ci@03oj:ci@03
o`000?nMZMooWJWO00GoWJWO0_l00007oj6Se`;o00002_nOWm<3o`00013oZ:;A00?o0000ojnWcon_
Yll01_n_Yll9o`0000;o]Zg@1ol00007okJ]d003o`000?nm]=7o_KCA00[o_KCA1?l00002okbddP03
o`000?o2_=Co`[cD00Co`[cD0_l00007ol2me`;o00000onk_]`01Ol0003o_LCOokg4gonma=oo0000
00Co]<?U00?o0000ojNojol000000onW_n/00ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?oR[Gc
ohZelol000000omo/O@00ol0003oNZodogZ_m002ogZ_m003o`000?oooooooooo01cooooo00?o0000
ooooooooool05oooool001oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0?oooo
o`03o`000?nehOKo]N7f00;o]N7f1?ndg_D5ok7Gl`03o`000?n]cO3o[Lg`00;o[Lg`00?o0000ojS0
jonX`>/00_nX`>/00ol0003oX[?Uoj:ci@03oj:ci@03o`000?nMZMooWJWO00GoWJWO00Co0000oiVQ
f_nIXM[o00001?nQXmL2o`0000[oWioC0_l000000onOW]?o0000ojRRd@0>ojRRd@_o00000_n_ZM83
o`0000?o[jWB00?o0000okJ_d_nf[m801onf[m88o`00013o_KCA0_l00009ol:le003o`000?o0_MOo
`;gG00Ko`;gG00?o0000ok^ng?l000001Onma=l00ol0003o]<?UokC3i@02okC3i@;o00001?nW_n/0
0ol0003oV;_`oiRkl003oiRkl005o`000?n:]O?oR[GcohZelol000000omo/O@00ol0003oNZodogZ_
m002ogZ_m003o`000?oooooooooo01_ooooo0_l0000Hooooo`007oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00gooooo3?l00003ok7Gl`Co[Lg`00?o0000ojS0jonX`>/00_nX`>/0
0ol0003oX[?Uoj:ci@03oj:ci@03o`000?nMZMooWJWO00GoWJWO00?o0000oiVQf_nIXMX00_nIXMX0
1?l0003oXJ?Goj6Seol0000:oinOd`;o00001?nOW]<00ol0003oZ:;AojRRd@08ojRRd@Co00000_nX
Y=<00ol0003o[jWBojnYdP05ojnYdP?o00001_n_ZM800ol0003o]ZoBokJ_dP0>okJ_dP03o`000?nl
]M?o_;GC00?o00003?nm]=400ol0003o`kcDo`000008ol:le0;o00001oo0_ML00ol0003o_LCOokg4
g`05okg4g`03o`000?nd`nGo]<?U00;o]<?U0_l00004ojNoj`03o`000?nH^o3oV;_`00?oV;_`00Go
0000ohZelon:]O?oR[Gco`000003ognam003o`000?mj[oCoNZod00;oNZod00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00cooooo00Go0000okkMkonngNoo_]g_o`000003okcKk`04o`000?nheNoo^=G_okSEk`Co
00000on]cO05ojS0j`GoX[?U00?o0000oifYgonMZMl01OnMZMl00ol0003oVJ7JoiVQfP03oiVQfP;o
00002OnOWm<3o`0000KoWikC00?o0000ojRRdOnXX]401?nXX]44o`0000KoZ:CC00?o0000ojnYd_n_
ZM800_n_ZM83o`0000Wo[jWB00?o0000okJ_d_nf[m803Onf[m800ol0003o_;GCokbed`04okbed`?o
00002?nm]=401?l0003o`kcDol>le?o3_=@2o`0000So`[cD0_l00004ol2me`03o`000?o4aM_oa<GK
00Oo_LCO00?o0000okC3iOnd`nD00_nd`nD2o`0000CoYko[00?o0000oiRkl?nH^o000onH^o001Ol0
003oR[GcohZelon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Gooooo000Oooooo`;o0000;Oooool00ol0003oooooooooo`0:oooo
o`05o`000?nngNoo_]g_okkMkol000000onlfnl00ol0003o^=G_okSEk`03okSEk`03o`000?nac>ko
/Lc^00Co00000onX`>/5oj:ci@03o`000?nMZMooWJWO00GoWJWO00?o0000oiVQf_nIXMX00onIXMX0
0ol0003oUYcGo`000007oinOd`;o00002OnOW]<00ol0003oZ:;AojRRd@04o`0000_oZ:CC1?l00004
ojnYdPWo00000_nf[m82o`0000_o]ZoB00?o0000okbedonl]M<01onl]M<3o`0000Co_KCA00?o0000
ol>le?o3_=@01?o3_=@2o`0000So`[cD0_l000000oo0_MOo0000olC5f`03olC5f`03o`000?nma=oo
_LCO00Co_LCO00?o0000okC3iOnd`nD00_nd`nD2o`0000CoYko[00?o0000oiRkl?nH^o000onH^o00
1Ol0003oR[GcohZelon:]O?o000000?oOk7d00?o0000ogZ_m?mj[o@00_mj[o@00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Cooooo000Nooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool02Oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00?o
0000ok7<k_nac>h00_nac>h00ol0003oZ<3[ojS0j`03o`0000CoX[?U00?o0000oifYgonMZMl01?nM
ZMl2o`0000GoVJ7J00Go0000oiJLeonFW=OoUYcGo`000004oinOd`;o00002onOW]<3o`0000goZ:CC
0ol000000on_ZM;o0000o`000004o`0000So[ZkG00?o0000ok>beonc/]L00_nc/]L7o`0000Co]ZoB
00?o0000okbedonl]M<02_nl]M<3o`000003okfddOl0003o`kcD00Oo`kcD00?o0000ol:le?o2_=@0
1oo2_=@00ol0003oa<GKolC5f`04olC5f`03o`000?nma=oo_LCO00Co_LCO00?o0000okC3iOnd`nD0
0_nd`nD00ol0003oYko[ojNoj`03ojNoj`04o`000?nH^o3oV;_`oiRkl13o00007Oooool00ol0003o
ooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo
00Go0000okkMkonngNoo_]g_o`000003okcKk`03o`000?nheNoo^=G_00?o^=G_00Go0000ok7<k_na
c>ko/Lc^o`000004ojS0j`04o`000?nO]>Oo0000o`0000;oX[?U1_nMZMl00ol0003oVJ7JoiVQfP04
oiVQfP03o`000?nFW=OoUYcG00?oUYcG00Co0000oinOdonOWm?o00002onOW]<2o`000003oj2QeOl0
003oZ:CC00WoZ:CC1?l00002ojRZf003o`000?n^[]Oo[ZkG00go[ZkG00?o0000ok>beonc/]L02Onc
/]L4o`00013o_;GC00?o0000ol>le?o3_=@02?o3_=@2o`0000Ko`[cD00?o0000olO5f?l000001_o4
aM/00ol0003o_LCOokg4g`04okg4g`03o`000?nd`nGo]<?U00;o]<?U00?o0000ojNojonW_n/00_nW
_n/4o`0000;oVKS]1?n=/>h4ohB[kPGoP:S^00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Cooooo`007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Gooooo00Go0000
okkMkonngNoo_]g_o`000004okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_nac>ko/Lc^
o`000004ojS0j`03o`000?nO]>OoWkCW00;oWkCW0_l00005oifYg`03o`000?nIXM[oVJ7J00?oVJ7J
0_l00006oiJLe`;o00002onOW]<2o`0000CoX:7E00?o0000ojRTdonXY=<01?nXY=<4o`0000GoZ:[H
00?o0000ojj^eon^[]L03?n^[]L00ol0003o/k;Gok>be`0=ok>be`03o`000?nh^=Wo^;SI00Co0000
2_nl]M<01?l0003o`KgFo`000?l00009ol>le0;o00000oo2_=@01Ol0003oalGHolO5f?o7aMSo0000
00Koa<GK00?o0000okg4gonma=l01?nma=l00ol0003o]<?UokC3i@02okC3i@05o`000?nW_n_o0000
o`000?nW_n/01_nI^>d4ohf`kPCoQ:_^1On0Z>h00ol0003oooooooooo`0Iooooo`03o`000?oooooo
000001Cooooo000Nooooo`?o0000<Oooool2o`0000Gooooo00Go0000okkMkonngNoo_]g_o`000003
okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000ok7<k_nac>h00_nac>h01Ol0003oZ<3[ojS0jonX
`>_o000000GoWkCW00?o0000oiJXhol000000onMZMl00ol0003oVJ7JoiVQfP03oiVQfP03o`000?nF
W=OoUYcG00GoUYcG00Co0000oiJKeonFVmOo00001onOW]<3o`0000KoX:7E00Co0000ojRTdonXY=?o
Z:CC1?l00009ojRZf003o`000?n^[]Oo[ZkG00Co[ZkG2?l00003ok>be`03o`000?nc/]Oo/k;G00Wo
/k;G00?o0000okRhfOnh^=T01?nh^=T3o`0000Ko_;GC00?o0000ol6me_o1_MH00_o1_MH2o`0000Wo
`kcD00?o0000ol:le?l000001Oo7aMP00ol0003oa<GKolC5f`04olC5f`03o`000?nma=oo_LCO00Co
_LCO00?o0000okC3iOnd`nD00ol00004ojNoj`GoVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[
kP03o`000?n0Z>koP:S^00;oP:S^00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aoooo
o`007_ooool00ol0003oooooooooo`0cooooo`05o`000?ooooooooooooooool000000onngNl00ol0
003o_=__okcKk`02okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_nac>ko/Lc^o`000004
ojS0j`03o`000?nO]>OoWkCW00;oWkCW00Oo0000oiJXhonFZ>?oUZSSo`000?nMZMoo000000GoVJ7J
00?o0000oiJLeonFW=L01OnFW=L00ol0003oUY_GoiJKe`02oiJKe`03o`000?nOW]?oWikC00;oWikC
0_l00009oj2Qe@Go00002_nXZ]P3o`000003ojj^eol0003o000000?o00001on/]^400ol0003o[kWQ
ojnih@02ojnih@Oo00000onc/]L00ol0003o^;SIokRhf@08okRhf@Co00000_nl]M<00ol0003o`KgF
ol6meP04ol6meP?o00001oo3_=@00ol0003oalGHolO5f005olO5f003o`000?o4aM_oa<GK00Coa<GK
00?o0000okg4gonma=l00onma=l3o`0000;o]<KW00?o0000ojNojonW_n/00_nW_n/00ol0003oVKS]
oiVhk@02oiVhk@03o`000?n=/>koSK3^00;oSK3^1?n4Znh00ol0003oP:S^oh2XkP02oh2XkP03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool04Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00000_nngNl00ol0003o
_=__okcKk`02okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000ok7<k_nac>h00_nac>h01Ol0003o
Z<3[ojS0jonX`>_o000000GoWkCW00?o0000oiJXhonFZ><00_nFZ><2o`0000CoVJ7J00?o0000oiJL
eonFW=L01OnFW=L00ol0003oUY_GoiJKe`04oiJKe`04o`000?nOW]?oWikCo`0000SoX:7E1Ol00008
ojRZf0Go00000_nX]>400ol0003o[;KQojbfh@0;ojbfh@03o`000?n_^N7o[kWQ00Wo[kWQ1?l0000>
okRhf@;o00002_o1_MH2o`0000Co`kcD00?o0000olS5f?o8aMP01oo7aMP00ol0003oa<GKolC5f`04
olC5f`06o`000?nma=oo_LCOokg4gol0003o_l_T1Onda^L00ol0003oYko[ojNoj`02ojNoj`03o`00
0?nI^>goVKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[kP03o`000?n0Z>koP:S^00;o
P:S^00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`004oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=_ooool2o`0000?o_]g_00Go0000okcKkonl
fnoo_=__o`000005okSEk`05o`000?nac>ko/Lc^ok7<k_l000001?nX`>/00ol0003oWkCWoindi`02
oindi`03o`000?nFZ>?oUZSS00?oUZSS0_n@X=l2o`0000;oVJ7J1onFW=L00ol0003oUY_GoiJKe`05
oiJKe`;o00002?nPXMD4o`0000?oXZSJ00Co0000ojRZf?nXZ]SoZ:[H1?l00007ojRdh@03o`000?n/
]^7o[;KQ00_o[;KQ00?o0000ojnihOn_^N403?n_^N400ol0003o/[cQok:lh@05o`0000Oo^;SI00?o
0000okbnfonl_]/00_l00009ol6meP;o000000?o`kcDo`000?o8aMP00oo8aMP00ol0003oalGHolO5
f004olO5f003o`000?o4aM_oa<GK00Coa<GK00?o0000okg4gol000000onobn@4okC6i`;o00000onW
_n/00ol0003oVKS]oiVhk@02oiVhk@03o`000?n=/>koSK3^00;oSK3^00Co0000ohB[k_n4Znko0000
1?n0Z>h00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo1?l000000ol@413ooooo
ooooo`02ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0
=oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00Go0000ok7<k_na
c>ko/Lc^o`000004ojS0j`03o`000?nO]>OoWkCW00;oWkCW00?o0000oiJXhonFZ><00onFZ><00ol0
003oT:3Ooi2Pg`02oi2Pg`03o`000?nFW=OoUYcG00GoUYcG00?o0000oiJKeonFVmL01OnFVmL01?l0
003oUikIoiNNfOl00005oj2Qe@?o00001_nRZ=X3o`0000goZ;CQ00?o0000ojbfhOn/]^401?n/]^47
o`0000?o[kWQ1?l00006ojnih@03o`000?nb_>7o/[cQ00Ko/[cQ1?l00002okRhf@03o`000?nl_]_o
_;kK00?o_;kK0_l00009ol6meP03o`000?o8aMSob<GH00Cob<GH00?o0000olO5f?o7aMP01?o7aMP0
0ol0003oa<GKolC5f`03olC5f`;o00001?nobn@00ol0003o]<KWokC6i`02okC6i`;o00000onW_n/0
0ol0003oVKS]oiVhk@02oiVhk@05o`000?n=/>koSK3^ohf`k_l000000on4Znh00ol0003oP:S^oh2X
kP02oh2XkP03o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo000C
ooooo`05o`000?ooooooooooooooool000001Oooool2o`0003Oooooo00Go0000okkMkonngNoo_]g_
o`000003okcKk`03o`000?nheNoo^=G_00?o^=G_00Go0000ok7<k_nac>ko/Lc^o`000003ojS0j`03
o`000?nO]>OoWkCW00?oWkCW00?o0000oiJXhonFZ><00_nFZ><00ol0003oT:3Ooi2Pg`03oi2Pg`03
ohbKg?l0003oUYcG00CoUYcG00?o0000oiJKeonFVmL01OnFVmL00ol0003oUikIoiNNf@02oiNNf@03
o`000?nPXMGo000000;o00001onRZ=X2o`000003ojFch_l0003oZ;CQ00_oZ;CQ2Ol00006ojK2kP03
o`000?nU`^koYL;^00GoYL;^1_l0000=ok:lh@;o00002?nl_]/00ol0003o`KgFol6meP05ol6meP03
o`000?o5aM[o000000Kob<GH00?o0000olO5f?o7aMP01?o7aMP01ol0003oa<GKolC5foo4aM_o0000
olK>h?l000001Onobn@01?l0003o]<KWokC6ionda^L2o`0000?oYko[00?o0000oiVhkOnI^>d00_nI
^>d00ol0003oSK3^ohf`kP02ohf`kP04o`000?n4ZnkoQ:_^o`0000CoP:S^00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0fooooo`04o`000?nngNoo_]g_o`0000Co
_=__00?o0000okSEkonheNl00_nheNl01Ol0003o/Lc^ok7<k_nac>ko000000CoZ<3[00?o0000oind
ionO]>L00_nO]>L00ol0003oUZSSoiJXh`03oiJXh`03o`000?n@X=ooT:3O00;oT:3O00Co0000ohbK
g?n<Vmco00000onFW=L00ol0003oUY_GoiJKe`05oiJKe`03o`000?nGW]WoUikI00;oUikI0ol00008
oj:XfP;o00001?nU/n800ol0003oZ;CQojRdh@05ojRdh@Co00000_nW`^d00ol0003oY/;^ojK2kP0:
ojK2kP03o`000?nU`^koYL;^00[oYL;^00?o0000ojG1kOnU`Nd01?l00007ok:lh@04o`000?nd_n?o
];oSo`0000Oo_;kK0_l00004ol6meP05o`000?o5aM[oaLGJolG5f_l000001_o8aMP00ol0003oalGH
olO5f004olO5f003o`000?o4aM_o000000?oa/kP00?o0000oko;i?nobn@00_nobn@00ol0003o]<KW
okC6i`02okC6i`;o00000onW_n/01Ol0003oVKS]oiVhkOnI^>go000000CoSK3^00Go0000ohB[k_n4
ZnkoQ:_^o`000004oh2XkP03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool0=Oooool01?l0003o_]g_okkMkol00004okcKk`03o`000?nheNoo^=G_00;o^=G_00?o0000
ok7<k_nac>h00_nac>h01Ol0003oZ<3[ojS0jonX`>_o000000GoWkCW00?o0000oiJXhonFZ><00_nF
Z><00ol0003oT:3Ooi2Pg`02oi2Pg`03o`000?n<VmcoS9_L00;oS9_L00?o0000oiJLeol000001_nF
VmL2o`0000;oUikI1?l000000onKY]go0000oj:XfP06oj:XfP03o`000?nU/n;oYK?R00GoYK?R00?o
0000ojRdhOnX]>401?l00005ojO2k@?o000000?oY/;^o`000?l000002Ol00002ojG2kPCo00001OnU
`^h00ol0003oYL7]ojG1k@05ojG1k@Co00000_nb_>400ol0003o];oSokBoh`03okBoh`;o00001_nl
_]/2o`000003ol6me_l0003oaLGJ00CoaLGJ00?o0000olS5f?o8aMP01?o8aMP00ol0003oalGHolO5
f003olO5f0;o00001?o6c^000ol0003o_l_Toko;i003oko;i007o`000?nda^Oo]<KWokC6iol0003o
Yko[o`000002ojNoj`03o`000?nI^>goVKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[
kP03o`000?n0Z>koP:S^00;oP:S^00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`0dooooo`05o`000?nngNoo_]g_okkMkol000001?nlfnl00ol0003o^=G_okSEk`02
okSEk`05o`000?nac>ko/Lc^ok7<k_l000001?nX`>/00ol0003oWkCWoindi`02oindi`03o`000?nF
Z>?oUZSS00;oUZSS00?o0000oi2Pgon@X=l00on@X=l00ol0003oS9_LohbKg003ohbKg0;o00001OnF
VmL00ol0003oUikIo`000002o`0000;oUikI00Go0000oi^VgOnKY]goVjKMo`000004oj:XfP;o0000
2?nU/n83o`0000GoYl;]1?l00002oioDnP03o`000?nGco_oUlok00KoUlok1?l00006oi3:n`Ko0000
2onU`Nd2o`0000So];oS00?o0000okbnfonl_]/01Onl_]/00ol0003oaLGJolG5fP05olG5fP03o`00
0?o8aMSob<GH00Cob<GH00Oo0000olO5f?o7aMSoalGHo`000?o:cmko000000Goa/kP00?o0000oko;
i?nobn@00_nobn@00ol0003o]<KWokC6i`02okC6i`;o00000onW_n/01Ol0003oVKS]oiVhkOnI^>go
000000CoSK3^00Go0000ohB[k_n4ZnkoQ:_^o`000004oh2XkP03o`000?oooooooooo01gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`004oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_l0000eoooooaCo00000_nX`>/00ol0003oWkCWoindi`02oindi`03o`000?nF
Z>?oUZSS00?oUZSS00?o0000oi2Pgon@X=l00_n@X=l00ol0003oS9_LohbKg004ohbKg0;oRi[L00Co
0000oiJKeonFVmOoUY_G0ol00004oiNNf@03o`000?nKY]goVjKM00?oVjKM00Co0000oj:Xf_nRZ=[o
00001onU/n83o`0000;oYl?]00Co0000ojO2kOnW`^goYl;]0_l00005oioDnP?o00000_nGco/3o`00
00GoM]Cn00Co0000ofO7o_mWaokoIlOn1Ol00003oi3:n`03o`000?n<`o[oS<?j00Co00001_nU`Nd0
0ol0003oYL3]o`000007okBoh`;o00001?nl_]/00ol0003o_lGNoko5gP07olG5fP03o`000?o8aMSo
b<GH00Cob<GH00?o0000olO5f?l000000oo:cmh00ol0003oa/kPolK>h002olK>h003o`000?nobnCo
_l_T00;o_l_T00?o0000okC6ionda^L00_nda^L00ol0003oYko[o`000002ojNoj`03o`000?nI^>go
VKS]00;oVKS]00Go0000ohf`k_n=/>koSK3^o`000003ohB[kP03o`000?n0Z>koP:S^00;oP:S^00?o
0000ooooooooool06oooool3o`0000Oooooo00?o0000ooooooooool01?ooool001cooooo00?o0000
ooooooooool0=?ooool2o`0000;o`mOY00?o0000ol7FjOo1e^T00_o1e^T00ol0003o_=7ZokcAjP02
okcAjP05o`000?ncb^_o/l[[ok?:jol000000_nX`>/5o`0000;oWkCW00?o0000oiJXhonFZ><00_nF
Z><00ol0003oT:3Ooi2Pg`02oi2Pg`03o`000?n<VmcoS9_L00CoS9_L00Co0000oh^Jg?n;V]coRi[L
0ol00006oiNNf@03o`000?nKY]goVjKM00CoVjKM0ol00005ojFchP?o00001OnW`nd3o`0000GoWmCj
0ol000001?n;gogo0000o`000?l00002ogKDoPSo00002?mWaoh3o`0000OoS<?j0ol00002ojG1k@03
o`000?nU`>goYL3]00;oYL3]0_l00006okBoh`;o000000?o_;kKo`000?noaMh00onoaMh00ol0003o
aLGJolG5fP04olG5fP03o`000?o8aMSob<GH00?ob<GH0_l00004ol[?gP03o`000?o6c^3oa/kP00?o
a/kP00?o0000oko;i?nobn@00_nobn@00ol0003o]<KWokC6i`02okC6i`03o`000?nW_n_o000000;o
Yko[00Go0000oiVhkOnI^>goVKS]o`000004ohf`kP04o`000?n4ZnkoQ:_^o`0000CoP:S^00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03oeEEEOmVIVKo000000Kooooo000Loooo
o`03o`000?oooooooooo03Cooooo00Go0000ol?GjOo3enWo`mOYo`000004ol7Fj@03o`000?nldN[o
_=7Z00;o_=7Z00Go0000ok?:joncb^_o/l[[o`000003ojS0j`CoW;GY0ol00004oiJXh`03o`000?n@
X=ooT:3O00;oT:3O00?o0000ohbKg?n<Vm`00on<Vm`00ol0003oRi[Loh^Jg002o`000003oh^Jg?l0
003o000000GoUikI00?o0000oi^VgOnKY]d01?nKY]d01Ol0003oXK;Toj6bi?nQ/^Co000000;oYK?R
0_l00006ojO3k@;o00000_nWe_P01?l0003oWmCjoioDn_nOe?X2o`000004oh_OoOl0003o0000o`00
00;oI]WZ0ol00003od?2i004o`000?lNZlKo0000o`0000;o@K[`00?o0000oa/00?l000001Ol00004
of6lo@Co00001?n<`oX2o`0000OoYL3]0_l00006okBoh`03o`000?noaMko_lGN00Co_lGN0_l00005
olG5fP07o`000?o8aMSob<GHolS5f?l0003obm3Mo`000005ol[?gP03o`000?o6c^3oa/kP00?oa/kP
00Go0000oko;i?nobnCo_l_To`000004okC6i`06o`000?nW_n_oYko[o`000?nW_n_o00000onI^>d0
0ol0003oSK3^ohf`kP02ohf`kP05o`000?n4ZnkoQ:_^ohB[k_l000001?n0Z>h00ol0003ooooooooo
o`0Looooo`?o00003?ooool001cooooo00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3
enWo000000Co`MKY00?o0000okcAj_nldNX00_nldNX01Ol0003o/l[[ok?:joncb^_o000000?oZ<3[
1OnL]NT2oi2Yi`;o000000?oUZSSo`000?n@X=l00on@X=l00ol0003oS9_LohbKg004ohbKg0?o0000
0on;V]`2ohjMgP05o`000?nGW]WoUikIoiNNfOl000001_nKY]d00ol0003oXK;Toj6bi002oj6bi0?o
00001OnW`nd3o`0000CoYmKh1_l00003ofKIjP?o000000?o;;Bdo`000?l000001?l000001?nFg?ko
0000o`000?l00003ogO1oP07o`000?m1XoKo@J?fo`000?l0LKWo0000o`24c@05o`0000?oHKcm0ol0
0003oh^mm`;o00001_nU`>d2o`000003okBohol0003o000000?o]L?U00?o0000oko5g_noaMh01?no
aMh00ol0003oaLGJolG5fP03olG5fP03o`000?o8aMSo000000?obm3M00?o0000ol[?g_o:cmh00_o:
cmh00ol0003oa/kPolK>h003olK>h003o`000?nobnCo_l_T00;o_l_T00Co0000okC6ionda^Oo]<KW
4ol00004oh2XkP03o`000?oooooooooo01Wooooo0ol00002ooooo`03o`000?oooooooooo00[ooooo
000Looooo`03o`000?oooooooooo03Cooooo00Go0000ol?GjOo3enWo`mOYo`000004ol7Fj@05o`00
0?nldN[o_=7ZokcAj_l000001?ncb^/01Ol0003oZ<3[ojS0jonX`>_o000000CoW;GY1?n@ZNL2o`00
00CoT:3O00Co0000ohbKg?n<VmcoS9_L0ol00005oh^Jg007o`000?n>WMkoSYgNohjMg_l0003oUikI
o`000005oi^Vg@;o00001?nQ/^@01?l0003oZ<?]ojS3kOnX`nd2o`0000;oYl?]00?o0000ojOFn?nW
e_P00_nWe_P3o`000004oj3Wo?l0003o0000ohk/l0So00000onbl_D00ol0003o/n7gok?Qm`07o`00
00;oM[Sj0_l000001_m1XoKo0000o`000?l0003o07GDo`1a^@Ko00000omR/_/00ol0003oRkggoh^m
m`02oh^mm`?o00001OnU`>d00ol0003o]L?UokG3i@04okG3i@03o`000?noaMko_lGN00Co_lGN00?o
0000olG5f_o5aMX00_o5aMX2o`0000Cobm3M00?o0000ol[?g_o:cmh00oo:cmh00ol0003oa/kPolK>
h003olK>h006o`000?nobnCo_l_Toko;i?l0003o]<KW0_l000001_ncbN[o0000ojNojonW_n_o0000
ojNoj`CoVkGZ1On@[NT3ohVVj0Oo00005oooool3o`0000Gooooo00?o0000ooooooooool02_ooool0
01cooooo0_l0000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T01Ol0003o_=7ZokcAj_nl
dN[o000000Co/l[[00Go0000ojS0jonX`>_oZ<3[o`000004oibej@04o`000?n@ZNOoT:WWoi2Yi`;o
QZ3U0_l000000on@X=oo0000ohbKg003o`000003ohbKg?l0003oRi[L00CoRi[L00?o0000ohjMg_n>
WMh00on>WMh2o`0000CoVjKM00?o0000oj6bi?nQ/^@00onQ/^@00ol0003oZ<?]ojS3k@03ojS3k@Co
00000_nWe_P2o`0000;oX>Ol1Ol000000omhi=_o0000o`00000Eo`000004ogV`m_l0003o0000odnL
m0;o:HS/00Go0000oa=ji?l0MMCo0000o`B2g`03oc2Kl@04o`000?mR/__oH[;kof:bn`?o00000on;
_OL2o`000003ojG0kOl0003oY;o]00;oY;o]1_ne`nD00ol0003o_lGNoko5gP04oko5gP06o`000?o5
aM[o0000o`000?o8cmoo00001Oo;d=d00ol0003ob/oNol[?gP02ol[?gP03o`000?o6c^3oa/kP00?o
a/kP00?o0000oko;i?nobn@00ol00003ok?9jP05o`000?nW_n_oYko[ojNojol000001?nK]NX00ol0
003oT:gYoi2]j@02oi2]j@CoRJKX1On7Y>L00ol0003oooooooooo`0Booooo`?o00002?ooool00ol0
003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`05o`000?o3enWo`mOYol?G
jOl000001?o1e^T01Ol0003o_=7ZokcAj_nldN[o000000Co/l[[00Go0000ojS0jonX`>_oZ<3[o`00
0003oibej@03o`000?n@ZNOoT:WW00;oT:WW1?n6X>D3o`0000CoS9_L00?o0000oh^Jg?n;V]`00on;
V]`00ol0003oSYgNohjMgP03ohjMgP06o`000?nDY^;o0000o`000?nKY]go00001OnQ/^@00ol0003o
Z<?]ojS3k@03ojS3k@04o`000?n_e_Co[mKdojoFm0Co00000_nPio`:o`000003olWgjol0003oaNk_
013o000000CoQZGYogjZkol0003o00000_mPV>h00ol0003o:HS/o`000002oa=ji004o`000?l@N>?o
0000o`B2g`;o<9_a00?o0000of:bnomR/_/00_mR/_/2o`0000?oRkgg00?o0000ojBokOnT_nd00onT
_nd00ol0003o]L?UokG3i@03okG3i@03o`000?noaMko_lGN00?o_lGN0_l00004olS?g`03o`000?o;
d=gobm3M00?obm3M00?o0000ol[?g_o:cmh00_o:cmh00ol0003oa/kPolK>h002olK>h0?o00000_nn
dNP01Ol0003o/lWZok?9j_ncbN[o000000CoYko[00Go0000oi^ej_nK]N[oVkGZo`000004oi2]j@04
o`000?n9Y^SoRJKXohVVj0GoQjCW00?o0000ooooooooool03_ooool4o`0000_ooooo00?o0000oooo
ooooool02_ooool001_ooooo00?o0000ooooooooool0=Oooool01Ol0003o`mOYol?GjOo3enWo0000
00Co`MKY00Go0000okcAj_nldN[o_=7Zo`000004ok?:j`05o`000?nX`>_oZ<3[ojS0jol000000onL
]NT00ol0003oT:WWoi2Yi`02oi2Yi`Co00000_n0Vn<3o`000003ohbKg?l0003oRi[L00CoRi[L00?o
0000ohjMg_n>WMh00on>WMh00ol0003oU:KRoiBVhP02oiBVhP;o00001?nQ/^@00ol0003oZ<?]ojS3
k@03ojS3k@05o`000?n_e_Co[mKdojoFm?l000000oncjOL3o`0000;oZ_SX0_l000001?nUmn7o0000
o`000?o;nnHEo`0000;oSJ?S0_l00002og2EiP;o000000?oAhOYo`000?l000000_l000001Ol@N>?o
0000ob:3jOl0003o<9_a00;o00000_mR/_/01?l0003oH[;ko`000?l00003oh^hm0GoY;o]00?o0000
okG3iOne`nD00one`nD01ol0003o_lGNoko5g_noaMko0000ol7<hol000001?o8cml00ol0003obm3M
ol_@g@03ol_@g@03o`000?o:cmkob/oN00;ob/oN00?o0000olK>h?l000000_l000000oo6enKo0000
okkAj002okkAj005o`000?ncbN[o/lWZok?9j_l000001?nW_n/01Ol0003oVkGZoi^ej_nK]N[o0000
00CoT:gY00Go0000ohVVj?n9Y^SoRJKXo`000004ohNTi`03o`000?oooooooooo00_ooooo0ol0000@
ooooo`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Gooooo00Go0000ol?G
jOo3enWo`mOYo`000003ol7Fj@03o`000?nldN[o_=7Z00;o_=7Z00Go0000ok?:joncb^_o/l[[o`00
0003ojS0j`03o`000?nL]NWoW;GY00;oW;GY00?o0000oi2Yion@ZNL00ol00003ohJPi@GoP9_S0_l0
0004oh^Jg003o`000?n>WMkoSYgN00?oSYgN00?o0000oiBVh_nDY^800onDY^801_l0003oWK;Wo`00
0?l0003oXK;To`0000CoZ<?]0_l00002ojoFm0;o00000oncjOL00ol0003o/OCbo`000002oj[hj0Co
00000_o;nnH2o`000005omK/hol0003o0000o`000?o@fMl01?l00002ol72fPOo000000?oW:?IoiFR
g_l000000_n=Xn<2ognCg@04o`000?m`UNKoH8SRof28hP;o000000?o>7kVo`000?l000000_l00002
ob:3j@04o`000?m3U_;o0000o`0000?oJJWf00?o0000oh^hm?n;^?@00_n;^?@00ol0003oY;o]ojBo
k@02ojBok@03o`000?ne`nGo]L?U00?o]L?U00?o0000oko5g_l000000oo1c><00ol0003ob<oOolS?
g`02olS?g`03o`000?o;d=gobm3M00?obm3M00Co0000ol[?g_o:cmkob/oN0_l00004olKGiP05o`00
0?nndNSo_]7XokkAj?l000000oncbNX00ol0003oYko[ojNoj`02ojNoj`;o00000_nK]NX00ol0003o
T:gYoi2]j@02oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L00ol0003oooooooooo`08oooo
o`?o00004oooool00ol0003oooooooooo`09ooooo`006oooool00ol0003oooooooooo`0eooooo`04
o`000?o3enWo`mOYo`0000Co`MKY00?o0000okcAj_nldNX00_nldNX01Ol0003o/l[[ok?:joncb^_o
000000?oZ<3[00?o0000oibejOnL]NT00_nL]NT3o`0000;oT:WW00Go0000ohJPiOn6X>GoQZ3Uo`00
0004oh2Kh`;oOi[S00Go0000oh^Jg?n;V]coRi[Lo`000004ohjMgP03o`000?nDY^;oU:KR00?oU:KR
00?o0000oifbionM/^L00_nM/^L2o`0000?oZ<?]00Go0000ojoFm?n_e_Co[mKdo`000003ok?Ym`;o
00000_nam?84o`0000;obo_V0ol00002omK/h`;o000000Cod=WOo`000?l0003oc/gH0_l00002ol72
fP03o`000?nn^mOo000000Co000000?oXjCFo`000?nLXmT00_nEX]h2o`0000?oOi?M00So0000of28
h_mPR>;oH8SRo`000?lhO^Ko0000ocMmi@;o00000_lRPnT00ol0003o@iKbod>FlP04ofVYmP03o`00
0?n;^?CoRkSd00;oRkSd00?o0000ojBokOnT_nd00_nT_nd00ol0003o]L?UokG3i@02okG3i@;o0000
1?o1c><00ol0003ob<oOolS?g`03olS?g`03o`000?o;d=gobm3M00;obm3M00Ko0000ol[?g_l0003o
0000ol_JiOl00004olKGiP05o`000?nndNSo_]7XokkAj?l000000oncbNX00ol0003oYko[ojNoj`02
ojNoj`05o`000?nK]N[o0000oi^ej_l000001?n@[NT01Ol0003oRJKXohVVj?n9Y^So000000CoQjCW
00?o0000ooooooooool01Oooool3o`0001Kooooo00?o0000ooooooooool02Oooool001_ooooo0_l0
000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T00ol0003o_=7ZokcAjP02okcAjP05o`00
0?ncb^_o/l[[ok?:jol000000onX`>/00ol0003oW;GYo`000003o`0000?oT:WW00?o0000ohJPiOn6
X>D00_n6X>D00ol0003oP9_Soh2Kh`02oh2Kh`?oOi[S00?o0000oh^Jg?l000001On>WMh00ol0003o
U:KRoiBVhP02oiBVhP03o`000?nM/^OoWK;W00?oWK;W00Go0000ojW3k?l0003oZ<?]o`000004ojoF
m0?o/nWg1Ol00002ol[hj@03o`000?o;nnKobo_V00;o000000GofNoQo`000?l0003o0000omSMf`02
o`0000?oc/gH0_l000001Oo1`][o0000okjkeol0003o^[GE00?o000000?oZJODoj>Te_nSY=H00_nL
XmT01?l0003oRiCGoh^Deol00002ognCg@;oM8WI0_mPR>82oeN1g`;o00000_lgOND4o`0000;o@iKb
00Go0000ofVYm_mYZOKoJJWfo`000004oh^hm003o`000?nT_ngoY;o]00;oY;o]00Ko0000okG3iOl0
003o0000okK7iol00005ol7<h`03o`000?o8cmoob<oO00;ob<oO00?o0000ol_@gOo;d=d00_o;d=d2
o`0000?obm[U00?o0000olKGi_o6enH00_o6enH01Ol0003o_]7XokkAj?nndNSo000000Co/lWZ00Go
0000ojNojonW_n_oYko[o`000002oi^ejP;o00001?n@[NT01Ol0003oRJKXohVVj?n9Y^So000000Co
QjCW00?o0000ooooooooool00_ooool3o`0001Wooooo00?o0000ooooooooool02Oooool001_ooooo
00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3enWo000000Co`MKY00Go0000okcAj_nl
dN[o_=7Zo`000004ok?:j`03o`000?nX`>_oZ<3[00?o00000onL]NT01Ol0003oT:WWoi2Yion@ZNOo
000000CoQZ3U00?o0000oh2Khon0Vn<00_n0Vn<4ognJh`;o00001?n>WMh00ol0003oU:KRoiBVhP03
oiBVhP03o`000?nM/^OoWK;W00;oWK;W00Co0000ojW3k?nY`ncoZL?/2_l00002olOakP05o`000?o:
n>Wob_SYo`000?o;nnH00_l00002omW_h@;o00000_oHgM/2o`0000?oc/gH00ko0000ol[2d_o:`];o
0000okjkeol0003o^[GEo`000?nd[m?o0000ojn[donYYmCo0000oj>TeP;o00000_nFU]43oh^De`;o
00000_mdRMT00omPR>;o0000oeN1g`02oeN1g`?o00000_m2Q>P5o`0000?oJJWf00?o0000oh^hm?n;
^?@00_n;^?@00ol0003oY;o]ojBok@03o`0000Co]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003o
b<oOolS?g`03olS?g`06o`000?o;d=gobm3Mo`000?o<fnCo00000oo;f^D00ol0003oa]OVolKGiP02
olKGiP05o`000?nndNSo_]7XokkAj?l000001?ncbNX01Ol0003oYko[ojNojonW_n_o000000;oVkGZ
0_l00004oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L5o`0001cooooo00?o0000oooooooo
ool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01Ol0003o`mOYol?GjOo3enWo000000Co
`MKY00Go0000okcAj_nldN[o_=7Zo`000004ok?:j`?o000000?oZ<3[o`000?nL]NT00_nL]NT00ol0
003oT:WWoi2Yi`02oi2Yi`05o`000?n6X>GoQZ3UohJPiOl000001?n0Vn<00ol0003oOi[SognJh`02
ognJh`;oPigT0_l000000on>WMko0000oiBVhP04oiBVhP03o`000?nM/^OoWK;W00;oWK;W00?o0000
ojW3k?nY`n`00_nY`n`01Ol0003o]MC`okGDl?nee?3o000000?o_nGa00Co0000olOak_o7lNko0000
0oo:n>T2o`000008om[_hOl0003o0000o`000?oKg]So0000omSMfol00002omC>d`03o`000?o>cMSo
000000?ob/;B2ol000000onOVLko0000oiJFd@02oiJFd@;oRiCG0_n5Rm800ol0003oM8WIogB9f@02
o`0000;oEh7O0_mGP=l2o`0000;o@XCX00?o0000oeNBkOmGT^d03?l00002ojBok003o`000?nfanOo
]/OW00;o]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003ob<oOolS?g`03olS?g`03o`000?o;d=go
000000;oc=_T00Go0000ol_JiOo;f^Gobm[Uo`000004olKGiP05o`000?nndNSo_]7XokkAj?l00000
1?ncbNX01Ol0003oYko[ojNojonW_n_o000000?oVkGZ00?o0000oi2]jOn@[NT00_n@[NT01Ol0003o
RJKXohVVj?n9Y^So000000CoQjCW00?o0000ooooooooool07_ooool00ol0003oooooooooo`09oooo
o`006_ooool00ol0003oooooooooo`0eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T01_l0
003o_=7ZokcAj_nldN[o0000ok?:j`Co00000onX`>/01Ol0003oW;GYoibejOnL]NWo000000CoT:WW
00Go0000ohJPiOn6X>GoQZ3Uo`000004oh2Kh`03o`000?moV^?oOi[S00;oOi[S1?n3WN@2o`0000Go
U:KR00Go0000oifbionM/^OoWK;Wo`000004ojW3k005o`000?nee?3o]MC`okGDl?l000000onoiO40
1?l0003oao7^olOak_l00002ol[hj@;o00000_oJkn42o`0000?ofmkH0_l00004omC>d`07o`000?o:
`];ob/;Bol[2d_l0003oaKS>o`000002okj`c007o`000?ngZL[o0000ok2Sb_l0003oZ9g;o`000002
oinIcP05o`000?nFU]7oUYKAoiJFdOl000000on5Rm82ogB9f@;oKh?G00?o0000oeN1gol000000omG
P=l01?l0003o@XCXod:4j?l00002oeNBk@05o`000?mbXo3oLZ?`og:Sl?l000001?n=/o000ol0003o
Y;o/ojBok002ojBok003o`000?nfanOo]/OW00;o]/OW00?o0000ol7<hoo1c><00_o1c><00ol0003o
b<oOolS?g`02olS?g`;o00000oo<fn@01Ol0003obm[Uol_JiOo;f^Go000000Coa]OV00Go0000okkA
j?nndNSo_]7Xo`000004ok?9jP05o`000?nW_n_oYko[ojNojol000000onK]NX2o`0000?oT:gY00Go
0000ohVVj?n9Y^SoRJKXo`000004ohNTi`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2Oooool001[ooooo0ol0000eooooo`05o`000?o3enWo`mOYol?GjOl000001?o1e^T00ol0003o_=7Z
o`00000Bo`000003oi2Yiol0003oQZ3U00;oQZ3U00?o0000oh2Khon0Vn<00_n0Vn<01Ol0003oOi[S
ognJhomoV^?o000000CoPigT0_n<Y^L3o`000003oiBVh_l0003oWK;W00?oWK;W00Go0000ojW3k?nY
`ncoZL?/o`000004okGDl004o`000?noiO7o_nGao`0000?oao7^0ol000000ooGkN?o0000om[_h@02
o`0000CofmkH00?o0000omC>dooDc]<00_oDc]<01ol0003ocl7=o`000?o:`];o0000olFhc_l00000
0_nn/<`01_l0003o]jW:okNYb_l0003o/:?:o`0000;oZ9g;00?o0000oinIc_nOVLh00_nFU]400ol0
003oTXk<o`000003ohF;dP03ogB9fOl0003oKh?G00;oKh?G00?oEh7Oo`000?mGP=l00_mGP=l2o`00
0005od:4j?l0003oEi;]oeNBkOl000000ombXo000ol0003oSK?`ohfcl002ohfcl005o`000?nT_nco
Y;o/ojBok?l000001?nfanL00ol0003o`LcSol7<h`02ol7<h`03o`000?o8cmoo000000;o000000?o
bMWUo`000?o<fn@00_o<fn@00ol0003obm[Uol_Ji@02ol_Ji@05o`000?o6enKoa]OVolKGi_l00000
0onndNP00ol0003o/lWZok?9jP02ok?9jP05o`000?nW_n_oYko[ojNojol000000onK]NX00ol0003o
T:gYo`000002oi2]j@05o`000?n9Y^SoRJKXohVVj?l000001?n7Y>L00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000ol?GjOo3
enWo`mOYo`000002ol7Fj@Go000000?o_LcUokC7j?ndanP00ondanP4ojS0j`CoVKO/1?n9[>`3o`00
00;oQZ3U00?o0000oh2Khon0Vn<00_n0Vn<01Ol0003oOi[SognJhomoV^?o000000CoPigT1On<Y^L3
o`0000;oWK;W00?o0000ojW3k?nY`n`00_nY`n`01Ol0003o]MC`okGDl?nee?3o000000?o_nGa1?l0
0004omO]h`;o000000?og=kHo`000?oKg]P00_oKg]P2o`0000?oe<kC00Co0000olo1cOo?`Lgocl7=
0_l000001Oo5^<ko0000okj`c?nn/<co000000;o]jW:00Ko0000ok2Sb_n`Xl[o0000ojRMbol00002
oinIcP;o00000onBS/`01?l0003oQH_BohF;d_n5Rm82o`0000?oKh?G0_l00002oeN0g`;oGHGQ0_l0
0003oeNBk@05o`000?mbXo3oLZ?`og:Sl?l000000on=/o000ol0003oY;o/ojBok002ojBok003o`00
0?nfanOo]/OW00;o]/OW00Co0000ol7<hoo1c>?o`LcS0_l00004olWIi@05o`000?o<fnCoc=_TolcK
i?l000001?o;f^D01Ol0003oa]OVolKGi_o6enKo000000?o_]7X00?o0000ok?9j_ncbNX00_ncbNX0
1Ol0003oYko[ojNojonW_n_o000000?oVkGZ00?o0000oi2]jOl000000_n@[NT01Ol0003oRJKXohVV
j?n9Y^So000000CoQjCW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`0000Co
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03Gooooo00?o0000ol?GjOl000001_l00005okg<i@Co]<OX00?o0000ojS0jonX
`>/00_nX`>/4oiVgk0CoRJc/0_mkX^`3o`0000CoP9_S00Go0000ognJhomoV^?oOi[So`000004oh>M
i003o`000?n<Y^OoS:KW00;oS:KW0onI/nX4o`0000;oZL?/00?o0000okGDl?nee?000_nee?05o`00
00;odNOV00Co0000omO]hooGkN?oengS0_l00002omcNf004o`000?oKg]SofmkHo`0000;of<o@00?o
0000omC>dol000000oo?`Ld00ol0003ob;K9olRfb@03o`000005okj`c?l0003o]jW:okNYb_l00000
0_n`XlX2ojRMb`?o000000?oWI?8o`000?nBS/`00onBS/`2ohF;dP03o`000?n2Q/ooPXK?00?oKh?G
0_m_PmH2oeN0g`04o`000?mMQN7oGHGQoef5h@Co00000ombXo000ol0003oSK?`ohfcl002ohfcl003
o`000?nT_ncoY;o/00;oY;o/00Ko0000okK7ionfanOo]/OWo`000?o1c><2o`000003ol7Cj?l0003o
bMWU00?obMWU00?o0000olcKi?o<fn@00_o<fn@01Ol0003obm[Uol_JiOo;f^Go000000?oa]OV00Go
0000okkAj?nndNSo_]7Xo`000002ok?9jPGo000000?oYko[o`000?nK]NX00_nK]NX01_l0003oT:gY
oi2]jOl0003oT:gYo`0000?oRJKX00?o0000ohNTion7Y>L00_n7Y>L00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo0_l000001?o5d>?o0000o`000?l00004
ol??h`Co_LcU00?o0000okC7j?ndanP00_ndanP01Ol0003oZ<3[ojS0jonX`>_o000000?oVKO/00Go
0000ohV/k?n9[>coRJc/o`000003og^Rk0;o00000_n0Vn<00ol0003oOi[SognJh`02ognJh`03o`00
0?n3WNCoPigT00;oPigT00?o0000ohbVion<Y^L00_n<Y^L4oiVcjP03o`000?nY`^coZL;/00So0000
0_o6g^X01Ol0003odNOVom7Wi_oAinKo000000;oengS0_l00004omcNf0;o00001?oHcm001Ol0003o
cl7=olo1cOo?`Lgo000000?ob;K900?o0000ol6]a_o1[LH02Ol000000onWV<Ko0000oifCb002oifC
b004o`000?nBS/coTXk<oi:>c0;o00001?n2Q/l00om_PmOo0000ofn3eP02ofn3eP03oeN0gol0003o
GHGQ00;oGHGQ0om[T>D6o`0000?oSK?`00?o0000ojBok?nT_n`00_nT_n`00ol0003o]/OWokK7i`03
o`0000?o`M?X00?o0000olWIiOo9fND00_o9fND00ol0003oc=_TolcKi002olcKi005o`000?o;f^Go
bm[Uol_JiOl000000oo6enH00ol0003o_]7Xo`000004o`0000;o//c]00?o0000ojNojonW_n/02ol0
0003ohVVj003o`000?n7Y>OoQjCW00;oQjCW00?o0000ooooooooool07oooool00ol0003ooooooooo
o`08ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0=Oooool3o`0000;oaM3S00?o0000ol??hoo3cn<00_o3cn<01Ol0003o_LcUokg<iOnm
c>Go000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk003o`000?n9[>coRJc/00;oRJc/
0omkX^`2og>Lj`?o00001?moV^<01Ol0003oPigToh>Mi?n3WNCo000000CoS:KW00?o0000oiVcj_nI
/nX00_nI/nX01Ol0003oZL;/ojW2k?nY`^co000000Co^M7/00Go0000olKNj_o6g^[oa]kZo`000002
om7WiPCo000000?ofMgJo`000?oLg]P00_oLg]P2o`0000Cof<o@00Go0000om71bol0003ocl7=o`00
0003olRfb@05o`000?o1[LKo`Jg6ol6]a_l000000oniYLD01?l0003o/9k5ok2NaOl00003ojNHaP09
o`000?nMTlSoWI?8oifCb?l0003oTXk<o`000?n@RlWo000000GoPXK?00?o0000ofn3e_m_PmH00_m_
PmH2o`0000;oGHGQ00Co0000of^@iOm[T>GoJi3U1?mmWnP5o`0000?oY;o/1?l00002okG;jP05o`00
0?o1dnSo`M?Xol7Cj?l000001?o9fND00ol0003oc=_TolcKi002olcKi006o`000?o;f^Gobm[Uol_J
iOl0003oa]OV1?l00002okcGkP05o`000?nbc>go//c]ok;<kOl000001?nW_n/01Ol0003oWK?Woifc
ionM/nOo000000?oUJ[T1?l000000on9Y^So0000ohNTi`03ohNTi`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8boooo
o`03ooooo`?o0000<oooool4o`0000CoaM3S00?o0000ol??hoo3cn<00_o3cn<00ol0003o_LcUokg<
i@02okg<i@05o`000?ndanSo]<OXokC7j?l000001?nX`>/01Ol0003oVKO/oiVgk?nI]nco000000?o
RJc/00Co0000og^Rk?mkX^co00000omcW>/3o`000003ognJhol0003oPigT00?oPigT00?o0000ohbV
ion<Y^L00_n<Y^L01Ol0003oVK?ZoiVcj_nI/n[o000000CoZL;/00Go0000okWAk?nidNco^M7/o`00
0004olKNjP04o`000?oAinKo0000o`0000CofMgJ00Ko0000omcNf?oLg]So0000omS?d?l00003omS?
d004o`000?oA`L_odL7;om71b`?o00000_o8]/T01Ol0003o`Jg6ol6]a_o1[LKo000000?o^JG500Co
0000ok2NaOn`W/Go00000onWV<H01?l0003oWI?8oifCb?nMTlP2o`0000?oT8_900Oo0000oh:6con2
Q/ooPXK?o`000?n1Q/oo000000?oKh?F0_mcQmP2o`000005oef5hOl0003oJi3Uof^@iOl000001?mm
WnP3oi6_j`Co00000_nU_^`01Ol0003o]L_ZokG;j_nebn[o000000?o`M?X00?o0000olWIiOo9fND0
0_o9fND00ol0003oc=_TolcKi002olcKi003o`000?o;f^Gobm[U00?o00000_o3gnd01?l0003o_=O^
okcGk_l00004ok;<k@05o`000?nW_n_oYko[ojNojol000000onM/nL00ol0003oUJ[ToiFZi003oiFZ
i003o`000?n@Y>;oT:CR00?o00000on7Y>L00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00Sooooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo037ooooo0_l00004ooooo`05o`000?o5d>?oaM3SolG@hol000001Oo3cn<0
1Ol0003o_LcUokg<iOnmc>Go000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk005o`00
0?n9[>coRJc/ohV/k?l000000omkX^`3og>Lj`?oLI_Z0ol00003oh>Mi003o`000?n<Y^OoS:KW00;o
S:KW00Go0000oiVcj_nI/n[oVK?Zo`000004ojW2k005o`000?nidNco^M7/okWAk?l000000oo6g^X0
1Ol0003odNOVo`000?oCf]ko000000GofMgJ0_l00003omS?d003o`000?oHcm3o000000CodL7;00?o
0000olVea_o9]LH00ol00002ol6]aP05o`000?niYLGo^JG5okVUaOl000001?n`W/D01Ol0003oYiS6
ojNHa_l0003oWI?800;o000000?oW8o5o`000?n@RlT00on@RlT00ol0003oPXK?o`000003oh66c`04
o`000?m_PmKoKh?Fo`0000CoLhOH0_l000000om[T>Go0000ogfOj003ogfOj005o`000?nA[n_oTJo[
oi6_jol000001?nU_^`01Ol0003o]L_ZokG;j_nebn[o000000Co`M?X00Go0000olWIiOo9fNGobMWU
o`000004olcKi0?o000000Gob>G/o`000?o3gngo`mo]o`000003okcGkP05o`000?nbc>go//c]ok;<
kOl000001?nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00?o0000oi2Th_l000000_n@Y>80
0ol0003oSZ;Qo`000003o`00027ooooo00?o0000ooooooooool02?ooool000?ooooo00?o410@oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02kooooo0ol00006oooo
o`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??hoo3cn<00_o3cn<01Ol0003o_LcUokg<iOnmc>Go
000000Co]<OX00Go0000ojS0jonX`>_oZ<3[o`000003oiVgk005o`000?n9[>coRJc/ohV/k?l00000
0omkX^`01?l0003oLic[og>Ljol00003og6KjP;oMio[1?l00004ohbVi`05o`000?nI/n[oVK?ZoiVc
j_l000000onY`^`00ol0003o^M7/okWAk002okWAk004o`000?o6g^[oa]kZolKNjP;o00000_oCf]h0
0ol0003ofMgJomWMfP02omWMfP;o00001OoHcm000ol0003odL7;om71b`02om71b`03o`000?o9]LKo
bKG600;obKG600?o0000ol:[`ol000000_l00003okVUa@03o`000?n`W/Go/9k500;o/9k500?o0000
ojNHa_l000000_l00004oib?a@03o`000?n@RlWoT8_900;oT8_900?o0000oh66con1Q/l00on1Q/l0
0om_PmKo0000og>7f004og>7f0;oNi3L0_m[T>D01Ol0003oOIoXogfOj?mmWnSo000000?oTJo[00?o
0000ojFnk?nU_^`00_nU_^`01Ol0003o]L_ZokG;j_nebn[o000000Co`M?X00Go0000olWIiOo9fNGo
bMWUo`000002olcKi0?o00000_o8iN`01Ol0003o`mo]ol?OkOo3gngo000000?o_=O^00Go0000ok;<
kOnbc>go//c]o`000003ojNoj`05o`000?nM/nOoWK?Woifciol000001OnEZ^@00ol0003oT:CRoi2T
hP02o`0000GoSZ;Q00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`0000CoV9RH
oooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02_ooooo0ol0
0009ooooo`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??hoo3cn<00_o3cn<00ol0003o_LcUokg<
i@02okg<i@05o`000?ndanSo]<OXokC7j?l000001?nX`>/01Ol0003oVKO/oiVgk?nI]nco000000?o
RJc/00Co0000og^Rk?mkX^co00000omcW>/01?l0003oLI_Zog6Kj_l00004ogNOj`?o000000?oS:KW
o`000?nI/nX00onI/nX01Ol0003oZL;/ojW2k?nY`^co000000?o^M7/00?o0000olKNj_o6g^X00ol0
0004om?JgP06o`000?oIgM[o0000o`000?oFc];o00001?oHcm001_l0003odL7:om71b_l0003odL7;
o`0000CobKG600?o0000ol:[`oo2Zl<00_o2Zl<;o`0000;oYiG300?o0000oib?aOnLSlD00onLSlD0
1_l0003oT8_9oi2;bOl0003oT8[9o`0000GoPHK?0_l00003og>7f006o`000?mkT=coNi3Log^@g?m[
T>Go00000ommWnP01Ol0003oTJo[oi6_jonA[n_o000000CoYKk/00?o0000okG;j_nebnX00_nebnX0
1Ol0003o`M?Xol7Cj?o1dnSo000000;obMWU1?l00002olSUk004o`000?o8iNcob>G/o`0000?o`mo]
00Co0000okcGk_nlenko00000onbc>d00ol0003oYko[ojNoj`02ojNoj`05o`000?nM/nOoWK?Woifc
iol000001?nEZ^@01?l0003oT:CRoi2Th_n@Y>82o`0000GoSZ;Q00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`07ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000
ooooooooool0:?ooool3o`0000gooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??h`02
ol??h`05o`000?nmc>Go_LcUokg<iOl000001?ndanP01Ol0003oZ<3[ojS0jonX`>_o000000?oVKO/
00Go0000ohV/k?n9[>coRJc/o`000003og^Rk004o`000?mcW>_oLic[o`0000?oLI_Z00Co0000ogNO
jomgWn_oMio[0on5ZN`4o`000003oiVcj_l0003oZL;/00?oZL;/00?o0000okWAk?l000001?l00002
olWEh`03o`000?oCf]kodm[N00;odm[N0_l00004omK>dP04o`000?oHcm3of<o@o`0000CodL7:0_l0
0004olVeaP03o`000?o2Zl?o`Z_300;o`Z_300Go0000okVS`_niXl;o^J?2o`000004ok2K`P03o`00
0?nWUL?oYiG300;oYiG300?o0000oib?aOnLSlD00_nLSlD00ol0003oT8_9o`000003oi2:b@05o`00
0?n1Q/ooPHK?oh66col000000_n4RM401?l0003oLhOHog>7f?l00004og^@g0?o000000?oOIoXo`00
0?nA[n/00onA[n/01Ol0003oYKk/ojFnk?nU_^co000000Co]L_Z00Co0000ol7Cj?o1dnSo`M?X0ol0
00000oo5h^go0000olSUk002olSUk005o`000?o8iNcob>G/olSUk?l000000_o3gnd01Ol0003o_=O^
okcGk_nlenko000000?o//c]00Go0000ojNojonW_n_oYko[o`000004oifci`03o`000?nEZ^CoUJ[T
00;oUJ[T00Co0000oi2Th_n@Y>;oT:CR0_l00004ohjRh@03o`000?oooooooooo027ooooo00?o0000
ooooooooool01oooool001Wooooo0_l0000Vooooo`?o00004?ooool00ol0003oaM3SolG@h`02olG@
h`03o`000?o3cn?o`loS00;o`loS00Go0000okg<iOnmc>Go_LcUo`000004okC7j005o`000?nX`>_o
Z<3[ojS0jol000000onI]n`01Ol0003oRJc/ohV/k?n9[>co000000?oNj;/00Co0000og>LjomcW>_o
00000omaVnX01Ol0003oMio[ogNOjomgWn_o000000?oQJW/0onF]Nd8o`0000;o^lgX00?o0000olWE
hoo9eN<00_o9eN<01?l0003odm[Nom?Jg_oCf]h2o`0000Goe/kB00?o0000omS?d?l000001OoA`LX0
0ol0003ob[G6o`000002o`000003olVea_l0003o`Z_300?o`Z_300Go0000okVS`_niXl;o^J?2o`00
0004ok2K`P03o`000?nWUL?oYiG300;oYiG300?o0000oib?aOnLSlD00_nLSlD2o`0000GoT8[900?o
0000oh66col000001?n4RM42og>7f003o`000?mkT=coNi3L00;oNi3L0on7WN85o`000003oi6_jol0
003oYKk/00;oYKk/00?o0000okG;j_nebnX00_nebnX00ol0003o`M?Xo`000002o`0000;oaN;]00?o
0000olSUk?o8iN`00_o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko_=O^o`0000Co
//c]00Go0000ojNojonW_n_oYko[o`000003oifci`03o`000?nEZ^CoUJ[T00;oUJ[T00?o0000oi2T
h_n@Y>800_n@Y>800ol0003oSZ;Qo`000003ohjRh@03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01oooool001Sooooo00?o0000ooooooooool08oooool3o`0001?ooooo00?o0000olG@hoo5
d><00_o5d><00ol0003o`loSol??h`02ol??h`03o`000?nmc>Go_LcU00;o_LcU00Go0000okC7j?nd
anSo]<OXo`000004ojS0j`05o`000?nI]ncoVKO/oiVgk?l000000_n9[>`01Ol0003oNj;/og^Rk?mk
X^co000000?oLic[00Co0000og6Kj_maVn[o00001?mgWn/01?l0003oQJW/ohFYk?l00003oiJek@03
o`000?nY`^_oZL;[00;oZL;[00?o0000ok_=j?nkcNP00_nkcNP00ol0003obMGSolWEh`02olWEh`05
o`000?oCf]ko0000om3=eol000001OoFc]82o`0000GodL7:00?o0000olZea_o:]LH00oo:]LH2o`00
00?o`Z_300?o0000okVS`_niXl800_niXl800ol0003o/9_2ok2K`P03ok2K`P06o`000?nWUL?oYiG3
ojNE`ol0003oW8o50ol000000onLSlGo0000oi2:b@04oi2:b@;o00001_n4RM42o`0000?oNi3L00?o
0000ohNMh_n7WN800_n7WN801?l0003oUZgWoiJ]ionF[NL<o`0000;o_][^00Co0000olGRkOo5h^go
00001?o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko_=O^o`0000?o//c]00?o0000
ojNojonW_n/00_nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00Go0000oi2Th_n@Y>;oT:CR
o`000003ohjRh@03o`000?n>X^7o000002Cooooo00?o0000ooooooooool01oooool001Sooooo00?o
0000ooooooooool08?ooool3o`0001Oooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??
h`02ol??h`05o`000?nmc>Go_LcUokg<iOl000001?ndanP00ol0003oZ<3[o`000008o`000003ohV/
k?l0003oNj;/00;oNj;/00Co0000og>LjomcW>_o00000omaVnX01Ol0003oMio[ogNOjomgWn_o0000
00?oQJW/00Co0000oiJekOnF]Ngo00001OnY`^/01Ol0003o^lgXok_=j?nkcNSo000000CobMGS0_l0
0003om3=e`05o`000?oFc];oe/kBomK>d_l000000oo@`L`01?l0003odL7:om71b_l00006olZeaP03
o`000?o2Zl?o000000?o00001?niXl800ol0003o/9_2ok2K`P03ok2K`P03o`000?nWUL?oYiG300?o
00001OnLSlD01Ol0003oT8[9oi2:bOn@R/Wo000000;oTHg;00?o0000ohB9dOn4RM400on4RM400ol0
003oRI7Eo`000002og^@g005o`000?n7WN;oQigRohNMh_l000001OnF[NL01Ol0003oYKk[ojFnjonU
_^_o000000Co/lk^00Co0000okkJk_nnf^ko00000oo5h^d01Ol0003ob>G/olSUk?o8iNco000000?o
b>G/00Co0000ol?OkOo3gngo00000_nlenh00ol0003o//c]ok;<k@02ok;<k@05o`000?nW_n_oYko[
ojNojol000000onM/nL00ol0003oUJ[ToiFZi002oiFZi003o`000?n@Y>;oT:CR00;oT:CR00Oo0000
ohjRhOn>X^7oSZ;Qo`000?n>X^7o000002Cooooo00?o0000ooooooooool01oooool001Sooooo00?o
0000ooooooooool07Oooool3o`0001[ooooo00?o0000olG@hoo5d><00_o5d><00ol0003o`loSol??
h`02ol??h`05o`000?nmc>Go_LcUokg<iOl000000_ndanP4o`0000;oZ<3[00Go0000oiNikonG^Noo
UkW_o`000002ohB`lPOo000000?oLic[o`000?maVnX00_maVnX01Ol0003oMio[ogNOjomgWn_o0000
00?oQJW/00Go0000oiJekOnF]NgoU[G]o`000004ojW2j`05o`000?nkcNSo^lgXok_=j?l000000oo9
eN<2o`0000God<gG00?o0000omK>d_l000001Oo@`L`00ol0003odL7:o`000005olZeaP03o`000?o2
Zl?o`Z_300?o`Z_33_l00002ojNE``03o`000?nLSlGoW8o500CoW8o500?o0000oi2:bOl000001?nA
SL/01Ol0003oQ8WAohB9dOn4RM7o000000?oRI7E00?o0000og^@g?l000000on7WN800ol0003oUZgW
oiJ]i`03oiJ]i`05o`000?nU_^_oYKk[ojFnjol000000oncc^h01Ol0003o_][^okkJk_nnf^ko0000
00;oaN;]00?o0000olSUk?o8iN`00_o8iN`01?l0003ob>G/olSUk?l00003ol?Ok@04o`000?nlenko
_=O^o`0000?o//c]00?o0000ojNojonW_n/00_nW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T
00Go0000oi2Th_n@Y>;oT:CRo`000005ohjRh@03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01oooool001Sooooo00?o0000ooooooooool06_ooool3o`0001gooooo00?o0000olG@hoo5d><0
0oo5d><01Ol0003o`loSol??hoo3cn?o000000?o_LcU0ol00002okG4i@03o`000?nX`>_oZ<3[00;o
Z<3[00Go0000oiNikonG^NooUkW_o`000002ohB`lP09o`000?maY_;oLJKbog6Vl_l0003oI9oao`00
0?mcW>_o000000;oLI_Z00Go0000ogNOjomgWn_oMio[o`000003ohFYk005o`000?nF]NgoU[G]oiJe
kOl000001?nY`^/00ol0003o^lgXok_=j002ok_=j0?o000000?ob<cMo`000?o@cML01Oo@cML00ol0
003od<7<om31c005om31c0?o00001?o:]LH00ol0003o`Z_3ol:[``03ol:[``03o`000?niXl;o^J?2
00;o^J?200?o0000ok2K`_n`Vl800on`Vl800ol0003oYiG3ojNE``03ojNE``03o`000?nLSlGoW8o5
00?oW8o50_l00006oi6=b`03o`000?n4RM7o000000GoRI7E0_l00003ohNMhP03o`000?nF[NOoUZgW
00;oUZgW00Go0000ojFnjonU_^_oYKk[o`000004ok?>kP05o`000?nnf^ko_][^okkJk_l000000_o5
h^d01Ol0003ob>G/olSUk?o8iNco000000?ob>G/00Go0000ol?OkOo3gngo`mo]o`000002okcGkP05
o`000?nbc>go//c]ok;<kOl000000onW_n/01Ol0003oWK?WoifcionM/nOo000000CoUJ[T00?o0000
oi2Th_n@Y>800_n@Y>800ol0003oSZ;QohjRh@03ohjRh@;o00009?ooool00ol0003oooooooooo`07
ooooo`006?ooool2o`0001Sooooo0ol0000Qooooo`03o`000?o5d>?oaM3S00;oaM3S00?o0000ol??
hoo3cn<00_o3cn<3o`000003okg7hOl0003o]LCU00?o]LCU00?o0000ojS0jonX`>/00_nX`>/01Ol0
003oUkW_oiNikonG^Noo000000;oQ;3b00Go0000og6Vl_maY_;oLJKbo`000002ofBOl@?o000000Go
LI_Zo`000?mgWn_oMio[o`000003ohFYk005o`000?nF]NgoU[G]oiJekOl000001OnY`^/00ol0003o
^lgXo`000002o`0000Cob<cM00?o0000om3=eoo@cML00oo@cML00ol0003oc<;Ao`000005om31c003
o`000?o8]/Sob;K800?o000000?ob[G6o`000?o2Zl<01?o2Zl<00ol0003o^J?2okVS`P02okVS`P03
o`000?n`Vl;o/9_200?o/9_200?o0000ojNE`onWUL<00onWUL<01?l0003oW8o5oib?aOnLSlD2o`00
0003oifBaol0003oTHg;00GoTHg;0_l00006ohVAe@03o`000?nAWM_o000000;o00001OnF[NL01Ol0
003oYKk[ojFnjonU_^_o000000Co/lk^00Co0000okkJk_nnf^ko00000oo5h^d01Ol0003ob>G/olSU
k?o8iNco000000?ob>G/3Ol00002ojNoj`05o`000?nM/nOoWK?Woifciol000001?nEZ^@00ol0003o
T:CRoi2ThP02oi2ThP03o`000?n>X^7oSZ;Q00;oSZ;Q00Co0000oooooooooooo00009?ooool00ol0
003oooooooooo`06ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o00009?ooool00ol0003o
aM3SolG@h`02olG@h`03o`000?o3cn?o`loS00?o00001?nman400ol0003o]LCUokG4i@02okG4i@03
o`000?nX`>_oZ<3[00;oZ<3[00Go0000oiNikonG^NooUkW_o`000002ohB`lP07o`000?maY_;oLJKb
og6Vl_l0003oI9oao`000002of:Nl@Co000000?oMio[o`000?n5ZN`00_n5ZN`01Ol0003oU[G]oiJe
kOnF]Ngo000000;oZL;[1?l00002ok_8i003o`000?o8c=gob<cM00?ob<cM00Go0000om3=eoo@cMOo
d<gGo`000003olc2d@05o`000?o@`Lcod<7<om31c?l000001_o8]/P3o`0000?o`Z_300?o0000okVS
`_niXl800oniXl800ol0003o/9_2ok2K`P04ok2K`P03o`000?nWUL?oYiG300;oYiG300Co0000oib?
aOl0003o00001?nMT/L00ol0003oTHg;oi6=b`02oi6=b`03o`000?nDTm3o000000GoRI7E00?o0000
oi6MfonAWM/00_nAWM/2o`0000CoUZgW00Go0000ojFnjonU_^_oYKk[o`000003ok?>kP05o`000?nn
f^ko_][^okkJk_l000000_o5h^d00ol0003ob>G/olSUk002olSUk0Go00000_nli_<01?l0003o]m_c
okOKlol00003ojo=l003o`000?nW_n_oYko[00Co00000_nM/nL01Ol0003oUJ[ToiFZi?nEZ^Co0000
00CoT:CR00?o0000ohjRhOn>X^400on>X^401?l0003oooooooooool0000Tooooo`03o`000?oooooo
oooo00Kooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0000Wooooo`03o`000?o5d>?oaM3S
00;oaM3S0ol00002ol;8gP03o`000?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D01Ol0
003oZ<3[ojS0jonX`>_o000000CoUkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oao`00
0002of:Nl@03o`000?m[Xo;oJj?b00co00000_nZ`N/00ol0003o^lSTok_8i002ok_8i003o`000?o8
c=gob<cM00?ob<cM00?o0000om3=eol000001Oo<`]400ol0003od<7<o`000007olRfb003o`000?o1
[<Go`Jc500Co00001OniXl800ol0003o/9_2ok2K`P04ok2K`P03o`000?nWUL?oYiG300Co00001onM
T/L01?l0003oTHg;oi6=bol00003oiBCd005o`000?n9TMGoRI7EohVAeOl000001OnAWM/01_l0003o
VZcSo`000?l0003oUZgWo`0000CoYKk[00Go0000ok?>k_ncc^ko/lk^o`000003okkJkPWo000000?o
_^cco`000?nli_<00_nli_<01?l0003o]m_cokOKlol00003ojo=l003o`000?nW_n_oYko[00;oYko[
00?o0000oj2biOnP/^D01?l00002oiFZi003o`000?n@Y>;oT:CR00;oT:CR00?o0000ohjRhOn>X^40
0on>X^401Ol0003ooooooooooooooooo000002?ooooo00?o0000ooooooooool01_ooool001Oooooo
00?o0000ooooooooool03oooool3o`0002_ooooo1?l000000oo4b=go0000ol;8gP03ol;8gP03o`00
0?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D01Ol0003oZ<3[ojS0jonX`>_o000000Co
UkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oao`000002of:Nl@04o`000?m[Xo;oJj?b
o`0000?oOJgb00Go0000oiBhl?nD^?3oU;S`o`000005oj[1j`03o`000?nkb>Co^lST00;o^lST00?o
0000olS<gOo8c=d00_o8c=d2o`0000Ooc<;A00?o0000olRfb?o8]/P01Oo8]/P00ol0003o`Jc5ol6/
a@04ol6/aA3o00000onWUlD00ol0003oWI;7oifBa`05oifBa`03o`000?nASL_o000000GoU9?@00?o
0000ohVAeOl000001OnAWM/00ol0003oVZcSoiZ/h`03oiZ/h`?o000000?oYKk[o`000?ncc^h00onc
c^h5o`0000;o_NWc00Co0000okk]lonnkO?o00000_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o
]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNoj`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZY
h?nJZN000ol00003oi2ThP03o`000?n>X^7oSZ;Q00?oSZ;Q00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00co
oooo0ol0000^ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_o2b=h00_o2b=h00ol0003o
_LOQokg7h@03okg7h@03o`000?nea>Go]LCU00;o]LCU00Go0000ojS0jonX`>_oZ<3[o`000003oiNi
k`04o`000?n4/?;oQ;3bo`0000?oLJKb00Co0000ofBOlOmTWo7o00000_mRW_401?l0003oJj?bof^S
l_l00003ogf]lP05o`000?nD^?3oU;S`oiBhl?l000001?nZ`N/00ol0003o^lSTok_8i002ok_8i005
o`000?o8c=gob<cMolS<gOl000000oo5`mP00ol0003oc<;Aolc2d@03olc2d@04o`000?o6^<go0000
o`0000?ob;K800?o0000ol6/aOo1[<D01Oo1[<D00ol0003o^JC4okVTa003okVTa003o`000?n`WLCo
/9g400Co/9g400?o0000ojNGaOnWUlD01?nWUlD00ol0003oWI;7oifBa`03oifBa`?o00001_nDTm03
o`0000CoTIgK00?o0000oiZ/honJ[><01?nJ[><00ol0003oY[k[ojJnj`07o`0000;o^=oc00Co0000
okgYlonmjO?o00000_nnkO<01?l0003o_^ccokk/lol00003okcVl`04o`000?ngfo?o]m_co`0000?o
[lg`00?o0000ojNojonW_n/00_nW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;o
VZWP00Ko0000oiNSgOl0003o0000oi2Th_l00005ohjRh@03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`06ooooo`005oooool2o`0000[ooooo0ol0000aoooo
o`03o`000?o4b=goa<SM00Coa<SM00?o0000ol;8g_o2b=h00_o2b=h00ol0003o_LOQokg7h@03okg7
h@05o`000?nea>Go]LCUokG4iOl000001?nX`>/01Ol0003oUkW_oiNikonG^Noo000000;oQ;3b00Go
0000og6Vl_maY_;oLJKbo`000002ofBOl@04o`000?mRW_7oHYkao`0000;oJj?b00Go0000ogf]l_mm
[O;oOJgbo`000003oiBhl003o`000?nZ`N_oZ/7[00;oZ/7[00?o0000ok_8i?nkb>@00_nkb>@00ol0
003ob<cMo`000005olG3f005o`000?o<`]7oc<;Aolc2dOl000001?o6^<d2o`000003olRfb?l0003o
`Jc500Go`Jc500?o0000okVTa?niY<@01?niY<@00ol0003o/9g4ok2Ma004ok2Ma003o`000?nWUlGo
YiO500CoYiO500?o0000oifBaonMT/L00ol00002oinGc003o`000?nDTm3oU9?@00?oU9?@00Go0000
oiVNeonIW]OoVIkGo`000003oi6Mf`03o`000?nJ[>?oVZcS00?oVZcS00Go0000ojJnjonV_^_oY[k[
o`000004ok3@l@04o`000?nhgo?o^=oco`0000;o_NWc00Co0000okk]lonnkO?o00000_nnk?<01Ol0
003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNoj`03o`000?nP
/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003oUj?MoiNSg@02oiNSg@;o00001?n>
X^400ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_oo
ool001Oooooo00?o0000ooooooooool01_ooool3o`0003Gooooo00?o0000olC8gOo4b=d01?o4b=d0
0ol0003o`/SNol;8gP02ol;8gP03o`000?nman7o_LOQ00;o_LOQ00?o0000okG4iOnea>D00_nea>D0
1Ol0003oZ<3[ojS0jonX`>_o000000CoUkW_00Co0000ohB`l_n4/?;o00000omaY_800ol0003oI9oa
o`000003of:Nl@04o`000?m[Xo;oJj?bo`0000?oOJgb00Go0000oiBhl?nD^?3oU;S`o`000004oj[1
j`04o`000?nkb>Co^lSTok_8i0;o00001oo5`mP00ol0003oc<;Ao`000007olJhc@03o`000?o1[<Go
000000Go`Jc500?o0000okVTa?niY<@01?niY<@00ol0003o/9g4ok2Ma005ok2Ma003o`000?nWUlGo
YiO500;oYiO51?l00006oinGc003o`000?nDTm3oU9?@00;o00001OnIW]L00ol0003oTIgKo`000005
oiZ/h`05o`000?nV_^_oY[k[ojJnjol000001?n`d?401?l0003o^=ocokSOlol00002okgYl`04o`00
0?nnkO?o_^gco`0000;o_^cc00Go0000okcVlonli_?o_>Kco`000002okOKl`05o`000?n_cO3o[lg`
ojo=l?l000001?nW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000
oiNSgOnGXmd00onGXmd00ol0003oUJ7Lo`000002o`000003ohjRhOl0003ooooo00Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`03oooo
o`?o0000>Oooool00ol0003oa<SMolC8g@04olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7
hOnman400_nman400ol0003o]LCUokG4i@02okG4i@05o`000?nX`>_oZ<3[ojS0jol000001?nG^Nl0
1?l0003oQ;3bohB`l_l00003og6VlP03o`000?mTWo7o000000?oHYka00Co0000of^Sl_m[Xo;o0000
0omm[O801?l0003oU;S`oiBhl?l00004oj[1j`04o`000?nkb>Co0000o`0000?o^/?Q00?o0000olG3
f?o5`mP01?o5`mP00ol0003oa[S=olJhc@06olJhc@03o`000?no[l[o_jo:00?o00000_o1[<D00ol0
003o^JC4okVTa004okVTa003o`000?n`WLCo/9g400Go/9g400?o0000ojNGaOl000000_l00002ojRK
b@03o`000?nOUlcoWiO<00GoWiO<00?o0000oiBCd?l000001onIW]L3o`0000CoVZcS00Go0000ojJn
jonV_^_oY[k[o`000004ok3@l@04o`000?nhgo?o^=oco`0000;o_NWc00Co0000okk]lonnkO?o0000
0_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o[lg`o`000004ojNo
j`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003oUj?MoiNSg@03oiNS
g@03o`000?nEXMcoUJ7L00?oUJ7L00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Gooooo000Fooooo`04o`000?ooooooooooooooo`?o0000?Oooool00ol0
003oa<SMolC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7hOnman400onman400ol0
003o]LCUokG4i@02okG4i@05o`000?nX`>_oZ<3[ojS0jol000000_nG^Nl<o`0000?oHYka00Co0000
of^Sl_m[Xo;o00000omm[O801?l0003oU;S`oiBhl?l00002oj[1j`?o00001_nj`n42o`0000?oaL?H
00?o0000ol6je?o1^]@00ol00003olJhc@03o`000?no[l[o_jo:00Co_jo:4ol00006ojRKb@03o`00
0?nOUlcoWiO<00CoWiO<0_l00006oiVNe`;o00000onO[>02o`000003oiZ/hol0003oY[k[00;oY[k[
00?o0000ok3@lOn`d?400_n`d?401?l0003o^=ocokSOlol00003okgYl`03o`000?nnkO?o000000;o
_^cc00Go0000okcVlonli_?o_>Kco`000002okOKl`05o`000?n_cO3o[lg`ojo=l?l000001?nW_n/0
0ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000oiNSgOnGXmd00onGXmd0
0ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`005_ooool4o`00047ooooo00?o0000olC8gOo4b=d00oo4b=d00ol0
003o`/SNol;8gP02ol;8gP03o`000?nman7o_LOQ00?o_LOQ00?o0000okG4iOnea>D00_nea>D00ol0
003oZ<3[ojS0j`03o`0000CoU[cb0omo]OL4ofN/n003oeFTmol0003o000000ko00001?nZ`NX00ol0
003o^/?Qok[3h@04ok[3h@03o`000?o5`mSo000000Ko`K[D0_l000000oo6^<go0000okn_bP06okn_
bP03o`000?nhYlSo^:O800Go^:O800?o0000ok2Qb?n`XLP01On`XLP00ol0003oZ9_9ojRKb@05ojRK
b@04o`000?nOUlcoWiO<oinGc0?o00000_nQX=<00ol0003oVIkGoiVNe`02oiVNe`03o`000?nO[>3o
WjcP00CoWjcP1?l000000onV_^_o0000ok3@l@03ok3@l@04o`000?nhgo?o^=oco`0000?o_NWc00?o
0000okk]lol000000_nnk?<01Ol0003o_>KcokcVlonli_?o000000;o]m_c00Go0000ojo=l?n_cO3o
[lg`o`000004ojNoj`03o`000?nP/^GoX;;U00;oX;;U00?o0000oiZYh?nJZN000_nJZN000ol0003o
Uj?MoiNSg@03oiNSg@03o`000?nEXMcoUJ7L00?oUJ7L00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Fooooo`?o0000@oooool00ol0003oa<SM
olC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o0000okg7hOnman400onman400ol0003o]LCU
okG4i@04o`0000?oZ;o[1OnF_?801?l0003oOkGgognemol00003ofN/n0;oEJCg1?mBXoH3oenXn0Co
Mk;h0onB_?<5oj[1jP;o00001Onj`n400ol0003o`K[Dol6je007ol6je003o`000?no[l[o000000Ko
_jo:00?o0000okRWb?nhYlP01OnhYlP00ol0003o/:78ok2Qb005ok2Qb003o`000?nXVlWoZ9_900Go
Z9_900Co0000oinGc?l0003o00001_nQX=<01?l0003oVIkGo`000?l00006oin/h004o`000?nV_^[o
Y[kZojJnjPCo00000_n`d?401?l0003o^=ocokSOlol00003okgYl`oo000000?o[lg`o`000?nW_n/0
0onW_n/00ol0003oX;;Uoj2bi@02oj2bi@03o`000?nJZN3oVZWP00;oVZWP00?o0000oiNSgOnGXmd0
0onGXmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo00gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`05ooooo`003?ooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0@_ooool00ol0003oa<SMolC8g@03olC8g@03o`000?o2b=ko`/SN00;o`/SN00?o
0000okg7hOnman400_nman43o`0000Co]<7S1?nX_n/00ol0003oU[cboiJllP02oiJllP;o00000_mo
]OL01_l0003oIjchofN/n?l0003oEJCgo`0000?oDZ?f00Co0000oenXn?mOZ?So00000omg/_P00ol0
003oT[ccoi:ll`02o`0000CoZ/7Z00Go0000ok[3hOnj`n7o^/?Qo`000002okRmgP;o00001_o1^]@0
0ol0003o_;?Aokbcd@04o`000003okn_b_l0003o^:O800Oo^:O800?o0000ok2Qb?n`XLP01_n`XLP0
0ol0003oZ9_9ojRKb@03ojRKb@?o00002?nQX=<2o`0000KoWjcP0_l00003ojJnjP03o`000?n/dO?o
[=7c00;o[=7c2_l00002ojc_m`05o`000?n^jOWo[^WiojkYnOl000000_n^gOP01?l0003o[<kbojc>
l_n/c_84o`0000;oYko[00?o0000oj2biOnP/^D00_nP/^D00ol0003oVZWPoiZYh003oiZYh003o`00
0?nGXmgoUj?M00;oUj?M00?o0000oiFQg?nEXM`00onEXM`00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`11ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_o2b=h00oo2
b=h01?l0003o_LOQo`000?l00003okc1gPGo]<7S00?o0000ojRojonX_n/00_nX_n/00ol0003oU[cb
oiJllP02oiJllP03o`000?mo]OOoOkGg00;o00000_mW[?P00ol0003oEJCgo`000002oe:SmP04o`00
0?mOZ?SoGjSho`0000?oMk;h00Co0000oi:llonB_??oT[cc0_l00003oj[1jP03o`000?nj`n7o0000
00Go^;gN0_l00003ol6je003o`000?nl/m7o_;?A00Go_;?A1ol00003okRWb003o`000?n`XLSo/:78
00Ko/:7800?o0000ojRKbOl000000ol00002ojVSd@03o`000?nQX=?oXJ3C00?oXJ3C0ol00002ojB]
g@04o`000?nO[>3oWjcPoin/h0;o00000onV_^X2o`0000Co[=7c00Co0000ojkRnOn^h_Wo00000_n]
k?P4o`0000;o[>og00?o0000ojkYnOn^jOT00_l000000on^gOSo0000o`000003ojc>lP03o`000?nW
_n[oYkoZ00;oYkoZ0ol00003oj2bi@03o`000?nJZN3oVZWP00?oVZWP00?o0000oiNSgOnGXmd00_nG
Xmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo013ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo047ooooo00?o0000olC8gOo4b=d00oo4b=d00ol0003o`/SNol;8gP03ol;8gP03o`000?nl`Mko
_<7N00Co_<7N00?o0000okC1hond`N<00_nd`N<2o`0000?oZ;o[0_l00003oiJllP05o`000?mo]OOo
OkGgognemol000000_mW[?P00ol0003oEJCgo`000003oe:SmP04o`000?mOZ?SoGjSho`0000;oMk;h
00?o0000oi:llonB_?<00_nB_?<00ol0003oZ/7Zoj[1jP02o`0000So^;gN0_l000000oo1^]Co0000
okbcd@07okbcd@03o`000?nf[M3o]Zg@00?o]Zg@3_l00007ojVSd@03o`000?nQX=?o000000;o0000
1_nT[Md00ol0003oWjcPo`000003ojJnjP;o00001?n/dO<2o`000004ojkRnOl0003o0000ojg/n0Co
00000_n/koL2o`000003ojkYnOl0003o000000;o[]gh00Co0000ojc>l_n/c_;o[<kb0_l00003ojNo
jP;o00000onS/^<00ol0003oX;;Uo`000005oiZYh003o`000?nGXmgoUj?M00;oUj?M00?o0000oiFQ
g?nEXM`00onEXM`00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`0004;ooooo00?o0000olC8gOo4
b=d00oo4b=d01Ol0003o`/SNol;8g_o2b=ko000000;o`<7J1_nl`Mh2o`0000Co]<7S00?o0000ojRo
jonX_n/00_nX_n/01?l0003oU[cboiJll_nF_?82o`0000;oOkGg0_l00002ofN/n0?o00000_mBXoH0
1?l0003oGjShoenXn?l00002ogNbn004o`000?nB_??oT[ccoi:ll`?o00000onY`>X2o`0000Oo^;gN
00?o0000okbcdOnl/m401onl/m400ol0003o]Zg@okJ]d006okJ]d003o`000?n_Z=3o[jS@00Ko[jS@
00?o0000ojVSdOnYXm401OnYXm43o`0000WoY:gM1?l000000onV_^[o0000ojcAl`04ojcAl`04o`00
0?n^h_Wo[^;io`0000;o[Nch00?o0000ojc_mol000000on/koL01?l0003o[^WiojkYnOl00002ojkM
n0;o00000on/c_800ol0003oYkoZojNojP02ojNojP03o`000?nS/^?oXk;S00?oXk;S0ol00004oiZY
h003o`000?nGXmgoUj?M00;oUj?M00?o0000oiFQg?nEXM`00onEXM`00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`10ooooo`03o`000?o4b=goa<SM00?oa<SM00?o0000ol;8g_l0
00001?o0`MX00ol0003o_<7Nokc1gP04okc1gP03o`000?nd`N?o]<7S00;o]<7S00?o0000ojRojonX
_n/00_nX_n/00ol0003oU[cboiJllP02oiJllP05o`000?mo]OOoOkGgognemol000000_mW[?P00ol0
003oEJCgo`000002oe:SmP04o`000?mOZ?SoGjSho`0000;oMk;h00?o0000oi:llol000000onB`?H0
0ol0003oZL3ZojW0jP02ojW0jP?o00001?nh_Mh00ol0003o]KWLokFig005o`000003okbcdOl0003o
]Zg@00So]Zg@00?o0000ojnXd?n_Z=001on_Z=000ol0003oZJ?Ao`000004o`0000;oZJoL00?o0000
ojB]gOnT[Md01?nT[Md3o`0000?oYkkZ0ol00003ojcAl`;o000000Co[^;io`000?l0003o[Nch1?l0
0002ojc_m`;o000000?o[^Wio`000?l000000_n^gOP01?l0003o[<kbojc>l_n/c_82o`0000?oYkoZ
0_l00005oj>bh`04o`000?nOZMgoWjWMoinYg@;o000000?oVZWPo`000?nGXmd00onGXmd00ol0003o
UJ7LoiFQg003oiFQg003o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo043ooooo
00?o0000olC8gOo4b=d00_o4b=d2o`0000Oo`<7J00?o0000okc1g_nl`Mh00onl`Mh2o`0000?o]<7S
00?o0000ojRojonX_n/00_nX_n/2o`0000?oU[cb00?o0000ognemomo]OL04?l00006oi;0mP;o0000
1?nY`>X2o`000003okRmg_l0003o]KWL00Oo]KWL0_l000000onf[M3o0000o`000002o`0000Co]Zg@
00?o0000ojnXd?n_Z=000_n_Z=07o`0000SoZJoL00?o0000ojB]gOnT[Md00ol00003ojNnjP?o0000
0onWdOH00ol0003o[=7co`000002ojkRn@06o`000?n]k?So0000o`000?n/koOo00000on/koL01?l0
003o[^Wio`000?l00003ojkMn003o`000?n/c_;o[<kb00;o00000onW_nX2o`0000GoXk;S0_l00005
oinYg@?o00000onGXmd00ol0003oUJ7LoiFQg003oiFQg003o`000?oooooooooo01Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo043ooooo00Co0000olC8gOl0003o00000oo2`MT7ol31fP;o00001Onl`Mh0
1?l0003o]<7SokC1hond`N<2o`0000CoZ;o[00?o0000oiJll_nF_?800ol00003ogfln`?oH;?k0_m9
ZoP3odFXm`04o`000?mF[o[oEZojo`0000;oM;[l00?o0000oi;0m_nB`?H01?nB`?H2o`0000CoZL3Z
00?o0000okFig?ne^M`02?ne^M`00ol0003o/KGKok6ef`03ok6ef`Wo00001On^/M/00ol0003oZJoL
ojV_g006ojV_g0Co00001?nW_^X2o`0000KoYm7f3?l000001?n/koOo0000ojkYnOl00003ojkMn0;o
00000_n/c_800ol0003oYkoZojNojP02ojNojP03o`000?nS/^?oXk;S00CoXk;S00?o0000oinYgOnO
ZMd00onOZMd2o`0000?oWJ?I00?o0000oiNSgOl000001OnEXM`00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool000cooooo00?oEEEEofIVI_l00000
4Oooool2o`00047ooooo00?o0000ol;1fOo2`MT01?o2`MT2o`0000Ko`<7J00?o0000okc1g_nl`Mh0
0onl`Mh00ol0003o]<7SokC1h`02okC1h`04o`000?nX_n_oZ;o[ojRoj`?o00000onG`?@00ol0003o
OKckogfln`02ogfln`04o`000?mP/o_oH;?kof2cn`;oBJ_h0_m5Z?L2o`0000;oEZoj00?o0000ogBj
o?md^_`00ol00003oi;0mP;o000000?oZL3Zo`000?nY_nX00onY_nX5o`000003okFig?l0003o/KGK
00Wo/KGK00?o0000ojjafon^/M/01on^/M/00ol0003oZJoLojV_g003ojV_g0?o00000onW_^X00ol0
003oYkkZo`000002o`0000GoYm7f2ol00003oi;Yn0Ko000000Co[]gho`000?n/c_;o[<kb0_l00003
ojNojP;o00001OnS/^<2o`0000GoWjWM00?o0000oifSfOnMXmT00onMXmT2o`0000GoUJ7L00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000Roooo
o`03o`000?oooooooooo043ooooo1oo2`MT00ol0003o`<7Jol31fP04ol31fP03o`000?nl`Mko_<7N
00?o_<7N0_l00003okC1h`03o`000?nX_n_o000000?oZ;oZ00?o0000oiO0m?nG`?@00_nG`?@2o`00
00?oOKck0_l00002of2cn`04o`000?m9ZoSo0000odFXm`?o000000?oEZojo`000?l000000_md^_`3
o`0000;oT/3f00?o0000ojVoj_nY_nX02?nY_nX2o`0000;o/KGK1?l00004ok6ef`03o`000?n^/M_o
[[7K00So[[7K00?o0000ojV_g?l000000_l00005ojNnjP?o00001OnWdOH3o`000003oj7Qo?l0003o
000000;o000000?oTNWgo`000?l000000onBjOP5o`0000?oXmgk0ol000000on/c_;o0000ojNojP02
ojNojP;o00001_nS/^<00ol0003oWjWMoinYg@03oinYg@;o00001OnMXmT01?l0003oW:7HoibQf?l0
0003oiFQg003o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`04ooooo`008oooool00ol0003oooooooooo`10ooooo`03o`000?o2`MWo`/7I00Co`/7I0_l00005
ol31fP;o00001Onl`Mh01Ol0003o]<7SokC1hond`N?o000000OoZ;oZ00?o0000oiO0m?nG`?@00_nG
`?@2o`0000?oOKck0_l000001?mP/o_o0000odV[n?l00002odFXm`;o000000CoEZojo`000?l0003o
00000_md^_`00ol0003oU<CgoiC4m`02oiC4m`Co00001OnY_nX00ol0003oZKoYojVoj@04ojVojA7o
00001?nW_^X4o`0000?oXLoh00?o0000ojOAm_l000000_l00002oj7Qo0Co000000?oTNWgo`000?l0
00000_nBjOP5o`0000?oXmgk0ol00002ojO>m0Co000000?oYkoZo`000?nS/^<01OnS/^<2o`0000Co
WjWM0_l00005oifSf@;o00001?nLXMP00ol0003oUJ7Lo`00000Pooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01?ooool002Cooooo0_l00012ooooo`03o`000?o2`MWo`/7I00Co`/7I
00?o0000ol31f_o0`MX01?o0`MX00ol0003o_<7Nokc1gP03okc1gP03o`000?nd`N?o000000;o/kkR
00?o0000ojRoj_nX_nX01OnX_nX2o`0000?oUl3d0_l00003ogfln`;o00000_mP/o/01?l0003oBJ_h
o`000?m5Z?L2o`000003oeJ_n_l0003o000000CoM<;n00?o0000oiC4monDa?L00onDa?L3o`000003
ojVoj_l0003oZKoY00[oZKoY00?o0000ojRnjOnX_^T02?nX_^T00ol0003oYkkZojNnjP03o`0000Ko
XLoh1?l000000onQhOco0000o`000006o`000003oi;Yn?l0003o000000Co00000_nSgO/3o`0000;o
Ylkd0ol00003ojRojP;o00001_nS/^<00ol0003oWjWMoinYg@03oinYg@03o`000?nMXmWoWJ?I00Co
WJ?I00?o0000oibQf?nLXMP01?nLXMP2o`0002;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`009_ooool00ol0003oooooooooo`10ooooo`03o`000?o2`MWo`/7I00Co`/7I
00?o0000ol31f_o0`MX01?o0`MX2o`0000?o_<7N0_l00006ok>nhP;o00001_nX_nX2o`0000;oUl3d
0ol00002ogfln`;o000000?oH;?ko`000?l000001?l00004oe:in`;o00001?md`_h4o`000003oiC4
mol0003o000000;oZKoY1?l00005ojVoj@03o`000?nX_^WoZ;kY00?oZ;kY2?l00005oj7?n0Co0000
0_nBg?h5o`000004oi7Ymol0003o0000oi;Yn0?o000000?oVnKlo`000?l000000onSgO/2o`0000;o
Ylkd0ol00003ojRojP?o00000_nV/n401?l0003oXk;Soj>bhonS/^<2o`0000CoWjWM0_l00005oifS
f@;o00001_nLXMP00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool002Oooooo00?o0000ooooooooool0@?ooool2o`0000Go`/7I0_l00006ol31fP03
o`000?nl`Mko000000?o^[cK00?o0000ok>nh_nc_^801?nc_^83o`0000GoZ;oZ0_l00003oiO0m0;o
000000?oOKcko`000?l000001?mN_?d01?l0003oAK?go`000?lo/OD2o`0000GoD[Wk1?l000000omd
`_ko0000o`000007oiO8n0_o00001_nLc?P00ol0003oXLohoj7?n004o`000003oi;Lo_l0003o0000
00Go000000?oL]cdo`000?l000001?l000001?nKi_co0000o`000?l00002oj?Mn`?o00000_nWc_@2
o`0000CoZ;oZ0_l00006ojJch@03o`000?nS/^?o000000CoWjWM0_l00005oifSf@;o00001_nLXMP2
o`0002Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0
003oooooooooo`11ooooo`03o`000?o2`MWo`/7I00Co`/7I00?o0000ol31f_o0`MX01?o0`MX00ol0
003o^[cKokZlf`05okZlf`;o00001Onc_^83o`0000CoZ;oZ0ol00002oiO0m003o`000?mn`ogoO/?m
00;oO/?m00?o0000oejloOmN_?d00omN_?d2o`000003odFcmol0003o?k7e00Co00000_mB^O/2o`00
00SoN/_o6ol000000ombg?Co0000o`000005o`000003ohKNoOl0003o000000?o000000CoXmgko`00
0?l0003o00000_nWc_@3o`0000?oZ;oZ0ol00008ojJch@;o00001?nOZMd00ol0003oWJ?IoifSf@04
oifSf@03o`000?nLXMSoW:7H00GoW:7H00?o0000ooooooooool09oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo000Yooooo`;o0000@_ooool2o`0000Go`/7I0_l00003ol31
fP04o`000?nm^]Oo_K[Go`0000Oo^[cK0ol00005ok>nhP;o00001OnX_nX00ol0003oV<?foiS3mP02
oiS3mP03o`000?mn`ogoO/?m00?oO/?m0ol00002oejlo@Co000000CoAK?go`000?l0003o00002OmH
a?XGo`000003og;Lm?l0003o000000_o00000onGfOh4o`000004ojO>m?l0003o0000o`0000?oZ;oZ
0ol00008ojJch@?o00000_nUZ]X01?l0003oWjWMo`000?l00005oifSf@;o00001_nLXMP2o`0002_o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003ooooo
ooooo`11ooooo`03o`000?o2`MWo`/7I00Co`/7I00?o0000ol31f_l000001_nm^]L2o`0000Ko^[cK
0ol00004ok>nhP?o000000?oZ;oZo`000?nX_nX00_nX_nX00ol0003oV<?foiS3mP03oiS3mP?o0000
0omn`od4o`000003oejloOl0003o000000GoBkkd1?l000000om5_?;o0000o`00000No`0000CoUmWn
1Ol00002oj?=mP?o00001?nX_nX2o`0000SoY[?Q0ol00005ojFZfP;o00001_nMXmT00ol0003oW:7H
oibQf004oibQf0;o0000;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo
000/ooooo`03o`000?oooooooooo047ooooo00?o0000ol;1fOo2`MT01?o2`MT00ol0003o_K[Gokfj
e`07okfje`;o00001onj_=/2o`0000Go/kkR00?o0000ojRoj_nX_nX01OnX_nX4o`0000CoV<?f1?l0
00000omn`ogo0000o`000005ofC7o@Go00001?m;__@;o`000003oe_=m?l0003o000000[o00001OnG
fOh4o`0000;oXlgf1Ol00002ojRojP03o`000?nX_n[o000000;o00001onV/n43o`0000GoYJ[J0ol0
0002ojBUeP04o`000?nMXmWoWJ?IoifSf@;o00001_nLXMP00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool002gooooo00?o0000ooooooooool0@Ooo
ool2o`0000?o`/7I00Co0000okjjeOnn^]Go00002Onm^]L3o`0000Ko^[cK0ol000000onc_^;o0000
ok6kh002ok6kh003o`000?nX_n[oZ;oZ00KoZ;oZ1?l00004oiS3mP;o00002_n3bol5ofC7o@co0000
2On<dol00ol0003oUmWnoiOIoP05o`000003oj?=m_l0003o000000?o00001_nX_nX3o`0000SoY[?Q
0_l00006ojFZfP;o00001_nTYMH00ol0003oWJ?Io`000006oibQf0;o0000<_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000^ooooo`;o0000@oooool00ol0003o`/7Io`00
0006okjje@;o00002?nm^]L2o`0000Oo^[cK00?o0000ok6kh?na^n001_na^n04o`0000GoZ;oZ0ol0
0002oiS3mP03o`000?nKaoKoVlOf00?oVlOf2Ol00004oh?;o`03o`000?n<doooS=?o00OoS=?o2ol0
00000onScOKo0000o`000003o`0000KoZ;oZ1Ol00002ojVdh003o`000?nV/n7oY[?Q00?oY[?Q0ol0
0006ojFZfP;o00002?nTYMH2o`0000KoW:7H00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000
okjjeOnn^]D01onn^]D3o`0000Oo_K[G0_l00005okZlf`03o`000?ng]mWo]kOI00;o00002?na^n03
o`0000GoZ;oZ0_l0000?oi_7mQ[o00001_nX_nX5o`0000SoZKCP00?o0000ojJchOl000000_l00006
ojFZfP?o00001onTYMH3o`0000;oXj?E00Co0000oibQf?nLXMSoW:7H0_l0000gooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool0037ooooo00?o0000ooooooooool0@_ooool0
0ol0003o_[[Eokjje@08okjje@;o00001onm^]L3o`000003okZlfol0003o]kOI00Ko]kOI1?l00005
ok6kh0Co00000_nX_nX00ol0003oZ;oZojRojP08ojRojQ?o00002_nX_nX00ol0003oZ;oZojRojP05
o`0000_oZKCP1?l00007ojFZfP;o00002?nTYMH2o`0000KoXj?E00?o0000oibQf?l00000>Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03o`000?oooooooooo
04Cooooo0ol00007okjje@?o00001onm^]L00ol0003o]kOIokNgf@0:okNgf@Co00001Ona^n02o`00
01CoZ;oZ00?o0000ojRoj_nX_nX03OnX_nX7o`0000_oZKCP1Ol00003ojZ/f@03o`000?nUZ][oYJ[J
00?oYJ[J0_l00007ojBUeP?o00002?nSXmD2o`0003_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`00<oooool2o`0004Oooooo0_l00008okjje@;o00001Onm^]L00ol0003o
^KCEokVde@04o`0000[o]kOI1?l00002ok6kh003o`000?n_^=oo[kSO00?o[kSO2ol00004ojRojP03
o`000?nX_n[oZ;oZ00;oZ;oZ2ol00005ojbfg`03o`000?nY]>3oZKCP00GoZKCP1Ol00009ojZ/f@03
o`000?nUZ][o000000;o00001onTYMH2o`0000SoXj?E0ol0000nooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0A_ooool3o`0000Oo_[[E
0ol000000onm^]Oo0000okVde@06okVde@Go00002Ong]mT2o`00017o[kSO2Ol0000@ojbfg`03o`00
0?nY]>3oZKCP00Go00003?nZ[=T4o`0000OoY:GF0ol00007oj>Se@?o0000@_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo04Sooooo0_l0
0008okjje@03o`000?ni]=Go^KCE00_o^KCE1?l00006okNgf@03o`000?nc/]So/k;H00Co/k;H2ol0
0004ojnhg`03o`000?n/]]oo[;KO00So[;KO3Ol0000<ojZ/f@Go00000onYYm@00ol0003oY:GFojBU
eP03ojBUeP;o00001onSXmD3o`0004Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`00=oooool00ol0003oooooooooo`19ooooo`?o00001Onn^]D00ol0003o^[?CokZcd`04
o`0000_o^KCE1?l000000ong]mWo0000ok>bf00Aok>bf0oo00002_n^[mP00ol0003oZZcIojZ/f@06
ojZ/f@Ko00002OnYYm@00ol0003oY:GFo`000002o`0000OoXj?E0_l00019ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00Oooool003Sooooo0_l0001<ooooo`?o000000?o_[[Eo`00
0?nj/m<01_nj/m<3o`0000co^KCE0_l0000Fok>bf003o`000?n^[mSo[ZoH01?o[ZoH00?o0000ojZ/
fOnZ[=T01Ol0000=ojVWe0Co00001onSXmD3o`0004cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`01ooooo`00>_ooool00ol0003oooooooooo`1<ooooo`03o`000?nj/m?o^[?C00Wo
^[?C1?l00009okVde@03o`000?nd[m?o]:oC00Co]:oC2ol00005ok>bf003o`000?n^[mSo[ZoH00So
[ZoH3_l0000<ojVWe0Ko00000onYY]<00ol0003oXj?Eoj>Se@02oj>Se@?o0000D?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000kooooo`03o`000?oooooooooo04kooooo
0_l0000;okZcd`Co00001Oni]=D00ol0003o]:oCokB_d`0?okB_da3o00002on_Zm<00ol0003oZJOD
ojVWe007ojVWe0Go00002_nYY]<4o`0005?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00??ooool2o`0005;ooooo1?l00009okZcd`?o000000?o^KCEo`000?nd[m<05_nd
[m<00ol0003o[j_Cojn[d`0Dojn[d`03o`000?nYYmCoZJOD00Ko00003OnYY]<3o`0005Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?_ooool00ol0003oooooooooo`1C
ooooo`?o00002Onj/m<2o`0000Go]:oC00?o0000okB_dond[m<03ond[m<00ol0003o[j_Cojn[d`0>
ojn[d`Wo00003_nYY]<5o`0005_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01
ooooo`00?oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo000000?o00001_nj/m<00ol0
003o]JkBokF^dP04okF^dP_o00001Ond[m<00ol0003o[j_Cojn[d`03ojn[d`co00001_n_ZM800ol0
003oZJKCojVVd`09ojVVd`Go0000HOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo0010ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00oooool4o`000003
okZcdol0003o]JkB017o]JkB2ol0000BojnYdP03o`000?nYY]?oZJKC00GoZJKC1?l0001Vooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Booooo`03o`00
0?oooooooooo00Oooooo0_l0000GokF^dP03o`000?n_ZM;o[jWB01Ko[jWB00?o0000ojVVdol00000
1?l0001[ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool03oooool<o`0000Go]JkB00?o0000ojnYd_n_ZM802_n_
ZM8>o`00077ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Cooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Koooooa;o0000P?ooool00ol0003oooooooooo`06
ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo0_l0001=ooooo`03
o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01?ooool1o`00007ooooo001;oooo
o`;o0000B?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`00COooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`2cooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo0_l0
0013ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo00000Oooool005;ooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo0000007ooooo001C
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`01
o`000000E?ooool2o`0003oooooo00?o0000ooooooooool0]_ooool1o`00007ooooo0Ol0000005Ko
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`;o0000001Gooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0]_ooool3o`000000F?ooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo0;;ooooo1?l00003ooooo`00FOooool2o`0003[ooooo00?o0000
ooooooooool0[_ooool4o`0000Oooooo001Kooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0Z_ooool4o`0000_ooooo001Looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0Y_ooool4o`0000oooooo001Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
X_ooool4o`0001?ooooo001Nooooo`;o0000=Oooool00ol0003oooooooooo`2Nooooo`Co00005ooo
ool0063ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`Co00006oooool0
067ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Hooooo`?o00007oooool006;o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`Co00008_ooool006?ooooo
0_l0000_ooooo`03o`000?oooooooooo093ooooo1?l0000Vooooo`00IOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo08cooooo1?l0000Zooooo`00I_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo08Sooooo1?l0000^ooooo`00Ioooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08Cooooo1?l0000booooo`00J?ooool2o`0002[ooooo00?o0000oooooooo
ool0P?ooool4o`0003Kooooo001Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
O?ooool4o`0003[ooooo001[ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?oo
ool4o`0003kooooo001/ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4
o`0004;ooooo001]ooooo`;o00009Oooool00ol0003oooooooooo`1`ooooo`Co0000A_ooool006oo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`Co0000B_ooool0073ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000C_ooool0077ooooo0_l0
000Qooooo`03o`000?oooooooooo06Cooooo1?l0001Booooo`00Loooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo063ooooo1?l0001Fooooo`00M?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05cooooo1?l0001Jooooo`00MOooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo05Wooooo0ol0001Nooooo`00M_ooool2o`0001cooooo00?o0000ooooooooool0
EOooool4o`00067ooooo001hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOoo
ool4o`0006Gooooo001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool4
o`0006Wooooo001jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`00
06gooooo001kooooo`;o00005oooool00ol0003oooooooooo`15ooooo`Co0000LOooool007gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`Co0000MOooool007kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0mooooo`Co0000NOooool007oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0iooooo`Co0000OOooool0083ooooo0_l0000Boooo
o`03o`000?oooooooooo03Gooooo1?l00021ooooo`00P_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo037ooooo1?l00025ooooo`00Poooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02kooooo1?l00029ooooo`00Q?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02[ooooo1?l0002=ooooo`00QOooool2o`0000cooooo00?o0000ooooooooool09_ooool4
o`00097ooooo0027ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`00
09Gooooo0028ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`0009Wo
oooo0029ooooo`;o00002?ooool00ol0003oooooooooo`0Kooooo`?o0000WOooool008_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`Co0000X?ooool008cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`Co0000Y?ooool008gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`Co0000Z?ooool008kooooo0_l00003ooooo`03
o`000?oooooooooo00_ooooo1?l0002/ooooo`00T?ooool01?l0003oooooooooool00009ooooo`Co
0000/?ooool0097ooooo00?o0000ooooool000001Oooool4o`000;Cooooo002Booooo`;o000000?o
ooooo`000?l000000_l0002hooooo`00Toooool2o`000;cooooo003ooooooe;ooooo003ooooooe;o
oooo003ooooooe;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65567 m .51694 .65827 L .43899 .65168 L p .394 .781 .99 r
F P
0 g
s
.51694 .65827 m .51723 .65567 L .59271 .65149 L p .446 .826 .99 r
F P
0 g
s
.59271 .65149 m .59527 .65394 L .51694 .65827 L p .446 .826 .99 r
F P
0 g
s
.59527 .65394 m .59271 .65149 L .66488 .63689 L p .52 .868 .99 r
F P
0 g
s
.66488 .63689 m .67023 .63881 L .59527 .65394 L p .52 .868 .99 r
F P
0 g
s
.44214 .64931 m .43899 .65168 L .36521 .63435 L p .372 .741 .99 r
F P
0 g
s
.43899 .65168 m .44214 .64931 L .51723 .65567 L p .394 .781 .99 r
F P
0 g
s
.51754 .65268 m .51723 .65567 L .44214 .64931 L p .437 .79 .997 r
F P
0 g
s
.51723 .65567 m .51754 .65268 L .59011 .64865 L p .483 .83 .997 r
F P
0 g
s
.59011 .64865 m .59271 .65149 L .51723 .65567 L p .483 .83 .997 r
F P
0 g
s
.59271 .65149 m .59011 .64865 L .65946 .6346 L p .546 .865 .995 r
F P
0 g
s
.65946 .6346 m .66488 .63689 L .59271 .65149 L p .546 .865 .995 r
F P
0 g
s
.36521 .63435 m .37112 .63259 L .44214 .64931 L p .372 .741 .99 r
F P
0 g
s
.44534 .64655 m .44214 .64931 L .37112 .63259 L p .415 .753 .995 r
F P
0 g
s
.44214 .64931 m .44534 .64655 L .51754 .65268 L p .437 .79 .997 r
F P
0 g
s
.51784 .6488 m .51754 .65268 L .44534 .64655 L p .519 .797 .996 r
F P
0 g
s
.51754 .65268 m .51784 .6488 L .58747 .64492 L p .552 .825 .997 r
F P
0 g
s
.58747 .64492 m .59011 .64865 L .51754 .65268 L p .552 .825 .997 r
F P
0 g
s
.67023 .63881 m .66488 .63689 L .73002 .61232 L p .602 .899 .987 r
F P
0 g
s
.73002 .61232 m .73799 .61332 L .67023 .63881 L p .602 .899 .987 r
F P
0 g
s
.59011 .64865 m .58747 .64492 L .65396 .63141 L p .593 .847 .993 r
F P
0 g
s
.65396 .63141 m .65946 .6346 L .59011 .64865 L p .593 .847 .993 r
F P
0 g
s
.37112 .63259 m .37711 .63046 L .44534 .64655 L p .415 .753 .995 r
F P
0 g
s
.44858 .6429 m .44534 .64655 L .37711 .63046 L p .501 .768 .991 r
F P
0 g
s
.44534 .64655 m .44858 .6429 L .51784 .6488 L p .519 .797 .996 r
F P
0 g
s
.37112 .63259 m .36521 .63435 L .29943 .6068 L p .378 .707 .985 r
F P
0 g
s
.51816 .64359 m .51784 .6488 L .44858 .6429 L p .599 .783 .969 r
F P
0 g
s
.51784 .6488 m .51816 .64359 L .58478 .63987 L p .614 .796 .969 r
F P
0 g
s
.58478 .63987 m .58747 .64492 L .51784 .6488 L p .614 .796 .969 r
F P
0 g
s
.66488 .63689 m .65946 .6346 L .72196 .61096 L p .615 .889 .989 r
F P
0 g
s
.72196 .61096 m .73002 .61232 L .66488 .63689 L p .615 .889 .989 r
F P
0 g
s
.58747 .64492 m .58478 .63987 L .64835 .6269 L p .633 .806 .966 r
F P
0 g
s
.64835 .6269 m .65396 .63141 L .58747 .64492 L p .633 .806 .966 r
F P
0 g
s
.37711 .63046 m .38319 .62743 L .44858 .6429 L p .501 .768 .991 r
F P
0 g
s
.45189 .63793 m .44858 .6429 L .38319 .62743 L p .588 .768 .965 r
F P
0 g
s
.44858 .6429 m .45189 .63793 L .51816 .64359 L p .599 .783 .969 r
F P
0 g
s
.29943 .6068 m .30791 .60604 L .37112 .63259 L p .378 .707 .985 r
F P
0 g
s
.37711 .63046 m .37112 .63259 L .30791 .60604 L p .417 .719 .987 r
F P
0 g
s
.51848 .63677 m .51816 .64359 L .45189 .63793 L p .653 .754 .924 r
F P
0 g
s
.51816 .64359 m .51848 .63677 L .58204 .63321 L p .654 .754 .924 r
F P
0 g
s
.58204 .63321 m .58478 .63987 L .51816 .64359 L p .654 .754 .924 r
F P
0 g
s
.65946 .6346 m .65396 .63141 L .71378 .60871 L p .637 .861 .984 r
F P
0 g
s
.71378 .60871 m .72196 .61096 L .65946 .6346 L p .637 .861 .984 r
F P
0 g
s
.58478 .63987 m .58204 .63321 L .64265 .62079 L p .654 .755 .924 r
F P
0 g
s
.64265 .62079 m .64835 .6269 L .58478 .63987 L p .654 .755 .924 r
F P
0 g
s
.38319 .62743 m .38937 .62309 L .45189 .63793 L p .588 .768 .965 r
F P
0 g
s
.45525 .63135 m .45189 .63793 L .38937 .62309 L p .653 .753 .924 r
F P
0 g
s
.45189 .63793 m .45525 .63135 L .51848 .63677 L p .653 .754 .924 r
F P
0 g
s
.30791 .60604 m .31649 .60492 L .37711 .63046 L p .417 .719 .987 r
F P
0 g
s
.38319 .62743 m .37711 .63046 L .31649 .60492 L p .496 .74 .981 r
F P
0 g
s
.5188 .62823 m .51848 .63677 L .45525 .63135 L p .684 .723 .879 r
F P
0 g
s
.51848 .63677 m .5188 .62823 L .57925 .62483 L p .674 .714 .879 r
F P
0 g
s
.57925 .62483 m .58204 .63321 L .51848 .63677 L p .674 .714 .879 r
F P
0 g
s
.65396 .63141 m .64835 .6269 L .70546 .60514 L p .652 .812 .96 r
F P
0 g
s
.70546 .60514 m .71378 .60871 L .65396 .63141 L p .652 .812 .96 r
F P
0 g
s
.58204 .63321 m .57925 .62483 L .63684 .61296 L p .662 .707 .881 r
F P
0 g
s
.63684 .61296 m .64265 .62079 L .58204 .63321 L p .662 .707 .881 r
F P
0 g
s
.73799 .61332 m .73002 .61232 L .78434 .57863 L p .674 .91 .976 r
F P
0 g
s
.78434 .57863 m .79464 .57831 L .73799 .61332 L p .674 .91 .976 r
F P
0 g
s
.38937 .62309 m .39567 .61714 L .45525 .63135 L p .653 .753 .924 r
F P
0 g
s
.45868 .62305 m .45525 .63135 L .39567 .61714 L p .693 .734 .882 r
F P
0 g
s
.45525 .63135 m .45868 .62305 L .5188 .62823 L p .684 .723 .879 r
F P
0 g
s
.51913 .61809 m .5188 .62823 L .45868 .62305 L p .701 .698 .844 r
F P
0 g
s
.5188 .62823 m .51913 .61809 L .57641 .61484 L p .683 .683 .843 r
F P
0 g
s
.57641 .61484 m .57925 .62483 L .5188 .62823 L p .683 .683 .843 r
F P
0 g
s
.31649 .60492 m .32519 .60292 L .38319 .62743 L p .496 .74 .981 r
F P
0 g
s
.38937 .62309 m .38319 .62743 L .32519 .60292 L p .582 .753 .959 r
F P
0 g
s
.57925 .62483 m .57641 .61484 L .63095 .60353 L p .664 .671 .847 r
F P
0 g
s
.63095 .60353 m .63684 .61296 L .57925 .62483 L p .664 .671 .847 r
F P
0 g
s
.64835 .6269 m .64265 .62079 L .697 .59997 L p .655 .755 .923 r
F P
0 g
s
.697 .59997 m .70546 .60514 L .64835 .6269 L p .655 .755 .923 r
F P
0 g
s
.39567 .61714 m .40208 .60947 L .45868 .62305 L p .693 .734 .882 r
F P
0 g
s
.46217 .61315 m .45868 .62305 L .40208 .60947 L p .717 .716 .848 r
F P
0 g
s
.45868 .62305 m .46217 .61315 L .51913 .61809 L p .701 .698 .844 r
F P
0 g
s
.30791 .60604 m .29943 .6068 L .24558 .56996 L p .405 .679 .973 r
F P
0 g
s
.51946 .60665 m .51913 .61809 L .46217 .61315 L p .71 .681 .82 r
F P
0 g
s
.51913 .61809 m .51946 .60665 L .57354 .60356 L p .687 .662 .819 r
F P
0 g
s
.57354 .60356 m .57641 .61484 L .51913 .61809 L p .687 .662 .819 r
F P
0 g
s
.73002 .61232 m .72196 .61096 L .77394 .57859 L p .677 .897 .976 r
F P
0 g
s
.77394 .57859 m .78434 .57863 L .73002 .61232 L p .677 .897 .976 r
F P
0 g
s
.32519 .60292 m .33403 .59959 L .38937 .62309 L p .582 .753 .959 r
F P
0 g
s
.39567 .61714 m .38937 .62309 L .33403 .59959 L p .652 .753 .923 r
F P
0 g
s
.57641 .61484 m .57354 .60356 L .62498 .59281 L p .663 .646 .823 r
F P
0 g
s
.62498 .59281 m .63095 .60353 L .57641 .61484 L p .663 .646 .823 r
F P
0 g
s
.64265 .62079 m .63684 .61296 L .68841 .59309 L p .65 .703 .885 r
F P
0 g
s
.68841 .59309 m .697 .59997 L .64265 .62079 L p .65 .703 .885 r
F P
0 g
s
.40208 .60947 m .40859 .60021 L .46217 .61315 L p .717 .716 .848 r
F P
0 g
s
.4657 .60195 m .46217 .61315 L .40859 .60021 L p .73 .703 .825 r
F P
0 g
s
.46217 .61315 m .4657 .60195 L .51946 .60665 L p .71 .681 .82 r
F P
0 g
s
.5198 .59439 m .51946 .60665 L .4657 .60195 L p .714 .671 .807 r
F P
0 g
s
.51946 .60665 m .5198 .59439 L .57064 .59147 L p .689 .65 .807 r
F P
0 g
s
.57064 .59147 m .57354 .60356 L .51946 .60665 L p .689 .65 .807 r
F P
0 g
s
.24558 .56996 m .25632 .5706 L .30791 .60604 L p .405 .679 .973 r
F P
0 g
s
.31649 .60492 m .30791 .60604 L .25632 .5706 L p .437 .691 .972 r
F P
0 g
s
.72196 .61096 m .71378 .60871 L .7634 .57767 L p .677 .864 .97 r
F P
0 g
s
.7634 .57767 m .77394 .57859 L .72196 .61096 L p .677 .864 .97 r
F P
0 g
s
.33403 .59959 m .34303 .59466 L .39567 .61714 L p .652 .753 .923 r
F P
0 g
s
.40208 .60947 m .39567 .61714 L .34303 .59466 L p .701 .746 .886 r
F P
0 g
s
.57354 .60356 m .57064 .59147 L .61896 .58129 L p .662 .633 .811 r
F P
0 g
s
.61896 .58129 m .62498 .59281 L .57354 .60356 L p .662 .633 .811 r
F P
0 g
s
.4657 .60195 m .46926 .58994 L .5198 .59439 L p .714 .671 .807 r
F P
0 g
s
.52014 .58193 m .5198 .59439 L .46926 .58994 L p .714 .67 .805 r
F P
0 g
s
.5198 .59439 m .52014 .58193 L .56772 .57917 L p .689 .649 .804 r
F P
0 g
s
.56772 .57917 m .57064 .59147 L .5198 .59439 L p .689 .649 .804 r
F P
0 g
s
.40859 .60021 m .41517 .58966 L .4657 .60195 L p .73 .703 .825 r
F P
0 g
s
.46926 .58994 m .4657 .60195 L .41517 .58966 L p .737 .696 .812 r
F P
0 g
s
.63684 .61296 m .63095 .60353 L .67969 .58461 L p .643 .662 .854 r
F P
0 g
s
.67969 .58461 m .68841 .59309 L .63684 .61296 L p .643 .662 .854 r
F P
0 g
s
.57064 .59147 m .56772 .57917 L .61291 .56958 L p .662 .631 .809 r
F P
0 g
s
.61291 .56958 m .61896 .58129 L .57064 .59147 L p .662 .631 .809 r
F P
0 g
s
.34303 .59466 m .35216 .58803 L .40208 .60947 L p .701 .746 .886 r
F P
0 g
s
.40859 .60021 m .40208 .60947 L .35216 .58803 L p .731 .736 .856 r
F P
0 g
s
.25632 .5706 m .26715 .57089 L .31649 .60492 L p .437 .691 .972 r
F P
0 g
s
.32519 .60292 m .31649 .60492 L .26715 .57089 L p .504 .715 .967 r
F P
0 g
s
.71378 .60871 m .70546 .60514 L .7527 .57543 L p .67 .813 .952 r
F P
0 g
s
.7527 .57543 m .7634 .57767 L .71378 .60871 L p .67 .813 .952 r
F P
0 g
s
.41517 .58966 m .42181 .5783 L .46926 .58994 L p .737 .696 .812 r
F P
0 g
s
.47284 .57773 m .46926 .58994 L .42181 .5783 L p .738 .695 .81 r
F P
0 g
s
.46926 .58994 m .47284 .57773 L .52014 .58193 L p .714 .67 .805 r
F P
0 g
s
.52048 .56992 m .52014 .58193 L .47284 .57773 L p .712 .676 .814 r
F P
0 g
s
.52014 .58193 m .52048 .56992 L .56479 .56733 L p .688 .656 .813 r
F P
0 g
s
.56479 .56733 m .56772 .57917 L .52014 .58193 L p .688 .656 .813 r
F P
0 g
s
.63095 .60353 m .62498 .59281 L .67088 .57485 L p .637 .635 .832 r
F P
0 g
s
.67088 .57485 m .67969 .58461 L .63095 .60353 L p .637 .635 .832 r
F P
0 g
s
.56772 .57917 m .56479 .56733 L .60684 .55834 L p .662 .64 .817 r
F P
0 g
s
.60684 .55834 m .61291 .56958 L .56772 .57917 L p .662 .64 .817 r
F P
0 g
s
.35216 .58803 m .36142 .57979 L .40859 .60021 L p .731 .736 .856 r
F P
0 g
s
.41517 .58966 m .40859 .60021 L .36142 .57979 L p .749 .729 .834 r
F P
0 g
s
.42181 .5783 m .42848 .56676 L .47284 .57773 L p .738 .695 .81 r
F P
0 g
s
.47644 .56598 m .47284 .57773 L .42848 .56676 L p .734 .7 .819 r
F P
0 g
s
.47284 .57773 m .47644 .56598 L .52048 .56992 L p .712 .676 .814 r
F P
0 g
s
.62498 .59281 m .61896 .58129 L .66201 .5643 L p .633 .62 .819 r
F P
0 g
s
.66201 .5643 m .67088 .57485 L .62498 .59281 L p .633 .62 .819 r
F P
0 g
s
.52083 .559 m .52048 .56992 L .47644 .56598 L p .704 .692 .835 r
F P
0 g
s
.52048 .56992 m .52083 .559 L .56186 .55659 L p .685 .675 .835 r
F P
0 g
s
.56186 .55659 m .56479 .56733 L .52048 .56992 L p .685 .675 .835 r
F P
0 g
s
.26715 .57089 m .27813 .57029 L .32519 .60292 L p .504 .715 .967 r
F P
0 g
s
.33403 .59959 m .32519 .60292 L .27813 .57029 L p .582 .738 .95 r
F P
0 g
s
.70546 .60514 m .697 .59997 L .74184 .57158 L p .655 .755 .923 r
F P
0 g
s
.74184 .57158 m .7527 .57543 L .70546 .60514 L p .655 .755 .923 r
F P
0 g
s
.56479 .56733 m .56186 .55659 L .60077 .54821 L p .664 .662 .838 r
F P
0 g
s
.60077 .54821 m .60684 .55834 L .56479 .56733 L p .664 .662 .838 r
F P
0 g
s
.36142 .57979 m .37078 .57028 L .41517 .58966 L p .749 .729 .834 r
F P
0 g
s
.42181 .5783 m .41517 .58966 L .37078 .57028 L p .758 .725 .822 r
F P
0 g
s
.61896 .58129 m .61291 .56958 L .65309 .55358 L p .632 .617 .817 r
F P
0 g
s
.65309 .55358 m .66201 .5643 L .61896 .58129 L p .632 .617 .817 r
F P
0 g
s
.42848 .56676 m .43517 .5557 L .47644 .56598 L p .734 .7 .819 r
F P
0 g
s
.48004 .55533 m .47644 .56598 L .43517 .5557 L p .722 .711 .839 r
F P
0 g
s
.47644 .56598 m .48004 .55533 L .52083 .559 L p .704 .692 .835 r
F P
0 g
s
.52117 .54973 m .52083 .559 L .48004 .55533 L p .688 .718 .872 r
F P
0 g
s
.52083 .559 m .52117 .54973 L .55893 .5475 L p .676 .708 .872 r
F P
0 g
s
.55893 .5475 m .56186 .55659 L .52083 .559 L p .676 .708 .872 r
F P
0 g
s
.697 .59997 m .68841 .59309 L .73082 .56603 L p .637 .701 .892 r
F P
0 g
s
.73082 .56603 m .74184 .57158 L .697 .59997 L p .637 .701 .892 r
F P
0 g
s
.27813 .57029 m .28926 .56837 L .33403 .59959 L p .582 .738 .95 r
F P
0 g
s
.34303 .59466 m .33403 .59959 L .28926 .56837 L p .652 .752 .923 r
F P
0 g
s
.37078 .57028 m .3802 .55999 L .42181 .5783 L p .758 .725 .822 r
F P
0 g
s
.42848 .56676 m .42181 .5783 L .3802 .55999 L p .759 .724 .82 r
F P
0 g
s
.61291 .56958 m .60684 .55834 L .64417 .54335 L p .635 .627 .826 r
F P
0 g
s
.64417 .54335 m .65309 .55358 L .61291 .56958 L p .635 .627 .826 r
F P
0 g
s
.56186 .55659 m .55893 .5475 L .59471 .53975 L p .663 .7 .874 r
F P
0 g
s
.59471 .53975 m .60077 .54821 L .56186 .55659 L p .663 .7 .874 r
F P
0 g
s
.79464 .57831 m .78434 .57863 L .82406 .53716 L p .727 .901 .956 r
F P
0 g
s
.82406 .53716 m .83625 .53514 L .79464 .57831 L p .727 .901 .956 r
F P
0 g
s
.43517 .5557 m .44186 .54575 L .48004 .55533 L p .722 .711 .839 r
F P
0 g
s
.48364 .54633 m .48004 .55533 L .44186 .54575 L p .698 .73 .875 r
F P
0 g
s
.48004 .55533 m .48364 .54633 L .52117 .54973 L p .688 .718 .872 r
F P
0 g
s
.3802 .55999 m .38965 .54952 L .42848 .56676 L p .759 .724 .82 r
F P
0 g
s
.43517 .5557 m .42848 .56676 L .38965 .54952 L p .753 .727 .828 r
F P
0 g
s
.68841 .59309 m .67969 .58461 L .71967 .55889 L p .621 .657 .864 r
F P
0 g
s
.71967 .55889 m .73082 .56603 L .68841 .59309 L p .621 .657 .864 r
F P
0 g
s
.28926 .56837 m .30057 .56485 L .34303 .59466 L p .652 .752 .923 r
F P
0 g
s
.35216 .58803 m .34303 .59466 L .30057 .56485 L p .705 .758 .893 r
F P
0 g
s
.60684 .55834 m .60077 .54821 L .63526 .53427 L p .641 .652 .846 r
F P
0 g
s
.63526 .53427 m .64417 .54335 L .60684 .55834 L p .641 .652 .846 r
F P
0 g
s
.52151 .54249 m .52117 .54973 L .48364 .54633 L p .65 .755 .926 r
F P
0 g
s
.52117 .54973 m .52151 .54249 L .55599 .54045 L p .653 .757 .926 r
F P
0 g
s
.55599 .54045 m .55893 .5475 L .52117 .54973 L p .653 .757 .926 r
F P
0 g
s
.38965 .54952 m .39912 .53956 L .43517 .5557 L p .753 .727 .828 r
F P
0 g
s
.44186 .54575 m .43517 .5557 L .39912 .53956 L p .737 .733 .848 r
F P
0 g
s
.55893 .5475 m .55599 .54045 L .58864 .53335 L p .655 .758 .926 r
F P
0 g
s
.58864 .53335 m .59471 .53975 L .55893 .5475 L p .655 .758 .926 r
F P
0 g
s
.67969 .58461 m .67088 .57485 L .70842 .55047 L p .608 .627 .844 r
F P
0 g
s
.70842 .55047 m .71967 .55889 L .67969 .58461 L p .608 .627 .844 r
F P
0 g
s
.78434 .57863 m .77394 .57859 L .81177 .53883 L p .722 .888 .956 r
F P
0 g
s
.81177 .53883 m .82406 .53716 L .78434 .57863 L p .722 .888 .956 r
F P
0 g
s
.44186 .54575 m .44854 .53748 L .48364 .54633 L p .698 .73 .875 r
F P
0 g
s
.48724 .53938 m .48364 .54633 L .44854 .53748 L p .648 .753 .926 r
F P
0 g
s
.48364 .54633 m .48724 .53938 L .52151 .54249 L p .65 .755 .926 r
F P
0 g
s
.30057 .56485 m .31203 .55962 L .35216 .58803 L p .705 .758 .893 r
F P
0 g
s
.36142 .57979 m .35216 .58803 L .31203 .55962 L p .741 .759 .867 r
F P
0 g
s
.60077 .54821 m .59471 .53975 L .62635 .52687 L p .65 .695 .879 r
F P
0 g
s
.62635 .52687 m .63526 .53427 L .60077 .54821 L p .65 .695 .879 r
F P
0 g
s
.25632 .5706 m .24558 .56996 L .20758 .52532 L p .443 .657 .952 r
F P
0 g
s
.67088 .57485 m .66201 .5643 L .6971 .54128 L p .601 .611 .833 r
F P
0 g
s
.6971 .54128 m .70842 .55047 L .67088 .57485 L p .601 .611 .833 r
F P
0 g
s
.39912 .53956 m .40857 .53073 L .44186 .54575 L p .737 .733 .848 r
F P
0 g
s
.44854 .53748 m .44186 .54575 L .40857 .53073 L p .706 .743 .88 r
F P
0 g
s
.31203 .55962 m .32362 .5528 L .36142 .57979 L p .741 .759 .867 r
F P
0 g
s
.37078 .57028 m .36142 .57979 L .32362 .5528 L p .764 .758 .847 r
F P
0 g
s
.52185 .53749 m .52151 .54249 L .48724 .53938 L p .561 .791 .985 r
F P
0 g
s
.52151 .54249 m .52185 .53749 L .55305 .53563 L p .587 .814 .986 r
F P
0 g
s
.55305 .53563 m .55599 .54045 L .52151 .54249 L p .587 .814 .986 r
F P
0 g
s
.66201 .5643 m .65309 .55358 L .68576 .53194 L p .6 .608 .831 r
F P
0 g
s
.68576 .53194 m .6971 .54128 L .66201 .5643 L p .6 .608 .831 r
F P
0 g
s
.77394 .57859 m .7634 .57767 L .79935 .53961 L p .709 .857 .953 r
F P
0 g
s
.79935 .53961 m .81177 .53883 L .77394 .57859 L p .709 .857 .953 r
F P
0 g
s
.55599 .54045 m .55305 .53563 L .58256 .52919 L p .62 .831 .981 r
F P
0 g
s
.58256 .52919 m .58864 .53335 L .55599 .54045 L p .62 .831 .981 r
F P
0 g
s
.59471 .53975 m .58864 .53335 L .61746 .52155 L p .658 .759 .925 r
F P
0 g
s
.61746 .52155 m .62635 .52687 L .59471 .53975 L p .658 .759 .925 r
F P
0 g
s
.32362 .5528 m .33531 .54471 L .37078 .57028 L p .764 .758 .847 r
F P
0 g
s
.3802 .55999 m .37078 .57028 L .33531 .54471 L p .775 .757 .836 r
F P
0 g
s
.44854 .53748 m .45523 .53127 L .48724 .53938 L p .648 .753 .926 r
F P
0 g
s
.49086 .53466 m .48724 .53938 L .45523 .53127 L p .545 .767 .98 r
F P
0 g
s
.48724 .53938 m .49086 .53466 L .52185 .53749 L p .561 .791 .985 r
F P
0 g
s
.20758 .52532 m .22009 .52775 L .25632 .5706 L p .443 .657 .952 r
F P
0 g
s
.26715 .57089 m .25632 .5706 L .22009 .52775 L p .467 .67 .952 r
F P
0 g
s
.65309 .55358 m .64417 .54335 L .67443 .52312 L p .605 .619 .839 r
F P
0 g
s
.67443 .52312 m .68576 .53194 L .65309 .55358 L p .605 .619 .839 r
F P
0 g
s
.40857 .53073 m .41801 .52361 L .44854 .53748 L p .706 .743 .88 r
F P
0 g
s
.45523 .53127 m .44854 .53748 L .41801 .52361 L p .647 .75 .924 r
F P
0 g
s
.33531 .54471 m .34707 .53585 L .3802 .55999 L p .775 .757 .836 r
F P
0 g
s
.38965 .54952 m .3802 .55999 L .34707 .53585 L p .777 .757 .835 r
F P
0 g
s
.7634 .57767 m .7527 .57543 L .78677 .53906 L p .686 .81 .942 r
F P
0 g
s
.78677 .53906 m .79935 .53961 L .7634 .57767 L p .686 .81 .942 r
F P
0 g
s
.64417 .54335 m .63526 .53427 L .66312 .51546 L p .617 .647 .857 r
F P
0 g
s
.66312 .51546 m .67443 .52312 L .64417 .54335 L p .617 .647 .857 r
F P
0 g
s
.34707 .53585 m .35884 .52684 L .38965 .54952 L p .777 .757 .835 r
F P
0 g
s
.39912 .53956 m .38965 .54952 L .35884 .52684 L p .769 .757 .842 r
F P
0 g
s
.22009 .52775 m .23269 .52981 L .26715 .57089 L p .467 .67 .952 r
F P
0 g
s
.27813 .57029 m .26715 .57089 L .23269 .52981 L p .52 .695 .949 r
F P
0 g
s
.5222 .53467 m .52185 .53749 L .49086 .53466 L p .368 .772 .984 r
F P
0 g
s
.52185 .53749 m .5222 .53467 L .55009 .53301 L p .428 .823 .983 r
F P
0 g
s
.55009 .53301 m .55305 .53563 L .52185 .53749 L p .428 .823 .983 r
F P
0 g
s
.58864 .53335 m .58256 .52919 L .60857 .5185 L p .653 .841 .972 r
F P
0 g
s
.60857 .5185 m .61746 .52155 L .58864 .53335 L p .653 .841 .972 r
F P
0 g
s
.63526 .53427 m .62635 .52687 L .65185 .50952 L p .636 .693 .886 r
F P
0 g
s
.65185 .50952 m .66312 .51546 L .63526 .53427 L p .636 .693 .886 r
F P
0 g
s
.35884 .52684 m .37061 .51835 L .39912 .53956 L p .769 .757 .842 r
F P
0 g
s
.40857 .53073 m .39912 .53956 L .37061 .51835 L p .749 .758 .86 r
F P
0 g
s
.55305 .53563 m .55009 .53301 L .57645 .52724 L p .514 .873 .985 r
F P
0 g
s
.57645 .52724 m .58256 .52919 L .55305 .53563 L p .514 .873 .985 r
F P
0 g
s
.41801 .52361 m .42743 .51857 L .45523 .53127 L p .647 .75 .924 r
F P
0 g
s
.46192 .5273 m .45523 .53127 L .42743 .51857 L p .538 .742 .97 r
F P
0 g
s
.45523 .53127 m .46192 .5273 L .49086 .53466 L p .545 .767 .98 r
F P
0 g
s
.7527 .57543 m .74184 .57158 L .77402 .53691 L p .656 .755 .923 r
F P
0 g
s
.77402 .53691 m .78677 .53906 L .7527 .57543 L p .656 .755 .923 r
F P
0 g
s
.49448 .53214 m .49086 .53466 L .46192 .5273 L p .344 .727 .985 r
F P
0 g
s
.49086 .53466 m .49448 .53214 L .5222 .53467 L p .368 .772 .984 r
F P
0 g
s
.23269 .52981 m .24543 .53099 L .27813 .57029 L p .52 .695 .949 r
F P
0 g
s
.28926 .56837 m .27813 .57029 L .24543 .53099 L p .587 .725 .939 r
F P
0 g
s
.37061 .51835 m .38234 .51103 L .40857 .53073 L p .749 .758 .86 r
F P
0 g
s
.41801 .52361 m .40857 .53073 L .38234 .51103 L p .712 .757 .888 r
F P
0 g
s
.62635 .52687 m .61746 .52155 L .64062 .50569 L p .66 .76 .923 r
F P
0 g
s
.64062 .50569 m .65185 .50952 L .62635 .52687 L p .66 .76 .923 r
F P
0 g
s
.74184 .57158 m .73082 .56603 L .76111 .53304 L p .625 .702 .9 r
F P
0 g
s
.76111 .53304 m .77402 .53691 L .74184 .57158 L p .625 .702 .9 r
F P
0 g
s
.58256 .52919 m .57645 .52724 L .59965 .51769 L p .607 .908 .983 r
F P
0 g
s
.59965 .51769 m .60857 .5185 L .58256 .52919 L p .607 .908 .983 r
F P
0 g
s
.38234 .51103 m .39402 .50544 L .41801 .52361 L p .712 .757 .888 r
F P
0 g
s
.42743 .51857 m .41801 .52361 L .39402 .50544 L p .647 .748 .923 r
F P
0 g
s
.24543 .53099 m .25833 .53084 L .28926 .56837 L p .587 .725 .939 r
F P
0 g
s
.30057 .56485 m .28926 .56837 L .25833 .53084 L p .652 .752 .923 r
F P
0 g
s
.73082 .56603 m .71967 .55889 L .74808 .52759 L p .598 .657 .878 r
F P
0 g
s
.74808 .52759 m .76111 .53304 L .73082 .56603 L p .598 .657 .878 r
F P
0 g
s
.52255 .53376 m .5222 .53467 L .49448 .53214 L p .086 .634 .834 r
F P
0 g
s
.49814 .53153 m .52255 .53376 L p .50188 .53257 L .086 .634 .834 r
F P
0 g
s
.49448 .53214 m .49814 .53153 L p .50188 .53257 L .086 .634 .834 r
F P
0 g
s
.49814 .53153 m .47541 .52573 L p .49381 .53034 L 0 .433 .703 r
F P
0 g
s
.52255 .53376 m .49814 .53153 L p .51537 .53343 L .135 0 0 r
F P
0 g
s
.5222 .53467 m .52255 .53376 L p .52875 .53404 L .175 .709 .83 r
F P
0 g
s
.50183 .53234 m .5229 .53426 L p .50215 .53198 L .135 0 0 r
F P
0 g
s
.49814 .53153 m .50183 .53234 L p .50215 .53198 L .135 0 0 r
F P
0 g
s
.50183 .53234 m .49814 .53153 L p .49381 .53034 L 0 .433 .703 r
F P
0 g
s
.49814 .53153 m .49448 .53214 L .46864 .52555 L p .067 .592 .872 r
F P
0 g
s
.46864 .52555 m .47541 .52573 L .49814 .53153 L p .067 .592 .872 r
F P
0 g
s
.48223 .52734 m .50183 .53234 L p .4797 .52681 L 0 .433 .703 r
F P
0 g
s
.47541 .52573 m .48223 .52734 L p .4797 .52681 L 0 .433 .703 r
F P
0 g
s
.48223 .52734 m .46535 .51955 L p .48498 .52792 L 0 .371 .734 r
F P
0 g
s
.50183 .53234 m .48223 .52734 L p .50149 .53274 L .256 0 0 r
F P
0 g
s
.48223 .52734 m .48914 .52969 L .50557 .53388 L p .256 0 0 r
F P
0 g
s
.48914 .52969 m .48223 .52734 L p .48498 .52792 L 0 .371 .734 r
F P
0 g
s
.50557 .53388 m .50183 .53234 L p .50149 .53274 L .256 0 0 r
F P
0 g
s
.5229 .53426 m .52255 .53376 L p .51537 .53343 L .135 0 0 r
F P
0 g
s
.52255 .53376 m .54711 .5323 L p .52875 .53404 L .175 .709 .83 r
F P
0 g
s
.54711 .5323 m .55009 .53301 L .5413 .53353 L p .175 .709 .83 r
F P
0 g
s
.55009 .53301 m .54711 .5323 L .57031 .52722 L p .323 .809 .862 r
F P
0 g
s
.54711 .5323 m .5441 .533 L .55423 .53078 L p 0 0 0 r
F P
0 g
s
.55423 .53078 m .56411 .52862 L p .54711 .5323 L 0 0 0 r
F P
0 g
s
.5413 .53353 m .5222 .53467 L p .54711 .5323 L .175 .709 .83 r
F P
0 g
s
.42743 .51857 m .43686 .5158 L .46192 .5273 L p .538 .742 .97 r
F P
0 g
s
.46864 .52555 m .46192 .5273 L .43686 .5158 L p .353 .69 .981 r
F P
0 g
s
.46192 .5273 m .46864 .52555 L .49448 .53214 L p .344 .727 .985 r
F P
0 g
s
.57031 .52722 m .57645 .52724 L .55009 .53301 L p .323 .809 .862 r
F P
0 g
s
.61746 .52155 m .60857 .5185 L .6294 .50416 L p .683 .842 .959 r
F P
0 g
s
.6294 .50416 m .64062 .50569 L .61746 .52155 L p .683 .842 .959 r
F P
0 g
s
.71967 .55889 m .70842 .55047 L .73496 .52086 L p .578 .624 .862 r
F P
0 g
s
.73496 .52086 m .74808 .52759 L .71967 .55889 L p .578 .624 .862 r
F P
0 g
s
.25833 .53084 m .27139 .52908 L .30057 .56485 L p .652 .752 .923 r
F P
0 g
s
.31203 .55962 m .30057 .56485 L .27139 .52908 L p .707 .771 .902 r
F P
0 g
s
.70842 .55047 m .6971 .54128 L .72179 .51338 L p .567 .606 .852 r
F P
0 g
s
.72179 .51338 m .73496 .52086 L .70842 .55047 L p .567 .606 .852 r
F P
0 g
s
.39402 .50544 m .40567 .50197 L .42743 .51857 L p .647 .748 .923 r
F P
0 g
s
.43686 .5158 m .42743 .51857 L .40567 .50197 L p .541 .72 .956 r
F P
0 g
s
.6971 .54128 m .68576 .53194 L .70862 .50576 L p .565 .603 .85 r
F P
0 g
s
.70862 .50576 m .72179 .51338 L .6971 .54128 L p .565 .603 .85 r
F P
0 g
s
.27139 .52908 m .2846 .5256 L .31203 .55962 L p .707 .771 .902 r
F P
0 g
s
.32362 .5528 m .31203 .55962 L .2846 .5256 L p .747 .783 .882 r
F P
0 g
s
.68576 .53194 m .67443 .52312 L .69549 .49869 L p .573 .616 .857 r
F P
0 g
s
.69549 .49869 m .70862 .50576 L .68576 .53194 L p .573 .616 .857 r
F P
0 g
s
.57645 .52724 m .57031 .52722 L .59069 .51881 L p .501 .906 .908 r
F P
0 g
s
.59069 .51881 m .59965 .51769 L .57645 .52724 L p .501 .906 .908 r
F P
0 g
s
.67443 .52312 m .66312 .51546 L .68241 .4928 L p .592 .646 .872 r
F P
0 g
s
.68241 .4928 m .69549 .49869 L .67443 .52312 L p .592 .646 .872 r
F P
0 g
s
.2846 .5256 m .29794 .52053 L .32362 .5528 L p .747 .783 .882 r
F P
0 g
s
.33531 .54471 m .32362 .5528 L .29794 .52053 L p .774 .789 .866 r
F P
0 g
s
.60857 .5185 m .59965 .51769 L .61818 .50488 L p .688 .92 .971 r
F P
0 g
s
.61818 .50488 m .6294 .50416 L .60857 .5185 L p .688 .92 .971 r
F P
0 g
s
.43686 .5158 m .4463 .51527 L .46864 .52555 L p .353 .69 .981 r
F P
0 g
s
.47541 .52573 m .46864 .52555 L .4463 .51527 L p .114 .575 .917 r
F P
0 g
s
.29794 .52053 m .31136 .5142 L .33531 .54471 L p .774 .789 .866 r
F P
0 g
s
.34707 .53585 m .33531 .54471 L .31136 .5142 L p .788 .792 .856 r
F P
0 g
s
.66312 .51546 m .65185 .50952 L .66941 .48866 L p .623 .694 .895 r
F P
0 g
s
.66941 .48866 m .68241 .4928 L .66312 .51546 L p .623 .694 .895 r
F P
0 g
s
.31136 .5142 m .32482 .50711 L .34707 .53585 L p .788 .792 .856 r
F P
0 g
s
.35884 .52684 m .34707 .53585 L .32482 .50711 L p .79 .793 .855 r
F P
0 g
s
.52255 .53376 m .5229 .53426 L .5441 .533 L p .032 0 0 r
F P
0 g
s
.5441 .533 m .54711 .5323 L .52255 .53376 L p .032 0 0 r
F P
0 g
s
.40567 .50197 m .41729 .5008 L .43686 .5158 L p .541 .72 .956 r
F P
0 g
s
.4463 .51527 m .43686 .5158 L .41729 .5008 L p .386 .66 .967 r
F P
0 g
s
.32482 .50711 m .33828 .49989 L .35884 .52684 L p .79 .793 .855 r
F P
0 g
s
.37061 .51835 m .35884 .52684 L .33828 .49989 L p .78 .791 .861 r
F P
0 g
s
.55783 .53077 m .56411 .52862 L .5441 .533 L p 0 0 0 r
F P
0 g
s
.56411 .52862 m .55783 .53077 L .56155 .52923 L p .313 .79 .706 r
F P
0 g
s
.56643 .52807 m .54711 .5323 L p .56411 .52862 L 0 0 0 r
F P
0 g
s
.56155 .52923 m .57252 .5247 L p .56411 .52862 L .313 .79 .706 r
F P
0 g
s
.56411 .52862 m .57031 .52722 L .56643 .52807 L p 0 0 0 r
F P
0 g
s
.33828 .49989 m .35169 .49321 L .37061 .51835 L p .78 .791 .861 r
F P
0 g
s
.38234 .51103 m .37061 .51835 L .35169 .49321 L p .756 .784 .876 r
F P
0 g
s
.65185 .50952 m .64062 .50569 L .65648 .48666 L p .663 .759 .922 r
F P
0 g
s
.65648 .48666 m .66941 .48866 L .65185 .50952 L p .663 .759 .922 r
F P
0 g
s
.83625 .53514 m .82406 .53716 L .8456 .4899 L p .759 .876 .932 r
F P
0 g
s
.8456 .4899 m .85906 .48583 L .83625 .53514 L p .759 .876 .932 r
F P
0 g
s
.35169 .49321 m .36504 .48773 L .38234 .51103 L p .756 .784 .876 r
F P
0 g
s
.39402 .50544 m .38234 .51103 L .36504 .48773 L p .714 .771 .897 r
F P
0 g
s
.59965 .51769 m .59069 .51881 L .60691 .50756 L p .661 .96 .936 r
F P
0 g
s
.60691 .50756 m .61818 .50488 L .59965 .51769 L p .661 .96 .936 r
F P
0 g
s
.36504 .48773 m .3783 .484 L .39402 .50544 L p .714 .771 .897 r
F P
0 g
s
.40567 .50197 m .39402 .50544 L .3783 .484 L p .647 .745 .921 r
F P
0 g
s
.64062 .50569 m .6294 .50416 L .6436 .48698 L p .707 .835 .943 r
F P
0 g
s
.6436 .48698 m .65648 .48666 L .64062 .50569 L p .707 .835 .943 r
F P
0 g
s
.57031 .52722 m .56411 .52862 L .58165 .52138 L p .381 .841 .785 r
F P
0 g
s
.58165 .52138 m .59069 .51881 L .57031 .52722 L p .381 .841 .785 r
F P
0 g
s
.82406 .53716 m .81177 .53883 L .83208 .4936 L p .75 .866 .933 r
F P
0 g
s
.83208 .4936 m .8456 .4899 L .82406 .53716 L p .75 .866 .933 r
F P
0 g
s
.4463 .51527 m .45579 .51669 L .47541 .52573 L p .114 .575 .917 r
F P
0 g
s
.48223 .52734 m .47541 .52573 L .45579 .51669 L p 0 .445 .806 r
F P
0 g
s
.41729 .5008 m .42892 .50188 L .4463 .51527 L p .386 .66 .967 r
F P
0 g
s
.45579 .51669 m .4463 .51527 L .42892 .50188 L p .203 .568 .938 r
F P
0 g
s
.3783 .484 m .39149 .48241 L .40567 .50197 L p .647 .745 .921 r
F P
0 g
s
.41729 .5008 m .40567 .50197 L .39149 .48241 L p .551 .702 .94 r
F P
0 g
s
.81177 .53883 m .79935 .53961 L .81844 .49641 L p .729 .841 .933 r
F P
0 g
s
.81844 .49641 m .83208 .4936 L .81177 .53883 L p .729 .841 .933 r
F P
0 g
s
.6294 .50416 m .61818 .50488 L .63073 .48957 L p .745 .908 .949 r
F P
0 g
s
.63073 .48957 m .6436 .48698 L .6294 .50416 L p .745 .908 .949 r
F P
0 g
s
.52325 .5355 m .5229 .53426 L .50183 .53234 L p .23 0 0 r
F P
0 g
s
.5229 .53426 m .52325 .5355 L .54105 .53444 L p .125 0 0 r
F P
0 g
s
.54105 .53444 m .5441 .533 L .5229 .53426 L p .125 0 0 r
F P
0 g
s
.22009 .52775 m .20758 .52532 L .18911 .47507 L p .484 .643 .926 r
F P
0 g
s
.5441 .533 m .54105 .53444 L .55783 .53077 L p 0 0 0 r
F P
0 g
s
.50183 .53234 m .50557 .53388 L .52325 .5355 L p .23 0 0 r
F P
0 g
s
.59069 .51881 m .58165 .52138 L .59558 .5117 L p .614 .957 .872 r
F P
0 g
s
.59558 .5117 m .60691 .50756 L .59069 .51881 L p .614 .957 .872 r
F P
0 g
s
.79935 .53961 m .78677 .53906 L .80465 .49788 L p .697 .802 .93 r
F P
0 g
s
.80465 .49788 m .81844 .49641 L .79935 .53961 L p .697 .802 .93 r
F P
0 g
s
.39149 .48241 m .40463 .48315 L .41729 .5008 L p .551 .702 .94 r
F P
0 g
s
.42892 .50188 m .41729 .5008 L .40463 .48315 L p .429 .638 .943 r
F P
0 g
s
.18911 .47507 m .20272 .47959 L .22009 .52775 L p .484 .643 .926 r
F P
0 g
s
.23269 .52981 m .22009 .52775 L .20272 .47959 L p .502 .654 .928 r
F P
0 g
s
.42892 .50188 m .44058 .50493 L .45579 .51669 L p .203 .568 .938 r
F P
0 g
s
.46535 .51955 m .45579 .51669 L .44058 .50493 L p .046 .474 .884 r
F P
0 g
s
.45579 .51669 m .46535 .51955 L .48223 .52734 L p 0 .445 .806 r
F P
0 g
s
.57252 .5247 m .58165 .52138 L .56411 .52862 L p .313 .79 .706 r
F P
0 g
s
.78677 .53906 m .77402 .53691 L .79071 .49773 L p .656 .755 .922 r
F P
0 g
s
.79071 .49773 m .80465 .49788 L .78677 .53906 L p .656 .755 .922 r
F P
0 g
s
.61818 .50488 m .60691 .50756 L .61785 .49414 L p .766 .959 .932 r
F P
0 g
s
.61785 .49414 m .63073 .48957 L .61818 .50488 L p .766 .959 .932 r
F P
0 g
s
.20272 .47959 m .2164 .48375 L .23269 .52981 L p .502 .654 .928 r
F P
0 g
s
.24543 .53099 m .23269 .52981 L .2164 .48375 L p .541 .681 .929 r
F P
0 g
s
.77402 .53691 m .76111 .53304 L .77664 .49586 L p .614 .705 .91 r
F P
0 g
s
.77664 .49586 m .79071 .49773 L .77402 .53691 L p .614 .705 .91 r
F P
0 g
s
.70862 .50576 m .69549 .49869 L .70559 .47146 L p .538 .618 .88 r
F P
0 g
s
.69549 .49869 m .68241 .4928 L .69154 .46761 L p .567 .65 .891 r
F P
0 g
s
.69154 .46761 m .70559 .47146 L .69549 .49869 L p .567 .65 .891 r
F P
0 g
s
.72179 .51338 m .70862 .50576 L .71974 .47653 L p .526 .604 .874 r
F P
0 g
s
.70559 .47146 m .71974 .47653 L .70862 .50576 L p .538 .618 .88 r
F P
0 g
s
.68241 .4928 m .66941 .48866 L .67761 .46553 L p .61 .698 .906 r
F P
0 g
s
.67761 .46553 m .69154 .46761 L .68241 .4928 L p .61 .698 .906 r
F P
0 g
s
.40463 .48315 m .41774 .48616 L .42892 .50188 L p .429 .638 .943 r
F P
0 g
s
.44058 .50493 m .42892 .50188 L .41774 .48616 L p .302 .562 .928 r
F P
0 g
s
.76111 .53304 m .74808 .52759 L .76246 .49238 L p .576 .661 .896 r
F P
0 g
s
.76246 .49238 m .77664 .49586 L .76111 .53304 L p .576 .661 .896 r
F P
0 g
s
.73496 .52086 m .72179 .51338 L .73396 .48215 L p .529 .608 .876 r
F P
0 g
s
.71974 .47653 m .73396 .48215 L .72179 .51338 L p .526 .604 .874 r
F P
0 g
s
.74808 .52759 m .73496 .52086 L .74822 .48764 L p .547 .627 .883 r
F P
0 g
s
.73396 .48215 m .74822 .48764 L .73496 .52086 L p .529 .608 .876 r
F P
0 g
s
.74822 .48764 m .76246 .49238 L .74808 .52759 L p .547 .627 .883 r
F P
0 g
s
.66941 .48866 m .65648 .48666 L .66377 .4656 L p .665 .758 .92 r
F P
0 g
s
.66377 .4656 m .67761 .46553 L .66941 .48866 L p .665 .758 .92 r
F P
0 g
s
.2164 .48375 m .2302 .48702 L .24543 .53099 L p .541 .681 .929 r
F P
0 g
s
.25833 .53084 m .24543 .53099 L .2302 .48702 L p .595 .715 .928 r
F P
0 g
s
.52361 .53666 m .52325 .5355 L .50557 .53388 L p .219 0 0 r
F P
0 g
s
.52325 .5355 m .52361 .53666 L .53796 .5358 L p .114 0 0 r
F P
0 g
s
.53796 .5358 m .54105 .53444 L .52325 .5355 L p .114 0 0 r
F P
0 g
s
.58165 .52138 m .57252 .5247 L .58414 .51661 L p .581 .942 .827 r
F P
0 g
s
.58414 .51661 m .59558 .5117 L .58165 .52138 L p .581 .942 .827 r
F P
0 g
s
.65648 .48666 m .6436 .48698 L .65003 .46801 L p .723 .822 .926 r
F P
0 g
s
.65003 .46801 m .66377 .4656 L .65648 .48666 L p .723 .822 .926 r
F P
0 g
s
.54105 .53444 m .53796 .5358 L .55147 .53285 L p 0 0 0 r
F P
0 g
s
.55147 .53285 m .55783 .53077 L .54105 .53444 L p 0 0 0 r
F P
0 g
s
.60691 .50756 m .59558 .5117 L .60491 .50019 L p .771 .984 .904 r
F P
0 g
s
.60491 .50019 m .61785 .49414 L .60691 .50756 L p .771 .984 .904 r
F P
0 g
s
.50937 .53536 m .50557 .53388 L .48914 .52969 L p .244 0 0 r
F P
0 g
s
.50557 .53388 m .50937 .53536 L .52361 .53666 L p .219 0 0 r
F P
0 g
s
.2302 .48702 m .24413 .48895 L .25833 .53084 L p .595 .715 .928 r
F P
0 g
s
.27139 .52908 m .25833 .53084 L .24413 .48895 L p .652 .751 .922 r
F P
0 g
s
.34404 .46562 m .35817 .46221 L .36504 .48773 L p .757 .811 .895 r
F P
0 g
s
.36504 .48773 m .35169 .49321 L .34404 .46562 L p .757 .811 .895 r
F P
0 g
s
.3783 .484 m .36504 .48773 L .35817 .46221 L p .712 .784 .908 r
F P
0 g
s
.32979 .47024 m .34404 .46562 L .35169 .49321 L p .784 .826 .885 r
F P
0 g
s
.35169 .49321 m .33828 .49989 L .32979 .47024 L p .784 .826 .885 r
F P
0 g
s
.44058 .50493 m .45231 .50944 L .46535 .51955 L p .046 .474 .884 r
F P
0 g
s
.47501 .52317 m .46535 .51955 L .45231 .50944 L p 0 .419 .845 r
F P
0 g
s
.46535 .51955 m .47501 .52317 L .48914 .52969 L p 0 .371 .734 r
F P
0 g
s
.31546 .47542 m .32979 .47024 L .33828 .49989 L p .795 .832 .88 r
F P
0 g
s
.33828 .49989 m .32482 .50711 L .31546 .47542 L p .795 .832 .88 r
F P
0 g
s
.35817 .46221 m .37219 .46057 L .3783 .484 L p .712 .784 .908 r
F P
0 g
s
.39149 .48241 m .3783 .484 L .37219 .46057 L p .648 .743 .919 r
F P
0 g
s
.30109 .48047 m .31546 .47542 L .32482 .50711 L p .792 .83 .881 r
F P
0 g
s
.32482 .50711 m .31136 .5142 L .30109 .48047 L p .792 .83 .881 r
F P
0 g
s
.24413 .48895 m .25821 .48924 L .27139 .52908 L p .652 .751 .922 r
F P
0 g
s
.2846 .5256 m .27139 .52908 L .25821 .48924 L p .705 .782 .912 r
F P
0 g
s
.6436 .48698 m .63073 .48957 L .63633 .47271 L p .776 .879 .921 r
F P
0 g
s
.63633 .47271 m .65003 .46801 L .6436 .48698 L p .776 .879 .921 r
F P
0 g
s
.41774 .48616 m .43086 .49116 L .44058 .50493 L p .302 .562 .928 r
F P
0 g
s
.45231 .50944 m .44058 .50493 L .43086 .49116 L p .198 .496 .904 r
F P
0 g
s
.28673 .48478 m .30109 .48047 L .31136 .5142 L p .776 .822 .888 r
F P
0 g
s
.31136 .5142 m .29794 .52053 L .28673 .48478 L p .776 .822 .888 r
F P
0 g
s
.25821 .48924 m .27242 .48781 L .2846 .5256 L p .705 .782 .912 r
F P
0 g
s
.29794 .52053 m .2846 .5256 L .27242 .48781 L p .747 .806 .899 r
F P
0 g
s
.37219 .46057 m .3861 .4611 L .39149 .48241 L p .648 .743 .919 r
F P
0 g
s
.40463 .48315 m .39149 .48241 L .3861 .4611 L p .566 .688 .923 r
F P
0 g
s
.55783 .53077 m .55147 .53285 L .56327 .52797 L p .321 .797 .716 r
F P
0 g
s
.56327 .52797 m .57252 .5247 L .55783 .53077 L p .321 .797 .716 r
F P
0 g
s
.27242 .48781 m .28673 .48478 L .29794 .52053 L p .747 .806 .899 r
F P
0 g
s
.48914 .52969 m .49614 .53199 L .50937 .53536 L p .244 0 0 r
F P
0 g
s
.49614 .53199 m .48914 .52969 L .47501 .52317 L p 0 .38 .743 r
F P
0 g
s
.3861 .4611 m .39992 .46396 L .40463 .48315 L p .566 .688 .923 r
F P
0 g
s
.41774 .48616 m .40463 .48315 L .39992 .46396 L p .476 .623 .915 r
F P
0 g
s
.63073 .48957 m .61785 .49414 L .62265 .47939 L p .816 .921 .907 r
F P
0 g
s
.62265 .47939 m .63633 .47271 L .63073 .48957 L p .816 .921 .907 r
F P
0 g
s
.59558 .5117 m .58414 .51661 L .59189 .507 L p .769 .992 .884 r
F P
0 g
s
.59189 .507 m .60491 .50019 L .59558 .5117 L p .769 .992 .884 r
F P
0 g
s
.57252 .5247 m .56327 .52797 L .57258 .52148 L p .585 .945 .833 r
F P
0 g
s
.57258 .52148 m .58414 .51661 L .57252 .5247 L p .585 .945 .833 r
F P
0 g
s
.43086 .49116 m .44403 .49763 L .45231 .50944 L p .198 .496 .904 r
F P
0 g
s
.46414 .51472 m .45231 .50944 L .44403 .49763 L p .144 .459 .887 r
F P
0 g
s
.45231 .50944 m .46414 .51472 L .47501 .52317 L p 0 .419 .845 r
F P
0 g
s
.39992 .46396 m .41367 .46911 L .41774 .48616 L p .476 .623 .915 r
F P
0 g
s
.43086 .49116 m .41774 .48616 L .41367 .46911 L p .391 .559 .9 r
F P
0 g
s
.48479 .52675 m .47501 .52317 L .46414 .51472 L p 0 .426 .851 r
F P
0 g
s
.47501 .52317 m .48479 .52675 L .49614 .53199 L p 0 .38 .743 r
F P
0 g
s
.52398 .5369 m .52361 .53666 L .50937 .53536 L p .094 0 0 r
F P
0 g
s
.52361 .53666 m .52398 .5369 L .53481 .53625 L p 0 0 0 r
F P
0 g
s
.53481 .53625 m .53796 .5358 L .52361 .53666 L p 0 0 0 r
F P
0 g
s
.53796 .5358 m .53481 .53625 L .54501 .53402 L p .18 .711 .722 r
F P
0 g
s
.54501 .53402 m .55147 .53285 L .53796 .5358 L p .18 .711 .722 r
F P
0 g
s
.50937 .53536 m .51322 .53592 L .52398 .5369 L p .094 0 0 r
F P
0 g
s
.51322 .53592 m .50937 .53536 L .49614 .53199 L p 0 .466 .739 r
F P
0 g
s
.61785 .49414 m .60491 .50019 L .60894 .48755 L p .84 .945 .889 r
F P
0 g
s
.60894 .48755 m .62265 .47939 L .61785 .49414 L p .84 .945 .889 r
F P
0 g
s
.55147 .53285 m .54501 .53402 L .5539 .53035 L p .406 .857 .813 r
F P
0 g
s
.5539 .53035 m .56327 .52797 L .55147 .53285 L p .406 .857 .813 r
F P
0 g
s
.50324 .53337 m .49614 .53199 L .48479 .52675 L p 0 .473 .831 r
F P
0 g
s
.49614 .53199 m .50324 .53337 L .51322 .53592 L p 0 .466 .739 r
F P
0 g
s
.41367 .46911 m .42741 .47625 L .43086 .49116 L p .391 .559 .9 r
F P
0 g
s
.44403 .49763 m .43086 .49116 L .42741 .47625 L p .328 .51 .884 r
F P
0 g
s
.58414 .51661 m .57258 .52148 L .57875 .51378 L p .769 .991 .887 r
F P
0 g
s
.57875 .51378 m .59189 .507 L .58414 .51661 L p .769 .991 .887 r
F P
0 g
s
.69154 .46761 m .67761 .46553 L .6755 .4416 L p .599 .705 .918 r
F P
0 g
s
.67761 .46553 m .66377 .4656 L .66169 .44387 L p .666 .756 .918 r
F P
0 g
s
.66169 .44387 m .6755 .4416 L .67761 .46553 L p .666 .756 .918 r
F P
0 g
s
.44403 .49763 m .45728 .50487 L .46414 .51472 L p .144 .459 .887 r
F P
0 g
s
.47609 .51997 m .46414 .51472 L .45728 .50487 L p .151 .463 .889 r
F P
0 g
s
.46414 .51472 m .47609 .51997 L .48479 .52675 L p 0 .426 .851 r
F P
0 g
s
.66377 .4656 m .65003 .46801 L .648 .44848 L p .732 .804 .909 r
F P
0 g
s
.648 .44848 m .66169 .44387 L .66377 .4656 L p .732 .804 .909 r
F P
0 g
s
.56327 .52797 m .5539 .53035 L .56089 .52546 L p .624 .96 .887 r
F P
0 g
s
.56089 .52546 m .57258 .52148 L .56327 .52797 L p .624 .96 .887 r
F P
0 g
s
.70559 .47146 m .69154 .46761 L .68945 .44149 L p .542 .66 .913 r
F P
0 g
s
.6755 .4416 m .68945 .44149 L .69154 .46761 L p .599 .705 .918 r
F P
0 g
s
.60491 .50019 m .59189 .507 L .59517 .49648 L p .851 .956 .879 r
F P
0 g
s
.59517 .49648 m .60894 .48755 L .60491 .50019 L p .851 .956 .879 r
F P
0 g
s
.4947 .52942 m .48479 .52675 L .47609 .51997 L p .077 .494 .897 r
F P
0 g
s
.48479 .52675 m .4947 .52942 L .50324 .53337 L p 0 .473 .831 r
F P
0 g
s
.65003 .46801 m .63633 .47271 L .63439 .45539 L p .787 .842 .893 r
F P
0 g
s
.63439 .45539 m .648 .44848 L .65003 .46801 L p .787 .842 .893 r
F P
0 g
s
.71974 .47653 m .70559 .47146 L .70354 .44316 L p .502 .627 .906 r
F P
0 g
s
.68945 .44149 m .70354 .44316 L .70559 .47146 L p .542 .66 .913 r
F P
0 g
s
.42741 .47625 m .44116 .48487 L .44403 .49763 L p .328 .51 .884 r
F P
0 g
s
.45728 .50487 m .44403 .49763 L .44116 .48487 L p .296 .484 .874 r
F P
0 g
s
.52435 .53542 m .52398 .5369 L .51322 .53592 L p .162 .68 .886 r
F P
0 g
s
.52398 .5369 m .52435 .53542 L .53162 .53499 L p .244 .75 .883 r
F P
0 g
s
.53162 .53499 m .53481 .53625 L .52398 .5369 L p .244 .75 .883 r
F P
0 g
s
.37649 .43668 m .39018 .43941 L .3861 .4611 L p .649 .742 .917 r
F P
0 g
s
.3861 .4611 m .37219 .46057 L .37649 .43668 L p .649 .742 .917 r
F P
0 g
s
.39992 .46396 m .3861 .4611 L .39018 .43941 L p .584 .679 .906 r
F P
0 g
s
.73396 .48215 m .71974 .47653 L .71778 .44606 L p .484 .612 .903 r
F P
0 g
s
.70354 .44316 m .71778 .44606 L .71974 .47653 L p .502 .627 .906 r
F P
0 g
s
.63633 .47271 m .62265 .47939 L .62083 .46428 L p .829 .868 .874 r
F P
0 g
s
.62083 .46428 m .63439 .45539 L .63633 .47271 L p .829 .868 .874 r
F P
0 g
s
.53481 .53625 m .53162 .53499 L .53846 .53349 L p .377 .836 .906 r
F P
0 g
s
.53846 .53349 m .54501 .53402 L .53481 .53625 L p .377 .836 .906 r
F P
0 g
s
.36267 .43612 m .37649 .43668 L .37219 .46057 L p .706 .796 .92 r
F P
0 g
s
.37219 .46057 m .35817 .46221 L .36267 .43612 L p .706 .796 .92 r
F P
0 g
s
.51713 .53477 m .51322 .53592 L .50324 .53337 L p .141 .636 .913 r
F P
0 g
s
.51322 .53592 m .51713 .53477 L .52435 .53542 L p .162 .68 .886 r
F P
0 g
s
.39018 .43941 m .40373 .44448 L .39992 .46396 L p .584 .679 .906 r
F P
0 g
s
.41367 .46911 m .39992 .46396 L .40373 .44448 L p .52 .615 .888 r
F P
0 g
s
.34869 .43733 m .36267 .43612 L .35817 .46221 L p .749 .835 .917 r
F P
0 g
s
.35817 .46221 m .34404 .46562 L .34869 .43733 L p .749 .835 .917 r
F P
0 g
s
.85906 .48583 m .8456 .4899 L .84599 .43954 L p .772 .844 .906 r
F P
0 g
s
.84599 .43954 m .85986 .43317 L .85906 .48583 L p .772 .844 .906 r
F P
0 g
s
.54501 .53402 m .53846 .53349 L .54441 .53103 L p .532 .914 .936 r
F P
0 g
s
.54441 .53103 m .5539 .53035 L .54501 .53402 L p .532 .914 .936 r
F P
0 g
s
.57258 .52148 m .56089 .52546 L .5655 .51968 L p .77 .98 .911 r
F P
0 g
s
.5655 .51968 m .57875 .51378 L .57258 .52148 L p .77 .98 .911 r
F P
0 g
s
.74822 .48764 m .73396 .48215 L .73212 .44952 L p .489 .616 .904 r
F P
0 g
s
.71778 .44606 m .73212 .44952 L .73396 .48215 L p .484 .612 .903 r
F P
0 g
s
.51045 .53306 m .50324 .53337 L .4947 .52942 L p .178 .611 .941 r
F P
0 g
s
.50324 .53337 m .51045 .53306 L .51713 .53477 L p .141 .636 .913 r
F P
0 g
s
.59189 .507 m .57875 .51378 L .58133 .50538 L p .85 .955 .88 r
F P
0 g
s
.58133 .50538 m .59517 .49648 L .59189 .507 L p .85 .955 .88 r
F P
0 g
s
.33457 .43977 m .34869 .43733 L .34404 .46562 L p .776 .86 .912 r
F P
0 g
s
.34404 .46562 m .32979 .47024 L .33457 .43977 L p .776 .86 .912 r
F P
0 g
s
.40373 .44448 m .4172 .45185 L .41367 .46911 L p .52 .615 .888 r
F P
0 g
s
.42741 .47625 m .41367 .46911 L .4172 .45185 L p .465 .561 .868 r
F P
0 g
s
.62265 .47939 m .60894 .48755 L .60728 .47464 L p .854 .883 .859 r
F P
0 g
s
.60728 .47464 m .62083 .46428 L .62265 .47939 L p .854 .883 .859 r
F P
0 g
s
.45728 .50487 m .47063 .51208 L .47609 .51997 L p .151 .463 .889 r
F P
0 g
s
.48817 .52432 m .47609 .51997 L .47063 .51208 L p .219 .509 .909 r
F P
0 g
s
.47609 .51997 m .48817 .52432 L .4947 .52942 L p .077 .494 .897 r
F P
0 g
s
.8456 .4899 m .83208 .4936 L .83207 .44553 L p .763 .837 .909 r
F P
0 g
s
.83207 .44553 m .84599 .43954 L .8456 .4899 L p .763 .837 .909 r
F P
0 g
s
.76246 .49238 m .74822 .48764 L .74653 .45285 L p .514 .637 .909 r
F P
0 g
s
.73212 .44952 m .74653 .45285 L .74822 .48764 L p .489 .616 .904 r
F P
0 g
s
.44116 .48487 m .45496 .49425 L .45728 .50487 L p .296 .484 .874 r
F P
0 g
s
.47063 .51208 m .45728 .50487 L .45496 .49425 L p .3 .487 .875 r
F P
0 g
s
.5539 .53035 m .54441 .53103 L .54907 .52776 L p .669 .954 .95 r
F P
0 g
s
.54907 .52776 m .56089 .52546 L .5539 .53035 L p .669 .954 .95 r
F P
0 g
s
.32033 .44277 m .33457 .43977 L .32979 .47024 L p .787 .87 .909 r
F P
0 g
s
.32979 .47024 m .31546 .47542 L .32033 .44277 L p .787 .87 .909 r
F P
0 g
s
.83208 .4936 m .81844 .49641 L .81807 .45061 L p .74 .819 .914 r
F P
0 g
s
.81807 .45061 m .83207 .44553 L .83208 .4936 L p .74 .819 .914 r
F P
0 g
s
.50473 .53041 m .4947 .52942 L .48817 .52432 L p .251 .595 .95 r
F P
0 g
s
.4947 .52942 m .50473 .53041 L .51045 .53306 L p .178 .611 .941 r
F P
0 g
s
.4172 .45185 m .43062 .46119 L .42741 .47625 L p .465 .561 .868 r
F P
0 g
s
.44116 .48487 m .42741 .47625 L .43062 .46119 L p .427 .522 .852 r
F P
0 g
s
.77664 .49586 m .76246 .49238 L .76097 .45542 L p .555 .671 .915 r
F P
0 g
s
.74653 .45285 m .76097 .45542 L .76246 .49238 L p .514 .637 .909 r
F P
0 g
s
.81844 .49641 m .80465 .49788 L .80395 .45433 L p .703 .791 .919 r
F P
0 g
s
.80395 .45433 m .81807 .45061 L .81844 .49641 L p .703 .791 .919 r
F P
0 g
s
.60894 .48755 m .59517 .49648 L .5937 .48576 L p .866 .889 .85 r
F P
0 g
s
.5937 .48576 m .60728 .47464 L .60894 .48755 L p .866 .889 .85 r
F P
0 g
s
.79071 .49773 m .77664 .49586 L .77538 .45672 L p .605 .712 .92 r
F P
0 g
s
.76097 .45542 m .77538 .45672 L .77664 .49586 L p .555 .671 .915 r
F P
0 g
s
.80465 .49788 m .79071 .49773 L .78971 .45639 L p .657 .754 .922 r
F P
0 g
s
.78971 .45639 m .80395 .45433 L .80465 .49788 L p .657 .754 .922 r
F P
0 g
s
.30601 .44565 m .32033 .44277 L .31546 .47542 L p .785 .867 .91 r
F P
0 g
s
.31546 .47542 m .30109 .48047 L .30601 .44565 L p .785 .867 .91 r
F P
0 g
s
.77538 .45672 m .78971 .45639 L .79071 .49773 L p .605 .712 .92 r
F P
0 g
s
.57875 .51378 m .5655 .51968 L .56738 .51338 L p .836 .941 .893 r
F P
0 g
s
.56738 .51338 m .58133 .50538 L .57875 .51378 L p .836 .941 .893 r
F P
0 g
s
.52473 .53158 m .52435 .53542 L .51713 .53477 L p .445 .791 .998 r
F P
0 g
s
.52435 .53542 m .52473 .53158 L .52839 .53136 L p .492 .831 .998 r
F P
0 g
s
.52839 .53136 m .53162 .53499 L .52435 .53542 L p .492 .831 .998 r
F P
0 g
s
.56089 .52546 m .54907 .52776 L .55213 .5239 L p .761 .948 .939 r
F P
0 g
s
.55213 .5239 m .5655 .51968 L .56089 .52546 L p .761 .948 .939 r
F P
0 g
s
.43062 .46119 m .44401 .47201 L .44116 .48487 L p .427 .522 .852 r
F P
0 g
s
.45496 .49425 m .44116 .48487 L .44401 .47201 L p .408 .502 .844 r
F P
0 g
s
.53162 .53499 m .52839 .53136 L .53182 .5306 L p .556 .867 .996 r
F P
0 g
s
.53182 .5306 m .53846 .53349 L .53162 .53499 L p .556 .867 .996 r
F P
0 g
s
.5211 .53125 m .51713 .53477 L .51045 .53306 L p .422 .751 .994 r
F P
0 g
s
.51713 .53477 m .5211 .53125 L .52473 .53158 L p .445 .791 .998 r
F P
0 g
s
.45496 .49425 m .46884 .50359 L .47063 .51208 L p .3 .487 .875 r
F P
0 g
s
.48411 .5184 m .47063 .51208 L .46884 .50359 L p .34 .52 .887 r
F P
0 g
s
.47063 .51208 m .48411 .5184 L .48817 .52432 L p .219 .509 .909 r
F P
0 g
s
.50038 .527 m .48817 .52432 L .48411 .5184 L p .334 .584 .935 r
F P
0 g
s
.48817 .52432 m .50038 .527 L .50473 .53041 L p .251 .595 .95 r
F P
0 g
s
.20272 .47959 m .18911 .47507 L .19318 .42214 L p .525 .634 .901 r
F P
0 g
s
.29167 .44776 m .30601 .44565 L .30109 .48047 L p .768 .853 .914 r
F P
0 g
s
.30109 .48047 m .28673 .48478 L .29167 .44776 L p .768 .853 .914 r
F P
0 g
s
.53846 .53349 m .53182 .5306 L .53481 .52936 L p .625 .89 .988 r
F P
0 g
s
.53481 .52936 m .54441 .53103 L .53846 .53349 L p .625 .89 .988 r
F P
0 g
s
.51774 .53039 m .51045 .53306 L .50473 .53041 L p .423 .716 .985 r
F P
0 g
s
.51045 .53306 m .51774 .53039 L .5211 .53125 L p .422 .751 .994 r
F P
0 g
s
.59517 .49648 m .58133 .50538 L .58008 .49683 L p .865 .889 .851 r
F P
0 g
s
.58008 .49683 m .5937 .48576 L .59517 .49648 L p .865 .889 .851 r
F P
0 g
s
.19318 .42214 m .20702 .429 L .20272 .47959 L p .525 .634 .901 r
F P
0 g
s
.2164 .48375 m .20272 .47959 L .20702 .429 L p .537 .645 .904 r
F P
0 g
s
.27734 .44859 m .29167 .44776 L .28673 .48478 L p .739 .828 .919 r
F P
0 g
s
.28673 .48478 m .27242 .48781 L .27734 .44859 L p .739 .828 .919 r
F P
0 g
s
.54441 .53103 m .53481 .52936 L .53714 .52772 L p .686 .896 .973 r
F P
0 g
s
.53714 .52772 m .54907 .52776 L .54441 .53103 L p .686 .896 .973 r
F P
0 g
s
.44401 .47201 m .45743 .48358 L .45496 .49425 L p .408 .502 .844 r
F P
0 g
s
.46884 .50359 m .45496 .49425 L .45743 .48358 L p .41 .505 .845 r
F P
0 g
s
.51488 .52905 m .50473 .53041 L .50038 .527 L p .442 .687 .969 r
F P
0 g
s
.50473 .53041 m .51488 .52905 L .51774 .53039 L p .423 .716 .985 r
F P
0 g
s
.20702 .429 m .22089 .43549 L .2164 .48375 L p .537 .645 .904 r
F P
0 g
s
.2302 .48702 m .2164 .48375 L .22089 .43549 L p .565 .671 .91 r
F P
0 g
s
.66169 .44387 m .648 .44848 L .63738 .42975 L p .733 .784 .894 r
F P
0 g
s
.648 .44848 m .63439 .45539 L .62483 .43881 L p .785 .804 .868 r
F P
0 g
s
.62483 .43881 m .63738 .42975 L .648 .44848 L p .785 .804 .868 r
F P
0 g
s
.6755 .4416 m .66169 .44387 L .65004 .42296 L p .667 .754 .916 r
F P
0 g
s
.63738 .42975 m .65004 .42296 L .66169 .44387 L p .733 .784 .894 r
F P
0 g
s
.5655 .51968 m .55213 .5239 L .55335 .5197 L p .806 .912 .912 r
F P
0 g
s
.55335 .5197 m .56738 .51338 L .5655 .51968 L p .806 .912 .912 r
F P
0 g
s
.26307 .4478 m .27734 .44859 L .27242 .48781 L p .699 .792 .923 r
F P
0 g
s
.27242 .48781 m .25821 .48924 L .26307 .4478 L p .699 .792 .923 r
F P
0 g
s
.63439 .45539 m .62083 .46428 L .61236 .44985 L p .82 .815 .845 r
F P
0 g
s
.61236 .44985 m .62483 .43881 L .63439 .45539 L p .82 .815 .845 r
F P
0 g
s
.22089 .43549 m .23484 .44105 L .2302 .48702 L p .565 .671 .91 r
F P
0 g
s
.24413 .48895 m .2302 .48702 L .23484 .44105 L p .606 .708 .917 r
F P
0 g
s
.2489 .44525 m .26307 .4478 L .25821 .48924 L p .653 .751 .922 r
F P
0 g
s
.25821 .48924 m .24413 .48895 L .2489 .44525 L p .653 .751 .922 r
F P
0 g
s
.46884 .50359 m .48281 .51205 L .48411 .5184 L p .34 .52 .887 r
F P
0 g
s
.49769 .52304 m .48411 .5184 L .48281 .51205 L p .412 .577 .906 r
F P
0 g
s
.48411 .5184 m .49769 .52304 L .50038 .527 L p .334 .584 .935 r
F P
0 g
s
.23484 .44105 m .2489 .44525 L .24413 .48895 L p .606 .708 .917 r
F P
0 g
s
.68945 .44149 m .6755 .4416 L .66283 .41852 L p .591 .716 .93 r
F P
0 g
s
.65004 .42296 m .66283 .41852 L .6755 .4416 L p .667 .754 .916 r
F P
0 g
s
.58133 .50538 m .56738 .51338 L .5664 .50699 L p .849 .881 .862 r
F P
0 g
s
.5664 .50699 m .58008 .49683 L .58133 .50538 L p .849 .881 .862 r
F P
0 g
s
.54907 .52776 m .53714 .52772 L .53866 .52578 L p .73 .886 .952 r
F P
0 g
s
.53866 .52578 m .55213 .5239 L .54907 .52776 L p .73 .886 .952 r
F P
0 g
s
.62083 .46428 m .60728 .47464 L .59992 .46234 L p .842 .821 .828 r
F P
0 g
s
.59992 .46234 m .61236 .44985 L .62083 .46428 L p .842 .821 .828 r
F P
0 g
s
.5127 .52734 m .50038 .527 L .49769 .52304 L p .471 .664 .947 r
F P
0 g
s
.50038 .527 m .5127 .52734 L .51488 .52905 L p .442 .687 .969 r
F P
0 g
s
.40378 .41887 m .4161 .42609 L .40373 .44448 L p .603 .674 .891 r
F P
0 g
s
.40373 .44448 m .39018 .43941 L .40378 .41887 L p .603 .674 .891 r
F P
0 g
s
.4172 .45185 m .40373 .44448 L .4161 .42609 L p .56 .614 .864 r
F P
0 g
s
.4161 .42609 m .4283 .43558 L .4172 .45185 L p .56 .614 .864 r
F P
0 g
s
.43062 .46119 m .4172 .45185 L .4283 .43558 L p .525 .567 .84 r
F P
0 g
s
.45743 .48358 m .47089 .49509 L .46884 .50359 L p .41 .505 .845 r
F P
0 g
s
.48281 .51205 m .46884 .50359 L .47089 .49509 L p .434 .529 .855 r
F P
0 g
s
.39132 .414 m .40378 .41887 L .39018 .43941 L p .651 .741 .915 r
F P
0 g
s
.39018 .43941 m .37649 .43668 L .39132 .414 L p .651 .741 .915 r
F P
0 g
s
.52511 .52492 m .52473 .53158 L .5211 .53125 L closepath p .61 .779 .962 r
F P
0 g
s
.52511 .52492 m .52839 .53136 L .52473 .53158 L closepath p .623 .79 .962 r
F P
0 g
s
.60728 .47464 m .5937 .48576 L .58749 .47557 L p .851 .823 .82 r
F P
0 g
s
.58749 .47557 m .59992 .46234 L .60728 .47464 L p .851 .823 .82 r
F P
0 g
s
.70354 .44316 m .68945 .44149 L .67579 .41625 L p .52 .676 .935 r
F P
0 g
s
.66283 .41852 m .67579 .41625 L .68945 .44149 L p .591 .716 .93 r
F P
0 g
s
.52511 .52492 m .53182 .5306 L .52839 .53136 L closepath p .637 .798 .96 r
F P
0 g
s
.52511 .52492 m .5211 .53125 L .51774 .53039 L closepath p .601 .767 .959 r
F P
0 g
s
.4283 .43558 m .44043 .44704 L .43062 .46119 L p .525 .567 .84 r
F P
0 g
s
.44401 .47201 m .43062 .46119 L .44043 .44704 L p .502 .535 .823 r
F P
0 g
s
.52511 .52492 m .53481 .52936 L .53182 .5306 L closepath p .653 .803 .955 r
F P
0 g
s
.52511 .52492 m .51774 .53039 L .51488 .52905 L closepath p .596 .754 .953 r
F P
0 g
s
.55213 .5239 m .53866 .52578 L .53925 .52369 L p .757 .862 .927 r
F P
0 g
s
.53925 .52369 m .55335 .5197 L .55213 .5239 L p .757 .862 .927 r
F P
0 g
s
.3787 .41129 m .39132 .414 L .37649 .43668 L p .695 .804 .933 r
F P
0 g
s
.37649 .43668 m .36267 .43612 L .3787 .41129 L p .695 .804 .933 r
F P
0 g
s
.56738 .51338 m .55335 .5197 L .55266 .51545 L p .818 .863 .881 r
F P
0 g
s
.55266 .51545 m .5664 .50699 L .56738 .51338 L p .818 .863 .881 r
F P
0 g
s
.48281 .51205 m .49686 .51881 L .49769 .52304 L p .412 .577 .906 r
F P
0 g
s
.51137 .52536 m .49769 .52304 L .49686 .51881 L p .505 .648 .922 r
F P
0 g
s
.49769 .52304 m .51137 .52536 L .5127 .52734 L p .471 .664 .947 r
F P
0 g
s
.52511 .52492 m .53714 .52772 L .53481 .52936 L closepath p .668 .803 .948 r
F P
0 g
s
.52511 .52492 m .51488 .52905 L .5127 .52734 L closepath p .595 .742 .946 r
F P
0 g
s
.44043 .44704 m .45252 .45995 L .44401 .47201 L p .502 .535 .823 r
F P
0 g
s
.45743 .48358 m .44401 .47201 L .45252 .45995 L p .491 .52 .814 r
F P
0 g
s
.5937 .48576 m .58008 .49683 L .57504 .48872 L p .85 .823 .821 r
F P
0 g
s
.57504 .48872 m .58749 .47557 L .5937 .48576 L p .85 .823 .821 r
F P
0 g
s
.47089 .49509 m .4844 .50569 L .48281 .51205 L p .434 .529 .855 r
F P
0 g
s
.49686 .51881 m .48281 .51205 L .4844 .50569 L p .478 .575 .874 r
F P
0 g
s
.52511 .52492 m .53866 .52578 L .53714 .52772 L closepath p .68 .801 .939 r
F P
0 g
s
.71778 .44606 m .70354 .44316 L .68891 .41575 L p .466 .644 .935 r
F P
0 g
s
.67579 .41625 m .68891 .41575 L .70354 .44316 L p .52 .676 .935 r
F P
0 g
s
.52511 .52492 m .5127 .52734 L .51137 .52536 L closepath p .598 .731 .937 r
F P
0 g
s
.45252 .45995 m .4646 .47359 L .45743 .48358 L p .491 .52 .814 r
F P
0 g
s
.47089 .49509 m .45743 .48358 L .4646 .47359 L p .492 .522 .815 r
F P
0 g
s
.36591 .41036 m .3787 .41129 L .36267 .43612 L p .73 .855 .94 r
F P
0 g
s
.36267 .43612 m .34869 .43733 L .36591 .41036 L p .73 .855 .94 r
F P
0 g
s
.55335 .5197 m .53925 .52369 L .53889 .52157 L p .768 .833 .902 r
F P
0 g
s
.53889 .52157 m .55266 .51545 L .55335 .5197 L p .768 .833 .902 r
F P
0 g
s
.52511 .52492 m .53925 .52369 L .53866 .52578 L closepath p .69 .794 .93 r
F P
0 g
s
.58008 .49683 m .5664 .50699 L .56257 .50094 L p .838 .82 .832 r
F P
0 g
s
.56257 .50094 m .57504 .48872 L .58008 .49683 L p .838 .82 .832 r
F P
0 g
s
.49686 .51881 m .51097 .52324 L .51137 .52536 L p .505 .648 .922 r
F P
0 g
s
.52511 .52492 m .51137 .52536 L .51097 .52324 L closepath p .605 .722 .928 r
F P
0 g
s
.4844 .50569 m .49795 .51459 L .49686 .51881 L p .478 .575 .874 r
F P
0 g
s
.51097 .52324 m .49686 .51881 L .49795 .51459 L p .54 .639 .897 r
F P
0 g
s
.4646 .47359 m .47669 .48715 L .47089 .49509 L p .492 .522 .815 r
F P
0 g
s
.4844 .50569 m .47089 .49509 L .47669 .48715 L p .506 .541 .826 r
F P
0 g
s
.52511 .52492 m .53889 .52157 L .53925 .52369 L closepath p .696 .786 .92 r
F P
0 g
s
.5664 .50699 m .55266 .51545 L .55007 .51144 L p .812 .814 .852 r
F P
0 g
s
.55007 .51144 m .56257 .50094 L .5664 .50699 L p .812 .814 .852 r
F P
0 g
s
.49795 .51459 m .51154 .52114 L .51097 .52324 L p .54 .639 .897 r
F P
0 g
s
.52511 .52492 m .51097 .52324 L .51154 .52114 L closepath p .614 .716 .918 r
F P
0 g
s
.73212 .44952 m .71778 .44606 L .70219 .41647 L p .441 .628 .933 r
F P
0 g
s
.68891 .41575 m .70219 .41647 L .71778 .44606 L p .466 .644 .935 r
F P
0 g
s
.52511 .52492 m .53542 .51784 L .53758 .51957 L closepath p .697 .764 .903 r
F P
0 g
s
.52511 .52492 m .53255 .51649 L .53542 .51784 L closepath p .693 .752 .897 r
F P
0 g
s
.52511 .52492 m .52916 .51561 L .53255 .51649 L closepath p .687 .742 .893 r
F P
0 g
s
.52511 .52492 m .5255 .51527 L .52916 .51561 L closepath p .679 .732 .89 r
F P
0 g
s
.52511 .52492 m .52181 .51549 L .5255 .51527 L closepath p .669 .724 .89 r
F P
0 g
s
.52511 .52492 m .51835 .51626 L .52181 .51549 L closepath p .658 .717 .892 r
F P
0 g
s
.52511 .52492 m .51535 .51752 L .51835 .51626 L closepath p .647 .713 .896 r
F P
0 g
s
.52511 .52492 m .51303 .51918 L .51535 .51752 L closepath p .635 .712 .902 r
F P
0 g
s
.52511 .52492 m .51154 .52114 L .51303 .51918 L closepath p .624 .712 .91 r
F P
0 g
s
.52511 .52492 m .53758 .51957 L .53889 .52157 L closepath p .698 .775 .911 r
F P
0 g
s
.35296 .41064 m .36591 .41036 L .34869 .43733 L p .752 .887 .94 r
F P
0 g
s
.34869 .43733 m .33457 .43977 L .35296 .41064 L p .752 .887 .94 r
F P
0 g
s
.47669 .48715 m .48879 .49977 L .4844 .50569 L p .506 .541 .826 r
F P
0 g
s
.49795 .51459 m .4844 .50569 L .48879 .49977 L p .533 .579 .847 r
F P
0 g
s
.55266 .51545 m .53889 .52157 L .53758 .51957 L p .767 .801 .88 r
F P
0 g
s
.53758 .51957 m .55007 .51144 L .55266 .51545 L p .767 .801 .88 r
F P
0 g
s
.50091 .51067 m .51303 .51918 L .51154 .52114 L p .573 .636 .876 r
F P
0 g
s
.51154 .52114 m .49795 .51459 L .50091 .51067 L p .573 .636 .876 r
F P
0 g
s
.48879 .49977 m .50091 .51067 L .49795 .51459 L p .533 .579 .847 r
F P
0 g
s
.62483 .43881 m .61236 .44985 L .59767 .43715 L p .801 .767 .822 r
F P
0 g
s
.61236 .44985 m .59992 .46234 L .58726 .45154 L p .818 .766 .804 r
F P
0 g
s
.58726 .45154 m .59767 .43715 L .61236 .44985 L p .818 .766 .804 r
F P
0 g
s
.63738 .42975 m .62483 .43881 L .60813 .42419 L p .773 .768 .848 r
F P
0 g
s
.59767 .43715 m .60813 .42419 L .62483 .43881 L p .801 .767 .822 r
F P
0 g
s
.59992 .46234 m .58749 .47557 L .57688 .46664 L p .825 .765 .796 r
F P
0 g
s
.57688 .46664 m .58726 .45154 L .59992 .46234 L p .825 .765 .796 r
F P
0 g
s
.55007 .51144 m .53758 .51957 L .53542 .51784 L p .759 .769 .862 r
F P
0 g
s
.50555 .50732 m .51535 .51752 L .51303 .51918 L p .604 .639 .859 r
F P
0 g
s
.51303 .51918 m .50091 .51067 L .50555 .50732 L p .604 .639 .859 r
F P
0 g
s
.65004 .42296 m .63738 .42975 L .61867 .41318 L p .729 .764 .88 r
F P
0 g
s
.60813 .42419 m .61867 .41318 L .63738 .42975 L p .773 .768 .848 r
F P
0 g
s
.58749 .47557 m .57504 .48872 L .56651 .48164 L p .824 .765 .797 r
F P
0 g
s
.56651 .48164 m .57688 .46664 L .58749 .47557 L p .824 .765 .797 r
F P
0 g
s
.74653 .45285 m .73212 .44952 L .71561 .41774 L p .447 .632 .933 r
F P
0 g
s
.70219 .41647 m .71561 .41774 L .73212 .44952 L p .441 .628 .933 r
F P
0 g
s
.56257 .50094 m .55007 .51144 L .54577 .50795 L p .795 .769 .829 r
F P
0 g
s
.53542 .51784 m .54577 .50795 L .55007 .51144 L p .759 .769 .862 r
F P
0 g
s
.54577 .50795 m .53542 .51784 L .53255 .51649 L p .745 .74 .848 r
F P
0 g
s
.57504 .48872 m .56257 .50094 L .55613 .49567 L p .815 .766 .808 r
F P
0 g
s
.55613 .49567 m .56651 .48164 L .57504 .48872 L p .815 .766 .808 r
F P
0 g
s
.51154 .50477 m .51835 .51626 L .51535 .51752 L p .633 .646 .846 r
F P
0 g
s
.51535 .51752 m .50555 .50732 L .51154 .50477 L p .633 .646 .846 r
F P
0 g
s
.44638 .4215 m .45631 .43482 L .44043 .44704 L p .575 .577 .818 r
F P
0 g
s
.44043 .44704 m .4283 .43558 L .44638 .4215 L p .575 .577 .818 r
F P
0 g
s
.45252 .45995 m .44043 .44704 L .45631 .43482 L p .561 .551 .8 r
F P
0 g
s
.54577 .50795 m .55613 .49567 L .56257 .50094 L p .795 .769 .829 r
F P
0 g
s
.45631 .43482 m .46619 .44956 L .45252 .45995 L p .561 .551 .8 r
F P
0 g
s
.4646 .47359 m .45252 .45995 L .46619 .44956 L p .555 .539 .792 r
F P
0 g
s
.33987 .41148 m .35296 .41064 L .33457 .43977 L p .761 .901 .939 r
F P
0 g
s
.33457 .43977 m .32033 .44277 L .33987 .41148 L p .761 .901 .939 r
F P
0 g
s
.49572 .49471 m .50555 .50732 L .50091 .51067 L p .58 .588 .825 r
F P
0 g
s
.50091 .51067 m .48879 .49977 L .49572 .49471 L p .58 .588 .825 r
F P
0 g
s
.43636 .41014 m .44638 .4215 L .4283 .43558 L p .596 .619 .844 r
F P
0 g
s
.4283 .43558 m .4161 .42609 L .43636 .41014 L p .596 .619 .844 r
F P
0 g
s
.46619 .44956 m .47604 .46501 L .4646 .47359 L p .555 .539 .792 r
F P
0 g
s
.47669 .48715 m .4646 .47359 L .47604 .46501 L p .556 .54 .793 r
F P
0 g
s
.53255 .51649 m .54002 .50522 L .54577 .50795 L p .745 .74 .848 r
F P
0 g
s
.54002 .50522 m .53255 .51649 L .52916 .51561 L p .727 .715 .839 r
F P
0 g
s
.51848 .50322 m .52181 .51549 L .51835 .51626 L p .659 .658 .837 r
F P
0 g
s
.51835 .51626 m .51154 .50477 L .51848 .50322 L p .659 .658 .837 r
F P
0 g
s
.66283 .41852 m .65004 .42296 L .62933 .40444 L p .667 .752 .914 r
F P
0 g
s
.61867 .41318 m .62933 .40444 L .65004 .42296 L p .729 .764 .88 r
F P
0 g
s
.47604 .46501 m .48588 .48034 L .47669 .48715 L p .556 .54 .793 r
F P
0 g
s
.48879 .49977 m .47669 .48715 L .48588 .48034 L p .564 .556 .804 r
F P
0 g
s
.48588 .48034 m .49572 .49471 L .48879 .49977 L p .564 .556 .804 r
F P
0 g
s
.52916 .51561 m .53324 .50346 L .54002 .50522 L p .727 .715 .839 r
F P
0 g
s
.53324 .50346 m .52916 .51561 L .5255 .51527 L p .707 .692 .834 r
F P
0 g
s
.52589 .50277 m .5255 .51527 L .52181 .51549 L p .684 .673 .833 r
F P
0 g
s
.52181 .51549 m .51848 .50322 L .52589 .50277 L p .684 .673 .833 r
F P
0 g
s
.5255 .51527 m .52589 .50277 L .53324 .50346 L p .707 .692 .834 r
F P
0 g
s
.42623 .40104 m .43636 .41014 L .4161 .42609 L p .623 .674 .878 r
F P
0 g
s
.4161 .42609 m .40378 .41887 L .42623 .40104 L p .623 .674 .878 r
F P
0 g
s
.55613 .49567 m .54577 .50795 L .54002 .50522 L p .772 .729 .813 r
F P
0 g
s
.50471 .49086 m .51154 .50477 L .50555 .50732 L p .62 .601 .81 r
F P
0 g
s
.50555 .50732 m .49572 .49471 L .50471 .49086 L p .62 .601 .81 r
F P
0 g
s
.76097 .45542 m .74653 .45285 L .72912 .41889 L p .482 .654 .935 r
F P
0 g
s
.71561 .41774 m .72912 .41889 L .74653 .45285 L p .447 .632 .933 r
F P
0 g
s
.67579 .41625 m .66283 .41852 L .64012 .39803 L p .587 .729 .942 r
F P
0 g
s
.62933 .40444 m .64012 .39803 L .66283 .41852 L p .667 .752 .914 r
F P
0 g
s
.41597 .39426 m .42623 .40104 L .40378 .41887 L p .653 .741 .914 r
F P
0 g
s
.40378 .41887 m .39132 .414 L .41597 .39426 L p .653 .741 .914 r
F P
0 g
s
.56651 .48164 m .55613 .49567 L .54753 .49154 L p .787 .721 .79 r
F P
0 g
s
.54002 .50522 m .54753 .49154 L .55613 .49567 L p .772 .729 .813 r
F P
0 g
s
.32667 .41218 m .33987 .41148 L .32033 .44277 L p .758 .897 .939 r
F P
0 g
s
.32033 .44277 m .30601 .44565 L .32667 .41218 L p .758 .897 .939 r
F P
0 g
s
.54753 .49154 m .54002 .50522 L .53324 .50346 L p .747 .694 .802 r
F P
0 g
s
.51514 .48851 m .51848 .50322 L .51154 .50477 L p .656 .619 .8 r
F P
0 g
s
.51154 .50477 m .50471 .49086 L .51514 .48851 L p .656 .619 .8 r
F P
0 g
s
.49786 .47516 m .50471 .49086 L .49572 .49471 L p .612 .574 .788 r
F P
0 g
s
.49572 .49471 m .48588 .48034 L .49786 .47516 L p .612 .574 .788 r
F P
0 g
s
.57688 .46664 m .56651 .48164 L .55504 .47608 L p .793 .716 .779 r
F P
0 g
s
.54753 .49154 m .55504 .47608 L .56651 .48164 L p .787 .721 .79 r
F P
0 g
s
.58726 .45154 m .57688 .46664 L .56258 .45962 L p .794 .716 .778 r
F P
0 g
s
.55504 .47608 m .56258 .45962 L .57688 .46664 L p .793 .716 .779 r
F P
0 g
s
.53324 .50346 m .53734 .48886 L .54753 .49154 L p .747 .694 .802 r
F P
0 g
s
.53734 .48886 m .53324 .50346 L .52589 .50277 L p .719 .665 .796 r
F P
0 g
s
.52628 .48782 m .52589 .50277 L .51848 .50322 L p .689 .64 .796 r
F P
0 g
s
.51848 .50322 m .51514 .48851 L .52628 .48782 L p .689 .64 .796 r
F P
0 g
s
.491 .45846 m .49786 .47516 L .48588 .48034 L p .607 .561 .777 r
F P
0 g
s
.48588 .48034 m .47604 .46501 L .491 .45846 L p .607 .561 .777 r
F P
0 g
s
.77538 .45672 m .76097 .45542 L .7427 .41925 L p .536 .686 .935 r
F P
0 g
s
.72912 .41889 m .7427 .41925 L .76097 .45542 L p .482 .654 .935 r
F P
0 g
s
.52589 .50277 m .52628 .48782 L .53734 .48886 L p .719 .665 .796 r
F P
0 g
s
.59767 .43715 m .58726 .45154 L .57012 .44304 L p .789 .719 .787 r
F P
0 g
s
.56258 .45962 m .57012 .44304 L .58726 .45154 L p .794 .716 .778 r
F P
0 g
s
.48412 .44162 m .491 .45846 L .47604 .46501 L p .607 .56 .775 r
F P
0 g
s
.47604 .46501 m .46619 .44956 L .48412 .44162 L p .607 .56 .775 r
F P
0 g
s
.40555 .38963 m .41597 .39426 L .39132 .414 L p .68 .809 .944 r
F P
0 g
s
.39132 .414 m .3787 .41129 L .40555 .38963 L p .68 .809 .944 r
F P
0 g
s
.55504 .47608 m .54753 .49154 L .53734 .48886 L p .756 .682 .779 r
F P
0 g
s
.60813 .42419 m .59767 .43715 L .57771 .42714 L p .777 .726 .805 r
F P
0 g
s
.57012 .44304 m .57771 .42714 L .59767 .43715 L p .789 .719 .787 r
F P
0 g
s
.68891 .41575 m .67579 .41625 L .65107 .39378 L p .503 .698 .957 r
F P
0 g
s
.64012 .39803 m .65107 .39378 L .67579 .41625 L p .587 .729 .942 r
F P
0 g
s
.51179 .47199 m .51514 .48851 L .50471 .49086 L p .653 .595 .777 r
F P
0 g
s
.50471 .49086 m .49786 .47516 L .51179 .47199 L p .653 .595 .777 r
F P
0 g
s
.47721 .42547 m .48412 .44162 L .46619 .44956 L p .61 .57 .784 r
F P
0 g
s
.46619 .44956 m .45631 .43482 L .47721 .42547 L p .61 .57 .784 r
F P
0 g
s
.31342 .4121 m .32667 .41218 L .30601 .44565 L p .745 .878 .941 r
F P
0 g
s
.30601 .44565 m .29167 .44776 L .31342 .4121 L p .745 .878 .941 r
F P
0 g
s
.61867 .41318 m .60813 .42419 L .58534 .41264 L p .756 .735 .833 r
F P
0 g
s
.57771 .42714 m .58534 .41264 L .60813 .42419 L p .777 .726 .805 r
F P
0 g
s
.47025 .41072 m .47721 .42547 L .45631 .43482 L p .618 .592 .802 r
F P
0 g
s
.45631 .43482 m .44638 .4215 L .47025 .41072 L p .618 .592 .802 r
F P
0 g
s
.78971 .45639 m .77538 .45672 L .75628 .41832 L p .598 .722 .931 r
F P
0 g
s
.7427 .41925 m .75628 .41832 L .77538 .45672 L p .536 .686 .935 r
F P
0 g
s
.53734 .48886 m .54145 .47247 L .55504 .47608 L p .756 .682 .779 r
F P
0 g
s
.54145 .47247 m .53734 .48886 L .52628 .48782 L p .724 .648 .773 r
F P
0 g
s
.56258 .45962 m .55504 .47608 L .54145 .47247 L p .761 .675 .768 r
F P
0 g
s
.52667 .47107 m .52628 .48782 L .51514 .48851 L p .69 .62 .773 r
F P
0 g
s
.51514 .48851 m .51179 .47199 L .52667 .47107 L p .69 .62 .773 r
F P
0 g
s
.50842 .45445 m .51179 .47199 L .49786 .47516 L p .651 .584 .767 r
F P
0 g
s
.49786 .47516 m .491 .45846 L .50842 .45445 L p .651 .584 .767 r
F P
0 g
s
.52628 .48782 m .52667 .47107 L .54145 .47247 L p .724 .648 .773 r
F P
0 g
s
.46322 .3979 m .47025 .41072 L .44638 .4215 L p .629 .628 .83 r
F P
0 g
s
.44638 .4215 m .43636 .41014 L .46322 .3979 L p .629 .628 .83 r
F P
0 g
s
.57012 .44304 m .56258 .45962 L .54557 .45506 L p .761 .675 .767 r
F P
0 g
s
.54145 .47247 m .54557 .45506 L .56258 .45962 L p .761 .675 .768 r
F P
0 g
s
.62933 .40444 m .61867 .41318 L .59304 .40008 L p .721 .744 .87 r
F P
0 g
s
.58534 .41264 m .59304 .40008 L .61867 .41318 L p .756 .735 .833 r
F P
0 g
s
.80395 .45433 m .78971 .45639 L .76983 .41574 L p .657 .754 .921 r
F P
0 g
s
.75628 .41832 m .76983 .41574 L .78971 .45639 L p .598 .722 .931 r
F P
0 g
s
.39497 .38677 m .40555 .38963 L .3787 .41129 L p .699 .866 .961 r
F P
0 g
s
.3787 .41129 m .36591 .41036 L .39497 .38677 L p .699 .866 .961 r
F P
0 g
s
.50505 .43676 m .50842 .45445 L .491 .45846 L p .651 .583 .765 r
F P
0 g
s
.491 .45846 m .48412 .44162 L .50505 .43676 L p .651 .583 .765 r
F P
0 g
s
.30015 .41071 m .31342 .4121 L .29167 .44776 L p .722 .844 .94 r
F P
0 g
s
.29167 .44776 m .27734 .44859 L .30015 .41071 L p .722 .844 .94 r
F P
0 g
s
.54557 .45506 m .54145 .47247 L .52667 .47107 L p .726 .641 .762 r
F P
0 g
s
.70219 .41647 m .68891 .41575 L .66219 .39129 L p .434 .669 .961 r
F P
0 g
s
.65107 .39378 m .66219 .39129 L .68891 .41575 L p .503 .698 .957 r
F P
0 g
s
.52707 .45329 m .52667 .47107 L .51179 .47199 L p .69 .61 .762 r
F P
0 g
s
.51179 .47199 m .50842 .45445 L .52707 .45329 L p .69 .61 .762 r
F P
0 g
s
.57771 .42714 m .57012 .44304 L .5497 .43749 L p .758 .68 .776 r
F P
0 g
s
.54557 .45506 m .5497 .43749 L .57012 .44304 L p .761 .675 .767 r
F P
0 g
s
.81807 .45061 m .80395 .45433 L .78331 .41138 L p .706 .779 .909 r
F P
0 g
s
.76983 .41574 m .78331 .41138 L .80395 .45433 L p .657 .754 .921 r
F P
0 g
s
.52667 .47107 m .52707 .45329 L .54557 .45506 L p .726 .641 .762 r
F P
0 g
s
.85986 .43317 m .84599 .43954 L .82333 .38952 L p .772 .809 .883 r
F P
0 g
s
.82333 .38952 m .8366 .38074 L .85986 .43317 L p .772 .809 .883 r
F P
0 g
s
.45611 .38732 m .46322 .3979 L .43636 .41014 L p .643 .678 .868 r
F P
0 g
s
.43636 .41014 m .42623 .40104 L .45611 .38732 L p .643 .678 .868 r
F P
0 g
s
.83207 .44553 m .81807 .45061 L .79672 .40533 L p .741 .796 .896 r
F P
0 g
s
.78331 .41138 m .79672 .40533 L .81807 .45061 L p .706 .779 .909 r
F P
0 g
s
.84599 .43954 m .83207 .44553 L .81005 .3979 L p .763 .806 .887 r
F P
0 g
s
.81005 .3979 m .82333 .38952 L .84599 .43954 L p .763 .806 .887 r
F P
0 g
s
.79672 .40533 m .81005 .3979 L .83207 .44553 L p .741 .796 .896 r
F P
0 g
s
.50166 .41973 m .50505 .43676 L .48412 .44162 L p .652 .592 .774 r
F P
0 g
s
.48412 .44162 m .47721 .42547 L .50166 .41973 L p .652 .592 .774 r
F P
0 g
s
.64012 .39803 m .62933 .40444 L .60084 .38976 L p .666 .75 .913 r
F P
0 g
s
.59304 .40008 m .60084 .38976 L .62933 .40444 L p .721 .744 .87 r
F P
0 g
s
.5497 .43749 m .54557 .45506 L .52707 .45329 L p .727 .64 .761 r
F P
0 g
s
.58534 .41264 m .57771 .42714 L .55385 .4206 L p .75 .69 .794 r
F P
0 g
s
.5497 .43749 m .55385 .4206 L .57771 .42714 L p .758 .68 .776 r
F P
0 g
s
.52746 .43534 m .52707 .45329 L .50842 .45445 L p .69 .609 .761 r
F P
0 g
s
.50842 .45445 m .50505 .43676 L .52746 .43534 L p .69 .609 .761 r
F P
0 g
s
.28691 .40767 m .30015 .41071 L .27734 .44859 L p .69 .8 .933 r
F P
0 g
s
.27734 .44859 m .26307 .4478 L .28691 .40767 L p .69 .8 .933 r
F P
0 g
s
.52707 .45329 m .52746 .43534 L .5497 .43749 L p .727 .64 .761 r
F P
0 g
s
.49824 .40409 m .50166 .41973 L .47721 .42547 L p .655 .611 .792 r
F P
0 g
s
.47721 .42547 m .47025 .41072 L .49824 .40409 L p .655 .611 .792 r
F P
0 g
s
.38424 .38511 m .39497 .38677 L .36591 .41036 L p .707 .902 .966 r
F P
0 g
s
.36591 .41036 m .35296 .41064 L .38424 .38511 L p .707 .902 .966 r
F P
0 g
s
.55385 .4206 m .5497 .43749 L .52746 .43534 L p .725 .646 .77 r
F P
0 g
s
.44889 .37905 m .45611 .38732 L .42623 .40104 L p .656 .741 .912 r
F P
0 g
s
.42623 .40104 m .41597 .39426 L .44889 .37905 L p .656 .741 .912 r
F P
0 g
s
.59304 .40008 m .58534 .41264 L .55804 .40509 L p .735 .705 .823 r
F P
0 g
s
.55385 .4206 m .55804 .40509 L .58534 .41264 L p .75 .69 .794 r
F P
0 g
s
.71561 .41774 m .70219 .41647 L .67347 .39 L p .4 .653 .96 r
F P
0 g
s
.66219 .39129 m .67347 .39 L .70219 .41647 L p .434 .669 .961 r
F P
0 g
s
.52786 .41806 m .52746 .43534 L .50505 .43676 L p .69 .617 .769 r
F P
0 g
s
.50505 .43676 m .50166 .41973 L .52786 .41806 L p .69 .617 .769 r
F P
0 g
s
.27372 .40285 m .28691 .40767 L .26307 .4478 L p .653 .751 .921 r
F P
0 g
s
.26307 .4478 m .2489 .44525 L .27372 .40285 L p .653 .751 .921 r
F P
0 g
s
.52746 .43534 m .52786 .41806 L .55385 .4206 L p .725 .646 .77 r
F P
0 g
s
.49478 .39036 m .49824 .40409 L .47025 .41072 L p .659 .641 .821 r
F P
0 g
s
.47025 .41072 m .46322 .3979 L .49478 .39036 L p .659 .641 .821 r
F P
0 g
s
.65107 .39378 m .64012 .39803 L .60875 .38176 L p .588 .745 .951 r
F P
0 g
s
.60084 .38976 m .60875 .38176 L .64012 .39803 L p .666 .75 .913 r
F P
0 g
s
.55804 .40509 m .55385 .4206 L .52786 .41806 L p .721 .659 .788 r
F P
0 g
s
.2606 .39633 m .27372 .40285 L .2489 .44525 L p .618 .704 .907 r
F P
0 g
s
.2489 .44525 m .23484 .44105 L .2606 .39633 L p .618 .704 .907 r
F P
0 g
s
.52826 .40216 m .52786 .41806 L .50166 .41973 L p .689 .633 .788 r
F P
0 g
s
.50166 .41973 m .49824 .40409 L .52826 .40216 L p .689 .633 .788 r
F P
0 g
s
.24755 .38841 m .2606 .39633 L .23484 .44105 L p .59 .667 .893 r
F P
0 g
s
.23484 .44105 m .22089 .43549 L .24755 .38841 L p .59 .667 .893 r
F P
0 g
s
.60084 .38976 m .59304 .40008 L .56227 .3915 L p .709 .726 .863 r
F P
0 g
s
.55804 .40509 m .56227 .3915 L .59304 .40008 L p .735 .705 .823 r
F P
0 g
s
.23454 .37954 m .24755 .38841 L .22089 .43549 L p .57 .642 .883 r
F P
0 g
s
.22089 .43549 m .20702 .429 L .23454 .37954 L p .57 .642 .883 r
F P
0 g
s
.52786 .41806 m .52826 .40216 L .55804 .40509 L p .721 .659 .788 r
F P
0 g
s
.22154 .37026 m .23454 .37954 L .20702 .429 L p .562 .632 .878 r
F P
0 g
s
.20702 .429 m .19318 .42214 L .22154 .37026 L p .562 .632 .878 r
F P
0 g
s
.44155 .37291 m .44889 .37905 L .41597 .39426 L p .662 .808 .953 r
F P
0 g
s
.41597 .39426 m .40555 .38963 L .44155 .37291 L p .662 .808 .953 r
F P
0 g
s
.37336 .38399 m .38424 .38511 L .35296 .41064 L p .709 .917 .965 r
F P
0 g
s
.35296 .41064 m .33987 .41148 L .37336 .38399 L p .709 .917 .965 r
F P
0 g
s
.49128 .37886 m .49478 .39036 L .46322 .3979 L p .661 .686 .862 r
F P
0 g
s
.46322 .3979 m .45611 .38732 L .49128 .37886 L p .661 .686 .862 r
F P
0 g
s
.72912 .41889 m .71561 .41774 L .68489 .38927 L p .409 .657 .961 r
F P
0 g
s
.67347 .39 m .68489 .38927 L .71561 .41774 L p .4 .653 .96 r
F P
0 g
s
.56227 .3915 m .55804 .40509 L .52826 .40216 L p .712 .68 .818 r
F P
0 g
s
.52866 .38816 m .52826 .40216 L .49824 .40409 L p .687 .659 .817 r
F P
0 g
s
.49824 .40409 m .49478 .39036 L .52866 .38816 L p .687 .659 .817 r
F P
0 g
s
.66219 .39129 m .65107 .39378 L .61679 .3759 L p .496 .727 .975 r
F P
0 g
s
.60875 .38176 m .61679 .3759 L .65107 .39378 L p .588 .745 .951 r
F P
0 g
s
.52826 .40216 m .52866 .38816 L .56227 .3915 L p .712 .68 .818 r
F P
0 g
s
.60875 .38176 m .60084 .38976 L .56656 .38014 L p .665 .747 .912 r
F P
0 g
s
.56227 .3915 m .56656 .38014 L .60084 .38976 L p .709 .726 .863 r
F P
0 g
s
.48772 .36966 m .49128 .37886 L .45611 .38732 L p .658 .742 .912 r
F P
0 g
s
.45611 .38732 m .44889 .37905 L .48772 .36966 L p .658 .742 .912 r
F P
0 g
s
.56656 .38014 m .56227 .3915 L .52866 .38816 L p .695 .71 .859 r
F P
0 g
s
.43408 .36853 m .44155 .37291 L .40555 .38963 L p .656 .864 .978 r
F P
0 g
s
.40555 .38963 m .39497 .38677 L .43408 .36853 L p .656 .864 .978 r
F P
0 g
s
.36238 .38271 m .37336 .38399 L .33987 .41148 L p .708 .913 .965 r
F P
0 g
s
.33987 .41148 m .32667 .41218 L .36238 .38271 L p .708 .913 .965 r
F P
0 g
s
.52907 .3764 m .52866 .38816 L .49478 .39036 L p .679 .696 .859 r
F P
0 g
s
.49478 .39036 m .49128 .37886 L .52907 .3764 L p .679 .696 .859 r
F P
0 g
s
.7427 .41925 m .72912 .41889 L .69642 .38837 L p .455 .678 .961 r
F P
0 g
s
.68489 .38927 m .69642 .38837 L .72912 .41889 L p .409 .657 .961 r
F P
0 g
s
.52866 .38816 m .52907 .3764 L .56656 .38014 L p .695 .71 .859 r
F P
0 g
s
.67347 .39 m .66219 .39129 L .62497 .37179 L p .413 .702 .981 r
F P
0 g
s
.61679 .3759 m .62497 .37179 L .66219 .39129 L p .496 .727 .975 r
F P
0 g
s
.61679 .3759 m .60875 .38176 L .57092 .37108 L p .595 .762 .959 r
F P
0 g
s
.56656 .38014 m .57092 .37108 L .60875 .38176 L p .665 .747 .912 r
F P
0 g
s
.57092 .37108 m .56656 .38014 L .52907 .3764 L p .663 .745 .911 r
F P
0 g
s
.4841 .36258 m .48772 .36966 L .44889 .37905 L p .642 .802 .96 r
F P
0 g
s
.44889 .37905 m .44155 .37291 L .4841 .36258 L p .642 .802 .96 r
F P
0 g
s
.52949 .36692 m .52907 .3764 L .49128 .37886 L p .661 .743 .911 r
F P
0 g
s
.49128 .37886 m .48772 .36966 L .52949 .36692 L p .661 .743 .911 r
F P
0 g
s
.35132 .38063 m .36238 .38271 L .32667 .41218 L p .705 .892 .965 r
F P
0 g
s
.32667 .41218 m .31342 .4121 L .35132 .38063 L p .705 .892 .965 r
F P
0 g
s
.75628 .41832 m .7427 .41925 L .70802 .38668 L p .523 .707 .955 r
F P
0 g
s
.69642 .38837 m .70802 .38668 L .7427 .41925 L p .455 .678 .961 r
F P
0 g
s
.42649 .36533 m .43408 .36853 L .39497 .38677 L p .642 .898 .984 r
F P
0 g
s
.39497 .38677 m .38424 .38511 L .42649 .36533 L p .642 .898 .984 r
F P
0 g
s
.52907 .3764 m .52949 .36692 L .57092 .37108 L p .663 .745 .911 r
F P
0 g
s
.68489 .38927 m .67347 .39 L .63328 .36887 L p .371 .686 .98 r
F P
0 g
s
.62497 .37179 m .63328 .36887 L .67347 .39 L p .413 .702 .981 r
F P
0 g
s
.62497 .37179 m .61679 .3759 L .57535 .36415 L p .502 .759 .988 r
F P
0 g
s
.57092 .37108 m .57535 .36415 L .61679 .3759 L p .595 .762 .959 r
F P
0 g
s
.76983 .41574 m .75628 .41832 L .71966 .38365 L p .595 .734 .941 r
F P
0 g
s
.70802 .38668 m .71966 .38365 L .75628 .41832 L p .523 .707 .955 r
F P
0 g
s
.57535 .36415 m .57092 .37108 L .52949 .36692 L p .607 .778 .963 r
F P
0 g
s
.34022 .37721 m .35132 .38063 L .31342 .4121 L p .694 .853 .959 r
F P
0 g
s
.31342 .4121 m .30015 .41071 L .34022 .37721 L p .694 .853 .959 r
F P
0 g
s
.48041 .35724 m .4841 .36258 L .44155 .37291 L p .608 .85 .99 r
F P
0 g
s
.44155 .37291 m .43408 .36853 L .48041 .35724 L p .608 .85 .99 r
F P
0 g
s
.52992 .35957 m .52949 .36692 L .48772 .36966 L p .623 .792 .963 r
F P
0 g
s
.48772 .36966 m .4841 .36258 L .52992 .35957 L p .623 .792 .963 r
F P
0 g
s
.41879 .36265 m .42649 .36533 L .38424 .38511 L p .632 .91 .982 r
F P
0 g
s
.38424 .38511 m .37336 .38399 L .41879 .36265 L p .632 .91 .982 r
F P
0 g
s
.52949 .36692 m .52992 .35957 L .57535 .36415 L p .607 .778 .963 r
F P
0 g
s
.78331 .41138 m .76983 .41574 L .73129 .37895 L p .657 .753 .921 r
F P
0 g
s
.71966 .38365 m .73129 .37895 L .76983 .41574 L p .595 .734 .941 r
F P
0 g
s
.32913 .3721 m .34022 .37721 L .30015 .41071 L p .676 .803 .943 r
F P
0 g
s
.30015 .41071 m .28691 .40767 L .32913 .3721 L p .676 .803 .943 r
F P
0 g
s
.69642 .38837 m .68489 .38927 L .64171 .36647 L p .382 .69 .98 r
F P
0 g
s
.63328 .36887 m .64171 .36647 L .68489 .38927 L p .371 .686 .98 r
F P
0 g
s
.63328 .36887 m .62497 .37179 L .57986 .35895 L p .413 .742 .993 r
F P
0 g
s
.57535 .36415 m .57986 .35895 L .62497 .37179 L p .502 .759 .988 r
F P
0 g
s
.79672 .40533 m .78331 .41138 L .74289 .37243 L p .704 .765 .899 r
F P
0 g
s
.73129 .37895 m .74289 .37243 L .78331 .41138 L p .657 .753 .921 r
F P
0 g
s
.57986 .35895 m .57535 .36415 L .52992 .35957 L p .524 .793 .994 r
F P
0 g
s
.47666 .35308 m .48041 .35724 L .43408 .36853 L p .566 .873 .994 r
F P
0 g
s
.43408 .36853 m .42649 .36533 L .47666 .35308 L p .566 .873 .994 r
F P
0 g
s
.53035 .35395 m .52992 .35957 L .4841 .36258 L p .561 .825 .995 r
F P
0 g
s
.4841 .36258 m .48041 .35724 L .53035 .35395 L p .561 .825 .995 r
F P
0 g
s
.81005 .3979 m .79672 .40533 L .75446 .36418 L p .737 .772 .881 r
F P
0 g
s
.74289 .37243 m .75446 .36418 L .79672 .40533 L p .704 .765 .899 r
F P
0 g
s
.41099 .3598 m .41879 .36265 L .37336 .38399 L p .635 .907 .983 r
F P
0 g
s
.37336 .38399 m .36238 .38271 L .41099 .3598 L p .635 .907 .983 r
F P
0 g
s
.31805 .36516 m .32913 .3721 L .28691 .40767 L p .654 .751 .921 r
F P
0 g
s
.28691 .40767 m .27372 .40285 L .31805 .36516 L p .654 .751 .921 r
F P
0 g
s
.52992 .35957 m .53035 .35395 L .57986 .35895 L p .524 .793 .994 r
F P
0 g
s
.82333 .38952 m .81005 .3979 L .76598 .3545 L p .756 .775 .869 r
F P
0 g
s
.75446 .36418 m .76598 .3545 L .81005 .3979 L p .737 .772 .881 r
F P
0 g
s
.8366 .38074 m .82333 .38952 L .77749 .34384 L p .763 .776 .864 r
F P
0 g
s
.76598 .3545 m .77749 .34384 L .82333 .38952 L p .756 .775 .869 r
F P
0 g
s
.70802 .38668 m .69642 .38837 L .65024 .3639 L p .439 .71 .981 r
F P
0 g
s
.64171 .36647 m .65024 .3639 L .69642 .38837 L p .382 .69 .98 r
F P
0 g
s
.30701 .35649 m .31805 .36516 L .27372 .40285 L p .632 .704 .898 r
F P
0 g
s
.27372 .40285 m .2606 .39633 L .30701 .35649 L p .632 .704 .898 r
F P
0 g
s
.77749 .34384 m .78901 .33274 L .8366 .38074 L p .763 .776 .864 r
F P
0 g
s
.64171 .36647 m .63328 .36887 L .58445 .35493 L p .364 .727 .988 r
F P
0 g
s
.57986 .35895 m .58445 .35493 L .63328 .36887 L p .413 .742 .993 r
F P
0 g
s
.58445 .35493 m .57986 .35895 L .53035 .35395 L p .439 .787 .998 r
F P
0 g
s
.29601 .34638 m .30701 .35649 L .2606 .39633 L p .614 .668 .878 r
F P
0 g
s
.2606 .39633 m .24755 .38841 L .29601 .34638 L p .614 .668 .878 r
F P
0 g
s
.47285 .34942 m .47666 .35308 L .42649 .36533 L p .54 .878 .989 r
F P
0 g
s
.42649 .36533 m .41879 .36265 L .47285 .34942 L p .54 .878 .989 r
F P
0 g
s
.40314 .35611 m .41099 .3598 L .36238 .38271 L p .647 .889 .984 r
F P
0 g
s
.36238 .38271 m .35132 .38063 L .40314 .35611 L p .647 .889 .984 r
F P
0 g
s
.53079 .3495 m .53035 .35395 L .48041 .35724 L p .493 .833 .998 r
F P
0 g
s
.48041 .35724 m .47666 .35308 L .53079 .3495 L p .493 .833 .998 r
F P
0 g
s
.28501 .33528 m .29601 .34638 L .24755 .38841 L p .602 .645 .865 r
F P
0 g
s
.24755 .38841 m .23454 .37954 L .28501 .33528 L p .602 .645 .865 r
F P
0 g
s
.53035 .35395 m .53079 .3495 L .58445 .35493 L p .439 .787 .998 r
F P
0 g
s
.71966 .38365 m .70802 .38668 L .65883 .3605 L p .519 .733 .971 r
F P
0 g
s
.65024 .3639 m .65883 .3605 L .70802 .38668 L p .439 .71 .981 r
F P
0 g
s
.27399 .32374 m .28501 .33528 L .23454 .37954 L p .597 .636 .86 r
F P
0 g
s
.23454 .37954 m .22154 .37026 L .27399 .32374 L p .597 .636 .86 r
F P
0 g
s
.65024 .3639 m .64171 .36647 L .58912 .35142 L p .377 .732 .99 r
F P
0 g
s
.58445 .35493 m .58912 .35142 L .64171 .36647 L p .364 .727 .988 r
F P
0 g
s
.39524 .35105 m .40314 .35611 L .35132 .38063 L p .658 .852 .974 r
F P
0 g
s
.35132 .38063 m .34022 .37721 L .39524 .35105 L p .658 .852 .974 r
F P
0 g
s
.58912 .35142 m .58445 .35493 L .53079 .3495 L p .391 .776 .99 r
F P
0 g
s
.46899 .34556 m .47285 .34942 L .41879 .36265 L p .547 .877 .991 r
F P
0 g
s
.41879 .36265 m .41099 .3598 L .46899 .34556 L p .547 .877 .991 r
F P
0 g
s
.73129 .37895 m .71966 .38365 L .66747 .35574 L p .596 .748 .95 r
F P
0 g
s
.65883 .3605 m .66747 .35574 L .71966 .38365 L p .519 .733 .971 r
F P
0 g
s
.53124 .34555 m .53079 .3495 L .47666 .35308 L p .453 .83 .99 r
F P
0 g
s
.47666 .35308 m .47285 .34942 L .53124 .34555 L p .453 .83 .99 r
F P
0 g
s
.53079 .3495 m .53124 .34555 L .58912 .35142 L p .391 .776 .99 r
F P
0 g
s
.38733 .34427 m .39524 .35105 L .34022 .37721 L p .66 .803 .951 r
F P
0 g
s
.34022 .37721 m .32913 .3721 L .38733 .34427 L p .66 .803 .951 r
F P
0 g
s
.65883 .3605 m .65024 .3639 L .59384 .34772 L p .441 .749 .993 r
F P
0 g
s
.58912 .35142 m .59384 .34772 L .65024 .3639 L p .377 .732 .99 r
F P
0 g
s
.74289 .37243 m .73129 .37895 L .67612 .34926 L p .657 .753 .921 r
F P
0 g
s
.66747 .35574 m .67612 .34926 L .73129 .37895 L p .596 .748 .95 r
F P
0 g
s
.59384 .34772 m .58912 .35142 L .53124 .34555 L p .404 .78 .993 r
F P
0 g
s
.46509 .34085 m .46899 .34556 L .41099 .3598 L p .58 .868 .995 r
F P
0 g
s
.41099 .3598 m .40314 .35611 L .46509 .34085 L p .58 .868 .995 r
F P
0 g
s
.53169 .3414 m .53124 .34555 L .47285 .34942 L p .464 .831 .993 r
F P
0 g
s
.47285 .34942 m .46899 .34556 L .53169 .3414 L p .464 .831 .993 r
F P
0 g
s
.75446 .36418 m .74289 .37243 L .68476 .34093 L p .7 .752 .892 r
F P
0 g
s
.67612 .34926 m .68476 .34093 L .74289 .37243 L p .657 .753 .921 r
F P
0 g
s
.37942 .33563 m .38733 .34427 L .32913 .3721 L p .654 .751 .921 r
F P
0 g
s
.32913 .3721 m .31805 .36516 L .37942 .33563 L p .654 .751 .921 r
F P
0 g
s
.53124 .34555 m .53169 .3414 L .59384 .34772 L p .404 .78 .993 r
F P
0 g
s
.66747 .35574 m .65883 .3605 L .5986 .34317 L p .526 .762 .983 r
F P
0 g
s
.59384 .34772 m .5986 .34317 L .65883 .3605 L p .441 .749 .993 r
F P
0 g
s
.76598 .3545 m .75446 .36418 L .69339 .33083 L p .727 .749 .869 r
F P
0 g
s
.68476 .34093 m .69339 .33083 L .75446 .36418 L p .7 .752 .892 r
F P
0 g
s
.37152 .32521 m .37942 .33563 L .31805 .36516 L p .645 .706 .891 r
F P
0 g
s
.31805 .36516 m .30701 .35649 L .37152 .32521 L p .645 .706 .891 r
F P
0 g
s
.46117 .33476 m .46509 .34085 L .40314 .35611 L p .617 .84 .985 r
F P
0 g
s
.40314 .35611 m .39524 .35105 L .46117 .33476 L p .617 .84 .985 r
F P
0 g
s
.5986 .34317 m .59384 .34772 L .53169 .3414 L p .467 .791 .999 r
F P
0 g
s
.77749 .34384 m .76598 .3545 L .702 .31926 L p .742 .746 .855 r
F P
0 g
s
.69339 .33083 m .702 .31926 L .76598 .3545 L p .727 .749 .869 r
F P
0 g
s
.53215 .33639 m .53169 .3414 L .46899 .34556 L p .515 .833 1 r
F P
0 g
s
.46899 .34556 m .46509 .34085 L .53215 .33639 L p .515 .833 1 r
F P
0 g
s
.36363 .31332 m .37152 .32521 L .30701 .35649 L p .637 .673 .867 r
F P
0 g
s
.30701 .35649 m .29601 .34638 L .36363 .31332 L p .637 .673 .867 r
F P
0 g
s
.67612 .34926 m .66747 .35574 L .60339 .33723 L p .602 .762 .956 r
F P
0 g
s
.5986 .34317 m .60339 .33723 L .66747 .35574 L p .526 .762 .983 r
F P
0 g
s
.78901 .33274 m .77749 .34384 L .71062 .30668 L p .748 .745 .849 r
F P
0 g
s
.702 .31926 m .71062 .30668 L .77749 .34384 L p .742 .746 .855 r
F P
0 g
s
.53169 .3414 m .53215 .33639 L .5986 .34317 L p .467 .791 .999 r
F P
0 g
s
.71062 .30668 m .71927 .29362 L .78901 .33274 L p .748 .745 .849 r
F P
0 g
s
.35574 .3004 m .36363 .31332 L .29601 .34638 L p .631 .652 .852 r
F P
0 g
s
.29601 .34638 m .28501 .33528 L .35574 .3004 L p .631 .652 .852 r
F P
0 g
s
.45724 .32691 m .46117 .33476 L .39524 .35105 L p .643 .797 .957 r
F P
0 g
s
.39524 .35105 m .38733 .34427 L .45724 .32691 L p .643 .797 .957 r
F P
0 g
s
.60339 .33723 m .5986 .34317 L .53215 .33639 L p .546 .792 .99 r
F P
0 g
s
.34782 .287 m .35574 .3004 L .28501 .33528 L p .628 .644 .846 r
F P
0 g
s
.28501 .33528 m .27399 .32374 L .34782 .287 L p .628 .644 .846 r
F P
0 g
s
.68476 .34093 m .67612 .34926 L .6082 .32955 L p .657 .752 .92 r
F P
0 g
s
.60339 .33723 m .6082 .32955 L .67612 .34926 L p .602 .762 .956 r
F P
0 g
s
.53261 .32998 m .53215 .33639 L .46509 .34085 L p .578 .819 .99 r
F P
0 g
s
.46509 .34085 m .46117 .33476 L .53261 .32998 L p .578 .819 .99 r
F P
0 g
s
.53215 .33639 m .53261 .32998 L .60339 .33723 L p .546 .792 .99 r
F P
0 g
s
.4533 .31718 m .45724 .32691 L .38733 .34427 L p .655 .751 .92 r
F P
0 g
s
.38733 .34427 m .37942 .33563 L .4533 .31718 L p .655 .751 .92 r
F P
0 g
s
.69339 .33083 m .68476 .34093 L .61301 .31998 L p .692 .739 .887 r
F P
0 g
s
.6082 .32955 m .61301 .31998 L .68476 .34093 L p .657 .752 .92 r
F P
0 g
s
.6082 .32955 m .60339 .33723 L .53261 .32998 L p .612 .776 .959 r
F P
0 g
s
.53307 .32182 m .53261 .32998 L .46117 .33476 L p .626 .788 .96 r
F P
0 g
s
.46117 .33476 m .45724 .32691 L .53307 .32182 L p .626 .788 .96 r
F P
0 g
s
.44937 .30564 m .4533 .31718 L .37942 .33563 L p .659 .711 .886 r
F P
0 g
s
.37942 .33563 m .37152 .32521 L .44937 .30564 L p .659 .711 .886 r
F P
0 g
s
.702 .31926 m .69339 .33083 L .61782 .30862 L p .713 .728 .861 r
F P
0 g
s
.61301 .31998 m .61782 .30862 L .69339 .33083 L p .692 .739 .887 r
F P
0 g
s
.53261 .32998 m .53307 .32182 L .6082 .32955 L p .612 .776 .959 r
F P
0 g
s
.61301 .31998 m .6082 .32955 L .53307 .32182 L p .656 .752 .92 r
F P
0 g
s
.44544 .2926 m .44937 .30564 L .37152 .32521 L p .659 .681 .86 r
F P
0 g
s
.37152 .32521 m .36363 .31332 L .44544 .2926 L p .659 .681 .86 r
F P
0 g
s
.71062 .30668 m .702 .31926 L .62262 .29575 L p .725 .72 .845 r
F P
0 g
s
.61782 .30862 m .62262 .29575 L .702 .31926 L p .713 .728 .861 r
F P
0 g
s
.53353 .31176 m .53307 .32182 L .45724 .32691 L p .656 .751 .92 r
F P
0 g
s
.45724 .32691 m .4533 .31718 L .53353 .31176 L p .656 .751 .92 r
F P
0 g
s
.53307 .32182 m .53353 .31176 L .61301 .31998 L p .656 .752 .92 r
F P
0 g
s
.71927 .29362 m .71062 .30668 L .62743 .28184 L p .729 .717 .839 r
F P
0 g
s
.62262 .29575 m .62743 .28184 L .71062 .30668 L p .725 .72 .845 r
F P
0 g
s
.4415 .27851 m .44544 .2926 L .36363 .31332 L p .658 .663 .844 r
F P
0 g
s
.36363 .31332 m .35574 .3004 L .4415 .27851 L p .658 .663 .844 r
F P
0 g
s
.61782 .30862 m .61301 .31998 L .53353 .31176 L p .682 .728 .884 r
F P
0 g
s
.53399 .2999 m .53353 .31176 L .4533 .31718 L p .671 .718 .884 r
F P
0 g
s
.4533 .31718 m .44937 .30564 L .53399 .2999 L p .671 .718 .884 r
F P
0 g
s
.62743 .28184 m .63227 .26744 L .71927 .29362 L p .729 .717 .839 r
F P
0 g
s
.43754 .26392 m .4415 .27851 L .35574 .3004 L p .657 .656 .838 r
F P
0 g
s
.35574 .3004 m .34782 .287 L .43754 .26392 L p .657 .656 .838 r
F P
0 g
s
.53353 .31176 m .53399 .2999 L .61782 .30862 L p .682 .728 .884 r
F P
0 g
s
.62262 .29575 m .61782 .30862 L .53399 .2999 L p .697 .709 .857 r
F P
0 g
s
.53446 .28652 m .53399 .2999 L .44937 .30564 L p .679 .694 .857 r
F P
0 g
s
.44937 .30564 m .44544 .2926 L .53446 .28652 L p .679 .694 .857 r
F P
0 g
s
.62743 .28184 m .62262 .29575 L .53446 .28652 L p .705 .698 .841 r
F P
0 g
s
.53399 .2999 m .53446 .28652 L .62262 .29575 L p .697 .709 .857 r
F P
0 g
s
.53492 .27208 m .53446 .28652 L .44544 .2926 L p .682 .679 .84 r
F P
0 g
s
.44544 .2926 m .4415 .27851 L .53492 .27208 L p .682 .679 .84 r
F P
0 g
s
.63227 .26744 m .62743 .28184 L .53492 .27208 L p .707 .693 .834 r
F P
0 g
s
.53446 .28652 m .53492 .27208 L .62743 .28184 L p .705 .698 .841 r
F P
0 g
s
.53539 .25714 m .53492 .27208 L .4415 .27851 L p .683 .673 .834 r
F P
0 g
s
.4415 .27851 m .43754 .26392 L .53539 .25714 L p .683 .673 .834 r
F P
0 g
s
.53492 .27208 m .53539 .25714 L .63227 .26744 L p .707 .693 .834 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000So[ZcE00?o0000okBaeOnd/MD00ond/MD;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`0001Oo[ZcE00?o0000
okBaeOnd/MD03_nd/MD:o`0001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[
ooooo`004_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool0K?ooool4o`0000;oZ:OF00?o0000ojj/eOn^[=D07?n^[=D00ol0003o];7EokBae@0HokBa
e@Oo00004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`Co
00001onXYmH00ol0003o[ZcEojj/e@0Kojj/e@03o`000?nd/MGo];7E01co];7E00?o0000okZge_nj
]mH00ol0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
1?l0000;ojRWeP03o`000?n^[=Go[ZcE01Co[ZcE2?l0000MokBae@03o`000?nj]mKo^[OF00Co^[OF
0ol0000<ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0:Oooool001gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo1?l0
000?ojRWeP03o`000?n^[=Go[ZcE00Go[ZcE3ol00007ojj]e`03o`000?nd/]Oo];;G00?o];;G2_l0
000>okBae@03o`000?nj]mKo^[OF00Oo^[OF0ol00009ooooo`03o`000?oooooooooo02oooooo0_l0
000[ooooo`007Oooool00ol0003oooooooooo`03ooooo`?o00002?ooool00ol0003oooooooooo`1H
ooooo`Co00004_nXYmH3o`000003ojj/eOl0003o000000?o00005_n^[ML00ol0003o];;GokBbe`0=
okBbe`Wo00001Ond/MD00ol0003o^[OFokZgeP0:okZgeP?o00001_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02Sooooo000Kooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Cooooo`Co00004_nXYmH4o`0000;oZ:WH00?o0000ojj]
eon^[ML06_n^[ML00ol0003o];;GokBbe`0FokBbe`Go00004?nj]mH3o`0000Cooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Xooooo`008oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo04oooooo0ol0000BojRWePCo00001_nXZMP00ol0003o[ZgGojj]e`0Cojj]e`So
00007?nd/]L00ol0003o^KSHokVhf002o`0000oo^[OF0ol000000ooooooo0000ooooo`0booooo`03
o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
C?ooool2o`000003oj2Tf?l0003oZ:OF00koZ:OF1?l0000;ojRYf003o`000?n^[MOo[ZgG00Co[ZgG
3_l00007ojfaf`03o`000?nb]M_o/[GK00?o/[GK2Ol0000>okBbe`03o`000?ni^=So^KSH00?o^KSH
0ol0000>okZgeP?o0000<oooool00ol0003oooooooooo`0Vooooo`008oooool2o`0000gooooo00?o
0000ooooooooool0BOooool2o`0000CoX:CH00?o0000ojRWe_nXYmH02OnXYmH3o`0000goZ:WH0ol0
00000on^[MOo0000o`000003o`0001Go[K7K00?o0000ok:efonb]M/03?nb]M/9o`0000Co];;G00?o
0000okVhf?ni^=P01oni^=P3o`0000co^[OF00?o0000okZge_l000000_l0000`ooooo`03o`000?oo
oooooooo02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2
o`0000OoX:CH00?o0000ojRWe_nXYmH01?nXYmH4o`0000coZ:WH1?l00002ojR^g003o`000?n]/M_o
[K7K01Wo[K7K00?o0000ok:efonb]M/05Onb]M/5o`0000co^KSH1?l00008okZgeP03o`000?nj]mKo
^[OF00;o^[OF0_l0000^ooooo`;o00009oooool002?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`13ooooo`;o00002OnPY=P01?l0003oZ:OFojRWe_nXYmH3o`0000goZ:WH0ol00006
ojR^g003o`000?n]/M_o[K7K01Wo[K7K00?o0000ok:efonb]M/06Onb]M/01?l0003o][[LokJjg?l0
000=okVhf0?o00001Onj]mH00ol0003o^[OFokZgeP02okZgeP04o`000?no_]Wo0000o`0002kooooo
00?o0000ooooooooool09?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`10ooooo`;o00002onPY=P3o`0000goZ:WH1?l0000:ojR^g003o`000?n]/M_o[K7K00_o[K7K3_l0
0006ok:ef`03o`000?nb]M_o/[GK017o/[GK00?o0000okJjg?nf^]`01?nf^]`3o`0000_o^KSH0ol0
0002okZgeP05o`000?nj]mKo^[OFokZge_l000001?no_]T2o`0002cooooo00?o0000ooooooooool0
9?ooool002;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nP
Y=SoX:CH00WoX:CH0_l000000onQY][o0000ojRYf009ojRYf0Co00003?nX[]`3o`000003ojfafol0
003o000000[o00003On[]n800ol0003o[[[RojjjhP05ojjjhPgo00001_nb]M/00ol0003o][[LokJj
g007okJjg0?o00002oni^=P3o`0000;o^[OF00?o0000oknnfOno_]T01Ono_]T00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02?ooooo000Rooooo`;o00004oooool00ol0003oooooooooo`0k
ooooo`;o00002_nPY=P2o`0000CoXJKJ00?o0000ojRYf?nXZMP01?nXZMP3o`0000coZ:kL1?l00002
ojRfhP03o`000?n[]n;oZkOR01SoZkOR00?o0000ojjjh_n^^^804_n^^^86o`0000go][[L0ol00006
okVhf0?o000000Co^KSHo`000?l0003o00002Ono_]T2o`0002_ooooo00?o0000ooooooooool08_oo
ool002;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0hooooo`;o00002_nPY=P2
o`0000KoXJKJ00Co0000ojRYf?nXZMSoZ:WH0ol0000;ojR^g0Co00001_nX]^800ol0003oZkORoj^g
hP0Boj^ghPOo00006On^^^801?l0003o/KgSok6mhol0000=okJjg0Ko00001Oni^=P2o`000003okfn
f_l0003o_kkI00So_kkI0_l0000Yooooo`03o`000?oooooooooo02;ooooo000Rooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=Oooool2o`0000[oX:CH0_l00008oj6VfP?o00002onX
[]`4o`0000_oZ;KR00?o0000oj^gh_n[]n801On[]n8<o`0000KoYl3[00?o0000ojO0jonW`>/00_nW
`>/9o`0000co[[[R00?o0000ok6mhona_N<00ona_N<4o`0000Oo][[L1_l00005okVhf0;o00000onm
_]X2o`0000So_kkI0_l0000Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0booooo`;o00002_nPY=P2o`0000SoXJKJ0_l00002oj>/g@03o`00
0?nX[]coZ:kL00GoZ:kL1?l0000=ojRfhP?o00000_n[]n84o`0001;oYl3[00?o0000ojO0jonW`>/0
3?nW`>/8o`0000?o[[[R00?o0000ok6mhona_N<02?na_N<3o`000004okJjg?l0003o0000o`0000Ko
][[L0ol000001Oni^=So0000okfnf_nm_][o000000Co_KkJ0_l00008oknnf@;o00009oooool00ol0
003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01?ooool0027ooooo0ol0000Gooooo`03o`000?oooooooooo02oooooo0_l0000:oj2T
f0;o00002?nQY]X2o`0000GoXjcM00Co0000ojR^g?nX[]coZ:kL0ol0000=ojRfhPCo00000_nW`>/0
0ol0003oYl3[ojO0j`0@ojO0j`Oo00005_nW`>/4o`0000_o/KgS1Ol0000:okJjg005o`000?nm_][o
_KkJokfnf_l000001_nm_]X2o`0000So_kkI0_l0000Uooooo`03o`000?oooooooooo00Gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oo
oooooooo01Sooooo0_l0000]ooooo`;o00002_nPY=P2o`0000SoXJKJ0_l00007oj>/g@?o00003OnX
]^84o`0000OoYl3[00?o0000ojO0jonW`>/01OnW`>/:o`0000KoX<We00?o0000oic6mOnLa_D00_nL
a_D8o`0000goYl3[00?o0000ojS0jonX`>/00_l00004ok6mh`?o00001Ona_N<4o`0000Ko][[L00?o
0000okZog_l000000_nm_]X00ol0003o_KkJokfnfP05okfnfP;o00002?no_]T00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:Oooool01?l0003oV:;LoiRRg?l00007oj2Tf0;o00002?nQY]X2o`0000OoXjcM0_l000000onU
]>Co0000ojRfhP0:ojRfhP?o00002_nW`>/3o`000003ojO0jol0003o000000;o00004OnPbOD00ol0
003oW<Keoic6m@0:oic6m@So00001?nW`>/00ol0003oZ<3[ojS0j`04ojS0j`Co00002ona_N<3o`00
00;o][[L00?o0000okZog_nj_mh00_nj_mh3o`0000So_KkJ00?o0000oknnfOno_]T01_no_]T2o`00
02Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Wooooo`03o`000?nHX]coV:;L00;oV:;L00?o0000oj2Tf?nPY=P00_nPY=P2o`0000OoXJKJ0ol0
0007oj>/g@;o00001?nU]>@00ol0003oZ;KRojRfhP04ojRfhPCo00002?nW`>/5o`0000;oY<cd00?o
0000oj39mOnPbOD02OnPbOD<o`0001CoW<Ke1?l00004ojS0j`?o00001?nX`>/4o`0000[o/KgS0_l0
0007okZogP;o00002?nm_]X2o`0000So_kkI0_l0000Rooooo`03o`000?oooooooooo00?ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0_l0000Mooooo`03o`00
0?oooooooooo02Gooooo00?o0000oiRRg?nHX]`01?nHX]`01?l0003oX:CHoj2Tf?l00007oj6VfP;o
00002?nS[=d2o`0000KoYKCT00Co0000ojRfh_nX]^;oZ;KR0ol00008ojO0j`Co00001_nTc?@3o`00
00;oX<We2?l0000;oi?Ao@03o`000?n;b_goRl[m00CoRl[m2ol00005oic6m@03o`000?nJ`oCoV/?d
00?o00002onX`>/4o`0000Ko/KgS00?o0000ok?0i?nc`>@01onj_mh2o`0000Wo_KkJ0_l00008oknn
f@03o`000?oooooooooo01kooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02?ooooo00?o0000
oiRRg?nHX]`01OnHX]`2o`0000OoXJKJ0_l00008oj>/g@;o00002?nU]>@3o`0000SoYl3[1?l00007
ojC<m0?o00000_nMeo`00ol0003oTm7moi?Ao@09oi?Ao@_o00004On;b_d8o`0000CoV/?d1?l0000:
ojS0j`?o00000_na_N<00ol0003o/l3Tok?0i003ok?0i003o`000?nj_mko^[oN00?o^[oN0ol00009
okfnfP;o00001?no_]T01?l0003o`lKMol?6gOl0000Qooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo027ooooo00?o0000oiRRg?nHX]`01OnHX]`01?l0003oVZGMoiZUgOl00004oj6V
fP;o00002?nS[=d2o`0000SoYKCT0_l00003ojO0j`03o`000?nW`>_oYl3[00;oYl3[0ol00007ojC<
m0Co00001?nMeo`3o`0000?oTm7m1ol0000:oh?Eo`03o`000?mgb_ooMl[o00?oMl[o2ol00003oh_:
o@?o00000_n6`o/00ol0003oV/?doi[3m006oi[3m0?o00002_nX`>/2o`0000Oo/l3T0_l00004okZo
gP04o`000?nj_mko0000o`0000Wo_KkJ0_l000000ono_]Wo0000ol?6g@03ol?6g@03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07?ooool000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0O
ooooo`03o`000?nHX]coV:;L00GoV:;L00?o0000oiZUgOnJYMd00_nJYMd01?l0003oXJKJoj6Vf_l0
0008oj>/g@;o00002?nU]>@2o`0000GoYl3[0ol00009ojC<m0?o00001?nMeo`4o`0000;oU=kn00?o
0000oh?Eoon3eOl02?n3eOl;o`00013oMl[o1Ol00006ohK3n`Co00001OnJ`o@4o`0000KoZ<3[00?o
0000ojS0jonX`>/02?nc`>@2o`0000;o^[oN00Co0000okZog_nj_mko^[oN0_l00009okfnfP03o`00
0?o3a]go`lKM00Co`lKM00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01gooooo00?o0000oiRRg?nHX]`01OnHX]`00ol0003oVZGM
oiZUg@03oiZUg@?o00001onS[=d2o`0000SoYKCT0_l00005ojO0j`;o000000?oZ<gco`000?nTc?@0
1_nTc?@3o`0000?oWMOl1?l00005oiCNoP?o00000_n3eOl7o`0000KoM]Cn1Ol00005ofO7oP_o0000
1?mgb_l01?l0003oL;onog2oo_l00007ohK3n`?o00001_nJ`o@3o`0000;oZ<3[00?o0000ojS0jonX
`>/00onX`>/00ol0003o/l3Tok?0i005ok?0i0;o000000?o^[oNo`000?nj_mh00onj_mh00ol0003o
_KkJokfnfP05okfnfP;o00001oo3a]d00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01_o
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Sooooo`03
o`000?oooooooooo01_ooooo00?o0000oiRRg?nHX]`01?nHX]`2o`0000GoVZGM00Go0000oif[h?nM
Zn3oWJ_Po`000004oj>/g@;o00001onU]>@3o`0000GoYl3[0_l00004ojS=l`03o`000?nTc?CoY<cd
00;oY<cd00?o0000oigGo?nMeo`00_nMeo`3o`0000CoU=kn1Ol00002ohcPo@?o00001?mfe?h4o`00
00GoLmCm1Ol00005ofC6o@So00000_mWaoh5o`0000KoL;on0ol00005ohK3n`Co00001OnJ`o@2o`00
00SoZ<3[00?o0000ok?0i?nc`>@01Onc`>@00ol0003o^[oNo`000004okZogP;o00001?nm_]X01?l0
003o`LKNol76g_l00007ol?6g@03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool0
023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?nHX]coV:;L
00CoV:;L00?o0000oiZUgOnJYMd01?nJYMd00ol0003oWJ_Poif[h003oif[h004o`000?nS[=goXjcM
o`0000OoYKCT0_l00006ojO0j`;o00001_nXcO<4o`0000CoWMOl0_l00003oiCNoPCo00000on<h?d4
o`000004oh[PoOl0003o0000o`0000?oLmCm1Ol00004ogkEo`Go00001?m`bOl6o`0000CoI<Km1?l0
0004of2ko@03o`000?m`_okoL;on00CoL;on0ol00006ohK3n`?o00000_nJ`o@01?l0003oV;ocoiRo
lol00007ojS0j`;o00001_nc`>@3o`0000Go^[oN0_l000000onm_][o0000ol76gP03ol76gP03o`00
0?o3a]go`lKM00Go`lKM00?o0000ooooooooool07?ooool00ol0003oooooo`00000Kooooo`008?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Oooooo00?o0000oiRRg?nHX]`01?nH
X]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3oWJ_P00CoWJ_P0_l00007ojFdi0;o00001OnW
`>/3o`0000KoZ<gc0_l00003ojSJn@?o00001?nDg_h3o`0000CoS>3m0ol00002oh[Po@?o000000Co
T=ono`000?l0003o00000omneOl4o`0000SoSm?n00?o0000ohK;o_n6boh00_n6boh5o`0000CoL<Wo
1?l00003oefjo0GoH;_m0ol00004og2ooP?o00001_n6`o/2o`0000GoV;oc0_l00006ojS0j`;o0000
1_nc`>@2o`0000Ko^[oN00?o0000ol76g_o1a]h01?o1a]h00ol0003o`lKMol?6g@05ol?6g@03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?nHX]coV:;L00CoV:;L00?o0000oiZUgOnJYMd01?nJ
YMd00ol0003oWJ_Poif[h004oif[h004o`000?nQ]>GoXKCUo`0000CoYKCT0_l00005ojO0j`;o0000
1onXcO<2o`0000?oZ=[i0_l00002ojGSn`Co00001On<h?d00ol0003oR^3moh[Po@02oh[Po@;o0000
0_n@goh3o`0000;oVmWm00?o0000ohoCo_n?doh01_n?doh7o`0000;oQ/_n0ol00007ohK;oPCo0000
1?mY_Oh00ol0003oGK[loefjo002oefjo003o`000?mP^ogoH;_m00;oH;_m0ol00003og2ooP?o0000
0_n6`o/01?l0003oQ;_hohBkn?n4^oP6oiRol`;o00001_nX`>/2o`0000Go/l3T0_l00004okZogP03
o`000?nlaN7o_<GQ00Ko`LKN00?o0000ol?6gOo3a]d01Oo3a]d00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Sooooo000Oooooo`;o0000:?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?nHX]coV:;L00CoV:;L00?o0000oiZUgOnJYMd01?nJYMd00ol0003oWJ_Poif[h004oif[h003o`00
0?nQ]>GoXKCU00;oXKCU00Co0000ojFdi?nU]>Co00001OnW`>/2o`0000OoZ<gc0_l00003ojSJn@;o
00000_nUho/2o`0000?oX^Sk0_l000000on<h?goR^3moh[Po@03oh[Po@04o`000?n@gokoT=onoi3O
oP;o00001OnKfOd3o`0000;oSm?n1?l00007oio:mP?o00000_nKaoH7o`0000CoQ/_n00Co0000oh32
o?n0`_co00001OmY_Oh3o`0000?oGK[l00?o0000of2koOmP^od00ol00003og2ooP;o00001_n4^oP0
0ol0003oV;ocoiRol`03oiRol`;o00001_nX`>/2o`0000Co/l3T0ol000000onj_mko0000okc5h@03
okc5h@Ko`LKN00?o0000ol?6gOo3a]d01Oo3a]d00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Oooooo000Oooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool04Oooool00ol0
003oV:;LoiRRg003oiRRg0;o00001OnJYMd2o`0000KoWJ_P00?o0000oj6diOnQ]>D00onQ]>D3o`00
00GoYl3[00?o0000ojS=lonXcO<01?nXcO<3o`0000?oZ=[i0_l00002ojGSn`;o00000onRj?/2o`00
00;oXNSk0_l000000on:h?goT=onoi3OoP02oi3OoP;o00000onKfOd5o`0000;oY<ge00?o0000oio:
m_nOb_H02OnOb_H3o`0000_oVlOf1?l00006oh32o0Co00000_mY_Oh4o`0000?oGK[l1Ol00003og2e
n`KoQ;_h0_l00005oiRol`;o00001_nX`>/00ol0003o/l3Tok?0i002ok?0i0?o00001_nlaN400ol0
003o`LKNol76gP03ol76gP03o`000?o3a]go`lKM00Go`lKM00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Gooooo`007oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oo
oooo00?o0000oiRRg?nHX]`00onHX]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3oWJ_P00Go
WJ_P00?o0000oj6diOnQ]>D00onQ]>D01Ol0003oYl3[ojO0jonW`>_o000000;oYl3[00?o0000ojS=
lonXcO<01?nXcO<2o`0000?oZ=[i0ol000001?nUho_o0000o`000?l00003oj;Xn`;o00000_nQj?/2
o`0000;oY>Gk1?l00004oi_Io@;o00001_nTcOD3o`000003oio:m_l0003o000000[o00003OnKaoH0
1?l0003oV<?eoiS3mOnH`oD2o`0000KoP<;l0ol00003ofVmoP?o00000omN[oX2of6`nPGoL;Gk00?o
0000ohBkn?n4^oP00on4^oP2o`0000GoV;oc0_l00005ojS0j`;o000000?o/l3To`000?l000000_nd
`nH00ol0003o_<GQokc5h@04okc5h@03o`000?o1a]ko`LKN00?o`LKN00?o0000ol?6gOo3a]d01Oo3
a]d00ol0003oooooooooo`0Kooooo`;o00006?ooool001oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0=ooooo`;o00001?nHX]`00ol0003oVZGMoiZUg@04oiZUg@03o`000?nMZn3o
WJ_P00GoWJ_P00?o0000oj6diOnQ]>D00onQ]>D00ol0003oYl3[ojO0j`02ojO0j`?o00001OnXcO<2
o`0000?oZ=[i0_l00003ojGSn`04o`000?nRj?_oX^Skoj;Xn`?o00000_nQj?/2o`0000;oY>Gk0_l0
0003ojOMnP?o00001_nTcOD4o`0000;oZ;gY00?o0000ojVnjOnY_^T00_nY_^T3o`0000GoZKkY00?o
0000ojVnjOnY_^T01OnY_^T6o`0000WoV<?e1?l00002oh32o0?o00000omY/o/4oej_nP;o000000?o
HK3jo`000?m`]O/00om`]O/2o`0000CoQ;_h0_l00005oiRol`;o00001?nX`>/2o`0000;o]<?V00Co
0000okC3i_nd`nKo00001_nlaN400ol0003o`LKNol76gP03ol76gP03o`000?o3a]go`lKM00Go`lKM
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo00cooooo00Co0000ohnQh?l0003o00000_nHX]`6oiZUg@03o`00
0?nMZn3oWJ_P00CoWJ_P0_l00005oj6di@03o`000?nW`>_oYl3[00;oYl3[00Co0000ojg=lOn]cO7o
[Lga0_l00002ojS=l`03o`000?nXf_WoZ=[i00;oZ=[i00Go0000ojGSnonUho_oYN?ko`000003oj;X
n`;o00000_nQj?/3o`0000;oY>Gk0_l00003ojOMnP;o00000_nYc_<01?l0003oY<geojC=mOnTcOD3
o`0000OoZ;gY1?l00008ojVnj@03o`000?nY_^WoZKkY00[oZKkY00?o0000ojZojOnZ_nT01?l00007
oiS3m@;o00000omn^_T5ofVcn`CoGZoj0_l000000omQ/?[o0000og2en`03og2en`03o`000?n4^oSo
Q;_h00?oQ;_h0_l00005oiRol`;o000000?oZ<3[o`000?nX`>/00_nX`>/2okC3iP04o`000?nd`nKo
]<?Vo`0000Ko_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMol?6g@05ol?6g@03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool05Oooool001oooooo0_l0000]ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ohnQh?n?XN000_n?XN02o`0000GoVZGM00?o0000oif[h?nMZn001?nMZn00
0ol0003oXKCUoj6di@04oj6di@03o`000?nW`>_oYl3[00;oYl3[00?o0000ojg=lOn]cO400on]cO44
o`0000;oZ=[i00Go0000ojGSnonUho_oYN?ko`000004oj;Xn`05o`000?nQj?_oXNSkoj7Xnol00000
0onTiO/2o`0000?oYmgj0_l00004ojW>l`?o00002OnX_NT3o`000003ojVnjOl0003o000000Wo0000
0_nY_^T4o`0000GoZKkY00?o0000ojZojOnZ_nT01OnZ_nT4o`0000;oV<?e00Co0000oiJnlonF__?o
U[kc1?mn^_T01?l0003oJK?kofVcnomY/o/2o`0000?oGZoj00Go0000of6`n_mQ/?[oHK3jo`000002
og2en`;o00001On4^oP00ol0003oV;ocoiRol`03oiRol`;o00001OnX`>/2okC3iP04o`000?nd`nKo
]<?Vo`0000Ko_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMol?6g@05ol?6g@03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`09ooooo`03o`000?n?XN3oSj7P00;oSj7P00?o0000oi6Th_l000001?nJYMd6
oif[h003o`000?nQ]>GoXKCU00CoXKCU00?o0000ojO0jonW`>/00_nW`>/00ol0003o[Lgaojg=l@03
ojg=l@04o`000?naf_Go/M[eok7Jm@So00000_nRj?/01Ol0003oXNSkoj7XnonQj?_o000000CoY>Gk
00Co0000ojOMn_nWgO[oYmgj0_l00004ojW>l`;o000000?oYkgYo`000?nX_NT01OnX_NT4o`0000;o
ZJoL00?o0000ojfbfon]/]/02On]/]/00ol0003o/KGKok6ef`04ok6ef`Ko00002onZ_nT2o`0000Ko
U[kc00Go0000ogjjnOmn^_WoO[[io`000003ofVcn`;o00000_mN[oX2o`0000?oHK3j0_l000000om`
]O_o0000o`000004ohBkn0;o000000?oV;oco`000?l000000_nH^o000ol0003oZ<3[ojS0j`03ojS0
j`;o00000ond`nH00ol0003o_<GQokc5h@04okc5h@03o`000?o1a]ko`LKN00?o`LKN00?o0000ol?6
gOo3a]d01?o3a]d2o`0001gooooo00?o0000ooooooooool04oooool001kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`07ooooo`03o`000?n?XN3oSj7P00;oSj7P00Go0000oi6Th_nA
Y>;oTJCRo`000002oiZUg@KoWJ_P00?o0000oj6diOnQ]>D00onQ]>D2o`0000CoYl3[00?o0000ojg=
lOn]cO400on]cO401Ol0003o/M[eok7JmOnaf_Go000000?o]>Cg00Co0000okGYmonejOOo]NWg2?l0
0002ojCUn`04o`000?nWgO[oYmgjojOMnP;o00001?nYc_<2o`0000CoYkgY00?o0000ojRmjOnX_NT0
1?l00005ojV_g003o`000?n]/]_o[K;K00Wo[K;K00?o0000ok6efona]M/02Ona]M/00ol0003o]KWL
okFig004o`0000KoZ[oY00?o0000ojZojOl000001OnF__<2o`0000?oO[[i0_l00002ofVcn`04o`00
0?mN[o[oGZojoej_nP;o00000omQ/?X2o`000003og2enol0003o000000;oQ;_h0ol00005oiRkl003
o`000?nX`>_oZ<3[00?oZ<3[0_l00003okC3iP03o`000?nlaN7o_<GQ00Co_<GQ00?o0000ol76g_o1
a]h00oo1a]h01?l0003o`lKMol?6gOo3a]d2o`000003olG?h_l0003ooooo01cooooo00?o0000oooo
ooooool04oooool001kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`05ooooo`03
o`000?n?XN3oSj7P00?oSj7P00?o0000oi6Th_nAY>800_nAY>82o`0000GoWJ_P00?o0000oj6diOnQ
]>D00onQ]>D00ol0003oYl3[ojO0j`02ojO0j`;o00001?n]cO42o`0000?o/M[e00Go0000okCTmond
i?Oo]>Cgo`000003okGYm`05o`000?nej_Oo]N[gokGZmol000000ondi_L4o`0000;oYmgj00?o0000
ojW>lonYc_<00_nYc_<2o`0000KoYkgY1?l00009ojV_g003o`000?n]/]_o[K;K00?o[K;K1_l00002
ok6ef`Co00001?na]M/00ol0003o]KWLokFig005okFig0?o00000_nZ_nT00ol0003oZ[oYojZoj@02
ojZoj@;o00001?nF__<2o`0000?oO[[i0_l000000omY/o_o0000o`000003oej_nP03o`000?mQ/?[o
HK3j00Oo00000on5]?@00ol0003oV;_`oiRkl003oiRkl003o`000?nX`>_oZ<3[00?oZ<3[0_l00003
okC3iP03o`000?nlaN7o_<GQ00Co_<GQ00?o0000ol76g_o1a]h00oo1a]h00ol0003o`lKMo`000004
olG?hP03o`000?oooooooooo01Wooooo00?o0000ooooool000005?ooool001kooooo0ol0000aoooo
o`;o00001Oooool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZ
i?l000000onMZn000ol0003oXKCUoj6di@03oj6di@03o`000?nW`>_oYl3[00;oYl3[00?o0000ojg=
lOn]cO400on]cO400ol0003o/M[eok7Jm@02ok7Jm@05o`000?ndi?Oo]>CgokCTmol000000onejOL0
1Ol0003o]N[gokGZmonej_Oo000000?o]>Kg00Co0000ok;Mm_nbgOKo/]gf1?l00003ojW>l`03o`00
0?nW_NWoYkgY00CoYkgY0ol000000onT[Mko0000ojV_g007ojV_g0So00001On_Z=400ol0003o]ZkA
okJ^d@04okJ^d@Go00002_ne^M`2o`0000OoZ[oY0_l00004oiJnl`03o`000?mn^_WoO[[i00_o0000
0omXZ?H01?l0003oM:gfogB]m_md[OH4ohFdm003o`000?nH^o3oV;_`00?oV;_`00?o0000ojS0jonX
`>/00onX`>/2o`0000?o]<?V00?o0000okc5hOnlaN401?nlaN400ol0003o`LKNol76gP02ol76gP;o
00001Oo5cn800ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo000Nooooo`03o`00
0?oooooooooo03?ooooo00Go0000ooooooooooooooooo`000004ohnQh003o`000?nAY>;oTJCR00?o
TJCR00Go0000oiNZi?nGZ^CoUj[To`000002oif[h0GoXKCU00?o0000ojO0jonW`>/00_nW`>/00ol0
003o[Lgaojg=l@03ojg=l@03o`000?naf_Go/M[e00;o/M[e00Go0000okCTmondi?Oo]>Cgo`000003
okGYm`05o`000?nej_Oo]N[gokGZmol000000ondi_L01Ol0003o/]gfok;Mm_nbgOKo000000Co[/oa
0ol00004ojNmj@?o00001OnT[Mh00ol0003oZJoLojV_g005o`0000;oZ:CB00?o0000ojnXdOn_Z=40
2?n_Z=400ol0003o]ZkAokJ^d@08okJ^d@03o`000?nl]=;o_;CB00?o00001One^M`00ol0003o^;kN
okRngP02o`0000KoZ[oY0_l00003oiJnl`;o00000on0/_@01?l0003oKj_fofn[m_m_ZoH4ofJWm@Co
J:Sf00Co0000ogB]m_md[OKoM:gf1?n5]?@00ol0003oV;_`oiRkl003oiRkl003o`000?nX`>_oZ<3[
00?oZ<3[00?o0000okC3i_nd`nH00_nd`nH00ol0003o_<GQokc5h@04okc5h@06o`000?o1a]ko0000
o`000?o3c^?o00001_o5cn800ol0003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo000C
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0dooooo`04o`000?oo
ooooooooo`0000CoSj7P00?o0000oi6Th_nAY>800onAY>800ol0003oUj[ToiNZi002oiNZi0;o0000
1OnQ]>D4ojO0j`03o`000?n]cO7o[Lga00?o[Lga00?o0000ok7JmOnaf_D00_naf_D01Ol0003o]>Cg
okCTmondi?Oo000000?o]NWg00?o0000okGZmonej_L00_l00002okCVm`;o00000onbgOH00ol0003o
[/oaojk?l@02ojk?l@04o`000?nW_NWoYkgYojNmj@Co00002?nT[Mh3o`0000SoZ:CB00?o0000ojnX
dOn_Z=401on_Z=400ol0003o]ZkAokJ^d@07okJ^d@03o`000?nl]=;o_;CB00Co_;CB0ol000000one
^Mco0000okRngP04okRngP?o00001OnZ_nT2o`0000?oU[[a1?n0/_@01Ol0003oKj_fofn[m_m_ZoKo
000000?oIZOe1?mXZ?H01Ol0003oM:gfogB]m_md[OKo000000?oQKCd00?o0000oiRkl?nH^o000onH
^o000ol0003oZ<3[ojS0j`03ojS0j`03o`000?nd`nKo]<?V00;o]<?V00?o0000okc5hOnlaN400onl
aN42o`0000Co`lkS00?o0000olG?h_o5cn800oo5cn800ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo013ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`0fooooo`;o00001?n?XN000ol0003oTJCRoi6ThP03oi6ThP03o`000?nGZ^CoUj[T00?oUj[T00Co
0000oijdj?l0003o00000_nQ]>D5ojO0j`Co[Lga0_l00004ok7Jm@05o`000?ndi?Oo]>CgokCTmol0
00000onejOL01?l0003o]N[gokGZmol00003okCVm`04o`000?nbgOKo/]gfok;MmP;o00001?n^co40
0ol0003oYkgYojNmj@04o`0000SoY:gN0_l000000onQX=Co0000ojRTdP08ojRTdP03o`000?n_Z=7o
[jSA00Oo[jSA00?o0000okJ^dOnf[]401onf[]400ol0003o_;CBokbddP07okbddP03o`000?nh_]ko
^;kN00Oo^;kN0_l000001OnZ_nWo0000oj[0jOnZ`>Wo000000CoU[[a00Go0000oh2bm?n0/_CoP;;d
o`000003ofn[mP05o`000?mVYoGoIZOeofJWmOl000000omXZ?H01Ol0003oM:gfogB]m_md[OKo0000
00?oQKCd00?o0000oiRkl?nH^o000onH^o000ol0003oZ<3[ojS0j`03ojS0j`03o`000?nd`nKo]<?V
00;o]<?V00Oo0000okc5hOnlaN7o_<GQo`000?nmbnGo000000Co`lkS00?o0000olG?h_o5cn800oo5
cn800ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo1?l000000ol@413ooooooooo
o`02ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0=ooo
ool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZi?nGZ^@00_nG
Z^@00ol0003oW[CXoijdj002oijdj0?o00000onW`>/5ojg=l@Go/M[e00Go0000okCTmondi?Oo]>Cg
o`000003okGYm`04o`000?nej_Oo]N[gokGZm`Co]>Kg0onbgOH00ol0003o[/oaojk?l@02ojk?l@Go
000000GoYkgYo`000?nO[>3oWjcPo`000004ojB]gP?o00001?nQX=@00ol0003oZ:CBojRTdP05ojRT
dQ7o00001?nf[]400ol0003o_;CBokbddP07okbddP04o`000?o1_=Go0000o`0000So^;kN00?o0000
oj[0jOnZ`>T00_nZ`>T00ol0003oU[[aoiJjl@02oiJjl@05o`000?n0/_CoP;;doh2bm?l000000om_
ZoH01Ol0003oIZOeofJWmOmVYoGo000000?oJ:Sf00Go0000ogB]m_md[OKoM:gfo`000003ohFdm003
o`000?nH^o3oV;_`00?oV;_`00?o0000ojS0jonX`>/00onX`>/00ol0003o]<?VokC3iP02okC3iP03
o`000?nlaN7o000000?o_L_U00?o0000ol?>hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03
o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05o`00
0?ooooooooooooooool000001Oooool2o`0003Oooooo00?o0000ohnQh?n?XN000_n?XN000ol0003o
TJCRoi6ThP03oi6ThP03o`000?nGZ^CoUj[T00?oUj[T00?o0000oijdj?nN]>P00_nN]>P00ol0003o
Yl3[ojO0j`04o`0000?o[Lga1_naf_D3okCTm`05o`000?nejOOo]NWgokGYmol000000onej_L4okCV
m`Co/]gf1?n^co43o`0000?oYkgY00?o0000oin/h?nO[>000_nO[>001?l0003oY:gNojB]g_l00007
oj6Pe003o`000?nXY=;oZ:CB00Go00000_nWW<X00ol0003o/:;9ok2Rb@06ok2Rb@03o`000?nhZ<Wo
^:S900?o^:S91?l00009okbddP03o`000?o1_=Go`KcE00;o`KcE0_l00004okRngP04o`000?nj`n7o
^/?Qo`0000CoZ/3Y00?o0000oiJjlOnF^_400_nF^_401Ol0003oP;;doh2bm?n0/_Co000000?oKj_f
00?o0000ofJWmOmVYoD00_mVYoD01?l0003oJ:SfofRXm_l00003ogB]mP05o`000?n5]?CoQKCdohFd
m?l000001OnH^o000ol0003oZ<3[ojS0j`02ojS0j`;o00000_nd`nH3o`0000Co_L_U00?o0000ol?>
hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`004oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0=_ooool00ol0003oSj7PohnQh002ohnQh003o`000?nAY>;oTJCR
00?oTJCR00?o0000oiNZi?nGZ^@00_nGZ^@00ol0003oW[CXoijdj002oijdj003o`000?nW`>_oYl3[
00;oYl3[00?o0000ok3<k_n`c>h01Ol00003ok7Jm@Co]>Cg1?nejOL@o`0000GoYkgY00?o0000oin/
h?nO[>000onO[>02o`0000WoXJ3D0ol00007ojNLbP03o`000?n`X/Wo/:;900Ko/:;900?o0000okRX
bOnhZ<T01_nhZ<T00ol0003o_k3;okn`b`05o`0000;o_;CB00?o0000ol6leOo1_=D01?o1_=D2o`00
0003okRng_l0003o^/?Q00?o^/?Q00?o0000oj[0jOnZ`>T00_nZ`>T00ol0003oU[[aoiJjl@02oiJj
l@05o`000?n0/_CoP;;doh2bm?l000000om_ZoH00ol0003oIZOeofJWm@02ofJWm@04o`000?mXZ?Ko
J:Sfo`0000?oM:gf00Go0000ohFdm?n5]?CoQKCdo`000005oiRkl003o`000?nX`>_oZ<3[00;oZ<3[
0ol00002okC7j0Ko_L_U00?o0000ol?>hoo3c^<00_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`004ooo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oSj7P
ohnQh002ohnQh003o`000?nAY>;oTJCR00?oTJCR00?o0000oiNZi?nGZ^@00_nGZ^@00ol0003oW[CX
oijdj002oijdj003o`000?nW`>_oYl3[00;oYl3[00?o0000ok3<k_n`c>h00_n`c>h01?l0003o^=S`
okSHl?nhf?0;o`0000;o`^K`00Go0000ol3Sl?o0ho3o`>?`o`000003ok[Jl0Ko00001?nW_NT00ol0
003oWjcPoin/h003oin/h003o`000?nHW]So000000OoXJ3D0_l000000onNUlgo0000ojNLbP08ojNL
bP03o`000?n`X/Wo/:;900Go/:;900?o0000okRXbOnhZ<T01_nhZ<T00ol0003o_k3;okn`b`05okn`
b`;o00002Oo1_=D00ol0003o^/?Qok[3h@04ok[3h@03o`000?nZ`>WoZ/3Y00;oZ/3Y00?o0000oiJj
lOnF^_400_nF^_401Ol0003oP;;doh2bm?n0/_Co000000?oKj_f00?o0000ofJWmOmVYoD00_mVYoD0
1?l0003oJ:SfofRXm_l00003ogB]mP05o`000?n5]?CoQKCdohFdm?l000001OnH^o001_l0003oZ<3[
o`000?l0003oZ<7[o`0000Co]<OX1OnmbnD00ol0003o`lkSol?>h`02ol?>h`03o`000?o5cn;oaLoR
00?oaLoR00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0doooo
o`03o`000?n?XN3oSj7P00?oSj7P00?o0000oi6Th_nAY>800_nAY>800ol0003oUj[ToiNZi003oiNZ
i003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/01Ol0003o/<c^ok3<k_n`c>ko
000000Go^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;Ul004o`000?o2i_3o`^K`o`0000?o`>?`
00?o0000ok[Jl?l000000_l00004ok7=kP06o`000?nV_N[o0000o`000?nW_NWo00001OnO[>001Ol0
003oV9kHoiRNf?nHW]So000000CoXJ3D0_l00004oijGc@03o`000?nWW<[oYic:00KoYic:00?o0000
ok2RbOn`X/T01On`X/T00ol0003o^:S9okRXb@05okRXb@03o`000?no/<_o_k3;00Oo_k3;00?o0000
olJic_l000000_l00004ol6le@04o`000?o5a=WoaLCIo`0000Go^/?Q00?o0000oj[0jOnZ`>T00_nZ
`>T00ol0003oU[[aoiJjl@0Co`0000?oM:gf00Go0000ohFdm?n5]?CoQKCdo`000003oiRkl0?o0000
0onX`N/00ol0003o]<OXokC7j002okC7j003o`000?nmbnGo_L_U00?o_L_U00?o0000ol?>hoo3c^<0
0_o3c^<00ol0003oaLoRolG?hP03olG?hP03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_l0000eooooo`03o`000?n?XN3oSj7P00;oSj7P00?o0000oi6Th_nAY>800onAY>800ol0003oUj[T
oiNZi002oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/00ol0003o/<c^
ok3<kP02ok3<kP03o`000?nhf?3o^=S`00;o^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;Ul004
o`000?o2i_3o`^K`o`0000?o`>?`0ol000000onjf_3o0000ok7=kP03ok7=kP03o`000?nV_N[oY[gZ
00;oY[gZ0_l00004oin/h003o`000?nHW]SoV9kH00?oV9kH00Co0000oj6Pe?nQX=Co00001_nNUld0
0ol0003oYic:ojNLbP04ojNLbQ?o00002?no/</00ol0003oa[W>olJicP03olJicP;o000000?o`KcE
o`000?o5a=T00oo5a=T00ol0003o^/?Qok[3h@03ok[3h@03o`000?nZ`>WoZ/3Y00Co00000_nG]nh0
1Ol0003oQJg_ohF]kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h00_m`X>h3og:QkPco00000_nI
^>h5ojS1j`03o`000?ndanSo]<OX00;o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>
h`03ol?>h`03o`000?o5cn;oaLoR00;oaLoR00?o0000ooooooooool06oooool3o`0000Oooooo00?o
0000ooooooooool01?ooool001cooooo00?o0000ooooooooool0=?ooool2o`0000?oSj7P00?o0000
oi6Th_nAY>800onAY>800ol0003oUj[ToiNZi003oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000
ojO0jonW`>/00_nW`>/01Ol0003o/<c^ok3<k_n`c>ko000000Co^=S`00Go0000okkPl?nnh?3o_^3`
o`000003ol;Ul004o`000?o2i_3o`^K`ol;Vl0Go00000onjf_001Ol0003o/Lg^ok7=k_nacNko0000
00GoY[gZ00Ko0000oiZ/i?l0003o0000oin/h?l00006oiRNf0;o00002?nNUld00ol0003oYic:ojNL
bP04o`0000;oYYO600?o0000ok2Ma?n`WL@01On`WL@00ol0003o^JG5okVUa@05okVUa@03o`000?o2
[/Ko`Zk600?o00000_no/</00ol0003oa[W>olJicP06olJicP03o`000?o5a=WoaLCI00CoaLCI00?o
0000ok[3hOnj`n400onj`n42o`0000;oZ/7Z00?o0000oiNgk_nG]nh00_nG]nh01Ol0003oQJg_ohF]
kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h00_m`X>h3og:QkPCoNjO_1?n9[nl6oiVhkPGoZ<7[
00Go0000okC7j?ndanSo]<OXo`000005okg;i@03o`000?o3c^?o`lkS00;o`lkS00?o0000olG?h_o5
cn800_o5cn800ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l0
00001_ooool001cooooo00?o0000ooooooooool0=?ooool2ohJRiP;o000000?oSj7Po`000?nAY>80
1?nAY>800ol0003oUj[ToiNZi002oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/0
0_nW`>/01Ol0003o/<c^ok3<k_n`c>ko000000Go^=S`00Go0000okkPl?nnh?3o_^3`o`000003ol;U
l003o`000?o2i_3o`^K`00;o00000_o0ho001Ol0003o^][`ok[Jl?njf_3o000000?o/Lg^00?o0000
ojJmj_nV_NX00onV_NX00ol0003oVZcToiZ/i002oiZ/i0;o00001OnHW]P00ol0003oTi?Ao`000008
oijGc@?o00001_nVUlH00ol0003o/9g4ok2Ma005ok2Ma003o`000?niYLGo^JG500Go^JG500?o0000
ol:^a_o2[/H00oo2[/H2o`0000Woa[W>0_l00006olG4f@06o`000?nj`n7o0000o`000?nkb>Co0000
1?nZ`NX01Ol0003oUkO^oiNgk_nG]nko000000CoQJg_00Co0000ogNTkomgY>oo00001?m`X>h01?l0
003oLZ7^og:Qk_mbXNh4og^Wk`CoRJo_1OnI^>h00ol0003oZ<7[ojS1j`02ojS1j`;o00000ondanP0
0ol0003o_L_Uokg;i@02okg;i@03o`000?o3c^?o`lkS00?o`lkS00?o0000olG?h_o5cn800_o5cn80
0ol0003oooooooooo`0Looooo`?o00003?ooool001cooooo00?o0000ooooooooool0=?ooool4ohJR
iP;o00001?nAY>800ol0003oUj[ToiNZi003oiNZi005o`000?nN]>SoW[CXoijdj?l000001?nW`>/0
0ol0003o/<c^ok3<kP02ok3<kP03o`000?nhf?3o^=S`00;o^=S`00Go0000okkPl?nnh?3o_^3`o`00
0003ol;Ul0Co00001?o0ho001Ol0003o^][`ok[Jl?njf_3o000000?o/Lg^00?o0000ojJmj_nV_NX0
0_nV_NX00ol0003oVZcToiZ/i003oiZ/i0;oSigM00Go0000oiRNf?nHW]SoV9kHo`000003oi>Cd@03
o`000?nNUlgoWYO=00;oWYO=0ol000000onLTLSo0000ojJGaP07ojJGaP03o`000?n`WLCo/9g400Co
/9g400?o0000okVUaOniYLD01OniYLD00ol0003o`Zk6ol:^aP04ol:^aP04o`000?o9^<Wo0000o`00
00Goa[W>00Co0000olg4d_o=a=;o00001_o5a=T00ol0003o^lSTok_8i002ok_8i005o`000?nZ`N[o
Z/7Zoj[1j_l000001?nG]nh01Ol0003oQJg_ohF]kon5[Noo000000?oMjC_00?o0000og2Pk_m`X>h0
0_m`X>h01?l0003oLZ7^og:Qk_l00003og^Wk`05o`000?n9[nooRJo_ohV_kol000001OnI^>h01?l0
003oZ<7[ojS1jonX`N/2o`0000?o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>h`03
ol?>h`03o`000?o5cn;oaLoR00;oaLoR00?o0000ooooooooool06Oooool3o`0000;ooooo00?o0000
ooooooooool02_ooool001cooooo00?o0000ooooooooool0=?ooool4ohJRiP;oRJGW0ol000000onA
Y>;o0000oiNZi003oiNZi003o`000?nN]>SoW[CX00;oW[CX00?o0000ojO0jonW`>/00_nW`>/01Ol0
003o/<c^ok3<k_n`c>ko000000Co^=S`00Go0000okkPl?nnh?3o_^3`o`000002ol;Ul0?o00000_o2
i_001Ol0003o`>?`ol3Sl?o0ho3o000000?o^][`00Go0000ok7=k_nacNko/Lg^o`000005ojJmjP03
o`000?nJ[>CoVZcT00;oVZcT00Oo0000ohnMgOn?WMgoSigMo`000?nHW]So000000GoTi?A00Co0000
oijGcOnNUlgo00001OnLTLP00ol0003oYYO6ojJGaP05ojJGaP03o`000?n`WLCo/9g400Co/9g400?o
0000okVUaOniYLD01?niYLD00ol0003o`Zk6ol:^aP04ol:^aP03o`000?o9^<WobKS900;obKS900Go
0000olJic_o6^Lkoa[W>o`000004olg4dP07o`000?o5a=WoaLCIolG4fOl0003ob<gNo`000004ok_8
i003o`000?nZ`N[oZ/7Z00;oZ/7Z00Go0000oiNgk_nG]nkoUkO^o`000004ohF]k`05o`000?mgY>oo
MjC_ogNTkol000000om`X>h01Ol0003oLZ7^og:Qk_mbXNko000000?oNjO_00Go0000ohV_kon9[noo
RJo_o`000004oiVhkP03o`000?nX`N_oZ<7[00;oZ<7[0_l00003okC7j003o`000?nmbnGo_L_U00;o
_L_U00?o0000ol?>hoo3c^<00oo3c^<01?l0003oaLoRolG?h_o5cn82o`0001Oooooo0ol00005oooo
o`03o`000?oooooooooo00[ooooo000Looooo`;o0000=Oooool01?l0003oQZ;VohJRi_n6X^H5ohVU
i`;o00000onGZ^@00ol0003oW[CXoijdj002oijdj003o`000?nW`>_oYl3[00;oYl3[00?o0000ok3<
k_n`c>h00_n`c>h00ol0003o^=S`okSHl002okSHl003o`000?nnh?3o_^3`00Co000000Go`^G`o`00
0?o2i_3o`^K`o`000004ol3Sl0_o00000_nV_NX00ol0003oVZcToiZ/i002oiZ/i003o`000?n?WMgo
SigM00?oSigM00?o0000oi>CdOnCTm401?nCTm42o`0000OoW97800?o0000ojJGa_nVUlH00onVUlH>
o`0000;o^JG500?o0000ol:^a_o2[/H01?o2[/H00ol0003obKS9olVhb@03olVhb@;o000000?oa[W>
o`000?o=a=801?o=a=800ol0003oaLCIo`000003olS=gP03o`000?nkb>Co^lST00;o^lST00?o0000
oj[1j_nZ`NX00_nZ`NX01Ol0003oUkO^oiNgk_nG]nko000000?oQJg_00Go0000ogNTkomgY>ooMjC_
o`000004og2PkP04o`000?mbXNkoLZ7^o`0000?oNjO_00Go0000ohV_kon9[nooRJo_o`000005oiVh
kP07o`000?nX`N_oZ<7[ojS1jol0003o]<OXo`000002okC7j003o`000?nmbnGo_L_U00;o_L_U00?o
0000ol?>hoo3c^<00oo3c^<01_l0003oaLoRo`000?l0003oaMSWo`0001Cooooo0ol00008ooooo`03
o`000?oooooooooo00[ooooo000Looooo`03o`000?oooooooooo03Cooooo00Co0000ohJRi_n6X^Ko
QZ;V1On9YNL2oi2[j0;o000000?oUj[To`000?nN]>P00onN]>P00ol0003oYl3[ojO0j`02ojO0j`05
o`000?n`c>ko/<c^ok3<k_l000001?nhf?000ol0003o_^3`o`000002o`0000?o`^G`2_l00002okoE
jP05o`000?ndbn_o]<_[okC;jol000000onV_NX3o`0000CoVZcT00?o0000ohnMgOn?WMd00on?WMd0
0ol0003oTi?Aoi>Cd@03oi>Cd@03o`000?n?SLco000000OoW97800?o0000ojJGa_nVUlH00ol00002
ojJE``03o`000?n`Vl;o/9_200Co/9_200?o0000okZS`_njXl800_njXl86o`0000?o`Zk600?o0000
olVhbOo9^<T01Oo9^<T00ol0003ocLCBolg4dP05olg4dP03o`000?o8cMkob<gN00;ob<gN00?o0000
ok_8i?nkb>@00onkb>@01Ol0003oZ/7Zoj[1j_nZ`N[o000000?oUkO^00?o0000ohF]kon5[Nl00_n5
[Nl01Ol0003oMjC_ogNTkomgY>oo000000?oL:3^00Go0000og:Qk_mbXNkoLZ7^o`000003og^Wk`05
o`000?n9[nooRJo_ohV_kol000001?nI^>h00ol0003oZ<7[ojS1j`02ojS1j`03o`000?ndanSo0000
00;o]<OX00?o0000okg;iOnmbnD00_nmbnD00ol0003o`lkSol?>h`02ol?>h`;o00000oo5f>L00ol0
003oooooooooo`0>ooooo`Co00002oooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003o
ooooooooo`0eooooo`05o`000?n6X^KoQZ;VohJRi_l000001?n9YNL4oi2[j0?o00000_nN]>P00ol0
003oYl3[ojO0j`02ojO0j`05o`000?n`c>ko/<c^ok3<k_l000001?nhf?03o`000003okkPl?l0003o
`^G`00Co00000_o9g^P00ol0003oa]cYolKLj@02olKLj@05o`000?noeN[o_mGZokoEj_l000000ond
bn/00ol0003oY[gZojJmjP02ojJmjP;oUJgW0_l000000onJ[>Co0000ohnMg@04ohnMg@03o`000?n6
TMOo000000?oTi?A00Go0000ohn=c?n?SLcoShg<o`000006oibAb0?o00001OnVUL<00ol0003o/9_2
ok2K`P04ok2K`P03o`000?njXl;o^Z?200Co^Z?200Co0000ol:/a?o2[<Co`Zc40ol00007olVhb@03
o`000?oAa<go000000GocLCB0_l00005olS=gP03o`000?nkb>Co^lST00;o^lST00?o0000oj[1j_nZ
`NX03ol00004og2PkP04o`000?mbXNkoLZ7^o`0000CoNjO_00Co0000ohV_kon9[noo00001?nI^>h0
0ol0003oZ<7[ojS1j`02ojS1j`03o`000?ndanSo000000;o]<OX00?o0000okg;iOnmbnD00_nmbnD0
0ol0003o`lkSo`000002o`000003ol?Fj?l0003oaMSW00;oaMSW00?o0000ooooooooool02oooool3
o`00013ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Oooool01Ol0
003oQZ;VohJRi_n6X^Ko000000CoRJGW1?n@ZnP3oi^ejPGo00000_nW`>/01_l0003o/<c^ok3<k_n`
c>ko0000okSHl0Wo00000_o8gNP01Ol0003obMkXolWNj?o9g^So000000Coa]cY00Go0000okoEj_no
eN[o_mGZo`000003okC;j`03o`000?nV_N[oY[gZ00;oY[gZ00Co0000oiF]ionE[NOoUJgW0_l00004
ohnMg@07o`000?n6TMOoQY7GohJAeol0003oTi?Ao`000005ohn=c003o`000?nLTLSoW97800?o0000
00?oVho6o`000?nVUL<01OnVUL<00ol0003o/9_2ok2K`P04ok2K`P03o`000?njXl;o^Z?200?o^Z?2
00?o0000ol:/a?o2[<@01?o2[<@01?l0003obkO7o`000?l00003olVhb@05o`000?oAa<godLC=om74
cOl000000oo=a=801?l0003odM3Hom7@f?l00004olS=gP04o`000?nkb>Co^lSTok_8i0Co00000_nZ
`N/4oiVdj`GoRZSY0on0X>L6o`0000?oLZ7^00Go0000og^WkomkYnooNjO_o`000003ohV_k`03o`00
0?nI^>koVKS^00;oVKS^00?o0000ojS1jonX`N/00_nX`N/00ol0003o]<OXo`000002okC7j004o`00
0?nmbnGo_L_Uokg;i@;o00001?o3e^P01Ol0003oaMSWolGHioo5f>Oo000000[ooooo0ol0000Coooo
o`03o`000?oooooooooo00Wooooo000Kooooo`03o`000?oooooooooo03Gooooo00Go0000ohJRi_n6
X^KoQZ;Vo`000004ohVUi`CoT:_X1?nK]NX01?l0003oYl3/ojO0k?nW`>`<o`0000;oa=[Y00?o0000
olSMj?o8gNP00_o8gNP01Ol0003obMkXolWNj?o9g^So000000?oa]cY00?o0000okoEj_noeNX00_no
eNX01Ol0003o]<_[okC;jondbn_o000000?oY[gZ00?o0000oiF]ionE[NL00_nE[NL2ohFMh`;o0000
00?oSigMo`000?n6TML01?n6TML00ol0003oShg<ohn=c005ohn=c0;o00001OnKSlH00ol0003oYYG3
ojJE``04ojJE``03o`000?n`Vl;o/9_200?o/9_200?o0000okZS`_njXl800onjXl800ol0003o`Zc4
ol:/a003ol:/a003o`000?o;]lOobkO700;obkO700?o0000olVhbOl000001OoAa<d00ol0003ocLCB
o`000004om7@f004o`000?o8cMkob<gNolS=gPCo00000_nkcNP01Ol0003oZ/7[oj[1jonZ`N_o0000
00?oVKC[00?o0000ohZXjOn:Z>T00_n:Z>T01?l0003oP:3Woh2Pion0X>L4og^Li`Go00001?mkYnl0
1?l0003oRJo_ohV_kol00004oiVhkP03o`000?nX`N_oZ<7[00;oZ<7[00Oo0000okC7j?ndanSo0000
okC7j?l0003o_L_U00;o000000?o_M7Yo`000?o3e^P00oo3e^P01Ol0003oaMSWolGHioo5f>Oo0000
00Oooooo0ol0000Fooooo`03o`000?oooooooooo00Wooooo000Kooooo`;o0000=Oooool00ol0003o
QZ;VohJRiP02ohJRiP05o`000?n9YNOoRJGWohVUiol000001?n@ZnP01Ol0003oVkGZoi^ej_nK]N[o
000000CoYl3/1Ol00004okgCj`05o`000?o4f^Woa=[YolCJjOl000001?o8gNP01Ol0003obMkXolWN
j?o9g^So000000?oa]cY00Go0000okoEj_noeN[o_mGZo`000003okC;j`03o`000?nV_N[oY[gZ00;o
Y[gZ00?o0000oiF]ionE[NL00_nE[NL01?l0003oQIgSohFMhon5WN<2o`0000GoQY7G00?oP8SBo`00
0?n?SL`01?n?SL`2o`0000KoVho600?o0000ojJE`onVUL<01?nVUL<00ol0003o/9_2ok2K`P03ok2K
`P03o`000?njXl;o^Z?200?o^Z?200?o0000ol:/a?o2[<@00oo2[<@00ol0003obkO7ol^ga`03ol^g
a`;o00001_oAa<d00ol0003odM3Hom7@f003om7@f006o`000?o8cMko0000o`000?o9enCo00001?nk
cNP01Ol0003oZ/7[oj[1jonZ`N_o000000?oVKC[00?o0000ohZXjOn:Z>T00_n:Z>T01Ol0003oP:3W
oh2Pion0X>Oo000000CoNicW0ommWNL6o`0000?oRJo_00?o0000oiVhk_nI^>h00_nI^>h01Ol0003o
Z<7[ojS1jonX`N_o000000?o]<OX0ol00003okgAj@03o`000?o3e^So`mKX00;o`mKX00Go0000olGH
ioo5f>OoaMSWo`000004ooooo`?o00006Oooool00ol0003oooooooooo`09ooooo`006oooool00ol0
003oooooooooo`0dooooo`03o`000?n6X^KoQZ;V00;oQZ;V00Go0000ohVUion9YNOoRJGWo`000003
oi2[j003o`000?nK]N[oVkGZ00;oVkGZ00?o0000ojO0k?nW`>`00ol00003ok;:k003o`000?nmdn_o
_M?[00;o_M?[00Go0000olCJjOo4f^Woa=[Yo`000003olSMj003o`000?o9g^SobMkX00;obMkX00Go
0000olKLjOo6g>Woa]cYo`000003okoEjP05o`000?ndbn_o]<_[okC;jol000001?nV_NX00ol0003o
UJgWoiF]i`02oiF]i`04o`000?n5WN?oQIgSohFMh`;oMhoN00Go0000ohJAeon6TMOoQY7Go`000002
oh28dP05o`000?n?SLcoShg<ohn=c?l000000_n>RLX00ol0003oVho6oi^?aP03oi^?aP04o`000?nV
UL?oYYG3ojJE`a7o00001?o2[<@00ol0003obkO7ol^ga`03ol^ga`03o`000?oC`l_o000000?odLC=
00?o0000omOBdol000001_oAd=P01Ol0003obMOTolWGi?o9enCo000000Co^lgX00?o0000oj[1jonZ
`N/00_nZ`N/01?l0003oVKC[oiVdjol00004ohZXj@05o`000?n0X>OoP:3Woh2Piol000001?mkW>L0
1?l0003oOIgWogfMiommWNL4oh>Sj0Go00001?nI^>h00ol0003oZ<7[ojS1j`06o`000003ok?:jol0
003o_M7Y00;o_M7Y00?o0000ol?Fj?o3e^P00_o3e^P01?l0003oaMSWolGHioo5f>L5o`0001cooooo
00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=?ooool01Ol0003oQZ;VohJR
i_n6X^Ko000000CoRJGW00Go0000oi2[j?n@ZnSoT:_Xo`000004oi^ejP?o00000_nW`>`01Ol0003o
//[/ok;:k?nbb^co000000Co_M?[00Go0000olCJjOo4f^Woa=[Yo`000003olSMj005o`000?o9g^So
bMkXolWNj?l000001?o6g>T01Ol0003o_mGZokoEj_noeN[o000000?o]<_[00Go0000ojJmj_nV_N[o
Y[gZo`000004oiF]i`03o`000?n5WN?oQIgS00;oQIgS00Ko0000ogN?g_mgSmko0000ohJAeol00004
oh28dP03o`000?n?SLco000000CoSXW:00?o0000oi^?a_nKSlH00_nKSlH4o`0000?oYYG400?o0000
ok2L`on`W<<00on`W<<00ol0003o^JC3okVT``02okVT``03o`000?o2[<Co`Zc400Co00001Oo;]lL0
1ol0003odl?;om?3booC`l_o0000om74cOl000000ooGd]<01ol0003odM3Hom7@f?oAd=So0000omCN
gol000000oo9en@00ol0003o^lgXok_=j002ok_=j003o`000?nZ`N_oZ/7[00;oZ/7[00Go0000oiVd
jonI]>_oVKC[o`000004ohZXj@04o`000?n0X>OoP:3Wo`0000CoNicW00Go0000ogfMiommWNOoOIgW
o`000004oh>Sj0?oSZ_Z2?l00002ojS1k004o`000?ncb^_o/l[[ok?:j`;o00000onmdNT00ol0003o
`mKXol?Fj002ol?Fj005o`000?o5f>OoaMSWolGHiol000008?ooool00ol0003oooooooooo`09oooo
o`006_ooool00ol0003oooooooooo`0eooooo`05o`000?n6X^KoQZ;VohJRi_l000001?n9YNL01_l0
003oT:_Xoi2[j?n@ZnSo0000oi^ejPCo00000onW`>`00ol0003o//[/ok;:k002ok;:k005o`000?nm
dn_o_M?[okgCjol000001?o4f^T01Ol0003ob=gXolSMj?o8gNSo000000?obMkX00Go0000olKLjOo6
g>Woa]cYo`000002okoEjPko000000?oUJgWo`000?n5WN<00on5WN<01?l0003oMhoNogN?g_mgSmh2
o`0000GoP8SB00?o0000ohj9b_n>RLX01?n>RLX01_l0003oVho6o`000?l0003oVho6o`0000GoYYG4
00?o0000ok2L`on`W<<00on`W<<00ol0003o^JC3okVT``02okVT``03o`000?o2[<Co`Zc400?o`Zc4
0_l00003ol^ga`03o`000?oC`l_odl?;00?odl?;00?o0000omOBdooGd]<00ooGd]<00ol0003odM3H
o`000002omCNg`03o`000?o9enCobMOT00;obMOT00Go0000ok_=j?nkcNSo^lgXo`000004oj[1j`05
o`000?nI]>_oVKC[oiVdjol000001?n:Z>T01?l0003oP:3Woh2Piol00004og^Li`05o`000?mmWNOo
OIgWogfMiol000001?n3XnP01?l0003oSZ_Zohj[j_n>ZnX5oiZfj`05o`000?nX`NcoZ<7/ojS1k?l0
00001?ncb^/01Ol0003o_M7YokgAjOnmdNWo000000Co`mKX00Go0000olGHioo5f>OoaMSWo`00000P
ooooo`03o`000?oooooooooo00Wooooo000Jooooo`?o0000=Oooool01Ol0003oQZ;VohJRi_n6X^Ko
000000CoRJGW00?o0000oi2[j?n@ZnP00ol00003oi^ejP05o`000?nW`>coYl3/ojO0k?l000001?nb
b^`01Ol0003o_M?[okgCjonmdn_o000000?oa=[Y00?o0000olSMj?o8gNP00_o8gNP01Ol0003obMkX
olWNj?o9g^So000000;oa]cY1?l00002ol7?i@Co]/SX1?nU_^/4oi2`k0?o00000_n5WN<00ol0003o
MhoNogN?gP02ogN?gP;oKHGJ0_l00003oh28dP03ogf5d?l0003oSXW:00CoSXW:0_l00004oi^?aP03
o`000?nVULCoYYG400?oYYG400Go0000ok2L`on`W<?o/9c3o`000005okVT``03o`000?o2[<Co`Zc4
00?o`Zc400Ko0000ol^gaol0003o0000ol^gaol00005om?3b`03o`000?oGd]?oem;C00Coem;C00Go
0000omCNgooDg]ooe=kOo`000004olWGi003o`000?nkcNSo000000Wo000000?oVKC[o`000?n:Z>T0
0on:Z>T01Ol0003oP:3Woh2Pion0X>Oo000000?oNicW00Go0000ogfMiommWNOoOIgWo`000004oh>S
j005o`000?n>Zn[oSZ_Zohj[j_l000001?nJ]^/01Ol0003oZ<7/ojS1k?nX`Nco000000Co/l[[0_l0
0002okgAj@03o`000?o3e^So`mKX00;o`mKX00Go0000olGHioo5f>OoaMSWo`00000Qooooo`03o`00
0?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000ohJRi_n6X^KoQZ;V
o`000004ohVUi`?o000000?oT:_Xo`000?nK]NX00onK]NX01Ol0003oYl3/ojO0k?nW`>co000000Co
//[/00Go0000okgCjonmdn_o_M?[o`000003olCJj@03o`000?o8gNSob=gX00;ob=gX00Co0000olWN
j?o9g^SobMkX0ol000000oo8dn;o0000ol7?i@03ol7?i@05o`000?nfb>So]/SXokK8j?l000000onU
_^/00ol0003oT;3/oi2`k002oi2`k0;oNIoZ00?o0000ohFMhol000001?mgSmh01ol0003oKHGJoff5
f_m]QM[o0000oh28d_l000000_mmQM001ol0003oSXW:ohj9b_n>RL[o0000ohj:bol000001?nKSlH0
0ol0003oYYG4ojJEa003ojJEa005o`000?n`W<?o/9c3ok2L`ol000001?niY<<00ol0003o`Zc4ol:/
a003ol:/a003o`000?o;]lOobkO700;obkO70_l00004om?3b`03o`000?oId]7o000000?oem;C00?o
0000om[Rfol000001?oDg]l00ol0003obMOTolWGi003o`0000;o^M;]00?o0000oj[2jonZ`^/00_nZ
`^/00ol0003oW;;Woibbi`05o`000003ohZXjOl0003oP:3W00;oP:3W00Go0000og^LiomkW>OoNicW
o`000003ogfMi`03o`000?n3XnSoPj?X00;oPj?X00Go0000ohj[j_n>Zn[oSZ_Zo`000004oiZfj`05
o`000?nX`NcoZ<7/ojS1k?l000001?ncb^/2o`0000;o_M7Y00Go0000ol?Fj?o3e^So`mKXo`000004
olGHi`03o`000?oooooooooo01oooooo00?o0000ooooooooool02?ooool00004oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0eooooo`06o`000?n6X^KoQZ;VohJRi_l0003oRJGW1?l00003oi2[j005o`000?nK]N[oVkGZoi^e
j_l000001?nW`>`01Ol0003o//[/ok;:k?nbb^co000000Co_M?[00Go0000olCJjOo4f^Woa=[Yo`00
0003olSMj004o`000?o9g^SobMkXolWNj0;o00001?o8dn800ol0003o`LoUol7?i@02ol7?i@05o`00
0?nfb>So]/SXokK8j?l000000onU_^/01Ol0003oT;3/oi2`k?n@/>co000000?oNIoZ0_l00002ogN?
gP03o`000?m]QM[oKHGJ00?oKHGJ00?o0000ogf5d?mmQM000_mmQM000ol0003oSXW:o`000003ohj:
b`05o`000?nKSlKoVho6oi^?a_l000000onVUL@:o`000003okVT`ol0003o`Zc400?o`Zc400?o0000
ol^gaoo;]lL00oo;]lL00ol0003od/?<o`000002om?3b`07o`000?oId]7ofM;AomWBdOl0003oem;C
o`000002om[Rf`03o`000?oDg]ooe=kO00;oe=kO0ol000000oo6hN_o0000okWBk@02okWBk@05o`00
0?nZ`^_oZ/;[oj[2jol000001?nL/^L01?l0003oTJKToi6Vi?nAY^@3o`0000;oP:3W00Go0000og^L
iomkW>OoNicWo`000004ogfMi`05o`000?n3XnSoPj?Xoh>Sj?l000000on>ZnX00ol0003oV[K[oiZf
j`02oiZfj`05o`000?nX`NcoZ<7/ojS1k?l000001?ncb^/01Ol0003o_M7Yo`000?nmdNWo000000?o
`mKX00?o0000olGHioo5f>L00_o5f>L00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00So
oooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03Gooooo0_l000001?n6X^Ko0000o`000?l00002ohVUi`03o`000?n@ZnSoT:_X
00;oT:_X00Go0000oi^ej_nK]N[oVkGZo`000004ojO0k005o`000?nbb^co//[/ok;:k?l000001?nm
dn/01Ol0003oa=[YolCJjOo4f^Wo000000?ob=gX1?l000000oo;e>7o0000olSChP03olSChP03o`00
0?o1cnGo`LoU00;o`LoU00Go0000okK8j?nfb>So]/SXo`000003ojFnj`05o`000?n@/>coT;3/oi2`
k?l000000omiWnX2ofB?iP03o`000?mgSmko000000GoKHGJ00?oJ83Ho`000?mmQM000ommQM000ol0
003oSX[;ohj:b`03ohj:b`03o`000?nKSlKoVho600Co00000_nWV<H01Ol0003o/9k5ok2NaOn`W/Go
000000?o^JG51?l00002ol:/a003o`000?o;]lOobkO700;obkO700Oo0000om;3c?oB`lcod/?<o`00
0?oC`l_o000000CofM;A00?o0000om[RfooJh]/00_oJh]/00ol0003oe=kOomCNg`02o`0000;oa^7[
00Go0000okWBkOnid^go^M;]o`000004oj[2j`05o`000?nL/^OoW;;Woibbiol000001OnAY^@2ohVN
h@03o`000?n0X>Oo000000?oNicW00?o0000ogfMiommWNL00_mmWNL01Ol0003oPj?Xoh>Sj?n3XnSo
000000?oSZ_Z00?o0000oiZfjonJ]^/00_nJ]^/01Ol0003oZ<7/ojS1k?nX`Nco000000Co/l[[00?o
0000okgAjOnmdNT00_l00003ol?Fj003o`000?o5f>OoaMSW00;oaMSW00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`08ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=Oooool5o`0000?oRJGW00Go0000oi2[j?n@ZnSoT:_Xo`00
0004oi^ejP03o`000?nW`>coYl3/00;oYl3/00Go0000ok;:k?nbb^co//[/o`000003okgCj`03o`00
0?o4f^Woa=[Y00;oa=[Y00?o0000olSMj?l000000_l00004ol_Dh@03o`000?o8dn;ob=?R00;ob=?R
00?o0000ol7?iOo1cnD00_o1cnD01Ol0003o]/SXokK8j?nfb>So000000?oYKk[00?o0000oi2`k?n@
/>`00_n@/>`01?l0003oNIoZogVOj_l00003ofB?iP;o00001?m]QMX00ol0003oJ83Ho`000004ogf5
d003o`000?n>R/_oSX[;00;oSX[;00Go0000oi^?a_l0003oW9;9o`000004ojNHaP05o`000?n`W/Go
/9k5ok2NaOl000001?niYLD00ol0003o`Jk7ol6^a`03o`0000?obkO700?o0000om;3c?oB`l`00ooB
`l`01ol0003ofM;AomWBdOoId]7o0000omgSfOl000001?oJh]/3o`000005om3[j?l0003oa^7[olKQ
jol000000onid^d00ol0003oZ/;[oj[2j`02oj[2j`05o`000?nL/^OoW;;Woibbiol000001?nAY^@0
0ol0003oRIkQohVNh@02ohVNh@;o00000_mkW>L00ol0003oOIgWogfMi`02ogfMi`05o`000?n3XnSo
Pj?Xoh>Sj?l000000on>ZnX00ol0003oV[K[oiZfj`02oiZfj`05o`000?nX`NcoZ<7/ojS1k?l00000
1?ncb^/00ol0003o_M7YokgAj@02o`0000?o`mKX00?o0000olGHioo5f>L00_o5f>L00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Sooooo0003ooooo`03o`000?oooooooooo00gooooo00?o
MgMgoc8b<_ooool00oooool3o`0003?ooooo1?l00003og^Tk@?o000000?oRJGWo`000?n@ZnP00_n@
ZnP00ol0003oVkGZoi^ejP02oi^ejP03o`000?nW`>coYl3/00;oYl3/00Go0000ok;:k?nbb^co//[/
o`000003okgCj`03o`000?o4f^Woa=[Y00Co00000_o:e>400ol0003obmCQol_Dh@03ol_Dh@03o`00
0?o8dn;ob=?R00;ob=?R00Go0000ol7?iOo1cnGo`LoUo`000004okK8j005o`000?nU_^_oYKk[ojFn
jol000000on@/>`01Ol0003oNIoZogVOj_miWn[o000000;oI8oV0_mCP^82o`000003off5f_l0003o
J83H00;oJ83H00?o0000ogf5d?l000000_mmQM001?l0003oSX[;ohj:bon>R//2o`0000?oW9;900Go
0000ojNHa_nWV<KoYiS6o`000003ok2Na@03o`000?niYLGo^JG500;o^JG500Ko0000ol6^aoo1[/Oo
`Jk7o`000?o9^<X2o`000003ol^gaol0003od/?<00?od/?<0_l00002omWBd@04o`000?oMhmWogN?I
o`0000?of^;K0_l00002om3[j005o`000?o6hN_oa^7[olKQjol000000onid^d01Ol0003oZ/;[oj[2
jonZ`^_o000000CoW;;W00?o0000oi6Vi?nAY^@00_nAY^@00ol0003oRIkQohVNh@02ohVNh@;oQY[O
00?o0000og^Liol000001?mmWNL01Ol0003oPj?Xoh>Sj?n3XnSo000000CoSZ_Z00Go0000oiZfjonJ
]^_oV[K[o`000004ojS1k005o`000?ncb^_o/l[[ok?:jol000000onmdNT01Ol0003o`mKXol?Fj?o3
e^So000000CoaMSW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0aooooo`;o00001?ooool3og^Tk@?oP:O]1?l000000on@ZnSo0000oi^ejP03oi^ejP05o`000?nW
`>coYl3/ojO0k?l000001?nbb^`00ol0003o_M?[o`000004o`0000;oa];S00?o0000ol[DhOo:e>40
0_o:e>400ol0003obmCQol_Dh@02ol_Dh@03o`000?o8dn;ob=?R00;ob=?R00?o0000ol7?iOo1cnD0
0_o1cnD00ol0003o]/SXo`00000<o`000005ogVOj_l0003oI8oVofB?i_l000000omCP^800om]QM[o
0000ofR0f003ofR0f003o`000?mmQM3oOHG@00;oOHG@00Go0000ohj:bol0003oT8k=o`000004oibB
b@05o`000?nWV<KoYiS6ojNHa_l000000_n`W/D01Ol0003o^JG5okVUaOniYLGo000000?o`Jk700?o
0000olVhb_o9^<X00_o9^<X2o`0000?od/?<00?o0000omWBd_oId]800_l00003omgSf@Co000000Go
eo7So`000?o@jnSod>_Xo`000002olKQj`05o`000?nid^go^M;]okWBkOl000001?nZ`^/01Ol0003o
W;;WoibbionL/^Oo000000CoTJKT00?o0000ohVNhOn9W^400_n9W^400ol0003oQY[OohJJg`02ohJJ
g`Co000000?oOIgWo`000?n3XnP00_n3XnP00ol0003oSZ_Zohj[jP02ohj[jP05o`000?nJ]^_oV[K[
oiZfjol000001?nX`N`01Ol0003o/l[[ok?:joncb^_o000000?o_M7Y0_l00002ol?Fj003o`000?o5
f>OoaMSW00;oaMSW00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`000oooool0
0ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;_ooool3
o`0000Kooooo00Co0000og^TkOmkY>goNjC]0on0Ynd3ohZ^k@Go000000?oVkGZo`000?nW`>`00_nW
`>`00ol0003o//[/ok;:k004o`0000;o_lkV00?o0000olKBhoo6d^<00_o6d^<00ol0003ob]CQol[D
h@02ol[Dh@03o`000?o;e>7obmCQ00;obmCQ00?o0000olSCh_o8dn800_o8dn801?l0003o`LoUol7?
iOo1cnD3o`0000;o]/GU00Go0000ojFnjonU_^_oYKk[o`000003ohfcl003o`000?m]Xo7oKJ?a00Co
000000?oI8oVo`000?mCP^800_mCP^82o`0000?oJ83H00?oJ87Ho`000?mmQM000ommQM001Ol0003o
T8k=oi2>cOn@S/go000000?oW9;900Ko0000ojNHa_nWV<KoYiS6o`000?n`W/D4o`000003okVUaOl0
003o`Jk700;o`Jk700?o0000olVhb_o9^<X00_o9^<X01Ol0003od<C>o`000?oB`lco000000?ofM;B
00?o0000omgSfOoMhmT00_oMhmT01Ol0003oeo7SomOahooGlN?o000000?od>_X2_l00002oj[2j`05
o`000?nL/^OoW;;Woibbiol000001?nAY^@00ol0003oRIkQohVNh@02ohVNh@03o`000?n6V]ooQY[O
00;oQY[O1?n7Vn03o`0000;oPj?X00?o0000ohj[j_n>ZnX00_n>ZnX01Ol0003oV[K[oiZfjonJ]^_o
000000CoZ<7/00Go0000ok?:joncb^_o/l[[o`000003okgAj@05o`000?o3e^So0000ol?Fj?l00000
0_o5f>L3o`0002;ooooo00?o0000ooooooooool01oooool00004oiRHV?ooooooV9RHogMgM`cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`?o00002Oooool01?l0003oNjC]
og^TkOmkY>d4oh2Wk@?oRZk]1?nH]nd8o`0000;o]<SY1Onoc^H00ol0003oa];SolKBh`02olKBh`05
o`000?o:e>7ob]CQol[DhOl000001?o;e>400ol0003ob=?RolSChP03olSChP?o000000?o`LSPo`00
0?nfaND00onfaND01Ol0003oYKk[ojFnjonU_^_o000000?oSK?`00Co0000offSlOm]Xo7o00000_m=
Snd3o`0000;oDh;R0_m;Nml00ol0003oJ83Ho`000002ofR1f006o`000?mmQM3oOHG@ogf5d?n1R]?o
00000on@S/d00ol0003oW9;9oibBb@06o`000004ok2Sbol0003o^:[;okRZb`Co000000?o`Jk7o`00
0?o9^<X00_o9^<X01Ol0003od<C>om34c_o@a<ko000000;ofM;B00?o0000omgSfOl000000_oMhmT0
0ol0003ofOCQo`000003omOah`Go00000_nnj?801Ol0003o]=GaokCElOndeO7o000000;oZL;/1?l0
0002oibbi`03o`000?nAY^CoTJKT00;oTJKT00Go0000ohVNhOn9W^7oRIkQo`000004ohJJg`03o`00
0?n7Vn3oQi_P00?oQi_P0_n<X>800ol0003oPj?Xo`000004ohj[jP05o`000?nJ]^_oV[K[oiZfjol0
00001?nX`N`01Ol0003o/l[[ok?:joncb^_o000000?o_M7Y00?o0000ol?Fj?l000001?l00002ol;P
kP03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00004oc8b<_l0003o<S8bonk^
kPcooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo0ol0000=ooooo`04o`000?mkY>goNjC]
o`0000?oP:O]00Co0000ohZ^kOn:[^goRZk]1?nH]nd4ojK0k0Ko]<SY1?noc^H00ol0003oa];SolKB
h`02olKBh`03o`000?o:e>7ob]CQ00;ob]CQ00Go0000ol_DhOo;e>7obmCQo`000004olSChP;o0000
1?o1b>000ol0003o]/GUokK5i@02okK5i@05o`000?nU_^_oYKk[ojFnjol000000on=/o001?l0003o
KJ?aoffSlOl00002odf?k@05o`000?lbO^Oo0000oe>2h_l000000om;Nml2o`0000;oJ87H00?o0000
ogf5d?l000000_n1R]<02?l0003oT8k=oi2>cOl0003oW9;9o`000?nNVLoo00000_nWW/`01?l0003o
/:?;ok2Sbol00003okRZb`03o`000?no/Lgo_k7=00?o000000?obKS:o`000?o@a<h00_o@a<h2o`00
0003omWBd_l0003ogN?I00;ogN?I0_l00002omWdh@03o`000?oGlN?o000000;o00000_o4mNh01?l0
003o_^SbokkXl_l00003okCEl@03o`000?nY`^coZL;/00;oZL;/00?o0000oinaiOnO/ND00ol00003
oi6Vi003o`000?n9W^7oRIkQ00;oRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh002
ohNKh003o`000?n<X>;oS:3R00;oS:3R1?l000000on>Zn[o0000oiZfj`02oiZfj`03o`000?nX`Nco
Z<7/00;oZ<7/00Ko0000ok?:joncb^_o/l[[o`000?nmdNT4o`000003okoMk_l0003o000000?o`^3^
00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`006Oooool2o`0002Kooooo0ol0
000@ooooo`05o`000?mkY>goNjC]og^TkOl000000_n0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?o
V;O]00?o0000ojK0k?nV`>`00_nV`>`5okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<00ol0
003ob]CQol[Dh@02ol[Dh@03o`000?o;e>7obmCQ00;obmCQ1?l000000oo7b]co0000ol78h004ol78
h003o`000?nfaNGo]/GU00;o]/GU00Co0000ojFnjonU_^_o00000on=/o001Ol0003oKJ?aoffSlOm]
Xo7o000000;oCHo]00Go0000oc9niolbO^OoDh;Ro`000002od]kg`;oC7cO00?o0000ofR1f?mXPMP0
0_l00003oh6:d`04o`000?n@S/go0000o`0000?oWYW?00?o0000ojNNc?l000000_n`Xl/01?l0003o
^:[;okRZbol00003oknac@04o`000?o5^]3oaK[@o`0000?od<C>00Co0000omKAe?oFdMCo00001?oM
hmT00ol0003ofOCQomWdh@03o`000005olGkiol0003oa?G^olCek_l000000_nnj?801Ol0003o]=Ga
okCElOndeO7o000000CoZL;/00?o0000oinaiOnO/ND00_nO/ND01_l0003oUjGOo`000?l0003oTJKT
o`0000CoRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh002ohNKh003o`000?n<X>;o
S:3R00;oS:3R00Co0000oi>YiOnCZNGoTjWU1?l000000onJ]^_o0000ojS1k003ojS1k003o`000?nc
b^_o000000?o00000_njenh00ol0003o_mg^okoMkP02o`0000?o`^3^00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Sooooo`?o00004oooool0
1Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go00001?nH]nd01Ol0003oY/3/
ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H00ol0003oa];SolKBh`02olKBh`05
o`000?o:e>7ob]CQol[DhOl000000oo;e>42o`0000Goal[L00?o0000ol78h?o1b>000_o1b>000ol0
003o]/GUokK5i@02okK5i@05o`000?nU_^_oYKk[ojFnjol000000on=/o001Ol0003oKJ?aoffSlOm]
Xo7o000000;oCHo]00?o0000oc9niolbO^L00_l000001?m;Nmoo0000odalgom<O=l2ofR1f0;oKhOJ
00Oo0000oh6:don1R]?oPH[Co`000?nDU]?o000000?oWYW?00Ko0000ojNNc?nWW/co0000ok2Sbol0
0002okRZb`04o`000?no/Lgo_k7=o`0000;oaK[@00Go0000ol_4e?l0003od<C>o`000002omKAe008
omWQg?l0003ogN?IomgSfOl0003ofOCQo`000?oIm>42o`0000;oaO_W00Co0000olCek_o4mNko0000
0onnj?801?l0003o]=GaokCElOl00004ojW2k003o`000?nO/NGoWk7U00;oWk7U00?o0000oiNUgonG
YMl00_nGYMl2o`0000?oRIkQ00?o0000ohJJgon6V]l00_n6V]l00ol0003oQi_PohNKh003ohNKh005
o`000?n<X>;oS:3RohbPh_l000001OnCZND00ol0003oWKCXoifdj008o`0000;o//g^00Co0000ok[G
k_njenko00000onogNh01Ol0003o`^3^o`000?o2h>ko000002Cooooo00?o0000ooooooooool01ooo
ool001Sooooo00?o0000ooooooooool08?ooool3o`0001Oooooo00Co0000og^TkOmkY>go00000on0
Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00Go0000ojK0k?nV`>coY/3/o`000005okC8j@05
o`000?noc^Ko_lkVoko>i_l000001?o6d^<00ol0003ob]CQol[Dh@02ol[Dh@?o000000?ob/_Jo`00
0?o7b]`01Oo7b]`00ol0003o`LSPol78h002ol78h003o`000?nfaNGo]/GU00;o]/GU00?o0000ojFn
jonU_^/03?l00002oc9ni`05o`000?lTMN?o0000od]kgol000000_m<O=l2o`0000;oKhOJ00Co0000
oh6:dol0003o00000_nDU]<01Ol0003oWYW?oijIcol0003oYik<00So000000Co_k7=o`000?o5^]3o
00000oo;a=@00ol0003oe]7Do`000003omWQg0;o000000SofOCQo`000?l0003o0000olCmh_l0003o
aO_Wo`0000;oa?G^00Go0000okkXl_nnj?;o_^Sbo`000002okCEl@03o`000?nY`^coZL;/00;oZL;/
00?o0000oinaiOnO/ND00_nO/ND00ol0003oUjGOoiNUg`03oiNUg`06o`000?nBWM_o0000o`000?n9
W^7o00001?n6V]l00ol0003oQi_PohNKh002ohNKh003o`000?n<X>;oS:3R00;oS:3R00?o0000oi>Y
iOnCZND00_nCZND00ol0003oWKCXoifdj002oifdj003o`000?nW`NcoYl7/00;oYl7/00Co0000ok;=
k_nbcNko00000onjenh02Ol0003o_mg^okoMk_nogNko0000ol;Pk_l0003o`^3^o`00000Tooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Jooooo`05o`00
0?mkY>goNjC]og^TkOl000000_n0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00?o0000ojK0
k?nV`>`00_nV`>`00ol0003o]<SYokC8j@02okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<0
1?l0003ob]CQol[DhOo:e>42o`0000Cob/_J00?o0000olO:g?o7b]`00oo7b]`00ol0003o`LSPol78
h002ol78h003o`000?nfaNGo]/GU00;o]/GU0ol00003ojFok0CoR[Sd1?mRZ?L00olcTO3o0000o`00
0002o`0000;o97GS0_l000001?m<O=oo0000oeN5hol00002ofn7fP;o000000KoR9CHo`000?nDU]?o
U9KCo`000?nNVLl2o`000006ojRXe_l0003o[jcEo`000?nd/MGo00000_nj]mH00ol0003oaK[@o`00
0003ol_4e0;ocm3J00?o0000omWQg?oIhM`00_oIhM`01?l0003ofOCQomWdhOl00002olCmhP03o`00
0?o5nnOoaO_W00co00000_nY`^`00ol0003oWk7Uoinai@02oinai@03o`000?nGYMooUjGO00?oUjGO
00?o0000oi:MfonBWM/00_nBWM/2o`0000CoQY[O00?o0000ohNKh?n7Vn000_n7Vn000ol0003oS:3R
ohbPhP02ohbPhP03o`000?nCZNGoTjWU00;oTjWU00Go0000oifdj?nM]>SoWKCXo`000004ojO1k005
o`000?nbcNko//g^ok;=k_l000000_njenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Joooo
o`?o00007Oooool01Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go00001?nH
]nd01Ol0003oY/3/ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H01Ol0003oa];S
olKBhoo6d^?o000000;ob]CQ00?o0000olW:fol000001Oo:bmX00ol0003oal[LolO:g003olO:g003
o`000?o1b>3o`LSP00;o`LSP00Co0000okK5iOl0003o00000onf`N<4ojFok0;o00000_n:^?@01ol0
003oHZSgof:XmomRZ?Oo0000oc>Al?l;NN801?l000001?lVM^?o0000odalgol00002oeN5h`07ofn7
f_l0003oNY?Oo`000?n8U=So0000oiBFd`02o`00000<oj:Uf?l0003oZ:SFo`000?n_[=Go0000okBa
eOl0003o^[OFo`000?nn_MWo00000_o;a=@01?l0003ocm3Jolo@f_oAg>44o`000004omK`i?l0003o
0000o`0000;oa?gR1Ol00002ok3[n0;o00000_n^eoD00ol0003oZ<;/ojS2k002ojS2k0?o00000onO
/ND00ol0003oUjGOoiNUg`03oiNUg`03o`000?nBWM_oTYgK00?oTYgK00?o0000oi2JfOl000000ol0
0005ohNKh005o`000?n<X>;oS:3RohbPh_l000001OnCZND01Ol0003oWKCXoifdj?nM]>So000000Co
Yl7/00Co0000ok;=k_nbcNko00000onjenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^0_l0000T
ooooo`03o`000?oooooooooo00Oooooo000Hooooo`;o00006?ooool3o`00027ooooo00Co0000og^T
kOmkY>go00000on0Ynd01Ol0003oRZk]ohZ^kOn:[^go000000?oV;O]00Go0000ojK0k?nV`>coY/3/
o`000005okC8j@05o`000?noc^Ko_lkVoko>i_l000001?o6d^<2o`0000?obL[K00?o0000ol[;f_o:
bmX00oo:bmX00ol0003oal[LolO:g002olO:g003o`000?o1b>3o`LSP00;o`LSP0_l00006okK1h`03
o`000?nU_ncoYKo/00;oYKo/00Go0000ohZhm?n:^?CoR[Sdo`000002of:Xm`03o`000?lcTO3o<i7`
00;o2gWR0_l00002obIfh`;o00000_mGQN<2o`000003ogZCgon8U=SoR9CH00;o000000GoVZ?Ko`00
0?nRYMSo0000ojRXeP03o`000004okZge_l0003o_[gIo`0000;o`/CL00?o0000olo@f_l000000_oA
g>401?l0003oe_3TomK`i?oFl>@:o`0000;o/>_h00?o0000ojkGmOn^eoD00_l00004ojS2k007o`00
0?nR/N;oX[7Roj:ah_l0003oWk7Uo`000005oiNUg`03o`000?nBWM_oTYgK00?oTYgK00?o0000oi2J
fOn@V]T00on@V]T2o`0000?oQi_P00?o0000ohbPh_n<X>800_n<X>800ol0003oTjWUoi>Yi@02oi>Y
i@03o`000?nM]>SoWKCX00;oWKCX00Go0000ojO1k?nW`NcoYl7/o`000003ok;=kP05o`000?njenko
^]O^ok[Gk_l000000_nogNh01Ol0003o`^3^ol;Pk_o2h>ko000000;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`06ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o00009?oo
ool01Ol0003oNjC]og^TkOmkY>go000000;oP:O]00Go0000ohZ^kOn:[^goRZk]o`000003oiRgk@03
o`000?nV`>coY/3/00;oY/3/00?o0000okC8jOndb>T00_ndb>T01Ol0003o_lkVoko>i_noc^Ko0000
00?oa];S0_l00005olW:f`03o`000?o:bm[ob/_J00?ob/_J00?o0000olO:g?o7b]`00_o7b]`01?l0
003o`LSPo`000?l00003oko2g0Ko]/7S00?o0000ojFok?nU_n`00_nU_n`00ol0003oR[SdohZhm008
o`000003o`]ih_l0JmSo000000;o000000Oo>8;Xo`000?mGQN?o0000ofVCiol0003oNY?O00;o0000
00GoTZ;Po`000?l0003o0000oj:Uf005o`000004okjmfOl0003o`/CLol;4g0;oa<gQ00So0000om7L
hOl0003oc^WYo`000?oFl>Co0000omK`i0Co000000CoWOCOo`000?nYmNoo00000_n`joP2o`0000;o
[]Oe00?o0000ojS2k?nX`^`00onX`^`00ol0003oX[7Roj:ahP02oj:ahP?o00001OnGYMl00ol0003o
TYgKoi:Mf`02oi:Mf`03o`000?n@V]WoT9[I00CoT9[I00?o0000oi6Kf_l000000_n7Vn000ol0003o
S:3RohbPhP02ohbPhP03o`000?nCZNGoTjWU00;oTjWU00Go0000oifdj?nM]>SoWKCXo`000004ojO1
k005o`000?nbcNko//g^ok;=k_l000000_njenh01Ol0003o_mg^okoMk_nogNko000000?o`^3^00Co
0000oooooooooooo00009?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003ooooooooo
o`0Booooo`?o00009oooool01Ol0003oNjC]og^TkOmkY>go000000?oP:O]00Co0000ohZ^kOn:[^go
00001?nH]nd01Ol0003oY/3/ojK0k?nV`>co000000Co]<SY00?o0000oko>i_noc^H00_noc^H3o`00
0003olK9gOl0003obL[K00CobL[K00?o0000ol[;f_o:bmX00oo:bmX00ol0003oal[LolO:g003olO:
g003o`000?no`]co_l;L00Co_l;L00?o0000okK1honf`N<00onf`N<01?l0003oYKo/ojFok?nU_n`3
o`0000?oRKgh00Co0000oeZ`nomJ/?_o00000_lMTnX00ol0LLko0000o`000002o`0000;o>8;X0ol0
00000omYTnOo0000o`00000<o`0000;oa<gQ00?o0000olCEi_l000000oo>jNT2o`000004olGjjOl0
003o0000oiCad`[o000000?o[]Oeo`000?nX`^`00onX`^`2o`0000CoX[7R00Go0000oifUfonMYM_o
WJGKo`000003oiNUg`03o`000?nBWM_oTYgK00;oTYgK00?o0000oi2JfOn@V]T01?n@V]T01ol0003o
TI_Joi6Kf_nAVm[o0000ohNKh?l000000on<X>800ol0003oTjWUoi>Yi@02oi>Yi@03o`000?nM]>So
WKCX00;oWKCX00Go0000ojO1k?nW`NcoYl7/o`000003ok;=kP05o`000?njenko^]O^ok[Gk_l00000
0onogNh01Ol0003o`^3^ol;Pk_o2h>ko000000?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`06ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000:oooool01?l0003oNjC]
og^TkOl00003oh2Wk@05o`000?n:[^goRZk]ohZ^kOl000000onH]nd01Ol0003oY/3/ojK0k?nV`>co
000000Go]<SY00?o0000oko>i_l000000_l00004olK9g@03o`000?o9b]_obL[K00?obL[K00?o0000
ol[;f_o:bmX00oo:bmX01Ol0003oal[LolO:g?o7b]co000000;oa<7G00?o0000oko2g?no`]`00ono
`]`2o`0000Co]/7S00?o0000ojFok?l000000onU_n`00ol0003oRKghohVmn002ohVmn0;o00000_mJ
/?/01Ol0003o7I?Zo`1ac_l0003o06gI00?o00000_mEUNl5o`000003ohZSiOl0003o000000Oo0000
0_o4eNH00ol0003o`Mc]o`00000?o`0000?oYmOh0ol00003ojS2k003o`000?nR/N;oX[7R00;oX[7R
0_l00005oifUf`03o`000?nGYMoo000000CoTYgK00?o0000oi2JfOn@V]T01?n@V]T00ol0003oTI_J
oi6KfP03oi6KfP;o00000on<X>800ol0003oTjWUoi>Yi@02oi>Yi@05o`000?nM]>SoWKCXoifdj?l0
00001?nW`N`01Ol0003o//g^ok;=k_nbcNko000000;o^]O^00Go0000okoMk_nogNko_mg^o`000003
ol;PkP03o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06
ooooo`005oooool00ol0003oooooooooo`0<ooooo`?o0000;_ooool3o`000005og^TkOl0003oP:O]
oh2WkOl000000on:[^d01Ol0003oV;O]oiRgkOnH]ngo000000CoY/3/00?o0000okC8jOndb>T01?l0
0002oko8h@03o`000?o6bMgoa/WM00?oa/WM00?o0000olW:foo9b]/00oo9b]/00ol0003ob/_Jol[;
fP03ol[;fP03o`000?o7b]co000000Coa<7G00?o0000oko2g?no`]`01?no`]`01?l0003o]/7SokK1
honf`N<2o`0000KoYKo/0ol00002ohVmn0;o00000_mJ/?/5o`000003oa=niOl0003o000000;o0000
0omhZO8:o`0000?o`Mc]00?o0000ol;bl?o2l_002ol00004ojOGn0;o00000onX`^`00ol0003oZ<;/
o`000004oj:ahP03o`000?nMYM_oWJGK00GoWJGK0ol00003oi:Mf`03o`000?n@V]WoT9[I00CoT9[I
00?o0000oi6Kf_nAVmX00onAVmX00ol0003oTioLoi>Og002o`000003ohbPh_l0003oTjWU00;oTjWU
00?o0000oifdj?nM]>P00_nM]>P00ol0003oYl7/ojO1k002ojO1k004o`000?nbcNko//g^o`0000?o
^]O^00Go0000okoMk_nogNko_mg^o`000003ol;PkP03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`06ooooo`005oooool2o`0000[ooooo0ol0000aooooo`03
o`000?maZ??oLJSc00Co000000GoP:O]o`000?n:[^goRZk]o`000004oiRgk@03o`000?nV`>co0000
00Co00000_ndaNH00ol0003o_lSQoko8h@02oko8h@03o`000?o6bMgoa/WM00?oa/WM00?o0000olW:
foo9b]/00oo9b]/00ol0003ob/_Jol[;fP02ol[;fP;o00001_o4`ML2o`0000Go_l;L00?o0000okK1
hol000000ond_^42o`0000KoYKo/0_l00002ohVmn003o`000?mH^_coF;[l00;oF;[l4Ol000000onW
cOCo0000o`000004o`000003oj_dlol0003o000000Oo00001?nWeoP3o`0000GoZ<;/0_l00003oj:a
hP;o00001_nMYM/2o`0000?oVYkF00?o0000oi:Mfol000001_n@V]T00ol0003oTI_Joi6KfP03oi6K
fP03o`000?nCWmcoTioL00?oTioL0_l00003oi>Yi@05o`000?nM]>SoWKCXoifdj?l000001?nW`N`0
1Ol0003o//g^ok;=k_nbcNko000000;o^]O^00Go0000okoMk_nogNko_mg^o`000003ol;PkP03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`005ooo
ool00ol0003oooooooooo`06ooooo`?o0000=Oooool01?l0003oLJScog6Xlol00002ogN[l`_o0000
0_nV`>`00ol0003o]<GVokC5iP03okC5iP03o`000?nob>7o_lSQ00;o_lSQ00?o0000olK9gOo6bMd0
0oo6bMd00ol0003obL[KolW:f`02olW:f`05o`000?o:bm[ob/_Jol[;f_l000000oo6`MD00ol0003o
a<7GolC1e`04olC1e`03o`000?no`]co_l;L00?o_l;L00?o0000okBnhOnd_^401Ond_^42o`0000Go
YKo/00?o0000oh_4n_n;a?X00_n;a?X3o`0000?oF;[l00Co0000o`1ie?l0NMCo;Ic`0ol00002ofbg
o0Go00000_nOho`;o`0000?oW]Ck00Co0000ojOGn?l0003o00001OnX`^`3o`0000;oY[7Q00?o0000
oj:ah_l000001onMYM/00ol0003oVYkFoiZNeP03oiZNeP?o00001On@V]T00ol0003oTI_Joi6KfP03
oi6KfP03o`000?nCWmcoTioL00CoTioL00Ko0000oiVXh?l0003o0000oi>YiOl00003oifdj003o`00
0?nW`NcoYl7/00;oYl7/00Co0000ok;=k_nbcNko00000onjenh01Ol0003o_mg^okoMk_nogNko0000
00?o`^3^00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0000iooooo`04o`000?maZ??oLJSco`00
00;oMj_c00Go0000ohFal_n5/O;oQK7bo`000003oiJil003o`000?nV`>coY/3/00;oY/3/00?o0000
okC5i_ndaNH00ondaNH00ol0003o_lSQoko8h@02oko8h@03o`000?o6bMgoa/WM00;oa/WM00?o0000
olW:foo9b]/00oo9b]/00ol0003ob/_Jo`000005olK1e@03o`000?o4`MOoa<7G00Coa<7G00Go0000
oko2g?no`]co_l;Lo`000002okbkf@;o00001_nd_^43o`000003ojFok?l0003oYL3]00;oYL3]0ol0
0004oh_4nP;o00000_mNaO/00om1003o0000o`000003o`000003og7:ool0003o000000[o00001onN
e?/3o`0000GoZ<;/0_l00005ojJah@;o00001_nMYM/2o`0000GoVYkF00Go0000oiVKe?nIVmCoVI_D
o`000003oi2Jf@03o`000?nAVm[oTI_J00?oTI_J00?o0000oi>Og?nCWm`01?nCWm`00ol0003oVJSP
oiVXh002oiVXh0?o00000_nM]>P01Ol0003oYl7/ojO1k?nW`Nco000000?o//g^00Go0000ok[Gk_nj
enko^]O^o`000003okoMkPCo00002_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Gooooo000Fooooo`04o`000?ooooooooooooooo`?o0000?Oooool01?l0003oLJScog6Xlol00002
ogN[l`05o`000?n5/O;oQK7bohFal_l000000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?nd
aNKo]<GV00?o]<GV00?o0000oko8hOnob>400_nob>400ol0003oa/WMolK9g@02olK9g@03o`000?o9
b]_obL[K00;obL[K0_l00007olK1e@;o00001Oo4`ML00ol0003o_l;Lo`000005okbkf@?o00001_nd
_^400ol0003oYL3]ojG0k@05ojG0k@?o00000_n;a?X00ol0003oSl[loho:o003oho:o0;o000000?o
:JkRo`000?l000001Ol00004oiK@o004o`000?nNe?_oW]CkoikDn`Go00000onW`^d00ol0003oZ<;/
o`000002o`0000CoY[7Q0ol00002ojBVf004o`000?nMYM_oWJGKoifUf`;o00001OnJW]H2o`0000Go
VI_D00?o0000oi2JfOl000001OnAVmX00ol0003oTioLoi>Og004oi>Og003o`000?nIZ>3oVJSP00;o
VJSP00Co0000oinci_nO/nKoWk?V1?l00002ojO1k004o`000?nbcNko//g^ok;=kPWo000000?o^^Kd
o`000?ooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Foooo
o`Co0000@Oooool01?l0003oLJScog6Xlol00002ogN[l`05o`000?n5/O;oQK7bohFal_l000000onF
^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo]<GV00;o]<GV00?o0000oko8hOnob>400_no
b>400ol0003oa/WMolK9g@03olK9g@04o`000?o9b]_o0000o`0000?oa/7F00?o0000olK1eOo6`MD0
1Oo6`MD00ol0003oa<7GolC1e`03olC1e`03o`000?nl^mWo_;_I00Oo_;_I0_l00004okBnh@03o`00
0?nb^]oo/[[O00Co00001?nU`>d2o`0000GoSl[l00?o0000oho:o?n?b_`00_n?b_`00ol0003oU]3l
oiK@o003oiK@o0So00001_nW`^d4o`0000GoY[7Q0_l00006ojBVf003o`000?nMYM_o000000KoVYkF
00?o0000oiVKe?nIVm@01OnIVm@2o`0000GoTI_J00?o0000oi>Og?nCWm`01?nCWm`00ol0003oVJSP
oiVXh002oiVXh003o`000?nO/nKoWk?V00?oWk?V00?o0000ojO1k?nW`N`01ol00002okGKl`04o`00
0?nhhoCo^>?do`0000;o^^Kd00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Gooooo000Fooooo`?o0000@oooool01?l0003oLJScog6Xlol00002ogN[l`05
o`000?n5/O;oQK7bohFal_l000000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo]<GV
00;o]<GV00?o0000oko8hOnob>400_nob>400ol0003oa/WMolK9g@03olK9g@03o`000?o6`MKoa/7F
00Coa/7F0_l00006olK1e@05o`000?o4`MOoa<7GolC1eol000000_o0^]<3o`0000Oo_;_I0_l00000
0ond_^7o0000ok:jg`06ok:jg`?o00000_nU`>d00ol0003oY/7]ojK1k@04ojK1k@[o00001OnW`Nd0
1?l0003oYl;]ojO2kOnW`^d5o`0000CoZK?O00?o0000ojJahOl000000_l00008ojBVf0;o00001_nJ
W]H00ol0003oVI_DoiVKe005oiVKe004o`000?nIW=GoVIcEo`0000?oTI_J00?o0000oi>Og?nCWm`0
1?nCWm`00ol0003oVJSPoiVXh002oiVXh003o`000?nO/nKoWk?V00?oWk?V00Go0000ojO1k?nW`Nco
Yl7/o`000004ojo?l@04o`000?nefo?o]M_co`0000;o^>?d00Co0000ok[Vm?nji_Co00003oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000<ooooo`Co000000?o410@oooo
ooooool01Oooool00ol0003oooooooooo`12ooooo`04o`000?maZ??oLJSco`0000;oMj_c00Go0000
ohFal_n5/O;oQK7bo`000003oiJil003o`000?nV`>coY/3/00;oY/3/00?o0000okC5i_ndaNH00_nd
aNH00ol0003o_lSQoko8h@02oko8h@05o`000?o6bMgoa/WMolK9gOl000000_o3`]P00ol0003oa/7F
olK1eP04olK1eP;o00001Oo6`MD00ol0003oa<7Go`000006ol2jd`;o00001onl^mT00ol0003o/[[O
ok:jg`09ok:jg`;o00001OnV`Nd00ol0003oY/7]ojK1k@03ojK1k@03o`000?nW`NgoYl7]00?oYl7]
2Ol00008ojVcg`?o00002OnTY]P2o`0000;oXZ3C00Co0000oiZNe_nJW]KoVYkF0_l00006oiVKe0;o
00001?nIW=D00ol0003oTI_Jo`000006oi>Og003o`000?nIZ>3oVJSP00;oVJSP00?o0000oinci_nO
/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@0
1?l0003o^^Kdok[Vm?l0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`05o`000?maZ??o
LJScog6Xlol000000_mgZo<01Ol0003oQK7bohFal_n5/O;o000000?oU[W`00Go0000ojK0k?nV`>co
Y/3/o`000004okC5iP03o`000?nob>7o_lSQ00?o_lSQ00?o0000olK9gOl000001?o3`]P2o`0000Ko
a/7F00?o0000olK1eOo6`MD00oo6`MD00ol0003o`;[Col2jd`07ol2jd`;o00001Onl^mT00ol0003o
^;KFokRfeP04o`0000Ko/[[O00?o0000ok2ggon`]ml01?n`]ml;o`0000Ko[KGO00?o0000ojVcgonY
/ml00onY/ml5o`0000;oZJWF00?o0000ojBVf?nTY]P01?nTY]P3o`0000GoXZ3C00?o0000oiZNe_l0
00001_nIVm@2o`0000KoVIcE0ol00005oi>Og003o`000?nIZ>3oVJSP00;oVJSP00?o0000oinci_nO
/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@0
1?l0003o^^Kdok[Vm?l0000Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool000kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`11ooooo`05o`000?maZ??o
LJScog6Xlol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`000?nV`>coY/3/00;oY/3/
00?o0000okC5i_ndaNH00_ndaNH00ol0003o_lSQoko8h@02oko8h@;o00001oo3`]P00ol0003oa/7F
olK1eP04olK1eP;o00000oo6`MD00ol0003o`[WAo`000002o`0000Oo`;[C0ol000000onl^mWo0000
okRfeP06okRfePCo000000?o/[[Oo`000?n`]ml02on`]ml00ol0003o[KGOojfeg`09ojfeg`03o`00
0?nY/moo000000?o00002?nYZMH01?l0003oY:KHojBVf?nTY]P2o`0000SoXZ3C0_l00006oiVKe003
o`000?nIW=GoVIcE00GoVIcE00Go0000oi^Pf?nKX=SoVj3Ho`000003oi>Og003o`000?nIZ>3oVJSP
00;oVJSP00?o0000oinci_nO/nH00onO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000
okGKlonefo?o00000_nhho@01?l0003o^^Kdok[Vm?l0000Dooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`0004;ooooo00Go
0000og6XlomaZ??oLJSco`000002ogN[l`04o`000?n5/O;oQK7bo`0000?oU[W`00?o0000ojK0k?nV
`>`00_nV`>`00ol0003o]<GVokC5iP02okC5iP04o`000?nob>7o0000o`0000?o_L;M00?o0000ol?2
f?o3`]P01?o3`]P2o`0000Koa/7F00?o0000olK1eOl000001Oo2^M43o`0000Oo`;[C00?o0000okRf
e_nh]]H02_nh]]H2o`0000;o/;OO1Ol00005ok2gg`03o`000?n]]Moo[KGO00?o[KGO2?l0000<ojVY
eP04o`000?nTY]So0000o`0000OoXZ3C0ol00002oj6Md@04o`000?nIVmCoVI_DoiVKe0;o00001onI
W=D00ol0003oVj3Hoi^Pf003oi^Pf003o`000?nCWmco000000CoVJSP00?o0000oinci_nO/nH00onO
/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGKlonefo?o00000_nhho@01?l0003o
^^Kdok[Vm?l0000Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`10ooooo`05o`000?maZ??oLJScog6X
lol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`000?nV`>coY/3/00;oY/3/00Co0000
okC5i_ndaNKo]<GV0_l00006okg2g@;o00001_o3`]P00ol0003oa/7FolK1eP04olK1eP03o`000?o2
^M7o`[WA00Oo`[WA0_l00005ol2jd`03o`000?nk/m7o^k?A00Go00001_nh]]H00ol0003o];7EokBa
e@05okBae@_o00001_n_[=D00ol0003oZJWFojVYeP09ojVYePCo00001_nRX=<3o`0000KoXIgA00?o
0000oiVKe?l000001onIW=D2o`0000KoVj3H0ol00003oiVXh003o`000?nO/nKoWk?V00?oWk?V00Go
0000ojO1k?nW`NcoYl7/o`000004ojo?l@04o`000?nefo?o]M_co`0000;o^>?d00Co0000ok[Vm?nj
i_Co00006?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool01Ol0003oLJScog6XlomaZ??o0000
00;oMj_c00Co0000ohFal_n5/O;o00000onF^O000ol0003oY/3/ojK0k002ojK0k003o`000?ndaNKo
000000?o]<;T1onm`]d00ol0003o`l;Hol?2f004ol?2f0;o00000oo6`MH00ol0003o`[WBol:idP02
o`0000So`[WA0ol000000oo0^]?o0000ok^cd@07ok^cd@Co000000?o^;KFo`000?nd/MD03?nd/MD0
0ol0003o[jcEojn/e@0:ojn/e@04o`000?nYZMKoZJWFojVYePOo00000onYXm400ol0003oXZ3Coj:P
d`02oj:Pd`;o00002OnQWM42o`0000OoVIcE00?o0000oi^Pf?nKX=P01OnKX=P01ol0003oWZSMoijX
gOnNZ=go0000oiVXh?l000001OnO/nH01Ol0003oYl7/ojO1k?nW`Nco000000Co[loa00Co0000okGK
lonefo?o00000_nhho@01?l0003o^^Kdok[Vm?l0000Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`10
ooooo`05o`000?maZ??oLJScog6Xlol000000_mgZo<01?l0003oQK7bohFal_l00003oiJil003o`00
0?nV`>coY/3/00?o00001Ond`^@2o`0000Go_L;M0_l00006ol?2f003o`000?o6`MKo000000Go`[WB
0_l00009ol:id@03o`000?nk/m7o^k?A00_o^k?A0_l00003okBae@Co00001Ond/MD00ol0003o[jcE
ojn/e@04ojn/e@_o00002onYXm44o`0000SoXIgA0ol000000onRW]7o0000oiVLe@04oiVLe@;o0000
1_nKX=P2o`0000CoWZSM0ol00004oinciP05o`000?nW`NcoYl7/ojO1k?l000001?n_co401?l0003o
]M_cokGKlol00002okSSm004o`000?nji_Co^^Kdo`0001_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000@Oooool@o`00
00CoY/3/1_nd`^@00ol0003o_L;Mokg2g@04okg2g@03o`000?o3`]So`l;H00Co`l;H00?o0000ol:i
d_o2^M801_o2^M83o`0000Ko`[WA00?o0000okbaconl/Ll00ol00009ok^cd@03o`000?nf[M3o]Zg@
00Go]Zg@3?l00007ok2Wd003o`000?nYXm7oZJ?A00[oZJ?A0ol00009oj6Md@;o00001OnRW]401Ol0
003oVIcEoiVLeOnIW=Go000000KoVj3H0_l00005oijXg@04o`000?nS/nCoXk?Toj>ci0;o000000?o
Wk?Vo`000?nW`N`00_nW`N`00ol0003o[loaojo?l@02ojo?l@04o`000?nefo?o]M_co`0000;o^>?d
00Co0000ok[Vm?nji_Co00007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Co
oooo000Rooooo`03o`000?oooooooooo043ooooo1?mW[OT3ofn`n0?oPKOg1?nD_?<5ojK0k003o`00
0?nd`^Co]<;T00?o]<;T0_l00005okg2g@;o00000oo3`]P00ol0003o_k[Eoknje@02o`0000So`[WB
0_l00003ol:id@03o`000?nl/Loo_;7?00Co_;7?1?l00005ok^cd@03o`000?nf[M3o]Zg@00[o]Zg@
00?o0000ok2Wd?n`Ym002on`Ym000ol0003oZJ?AojVSd@05ojVSd@Go00000_nYXLl00ol0003oXIgA
oj6Md@05oj6Md@;o00002?nRW]400ol0003oVIcEo`000006oi^Pf003o`000?nNZ=goWZSM00?oWZSM
0_l00005oj>ci0Co000000?oYl7/o`000?n_co400on_co401?l0003o]M_cokGKlol00002okSSm004
o`000?nji_Co^^Kdo`0001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`008oooool00ol0003oooooooooo`10ooooo`05o`000?mW[OWoIjgiofN]nOl000000_m_/?P3oh6g
m`05o`000?nD_??oU;ccoiBllol000001OnV`>`00ol0003o]<;TokC2i003okC2i003o`000?nm`]go
_L;M00Co_L;M00?o0000ol?2f?l000001Ono^]D2o`0000So`[WB0_l000000oo2^M7o0000okbac`09
okbac`?o000000?o^k?Ao`000?nf[M003?nf[M000ol0003o/:O@ok2Wd00<ok2Wd003o`000?nYXm7o
000000Co00002?nYXLl01?l0003oXIgAoj6MdOnQWM43o`0000[oXYkA0_l00005oi^Pf0;o00001?nN
Z=d2o`0000KoXk?T00Co0000ojO1k?nW`NcoYl7/1?l00002ojo?l@04o`000?nefo?o]M_co`0000;o
^>?d00Co0000ok[Vm?nji_Co00008?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Cooooo000Tooooo`;o0000@_ooool3ofN]n@04o`000?m_/?SoKk3hofn`n0;oPKOg0_l00003oiBl
l`03o`000?nV`>coY/3/00;oY/3/0_l00004okC2i003o`000?nm`]go_L;M00Co_L;M00?o0000oknj
eOno^]D01_no^]D3o`0000Oo`[WB00?o0000okbaconl/Ll03?nl/Ll2o`000003okJ]d?l0003o0000
00Co00001_nf[M000ol0003o/:O@ok2Wd005ok2Wd0Wo00003OnYXLl01?l0003oXIgAo`000?l0000:
oj:Nd@?o000000?oXj;Do`000?nKX=P00_nKX=P2o`0000GoWZSM00?o0000oj>ci?nS/n@01?nS/n@2
o`0000?oYl7/00?o0000oj_@lon[d?<00_n[d?<;o`0002;ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`10ooooo`05o`000?mW[OWoIjgi
ofN]nOl000000_m_/?P01?l0003oPKOgoh6gmol00003oiBll`;o00001?nV`>`00ol0003o]<;TokC2
i002okC2i0;o00000onm`]d00ol0003o^kcKok^lf`02o`0000So_k[E0_l00004ol:idP04o`000?nl
//oo_;;?okbbc`Go00002?nl/Ll00ol0003o]Z_>okJ[cP05okJ[cPko00001on`Y/d00ol0003oZJ7?
ojVQc`0;ojVQc`?o00002OnRW]43o`0000GoXj;D00?o0000oi^Pf?l000001OnNZ=d2o`0000KoXk?T
00Co0000ojO1k?nW`NcoYl7/0_l00003oj_@l`;o00000_n]gOP01?l0003o[NGio`000?l00002ojcX
n@03o`000?oooooooooo02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`009oooool00ol0003oooooooooo`10ooooo`;o00000_mW[OT01?l0003oKk3hofn`n?m_/?P2oh6g
m`;o00000onD_?<2o`0000?oY/3/00?o0000okC2i?nd`^@00ond`^@00ol0003o_L;Mo`000005ok^l
f`;o00002?no^]D2o`000003ol:id_l0003o_;;?00So_;;?1Ol00002okbac`03o`000?nfZlko]Z_>
00co]Z_>00?o0000ok2VcOn`Y/d03?n`Y/d00ol0003oZJ7?ojVQc`06ojVQc`Go00000_nYX/l00ol0
003oXYkAoj:Nd@04oj:Nd@?o00002?nSX]@3o`0000?oWZSM0_l00006oj>ci0;o00000onW`N`00ol0
003oZm3coj_@l`02oj_@l`03o`000?n]gOSo[Mgh00;o000000Co[NGio`000?n/j?Wo[>Si0_l0000W
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002Sooooo00?o0000oooo
ooooool0@Oooool00ol0003oIjgiofN]n@02o`0000;oKk3h00Co0000oh6gmon1]oOo00001?nD_?<0
1?l0003oY/3/ojK0k?nV`>`2o`0000?o]<;T0_l00008ok^lf`;o00002?no^]D00ol0003o_;;?okbb
c`0=okbbc`;o00000onfZlh00ol0003o]Z_>okJ[cP09okJ[cP03o`000?n`Y/go/:K=00go/:K=00?o
0000ojVQconYXLl01Ol00008ojVRc`03o`000?nRW]7oXYkA00?o00002?nSX]@3o`0000?oY:WJ00?o
0000oijXgOl000001_nS/n@2o`0000?oYl7/0_l00003oj_@l`;o000000Co[Mgho`000?l0003o[NGi
0_l00002ojcXn@03o`000?oooooooooo02Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`00:Oooool2o`0004;ooooo0_l00002ofN]n@03o`000?m_/?SoKk3h00;o000000?o
PKOgo`000?nD_?<00onD_?<2o`0000?oY/3/00?o0000okC2i?l000000onc_^800ol0003o^kcKok^l
f`06ok^lf`;o00001_no^]D00ol0003o^[?CokZcd`04o`0000[o_;;?00?o0000okJ[c_nfZlh00_nf
Zlh8o`0000?o]Z_>00?o0000ok2VcOn`Y/d01On`Y/d;o`0000coZJ;?1?l00009oj>Re0;o00001_nT
ZMX2o`0000KoXk?T00Co0000ojO1k?nW`NcoYl7/0_l00003oj_@l`;o00000_n]gOP01?l0003o[NGi
o`000?l00002ojcXn@;o0000:oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo000[ooooo`03o`000?oooooooooo047ooooo00Co0000ofN]nOmW[OWo00000om_/?P01?l0003o
PKOgo`000?l00004oiBll`03o`000?nV`>coY/3/00;o00001_nc_^82o`0000Oo^kcK0_l00003oknj
e@03o`000?nj/m?o^[?C00Go^[?C1?l00006okbbc`03o`000?nfZlko]Z_>00[o]Z_>2ol00008ok2V
cP03o`000?nYX/ooZJ;?00SoZJ;?1?l00002ojVUdP03o`000?nSX]CoXj;D00GoXj;D0ol00006ojBY
fP;o00000_nV/n801?l0003oXk?Toj>ci?nS/n@2o`0000?oYl7/00Co0000oj_@lon[d??oZm3c0_l0
0002ojgMn0;o000000Co[NGio`000?n/j?Wo[>Si0_l0000^ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0@Oooool00ol0003oIjgiofN]
n@02o`0000;oKk3h0_l000000on1]oOo0000oiBll`02oiBll`?o00000onV`>`00ol0003o/kkRok>n
hP04ok>nhP?o00001_nk_=/2o`000003oknjeOl0003o^[?C00[o^[?C1?l000000onl//oo0000okJ[
cP0?okJ[cP03o`000?n`Y/ko/:K>00go/:K>00?o0000ojVRconYX/l01?nYX/l4o`0000OoZJGB00?o
0000oj>Re?nSX]@00_nSX]@2o`0000KoY:WJ0ol00005ojJchP03o`000?nS/nCo000000?oYl7/0_l0
0002oj_@l`;o00000on]gOP01?l0003o[NGio`000?l00002ojcXn@03o`000?oooooooooo02oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003ooooooooo
o`11ooooo`;o00000_mW[OT02Ol0003oKk3hofn`n?m_/?So0000oh6gmol0003oU;cco`000003oiC0
m@03o`000?nV`>coY/3/00;oY/3/0_l00006ok>nhP;o00001_nk_=/00ol0003o^[?CokZcd`0>okZc
d`;o00000onfZlh00ol0003o]Z_>okJ[cP0:okJ[cP03o`000?n`Y/ko/:K>00ko/:K>00?o0000ojVR
col000000ol0000;ojVUdP03o`000?nSX]Co000000;o00001_nTZMX2o`0000SoY[?R1?l000000onW
`Nco0000oj_@l`02oj_@l`04o`000?n]gOSo[MghojgMn0Co00000_n/j?T2o`0003;ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00;_ooool2o`0004?ooooo00Co0000ofN]
nOmW[OWo00000_m_/?P4o`0000KoU<3e0_l00004ojK0k0;o00001Onc_^82o`0000Co^kcK00?o0000
okNgfOng]mT01?l0000;okZcd`03o`000?ne[]7o]JkA00;o]JkA2Ol00003okJ[cP03o`000?n`Y/ko
/:K>00Ko/:K>2_l0000=ojVUdPCo00001onTZMX2o`0000OoY[?R0ol00003ojO1k0?o000000?oZm3c
o`000?l000000_n]gOP2o`000003ojgUnOl0003o[>Si00;o[>Si00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo000`ooooo`03o`000?oooooooooo
047ooooo1Ol00003ofZho0;oO[gk00?o0000oiC0mOnD`?D01?nD`?D2o`0000CoY/3/0_l00005ok>n
hP;o000000?o^kcKo`000?ng]mT01_ng]mT5o`0000Ko^[?C00?o0000okF^dOne[]402one[]4<o`00
00So[jWA00?o0000ojVUd_nYYM801_nYYM86o`0000?oZJ_H00?o0000ojBYf_nTZMX00_nTZMX3o`00
00KoY[?R0ol00003ojO1k0?o00000_nVcoD4o`000003ojgMn?l0003o[NGi00;o00000_n/j?T2o`00
03Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00<Oooool00ol0003o
ooooooooo`12ooooo`?oH;Cl00?o0000ofZho?mZ^?`00omZ^?`2ogjmn`03o`000?nD`?GoU<3e00?o
U<3e0ol00003ojK0k0?o00001?nc_^800ol0003o]kOIokNgf@0;okNgf@Co000000?o^[?Co`000?ne
[]404?ne[]400ol0003o[jWAojnYd@0?ojnYd@03o`000?nYYM;oZJGB00Go00002_nYZmP01?l0003o
Y:WJo`000?l00006ojJchP?o00001?nW`N`2o`0000;oY/oe0ol00003oj?Ln`Ko000000?o[>Sio`00
0?ooool0>?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000booooo`03
o`000?oooooooooo04Cooooo0omP]?`00ol0003oJ[SlofZho002ofZho004o`000?mn_O_o0000o`00
00GoU<3e0_l00004ojK0k0;o000000?o/kkRo`000?na^n400_na^n45o`0000[o]kOI0_l00004okF^
d@Go00002?ne[]400ol0003o[jWAojnYd@06ojnYd@co00003OnYZmP4o`0000GoY[?R0ol00004ojO1
k0?o000000CoY/oeo`000?l0003o00000onSg?/5o`0000?oV^Kl0_l0000kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool003?ooooo0_l00017ooooo`;oH;Cl0_l00003ofZh
o0;o000000CoO[gko`000?l0003o00000onD`?D2o`0000CoY/3/00?o0000ok6khOna^n401ona^n44
o`0000Oo]kOI00?o0000ok>bf?nc/]P01onc/]PAo`0000Wo[ZkG00?o0000ojV[f?nYZmP01onYZmP6
o`0000CoZKCQ00?o0000ojJch_l000000_l00004ojO1k0?o000000CoY/oeo`000?l0003o00000onS
g?/5o`0000?oV^Kl0ol0000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool003Gooooo00?o0000ooooooooool0A_ooool00ol0003oH;Clof2do002o`0000?oJ[Sl0_l00000
0omn_O_o0000o`000003oiC0m@;o000000?oY/3/o`000?nW`>`00_nW`>`3o`0000So/K_Q1Ol00000
0ong]mWo0000ok>bf00Aok>bf003o`000?n^[]Oo[ZkG013o[ZkG00?o0000ojV[f?nYZmP01_l00009
ojVdh@?o00001OnW`N`2o`0000;oY/oe0_l00003oj?Ln`Ko00000_nJi_`3o`0004;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`18oooo
o`03o`000?mP]?co000000;o00000_mZ^?`2o`000004ogjmnol0003o0000o`0000;oU<3e00?o0000
ojO0k?nW`>`01onW`>`5o`0000Ko/K_Q0_l00004ok>bf0Ko00002?nc/]P00ol0003o[ZkGojj^e`07
ojj^e`co00002_nY]>45o`0000?oYl7/00?o0000ojO1k?l000000_l000001?nVcoGo0000o`000?l0
0002oj?Ln`?o000000?oWN?mo`000?l000000_nJi_`3o`0004Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=oooool00ol0003oooooooooo`19ooooo`;o000000?oH;Cl
o`000?l000000_mZ^?`3o`000003ogjmnol0003oU/Cg00?oU/Cg0ol00009ojO0k0Go00000_na^n40
0ol0003o[kWQojnih@08ojnihA;o00002On/]^400ol0003oZKCQojVdh@05ojVdh@Go00001onW`N`3
o`000004ojK?mOl0003o0000o`0000;oXmck0ol000001?nMhogo0000o`000?l00002oi[Vo0;o0000
BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000hooooo`;o0000C?oo
ool5o`0000;oJ[Sl00Go0000oh34oOn0a?goP<Cmo`000005oiK4m`Co00002OnW`>`2o`0001?o[kWQ
00?o0000ojbfhOn/]^404On/]^400ol0003oZKCQo`000004o`0000OoYl7/1Ol000000onRc_Oo0000
o`000002o`000004oj?Lnol0003o0000o`0000;oWN?m0_l00002oi[Vo0?o0000C?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000jooooo`03o`000?oooooooooo04cooooo
0ol00004of[0oP03o`000?n0a?goP<Cm00;oP<Cm0_l00004oiK4m`Co00001_nW`>`00ol0003oYl7/
ojO1k003ojO1k0[o00001?n_^N400ol0003o[;KQojbfh@07ojbfh@co00001onW`N`5o`0000;oX/kg
1?l00002oiOHoPCo000000GoWN?mo`000?l0003o0000oi[Vo003o`00053ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`01ooooo`00>oooool00ol0003oooooooooo`1>ooooo`;oGkgm
00?o0000of[0o_mZ`?h00omZ`?h2o`0000CoP<Cm0ol00002oiK4m`Co000000?oYl3/o`000?nW`N`0
3onW`N`>o`0000[oYl7/00Co0000ojO1k?nW`NcoYl7/1Ol00003oj;>m`Co000000?oUmSno`000?l0
00000ol00002oh_MoP?o000000CoV^Klo`000?l0003o0000Doooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo000looooo`;o0000D_ooool00ol0003oGkgmoenmo@02o`0000Co
J/3n0ol00002oh34o@Co000000?oU/Cgo`000?l000002_nW`N`00ol0003oYl7/ojO1k007ojO1k003
o`000?nW`NcoYl7/00SoYl7/3Ol00004oj;>m`Co000000?oUmSno`000?l000000_l00002oh_MoPGo
000000CoQMkmo`000?l0003o0000Eoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo000nooooo`03o`000?oooooooooo05?ooooo0_l000001?mO_Ogo0000o`000?l00003of[0
oPCo000000?oP<Cmo`000?l000003?nIb?PDo`0000[oWL_h00?o0000oj;>monRc_L01?l000000onG
f?ko0000o`000002o`000003oh_Mo_l0003o000000?o000000?oQMkmo`000?l000000ol0001Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool003oooooo00?o0000oooooooo
ool0Doooool00ol0003oooooo`000008o`000003of[0o_l0003o000000OoQ<cn2ol00004oiW8n003
o`000?nMboSoWL_h00SoWL_h4_l000000on;gOko0000o`000002o`000003ohGNoOl0003o000000?o
0000HOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool00oooool4o`000003oenmoOl0003o000000OoKl[o
1_l00006ohC<oQco000000?oRmgno`000?l000000ol000000on5g_go0000o`000002o`0006Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool2o`0005;ooooo00?o
0000ooooooooool01oooool2o`0000OoI<Om1_l00006ofo:oako000000?oQMkmo`000?l000000ol0
001[ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooo
oooo04oooooo00?o0000ooooooooool03oooool6o`0000KoI<Om4Ol000000ombdogo0000o`00000<
o`00077ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0Koooooa;o0000P?ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo0:go
oooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo0_l0001=ooooo`03o`00
0?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Sooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo0019ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0/?ooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01?ooool1o`00007ooooo001;ooooo`;o
0000B?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
COooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo001>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`2cooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo0_l00013
ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo00000Oooool005;ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo0000007ooooo001Coooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`01o`00
0000E?ooool2o`0003oooooo00?o0000ooooooooool0]_ooool1o`00007ooooo0Ol0000005Kooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`;o0000001Gooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0]_ooool3o`000000F?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo0;;ooooo1?l00003ooooo`00FOooool2o`0003[ooooo00?o0000oooo
ooooool0[_ooool4o`0000Oooooo001Kooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Z_ooool4o`0000_ooooo001Looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
Y_ooool4o`0000oooooo001Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0X_oo
ool4o`0001?ooooo001Nooooo`;o0000=Oooool00ol0003oooooooooo`2Nooooo`Co00005oooool0
063ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2Jooooo`Co00006oooool0067o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Hooooo`?o00007oooool006;ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Dooooo`Co00008_ooool006?ooooo0_l0
000_ooooo`03o`000?oooooooooo093ooooo1?l0000Vooooo`00IOooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo08cooooo1?l0000Zooooo`00I_ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Sooooo1?l0000^ooooo`00Ioooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo08Cooooo1?l0000booooo`00J?ooool2o`0002[ooooo00?o0000ooooooooool0
P?ooool4o`0003Kooooo001Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0O?oo
ool4o`0003[ooooo001[ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0N?ooool4
o`0003kooooo001/ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool4o`00
04;ooooo001]ooooo`;o00009Oooool00ol0003oooooooooo`1`ooooo`Co0000A_ooool006oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1/ooooo`Co0000B_ooool0073ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Xooooo`Co0000C_ooool0077ooooo0_l0000Q
ooooo`03o`000?oooooooooo06Cooooo1?l0001Booooo`00Loooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo063ooooo1?l0001Fooooo`00M?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05cooooo1?l0001Jooooo`00MOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Wooooo0ol0001Nooooo`00M_ooool2o`0001cooooo00?o0000ooooooooool0EOoo
ool4o`00067ooooo001hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0DOooool4
o`0006Gooooo001iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0COooool4o`00
06Wooooo001jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0006go
oooo001kooooo`;o00005oooool00ol0003oooooooooo`15ooooo`Co0000LOooool007gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`11ooooo`Co0000MOooool007kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0mooooo`Co0000NOooool007oooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0iooooo`Co0000OOooool0083ooooo0_l0000Booooo`03
o`000?oooooooooo03Gooooo1?l00021ooooo`00P_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo037ooooo1?l00025ooooo`00Poooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02kooooo1?l00029ooooo`00Q?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02[ooooo1?l0002=ooooo`00QOooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`00
097ooooo0027ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0009Go
oooo0028ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`0009Wooooo
0029ooooo`;o00002?ooool00ol0003oooooooooo`0Kooooo`?o0000WOooool008_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`Co0000X?ooool008cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Cooooo`Co0000Y?ooool008gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`Co0000Z?ooool008kooooo0_l00003ooooo`03o`00
0?oooooooooo00_ooooo1?l0002/ooooo`00T?ooool01?l0003oooooooooool00009ooooo`Co0000
/?ooool0097ooooo00?o0000ooooool000001Oooool4o`000;Cooooo002Booooo`;o000000?ooooo
o`000?l000000_l0002hooooo`00Toooool2o`000;cooooo003ooooooe;ooooo003ooooooe;ooooo
003ooooooe;ooooo0000\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51722 .66229 m .51694 .65827 L .43899 .65168 L p .517 0 0 r
F P
0 g
s
.51694 .65827 m .51722 .66229 L .59284 .65812 L p .421 0 0 r
F P
0 g
s
.59284 .65812 m .59527 .65394 L .51694 .65827 L p .421 0 0 r
F P
0 g
s
.59527 .65394 m .59284 .65812 L .66515 .64355 L p .274 0 0 r
F P
0 g
s
.66515 .64355 m .67023 .63881 L .59527 .65394 L p .274 0 0 r
F P
0 g
s
.44198 .65594 m .43899 .65168 L .36521 .63435 L p .573 .014 0 r
F P
0 g
s
.43899 .65168 m .44198 .65594 L .51722 .66229 L p .517 0 0 r
F P
0 g
s
.51751 .66542 m .51722 .66229 L .44198 .65594 L p .458 0 0 r
F P
0 g
s
.51722 .66229 m .51751 .66542 L .59035 .66141 L p .36 0 0 r
F P
0 g
s
.59035 .66141 m .59284 .65812 L .51722 .66229 L p .36 0 0 r
F P
0 g
s
.59284 .65812 m .59035 .66141 L .65997 .64742 L p .203 0 0 r
F P
0 g
s
.65997 .64742 m .66515 .64355 L .59284 .65812 L p .203 0 0 r
F P
0 g
s
.36521 .63435 m .37082 .63926 L .44198 .65594 L p .573 .014 0 r
F P
0 g
s
.44504 .65932 m .44198 .65594 L .37082 .63926 L p .505 0 0 r
F P
0 g
s
.44198 .65594 m .44504 .65932 L .51751 .66542 L p .458 0 0 r
F P
0 g
s
.67023 .63881 m .66515 .64355 L .73043 .61904 L p .048 0 0 r
F P
0 g
s
.73043 .61904 m .73799 .61332 L .67023 .63881 L p .048 0 0 r
F P
0 g
s
.51781 .66632 m .51751 .66542 L .44504 .65932 L p .205 0 0 r
F P
0 g
s
.51751 .66542 m .51781 .66632 L .58779 .66247 L p .108 0 0 r
F P
0 g
s
.58779 .66247 m .59035 .66141 L .51751 .66542 L p .108 0 0 r
F P
0 g
s
.37082 .63926 m .36521 .63435 L .29943 .6068 L p .569 0 0 r
F P
0 g
s
.59035 .66141 m .58779 .66247 L .65462 .64904 L p 0 0 0 r
F P
0 g
s
.65462 .64904 m .65997 .64742 L .59035 .66141 L p 0 0 0 r
F P
0 g
s
.37082 .63926 m .37655 .64329 L .44504 .65932 L p .505 0 0 r
F P
0 g
s
.44819 .66046 m .44504 .65932 L .37655 .64329 L p .228 0 0 r
F P
0 g
s
.44504 .65932 m .44819 .66046 L .51781 .66632 L p .205 0 0 r
F P
0 g
s
.66515 .64355 m .65997 .64742 L .72271 .62388 L p 0 0 0 r
F P
0 g
s
.72271 .62388 m .73043 .61904 L .66515 .64355 L p 0 0 0 r
F P
0 g
s
.51812 .66382 m .51781 .66632 L .44819 .66046 L p .367 .774 .983 r
F P
0 g
s
.51781 .66632 m .51812 .66382 L .58513 .66013 L p .422 .821 .982 r
F P
0 g
s
.58513 .66013 m .58779 .66247 L .51781 .66632 L p .422 .821 .982 r
F P
0 g
s
.29943 .6068 m .30748 .61277 L .37082 .63926 L p .569 0 0 r
F P
0 g
s
.37655 .64329 m .37082 .63926 L .30748 .61277 L p .481 0 0 r
F P
0 g
s
.58779 .66247 m .58513 .66013 L .64909 .64726 L p .502 .867 .985 r
F P
0 g
s
.64909 .64726 m .65462 .64904 L .58779 .66247 L p .502 .867 .985 r
F P
0 g
s
.37655 .64329 m .38245 .64508 L .44819 .66046 L p .228 0 0 r
F P
0 g
s
.45145 .65821 m .44819 .66046 L .38245 .64508 L p .345 .733 .985 r
F P
0 g
s
.44819 .66046 m .45145 .65821 L .51812 .66382 L p .367 .774 .983 r
F P
0 g
s
.65997 .64742 m .65462 .64904 L .71477 .62647 L p .294 .781 .716 r
F P
0 g
s
.71477 .62647 m .72271 .62388 L .65997 .64742 L p .294 .781 .716 r
F P
0 g
s
.51844 .65716 m .51812 .66382 L .45145 .65821 L p .648 .758 .93 r
F P
0 g
s
.51812 .66382 m .51844 .65716 L .58238 .65363 L p .65 .759 .93 r
F P
0 g
s
.58238 .65363 m .58513 .66013 L .51812 .66382 L p .65 .759 .93 r
F P
0 g
s
.73799 .61332 m .73043 .61904 L .78487 .58542 L p 0 0 0 r
F P
0 g
s
.78487 .58542 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.30748 .61277 m .31569 .61787 L .37655 .64329 L p .481 0 0 r
F P
0 g
s
.38245 .64508 m .37655 .64329 L .31569 .61787 L p 0 .396 .742 r
F P
0 g
s
.58513 .66013 m .58238 .65363 L .64336 .64129 L p .651 .76 .929 r
F P
0 g
s
.64336 .64129 m .64909 .64726 L .58513 .66013 L p .651 .76 .929 r
F P
0 g
s
.38245 .64508 m .38856 .64347 L .45145 .65821 L p .345 .733 .985 r
F P
0 g
s
.45483 .65178 m .45145 .65821 L .38856 .64347 L p .647 .757 .929 r
F P
0 g
s
.45145 .65821 m .45483 .65178 L .51844 .65716 L p .648 .758 .93 r
F P
0 g
s
.51877 .64606 m .51844 .65716 L .45483 .65178 L p .708 .684 .825 r
F P
0 g
s
.51844 .65716 m .51877 .64606 L .57953 .64268 L p .686 .666 .824 r
F P
0 g
s
.57953 .64268 m .58238 .65363 L .51844 .65716 L p .686 .666 .824 r
F P
0 g
s
.65462 .64904 m .64909 .64726 L .70656 .62564 L p .59 .902 .985 r
F P
0 g
s
.70656 .62564 m .71477 .62647 L .65462 .64904 L p .59 .902 .985 r
F P
0 g
s
.30748 .61277 m .29943 .6068 L .24558 .56996 L p .45 0 0 r
F P
0 g
s
.58238 .65363 m .57953 .64268 L .63743 .63088 L p .662 .651 .828 r
F P
0 g
s
.63743 .63088 m .64336 .64129 L .58238 .65363 L p .662 .651 .828 r
F P
0 g
s
.45483 .65178 m .45833 .64091 L .51877 .64606 L p .708 .684 .825 r
F P
0 g
s
.51911 .63082 m .51877 .64606 L .45833 .64091 L p .724 .64 .764 r
F P
0 g
s
.51877 .64606 m .51911 .63082 L .5766 .62758 L p .692 .613 .764 r
F P
0 g
s
.5766 .62758 m .57953 .64268 L .51877 .64606 L p .692 .613 .764 r
F P
0 g
s
.38856 .64347 m .39489 .63767 L .45483 .65178 L p .647 .757 .929 r
F P
0 g
s
.45833 .64091 m .45483 .65178 L .39489 .63767 L p .729 .706 .829 r
F P
0 g
s
.31569 .61787 m .32414 .62071 L .38245 .64508 L p 0 .396 .742 r
F P
0 g
s
.38856 .64347 m .38245 .64508 L .32414 .62071 L p .355 .7 .984 r
F P
0 g
s
.73043 .61904 m .72271 .62388 L .77491 .59164 L p 0 0 0 r
F P
0 g
s
.77491 .59164 m .78487 .58542 L .73043 .61904 L p 0 0 0 r
F P
0 g
s
.45833 .64091 m .46193 .6259 L .51911 .63082 L p .724 .64 .764 r
F P
0 g
s
.51946 .61228 m .51911 .63082 L .46193 .6259 L p .729 .616 .732 r
F P
0 g
s
.51911 .63082 m .51946 .61228 L .57362 .6092 L p .692 .585 .732 r
F P
0 g
s
.57362 .6092 m .5766 .62758 L .51911 .63082 L p .692 .585 .732 r
F P
0 g
s
.57953 .64268 m .5766 .62758 L .63135 .61632 L p .657 .59 .768 r
F P
0 g
s
.63135 .61632 m .63743 .63088 L .57953 .64268 L p .657 .59 .768 r
F P
0 g
s
.64909 .64726 m .64336 .64129 L .69806 .62061 L p .653 .761 .929 r
F P
0 g
s
.69806 .62061 m .70656 .62564 L .64909 .64726 L p .653 .761 .929 r
F P
0 g
s
.46193 .6259 m .4656 .60759 L .51946 .61228 L p .729 .616 .732 r
F P
0 g
s
.51981 .59177 m .51946 .61228 L .4656 .60759 L p .731 .605 .717 r
F P
0 g
s
.51946 .61228 m .51981 .59177 L .5706 .58884 L p .691 .572 .717 r
F P
0 g
s
.5706 .58884 m .57362 .6092 L .51946 .61228 L p .691 .572 .717 r
F P
0 g
s
.39489 .63767 m .40143 .62741 L .45833 .64091 L p .729 .706 .829 r
F P
0 g
s
.46193 .6259 m .45833 .64091 L .40143 .62741 L p .755 .672 .77 r
F P
0 g
s
.4656 .60759 m .4693 .58732 L .51981 .59177 L p .731 .605 .717 r
F P
0 g
s
.52016 .57089 m .51981 .59177 L .4693 .58732 L p .731 .603 .715 r
F P
0 g
s
.51981 .59177 m .52016 .57089 L .56758 .56812 L p .691 .57 .714 r
F P
0 g
s
.56758 .56812 m .5706 .58884 L .51981 .59177 L p .691 .57 .714 r
F P
0 g
s
.4693 .58732 m .47301 .56667 L .52016 .57089 L p .731 .603 .715 r
F P
0 g
s
.52051 .55135 m .52016 .57089 L .47301 .56667 L p .73 .611 .725 r
F P
0 g
s
.52016 .57089 m .52051 .55135 L .56457 .54874 L p .691 .579 .724 r
F P
0 g
s
.56457 .54874 m .56758 .56812 L .52016 .57089 L p .691 .579 .724 r
F P
0 g
s
.5766 .62758 m .57362 .6092 L .62515 .59847 L p .651 .557 .736 r
F P
0 g
s
.62515 .59847 m .63135 .61632 L .5766 .62758 L p .651 .557 .736 r
F P
0 g
s
.24558 .56996 m .25577 .57741 L .30748 .61277 L p .45 0 0 r
F P
0 g
s
.31569 .61787 m .30748 .61277 L .25577 .57741 L p 0 .203 .638 r
F P
0 g
s
.47301 .56667 m .47671 .54739 L .52051 .55135 L p .73 .611 .725 r
F P
0 g
s
.52086 .53479 m .52051 .55135 L .47671 .54739 L p .726 .631 .752 r
F P
0 g
s
.52051 .55135 m .52086 .53479 L .56159 .53236 L p .692 .603 .752 r
F P
0 g
s
.56159 .53236 m .56457 .54874 L .52051 .55135 L p .692 .603 .752 r
F P
0 g
s
.57362 .6092 m .5706 .58884 L .61889 .57866 L p .648 .542 .72 r
F P
0 g
s
.61889 .57866 m .62515 .59847 L .57362 .6092 L p .648 .542 .72 r
F P
0 g
s
.40143 .62741 m .40814 .61301 L .46193 .6259 L p .755 .672 .77 r
F P
0 g
s
.4656 .60759 m .46193 .6259 L .40814 .61301 L p .765 .652 .737 r
F P
0 g
s
.5706 .58884 m .56758 .56812 L .61262 .55849 L p .648 .54 .718 r
F P
0 g
s
.61262 .55849 m .61889 .57866 L .5706 .58884 L p .648 .54 .718 r
F P
0 g
s
.32414 .62071 m .33287 .62013 L .38856 .64347 L p .355 .7 .984 r
F P
0 g
s
.39489 .63767 m .38856 .64347 L .33287 .62013 L p .646 .755 .928 r
F P
0 g
s
.56758 .56812 m .56457 .54874 L .60639 .5397 L p .65 .55 .728 r
F P
0 g
s
.60639 .5397 m .61262 .55849 L .56758 .56812 L p .65 .55 .728 r
F P
0 g
s
.40814 .61301 m .41498 .59532 L .4656 .60759 L p .765 .652 .737 r
F P
0 g
s
.4693 .58732 m .4656 .60759 L .41498 .59532 L p .769 .642 .722 r
F P
0 g
s
.56457 .54874 m .56159 .53236 L .60022 .52392 L p .655 .578 .756 r
F P
0 g
s
.60022 .52392 m .60639 .5397 L .56457 .54874 L p .655 .578 .756 r
F P
0 g
s
.41498 .59532 m .42189 .57567 L .4693 .58732 L p .769 .642 .722 r
F P
0 g
s
.47301 .56667 m .4693 .58732 L .42189 .57567 L p .77 .641 .719 r
F P
0 g
s
.47671 .54739 m .48037 .53109 L .52086 .53479 L p .726 .631 .752 r
F P
0 g
s
.5212 .5226 m .52086 .53479 L .48037 .53109 L p .712 .674 .812 r
F P
0 g
s
.52086 .53479 m .5212 .5226 L .55865 .52035 L p .688 .655 .811 r
F P
0 g
s
.55865 .52035 m .56159 .53236 L .52086 .53479 L p .688 .655 .811 r
F P
0 g
s
.42189 .57567 m .4288 .55567 L .47301 .56667 L p .77 .641 .719 r
F P
0 g
s
.47671 .54739 m .47301 .56667 L .4288 .55567 L p .767 .647 .73 r
F P
0 g
s
.72271 .62388 m .71477 .62647 L .76468 .5956 L p .546 .928 .833 r
F P
0 g
s
.76468 .5956 m .77491 .59164 L .72271 .62388 L p .546 .928 .833 r
F P
0 g
s
.4288 .55567 m .43567 .53705 L .47671 .54739 L p .767 .647 .73 r
F P
0 g
s
.48037 .53109 m .47671 .54739 L .43567 .53705 L p .758 .664 .757 r
F P
0 g
s
.64336 .64129 m .63743 .63088 L .68928 .61112 L p .637 .639 .836 r
F P
0 g
s
.68928 .61112 m .69806 .62061 L .64336 .64129 L p .637 .639 .836 r
F P
0 g
s
.56159 .53236 m .55865 .52035 L .59413 .51254 L p .663 .638 .815 r
F P
0 g
s
.59413 .51254 m .60022 .52392 L .56159 .53236 L p .663 .638 .815 r
F P
0 g
s
.43567 .53705 m .44247 .52145 L .48037 .53109 L p .758 .664 .757 r
F P
0 g
s
.48398 .51918 m .48037 .53109 L .44247 .52145 L p .734 .698 .816 r
F P
0 g
s
.48037 .53109 m .48398 .51918 L .5212 .5226 L p .712 .674 .812 r
F P
0 g
s
.33287 .62013 m .34191 .61534 L .39489 .63767 L p .646 .755 .928 r
F P
0 g
s
.40143 .62741 m .39489 .63767 L .34191 .61534 L p .746 .732 .838 r
F P
0 g
s
.52154 .51576 m .5212 .5226 L .48398 .51918 L p .641 .761 .936 r
F P
0 g
s
.5212 .5226 m .52154 .51576 L .55574 .5137 L p .647 .766 .936 r
F P
0 g
s
.55574 .5137 m .55865 .52035 L .5212 .5226 L p .647 .766 .936 r
F P
0 g
s
.63743 .63088 m .63135 .61632 L .68028 .59747 L p .618 .57 .778 r
F P
0 g
s
.68028 .59747 m .68928 .61112 L .63743 .63088 L p .618 .57 .778 r
F P
0 g
s
.25577 .57741 m .26614 .58397 L .31569 .61787 L p 0 .203 .638 r
F P
0 g
s
.32414 .62071 m .31569 .61787 L .26614 .58397 L p 0 .442 .852 r
F P
0 g
s
.55865 .52035 m .55574 .5137 L .58812 .50654 L p .654 .77 .934 r
F P
0 g
s
.58812 .50654 m .59413 .51254 L .55865 .52035 L p .654 .77 .934 r
F P
0 g
s
.63135 .61632 m .62515 .59847 L .67113 .58054 L p .606 .532 .745 r
F P
0 g
s
.67113 .58054 m .68028 .59747 L .63135 .61632 L p .606 .532 .745 r
F P
0 g
s
.44247 .52145 m .44917 .51025 L .48398 .51918 L p .734 .698 .816 r
F P
0 g
s
.48755 .51262 m .48398 .51918 L .44917 .51025 L p .636 .755 .934 r
F P
0 g
s
.48398 .51918 m .48755 .51262 L .52154 .51576 L p .641 .761 .936 r
F P
0 g
s
.61889 .57866 m .61262 .55849 L .65267 .54245 L p .599 .511 .726 r
F P
0 g
s
.61262 .55849 m .60639 .5397 L .6435 .52464 L p .603 .523 .737 r
F P
0 g
s
.6435 .52464 m .65267 .54245 L .61262 .55849 L p .603 .523 .737 r
F P
0 g
s
.62515 .59847 m .61889 .57866 L .6619 .56166 L p .6 .514 .729 r
F P
0 g
s
.65267 .54245 m .6619 .56166 L .61889 .57866 L p .599 .511 .726 r
F P
0 g
s
.60639 .5397 m .60022 .52392 L .63444 .50988 L p .615 .556 .765 r
F P
0 g
s
.63444 .50988 m .6435 .52464 L .60639 .5397 L p .615 .556 .765 r
F P
0 g
s
.6619 .56166 m .67113 .58054 L .62515 .59847 L p .6 .514 .729 r
F P
0 g
s
.34191 .61534 m .35123 .60609 L .40143 .62741 L p .746 .732 .838 r
F P
0 g
s
.40814 .61301 m .40143 .62741 L .35123 .60609 L p .784 .708 .78 r
F P
0 g
s
.71477 .62647 m .70656 .62564 L .75411 .59612 L p .669 .916 .976 r
F P
0 g
s
.75411 .59612 m .76468 .5956 L .71477 .62647 L p .669 .916 .976 r
F P
0 g
s
.60022 .52392 m .59413 .51254 L .62552 .49956 L p .636 .626 .823 r
F P
0 g
s
.62552 .49956 m .63444 .50988 L .60022 .52392 L p .636 .626 .823 r
F P
0 g
s
.38031 .55734 m .39011 .53837 L .4288 .55567 L p .808 .685 .729 r
F P
0 g
s
.4288 .55567 m .42189 .57567 L .38031 .55734 L p .808 .685 .729 r
F P
0 g
s
.43567 .53705 m .4288 .55567 L .39011 .53837 L p .803 .69 .739 r
F P
0 g
s
.39011 .53837 m .39983 .52082 L .43567 .53705 L p .803 .69 .739 r
F P
0 g
s
.44247 .52145 m .43567 .53705 L .39983 .52082 L p .79 .702 .768 r
F P
0 g
s
.35123 .60609 m .36079 .59268 L .40814 .61301 L p .784 .708 .78 r
F P
0 g
s
.41498 .59532 m .40814 .61301 L .36079 .59268 L p .8 .693 .747 r
F P
0 g
s
.37051 .57598 m .38031 .55734 L .42189 .57567 L p .807 .686 .731 r
F P
0 g
s
.42189 .57567 m .41498 .59532 L .37051 .57598 L p .807 .686 .731 r
F P
0 g
s
.36079 .59268 m .37051 .57598 L .41498 .59532 L p .8 .693 .747 r
F P
0 g
s
.52188 .51478 m .52154 .51576 L .48755 .51262 L p .103 .644 .847 r
F P
0 g
s
.49109 .51194 m .52188 .51478 L p .50228 .51355 L .103 .644 .847 r
F P
0 g
s
.48755 .51262 m .49109 .51194 L p .50228 .51355 L .103 .644 .847 r
F P
0 g
s
.44917 .51025 m .4558 .50445 L .48755 .51262 L p .636 .755 .934 r
F P
0 g
s
.49109 .51194 m .48755 .51262 L .4558 .50445 L p .083 .601 .882 r
F P
0 g
s
.46236 .50453 m .49109 .51194 L p .47097 .50767 L .083 .601 .882 r
F P
0 g
s
.4558 .50445 m .46236 .50453 L p .47097 .50767 L .083 .601 .882 r
F P
0 g
s
.46236 .50453 m .4558 .50445 L .42823 .49165 L p .128 .582 .923 r
F P
0 g
s
.43747 .49296 m .46236 .50453 L p .44293 .4972 L .128 .582 .923 r
F P
0 g
s
.42823 .49165 m .43747 .49296 L p .44293 .4972 L .128 .582 .923 r
F P
0 g
s
.41805 .47786 m .43747 .49296 L p .41994 .48271 L .214 .572 .94 r
F P
0 g
s
.40665 .47493 m .41805 .47786 L p .41994 .48271 L .214 .572 .94 r
F P
0 g
s
.41805 .47786 m .40548 .4601 L p .41543 .47117 L 0 .238 .75 r
F P
0 g
s
.43747 .49296 m .41805 .47786 L p .42995 .48712 L .435 0 0 r
F P
0 g
s
.43747 .49296 m .42823 .49165 L .40665 .47493 L p .214 .572 .94 r
F P
0 g
s
.42936 .48667 m .44666 .50012 L p .42789 .48551 L .435 0 0 r
F P
0 g
s
.41805 .47786 m .42936 .48667 L p .42789 .48551 L .435 0 0 r
F P
0 g
s
.44666 .50012 m .43747 .49296 L p .42995 .48712 L .435 0 0 r
F P
0 g
s
.4558 .50445 m .44917 .51025 L .4189 .49627 L p .633 .748 .931 r
F P
0 g
s
.4189 .49627 m .42823 .49165 L .4558 .50445 L p .633 .748 .931 r
F P
0 g
s
.45588 .51247 m .44666 .50012 L .42936 .48667 L p .73 .213 0 r
F P
0 g
s
.42936 .48667 m .41824 .47089 L p .43121 .48811 L 0 0 .499 r
F P
0 g
s
.44069 .5007 m .45588 .51247 L p .43637 .49349 L .73 .213 0 r
F P
0 g
s
.42936 .48667 m .44069 .5007 L p .43637 .49349 L .73 .213 0 r
F P
0 g
s
.44069 .5007 m .42936 .48667 L p .43121 .48811 L 0 0 .499 r
F P
0 g
s
.40944 .50632 m .4189 .49627 L .44917 .51025 L p .753 .725 .826 r
F P
0 g
s
.43098 .48691 m .44069 .5007 L p .42419 .47879 L 0 0 .499 r
F P
0 g
s
.41824 .47089 m .43098 .48691 L p .42419 .47879 L 0 0 .499 r
F P
0 g
s
.43098 .48691 m .42753 .47199 L p .43887 .49636 L 0 .037 .606 r
F P
0 g
s
.44069 .5007 m .43098 .48691 L p .4457 .50908 L .643 .206 0 r
F P
0 g
s
.44917 .51025 m .44247 .52145 L .40944 .50632 L p .753 .725 .826 r
F P
0 g
s
.4521 .51872 m .44069 .5007 L p .4457 .50908 L .643 .206 0 r
F P
0 g
s
.46518 .52881 m .45588 .51247 L .44069 .5007 L p .817 .336 0 r
F P
0 g
s
.44069 .5007 m .4521 .51872 L .46518 .52881 L p .817 .336 0 r
F P
0 g
s
.4438 .50694 m .4521 .51872 L p .43442 .49209 L .643 .206 0 r
F P
0 g
s
.43098 .48691 m .4438 .50694 L p .43442 .49209 L .643 .206 0 r
F P
0 g
s
.46236 .50453 m .43747 .49296 L p .45053 .50022 L .575 0 0 r
F P
0 g
s
.43747 .49296 m .44666 .50012 L .4689 .51044 L p .575 0 0 r
F P
0 g
s
.46369 .539 m .4521 .51872 L .4438 .50694 L p .698 .265 0 r
F P
0 g
s
.4438 .50694 m .44092 .49421 L p .454 .5231 L 0 0 .564 r
F P
0 g
s
.4438 .50694 m .45677 .52921 L .46369 .539 L p .698 .265 0 r
F P
0 g
s
.45677 .52921 m .4438 .50694 L p .454 .5231 L 0 0 .564 r
F P
0 g
s
.4438 .50694 m .43098 .48691 L p .43887 .49636 L 0 .037 .606 r
F P
0 g
s
.42936 .48667 m .41805 .47786 L p .41543 .47117 L 0 .238 .75 r
F P
0 g
s
.4689 .51044 m .46236 .50453 L p .45053 .50022 L .575 0 0 r
F P
0 g
s
.49109 .51194 m .46236 .50453 L p .47574 .50973 L .583 .024 0 r
F P
0 g
s
.49462 .51705 m .49109 .51194 L p .47574 .50973 L .583 .024 0 r
F P
0 g
s
.52188 .51478 m .49109 .51194 L p .50398 .51511 L .524 0 0 r
F P
0 g
s
.52154 .51576 m .52188 .51478 L p .53495 .51454 L .191 .719 .843 r
F P
0 g
s
.55285 .51291 m .55574 .5137 L .52154 .51576 L p .191 .719 .843 r
F P
0 g
s
.52221 .5196 m .52188 .51478 L p .50398 .51511 L .524 0 0 r
F P
0 g
s
.52188 .51478 m .55285 .51291 L p .53495 .51454 L .191 .719 .843 r
F P
0 g
s
.39983 .52082 m .40944 .50632 L .44247 .52145 L p .79 .702 .768 r
F P
0 g
s
.55574 .5137 m .55285 .51291 L .58216 .50643 L p .339 .818 .873 r
F P
0 g
s
.58216 .50643 m .58812 .50654 L .55574 .5137 L p .339 .818 .873 r
F P
0 g
s
.59413 .51254 m .58812 .50654 L .61671 .49466 L p .661 .772 .932 r
F P
0 g
s
.61671 .49466 m .62552 .49956 L .59413 .51254 L p .661 .772 .932 r
F P
0 g
s
.79464 .57831 m .78487 .58542 L .82468 .54403 L p .645 .944 .709 r
F P
0 g
s
.82468 .54403 m .83625 .53514 L .79464 .57831 L p .645 .944 .709 r
F P
0 g
s
.26614 .58397 m .2768 .58827 L .32414 .62071 L p 0 .442 .852 r
F P
0 g
s
.33287 .62013 m .32414 .62071 L .2768 .58827 L p .386 .673 .973 r
F P
0 g
s
.70656 .62564 m .69806 .62061 L .74319 .59241 L p .655 .761 .928 r
F P
0 g
s
.74319 .59241 m .75411 .59612 L .70656 .62564 L p .655 .761 .928 r
F P
0 g
s
.58812 .50654 m .58216 .50643 L .60799 .49568 L p .513 .91 .915 r
F P
0 g
s
.60799 .49568 m .61671 .49466 L .58812 .50654 L p .513 .91 .915 r
F P
0 g
s
.69806 .62061 m .68928 .61112 L .73194 .58422 L p .609 .632 .849 r
F P
0 g
s
.73194 .58422 m .74319 .59241 L .69806 .62061 L p .609 .632 .849 r
F P
0 g
s
.2768 .58827 m .2878 .58911 L .33287 .62013 L p .386 .673 .973 r
F P
0 g
s
.34191 .61534 m .33287 .62013 L .2878 .58911 L p .646 .754 .928 r
F P
0 g
s
.65267 .54245 m .6435 .52464 L .67357 .50429 L p .548 .497 .751 r
F P
0 g
s
.6435 .52464 m .63444 .50988 L .66209 .49095 L p .568 .537 .78 r
F P
0 g
s
.66209 .49095 m .67357 .50429 L .6435 .52464 L p .568 .537 .78 r
F P
0 g
s
.52188 .51478 m .52221 .5196 L .54997 .51793 L p .42 0 0 r
F P
0 g
s
.54997 .51793 m .55285 .51291 L .52188 .51478 L p .42 0 0 r
F P
0 g
s
.25577 .57741 m .24558 .56996 L .20758 .52532 L p 0 .242 .742 r
F P
0 g
s
.63444 .50988 m .62552 .49956 L .65079 .48208 L p .606 .618 .837 r
F P
0 g
s
.65079 .48208 m .66209 .49095 L .63444 .50988 L p .606 .618 .837 r
F P
0 g
s
.6619 .56166 m .65267 .54245 L .68522 .52073 L p .541 .482 .74 r
F P
0 g
s
.67357 .50429 m .68522 .52073 L .65267 .54245 L p .548 .497 .751 r
F P
0 g
s
.78487 .58542 m .77491 .59164 L .81292 .55204 L p .682 .971 .775 r
F P
0 g
s
.81292 .55204 m .82468 .54403 L .78487 .58542 L p .682 .971 .775 r
F P
0 g
s
.55285 .51291 m .54997 .51793 L .57622 .51213 L p .26 0 0 r
F P
0 g
s
.57622 .51213 m .58216 .50643 L .55285 .51291 L p .26 0 0 r
F P
0 g
s
.67113 .58054 m .6619 .56166 L .69696 .53862 L p .542 .486 .743 r
F P
0 g
s
.68522 .52073 m .69696 .53862 L .6619 .56166 L p .541 .482 .74 r
F P
0 g
s
.68928 .61112 m .68028 .59747 L .72043 .57185 L p .575 .553 .793 r
F P
0 g
s
.72043 .57185 m .73194 .58422 L .68928 .61112 L p .575 .553 .793 r
F P
0 g
s
.49109 .51194 m .49462 .51705 L .52221 .5196 L p .524 0 0 r
F P
0 g
s
.68028 .59747 m .67113 .58054 L .70873 .55621 L p .553 .508 .759 r
F P
0 g
s
.69696 .53862 m .70873 .55621 L .67113 .58054 L p .542 .486 .743 r
F P
0 g
s
.35941 .51561 m .37149 .4995 L .39983 .52082 L p .839 .74 .755 r
F P
0 g
s
.39983 .52082 m .39011 .53837 L .35941 .51561 L p .839 .74 .755 r
F P
0 g
s
.40944 .50632 m .39983 .52082 L .37149 .4995 L p .819 .747 .784 r
F P
0 g
s
.62552 .49956 m .61671 .49466 L .63967 .47868 L p .668 .773 .928 r
F P
0 g
s
.63967 .47868 m .65079 .48208 L .62552 .49956 L p .668 .773 .928 r
F P
0 g
s
.70873 .55621 m .72043 .57185 L .68028 .59747 L p .553 .508 .759 r
F P
0 g
s
.37149 .4995 m .38341 .48649 L .40944 .50632 L p .819 .747 .784 r
F P
0 g
s
.4189 .49627 m .40944 .50632 L .38341 .48649 L p .769 .755 .84 r
F P
0 g
s
.2878 .58911 m .29916 .58572 L .34191 .61534 L p .646 .754 .928 r
F P
0 g
s
.35123 .60609 m .34191 .61534 L .29916 .58572 L p .761 .76 .852 r
F P
0 g
s
.34721 .53318 m .35941 .51561 L .39011 .53837 L p .846 .737 .743 r
F P
0 g
s
.39011 .53837 m .38031 .55734 L .34721 .53318 L p .846 .737 .743 r
F P
0 g
s
.33498 .55045 m .34721 .53318 L .38031 .55734 L p .845 .738 .746 r
F P
0 g
s
.38031 .55734 m .37051 .57598 L .33498 .55045 L p .845 .738 .746 r
F P
0 g
s
.38341 .48649 m .39512 .47797 L .4189 .49627 L p .769 .755 .84 r
F P
0 g
s
.42823 .49165 m .4189 .49627 L .39512 .47797 L p .631 .742 .927 r
F P
0 g
s
.29916 .58572 m .31086 .57784 L .35123 .60609 L p .761 .76 .852 r
F P
0 g
s
.36079 .59268 m .35123 .60609 L .31086 .57784 L p .811 .751 .797 r
F P
0 g
s
.58216 .50643 m .57622 .51213 L .59931 .50254 L p .011 0 0 r
F P
0 g
s
.59931 .50254 m .60799 .49568 L .58216 .50643 L p .011 0 0 r
F P
0 g
s
.32283 .56579 m .33498 .55045 L .37051 .57598 L p .834 .743 .763 r
F P
0 g
s
.37051 .57598 m .36079 .59268 L .32283 .56579 L p .834 .743 .763 r
F P
0 g
s
.31086 .57784 m .32283 .56579 L .36079 .59268 L p .811 .751 .797 r
F P
0 g
s
.20758 .52532 m .21945 .53464 L .25577 .57741 L p 0 .242 .742 r
F P
0 g
s
.26614 .58397 m .25577 .57741 L .21945 .53464 L p 0 .317 .799 r
F P
0 g
s
.61671 .49466 m .60799 .49568 L .62867 .48124 L p .668 .96 .939 r
F P
0 g
s
.62867 .48124 m .63967 .47868 L .61671 .49466 L p .668 .96 .939 r
F P
0 g
s
.46236 .50453 m .4689 .51044 L .49462 .51705 L p .583 .024 0 r
F P
0 g
s
.77491 .59164 m .76468 .5956 L .80085 .55775 L p .734 .987 .895 r
F P
0 g
s
.80085 .55775 m .81292 .55204 L .77491 .59164 L p .734 .987 .895 r
F P
0 g
s
.39512 .47797 m .40665 .47493 L .42823 .49165 L p .631 .742 .927 r
F P
0 g
s
.52255 .52956 m .52221 .5196 L .49462 .51705 L p .641 .201 .189 r
F P
0 g
s
.52221 .5196 m .52255 .52956 L .54708 .5281 L p .549 .127 .193 r
F P
0 g
s
.54708 .5281 m .54997 .51793 L .52221 .5196 L p .549 .127 .193 r
F P
0 g
s
.54997 .51793 m .54708 .5281 L .57025 .52301 L p .423 .014 .156 r
F P
0 g
s
.57025 .52301 m .57622 .51213 L .54997 .51793 L p .423 .014 .156 r
F P
0 g
s
.49817 .52733 m .49462 .51705 L .4689 .51044 L p .714 .248 .142 r
F P
0 g
s
.49462 .51705 m .49817 .52733 L .52255 .52956 L p .641 .201 .189 r
F P
0 g
s
.21945 .53464 m .23152 .54306 L .26614 .58397 L p 0 .317 .799 r
F P
0 g
s
.2768 .58827 m .26614 .58397 L .23152 .54306 L p .142 .482 .899 r
F P
0 g
s
.76468 .5956 m .75411 .59612 L .78842 .55998 L p .727 .908 .958 r
F P
0 g
s
.78842 .55998 m .80085 .55775 L .76468 .5956 L p .727 .908 .958 r
F P
0 g
s
.60799 .49568 m .59931 .50254 L .61775 .48968 L p 0 0 0 r
F P
0 g
s
.61775 .48968 m .62867 .48124 L .60799 .49568 L p 0 0 0 r
F P
0 g
s
.67357 .50429 m .66209 .49095 L .68122 .46814 L p .512 .521 .802 r
F P
0 g
s
.66209 .49095 m .65079 .48208 L .66819 .46107 L p .575 .614 .854 r
F P
0 g
s
.66819 .46107 m .68122 .46814 L .66209 .49095 L p .575 .614 .854 r
F P
0 g
s
.68522 .52073 m .67357 .50429 L .6945 .47974 L p .479 .472 .772 r
F P
0 g
s
.68122 .46814 m .6945 .47974 L .67357 .50429 L p .512 .521 .802 r
F P
0 g
s
.65079 .48208 m .63967 .47868 L .65539 .45952 L p .674 .771 .924 r
F P
0 g
s
.65539 .45952 m .66819 .46107 L .65079 .48208 L p .674 .771 .924 r
F P
0 g
s
.57622 .51213 m .57025 .52301 L .59061 .5146 L p .233 0 .061 r
F P
0 g
s
.59061 .5146 m .59931 .50254 L .57622 .51213 L p .233 0 .061 r
F P
0 g
s
.69696 .53862 m .68522 .52073 L .70799 .49447 L p .466 .453 .759 r
F P
0 g
s
.6945 .47974 m .70799 .49447 L .68522 .52073 L p .479 .472 .772 r
F P
0 g
s
.47547 .52153 m .4689 .51044 L .44666 .50012 L p .761 .262 .03 r
F P
0 g
s
.4689 .51044 m .47547 .52153 L .49817 .52733 L p .714 .248 .142 r
F P
0 g
s
.3527 .47423 m .36625 .46303 L .38341 .48649 L p .845 .8 .807 r
F P
0 g
s
.38341 .48649 m .37149 .4995 L .3527 .47423 L p .845 .8 .807 r
F P
0 g
s
.39512 .47797 m .38341 .48649 L .36625 .46303 L p .781 .788 .859 r
F P
0 g
s
.75411 .59612 m .74319 .59241 L .7756 .55796 L p .656 .761 .927 r
F P
0 g
s
.7756 .55796 m .78842 .55998 L .75411 .59612 L p .656 .761 .927 r
F P
0 g
s
.33893 .48858 m .3527 .47423 L .37149 .4995 L p .873 .802 .777 r
F P
0 g
s
.37149 .4995 m .35941 .51561 L .33893 .48858 L p .873 .802 .777 r
F P
0 g
s
.36625 .46303 m .37955 .45637 L .39512 .47797 L p .781 .788 .859 r
F P
0 g
s
.40665 .47493 m .39512 .47797 L .37955 .45637 L p .632 .736 .923 r
F P
0 g
s
.63967 .47868 m .62867 .48124 L .64276 .46396 L p .77 .957 .932 r
F P
0 g
s
.64276 .46396 m .65539 .45952 L .63967 .47868 L p .77 .957 .932 r
F P
0 g
s
.70873 .55621 m .69696 .53862 L .72163 .5107 L p .469 .457 .763 r
F P
0 g
s
.70799 .49447 m .72163 .5107 L .69696 .53862 L p .466 .453 .759 r
F P
0 g
s
.23152 .54306 m .24389 .54917 L .2768 .58827 L p .142 .482 .899 r
F P
0 g
s
.2878 .58911 m .2768 .58827 L .24389 .54917 L p .429 .652 .953 r
F P
0 g
s
.32499 .50442 m .33893 .48858 L .35941 .51561 L p .883 .802 .764 r
F P
0 g
s
.35941 .51561 m .34721 .53318 L .32499 .50442 L p .883 .802 .764 r
F P
0 g
s
.72043 .57185 m .70873 .55621 L .73532 .52665 L p .488 .485 .78 r
F P
0 g
s
.72163 .5107 m .73532 .52665 L .70873 .55621 L p .469 .457 .763 r
F P
0 g
s
.74319 .59241 m .73194 .58422 L .76243 .55141 L p .58 .63 .866 r
F P
0 g
s
.76243 .55141 m .7756 .55796 L .74319 .59241 L p .58 .63 .866 r
F P
0 g
s
.37955 .45637 m .39261 .45524 L .40665 .47493 L p .632 .736 .923 r
F P
0 g
s
.41805 .47786 m .40665 .47493 L .39261 .45524 L p .31 .564 .928 r
F P
0 g
s
.73194 .58422 m .72043 .57185 L .74896 .54067 L p .523 .54 .814 r
F P
0 g
s
.73532 .52665 m .74896 .54067 L .72043 .57185 L p .488 .485 .78 r
F P
0 g
s
.74896 .54067 m .76243 .55141 L .73194 .58422 L p .523 .54 .814 r
F P
0 g
s
.52289 .54348 m .52255 .52956 L .49817 .52733 L p .672 .271 .278 r
F P
0 g
s
.52255 .52956 m .52289 .54348 L .54415 .54222 L p .585 .201 .281 r
F P
0 g
s
.54415 .54222 m .54708 .5281 L .52255 .52956 L p .585 .201 .281 r
F P
0 g
s
.59931 .50254 m .59061 .5146 L .60681 .50334 L p 0 0 0 r
F P
0 g
s
.60681 .50334 m .61775 .48968 L .59931 .50254 L p 0 0 0 r
F P
0 g
s
.31098 .52 m .32499 .50442 L .34721 .53318 L p .881 .802 .767 r
F P
0 g
s
.34721 .53318 m .33498 .55045 L .31098 .52 L p .881 .802 .767 r
F P
0 g
s
.24389 .54917 m .25663 .55181 L .2878 .58911 L p .429 .652 .953 r
F P
0 g
s
.29916 .58572 m .2878 .58911 L .25663 .55181 L p .646 .752 .926 r
F P
0 g
s
.54708 .5281 m .54415 .54222 L .56422 .53785 L p .472 .101 .253 r
F P
0 g
s
.56422 .53785 m .57025 .52301 L .54708 .5281 L p .472 .101 .253 r
F P
0 g
s
.62867 .48124 m .61775 .48968 L .63024 .47431 L p .71 .967 .721 r
F P
0 g
s
.63024 .47431 m .64276 .46396 L .62867 .48124 L p .71 .967 .721 r
F P
0 g
s
.50177 .54156 m .49817 .52733 L .47547 .52153 L p .745 .321 .243 r
F P
0 g
s
.49817 .52733 m .50177 .54156 L .52289 .54348 L p .672 .271 .278 r
F P
0 g
s
.44666 .50012 m .45588 .51247 L .47547 .52153 L p .761 .262 .03 r
F P
0 g
s
.29703 .53365 m .31098 .52 L .33498 .55045 L p .866 .802 .786 r
F P
0 g
s
.33498 .55045 m .32283 .56579 L .29703 .53365 L p .866 .802 .786 r
F P
0 g
s
.83625 .53514 m .82468 .54403 L .84629 .49686 L p .853 .997 .815 r
F P
0 g
s
.84629 .49686 m .85906 .48583 L .83625 .53514 L p .853 .997 .815 r
F P
0 g
s
.25663 .55181 m .26976 .55017 L .29916 .58572 L p .646 .752 .926 r
F P
0 g
s
.31086 .57784 m .29916 .58572 L .26976 .55017 L p .77 .79 .87 r
F P
0 g
s
.39261 .45524 m .40548 .4601 L .41805 .47786 L p .31 .564 .928 r
F P
0 g
s
.28326 .54401 m .29703 .53365 L .32283 .56579 L p .834 .801 .82 r
F P
0 g
s
.32283 .56579 m .31086 .57784 L .28326 .54401 L p .834 .801 .82 r
F P
0 g
s
.26976 .55017 m .28326 .54401 L .31086 .57784 L p .77 .79 .87 r
F P
0 g
s
.57025 .52301 m .56422 .53785 L .58181 .53063 L p .306 0 .181 r
F P
0 g
s
.58181 .53063 m .59061 .5146 L .57025 .52301 L p .306 0 .181 r
F P
0 g
s
.48211 .53657 m .47547 .52153 L .45588 .51247 L p .806 .351 .157 r
F P
0 g
s
.47547 .52153 m .48211 .53657 L .50177 .54156 L p .745 .321 .243 r
F P
0 g
s
.68122 .46814 m .66819 .46107 L .6763 .43777 L p .541 .617 .877 r
F P
0 g
s
.66819 .46107 m .65539 .45952 L .6626 .43831 L p .679 .768 .919 r
F P
0 g
s
.6626 .43831 m .6763 .43777 L .66819 .46107 L p .679 .768 .919 r
F P
0 g
s
.6945 .47974 m .68122 .46814 L .69027 .44279 L p .443 .508 .831 r
F P
0 g
s
.6763 .43777 m .69027 .44279 L .68122 .46814 L p .541 .617 .877 r
F P
0 g
s
.82468 .54403 m .81292 .55204 L .83334 .50698 L p .85 .992 .844 r
F P
0 g
s
.83334 .50698 m .84629 .49686 L .82468 .54403 L p .85 .992 .844 r
F P
0 g
s
.61775 .48968 m .60681 .50334 L .61773 .4899 L p 0 0 0 r
F P
0 g
s
.61773 .4899 m .63024 .47431 L .61775 .48968 L p 0 0 0 r
F P
0 g
s
.65539 .45952 m .64276 .46396 L .64913 .44487 L p .817 .917 .905 r
F P
0 g
s
.64913 .44487 m .6626 .43831 L .65539 .45952 L p .817 .917 .905 r
F P
0 g
s
.70799 .49447 m .6945 .47974 L .70453 .45238 L p .386 .444 .799 r
F P
0 g
s
.69027 .44279 m .70453 .45238 L .6945 .47974 L p .443 .508 .831 r
F P
0 g
s
.21945 .53464 m .20758 .52532 L .18911 .47507 L p .094 .353 .822 r
F P
0 g
s
.35946 .43735 m .37351 .43278 L .37955 .45637 L p .785 .823 .882 r
F P
0 g
s
.37955 .45637 m .36625 .46303 L .35946 .43735 L p .785 .823 .882 r
F P
0 g
s
.39261 .45524 m .37955 .45637 L .37351 .43278 L p .635 .731 .917 r
F P
0 g
s
.59061 .5146 m .58181 .53063 L .59578 .52098 L p .029 0 .026 r
F P
0 g
s
.59578 .52098 m .60681 .50334 L .59061 .5146 L p .029 0 .026 r
F P
0 g
s
.34511 .4465 m .35946 .43735 L .36625 .46303 L p .863 .862 .837 r
F P
0 g
s
.36625 .46303 m .3527 .47423 L .34511 .4465 L p .863 .862 .837 r
F P
0 g
s
.40548 .4601 m .41824 .47089 L .42936 .48667 L p 0 .238 .75 r
F P
0 g
s
.45588 .51247 m .46518 .52881 L .48211 .53657 L p .806 .351 .157 r
F P
0 g
s
.37351 .43278 m .38728 .43377 L .39261 .45524 L p .635 .731 .917 r
F P
0 g
s
.40548 .4601 m .39261 .45524 L .38728 .43377 L p .397 .56 .898 r
F P
0 g
s
.72163 .5107 m .70799 .49447 L .71906 .46515 L p .363 .419 .785 r
F P
0 g
s
.70453 .45238 m .71906 .46515 L .70799 .49447 L p .386 .444 .799 r
F P
0 g
s
.33048 .45884 m .34511 .4465 L .3527 .47423 L p .899 .876 .805 r
F P
0 g
s
.3527 .47423 m .33893 .48858 L .33048 .45884 L p .899 .876 .805 r
F P
0 g
s
.64276 .46396 m .63024 .47431 L .6358 .45738 L p .886 .987 .804 r
F P
0 g
s
.6358 .45738 m .64913 .44487 L .64276 .46396 L p .886 .987 .804 r
F P
0 g
s
.52324 .55963 m .52289 .54348 L .50177 .54156 L p .681 .295 .308 r
F P
0 g
s
.52289 .54348 m .52324 .55963 L .54117 .55857 L p .596 .226 .311 r
F P
0 g
s
.54117 .55857 m .54415 .54222 L .52289 .54348 L p .596 .226 .311 r
F P
0 g
s
.81292 .55204 m .80085 .55775 L .82009 .51478 L p .827 .962 .897 r
F P
0 g
s
.82009 .51478 m .83334 .50698 L .81292 .55204 L p .827 .962 .897 r
F P
0 g
s
.54415 .54222 m .54117 .55857 L .55807 .55493 L p .488 .131 .286 r
F P
0 g
s
.55807 .55493 m .56422 .53785 L .54415 .54222 L p .488 .131 .286 r
F P
0 g
s
.50543 .55803 m .50177 .54156 L .48211 .53657 L p .754 .346 .277 r
F P
0 g
s
.50177 .54156 m .50543 .55803 L .52324 .55963 L p .681 .295 .308 r
F P
0 g
s
.18911 .47507 m .20203 .48658 L .21945 .53464 L p .094 .353 .822 r
F P
0 g
s
.23152 .54306 m .21945 .53464 L .20203 .48658 L p .153 .4 .846 r
F P
0 g
s
.38728 .43377 m .40081 .4408 L .40548 .4601 L p .397 .56 .898 r
F P
0 g
s
.41824 .47089 m .40548 .4601 L .40081 .4408 L p .126 .343 .807 r
F P
0 g
s
.73532 .52665 m .72163 .5107 L .73379 .47944 L p .369 .425 .788 r
F P
0 g
s
.71906 .46515 m .73379 .47944 L .72163 .5107 L p .363 .419 .785 r
F P
0 g
s
.31564 .47271 m .33048 .45884 L .33893 .48858 L p .912 .88 .79 r
F P
0 g
s
.33893 .48858 m .32499 .50442 L .31564 .47271 L p .912 .88 .79 r
F P
0 g
s
.56422 .53785 m .55807 .55493 L .57287 .54891 L p .331 0 .221 r
F P
0 g
s
.57287 .54891 m .58181 .53063 L .56422 .53785 L p .331 0 .221 r
F P
0 g
s
.48888 .55386 m .48211 .53657 L .46518 .52881 L p .818 .38 .2 r
F P
0 g
s
.48211 .53657 m .48888 .55386 L .50543 .55803 L p .754 .346 .277 r
F P
0 g
s
.60681 .50334 m .59578 .52098 L .60514 .50949 L p 0 0 0 r
F P
0 g
s
.60514 .50949 m .61773 .4899 L .60681 .50334 L p 0 0 0 r
F P
0 g
s
.80085 .55775 m .78842 .55998 L .80646 .51905 L p .761 .883 .933 r
F P
0 g
s
.80646 .51905 m .82009 .51478 L .80085 .55775 L p .761 .883 .933 r
F P
0 g
s
.74896 .54067 m .73532 .52665 L .74862 .49348 L p .401 .462 .808 r
F P
0 g
s
.73379 .47944 m .74862 .49348 L .73532 .52665 L p .369 .425 .788 r
F P
0 g
s
.63024 .47431 m .61773 .4899 L .62252 .47513 L p .881 .975 .669 r
F P
0 g
s
.62252 .47513 m .6358 .45738 L .63024 .47431 L p .881 .975 .669 r
F P
0 g
s
.30069 .48632 m .31564 .47271 L .32499 .50442 L p .909 .879 .794 r
F P
0 g
s
.32499 .50442 m .31098 .52 L .30069 .48632 L p .909 .879 .794 r
F P
0 g
s
.20203 .48658 m .21513 .49717 L .23152 .54306 L p .153 .4 .846 r
F P
0 g
s
.24389 .54917 m .23152 .54306 L .21513 .49717 L p .291 .506 .892 r
F P
0 g
s
.78842 .55998 m .7756 .55796 L .79244 .51902 L p .658 .76 .926 r
F P
0 g
s
.79244 .51902 m .80646 .51905 L .78842 .55998 L p .658 .76 .926 r
F P
0 g
s
.40081 .4408 m .4142 .45377 L .41824 .47089 L p .126 .343 .807 r
F P
0 g
s
.43098 .48691 m .41824 .47089 L .4142 .45377 L p 0 .156 .693 r
F P
0 g
s
.76243 .55141 m .74896 .54067 L .76342 .5056 L p .461 .531 .843 r
F P
0 g
s
.74862 .49348 m .76342 .5056 L .74896 .54067 L p .401 .462 .808 r
F P
0 g
s
.58181 .53063 m .57287 .54891 L .58458 .54087 L p .068 0 .081 r
F P
0 g
s
.58458 .54087 m .59578 .52098 L .58181 .53063 L p .068 0 .081 r
F P
0 g
s
.69027 .44279 m .6763 .43777 L .67419 .41367 L p .505 .626 .904 r
F P
0 g
s
.6763 .43777 m .6626 .43831 L .66052 .41642 L p .682 .764 .913 r
F P
0 g
s
.66052 .41642 m .67419 .41367 L .6763 .43777 L p .682 .764 .913 r
F P
0 g
s
.7756 .55796 m .76243 .55141 L .77807 .51442 L p .549 .633 .887 r
F P
0 g
s
.77807 .51442 m .79244 .51902 L .7756 .55796 L p .549 .633 .887 r
F P
0 g
s
.6626 .43831 m .64913 .44487 L .64711 .42523 L p .828 .865 .873 r
F P
0 g
s
.64711 .42523 m .66052 .41642 L .6626 .43831 L p .828 .865 .873 r
F P
0 g
s
.76342 .5056 m .77807 .51442 L .76243 .55141 L p .461 .531 .843 r
F P
0 g
s
.47464 .54739 m .46518 .52881 L .4521 .51872 L p .843 .377 .037 r
F P
0 g
s
.46518 .52881 m .47464 .54739 L .48888 .55386 L p .818 .38 .2 r
F P
0 g
s
.28576 .49802 m .30069 .48632 L .31098 .52 L p .889 .873 .815 r
F P
0 g
s
.31098 .52 m .29703 .53365 L .28576 .49802 L p .889 .873 .815 r
F P
0 g
s
.70453 .45238 m .69027 .44279 L .68817 .4165 L p .352 .497 .864 r
F P
0 g
s
.67419 .41367 m .68817 .4165 L .69027 .44279 L p .505 .626 .904 r
F P
0 g
s
.21513 .49717 m .22853 .50543 L .24389 .54917 L p .291 .506 .892 r
F P
0 g
s
.25663 .55181 m .24389 .54917 L .22853 .50543 L p .474 .638 .927 r
F P
0 g
s
.64913 .44487 m .6358 .45738 L .63387 .43999 L p .916 .912 .801 r
F P
0 g
s
.63387 .43999 m .64711 .42523 L .64913 .44487 L p .916 .912 .801 r
F P
0 g
s
.36394 .41109 m .37779 .40872 L .37351 .43278 L p .777 .857 .91 r
F P
0 g
s
.37351 .43278 m .35946 .43735 L .36394 .41109 L p .777 .857 .91 r
F P
0 g
s
.38728 .43377 m .37351 .43278 L .37779 .40872 L p .638 .727 .912 r
F P
0 g
s
.37779 .40872 m .39133 .41193 L .38728 .43377 L p .638 .727 .912 r
F P
0 g
s
.40081 .4408 m .38728 .43377 L .39133 .41193 L p .469 .561 .866 r
F P
0 g
s
.27098 .50641 m .28576 .49802 L .29703 .53365 L p .848 .858 .849 r
F P
0 g
s
.29703 .53365 m .28326 .54401 L .27098 .50641 L p .848 .858 .849 r
F P
0 g
s
.5236 .57592 m .52324 .55963 L .50543 .55803 L p .68 .292 .305 r
F P
0 g
s
.52324 .55963 m .5236 .57592 L .53811 .57508 L p .595 .223 .308 r
F P
0 g
s
.53811 .57508 m .54117 .55857 L .52324 .55963 L p .595 .223 .308 r
F P
0 g
s
.22853 .50543 m .2423 .51017 L .25663 .55181 L p .474 .638 .927 r
F P
0 g
s
.26976 .55017 m .25663 .55181 L .2423 .51017 L p .647 .751 .925 r
F P
0 g
s
.61773 .4899 m .60514 .50949 L .60918 .49689 L p .852 .938 .567 r
F P
0 g
s
.60918 .49689 m .62252 .47513 L .61773 .4899 L p .852 .938 .567 r
F P
0 g
s
.71906 .46515 m .70453 .45238 L .70248 .42394 L p .253 .411 .827 r
F P
0 g
s
.68817 .4165 m .70248 .42394 L .70453 .45238 L p .352 .497 .864 r
F P
0 g
s
.54117 .55857 m .53811 .57508 L .55178 .57215 L p .486 .127 .282 r
F P
0 g
s
.55178 .57215 m .55807 .55493 L .54117 .55857 L p .486 .127 .282 r
F P
0 g
s
.34975 .41808 m .36394 .41109 L .35946 .43735 L p .859 .927 .871 r
F P
0 g
s
.35946 .43735 m .34511 .4465 L .34975 .41808 L p .859 .927 .871 r
F P
0 g
s
.50918 .57464 m .50543 .55803 L .48888 .55386 L p .753 .343 .273 r
F P
0 g
s
.50543 .55803 m .50918 .57464 L .5236 .57592 L p .68 .292 .305 r
F P
0 g
s
.25646 .51058 m .27098 .50641 L .28326 .54401 L p .772 .822 .892 r
F P
0 g
s
.28326 .54401 m .26976 .55017 L .25646 .51058 L p .772 .822 .892 r
F P
0 g
s
.39133 .41193 m .40461 .42121 L .40081 .4408 L p .469 .561 .866 r
F P
0 g
s
.4142 .45377 m .40081 .4408 L .40461 .42121 L p .316 .406 .796 r
F P
0 g
s
.2423 .51017 m .25646 .51058 L .26976 .55017 L p .647 .751 .925 r
F P
0 g
s
.59578 .52098 m .58458 .54087 L .59238 .53133 L p 0 0 0 r
F P
0 g
s
.59238 .53133 m .60514 .50949 L .59578 .52098 L p 0 0 0 r
F P
0 g
s
.4142 .45377 m .42753 .47199 L .43098 .48691 L p 0 .156 .693 r
F P
0 g
s
.4521 .51872 m .46369 .539 L .47464 .54739 L p .843 .377 .037 r
F P
0 g
s
.55807 .55493 m .55178 .57215 L .56373 .56734 L p .328 0 .217 r
F P
0 g
s
.56373 .56734 m .57287 .54891 L .55807 .55493 L p .328 0 .217 r
F P
0 g
s
.6358 .45738 m .62252 .47513 L .6207 .46 L p .956 .924 .731 r
F P
0 g
s
.6207 .46 m .63387 .43999 L .6358 .45738 L p .956 .924 .731 r
F P
0 g
s
.49579 .5713 m .48888 .55386 L .47464 .54739 L p .817 .377 .195 r
F P
0 g
s
.48888 .55386 m .49579 .5713 L .50918 .57464 L p .753 .343 .273 r
F P
0 g
s
.33525 .42828 m .34975 .41808 L .34511 .4465 L p .896 .955 .831 r
F P
0 g
s
.34511 .4465 m .33048 .45884 L .33525 .42828 L p .896 .955 .831 r
F P
0 g
s
.73379 .47944 m .71906 .46515 L .71709 .43459 L p .211 .373 .808 r
F P
0 g
s
.70248 .42394 m .71709 .43459 L .71906 .46515 L p .253 .411 .827 r
F P
0 g
s
.40461 .42121 m .41772 .43643 L .4142 .45377 L p .316 .406 .796 r
F P
0 g
s
.42753 .47199 m .4142 .45377 L .41772 .43643 L p .205 .292 .733 r
F P
0 g
s
.57287 .54891 m .56373 .56734 L .57315 .56092 L p .064 0 .075 r
F P
0 g
s
.57315 .56092 m .58458 .54087 L .57287 .54891 L p .064 0 .075 r
F P
0 g
s
.48431 .56612 m .47464 .54739 L .46369 .539 L p .84 .373 .03 r
F P
0 g
s
.47464 .54739 m .48431 .56612 L .49579 .5713 L p .817 .377 .195 r
F P
0 g
s
.3205 .44003 m .33525 .42828 L .33048 .45884 L p .907 .963 .811 r
F P
0 g
s
.33048 .45884 m .31564 .47271 L .3205 .44003 L p .907 .963 .811 r
F P
0 g
s
.60514 .50949 m .59238 .53133 L .5957 .52088 L p .834 .916 .518 r
F P
0 g
s
.5957 .52088 m .60918 .49689 L .60514 .50949 L p .834 .916 .518 r
F P
0 g
s
.74862 .49348 m .73379 .47944 L .73194 .44679 L p .222 .383 .813 r
F P
0 g
s
.71709 .43459 m .73194 .44679 L .73379 .47944 L p .211 .373 .808 r
F P
0 g
s
.85906 .48583 m .84629 .49686 L .84669 .4466 L p .904 .934 .822 r
F P
0 g
s
.84669 .4466 m .85986 .43317 L .85906 .48583 L p .904 .934 .822 r
F P
0 g
s
.62252 .47513 m .60918 .49689 L .60752 .48401 L p .972 .922 .682 r
F P
0 g
s
.60752 .48401 m .6207 .46 L .62252 .47513 L p .972 .922 .682 r
F P
0 g
s
.67419 .41367 m .66052 .41642 L .64896 .39538 L p .683 .758 .909 r
F P
0 g
s
.66052 .41642 m .64711 .42523 L .63656 .40639 L p .82 .813 .844 r
F P
0 g
s
.63656 .40639 m .64896 .39538 L .66052 .41642 L p .82 .813 .844 r
F P
0 g
s
.68817 .4165 m .67419 .41367 L .66162 .39044 L p .47 .643 .932 r
F P
0 g
s
.64896 .39538 m .66162 .39044 L .67419 .41367 L p .683 .758 .909 r
F P
0 g
s
.42753 .47199 m .44092 .49421 L .4438 .50694 L p 0 .037 .606 r
F P
0 g
s
.64711 .42523 m .63387 .43999 L .62435 .42335 L p .892 .828 .777 r
F P
0 g
s
.62435 .42335 m .63656 .40639 L .64711 .42523 L p .892 .828 .777 r
F P
0 g
s
.41772 .43643 m .43074 .45691 L .42753 .47199 L p .205 .292 .733 r
F P
0 g
s
.44092 .49421 m .42753 .47199 L .43074 .45691 L p .139 .223 .689 r
F P
0 g
s
.58458 .54087 m .57315 .56092 L .5794 .55331 L p 0 0 0 r
F P
0 g
s
.5794 .55331 m .59238 .53133 L .58458 .54087 L p 0 0 0 r
F P
0 g
s
.3925 .38589 m .40483 .39126 L .39133 .41193 L p .643 .725 .908 r
F P
0 g
s
.39133 .41193 m .37779 .40872 L .3925 .38589 L p .643 .725 .908 r
F P
0 g
s
.40461 .42121 m .39133 .41193 L .40483 .39126 L p .527 .566 .838 r
F P
0 g
s
.52396 .59008 m .5236 .57592 L .50918 .57464 L p .667 .261 .265 r
F P
0 g
s
.5236 .57592 m .52396 .59008 L .53497 .58944 L p .58 .19 .268 r
F P
0 g
s
.53497 .58944 m .53811 .57508 L .5236 .57592 L p .58 .19 .268 r
F P
0 g
s
.40483 .39126 m .41689 .40271 L .40461 .42121 L p .527 .566 .838 r
F P
0 g
s
.41772 .43643 m .40461 .42121 L .41689 .40271 L p .439 .449 .772 r
F P
0 g
s
.84629 .49686 m .83334 .50698 L .83336 .45908 L p .891 .926 .838 r
F P
0 g
s
.83336 .45908 m .84669 .4466 L .84629 .49686 L p .891 .926 .838 r
F P
0 g
s
.30561 .45155 m .3205 .44003 L .31564 .47271 L p .905 .961 .816 r
F P
0 g
s
.31564 .47271 m .30069 .48632 L .30561 .45155 L p .905 .961 .816 r
F P
0 g
s
.70248 .42394 m .68817 .4165 L .6746 .3911 L p .234 .488 .893 r
F P
0 g
s
.66162 .39044 m .6746 .3911 L .68817 .4165 L p .47 .643 .932 r
F P
0 g
s
.4755 .55942 m .46369 .539 L .45677 .52921 L p .692 .258 0 r
F P
0 g
s
.46369 .539 m .4755 .55942 L .48431 .56612 L p .84 .373 .03 r
F P
0 g
s
.37986 .38612 m .3925 .38589 L .37779 .40872 L p .754 .885 .938 r
F P
0 g
s
.37779 .40872 m .36394 .41109 L .37986 .38612 L p .754 .885 .938 r
F P
0 g
s
.53811 .57508 m .53497 .58944 L .54533 .58725 L p .465 .088 .239 r
F P
0 g
s
.54533 .58725 m .55178 .57215 L .53811 .57508 L p .465 .088 .239 r
F P
0 g
s
.76342 .5056 m .74862 .49348 L .74694 .45874 L p .281 .436 .839 r
F P
0 g
s
.73194 .44679 m .74694 .45874 L .74862 .49348 L p .222 .383 .813 r
F P
0 g
s
.51303 .58911 m .50918 .57464 L .49579 .5713 L p .741 .31 .228 r
F P
0 g
s
.50918 .57464 m .51303 .58911 L .52396 .59008 L p .667 .261 .265 r
F P
0 g
s
.63387 .43999 m .6207 .46 L .61224 .44556 L p .928 .829 .728 r
F P
0 g
s
.61224 .44556 m .62435 .42335 L .63387 .43999 L p .928 .829 .728 r
F P
0 g
s
.55178 .57215 m .54533 .58725 L .55437 .58363 L p .296 0 .163 r
F P
0 g
s
.55437 .58363 m .56373 .56734 L .55178 .57215 L p .296 0 .163 r
F P
0 g
s
.41689 .40271 m .42877 .4201 L .41772 .43643 L p .439 .449 .772 r
F P
0 g
s
.43074 .45691 m .41772 .43643 L .42877 .4201 L p .382 .373 .725 r
F P
0 g
s
.20203 .48658 m .18911 .47507 L .19318 .42214 L p .295 .42 .818 r
F P
0 g
s
.50289 .58661 m .49579 .5713 L .48431 .56612 L p .8 .338 .138 r
F P
0 g
s
.49579 .5713 m .50289 .58661 L .51303 .58911 L p .741 .31 .228 r
F P
0 g
s
.36688 .39098 m .37986 .38612 L .36394 .41109 L p .809 .978 .897 r
F P
0 g
s
.36394 .41109 m .34975 .41808 L .36688 .39098 L p .809 .978 .897 r
F P
0 g
s
.83334 .50698 m .82009 .51478 L .81976 .4692 L p .851 .902 .871 r
F P
0 g
s
.81976 .4692 m .83336 .45908 L .83334 .50698 L p .851 .902 .871 r
F P
0 g
s
.60918 .49689 m .5957 .52088 L .59422 .51023 L p .977 .919 .659 r
F P
0 g
s
.59422 .51023 m .60752 .48401 L .60918 .49689 L p .977 .919 .659 r
F P
0 g
s
.77807 .51442 m .76342 .5056 L .76194 .46877 L p .383 .527 .877 r
F P
0 g
s
.74694 .45874 m .76194 .46877 L .76342 .5056 L p .281 .436 .839 r
F P
0 g
s
.71709 .43459 m .70248 .42394 L .68791 .39639 L p .061 .362 .832 r
F P
0 g
s
.6746 .3911 m .68791 .39639 L .70248 .42394 L p .234 .488 .893 r
F P
0 g
s
.29069 .46113 m .30561 .45155 L .30069 .48632 L p .886 .949 .844 r
F P
0 g
s
.30069 .48632 m .28576 .49802 L .29069 .46113 L p .886 .949 .844 r
F P
0 g
s
.59238 .53133 m .5794 .55331 L .58201 .545 L p .836 .919 .524 r
F P
0 g
s
.58201 .545 m .5957 .52088 L .59238 .53133 L p .836 .919 .524 r
F P
0 g
s
.43074 .45691 m .44378 .48138 L .44092 .49421 L p .139 .223 .689 r
F P
0 g
s
.45444 .51867 m .44092 .49421 L .44378 .48138 L p .109 .192 .669 r
F P
0 g
s
.44092 .49421 m .45444 .51867 L .45677 .52921 L p 0 0 .564 r
F P
0 g
s
.56373 .56734 m .55437 .58363 L .56147 .57882 L p .013 0 .002 r
F P
0 g
s
.56147 .57882 m .57315 .56092 L .56373 .56734 L p .013 0 .002 r
F P
0 g
s
.6207 .46 m .60752 .48401 L .60014 .47174 L p .945 .826 .697 r
F P
0 g
s
.60014 .47174 m .61224 .44556 L .6207 .46 L p .945 .826 .697 r
F P
0 g
s
.49421 .58272 m .48431 .56612 L .4755 .55942 L p .805 .317 0 r
F P
0 g
s
.48431 .56612 m .49421 .58272 L .50289 .58661 L p .8 .338 .138 r
F P
0 g
s
.82009 .51478 m .80646 .51905 L .8058 .47574 L p .775 .849 .907 r
F P
0 g
s
.8058 .47574 m .81976 .4692 L .82009 .51478 L p .775 .849 .907 r
F P
0 g
s
.19318 .42214 m .20631 .43608 L .20203 .48658 L p .295 .42 .818 r
F P
0 g
s
.21513 .49717 m .20203 .48658 L .20631 .43608 L p .327 .45 .833 r
F P
0 g
s
.45677 .52921 m .46998 .55162 L .4755 .55942 L p .692 .258 0 r
F P
0 g
s
.46998 .55162 m .45677 .52921 L .45444 .51867 L p 0 0 .569 r
F P
0 g
s
.79244 .51902 m .77807 .51442 L .77683 .47547 L p .517 .643 .911 r
F P
0 g
s
.76194 .46877 m .77683 .47547 L .77807 .51442 L p .383 .527 .877 r
F P
0 g
s
.42877 .4201 m .44055 .44274 L .43074 .45691 L p .382 .373 .725 r
F P
0 g
s
.44378 .48138 m .43074 .45691 L .44055 .44274 L p .348 .329 .696 r
F P
0 g
s
.80646 .51905 m .79244 .51902 L .79148 .47792 L p .658 .759 .924 r
F P
0 g
s
.79148 .47792 m .8058 .47574 L .80646 .51905 L p .658 .759 .924 r
F P
0 g
s
.35358 .39907 m .36688 .39098 L .34975 .41808 L p .811 1 .826 r
F P
0 g
s
.34975 .41808 m .33525 .42828 L .35358 .39907 L p .811 1 .826 r
F P
0 g
s
.77683 .47547 m .79148 .47792 L .79244 .51902 L p .517 .643 .911 r
F P
0 g
s
.64896 .39538 m .63656 .40639 L .61798 .38973 L p .801 .765 .82 r
F P
0 g
s
.63656 .40639 m .62435 .42335 L .60773 .40867 L p .854 .758 .756 r
F P
0 g
s
.60773 .40867 m .61798 .38973 L .63656 .40639 L p .854 .758 .756 r
F P
0 g
s
.66162 .39044 m .64896 .39538 L .62842 .37674 L p .683 .752 .904 r
F P
0 g
s
.61798 .38973 m .62842 .37674 L .64896 .39538 L p .801 .765 .82 r
F P
0 g
s
.27589 .46738 m .29069 .46113 L .28576 .49802 L p .843 .917 .884 r
F P
0 g
s
.28576 .49802 m .27098 .50641 L .27589 .46738 L p .843 .917 .884 r
F P
0 g
s
.57315 .56092 m .56147 .57882 L .56615 .57313 L p 0 0 0 r
F P
0 g
s
.56615 .57313 m .5794 .55331 L .57315 .56092 L p 0 0 0 r
F P
0 g
s
.20631 .43608 m .2196 .44907 L .21513 .49717 L p .327 .45 .833 r
F P
0 g
s
.22853 .50543 m .21513 .49717 L .2196 .44907 L p .404 .523 .865 r
F P
0 g
s
.73194 .44679 m .71709 .43459 L .70155 .40492 L p 0 .303 .797 r
F P
0 g
s
.68791 .39639 m .70155 .40492 L .71709 .43459 L p .061 .362 .832 r
F P
0 g
s
.48757 .5777 m .4755 .55942 L .46998 .55162 L p .619 .181 0 r
F P
0 g
s
.4755 .55942 m .48757 .5777 L .49421 .58272 L p .805 .317 0 r
F P
0 g
s
.62435 .42335 m .61224 .44556 L .59757 .43284 L p .879 .748 .714 r
F P
0 g
s
.59757 .43284 m .60773 .40867 L .62435 .42335 L p .879 .748 .714 r
F P
0 g
s
.4271 .37331 m .43701 .38667 L .41689 .40271 L p .577 .577 .816 r
F P
0 g
s
.41689 .40271 m .40483 .39126 L .4271 .37331 L p .577 .577 .816 r
F P
0 g
s
.42877 .4201 m .41689 .40271 L .43701 .38667 L p .525 .483 .752 r
F P
0 g
s
.6746 .3911 m .66162 .39044 L .6391 .36982 L p .439 .668 .959 r
F P
0 g
s
.62842 .37674 m .6391 .36982 L .66162 .39044 L p .683 .752 .904 r
F P
0 g
s
.41694 .36602 m .4271 .37331 L .40483 .39126 L p .649 .724 .903 r
F P
0 g
s
.40483 .39126 m .3925 .38589 L .41694 .36602 L p .649 .724 .903 r
F P
0 g
s
.60752 .48401 m .59422 .51023 L .58796 .50011 L p .951 .824 .683 r
F P
0 g
s
.58796 .50011 m .60014 .47174 L .60752 .48401 L p .951 .824 .683 r
F P
0 g
s
.5957 .52088 m .58201 .545 L .58075 .53654 L p .976 .919 .662 r
F P
0 g
s
.58075 .53654 m .59422 .51023 L .5957 .52088 L p .976 .919 .662 r
F P
0 g
s
.26132 .46937 m .27589 .46738 L .27098 .50641 L p .763 .852 .917 r
F P
0 g
s
.27098 .50641 m .25646 .51058 L .26132 .46937 L p .763 .852 .917 r
F P
0 g
s
.52434 .59988 m .52396 .59008 L .51303 .58911 L p .626 .169 .149 r
F P
0 g
s
.52396 .59008 m .52434 .59988 L .53175 .59945 L p .532 .094 .153 r
F P
0 g
s
.53175 .59945 m .53497 .58944 L .52396 .59008 L p .532 .094 .153 r
F P
0 g
s
.2196 .44907 m .23316 .45969 L .22853 .50543 L p .404 .523 .865 r
F P
0 g
s
.2423 .51017 m .22853 .50543 L .23316 .45969 L p .518 .631 .902 r
F P
0 g
s
.53497 .58944 m .53175 .59945 L .53872 .59799 L p .402 0 .112 r
F P
0 g
s
.53872 .59799 m .54533 .58725 L .53497 .58944 L p .402 0 .112 r
F P
0 g
s
.43701 .38667 m .44676 .40598 L .42877 .4201 L p .525 .483 .752 r
F P
0 g
s
.44055 .44274 m .42877 .4201 L .44676 .40598 L p .493 .427 .711 r
F P
0 g
s
.51698 .59923 m .51303 .58911 L .50289 .58661 L p .697 .214 .097 r
F P
0 g
s
.51303 .58911 m .51698 .59923 L .52434 .59988 L p .626 .169 .149 r
F P
0 g
s
.44378 .48138 m .45692 .50806 L .45444 .51867 L p .109 .192 .669 r
F P
0 g
s
.46816 .54323 m .45444 .51867 L .45692 .50806 L p .113 .195 .672 r
F P
0 g
s
.45444 .51867 m .46816 .54323 L .46998 .55162 L p 0 0 .569 r
F P
0 g
s
.44055 .44274 m .45231 .46935 L .44378 .48138 L p .348 .329 .696 r
F P
0 g
s
.45692 .50806 m .44378 .48138 L .45231 .46935 L p .334 .31 .683 r
F P
0 g
s
.24706 .46672 m .26132 .46937 L .25646 .51058 L p .648 .75 .924 r
F P
0 g
s
.25646 .51058 m .2423 .51017 L .24706 .46672 L p .648 .75 .924 r
F P
0 g
s
.23316 .45969 m .24706 .46672 L .2423 .51017 L p .518 .631 .902 r
F P
0 g
s
.40651 .36434 m .41694 .36602 L .3925 .38589 L p .71 .9 .964 r
F P
0 g
s
.3925 .38589 m .37986 .38612 L .40651 .36434 L p .71 .9 .964 r
F P
0 g
s
.34003 .40872 m .35358 .39907 L .33525 .42828 L p .802 .997 .784 r
F P
0 g
s
.33525 .42828 m .3205 .44003 L .34003 .40872 L p .802 .997 .784 r
F P
0 g
s
.54533 .58725 m .53872 .59799 L .54479 .59557 L p .202 0 .008 r
F P
0 g
s
.54479 .59557 m .55437 .58363 L .54533 .58725 L p .202 0 .008 r
F P
0 g
s
.51016 .59756 m .50289 .58661 L .49421 .58272 L p .737 .221 0 r
F P
0 g
s
.50289 .58661 m .51016 .59756 L .51698 .59923 L p .697 .214 .097 r
F P
0 g
s
.61224 .44556 m .60014 .47174 L .58744 .46096 L p .891 .741 .689 r
F P
0 g
s
.58744 .46096 m .59757 .43284 L .61224 .44556 L p .891 .741 .689 r
F P
0 g
s
.5794 .55331 m .56615 .57313 L .56807 .56693 L p .857 .946 .585 r
F P
0 g
s
.56807 .56693 m .58201 .545 L .5794 .55331 L p .857 .946 .585 r
F P
0 g
s
.68791 .39639 m .6746 .3911 L .65007 .36851 L p .092 .477 .894 r
F P
0 g
s
.6391 .36982 m .65007 .36851 L .6746 .3911 L p .439 .668 .959 r
F P
0 g
s
.46998 .55162 m .48344 .57187 L .48757 .5777 L p .619 .181 0 r
F P
0 g
s
.48344 .57187 m .46998 .55162 L .46816 .54323 L p 0 .058 .622 r
F P
0 g
s
.74694 .45874 m .73194 .44679 L .71544 .41499 L p .004 .318 .807 r
F P
0 g
s
.70155 .40492 m .71544 .41499 L .73194 .44679 L p 0 .303 .797 r
F P
0 g
s
.44676 .40598 m .4564 .43051 L .44055 .44274 L p .493 .427 .711 r
F P
0 g
s
.45231 .46935 m .44055 .44274 L .4564 .43051 L p .476 .397 .688 r
F P
0 g
s
.55437 .58363 m .54479 .59557 L .54954 .59236 L p 0 0 0 r
F P
0 g
s
.54954 .59236 m .56147 .57882 L .55437 .58363 L p 0 0 0 r
F P
0 g
s
.50433 .59496 m .49421 .58272 L .48757 .5777 L p .687 .16 0 r
F P
0 g
s
.49421 .58272 m .50433 .59496 L .51016 .59756 L p .737 .221 0 r
F P
0 g
s
.39577 .36729 m .40651 .36434 L .37986 .38612 L p .676 .976 .888 r
F P
0 g
s
.37986 .38612 m .36688 .39098 L .39577 .36729 L p .676 .976 .888 r
F P
0 g
s
.59422 .51023 m .58075 .53654 L .57565 .52853 L p .951 .825 .684 r
F P
0 g
s
.57565 .52853 m .58796 .50011 L .59422 .51023 L p .951 .825 .684 r
F P
0 g
s
.62842 .37674 m .61798 .38973 L .59253 .37656 L p .777 .724 .803 r
F P
0 g
s
.61798 .38973 m .60773 .40867 L .58504 .39708 L p .814 .7 .74 r
F P
0 g
s
.58504 .39708 m .59253 .37656 L .61798 .38973 L p .814 .7 .74 r
F P
0 g
s
.60014 .47174 m .58796 .50011 L .57727 .49124 L p .895 .738 .679 r
F P
0 g
s
.57727 .49124 m .58744 .46096 L .60014 .47174 L p .895 .738 .679 r
F P
0 g
s
.56147 .57882 m .54954 .59236 L .55266 .58857 L p .574 .843 .495 r
F P
0 g
s
.55266 .58857 m .56615 .57313 L .56147 .57882 L p .574 .843 .495 r
F P
0 g
s
.60773 .40867 m .59757 .43284 L .57763 .42282 L p .83 .684 .702 r
F P
0 g
s
.57763 .42282 m .58504 .39708 L .60773 .40867 L p .83 .684 .702 r
F P
0 g
s
.6391 .36982 m .62842 .37674 L .60017 .36197 L p .681 .746 .901 r
F P
0 g
s
.59253 .37656 m .60017 .36197 L .62842 .37674 L p .777 .724 .803 r
F P
0 g
s
.45231 .46935 m .46414 .49814 L .45692 .50806 L p .334 .31 .683 r
F P
0 g
s
.47023 .53482 m .45692 .50806 L .46414 .49814 L p .336 .312 .684 r
F P
0 g
s
.45692 .50806 m .47023 .53482 L .46816 .54323 L p .113 .195 .672 r
F P
0 g
s
.58201 .545 m .56807 .56693 L .56707 .56063 L p .97 .923 .691 r
F P
0 g
s
.56707 .56063 m .58075 .53654 L .58201 .545 L p .97 .923 .691 r
F P
0 g
s
.3263 .41813 m .34003 .40872 L .3205 .44003 L p .805 .999 .795 r
F P
0 g
s
.3205 .44003 m .30561 .45155 L .3263 .41813 L p .805 .999 .795 r
F P
0 g
s
.48757 .5777 m .4999 .59161 L .50433 .59496 L p .687 .16 0 r
F P
0 g
s
.4999 .59161 m .48757 .5777 L .48344 .57187 L p 0 .007 .553 r
F P
0 g
s
.45672 .35951 m .46368 .37436 L .43701 .38667 L p .619 .591 .801 r
F P
0 g
s
.43701 .38667 m .4271 .37331 L .45672 .35951 L p .619 .591 .801 r
F P
0 g
s
.44676 .40598 m .43701 .38667 L .46368 .37436 L p .59 .514 .737 r
F P
0 g
s
.4564 .43051 m .46602 .45899 L .45231 .46935 L p .476 .397 .688 r
F P
0 g
s
.46414 .49814 m .45231 .46935 L .46602 .45899 L p .468 .383 .677 r
F P
0 g
s
.70155 .40492 m .68791 .39639 L .66135 .37183 L p 0 .287 .759 r
F P
0 g
s
.65007 .36851 m .66135 .37183 L .68791 .39639 L p .092 .477 .894 r
F P
0 g
s
.48212 .56561 m .46816 .54323 L .47023 .53482 L p .15 .235 .697 r
F P
0 g
s
.46816 .54323 m .48212 .56561 L .48344 .57187 L p 0 .058 .622 r
F P
0 g
s
.46368 .37436 m .47052 .39515 L .44676 .40598 L p .59 .514 .737 r
F P
0 g
s
.4564 .43051 m .44676 .40598 L .47052 .39515 L p .573 .471 .7 r
F P
0 g
s
.44957 .35071 m .45672 .35951 L .4271 .37331 L p .655 .725 .9 r
F P
0 g
s
.4271 .37331 m .41694 .36602 L .44957 .35071 L p .655 .725 .9 r
F P
0 g
s
.76194 .46877 m .74694 .45874 L .7295 .42483 L p .11 .399 .853 r
F P
0 g
s
.71544 .41499 m .7295 .42483 L .74694 .45874 L p .004 .318 .807 r
F P
0 g
s
.59757 .43284 m .58744 .46096 L .57026 .45248 L p .837 .674 .681 r
F P
0 g
s
.57026 .45248 m .57763 .42282 L .59757 .43284 L p .837 .674 .681 r
F P
0 g
s
.52472 .60344 m .52434 .59988 L .51698 .59923 L p .425 0 0 r
F P
0 g
s
.52434 .59988 m .52472 .60344 L .52846 .60323 L p .321 0 0 r
F P
0 g
s
.52846 .60323 m .53175 .59945 L .52434 .59988 L p .321 0 0 r
F P
0 g
s
.65007 .36851 m .6391 .36982 L .608 .35345 L p .42 .701 .98 r
F P
0 g
s
.60017 .36197 m .608 .35345 L .6391 .36982 L p .681 .746 .901 r
F P
0 g
s
.56615 .57313 m .55266 .58857 L .55391 .58445 L p .882 .983 .701 r
F P
0 g
s
.55391 .58445 m .56807 .56693 L .56615 .57313 L p .882 .983 .701 r
F P
0 g
s
.53175 .59945 m .52846 .60323 L .53197 .60249 L p .149 0 0 r
F P
0 g
s
.53197 .60249 m .53872 .59799 L .53175 .59945 L p .149 0 0 r
F P
0 g
s
.52101 .60312 m .51698 .59923 L .51016 .59756 L p .47 0 0 r
F P
0 g
s
.51698 .59923 m .52101 .60312 L .52472 .60344 L p .425 0 0 r
F P
0 g
s
.47052 .39515 m .47727 .42115 L .4564 .43051 L p .573 .471 .7 r
F P
0 g
s
.46602 .45899 m .4564 .43051 L .47727 .42115 L p .563 .447 .679 r
F P
0 g
s
.49715 .58774 m .48344 .57187 L .48212 .56561 L p 0 .196 .72 r
F P
0 g
s
.48344 .57187 m .49715 .58774 L .4999 .59161 L p 0 .007 .553 r
F P
0 g
s
.38476 .37348 m .39577 .36729 L .36688 .39098 L p .574 .923 .73 r
F P
0 g
s
.36688 .39098 m .35358 .39907 L .38476 .37348 L p .574 .923 .73 r
F P
0 g
s
.53872 .59799 m .53197 .60249 L .53502 .60128 L p 0 0 0 r
F P
0 g
s
.53502 .60128 m .54479 .59557 L .53872 .59799 L p 0 0 0 r
F P
0 g
s
.51758 .60227 m .51016 .59756 L .50433 .59496 L p .431 0 0 r
F P
0 g
s
.51016 .59756 m .51758 .60227 L .52101 .60312 L p .47 0 0 r
F P
0 g
s
.58796 .50011 m .57565 .52853 L .56701 .52152 L p .895 .739 .68 r
F P
0 g
s
.56701 .52152 m .57727 .49124 L .58796 .50011 L p .895 .739 .68 r
F P
0 g
s
.58075 .53654 m .56707 .56063 L .56318 .55468 L p .942 .827 .702 r
F P
0 g
s
.56318 .55468 m .57565 .52853 L .58075 .53654 L p .942 .827 .702 r
F P
0 g
s
.44222 .34752 m .44957 .35071 L .41694 .36602 L p .647 .897 .983 r
F P
0 g
s
.41694 .36602 m .40651 .36434 L .44222 .34752 L p .647 .897 .983 r
F P
0 g
s
.54479 .59557 m .53502 .60128 L .5374 .59967 L p .446 .848 .659 r
F P
0 g
s
.5374 .59967 m .54954 .59236 L .54479 .59557 L p .446 .848 .659 r
F P
0 g
s
.58744 .46096 m .57727 .49124 L .56286 .48427 L p .84 .67 .672 r
F P
0 g
s
.56286 .48427 m .57026 .45248 L .58744 .46096 L p .84 .67 .672 r
F P
0 g
s
.46602 .45899 m .47567 .48961 L .46414 .49814 L p .468 .383 .677 r
F P
0 g
s
.4761 .52697 m .46414 .49814 L .47567 .48961 L p .469 .385 .679 r
F P
0 g
s
.46414 .49814 m .4761 .52697 L .47023 .53482 L p .336 .312 .684 r
F P
0 g
s
.50433 .59496 m .51465 .60097 L .51758 .60227 L p .431 0 0 r
F P
0 g
s
.51465 .60097 m .50433 .59496 L .4999 .59161 L p 0 .249 .698 r
F P
0 g
s
.31252 .42559 m .3263 .41813 L .30561 .45155 L p .812 .998 .85 r
F P
0 g
s
.30561 .45155 m .29069 .46113 L .31252 .42559 L p .812 .998 .85 r
F P
0 g
s
.59253 .37656 m .58504 .39708 L .55788 .3895 L p .773 .653 .73 r
F P
0 g
s
.58504 .39708 m .57763 .42282 L .55382 .41628 L p .782 .632 .694 r
F P
0 g
s
.55382 .41628 m .55788 .3895 L .58504 .39708 L p .782 .632 .694 r
F P
0 g
s
.60017 .36197 m .59253 .37656 L .562 .36793 L p .75 .688 .793 r
F P
0 g
s
.55788 .3895 m .562 .36793 L .59253 .37656 L p .773 .653 .73 r
F P
0 g
s
.48373 .55936 m .47023 .53482 L .4761 .52697 L p .354 .336 .701 r
F P
0 g
s
.47023 .53482 m .48373 .55936 L .48212 .56561 L p .15 .235 .697 r
F P
0 g
s
.77683 .47547 m .76194 .46877 L .74362 .43272 L p .285 .527 .908 r
F P
0 g
s
.7295 .42483 m .74362 .43272 L .76194 .46877 L p .11 .399 .853 r
F P
0 g
s
.47727 .42115 m .484 .45107 L .46602 .45899 L p .563 .447 .679 r
F P
0 g
s
.47567 .48961 m .46602 .45899 L .484 .45107 L p .559 .437 .671 r
F P
0 g
s
.56807 .56693 m .55391 .58445 L .5532 .58029 L p .949 .925 .748 r
F P
0 g
s
.5532 .58029 m .56707 .56063 L .56807 .56693 L p .949 .925 .748 r
F P
0 g
s
.49501 .36679 m .49837 .3885 L .47052 .39515 L p .643 .545 .728 r
F P
0 g
s
.47052 .39515 m .46368 .37436 L .49501 .36679 L p .643 .545 .728 r
F P
0 g
s
.47727 .42115 m .47052 .39515 L .49837 .3885 L p .635 .509 .693 r
F P
0 g
s
.49158 .351 m .49501 .36679 L .46368 .37436 L p .656 .61 .791 r
F P
0 g
s
.46368 .37436 m .45672 .35951 L .49158 .351 L p .656 .61 .791 r
F P
0 g
s
.71544 .41499 m .70155 .40492 L .67292 .37838 L p 0 .198 .682 r
F P
0 g
s
.66135 .37183 m .67292 .37838 L .70155 .40492 L p 0 .287 .759 r
F P
0 g
s
.54954 .59236 m .5374 .59967 L .53895 .59777 L p .733 .989 .807 r
F P
0 g
s
.53895 .59777 m .55266 .58857 L .54954 .59236 L p .733 .989 .807 r
F P
0 g
s
.57763 .42282 m .57026 .45248 L .54977 .44695 L p .786 .62 .675 r
F P
0 g
s
.54977 .44695 m .55382 .41628 L .57763 .42282 L p .786 .62 .675 r
F P
0 g
s
.4963 .58358 m .48212 .56561 L .48373 .55936 L p .226 .317 .748 r
F P
0 g
s
.48212 .56561 m .4963 .58358 L .49715 .58774 L p 0 .196 .72 r
F P
0 g
s
.51243 .59929 m .4999 .59161 L .49715 .58774 L p 0 .347 .823 r
F P
0 g
s
.4999 .59161 m .51243 .59929 L .51465 .60097 L p 0 .249 .698 r
F P
0 g
s
.85986 .43317 m .84669 .4466 L .824 .39666 L p .889 .851 .8 r
F P
0 g
s
.824 .39666 m .8366 .38074 L .85986 .43317 L p .889 .851 .8 r
F P
0 g
s
.66135 .37183 m .65007 .36851 L .61605 .35053 L p 0 .462 .841 r
F P
0 g
s
.608 .35345 m .61605 .35053 L .65007 .36851 L p .42 .701 .98 r
F P
0 g
s
.608 .35345 m .60017 .36197 L .5662 .35229 L p .677 .74 .898 r
F P
0 g
s
.562 .36793 m .5662 .35229 L .60017 .36197 L p .75 .688 .793 r
F P
0 g
s
.49837 .3885 m .50169 .41541 L .47727 .42115 L p .635 .509 .693 r
F P
0 g
s
.484 .45107 m .47727 .42115 L .50169 .41541 L p .63 .49 .674 r
F P
0 g
s
.48806 .34127 m .49158 .351 L .45672 .35951 L p .662 .727 .898 r
F P
0 g
s
.45672 .35951 m .44957 .35071 L .48806 .34127 L p .662 .727 .898 r
F P
0 g
s
.55266 .58857 m .53895 .59777 L .53956 .59572 L p .867 .981 .847 r
F P
0 g
s
.53956 .59572 m .55391 .58445 L .55266 .58857 L p .867 .981 .847 r
F P
0 g
s
.57727 .49124 m .56701 .52152 L .55541 .51602 L p .839 .671 .673 r
F P
0 g
s
.55541 .51602 m .56286 .48427 L .57727 .49124 L p .839 .671 .673 r
F P
0 g
s
.57565 .52853 m .56318 .55468 L .55665 .54949 L p .889 .743 .694 r
F P
0 g
s
.55665 .54949 m .56701 .52152 L .57565 .52853 L p .889 .743 .694 r
F P
0 g
s
.562 .36793 m .55788 .3895 L .52824 .38656 L p .732 .613 .724 r
F P
0 g
s
.55788 .3895 m .55382 .41628 L .52785 .41374 L p .736 .587 .69 r
F P
0 g
s
.52785 .41374 m .52824 .38656 L .55788 .3895 L p .736 .587 .69 r
F P
0 g
s
.43464 .34897 m .44222 .34752 L .40651 .36434 L p .455 .884 .823 r
F P
0 g
s
.40651 .36434 m .39577 .36729 L .43464 .34897 L p .455 .884 .823 r
F P
0 g
s
.51107 .59735 m .49715 .58774 L .4963 .58358 L p .198 .413 .846 r
F P
0 g
s
.49715 .58774 m .51107 .59735 L .51243 .59929 L p 0 .347 .823 r
F P
0 g
s
.84669 .4466 m .83336 .45908 L .81128 .41161 L p .877 .848 .812 r
F P
0 g
s
.81128 .41161 m .824 .39666 L .84669 .4466 L p .877 .848 .812 r
F P
0 g
s
.57026 .45248 m .56286 .48427 L .54572 .47973 L p .788 .615 .667 r
F P
0 g
s
.54572 .47973 m .54977 .44695 L .57026 .45248 L p .788 .615 .667 r
F P
0 g
s
.79148 .47792 m .77683 .47547 L .75765 .43726 L p .487 .659 .937 r
F P
0 g
s
.74362 .43272 m .75765 .43726 L .77683 .47547 L p .285 .527 .908 r
F P
0 g
s
.36207 .38871 m .37349 .38122 L .36784 .38587 L p .53 .888 .665 r
F P
0 g
s
.36784 .38587 m .34003 .40872 L p .36207 .38871 L .53 .888 .665 r
F P
0 g
s
.35057 .39422 m .36207 .38871 L .3263 .41813 L p .607 .946 .782 r
F P
0 g
s
.36207 .38871 m .35057 .39422 L .35704 .39118 L p 0 0 0 r
F P
0 g
s
.38387 .3742 m .35358 .39907 L p .37349 .38122 L .515 .874 .642 r
F P
0 g
s
.35358 .39907 m .34003 .40872 L .37349 .38122 L p .515 .874 .642 r
F P
0 g
s
.34003 .40872 m .3263 .41813 L .36207 .38871 L p .53 .888 .665 r
F P
0 g
s
.35704 .39118 m .4026 .36977 L p .36207 .38871 L 0 0 0 r
F P
0 g
s
.37349 .38122 m .36207 .38871 L .36322 .38817 L p 0 0 0 r
F P
0 g
s
.36322 .38817 m .41077 .36582 L p .37349 .38122 L 0 0 0 r
F P
0 g
s
.37349 .38122 m .38476 .37348 L .38387 .3742 L p .515 .874 .642 r
F P
0 g
s
.56707 .56063 m .5532 .58029 L .55057 .57635 L p .921 .832 .74 r
F P
0 g
s
.55057 .57635 m .56318 .55468 L .56707 .56063 L p .921 .832 .74 r
F P
0 g
s
.52864 .36458 m .52824 .38656 L .49837 .3885 L p .69 .577 .724 r
F P
0 g
s
.49837 .3885 m .49501 .36679 L .52864 .36458 L p .69 .577 .724 r
F P
0 g
s
.50169 .41541 m .49837 .3885 L .52824 .38656 L p .687 .547 .69 r
F P
0 g
s
.5662 .35229 m .562 .36793 L .52864 .36458 L p .721 .658 .787 r
F P
0 g
s
.52824 .38656 m .52864 .36458 L .562 .36793 L p .732 .613 .724 r
F P
0 g
s
.47567 .48961 m .4854 .52024 L .4761 .52697 L p .469 .385 .679 r
F P
0 g
s
.4882 .55353 m .4761 .52697 L .4854 .52024 L p .479 .402 .692 r
F P
0 g
s
.4761 .52697 m .4882 .55353 L .48373 .55936 L p .354 .336 .701 r
F P
0 g
s
.484 .45107 m .49074 .48311 L .47567 .48961 L p .559 .437 .671 r
F P
0 g
s
.4854 .52024 m .47567 .48961 L .49074 .48311 L p .559 .439 .672 r
F P
0 g
s
.29881 .42968 m .31252 .42559 L .29069 .46113 L p .799 .965 .913 r
F P
0 g
s
.29069 .46113 m .27589 .46738 L .29881 .42968 L p .799 .965 .913 r
F P
0 g
s
.52511 .59947 m .52472 .60344 L .52101 .60312 L closepath p .447 .793 .998 r
F P
0 g
s
.52511 .59947 m .52846 .60323 L .52472 .60344 L closepath p .49 .83 .998 r
F P
0 g
s
.50169 .41541 m .50499 .44622 L .484 .45107 L p .63 .49 .674 r
F P
0 g
s
.49074 .48311 m .484 .45107 L .50499 .44622 L p .627 .483 .666 r
F P
0 g
s
.52511 .59947 m .53197 .60249 L .52846 .60323 L closepath p .549 .863 .996 r
F P
0 g
s
.55382 .41628 m .54977 .44695 L .52747 .44481 L p .737 .574 .672 r
F P
0 g
s
.52747 .44481 m .52785 .41374 L .55382 .41628 L p .737 .574 .672 r
F P
0 g
s
.52511 .59947 m .52101 .60312 L .51758 .60227 L closepath p .425 .757 .995 r
F P
0 g
s
.52904 .34852 m .52864 .36458 L .49501 .36679 L p .69 .632 .786 r
F P
0 g
s
.49501 .36679 m .49158 .351 L .52904 .34852 L p .69 .632 .786 r
F P
0 g
s
.49742 .57944 m .48373 .55936 L .4882 .55353 L p .392 .389 .737 r
F P
0 g
s
.48373 .55936 m .49742 .57944 L .4963 .58358 L p .226 .317 .748 r
F P
0 g
s
.52511 .59947 m .53502 .60128 L .53197 .60249 L closepath p .614 .886 .99 r
F P
0 g
s
.52824 .38656 m .52785 .41374 L .50169 .41541 L p .687 .547 .69 r
F P
0 g
s
.50499 .44622 m .50169 .41541 L .52785 .41374 L p .686 .531 .671 r
F P
0 g
s
.52511 .59947 m .51758 .60227 L .51465 .60097 L closepath p .426 .724 .988 r
F P
0 g
s
.61605 .35053 m .608 .35345 L .57051 .3427 L p .42 .742 .993 r
F P
0 g
s
.5662 .35229 m .57051 .3427 L .608 .35345 L p .677 .74 .898 r
F P
0 g
s
.55391 .58445 m .53956 .59572 L .53919 .59364 L p .892 .909 .83 r
F P
0 g
s
.53919 .59364 m .5532 .58029 L .55391 .58445 L p .892 .909 .83 r
F P
0 g
s
.52511 .59947 m .5374 .59967 L .53502 .60128 L closepath p .672 .893 .977 r
F P
0 g
s
.83336 .45908 m .81976 .4692 L .79833 .42414 L p .842 .838 .841 r
F P
0 g
s
.79833 .42414 m .81128 .41161 L .83336 .45908 L p .842 .838 .841 r
F P
0 g
s
.52864 .36458 m .52904 .34852 L .5662 .35229 L p .721 .658 .787 r
F P
0 g
s
.52511 .59947 m .51465 .60097 L .51243 .59929 L closepath p .444 .697 .974 r
F P
0 g
s
.52785 .41374 m .52747 .44481 L .50499 .44622 L p .686 .531 .671 r
F P
0 g
s
.51066 .59528 m .4963 .58358 L .49742 .57944 L p .353 .454 .825 r
F P
0 g
s
.4963 .58358 m .51066 .59528 L .51107 .59735 L p .198 .413 .846 r
F P
0 g
s
.8058 .47574 m .79148 .47792 L .7715 .43748 L p .659 .758 .923 r
F P
0 g
s
.75765 .43726 m .7715 .43748 L .79148 .47792 L p .487 .659 .937 r
F P
0 g
s
.57051 .3427 m .5662 .35229 L .52904 .34852 L p .673 .735 .897 r
F P
0 g
s
.48443 .33714 m .48806 .34127 L .44957 .35071 L p .572 .873 .994 r
F P
0 g
s
.44957 .35071 m .44222 .34752 L .48443 .33714 L p .572 .873 .994 r
F P
0 g
s
.52511 .59947 m .53895 .59777 L .5374 .59967 L closepath p .717 .885 .958 r
F P
0 g
s
.54977 .44695 m .54572 .47973 L .52708 .47797 L p .737 .568 .664 r
F P
0 g
s
.52708 .47797 m .52747 .44481 L .54977 .44695 L p .737 .568 .664 r
F P
0 g
s
.52511 .59947 m .51243 .59929 L .51107 .59735 L closepath p .473 .676 .954 r
F P
0 g
s
.56286 .48427 m .55541 .51602 L .54165 .51245 L p .787 .616 .668 r
F P
0 g
s
.54165 .51245 m .54572 .47973 L .56286 .48427 L p .787 .616 .668 r
F P
0 g
s
.81976 .4692 m .8058 .47574 L .78507 .43303 L p .775 .813 .883 r
F P
0 g
s
.78507 .43303 m .79833 .42414 L .81976 .4692 L p .775 .813 .883 r
F P
0 g
s
.52945 .33851 m .52904 .34852 L .49158 .351 L p .667 .73 .897 r
F P
0 g
s
.49158 .351 m .48806 .34127 L .52945 .33851 L p .667 .73 .897 r
F P
0 g
s
.56701 .52152 m .55665 .54949 L .5479 .54542 L p .836 .676 .685 r
F P
0 g
s
.5479 .54542 m .55541 .51602 L .56701 .52152 L p .836 .676 .685 r
F P
0 g
s
.5083 .47913 m .50499 .44622 L .52747 .44481 L p .685 .525 .664 r
F P
0 g
s
.50499 .44622 m .5083 .47913 L .49074 .48311 L p .627 .483 .666 r
F P
0 g
s
.20631 .43608 m .19318 .42214 L .22154 .37026 L p .427 .463 .795 r
F P
0 g
s
.7715 .43748 m .78507 .43303 L .8058 .47574 L p .659 .758 .923 r
F P
0 g
s
.7295 .42483 m .71544 .41499 L .68475 .3865 L p 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .71544 .41499 L p .67401 .37932 L 0 .198 .682 r
F P
0 g
s
.69674 .39436 m .7295 .42483 L p .69085 .39172 L 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .69674 .39436 L p .69085 .39172 L 0 .221 .702 r
F P
0 g
s
.68475 .3865 m .64161 .36369 L p .69538 .3936 L .454 0 0 r
F P
0 g
s
.69674 .39436 m .68475 .3865 L p .69538 .3936 L .454 0 0 r
F P
0 g
s
.65048 .36992 m .69674 .39436 L p .64909 .36785 L .454 0 0 r
F P
0 g
s
.64161 .36369 m .65048 .36992 L p .64909 .36785 L .454 0 0 r
F P
0 g
s
.65048 .36992 m .59397 .35376 L p .6517 .37175 L .358 0 0 r
F P
0 g
s
.69674 .39436 m .65048 .36992 L p .70197 .3967 L 0 .279 .665 r
F P
0 g
s
.65941 .37416 m .70881 .40025 L p .66531 .37763 L 0 .279 .665 r
F P
0 g
s
.65048 .36992 m .65941 .37416 L p .66531 .37763 L 0 .279 .665 r
F P
0 g
s
.65941 .37416 m .65048 .36992 L p .6517 .37175 L .358 0 0 r
F P
0 g
s
.59893 .35687 m .65941 .37416 L p .61054 .35892 L .358 0 0 r
F P
0 g
s
.59397 .35376 m .59893 .35687 L p .61054 .35892 L .358 0 0 r
F P
0 g
s
.52904 .34852 m .52945 .33851 L .57051 .3427 L p .673 .735 .897 r
F P
0 g
s
.59893 .35687 m .59397 .35376 L .5317 .34744 L p .323 0 0 r
F P
0 g
s
.53218 .35011 m .59893 .35687 L p .54865 .34982 L .323 0 0 r
F P
0 g
s
.5317 .34744 m .53218 .35011 L p .54865 .34982 L .323 0 0 r
F P
0 g
s
.53218 .35011 m .5317 .34744 L .46888 .3516 L p .204 0 0 r
F P
0 g
s
.46888 .3516 m .46483 .35456 L .53218 .35011 L p .204 0 0 r
F P
0 g
s
.53218 .35011 m .46483 .35456 L p .51927 .35034 L .132 .679 .788 r
F P
0 g
s
.53265 .3493 m .53218 .35011 L p .51927 .35034 L .132 .679 .788 r
F P
0 g
s
.59893 .35687 m .53218 .35011 L p .5898 .35526 L .029 .593 .793 r
F P
0 g
s
.58906 .34863 m .59397 .35376 L .65048 .36992 L p .501 0 0 r
F P
0 g
s
.60388 .35652 m .59893 .35687 L p .5898 .35526 L .029 .593 .793 r
F P
0 g
s
.65941 .37416 m .59893 .35687 L p .65478 .37142 L .009 .549 .841 r
F P
0 g
s
.61605 .35053 m .62435 .35224 L .66135 .37183 L p 0 .462 .841 r
F P
0 g
s
.67292 .37838 m .66135 .37183 L .62435 .35224 L p .37 0 0 r
F P
0 g
s
.67292 .37838 m .68475 .3865 L p .67401 .37932 L 0 .198 .682 r
F P
0 g
s
.68475 .3865 m .67292 .37838 L .63288 .35719 L p .48 0 0 r
F P
0 g
s
.62435 .35224 m .63288 .35719 L .67292 .37838 L p .37 0 0 r
F P
0 g
s
.63288 .35719 m .64161 .36369 L .68475 .3865 L p .48 0 0 r
F P
0 g
s
.66834 .37496 m .65941 .37416 L p .65478 .37142 L .009 .549 .841 r
F P
0 g
s
.70881 .40025 m .69674 .39436 L p .70197 .3967 L 0 .279 .665 r
F P
0 g
s
.56318 .55468 m .55057 .57635 L .54618 .57293 L p .875 .752 .724 r
F P
0 g
s
.54618 .57293 m .55665 .54949 L .56318 .55468 L p .875 .752 .724 r
F P
0 g
s
.49753 .51511 m .49074 .48311 L .5083 .47913 L p .628 .483 .667 r
F P
0 g
s
.49074 .48311 m .49753 .51511 L .4854 .52024 L p .559 .439 .672 r
F P
0 g
s
.52511 .59947 m .53956 .59572 L .53895 .59777 L closepath p .744 .864 .936 r
F P
0 g
s
.49523 .54854 m .4854 .52024 L .49753 .51511 L p .564 .451 .683 r
F P
0 g
s
.4854 .52024 m .49523 .54854 L .4882 .55353 L p .479 .402 .692 r
F P
0 g
s
.52747 .44481 m .52708 .47797 L .5083 .47913 L p .685 .525 .664 r
F P
0 g
s
.5532 .58029 m .53919 .59364 L .53786 .59169 L p .874 .832 .803 r
F P
0 g
s
.53786 .59169 m .55057 .57635 L .5532 .58029 L p .874 .832 .803 r
F P
0 g
s
.52511 .59947 m .51107 .59735 L .51066 .59528 L closepath p .505 .661 .931 r
F P
0 g
s
.50043 .57559 m .4882 .55353 L .49523 .54854 L p .499 .439 .721 r
F P
0 g
s
.4882 .55353 m .50043 .57559 L .49742 .57944 L p .392 .389 .737 r
F P
0 g
s
.28527 .42946 m .29881 .42968 L .27589 .46738 L p .74 .875 .943 r
F P
0 g
s
.27589 .46738 m .26132 .46937 L .28527 .42946 L p .74 .875 .943 r
F P
0 g
s
.51124 .59322 m .49742 .57944 L .50043 .57559 L p .459 .484 .797 r
F P
0 g
s
.49742 .57944 m .51124 .59322 L .51066 .59528 L p .353 .454 .825 r
F P
0 g
s
.52511 .59947 m .53919 .59364 L .53956 .59572 L closepath p .757 .837 .913 r
F P
0 g
s
.52511 .59947 m .51066 .59528 L .51124 .59322 L closepath p .539 .652 .908 r
F P
0 g
s
.22154 .37026 m .23388 .3867 L .20631 .43608 L p .427 .463 .795 r
F P
0 g
s
.2196 .44907 m .20631 .43608 L .23388 .3867 L p .444 .484 .806 r
F P
0 g
s
.54572 .47973 m .54165 .51245 L .52669 .51106 L p .737 .569 .665 r
F P
0 g
s
.52669 .51106 m .52708 .47797 L .54572 .47973 L p .737 .569 .665 r
F P
0 g
s
.51162 .51197 m .5083 .47913 L .52708 .47797 L p .685 .526 .664 r
F P
0 g
s
.5083 .47913 m .51162 .51197 L .49753 .51511 L p .628 .483 .667 r
F P
0 g
s
.42685 .35365 m .43464 .34897 L .39577 .36729 L p 0 0 0 r
F P
0 g
s
.39577 .36729 m .38476 .37348 L .42685 .35365 L p 0 0 0 r
F P
0 g
s
.52511 .59947 m .53786 .59169 L .53919 .59364 L closepath p .758 .807 .892 r
F P
0 g
s
.52511 .59947 m .53565 .58999 L .53786 .59169 L closepath p .751 .777 .874 r
F P
0 g
s
.52511 .59947 m .53271 .58867 L .53565 .58999 L closepath p .739 .749 .86 r
F P
0 g
s
.52511 .59947 m .52925 .58781 L .53271 .58867 L closepath p .722 .724 .851 r
F P
0 g
s
.52511 .59947 m .52551 .58748 L .52925 .58781 L closepath p .703 .702 .846 r
F P
0 g
s
.52511 .59947 m .52174 .5877 L .52551 .58748 L closepath p .681 .684 .846 r
F P
0 g
s
.52511 .59947 m .5182 .58845 L .52174 .5877 L closepath p .657 .669 .85 r
F P
0 g
s
.52511 .59947 m .51514 .58969 L .5182 .58845 L closepath p .631 .658 .858 r
F P
0 g
s
.52511 .59947 m .51276 .59131 L .51514 .58969 L closepath p .602 .651 .871 r
F P
0 g
s
.52511 .59947 m .51124 .59322 L .51276 .59131 L closepath p .572 .649 .888 r
F P
0 g
s
.55541 .51602 m .5479 .54542 L .53754 .54278 L p .786 .622 .678 r
F P
0 g
s
.53754 .54278 m .54165 .51245 L .55541 .51602 L p .786 .622 .678 r
F P
0 g
s
.55057 .57635 m .53786 .59169 L .53565 .58999 L p .842 .766 .779 r
F P
0 g
s
.53565 .58999 m .54618 .57293 L .55057 .57635 L p .842 .766 .779 r
F P
0 g
s
.55665 .54949 m .54618 .57293 L .54032 .57025 L p .827 .689 .711 r
F P
0 g
s
.54032 .57025 m .5479 .54542 L .55665 .54949 L p .827 .689 .711 r
F P
0 g
s
.50043 .57559 m .51276 .59131 L .51124 .59322 L p .459 .484 .797 r
F P
0 g
s
.52708 .47797 m .52669 .51106 L .51162 .51197 L p .685 .526 .664 r
F P
0 g
s
.57051 .3427 m .57494 .33871 L .61605 .35053 L p .42 .742 .993 r
F P
0 g
s
.57494 .33871 m .57051 .3427 L .52945 .33851 L p .447 .787 .998 r
F P
0 g
s
.62435 .35224 m .61605 .35053 L .57494 .33871 L p 0 .46 .751 r
F P
0 g
s
.49523 .54854 m .50516 .57231 L .50043 .57559 L p .499 .439 .721 r
F P
0 g
s
.51276 .59131 m .50043 .57559 L .50516 .57231 L p .537 .511 .775 r
F P
0 g
s
.50437 .54475 m .49753 .51511 L .51162 .51197 L p .63 .494 .677 r
F P
0 g
s
.49753 .51511 m .50437 .54475 L .49523 .54854 L p .564 .451 .683 r
F P
0 g
s
.50516 .57231 m .49523 .54854 L .50437 .54475 L p .576 .48 .709 r
F P
0 g
s
.272 .42454 m .28527 .42946 L .26132 .46937 L p .649 .749 .923 r
F P
0 g
s
.26132 .46937 m .24706 .46672 L .272 .42454 L p .649 .749 .923 r
F P
0 g
s
.23388 .3867 m .24634 .40215 L .2196 .44907 L p .444 .484 .806 r
F P
0 g
s
.23316 .45969 m .2196 .44907 L .24634 .40215 L p .488 .539 .836 r
F P
0 g
s
.52988 .33411 m .52945 .33851 L .48806 .34127 L p .5 .834 .999 r
F P
0 g
s
.48806 .34127 m .48443 .33714 L .52988 .33411 L p .5 .834 .999 r
F P
0 g
s
.50516 .57231 m .51514 .58969 L .51276 .59131 L p .537 .511 .775 r
F P
0 g
s
.48069 .33764 m .48443 .33714 L .44222 .34752 L p .211 .733 .733 r
F P
0 g
s
.44222 .34752 m .43464 .34897 L .48069 .33764 L p .211 .733 .733 r
F P
0 g
s
.54165 .51245 m .53754 .54278 L .5263 .54176 L p .737 .576 .675 r
F P
0 g
s
.5263 .54176 m .52669 .51106 L .54165 .51245 L p .737 .576 .675 r
F P
0 g
s
.24634 .40215 m .25903 .41517 L .23316 .45969 L p .488 .539 .836 r
F P
0 g
s
.24706 .46672 m .23316 .45969 L .25903 .41517 L p .558 .629 .878 r
F P
0 g
s
.25903 .41517 m .272 .42454 L .24706 .46672 L p .558 .629 .878 r
F P
0 g
s
.54618 .57293 m .53565 .58999 L .53271 .58867 L p .806 .712 .762 r
F P
0 g
s
.53271 .58867 m .54032 .57025 L .54618 .57293 L p .806 .712 .762 r
F P
0 g
s
.51498 .54243 m .51162 .51197 L .52669 .51106 L p .686 .534 .675 r
F P
0 g
s
.51162 .51197 m .51498 .54243 L .50437 .54475 L p .63 .494 .677 r
F P
0 g
s
.51127 .56981 m .5182 .58845 L .51514 .58969 L p .597 .537 .759 r
F P
0 g
s
.51514 .58969 m .50516 .57231 L .51127 .56981 L p .597 .537 .759 r
F P
0 g
s
.50437 .54475 m .51127 .56981 L .50516 .57231 L p .576 .48 .709 r
F P
0 g
s
.5479 .54542 m .54032 .57025 L .5334 .56852 L p .781 .637 .702 r
F P
0 g
s
.5334 .56852 m .53754 .54278 L .5479 .54542 L p .781 .637 .702 r
F P
0 g
s
.52945 .33851 m .52988 .33411 L .57494 .33871 L p .447 .787 .998 r
F P
0 g
s
.52669 .51106 m .5263 .54176 L .51498 .54243 L p .686 .534 .675 r
F P
0 g
s
.51127 .56981 m .50437 .54475 L .51498 .54243 L p .636 .517 .701 r
F P
0 g
s
.54032 .57025 m .53271 .58867 L .52925 .58781 L p .768 .667 .751 r
F P
0 g
s
.51835 .56829 m .52174 .5877 L .5182 .58845 L p .646 .565 .749 r
F P
0 g
s
.5182 .58845 m .51127 .56981 L .51835 .56829 L p .646 .565 .749 r
F P
0 g
s
.52925 .58781 m .5334 .56852 L .54032 .57025 L p .768 .667 .751 r
F P
0 g
s
.5334 .56852 m .52925 .58781 L .52551 .58748 L p .73 .628 .745 r
F P
0 g
s
.5259 .56785 m .52551 .58748 L .52174 .5877 L p .69 .595 .745 r
F P
0 g
s
.52174 .5877 m .51835 .56829 L .5259 .56785 L p .69 .595 .745 r
F P
0 g
s
.52551 .58748 m .5259 .56785 L .5334 .56852 L p .73 .628 .745 r
F P
0 g
s
.74362 .43272 m .7295 .42483 L .69674 .39436 L p 0 .344 .804 r
F P
0 g
s
.51498 .54243 m .51835 .56829 L .51127 .56981 L p .636 .517 .701 r
F P
0 g
s
.53754 .54278 m .5334 .56852 L .5259 .56785 L p .735 .593 .698 r
F P
0 g
s
.5259 .56785 m .5263 .54176 L .53754 .54278 L p .735 .593 .698 r
F P
0 g
s
.51835 .56829 m .51498 .54243 L .5263 .54176 L p .688 .554 .698 r
F P
0 g
s
.5263 .54176 m .5259 .56785 L .51835 .56829 L p .688 .554 .698 r
F P
0 g
s
.57494 .33871 m .57952 .33935 L .62435 .35224 L p 0 .46 .751 r
F P
0 g
s
.57952 .33935 m .57494 .33871 L .52988 .33411 L p .093 0 0 r
F P
0 g
s
.41888 .35987 m .42685 .35365 L .38476 .37348 L p 0 0 0 r
F P
0 g
s
.38476 .37348 m .37349 .38122 L .41888 .35987 L p 0 0 0 r
F P
0 g
s
.3263 .41813 m .31252 .42559 L .35057 .39422 L p .607 .946 .782 r
F P
0 g
s
.53032 .33433 m .52988 .33411 L .48443 .33714 L p 0 0 0 r
F P
0 g
s
.48443 .33714 m .48069 .33764 L .53032 .33433 L p 0 0 0 r
F P
0 g
s
.63288 .35719 m .62435 .35224 L .57952 .33935 L p .432 0 0 r
F P
0 g
s
.52988 .33411 m .53032 .33433 L .57952 .33935 L p .093 0 0 r
F P
0 g
s
.47684 .34136 m .48069 .33764 L .43464 .34897 L p .069 0 0 r
F P
0 g
s
.43464 .34897 m .42685 .35365 L .47684 .34136 L p .069 0 0 r
F P
0 g
s
.75765 .43726 m .74362 .43272 L .70881 .40025 L p .172 .529 .922 r
F P
0 g
s
.69674 .39436 m .70881 .40025 L .74362 .43272 L p 0 .344 .804 r
F P
0 g
s
.3391 .39633 m .35057 .39422 L .31252 .42559 L p .69 .972 .92 r
F P
0 g
s
.31252 .42559 m .29881 .42968 L .3391 .39633 L p .69 .972 .92 r
F P
0 g
s
.57952 .33935 m .58423 .34322 L .63288 .35719 L p .432 0 0 r
F P
0 g
s
.58423 .34322 m .57952 .33935 L .53032 .33433 L p .389 0 0 r
F P
0 g
s
.7715 .43748 m .75765 .43726 L .72083 .40275 L p .462 .684 .962 r
F P
0 g
s
.70881 .40025 m .72083 .40275 L .75765 .43726 L p .172 .529 .922 r
F P
0 g
s
.41077 .36582 m .41888 .35987 L .37349 .38122 L p 0 0 0 r
F P
0 g
s
.53077 .33777 m .53032 .33433 L .48069 .33764 L p .27 0 0 r
F P
0 g
s
.48069 .33764 m .47684 .34136 L .53077 .33777 L p .27 0 0 r
F P
0 g
s
.64161 .36369 m .63288 .35719 L .58423 .34322 L p .522 0 0 r
F P
0 g
s
.53032 .33433 m .53077 .33777 L .58423 .34322 L p .389 0 0 r
F P
0 g
s
.47289 .34662 m .47684 .34136 L .42685 .35365 L p .158 0 0 r
F P
0 g
s
.42685 .35365 m .41888 .35987 L .47289 .34662 L p .158 0 0 r
F P
0 g
s
.78507 .43303 m .7715 .43748 L .73273 .40088 L p .659 .756 .922 r
F P
0 g
s
.72083 .40275 m .73273 .40088 L .7715 .43748 L p .462 .684 .962 r
F P
0 g
s
.32776 .39406 m .3391 .39633 L .29881 .42968 L p .701 .888 .966 r
F P
0 g
s
.29881 .42968 m .28527 .42946 L .32776 .39406 L p .701 .888 .966 r
F P
0 g
s
.8366 .38074 m .824 .39666 L .77807 .35105 L p .854 .778 .777 r
F P
0 g
s
.77807 .35105 m .78901 .33274 L .8366 .38074 L p .854 .778 .777 r
F P
0 g
s
.824 .39666 m .81128 .41161 L .76705 .36834 L p .845 .779 .788 r
F P
0 g
s
.76705 .36834 m .77807 .35105 L .824 .39666 L p .845 .779 .788 r
F P
0 g
s
.79833 .42414 m .78507 .43303 L .74441 .39427 L p .765 .778 .863 r
F P
0 g
s
.73273 .40088 m .74441 .39427 L .78507 .43303 L p .659 .756 .922 r
F P
0 g
s
.81128 .41161 m .79833 .42414 L .75585 .38316 L p .819 .78 .816 r
F P
0 g
s
.75585 .38316 m .76705 .36834 L .81128 .41161 L p .819 .78 .816 r
F P
0 g
s
.74441 .39427 m .75585 .38316 L .79833 .42414 L p .765 .778 .863 r
F P
0 g
s
.31661 .38704 m .32776 .39406 L .28527 .42946 L p .65 .749 .922 r
F P
0 g
s
.28527 .42946 m .272 .42454 L .31661 .38704 L p .65 .749 .922 r
F P
0 g
s
.58423 .34322 m .58906 .34863 L .64161 .36369 L p .522 0 0 r
F P
0 g
s
.58906 .34863 m .58423 .34322 L .53077 .33777 L p .468 0 0 r
F P
0 g
s
.4026 .36977 m .41077 .36582 L .3931 .37413 L p 0 0 0 r
F P
0 g
s
.41077 .36582 m .4026 .36977 L .46483 .35456 L p 0 0 0 r
F P
0 g
s
.4026 .36977 m .39444 .37028 L .40958 .36658 L p .304 .798 .829 r
F P
0 g
s
.46483 .35456 m .46888 .3516 L .44785 .35675 L p 0 0 0 r
F P
0 g
s
.44785 .35675 m .41077 .36582 L p .46483 .35456 L 0 0 0 r
F P
0 g
s
.46483 .35456 m .46077 .35405 L .47726 .35296 L p .132 .679 .788 r
F P
0 g
s
.47726 .35296 m .53265 .3493 L p .46483 .35456 L .132 .679 .788 r
F P
0 g
s
.40958 .36658 m .46077 .35405 L p .4026 .36977 L .304 .798 .829 r
F P
0 g
s
.3931 .37413 m .36207 .38871 L p .4026 .36977 L 0 0 0 r
F P
0 g
s
.53123 .34275 m .53077 .33777 L .47684 .34136 L p .35 0 0 r
F P
0 g
s
.47684 .34136 m .47289 .34662 L .53123 .34275 L p .35 0 0 r
F P
0 g
s
.65048 .36992 m .64161 .36369 L .58906 .34863 L p .501 0 0 r
F P
0 g
s
.23388 .3867 m .22154 .37026 L .27399 .32374 L p .518 .497 .772 r
F P
0 g
s
.30569 .3755 m .31661 .38704 L .272 .42454 L p .594 .633 .86 r
F P
0 g
s
.272 .42454 m .25903 .41517 L .30569 .3755 L p .594 .633 .86 r
F P
0 g
s
.27399 .32374 m .28445 .34251 L .23388 .3867 L p .518 .497 .772 r
F P
0 g
s
.24634 .40215 m .23388 .3867 L .28445 .34251 L p .528 .513 .783 r
F P
0 g
s
.53077 .33777 m .53123 .34275 L .58906 .34863 L p .468 0 0 r
F P
0 g
s
.29499 .36025 m .30569 .3755 L .25903 .41517 L p .552 .556 .812 r
F P
0 g
s
.25903 .41517 m .24634 .40215 L .29499 .36025 L p .552 .556 .812 r
F P
0 g
s
.46888 .3516 m .47289 .34662 L .41888 .35987 L p .137 0 0 r
F P
0 g
s
.41888 .35987 m .41077 .36582 L .46888 .3516 L p .137 0 0 r
F P
0 g
s
.28445 .34251 m .29499 .36025 L .24634 .40215 L p .528 .513 .783 r
F P
0 g
s
.72083 .40275 m .70881 .40025 L .65941 .37416 L p .066 .534 .897 r
F P
0 g
s
.39444 .37028 m .4026 .36977 L .35057 .39422 L p .511 .913 .887 r
F P
0 g
s
.35057 .39422 m .3391 .39633 L .39444 .37028 L p .511 .913 .887 r
F P
0 g
s
.59397 .35376 m .58906 .34863 L .53123 .34275 L p .45 0 0 r
F P
0 g
s
.5317 .34744 m .53123 .34275 L .47289 .34662 L p .332 0 0 r
F P
0 g
s
.47289 .34662 m .46888 .3516 L .5317 .34744 L p .332 0 0 r
F P
0 g
s
.73273 .40088 m .72083 .40275 L .66834 .37496 L p .447 .715 .981 r
F P
0 g
s
.65941 .37416 m .66834 .37496 L .72083 .40275 L p .066 .534 .897 r
F P
0 g
s
.53123 .34275 m .5317 .34744 L .59397 .35376 L p .45 0 0 r
F P
0 g
s
.38635 .36637 m .39444 .37028 L .3391 .39633 L p .646 .885 .984 r
F P
0 g
s
.3391 .39633 m .32776 .39406 L .38635 .36637 L p .646 .885 .984 r
F P
0 g
s
.74441 .39427 m .73273 .40088 L .67719 .37134 L p .659 .755 .921 r
F P
0 g
s
.66834 .37496 m .67719 .37134 L .73273 .40088 L p .447 .715 .981 r
F P
0 g
s
.75585 .38316 m .74441 .39427 L .68589 .36293 L p .75 .746 .848 r
F P
0 g
s
.67719 .37134 m .68589 .36293 L .74441 .39427 L p .659 .755 .921 r
F P
0 g
s
.37838 .35765 m .38635 .36637 L .32776 .39406 L p .652 .749 .921 r
F P
0 g
s
.32776 .39406 m .31661 .38704 L .37838 .35765 L p .652 .749 .921 r
F P
0 g
s
.46077 .35405 m .46483 .35456 L .4026 .36977 L p .304 .798 .829 r
F P
0 g
s
.76705 .36834 m .75585 .38316 L .69443 .34995 L p .79 .731 .798 r
F P
0 g
s
.68589 .36293 m .69443 .34995 L .75585 .38316 L p .75 .746 .848 r
F P
0 g
s
.78901 .33274 m .77807 .35105 L .71106 .31395 L p .814 .718 .759 r
F P
0 g
s
.71106 .31395 m .71927 .29362 L .78901 .33274 L p .814 .718 .759 r
F P
0 g
s
.77807 .35105 m .76705 .36834 L .7028 .33321 L p .808 .722 .77 r
F P
0 g
s
.69443 .34995 m .7028 .33321 L .76705 .36834 L p .79 .731 .798 r
F P
0 g
s
.7028 .33321 m .71106 .31395 L .77807 .35105 L p .808 .722 .77 r
F P
0 g
s
.37057 .34435 m .37838 .35765 L .31661 .38704 L p .626 .642 .846 r
F P
0 g
s
.31661 .38704 m .30569 .3755 L .37057 .34435 L p .626 .642 .846 r
F P
0 g
s
.3629 .32728 m .37057 .34435 L .30569 .3755 L p .605 .576 .795 r
F P
0 g
s
.30569 .3755 m .29499 .36025 L .3629 .32728 L p .605 .576 .795 r
F P
0 g
s
.67719 .37134 m .66834 .37496 L .60388 .35652 L p .449 .752 .993 r
F P
0 g
s
.59893 .35687 m .60388 .35652 L .66834 .37496 L p .009 .549 .841 r
F P
0 g
s
.35534 .30767 m .3629 .32728 L .29499 .36025 L p .591 .541 .767 r
F P
0 g
s
.29499 .36025 m .28445 .34251 L .35534 .30767 L p .591 .541 .767 r
F P
0 g
s
.28445 .34251 m .27399 .32374 L .34782 .287 L p .586 .528 .756 r
F P
0 g
s
.34782 .287 m .35534 .30767 L .28445 .34251 L p .586 .528 .756 r
F P
0 g
s
.45675 .34909 m .46077 .35405 L .39444 .37028 L p .582 .865 .995 r
F P
0 g
s
.39444 .37028 m .38635 .36637 L .45675 .34909 L p .582 .865 .995 r
F P
0 g
s
.53218 .35011 m .53265 .3493 L .60388 .35652 L p .029 .593 .793 r
F P
0 g
s
.68589 .36293 m .67719 .37134 L .6088 .35172 L p .658 .753 .92 r
F P
0 g
s
.60388 .35652 m .6088 .35172 L .67719 .37134 L p .449 .752 .993 r
F P
0 g
s
.45279 .33928 m .45675 .34909 L .38635 .36637 L p .654 .75 .92 r
F P
0 g
s
.38635 .36637 m .37838 .35765 L .45279 .33928 L p .654 .75 .92 r
F P
0 g
s
.6088 .35172 m .60388 .35652 L .53265 .3493 L p .474 .792 .999 r
F P
0 g
s
.69443 .34995 m .68589 .36293 L .61364 .34207 L p .73 .717 .838 r
F P
0 g
s
.6088 .35172 m .61364 .34207 L .68589 .36293 L p .658 .753 .92 r
F P
0 g
s
.53313 .34403 m .53265 .3493 L .46077 .35405 L p .521 .832 1 r
F P
0 g
s
.46077 .35405 m .45675 .34909 L .53313 .34403 L p .521 .832 1 r
F P
0 g
s
.4489 .32486 m .45279 .33928 L .37838 .35765 L p .656 .655 .837 r
F P
0 g
s
.37838 .35765 m .37057 .34435 L .4489 .32486 L p .656 .655 .837 r
F P
0 g
s
.7028 .33321 m .69443 .34995 L .61839 .32782 L p .758 .69 .786 r
F P
0 g
s
.61364 .34207 m .61839 .32782 L .69443 .34995 L p .73 .717 .838 r
F P
0 g
s
.53265 .3493 m .53313 .34403 L .6088 .35172 L p .474 .792 .999 r
F P
0 g
s
.71106 .31395 m .7028 .33321 L .62307 .30977 L p .77 .675 .758 r
F P
0 g
s
.61839 .32782 m .62307 .30977 L .7028 .33321 L p .758 .69 .786 r
F P
0 g
s
.71927 .29362 m .71106 .31395 L .62768 .28915 L p .773 .669 .748 r
F P
0 g
s
.62307 .30977 m .62768 .28915 L .71106 .31395 L p .77 .675 .758 r
F P
0 g
s
.44507 .30663 m .4489 .32486 L .37057 .34435 L p .649 .599 .784 r
F P
0 g
s
.37057 .34435 m .3629 .32728 L .44507 .30663 L p .649 .599 .784 r
F P
0 g
s
.61364 .34207 m .6088 .35172 L .53313 .34403 L p .657 .752 .92 r
F P
0 g
s
.62768 .28915 m .63227 .26744 L .71927 .29362 L p .773 .669 .748 r
F P
0 g
s
.53359 .33389 m .53313 .34403 L .45675 .34909 L p .655 .751 .92 r
F P
0 g
s
.45675 .34909 m .45279 .33928 L .53359 .33389 L p .655 .751 .92 r
F P
0 g
s
.4413 .28582 m .44507 .30663 L .3629 .32728 L p .644 .569 .756 r
F P
0 g
s
.3629 .32728 m .35534 .30767 L .4413 .28582 L p .644 .569 .756 r
F P
0 g
s
.43754 .26392 m .4413 .28582 L .35534 .30767 L p .641 .559 .746 r
F P
0 g
s
.35534 .30767 m .34782 .287 L .43754 .26392 L p .641 .559 .746 r
F P
0 g
s
.53313 .34403 m .53359 .33389 L .61364 .34207 L p .657 .752 .92 r
F P
0 g
s
.61839 .32782 m .61364 .34207 L .53359 .33389 L p .708 .692 .833 r
F P
0 g
s
.53405 .31914 m .53359 .33389 L .45279 .33928 L p .683 .672 .832 r
F P
0 g
s
.45279 .33928 m .4489 .32486 L .53405 .31914 L p .683 .672 .832 r
F P
0 g
s
.62307 .30977 m .61839 .32782 L .53405 .31914 L p .724 .655 .78 r
F P
0 g
s
.53359 .33389 m .53405 .31914 L .61839 .32782 L p .708 .692 .833 r
F P
0 g
s
.5345 .30056 m .53405 .31914 L .4489 .32486 L p .688 .625 .78 r
F P
0 g
s
.4489 .32486 m .44507 .30663 L .5345 .30056 L p .688 .625 .78 r
F P
0 g
s
.62768 .28915 m .62307 .30977 L .5345 .30056 L p .73 .635 .752 r
F P
0 g
s
.53405 .31914 m .5345 .30056 L .62307 .30977 L p .724 .655 .78 r
F P
0 g
s
.63227 .26744 m .62768 .28915 L .53494 .2794 L p .732 .628 .742 r
F P
0 g
s
.5345 .30056 m .53494 .2794 L .62768 .28915 L p .73 .635 .752 r
F P
0 g
s
.53494 .2794 m .5345 .30056 L .44507 .30663 L p .689 .6 .752 r
F P
0 g
s
.44507 .30663 m .4413 .28582 L .53494 .2794 L p .689 .6 .752 r
F P
0 g
s
.53494 .2794 m .53539 .25714 L .63227 .26744 L p .732 .628 .742 r
F P
0 g
s
.53539 .25714 m .53494 .2794 L .4413 .28582 L p .689 .592 .742 r
F P
0 g
s
.4413 .28582 m .43754 .26392 L .53539 .25714 L p .689 .592 .742 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{269.938, 232.062},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005A00018R000`400?l00000o`00003ooooooomB
ooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomBooooo`00oooooomB
ooooo`00hOooool4o`000003oa0@4?oooooooooo06Wooooo003Sooooo`03o`000?oooooooooo06_o
oooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003S
ooooo`03o`000?oooooooooo06_ooooo003Sooooo`03o`000?oooooooooo06_ooooo003Sooooo`03
o`000?oooooooooo06_ooooo003Qooooo`03oeEEEOmVIVKo000006gooooo003nooooo`Co000000?o
410@ooooooooool0C?ooool00?oooooo0Oooool00ol0003oooooooooo`1>ooooo`00k?ooool2o`00
00Oooooo1_l00005ooooo`03o`000?oooooooooo04kooooo003Yooooo`?o000000?oooooo`000?oo
ool04Oooool00ol0003oooooooooo`1>ooooo`00ioooool2o`0000Cooooo0_l0000Aooooo`03o`00
0?oooooooooo04kooooo003Tooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooo`00
000@ooooo`03o`000?oooooooooo04kooooo003Rooooo`;o00001Oooool01_l0003ooooooooooooo
oooo0000ooooo`;o00003oooool00ol0003oooooooooo`1>ooooo`00goooool3o`0000_ooooo0_l0
00000ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo0000053ooooo003Mooooo`;o00003_ooool0
1Ol0003ooooooooooooooooo000005oooooo003Jooooo`Co00003oooool01Ol0003ooooooooooooo
oooo000005oooooo003Hooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0G?ooool00=Gooooo0ol0000Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00=?ooooo0_l0000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Foooool009gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo1?l0000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0F_ooool009gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00001?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo0_l0001Kooooo`00WOooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool05_ooool3o`00023ooooo00?o0000ooooooooool00oooool2o`00
05_ooooo002Mooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Eoooo
o`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo002Mooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0ol0000U
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool009gooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`00WOooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool3o`0002[ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00WOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l0000=ooooo`;o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo002looooo`?o0000;oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo002jooooo`;o00000oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00So
oooo0_l0001Fooooo`00]oooool3o`0003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1Dooooo`00]Oooool2o`0003Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`00/_ooool3o`0003Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`00/?ooool2o`0000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05;ooooo002]ooooo`?o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0DOooool00:_ooooo0_l00012ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00:Sooooo0ol00014ooooo`03o`000?oo
oooooooo00_ooooo0ol0001Aooooo`00Y_ooool2o`0000?ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo002Sooooo`?o0000BOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo002Qooooo`;o0000C?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo04kooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h07oooool3o`0004kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo0_l00003ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`00N_ooool01Ol@413ooooo
oooooooooooo410@01[ooooo0ol0001Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0C?ooool007[ooooo00Go0000ooooooooooooooooo`00000Hooooo`;o0000E_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo001jooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0005Sooooo00?o0000ooooooooool04?ooool2o`00017ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM02Kooooo001joooo
o`05oa0@4?ooooooooooooooool@41004oooool2o`0000?ooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Uooooo`00N_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg013ooooo0ol0001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Ooo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo02Cooooo
001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03_ooool2o`00063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`0Uooooo`00R_ooool4o`00067ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
02Kooooo0028ooooo`;o00000oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool0:?ooool008Gooooo0ol0001Xooooo`03o`000?oooooooooo01Cooooo0_l0000<ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0Xooooo`00Poooool2o`0006_o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`00000<ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0002Oooooo0020ooooo`Co0000K?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Gooooo001nooooo`;o00001?ooool00ol0003oooooooooo`1Yooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0AOooool007_ooooo0ol0001booooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0A?ooool007Wooooo0_l0001eooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0@oooool007Kooooo0ol000000ooooooo0000ooooo`1doooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0@oooool007Cooooo0_l0001jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0@_ooool003cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01oooooo0ol0001loooo
o`03o`000?oooooooooo01Sooooo0_l00014ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo0_l0001oooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@Oooool003Cooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00000_ooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0_l00024ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0@?ooool003cooooo00Go0000ooooooooooooooooo`00000<oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`05Oooool3o`0008Kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0oooooo`00??ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool05Oooool3o`0008Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0n
ooooo`00??ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool3
o`0000?ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Looooo`?o0000?oooool0
03cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0008kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0mooooo`00GOooool3o`00097ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0looooo`00Foooool2o`0000;ooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo001Hooooo`?o0000
U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo001Fooooo`;o0000VOoo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Cooooo`?o0000Voooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo001Aooooo`;o00000_ooool00ol0
003oooooooooo`2Iooooo`03o`000?oooooooooo023ooooo0_l0000kooooo`00C_ooool3o`0000Go
oooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03So
oooo001<ooooo`;o0000Xoooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Sooooo
0019ooooo`Go0000Xoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Oooooo0017
ooooo`;o0000Z?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Kooooo000Poooo
o`Co000000?o410@ooooooooool07Oooool3o`000:[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0fooooo`008_ooool00ol0003oooooooooo`0Mooooo`;o0000[Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo000Gooooo`Ko00001Oooool00ol0003ooooo
ooooo`0Jooooo`?o00000_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo02Cooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0:_ooool002;ooooo00?o0000ooooooooool0
6?ooool2o`000;;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0:_ooool002;ooooo00?o0000ooooooooool05Oooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100:_ooool002;ooooo00?o0000ooooooooool04oooool4o`000;Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002;ooooo
00?o0000ooooooooool04?ooool3o`000;[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000:_ooool0023ooooo00?oEEEEofIVI_l00000
4?ooool2o`000;gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100:_ooool0033ooooo0ol0002oooooo`03o`000?oooooooooo02Kooooo
0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool002kooooo0_l00002ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool0:Oooool02Ol0003oooooooooooooooook^k^oc8b
<_l0003o<S8bonk^kP0Zooooo`00:oooool3o`000<Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0_ooooo`00:Oooool2o`000<Oooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0_ooooo`009_ooool4o`000<Sooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0^ooooo`009Oooool2o`0000?ooooo00?o0000ooooooooool0aOooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo02gooooo000Uooooo`03o`000?oooooo000008kooooo3_l0000^
ooooo`03o`000?oooooooooo02_ooooo0_l0000_ooooo`006oooool4o`000003oa0@4?oooooooooo
00?ooooo00Co0000oooooooooooo0000O_ooool?o`0000So/9Nm00?o0000ok^P_OnkX;d00onkX;d;
o`0002?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0/ooooo`007Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000Loooool:o`0001Oo/9Nm00?o0000
ok^P_OnkX;d03_nkX;d:o`0001Wooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0[
ooooo`004_ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooo
ooooool0K?ooool4o`0000;oY8nn00?o0000ok2G_On`Ukd07?n`Ukd00ol0003o^j2mok^P_@0Hok^P
_@Oo00004_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02_ooooo000Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`Co
00001_nTSkh00ol0003o/9Nmok2G_@0Lok2G_@03o`000?nkX;go^j2m01co^j2m00?o0000olF[_oo5
Zkl00ol0000?ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:_ooool001gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo
1?l0000;ojB?_P03o`000?n`Ukgo/9Nm01_o/9Nm00?o0000ok^P_OnkX;d07?nkX;d00ol0003oaJ^o
olF[_`03olF[_`?o00003?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Wooooo
000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Mooooo`Co00003onTSkh00ol0003o/9Nmok2G_@0Kok2G_@03o`000?nkX;go^j2m01_o^j2m00?o
0000olF[_oo5Zkl01oo5Zkl3o`0000Wooooo00?o0000ooooooooool0;oooool2o`0002_ooooo000M
ooooo`03o`000?oooooooooo00?ooooo0ol00008ooooo`03o`000?oooooooooo05Sooooo1?l0000C
ojB?_P03o`000?n`Ukgo/9Nm01Co/9Nm2?l00003ok^P_@;o00006?nkX;d00ol0003oaJ^oolF[_`0:
olF[_`?o00001_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo000Koooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Coooo
o`Co00006?nTSkh00ol0003o/9Nmok2G_@04ok2G_@oo00001on`VL000ol0003o^Z;0okZR`003okZR
`0[o00003_nkX;d00ol0003oaJ^oolF[_`0=olF[_`?o00001?ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Sooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Coooool3o`0001[oY8nn0ol000000on`Ukgo0000o`000003o`0001Ko/9W000?o0000okZR`?nj
X/003OnjX/09o`0000Co^j2m00?o0000olF[_oo5Zkl04Oo5Zkl3o`000003ooooool0003ooooo03;o
oooo00?o0000ooooooooool09oooool002?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1<ooooo`;o000000?oUXO1o`000?nTSkh05_nTSkh4o`0000;oY97100?o0000ok2I`?n`VL00
6_n`VL000ol0003o^Z;0okZR`00FokZR`0Go00005_o5Zkl3o`0003?ooooo00?o0000ooooooooool0
9_ooool002?ooooo0_l0000=ooooo`03o`000?oooooooooo04Wooooo0_l00004oiJ7`@03o`000?nT
SkkoY8nn013oY8nn1?l00006ojBA`@03o`000?n`VL3o/9W001[o/9W000?o0000okZR`?njX/006_nj
X/000ol0003oaJc2olF/`P03o`0001;oaJ^o00?o0000olF[_ol000000_l0000`ooooo`03o`000?oo
oooooooo02Kooooo000Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A_ooool2
o`0000KoUXO100?o0000ojB?__nTSkh03?nTSkh4o`0000[oY97100?o0000ok2I`?n`VL006_n`VL00
0ol0003o^Z;0okZR`00JokZR`003o`000?o5[<;oaJc200?oaJc20ol0000?olF[_`03o`000?o5Zkoo
aJ^o00;oaJ^o0_l0000^ooooo`;o00009oooool002?ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`13ooooo`;o00002OnFQl400ol0003oY8nnojB?_P08ojB?_P?o00003onTTL400ol0
003o/9W0ok2I`00Iok2I`003o`000?njX/3o^Z;001[o^Z;000?o0000olF/`_o5[<801_o5[<83o`00
00coaJ^o00?o0000olF[_oo5Zkl00_o5Zkl01?l0003od;O2o`000?l0000^ooooo`03o`000?oooooo
oooo02Cooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@?ooool2o`00
00_oUXO100?o0000ojB?__nTSkh01?nTSkh4o`0001;oY97100?o0000ok2I`?n`VL004_n`VL08o`00
00?o^Z;00_l0000FokZR`003o`000?o5[<;oaJc200[oaJc21?l00008olF[_`05o`000?o5ZkooaJ^o
olF[_ol000001?o@]l82o`0002cooooo00?o0000ooooooooool09?ooool002;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0nooooo`03o`000?nFQl7oUXO100_oUXO100Co0000ojB?
__nTSkkoY8nn0ol0000FojBA`@03o`000?n`VL3o/9W000Co/9W03_l00007ok2Oa`03o`000?niYlOo
^JO700?o^JO72Ol0000=okZR`003o`000?o5[<;oaJc200koaJc20ol00004olF[_`;o00000oo5Zkl0
0ol0003od;O2om2g`P04om2g`P03o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool0
02;ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo0_l0000>oiJ7`@?o00006?nTTL43o`00
0003ok2I`?l0003o000000?o00005On`WlL00ol0003o^JO7okVWa`0<okVWa`Wo00001?njX/000ol0
003oaJc2olF/`P0AolF/`PCo000000GoaJ^oo`000?o5ZkooaJ^oo`000008om2g`P;o0000:oooool0
0ol0003oooooooooo`0Rooooo`008_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03Sooooo0_l0000>oiJ7`@;o000000?oUh[4o`000?nTTL404onTTL45o`0000;oYYW800?o0000ok2O
aon`WlL06On`WlL00ol0003o^JO7okVWa`0EokVWa`Go00004Oo5[<83o`0000;oaJc21?l000000oo5
Zkoo0000om2g`P09om2g`P;o0000:Oooool00ol0003oooooooooo`0Rooooo`008_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo0_l0000>oiJ7`@;o00001?nGR/@00ol0003o
Y971ojBA`@0=ojBA`@Co00001onVVLP00ol0003o/9o7ok2Oa`0Iok2Oa`03o`000?niYlOo^JO701Wo
^JO700?o0000ol:`bOo2/<T00ol00009olF/`P?o00002?o5[<83o`0000cod;O20_l0000Wooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool002;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0boooo
o`;o00003_nFQl42o`0000KoUh[400?o0000ojBA`OnTTL402OnTTL44o`0000coYYW800?o0000ok2O
aon`WlL06?n`WlL00ol0003o^JO7okVWa`0HokVWa`03o`000?o2/<Wo`[3900Co`[391?l00002olF/
`P?o00003?o5[<84o`0000cod;O20_l0000Wooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`008Oooool3o`00
01Oooooo00?o0000ooooooooool0;oooool2o`0000koUXO10_l00008oiN:a003o`000?nTTL7oY971
00CoY9711Ol0000@ojJIb003o`000?n`WlOo/9o700_o/9o73_l00004okVWa`?o00004oniYlL00ol0
003o`[39ol:`b@07ol:`b@Go00003?o5[<800ol0003oc[S5o`000002oljha@03o`000?o@]l;od;O2
00_od;O20_l0000Uooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo01Sooooo0_l0000]oooo
o`;o00003OnFQl43o`0000_oUh[400?o0000ojBA`OnTTL400ol0000CojJIb0?o000000?o/9o7o`00
0?l000002_l0000=ojj/e003o`000?ne/MGo]K7E00Go]K7E3Ol00006okVWa`03o`000?o2/<Wo`[39
00Co`[390ol00005ol:`b@?o00002Oo5[<801?l0003oc[S5oljhaOl00002oljha@;o00003Oo@]l80
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0:Oooool00ol0003oQ7o5o`00000;oiJ7`@;o00003OnGR/@3o`0001?oYYW8
1?l00002ojNWeP03o`000?n^[=Co[ZcD01So[ZcD00?o0000okFaeOne/MD04_ne/MD6o`0000Co`[39
0ol0000;ol:`b@Co00001Oo5[<801Ol0003oc[S5oljhaOo>^<Go000000?oc[S50_l0000<om2g`P;o
00009?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Oooooo00Go0000ohAoaOn4OlGoQ7o5o`000008oiJ7`@;o00003OnGR/@2o`000003oiZCbol0
003oYYW800ooYYW81?l00006ojNWeP03o`000?n^[=Co[ZcD01So[ZcD00?o0000okFaeOne/MD05one
/MD00ol0003o^[OFo`000003o`00017o`[390ol000000oo5[<;o0000oljha@04oljha@03o`000?o>
^<Goc[S500;oc[S50_l0000<om2g`P;o00008_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`001Ol00002ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00007Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?n4OlGoQ7o500;oQ7o500?o0000oiJ7`OnFQl401?nFQl42o`0000goUh[4
0_l00004oiZCb`03o`000?nVVLSoYYW800SoYYW81Ol0000;ojNWeP03o`000?n^[=Co[ZcD017o[ZcD
1ol0000HokFae@?o00001?nj]mH4o`00013o`[390_l00005oljha@03o`000?o>^<Goc[S500Coc[S5
00?o0000om2g`_o@]l802oo@]l800ol0003oooooooooo`0Nooooo`?o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?n4OlGoQ7o500CoQ7o500Co0000oiJ7`OnFQl7oUXO10_l0000=oiN:
a0;o00001_nJTl/00ol0003oYYW8ojJIb004ojJIb0Co00004?nWYmH00ol0003o[ZcDojj/e004ojj/
e0go00001_nW`>/00ol0003oZ<3[ojS0j`02ojS0j`Wo00002?ne/MD4o`0000[o^[OF0ol0000>ol:`
b@03o`000?o:^lco000000Coc[S500?o0000oljhaOo>^<D01?o>^<D2o`0000_od;O20_l0000Qoooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo027ooooo00?o0000ohAoaOn4OlD01On4
OlD01?l0003oUXO1o`000?l0000=oiN:a0;o00002?nJTl/01?l0003oYYW8ojJIb?nVVLP3o`0001;o
YjOF0ol000000on^[=Co0000o`000003o`0001;oYl3[00?o0000ojS0jonX`>/03?nX`>/8o`0000?o
]K7E00?o0000okZge_nj]mH02onj]mH3o`0000[o`[3900?o0000olZkc?o:^l`00_o:^l`2o`0000;o
c[S500?o0000oljhaOo>^<D01Oo>^<D2o`0000Sod;O200Co0000om[7a_oJalKo00008Oooool00ol0
003oooooooooo`0Looooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ohAo
aOn4OlD01_n4OlD2o`0000coUh[40ol0000:oiZCb`?o00004_nWYmH4o`0000;oYko[00?o0000ojO0
jonW`>/04?nW`>/7o`00013oZ<3[0ol00003ojS0j`Co00004?nj]mH4o`0000Go`[3900?o0000olZk
c?o:^l`01Oo:^l`00ol0003oc[S5o`000009oljha@;o00001Oo@]l800ol0003of/O6om[7aP02om[7
aP03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0Mooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?l000002_nGR/@2o`00
00_oVY?;0_l000000onPY=So0000ojNWeP0>ojNWePCo00001onW_n/00ol0003oYl3[ojO0j`05ojO0
j`[o00001_n5e?l00ol0003oNL[oogW:o`02ogW:o`So000000CoZ<3[o`000?l0003o00002OnX`>/0
0ol0003oZ<3[ojS0j`04o`0000ko^[OF0ol00002ol:`b@03o`000?o:^lcob[_<00Kob[_<0ol0000:
oljha@03o`000?o@]l;od;O200;od;O200?o0000om[7a_oJalH00ooJalH00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Cooooo0_l0000Sooooo`03o`000?oooooooooo01_ooooo00?o0000ohAoaOn4OlD01_n4OlD0
1Ol0003oQh?8ohN3b?n7PlSo000000OoUh[40_l0000;oiZCb`;o00001?nPY=P00ol0003oYjOFojNW
eP09ojNWeP?o00002_nW_n/3o`000003ojO0jol0003o000000;o00001_n5e?l<o`0000[oNL[o2_l0
0004ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[0ol0000>okZgeP;o00002oo:^l`2o`0000[oc[S50_l0
00000oo@]l;o0000om[7aP06om[7aP03o`000?oooooooooo01kooooo00?o0000ooooooooool06_oo
ool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?n4OlGo
Q7o500KoQ7o500?o0000ohN3b?n7PlP00on7PlP00ol0003oUh[4oiN:a002oiN:a0;o00002onJTl/2
o`0000OoX:CH00?o0000ojNWe_nWYmH01?nWYmH4o`0000SoYko[1Ol000001?nDgOko0000o`000?l0
0003ohGDo`[o00000olQ[LT4ok2Qb@03o`000?nhZ<Wo^:S900Co^:S91ol00008ogW:o`Co00002onX
`>/4o`0000_o^[OF00?o0000oknnfOl000002oo:^l`2o`0000[oc[S50_l00008om[7aP03o`000?oo
oooooooo01cooooo00?o0000ooooool000006oooool0023ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01On7PlP0
1?l0003oUh[4oiN:a?l0000;oiZCb`;o00002OnPY=P01?l0003oYjOFojNWe_nWYmH3o`0000OoYko[
1Ol00003oiCMoP?o000000CoCLcDo`000?l0003o00001?lQ[LT3ojNLbP03o`000?n`XLWo/:7900Wo
/:7900?o0000okRXbOnhZ<T00onhZ<T3o`0000?o^:S900Co0000okn`bono/<_o00000_l7Ul/7o`00
00?oL/3n0_l0000;ojS0j`Co00001_nj]mH00ol0003o_kkIoknnf@02oknnf@03o`000?o:^lcob[_<
00Oob[_<00Co0000olZkc?l0003o00002?o>^<D00ol0003of<O9o`000008om[7aP03o`000?oooooo
oooo01gooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Eooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP2o`00
00_oVY?;0_l0000;oj2Tf0?o00001onW_n/4o`0000GoU=gn2Ol00009ojNLbP03o`000?n`XLWo/:79
00So/:7900?o0000okRXbOnhZ<T00ol00006okRXb@03o`000?no/<_o_k3;00?o_k3;0ol00002ojfm
i@04o`000?n^_^Ko0XcGo`:<e`GoL/3n0ol0000:ojS0j`?o00000_nj]mH00ol0003o_kkIoknnf@04
oknnf@;o00002?o:^l`01?l0003ob[_<olZkc?l00006oljha@05o`000?oHalWof<O9omS7bOl00000
2?oJalH00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo000Oooooo`;o0000:?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7
PlP00ol0003oSHk?o`000009oiZCb`;o00002onPY=P2o`0000;oY[o[00?o0000ojNojonW_n/00_nW
_n/3o`0000KoU=gn1Ol000001OnW^NKo0000o`000?nNUlgo000000_oYic:00?o0000ok2QbOn`XLT0
2?n`XLT3o`0000So^:S900?o0000okn`bono/</01ono/</2o`0000Go[[kV00Co0000o`:<eol0003o
00000omb`?h4o`0000WoZ<3[0_l00009oknnf@;o00001oo:^l`00ol0003ob[_<olZkc002o`0000?o
c[S500?o0000omS7bOoHalT00ooHalT00ol0003of/O6om[7aP06om[7aP03o`000?oooooooooo01go
oooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP01Ol0003oSHk?
ohf>con=S/oo000000KoVY?;0_l0000;oj2Tf0;o00001?nV_n/3o`0000SoU=gn0ol00004ojNiiP;o
00001?nNUld00ol0003oYic:ojNLbP07ojNLbPgo000000?o^:S9o`000?l000000ol00004okRXb@03
o`000?no/<_o_k3;00So_k3;00Co0000olJicOl0003o00001On^_^H00ol0003o0XcGo`000003o`00
00;oL/3n1?l00006ojS0j`03o`000?nX`N_o000000Wo_kkI0_l00006olZkc004o`000?o:^lcob[_<
olZkc0;o000000?oc[S5o`000?oHalT01OoHalT00ol0003of/O6om[7aP06om[7aP03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool001oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0?ooooo`03o`000?n4OlGoQ7o500KoQ7o500?o0000ohN3b?n7PlP01_n7PlP00ol0
003oSHk?ohf>c`03ohf>c`04o`000?nJTl_oVY?;oiZCb`;o00002onPY=P2o`0000CoY[o[0_l00003
ojGRn`03o`000?nDgOkoU=gn00;oU=gn0_l00002ojJii`03o`000?nW^NKoYkWV00;oYkWV00?o0000
oijGcOnNUld01OnNUld00ol0003oYic:ojNLbP03ojNLbP?o00000_nTRkX00ol0003o/9>iok2C^@02
ok2C^@?o00000_n`TkT00ol0003o^ibiok^L^@04ok^L^@Go00002Ono/</00ol0003oa[W=olJic@02
olJic@;o00001_n^_^H2o`000004o`:<eol0003o0000o`0000?oL/3n0ol00002ojS0j`03o`000?nX
`N_oZ<7[00;oZ<7[0_l00008oknnf@03o`000?o:^lcob[_<00?ob[_<00?o0000olZkc?o:^l`00oo:
^l`00ol0003of<O9omS7b@06omS7b@03o`000?oJalKof/O600Kof/O600?o0000ooooooooool06ooo
ool2o`0001Sooooo000Oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03Oooool0
0ol0003oQ7o5ohAoa@06ohAoa@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01?n=S/l0
1?l0003oVY?;oiZCbol0000:oj2Tf0?o00001?nV_n/2o`0000GoYN;k0ol00002okGVmP03o`000?nV
^NOoY[WW00;oY[WW00Co0000ojNii_nW^NKo00002?nNUld00ol0003oYic:ojNLbP03o`0000GoY8^j
00?o0000ok2C^Ol000000_l00005ok2C^@03o`000?nkW;Wo^ibi00So^ibi00?o0000olFW^_o5YkX0
0ol00004okn`b`03o`000?o6^Lgoa[W=00Coa[W=00?o0000ojjni_n^_^H00_n^_^H00ol0003o[/3W
ojk0i`07o`0000?oL/3n0_l00007ojS1j`;o00001ono_]T2o`0000Cob[_<00?o0000olZkc?o:^l`0
0_o:^l`2o`0000Sof<O900?o0000om[7a_oJalH01_oJalH00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo01Gooooo000Oooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03?oo
ool00ol0003oQ7o5ohAoa@05ohAoa@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=
S/l2o`0000[oX:CH0_l00005ojJoj`;o00001OnUh_/4o`0000;o]NKf00?o0000ojJiionV^NL00onV
^NL2o`0000[oWYO=0ol00007ojB;^P?o00002?n`TkT00ol0003o^ibiok^L^@08ok^L^@03o`000?o5
Yk[oaJNj00?oaJNj0ol000000ono/<_o0000olJic@06olJic@;o000000?o[[kVo`000?n^`>L00on^
`>L00ol0003oL:_eog2[m@06o`0000?oL[Ok00?o0000ojS1jonX`N/01OnX`N/2o`0000Oo_kkI0_l0
0003olZkc004o`000?o:^lcob[_<o`0000;odLO@00?o0000omS7bOoHalT01_oHalT00ol0003of/O6
om[7aP06om[7aP03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool001oooooo0_l0
000]ooooo`03o`000?oooooooooo00[ooooo00?o0000ofefbol000001On4OlD00ol0003oQh?8ohN3
b006ohN3b003o`000?n=S/ooSHk?00GoSHk?00Co0000oiRRg?nHX]co00001onPY=P2o`0000GoY[o[
0_l00005ojGRn`Co00000onei_H6ojJii`03o`000?nCTm3o000000SoWYO=0_l000000onGPkco0000
ojB;^P04ojB;^P?o00000_nTRkX00ol0003o/9>iok2C^@06ok2C^@03o`000?nkW;Wo^ibi00Oo^ibi
00?o0000olFW^_o5YkX01oo5YkX00ol0003oa[W=olJic@08olJic@03o`000?n^`>Oo[/3W00Co[/3W
00Go0000og2[mOm`ZoGoL:_eoaMji003oa28i@GoL[Ok0_l00006ojS1j`03o`000?no_]Wo_kkI00Ko
_kkI00Co0000olZkc?o:^lcob[_<0_l00004om77d003o`000?oHalWof<O900Kof<O900?o0000om[7
a_oJalH01_oJalH00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo000Nooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool01?l0003oKGK;ofefbol00003ohAo
a@03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=S/l00ol0003oV:;LoiRRg002oiRR
g003o`000?nPY=SoX:CH00;oX:CH0_l00005ojJoj`;o00001OnUh_/3o`0000;o[OWS0onei_H5ojJi
i`;o00000onCTm000ol0003oWYO=oijGc@02oijGc@?o00001?nGPk`00ol0003oY8^jo`000002o`00
00GoY8^j00?o0000ok2C^On`TkT01_n`TkT00ol0003o^ibiok^L^@07ok^L^@03o`000?o5Yk[oaJNj
00OoaJNj00Co0000om2c_Ol0003o00001oo6^Ld00ol0003ocL?Aojk0i`05ojk0i`06o`000?m`ZoGo
L:_eog2[mOl0003o5g[T0ol@R>D00ol0003oL[Okog:gn`02og:gn`;o00001OnX`N/2o`0000Oo_kkI
0_l000000oo:^lco0000om77d005om77d003o`000?oHalWof<O900Kof<O900?o0000om[7a_oJalH0
1_oJalH00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool01oooool00ol0003oKGK;ofefb`02ofefb`03o`000?n4
OlGo000000SoQh?800?o0000ohf>con=S/l01On=S/l00ol0003oV:;LoiRRg004oiRRg004o`000?nP
Y=SoX:CHo`0000GoY[o[0_l00004ojGRn`Co00000on]nN<4o`0000CoY[WW00?o0000oi>Cd?nCTm00
1?nCTm001?l0003oWYO=o`000?l00006oiN3_0?o00002?nTRkX00ol0003o/9>iok2C^@06ok2C^@03
o`000?nkW;Wo^ibi00Oo^ibi00?o0000olFW^_o5YkX01_o5YkX00ol0003od;>mom2c_@02om2c_@;o
00001?o6^Ld01?l0003ocL?Aolg3dOo=`m42o`0000Co[/3W00Oo0000og2[mOm`ZoGoL:_eo`000?lG
N^CoM00000;o48SU0_l00004og:gn`;o00001OnX`N/2o`0000Oo_kkI0ol00006om77d003o`000?oH
alWof<O900Kof<O900?o0000om[7a_oJalH01OoJalH00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01?ooooo000Nooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool0
0ol0003oKGK;ofefb`04ofefb`03o`000?n7PlSoQh?800KoQh?800?o0000ohf>con=S/l01On=S/l0
0ol0003oV:;LoiRRg005oiRRg0?o00001OnV_n/00ol0003oYN;kojGRn`02ojGRn`;o000000?oP^WS
oh?OY?l000001?l00002ol7Rl006o`000?nT^NSo0000o`000?nV^NOo00001onCTm02o`0000GoUh>l
0ol000000onGPkco0000ojB;^P06ojB;^Q7o00000onkW;T00ol0003oaJNjolFW^P07olFW^P03o`00
0?o@/kgod;>m00Cod;>m0_l000000oo6^Lgo0000olg3d@05olg3d@03o`000?n^`>Oo[/3W00;o[/3W
00So0000og2[mOm`ZoGoL:_eo`000?lGN^Co0000og@000;o48SU0_l00004og:gn`03o`000?nX`N_o
Z<7[00CoZ<7[0_l00004oknnf@03o`000?o3amco`lOL00;o00001_oAam000ol0003of<O9omS7b@06
omS7b@03o`000?oJalKof/O600?of/O600?o0000on?Ic?l000006oooool00ol0003oooooo`00000D
ooooo`007_ooool3o`00037ooooo0_l00005ooooo`03o`000?m]M/_oKGK;00CoKGK;00?o0000ohN3
b?n7PlP01On7PlP00ol0003oSHk?ohf>c`05ohf>c`03o`000?nHX]coV:;L00GoV:;L00Go0000ojJo
k?nV_ncoY[o/o`000002ojJoj`03o`000?nUh__oYN;k00;oYN;k0_l000000on2jN?oQn>Zoh?OY002
o`0000;oco[U00Co0000ol7Rl?o1h_3o00001?nT^NP00ol0003oTi?@oi>Cd005oi>Cd003o`000?n6
Nl3o000000;oUh>l0ol00005oiN3_003o`000?nTRk[o000000Co00000_nRP[400ol0003o[hb`ojn<
/006ojn</003o`000?nlU[3o_9J`00?o_9J`1_l00007olFW^P03o`000?o@/kgod;>m00Kod;>m00?o
0000olg3dOo=`m401_o=`m400ol0003o[/3Wojk0i`09o`000004o`19`_md003o0000oa28i@;o0000
0omb]o/2o`0000KoZ<7[0_l000000ono_]Wo0000ol?7g003ol?7g0;o00001_oAam000ol0003of<O9
omS7b@06omS7b@05o`000?oJalKof/O6om[7a_l000000_oSfL`00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo017ooooo000Nooooo`03o`000?oooooooooo03?ooooo00Go0000oooooooooooo
ooooo`000006ofefb`03o`000?maNlko000000GoQh?800?o0000ohf>con=S/l01On=S/l00ol0003o
V:;LoiRRg005oiRRg003o`000?nV_ncoY[o/00;oY[o/1?l00003ojGRn`?o000000CoQn>Zoh?OY?o?
om?o00000_o?n^D01Ol0003o`N;`ol7Rl?o1h_3o000000CoY;WX00?oQY3Fo`000?nCTm001?nCTm00
0ol0003oQW_0ohIk`003o`0000OoUh>l0ol00007oj:2/@03o`000?n_S;3o[hb`00Ko[hb`00?o0000
okbF/?nlU[001_nlU[000ol0003ob:6aolRQ/@05o`000003olFW^_l0003od;>m00Sod;>m00?o0000
om[2`Ol000001oo=`m42o`0000;o[/;X00Co0000ogRTk_mhY>koN:C^0_lkO>@2o`000005o`19`_l0
003o04NZo`000?l@R>D00_l00003og:gn`;o00001OnX`N/2o`0000Ko`lOL00?o0000om77d?oAam00
1OoAam000ol0003of<O9omS7b@06omS7b@03o`000?oJalKo000000CohmW<00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Aooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0=?ooool01?l0003oooooooooool00005ofefb`05o`000?maNlkoLG_>og5k
c_l000000on7PlP00ol0003oSHk?ohf>c`05ohf>c`03o`000?nHX]coV:;L00GoV:;L00?o0000ojJo
k?nV_n`00_nV_n`00ol0003o/n?gok?Sm`02ok?Sm`?o000000KoVo;8o`000?n7hj[oPmnToloodol0
0002oloji@05o`000?o1h_3o`N;`ol7Rl?l000001?nT^NP01?l0003oQY3FohJ@e_l00003oi>Cd0Co
000000?oQW_0o`000?nGPk`01OnGPk`2o`000003oi9h/ol0003oXX:a00OoXX:a00?o0000ojn</?n_
S;001_n_S;000ol0003o_9J`okbF/006okbF/003o`000?o8XK7ob:6a00Gob:6a0ol00007om2c_@05
o`000?oJ`/7of/;1om[2`Ol000001Oo=`m42o`0000Co[/;X00Co0000ogRTk_mhY>koN:C^0olkO>@6
o`000003oa28iOl0003oL[Ok00?oL[Ok0_l000000onX`N_o0000o`000002ojS1k003o`000?o3amco
`lOL00Co`lOL00?o0000om77d?oAam001OoAam000ol0003of<O9omS7b@06omS7b@03o`000?oSfLco
hmW<00?ohmW<00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`004oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=_ooool2o`0000KoKGK;00?o0000
og5kc_maNlh00_maNlh00ol0003oQh?8o`000007ohf>c`03o`000?nHX]coV:;L00GoV:;L00?o0000
ojJok?nV_n`00_nV_n`00ol0003o/n?gok?Sm`02ok?Sm`03o`000?n`n>_o000000;oVo;800OoQn>Z
o`000?o?om?ocooCo`000?o?n^Go000000Co`N;`00?o0000ojBij?nT^NP00_nT^NP01?l0003oQY3F
ohJ@e_n6T=H4o`0000GoQW_000Co0000oiN3_?nGPkcoUh>l0_l00003oi9h/`03o`000?nRP[7oXX:a
00KoXX:a00?o0000ojn</?n_S;001_n_S;000ol0003o_9J`okbF/006okbF/003o`000?o8XK7ob:6a
00Kob:6a00Co0000omB_/ol0003o00001Oo@/kd00ol0003of/;1om[2`@02om[2`@05o`000?o=`m7o
cL?Aolg3dOl000000_oAd=P01Ol0003o[/;Xojk2j?n^`^So000000?oN:C^00?o0000oc]li?lkO>@0
0_l?G=@4o`000004o`1HcOl0003o0000o`0000;oL[Ok0ol00005ojS1k003o`000?o3amco`lOL00Co
`lOL00?o0000om77d?oAam001OoAam000ol0003of<O9omS7b@05omS7b@03o`000?oSfLcohmW<00?o
hmW<00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`Co000000?o410@oooooooo
ool00_ooool001?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ofefbom]M//00om]M//00ol0003oLG_>og5kcP04og5kcP03o`000?n=S/ooSHk?00Go
SHk?00?o0000oiRRg?nHX]`01OnHX]`00ol0003oY[o/ojJok002ojJok003o`000?nchoOo/n?g00;o
/n?g00?o0000ok3hjol000000_nKl/P01On7hj[ocOo8o`000?o?om?o000000;oco[U00Go0000ol7R
l?o1h_3o`N;`o`000004ojBij003o`000?n6T=KoQY3F00Co00001on6Nl001?l0003oUh>lo`000?l0
0006oi9h/`03o`000?nRP[7oXX:a00KoXX:a00?o0000ojn</?n_S;001On_S;000ol0003o_9J`okbF
/006okbF/003o`000?o8XK7ob:6a00Gob:6a00?o0000omB_/ooD[k<00_oD[k<01Ol0003od;>mom2c
_Oo@/kgo000000Kof/;100?o0000olg3dOl000000ooAd=P00ol0003o[/;Xojk2j002ojk2j005o`00
0?mhY>koN:C^ogRTk_l000000_lkO>@3o`mLe0?o000000?o05S=o`000?l/Qn`00_l00003ogJ_mP03
o`000?nX`NcoZ<7/00?oZ<7/00?o0000ol?7g?o3am`01?o3am`2o`0000KodLO@00?o0000omS7bOoH
alT00ooHalT00ol0003oh=W?o`000005on?Ic003o`000?oooooooooo01_ooooo0_l0000:ooooo`03
o`000?oooooooooo00Cooooo000Cooooo`05o`000?ooooooooooooooool000001Oooool2o`0003Oo
oooo00?o0000ofefbom]M//01?m]M//00ol0003oLG_>og5kcP04og5kcP03ogb9e_l0003oSHk?00Co
SHk?00?o0000oiRRg?nHX]`01?nHX]`2o`0000CoY[o/00Co0000ok?SmonchoOo/n?g0_l000002On`
n>_o0000oi_bb?nKl/SoQn>Zolgob?l0003ocooCo`000002oloji@03o`000?o1h_3o`N;`00;o`N;`
00Co0000ojBij?nT^NSoY;WX1?l00003ohJ@eP03o`000?n6Nl3oQW_000GoQW_00_l00008oi9h/`03
o`000?nRP[7oXX:a00KoXX:a00?o0000ojn</?n_S;001On_S;000ol0003o_9J`okbF/005okbF/003
o`000?o8XK7ob:6a00Kob:6a00?o0000omB_/ooD[k<00ooD[k<2o`000003om2c_Ol0003of/;100Ko
f/;100?o0000om7@f?oAd=P00ooAd=P00ol0003o[/;Xojk2j002ojk2j004o`000?mhY>koN:C^o`00
00?o>gcT0_l?G=@2o`1=c0;o000000Co05S=o`000?l/Qnco;8O/1?mf[oH00ol0003oZ<7/ojS1k003
ojS1k003o`000?o3amco`lOL00?o`lOL00?o0000ol?7g?l000001_oAam001Ol0003of<O9omS7bOoH
alWo000000;oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool001?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo03Kooooo00?o0000ofefbom]M//00om]M//00ol0003oLG_>og5k
cP04og5kcP04o`000?mlRMKoO8WFo`0000?oSHk?00?o0000oiRRg?nHX]`01?nHX]`00ol0003oY[o/
ojJok002ojJok0;o00000onchoL01?l0003o/?S[ok3hjol00002oi_bb003o`000?o=olSo000000;o
cooC3Ol00005ohJ@eP03o`000?m`L/Go000000GoQW_000?o0000ogi]]_l000002?nBN;<00ol0003o
XX:aoj:2/@06oj:2/@03o`000?n_S;3o[hb`00Go[hb`00?o0000okbF/?nlU[001OnlU[000ol0003o
b:6aolRQ/@06olRQ/@03o`000?oD[k?oe:nc00Goe:nc0_l00007om[2`@03o`000?oAd=SodM3H00?o
dM3H00?o0000ojk2j?n^`^P00_n^`^P01Ol0003oN:C^ogRTk_mhY>ko000000;o>gcT00?o0000o`mL
e?l?G=@00_l0CL`2o`000004o`1HcOl0003o;8O/obb7k0CoMZof00?o0000ojS1k?nX`N`00onX`N`0
0ol0003o`lOLol?7g003ol?7g003o`000?o3amco000000KodLO@00?o0000omS7bOl000001?oPfLl0
0ol0003ohmW<on?Ic003on?Ic003o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`004oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0=Oooool00ol0003oKGK;ofefb`03ofefb`03o`000?maNlkoLG_>00CoLG_>00?o0000
ogb9e_mlRMH00_mlRMH00ol0003oSHk?ohf>c`06oiRRg003o`000?nV_ncoY[o/00;oY[o/00?o0000
ok?SmonchoL00_nchoL00ol0003o/?S[ok3hj`03oi_bb005olkobol0003ocOo8o`000?o?om<00_l0
00000ooKkMko0000olKKj003olKKj0Ko00001?n6T=H01Ol0003oL7;5og1baOm`L/Go000000?oQW_0
00Go0000ogi]]_mnKKKoOVffo`000007oi9h/`03o`000?nRP[7oXX:a00KoXX:a00Co0000ojn</?n_
S;3o[hb`2Ol00003okbF/003o`000?o8XK7ob:6a00Gob:6a00?o0000omB_/ooD[k<01_oD[k<00ol0
003ohKnfo`000005om[2`@03o`000?oTdlKo000000CodM3H00Co0000ojk2j?n^`^So[/;X1_l00003
oc]li0;o3ecD00?o0000o`1=c?l0CL`00_l000001Ol0F<go0000obb7k?l/Qnco000000?oMZof00?o
0000ojS1k?nX`N`00onX`N`00ol0003o`lOLol?7g003ol?7g003o`000?o3amco000000GodLO@0_l0
0005on3Ic`03o`000?oSfLcohmW<00?ohmW<00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?m]M/_oKGK;00CoKGK;00?o0000og5kc_maNlh01?ma
Nlh00ol0003oO8WFogb9eP03ogb9eP;o00001OnHX]`00ol0003oY[o/ojJok002ojJok003o`000?nc
hoOo/n?g00;o/n?g00?o0000ok3hjon`n>/00onKl/P01?o>ol_o0000olgob?l00002olood`05o`00
0?oKkMkofngNo`000?o6fnP01?l00003oj>jj@;oN8oM00Go0000ohJ@e_n6T=KoQY3Fo`000004og1b
a@03o`000?n6Nl3o000000CoOVff00?o0000oi9h/onBN;<01OnBN;<00ol0003oXX:aoj:2/@04oj:2
/@Ko00001?n_Qj/00ol0003o_9:/okbB[002okbB[0Ko00001Oo8XK400ol0003oe:ncomB_/`05omB_
/`05o`000?oQ_kKohKnfon6o]_l000000ooJ`/401?l0003oi=?6onCCa_l00004om7@f0Co00000_n^
`nT3oh6Pi`?o000000Go>gcTo`000?l?G=Co3ecDo`000002o`1=c0;o000000Go05S=o`000?l/Qnco
;8O/o`000003ogJ_mP03o`000?nX`NcoZ<7/00?oZ<7/00?o0000ol?7g?o3am`00_o3am`01?l0003o
`lOLol?7g?l00003om77d003o`000?oGe]Oo000000Goh=W?00?o0000on?Ic?oSfL`01?oSfL`00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool001?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000=Oooool00ol0003oKGK;ofefb`03ofef
b`03o`000?maNlkoLG_>00CoLG_>00?o0000ogb9e_mlRMH01?mlRMH2ohjQh005o`000?nHX]coV:;L
oiRRg?l000001?nV_n`00ol0003o/n?gok?Sm`02ok?Sm`04o`000?n`n>_o/?S[oi_bb0;o000000Go
c_o;o`000?o=olSo0000olood`02o`0000;ofngN0ol00002olKKj003o`000?nS^^WoXk[Y00;oXk[Y
00Ko0000ogR?gOmhSmgo0000ohJ@e_l00006og1ba@03o`000?mnKKKoOVff00CoOVff00?o0000oi9h
/onBN;<01OnBN;<00ol0003oXX:ao`000003o`0000;oXGf/00?o0000ojn7Zon_Qj/01On_Qj/00ol0
003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00?o00000_o8XK400ol0003oe:ncomB_/`05omB_
/`03o`000?oQ_kKohKnf00;ohKnf00?o0000om[2`Ol000001?oTdlH01_l0003odM3Hom7@f?l0003o
dmgOo`0000Co[/?Y00Co0000oh6Pion1X>OoPJ3W0_mJOmd3o`000004o`mLe?l0003o04g<o`1=c0;o
0E7>00?o0000o`1HcOl000000_l/Qn`01Ol0003oMZofogJ_m_mf[oKo000000GoZ<7/00?o0000ol?7
g?o3am`00_o3am`01_l0003o`lOLol?7g?l0003odLO@o`0000?oemKG00?o0000on3IcooPfLl00ooP
fLl00ol0003ohmW<on?Ic003on?Ic003o`000?oooooooooo01_ooooo0ol00007ooooo`03o`000?oo
oooooooo00Cooooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000ofefbom]M//01?m]M//0
0ol0003oLG_>og5kcP03og5kcP03o`000?mlRMKoO8WF00CoO8WF00Go0000ohjQh?n>XN3oSZ7Po`00
0002oiRRg0GoY[o/1?nchoL3ok3hj`;o000000GocooIo`000?o>ol_o0000olgob002o`000006onGd
e?l0003o0000o`000?oKkMko00000oo6fnP00ol0003oXk[Yoj>jj@02oj>jj@05o`000?mhSmgoN8oM
ogR?gOl000001om`L/D00ol0003oOVffogi]]P04ogi]]P03o`000?nBN;?oTWRc00?oTWRc1?l00006
oj5m[003o`000?n_Qj_o[hN[00Go[hN[00?o0000okbB[?nlTZ`01OnlTZ`00ol0003obIj/olVN[003
olVN[0?o00001_oD[k<00ol0003ohKnfon6o]P04on6o]P03o`000?oTdlKoi=?600?oi=?600?o0000
om7@f?l000000_oCgMl00ol0003o[/?Yojk3j@02ojk3j@05o`000?n1X>OoPJ3Woh6Piol000001?mJ
Omd00ol0003o3ecDo`000002o`1=c0;o0E7>00?o0000o`1HcOl000000_l/Qn`01Ol0003oMZofogJ_
m_mf[oKo000000GoZ<7/00?o0000ol?7g?o3am`00_o3am`01?l0003o`lOLo`000?l00004omOFe`03
o`000?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo00?oEEEEofIVI_l000001_ooool001cooooo00?o0000ooooooooool0
=?ooool00om;Jm7o0000ofefb`03ofefb`03o`000?maNlkoLG_>00CoLG_>00?o0000ogb9e_mlRMH0
0omlRMH00ol0003oSZ7PohjQh003ohjQh0?o00000onV_n`4ok?Sm`?o00000oo?omT01_l0003oc_o;
o`000?o=olSo0000onGde0?o00000_oKkMh00ol0003oa]_XolKKj002olKKj005o`000?nS^^WoXk[Y
oj>jjOl000001?mhSmd00om@Il_o0000og1ba@04og1ba@03o`000?mQGkWo000000GoOVff00?o0000
oi9h/onBN;<00ol00002oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01On_Qj/0
0ol0003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_l000000_l00003
omB_/`03o`000?oQ_kKohKnf00CohKnf00?o0000onCCa_oTdlH01?oTdlH01Ol0003odmgOom?MgooC
gMoo000000Co[/?Y00Go0000oh6Pion1X>OoPJ3Wo`000004oeYog@03od1Ydol?G=Co000000;o04g<
00?o0000o`5Ac_l1DLh00ol00002obb7k005o`000?mf[oKoMZofogJ_m_l000001OnX`N`01?l0003o
`lOLol?7g?o3am`2o`000003olK@h_l0003oemKG00CoemKG00?o0000on3IcooPfLl00ooPfLl00ol0
003ohmW<on?Ic003on?Ic003o`000?oooooooooo01cooooo0ol0000<ooooo`007?ooool00ol0003o
ooooooooo`0dooooo`;oBf_A00Co0000ofefbom]M/_o00001_maNlh00ol0003oO8WFogb9eP04ogb9
eP03o`000?n>XN3oSZ7P00?oSZ7P00?o0000ojJok?nV_n`01ol00002olcgj@05o`000?o?omWocooI
o`000?o>ol/01Ol000000ooUm=Co0000om_]gP02om_]gP05o`000?o6fnSoa]_XolKKj?l000001?nS
^^T00ol0003oN8oMogR?g@02ogR?g@;oD6O;00Go0000og1baOm`L/GoL7;5o`000002of5O^@03o`00
0?mnKKKoOVff00?oOVff0ol00005oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/0
1On_Qj/00ol0003o_9:/okbB[005okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_oF[:h0
0_oF[:h2o`000003omB_/ol0003ohKnf00CohKnf00?o0000ongD^_l000001?oTdlH2o`0000CodmgO
00Go0000ojk3jOn^`nWo[/?Yo`000003oh6Pi`03o`000?mJOmgoFWoM00;oFWoM00Co0000od1Ydol?
G=Co00000_l0CL`01?l0003o0E7>oaaVf_lLI]X2o`0000;o;8O/00Go0000ogJ_m_mf[oKoMZofo`00
0005ojS1k005o`000?o3amco0000olK@h_l000000_o6d>800ol0003oemKGomOFe`02omOFe`03o`00
0?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Iooooo`?o0000
0_ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`?oBf_A00?o
0000ofefbol000001_maNlh00ol0003oO8WFogb9eP03ogb9eP03o`000?n>XN3oSZ7P00?oSZ7P00?o
0000ojJok?nV_n`00_nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;oc?OY00Co0000oloofOo?omWo
cooI1Ol00003onGde005o`000?oKkMkofngNom_]g_l000000_o6fnP8o`0000?oN8oM00Ko0000oe1W
bom@Il_o0000og1baOl00004of5O^@07o`000?mnKKKoOVffogi]]_l0003oNFF`o`000007oi1b[@03
o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/00ol0003o_9:/okbB[005okbB[003
o`000?o9WZcobIj/00?obIj/00?o0000omJ/[_oF[:h01OoF[:h00ol0003ohKnfon6o]P04on6o]P04
o`000?o]e;[okMBjo`0000;oi=?600?o0000on[YcOl000001?oCgMl01Ol0003o[/?Yojk3jOn^`nWo
000000CoPJ3W00Go0000oeYogOmJOmgoFWoMo`000002od1Yd`04o`000?l0CLco04g<o`0000;o0E7>
0olLI]X2o`000003obb7k?l0003oMZof00;oMZof00?o0000ojS1k?nX`N`00_nX`N`2o`0000?oa]3R
00?o0000olK@h_l000001OoGe]L00ol0003oh=W?on3Ic`03on3Ic`03o`000?oSfLcohmW<00?ohmW<
00?o0000ooooooooool05Oooool3o`0000Gooooo00?o0000ooooooooool02_ooool001cooooo0_l0
000eooooo`05o`000?m;Jm7oBf_Aod][dOl000001_maNlh00ol0003oO8WFogb9eP03ogb9eP03o`00
0?n>XN3oSZ7P00?oSZ7P00?o0000ojJok?nV_n`00_nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;o
c?OY00?o0000oloofOo?omT01?l00002onSfc`05o`000?oUm=CoiOCDonGde?l000000ooKkMh3o`00
0003olSBhOnR^n[oX[_Z00?oX[_Z0_mUSnD00ol0003oN8oMo`000004oe1Wb`03o`000?mQGkWoHEni
00?oHEni00Co0000ogi]]_mnKKKo00000omiIK000ol0003oT7:]oi1b[@04oi1b[@03o`000?nQOJco
XGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/00ol0003o_9:/okbB[004okbB[003o`000?o9WZco
bIj/00CobIj/00?o0000omJ/[_oF[:h01OoF[:h2o`0000CohKnf00Oo0000ongD^_o]e;[okMBjo`00
0?oTdlKo000000;oj^W=00?o0000om?MgooCgMl00_oCgMl01Ol0003o[/?Yojk3jOn^`nWo000000Co
PJ3W00Go0000oeYogOmJOmgoFWoMo`000003od1Yd`;o000000Co04g<o`000?l1DLko0E7>0_lLI]X2
odR6j0?o00000omf[oH01_l0003oZ<7/o`000?l0003oZ<;/o`0000Coa]3R0_l00005omOFe`03o`00
0?oPfLooh=W?00?oh=W?00?o0000on?Ic?oSfL`00ooSfL`00ol0003oooooooooo`0Booooo`?o0000
2?ooool00ol0003oooooooooo`0:ooooo`007?ooool00ol0003oooooooooo`0dooooo`06o`000?m;
Jm7oBf_Aod][dOmCLmGo00001?maNlh00ol0003oO8WFogb9eP04ogb9eP03o`000?n>XN3oSZ7P00?o
SZ7P00Go0000ojJok?nV_ncoY[o/o`000004okgOl@03o`000?o<mnWoc?OY00Ko00000ooXm/l01Ol0
003oiOCDonGde?oUm=Co000000;ofngN0_l00003olSBh@03o`000?nR^n[oX[_Z00;oX[_Z00?o0000
ofF?iOmUSnD00_l00004oe1Wb`03o`000?mQGkWoHEni00?oHEni00?o0000ogi]]_l000001?miIK00
0ol0003oT7:]oi1b[@04oi1b[@03o`000?nQOJcoXGf/00GoXGf/00?o0000ojn7Zon_Qj/01?n_Qj/0
0ol0003o_9:/okbB[004okbB[003o`000?o9WZcobIj/00CobIj/00?o0000omJ/[_oF[:h01?oF[:h0
1?l0003oi;f`onBm/?l00002on6o]P03o`000?o]e;[okMBj00?okMBj00?o0000on[YcOoZjLd00_oZ
jLd00ol0003odmgOom?Mg`09o`000003oh6Piol0003oFWoM00;oFWoM00Co0000od1Ydom0JM?o@6WC
0_lfGlh2o`0000;o0E7>00?o0000oaaVf_lLI]X01?m8Q^P5o`0000CoZ<;/00?o0000olK@h_o6d>80
0_o6d>82o`0000GoemKG00?o0000on3IcooPfLl00_oPfLl00ol0003ohmW<on?Ic002on?Ic0;o0000
4?ooool4o`0000_ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0=Ooo
ool01?l0003oBf_Aod][dOm;Jm42oe=ce@05o`000?maNlkoLG_>og5kc_l000001OmlRMH00ol0003o
SZ7PohjQh003ohjQh003o`000?nV_ncoY[o/00;oY[o/00Co0000okgOlOnmgo7o_Moa1?l00002oloo
f@;o000000?oioK@o`000?oXm/l00_oXm/l00ol0003oiOCDonGde004o`000003omcLe_l0003ob=;Q
00?ob=;Q00Go0000oj:kj_nR^n[oX[_Zo`000003ofF?i@03o`000?m@Il_oD6O;00;oD6O;00?o=4Zk
o`000?mQGkT01?mQGkT00ol0003oNFF`ogUU/003ogUU/003o`000?n@LZgoT7:]00CoT7:]00?o0000
oj5m[?nQOJ`01OnQOJ`00ol0003o[hN[ojn7Z`04ojn7Z`03o`000?nlTZco_9:/00Co_9:/00?o0000
olVN[?o9WZ`01?o9WZ`00ol0003oeZb^omJ/[P04omJ/[P07o`000?oT_K3oi;f`onBm/?l0003ohKnf
o`000005ongD^P03o`000?oZjLgoj^W=00;oj^W=0ol000000ooAj^Oo0000ojg4j`02ojg4j`CoRYgP
0ol00002oeYog@05o`000?m0JM?o@6WCod1Ydol000000_lfGlh01?l0CLco0000o`5Ac_l1DLh2oaaV
fP04o`000?m8Q^SoB8KXodR6j0CoO:S_1OnX`^`00ol0003oa]3RolK@hP02olK@hP;o00001OoGe]L0
0ol0003oh=W?on3Ic`03on3Ic`06o`000?oSfLcohmW<o`000?oWkm;o00003Oooool3o`00013ooooo
00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0=Oooool01?l0003oBf_Aod][
dOm;Jm43oe=ce@03o`000?maNlko000000KoO8WF00?o0000ohjQh?n>XN000on>XN001Ol0003oY[o/
ojJok?nV_nco000000;o_Moa0ol000000oo<mnWo0000oloof@02oloof@04o`000?oWm]3oioK@o`00
00;oj?K?00Go0000onGde?oUm=CoiOCDo`000004omcLeP03o`000?o8d^7ob=;Q00;ob=;Q00?o0000
oj:kj_nR^nX00_nR^nX01Ol0003oIHoUofF?iOlPElko000000?oD6O;0_l00005of5O^@03o`000?mi
IK3oNFF`00CoNFF`00?o0000oi1b[On@LZd00on@LZd00ol0003oXGf/oj5m[003oj5m[0ko00000_nl
TZ`00ol0003obIj/olVN[004olVN[003o`000?oF[:koeZb^00?oeZb^00?o0000onBm/?oT_K000ooT
_K000ol0003okMBjongD^P03ongD^P;o00001?oZjLd01Ol0003odN[Wom7ZiooAj^Oo000000?o[LC[
1On:WN02og62e003o`000?mJOmgo000000?o@6WC00Go0000ocIOc_lfGlko=Uo>o`000002o`5AcP04
o`000?lLI][o76KJo`0000?oB8KX1?mlZ>l5ojS2k003o`000?o6d>;oa]3R00;oa]3R0_l00005omOF
e`03o`000?oPfLooh=W?00;oh=W?00?o0000on?Ic?l000000_oWkm800ol0003oooooooooo`08oooo
o`?o00004oooool00ol0003oooooooooo`09ooooo`006oooool00ol0003oooooooooo`0eooooo`05
o`000?m;Jm7oBf_Aod][dOl000000omCLmD00ol0003oO8WFogb9eP04ogb9eP03o`000?n>XN3oSZ7P
00?oSZ7P00?o0000ojJok?nV_n`00_nV_n`3o`000005okgOlOl0003oc?OYolcgjOl000000_o?omT0
1Ol0003oioK@onOfd?oWm]3o000000;oj?K?00?o0000onGde?oUm=@00_l00005omcLeP05o`000?o8
d^7ob=;QolSBhOl000001?nR^nX02?l0003oIHoUofF?iOl0003o85O>o`000?m@Il_o00000_ldB[/0
1ol0003oHEniof5O^OmQGkWo0000oeUD/_l000001OmiIK000ol0003oT7:]oi1b[@04oi1b[@03o`00
0?nQOJco000000;o00000_nPNjX00ol0003o[hJYojn6Z@04ojn6Z@03o`000?nlTJWo_96Y00;o_96Y
1_l00002olVN[003o`000?oF[:koeZb^00CoeZb^00?o0000onBm/?oT_K000ooT_K000ol0003okMBj
ongD^P03ongD^P;o00000ooZjLd2o`0000;odN[W00Go0000ojg4jon]a>_o[LC[o`000004ohZMh006
o`000?maP]CoLH;Dog62e?mJOmgo00000om0JM<00ol0003o=Uo>ocIOcP02ocIOcP;o000000Co0E7>
o`000?lLI][o00000om8Q^P01Ol0003oO:S_ogbXkomlZ>oo000000CoZ<;/00?o0000olK@h_o6d>80
0oo6d>800ol0003oemKGomOFe`03omOFe`03o`000?oPfLooh=W?00;oh=W?0_l00003onO_dP03o`00
0?oooooooooo00Gooooo0ol0000Fooooo`03o`000?oooooooooo00Wooooo000Kooooo`;o0000=Ooo
ool00ol0003oBf_Aod][d@02od][d@06o`000?mCLmGoDg?Eoe=ceOmWQMgo00001?mlRMH00ol0003o
SZ7PohjQh003ohjQh003o`000?nV_ncoY[o/00?o00000onmgo401Ol0003oc?OYolcgjOl0003ocooI
00;o00000ooWm]001ol0003oj?K?onSfcooXm/oo0000onGde?l000000_oVh<h00ol0003og=cFomcL
eP02omcLeP05o`000?o8d^7ob=;QolSBhOl000001?nR^nX01?l0003oIHoUofF?iOl00002ob1GcP;o
00000oldB[/00ol0003oHEnio`000002oeUD/P03o`000?miIK3oNFF`00?oNFF`00?o0000oi1b[On@
LZd00on@LZd3o`0000GoX7^Z00?o0000ojn6ZOn_QZT01?n_QZT00ol0003o_96YokbAZ@04okbAZ@04
o`000?o9WJ[obIfZolVMZPCo00001OoF[:h00ol0003oi;f`onBm/002onBm/003o`000?oadk;o0000
00?okMBj00Go0000ooC/^oodk;_o0000on[Yc@02o`0000?odN[W00Go0000ojg4jon]a>_o[LC[o`00
0004ohZMh003o`000?maP]CoLH;D00;oLH;D0_l00003od1Yd`04o`000?lfGlko=Uo>ocIOcP;o>6;@
00Go0000o`5Ac_l0003o76KJo`000003odR6j005o`000?mlZ>ooO:S_ogbXkol000001?nX`^`00ol0
003oa]3RolK@hP02olK@hP;o00001OoGe]L01_l0003oh=W?on3Icol0003oi>gFo`0000?oinoB00?o
0000ooooooooool00_ooool3o`0001Wooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000
ooooooooool0=?ooool00ol0003oBf_Aod][d@02od][d@04o`000?mCLmGoDg?Eoe=ce@;oIhGM00Go
0000ogb9e_mlRMKoO8WFo`000005ohjQh0?o000000?oY[o/o`000?nmgo400onmgo400ol0003oc?OY
olcgj@02o`000003on;bf?l0003oioK@00;oioK@00Co0000onSfcooXm/ooj?K?0_l00003onKPcP03
o`000?oLg=Kog=cF00;og=cF00?o0000olSBhOo8d^400_o8d^400ol0003oX[_Zo`000003o`0000;o
IHoU00Co0000ob1Gc_lPElko00000oldB[/00ol0003oHEnio`000003oeUD/P03o`000?miIK3oNFF`
00?oNFF`00?o0000oi1b[Ol000000_l000000on?Kj_o0000oj1kZP05oj1kZP03o`000?n_QZWo[hJY
00Co[hJY00?o0000okbAZOnlTJT01?nlTJT00ol0003obIfZolVMZP03olVMZP04o`000?oGZjco0000
o`0000;oeZb^00?o0000onBm/?oT_K000ooT_K001_l0003olM>boo7C/_l0003okMBjo`0000?om>bk
0_l000000ooRo<go0000om7Zi`02om7Zi`05o`000?n]a>_o[LC[ojg4jol000001?n:WN000ol0003o
LH;Dog62e002og62e0;oHW7<00Co0000od1Ydom0JM?o00000olfGlh01Ol0003o>6;@ocQRd?lhH]3o
000000;o76KJ00Co0000odR6j?m8Q^So00000omlZ>l00ol0003oZ<;/ojS2k002ojS2k003o`000?o6
d>;oa]3R00?oa]3R00?o0000omOFeooGe]L00ooGe]L00ol0003oh=W?o`000002onC]eP04o`000?oW
km;oinoBonO_dPGo00007?ooool00ol0003oooooooooo`09ooooo`006oooool00ol0003ooooooooo
o`0dooooo`03o`000?m;Jm7oBf_A00;oBf_A00Co0000oe=ceOmCLmGoDg?E0omWQMd00ol0003oO8WF
o`000003ohjQh0?o00001?nV_n`01Ol0003o_MoaokgOlOnmgo7o000000;oc?OY00Go0000on;bf?oR
l]Soh_;Ho`000003onOfd005o`000?oXm/ooj?K?onSfcol000001?oVh<h00ol0003og=cFomcLeP02
omcLeP04o`000?o8d^7ob=;QolSBh@?o00000_nQ_>`01Ol0003oCi3]o`000?mUSnGo000000;o85O>
00?o0000ocA:^oldB[/00_ldB[/00ol0003oFEBboeUD/P02oeUD/P03o`000?miIK3oNFF`00?oNFF`
0_l00004ohm_Z`03o`000?nPNj[oX7^Z00CoX7^Z00?o0000ojn6ZOn_QZT01?n_QZT00ol0003o_96Y
okbAZ@03okbAZ@03o`000?o9WJ[obIfZ00CobIfZ00Oo0000omN[[?oGZjcoej^/o`000?oF[:ko0000
00Coi;f`00Oo0000oo7C/_oadk;olM>bo`000?o]e;[o000000?om>bk00Co0000on;lcOoRo<go0000
0_oAj^L01Ol0003o[LC[ojg4jon]a>_o000000CoRYgP00?o0000og62e?maP]@00_maP]@01ol0003o
HW7<of9ac?mRLLco0000od1Ydol000000olfGlh00ol0003o>6;@ocQRd002ocQRd003o`000?lLI][o
000000?oB8KX00Go0000ogbXkomlZ>ooO:S_o`000004ojS2k003o`000?o6d>;oa]3R00;oa]3R0_l0
0004omOFe`;o00000ooTkMH01Ol0003oinoBonO_d_oWkm;o0000023ooooo00?o0000ooooooooool0
2Oooool001[ooooo00?o0000ooooooooool0=Oooool00ol0003oBf_Aod][d@02od][d@05o`000?mC
LmGoDg?Eoe=ceOl000000omWQMd5o`0000;oSZ7P00Go0000ojJok?nV_ncoY[o/o`000003okgOl@04
o`000?o<mnWo0000o`0000Coh_;H00Go0000onOfd?oWm]3oioK@o`000002onSfc`;o00001OoVh<h0
0ol0003og=cFomcLeP02omcLeP?o000000?oalWKo`000?nQ_>`00onQ_>`00ol0003oCi3]odn@k@02
o`000003ob1Gc_l0003o000000?o=4Zk00?o0000oeUD/_mIE;800_mIE;800ol0003oNFF`ogUU/002
ogUU/0;o00001_n?Kj/00ol0003oX7^Zoj1kZP03oj1kZP03o`000?n_QZWo[hJY00Co[hJY00?o0000
okbAZOnlTJT00onlTJT00ol0003obIfZolVMZP03olVMZP03o`000?oGZjcoej^/00?oej^/0_l00004
onBm/003o`000?oadk;olM>b00;olM>b00Co0000ooC/^oodk;_om>bk0_l000000ooRo<go0000om7Z
i`08o`0000?oRYgP00?o0000og62e?maP]@00_maP]@00ol0003oHW7<of9ac002of9ac003od1Ydol0
003o=Uo>00;o=Uo>00?o0000ocQRd?lhH]000_lhH]02odM_eP05oaaVf_l0003oB8KXodR6j?l00000
0omlZ>l00ol0003oZ<;/ojS2k002ojS2k003o`000?o6d>;oa]3R00?oa]3R0_l00002omOFe`03o`00
0?oIi]ko000000?oi>gF00Go0000onO_d_oWkm;oinoBo`00000Pooooo`03o`000?oooooooooo00Wo
oooo000Jooooo`?o0000=Oooool01Ol0003oBf_Aod][dOm;Jm7o000000CoDg?E00?o0000ofN5gOmW
QMd01_l000000on>XN3o0000ojJok003ojJok004o`000?nmgo7o_MoaokgOl@;o000000?oen[Ro`00
0?oRl]P00ooRl]P02Ol0003oioK@onOfd?oWm]3o0000onSfcol0003ojN7:o`000005onKPcP04o`00
0?oLg=Kog=cFomcLeP;o00001?o7bM/00ol0003oXKc/oj6lk002oj6lk008o`000?m?T>go0000o`0l
_ol0003o85O>o`0W/Ol00002ocA:^`;o00001?mIE;801_l0003oNFF`ogUU/?l0003oMf:]o`0000Ko
Sfn[00?o0000oj1kZ_nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJWo_96Y00?o
_96Y00?o0000olVMZ_o9WJX00oo9WJX00ol0003oej^/omN[[003omN[[003o`000?oU_:go000000;o
i;f`00?o0000oo7C/_oadk800ooadk800ol0003om>bkooC/^`02o`000004on;lcOl0003o0000o`00
00;oaOC^00Ko0000ojc5k?n/aNco[<G/o`000?nCWMX2o`000003ohZMh?l0003oLH;D00?oLH;D00?o
0000of9ac?mRLL`00omRLL`01Ol0003o=Uo>ocIOc_lfGlko000000Co>6;@00Co0000odM_e_m7KmKo
00000om8Q^P01Ol0003oO:S_ogbXkomlZ>oo000000CoZ<;/00?o0000olK@h_o6d>800_o6d>801?l0
003oemKGo`000?l00002omWVgP05o`000?oTkMKoi>gFonC]e_l000000ooWkm800ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo000Jooooo`03o`000?oooooooooo03Gooooo00Go0000
od][dOm;Jm7oBf_Ao`000004oe=ce@?o000000?oIhGMohBQi_n4XNH00on4XNH3o`0000;oY[o/00?o
0000okgOlOl000000_l00003omOZhP03o`000?oRl]Soh_;H00;oh_;H00Ko0000onOfd?oWm]3o0000
onSfcol00003onWQbP03o`000?oVh<koi^3>00;oi^3>00Ko0000omcLe_oLg=Ko0000omS<c_l00005
olO9f`03o`000?nQ_>coXKc/00;oXKc/00Oo0000odn@kOl0003o03boob1Gc_l0003o02Na00;o0000
00?o8cV`o`000?mIE;800omIE;800ol0003oNFF`o`000003ogMR[@03o`000?n?Kj_oSfn[00?oSfn[
00?o0000oj1kZ_nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJWo_96Y00?o_96Y
00?o0000olVMZ_o9WJX00oo9WJX00ol0003oej^/omN[[003omN[[006o`000?oU_:goiKb]o`000?oT
_K3o00001?oadk82o`000003ooC/^ol0003ohOV[00?o00000oo5m>h01Ol0003o[<G/ojc5k?n/aNco
000000CoTigJ00?o0000og62e?maP]@00_maP]@00ol0003oHW7<of9ac004of9ac005o`000?lfGlko
=Uo>ocIOc_l000001?lhH]001?l0003oAfoFodM_e_m7KmH2o`000003odR6j?l0003oO:S_00;oO:S_
00?o0000ojS2k?nX`^`00_nX`^`00ol0003oa]3RolK@hP02olK@hP03o`000?oGe]Oo000000?ofNKN
00Go0000onC]e_oTkMKoi>gFo`000003onO_dP03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0eooooo`06o`000?m;Jm7oBf_Aod][dOl0003oDg?E1?l0
0003ofN5g@03o`000?n4XNKoQ:7V00;oQ:7V00?o0000ojFok?nU_n`01?l00002ol?JjP05o`000?oG
j^;oen[RomOZh_l000000ooRl]P01?l0003oioK@onOfd?oWm]02o`0000CojN7:00?o0000onKPc_oV
h<h00ooVh<h2o`0000?of<c>00?o0000olO9foo7bM/00oo7bM/00ol0003oXKc/oj6lk002oj6lk005
o`000?m?T>go0000o`0l_ol000000_l09k401?l0003o8cV`ob<i/?l00004oeUD/P03o`000?mgHZgo
Mf:]00;oMf:]00?o0000ohm_Zon?Kj/00on?Kj/00ol0003oX7^Zoj1kZP04oj1kZP03o`000?n_QZWo
[hJY00?o[hJY00?o0000okbAZOnlTJT00onlTJT00ol0003obIfZolVMZP03olVMZP03o`000?oGZjco
ej^/00;oej^/00?o0000onFl[OoU_:d00_oU_:d00ol0003olM>boo7C/P03oo7C/P?o00000_oQnJ/2
o`0000?oaOC^00Go0000ojc5k?n/aNco[<G/o`000005oi>MfP03oh>5cOl0003oLH;D00;oLH;D00?o
0000of9ac?mRLL`00omRLL`00ol0003oG6_8o`000002ocIOcP03o`000?lhH]3o>6;@00;o>6;@00Co
0000odM_e_m7KmKoAfoF0_mRQ^000ol0003oB8KXo`000003ogbXk`03o`000?nX`^coZ<;/00;oZ<;/
00Co0000olK@h_o6d>;oa]3R0_l000001OoIi]ko0000omWVg_oIi]ko000000?oi>gF00Go0000onO_
d_oWkm;oinoBo`00000Qooooo`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Gooooo00?o0000
od][dOm;Jm400ol00002oe=ce@03o`000?mWQMgoIhGM00;oIhGM00?o0000ohBQi_n4XNH00_n4XNH0
1Ol0003oYKo/ojFok?nU_nco000000Co`m[Z00Go0000omOZh_oGj^;oen[Ro`000003on;bf005o`00
0?oWm]3oioK@onOfd?l000001OoYhLX00ol0003oi^3>onKPcP03onKPcP03o`000?oHc<kof<c>00?o
f<c>00?o0000olO9foo7bM/00oo7bM/00ol0003oXKc/oj6lk006o`0000;o02Na00Go0000ob<i/?lS
>K3o8cV`o`000002oeUD/P;o00001?mgHZd00ol0003oSfn[ohm_Z`03ohm_Z`03o`000?nPNj[oX7^Z
00CoX7^Z00?o0000ojn6ZOn_QZT00on_QZT00ol0003o_96YokbAZ@02okbAZ@03o`000?o9WJ[obIfZ
00CobIfZ00?o0000omN[[?oGZj`00_oGZj`00ol0003oiKb]onFl[@02onFl[@03o`000?oadk;olM>b
00;olM>b00?o0000ooS/[_l000000_oQnJ/2o`0000?oaOC^00Go0000ojc5k?n/aNco[<G/o`000005
oi>MfP04o`000?n3QLgoPhG=o`0000;oLH;D00?o0000of9ac?mRLL`00omRLL`01_l0003oG6_8oea[
b?l0003o=Uo>o`0000Co>6;@00Go0000odM_e_m7KmKoAfoFo`000003of:6h005o`000?mlZ>ooO:S_
ogbXkol000001?nX`^`01_l0003oa]3Ro`000?l0003oa]WXo`0000;ofNKN00?o0000omWVg_l00000
0ooTkMH01Ol0003oinoBonO_d_oWkm;o0000027ooooo00?o0000ooooooooool02?ooool000?ooooo
00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo
0ol000000om;Jm7o0000oe=ce@02oe=ce@03o`000?mWQMgoIhGM00;oIhGM00?o0000ohBQi_n4XNH0
0_n4XNH01Ol0003oYKo/ojFok?nU_nco000000Co`m[Z00Go0000omOZh_oGj^;oen[Ro`000003on;b
f003o`000?oWm]3oioK@00;o00001_oYhLX00ol0003oi^3>onKPcP02onKPcP03o`000?oHc<kof<c>
00Cof<c>00?o0000olO9foo7bM/00oo7bM/2o`0000CoXKg]0ol000000ol09k7o0000o`000002ob<i
/003o`000?mIE;;o000000;oEDn^00?o0000ogMR[OmgHZd00_mgHZd00ol0003oSfn[ohm_Z`03ohm_
Z`03o`000?nPNj[oX7^Z00?oX7^Z00?o0000ojn6ZOn_QZT01ol000000onlTJWo0000olVMZP04olVM
ZP03o`000?oGZjcoej^/00?oej^/00Oo0000onFl[OoU_:goiKb]o`000?ocdZko000000;olM>b00Co
0000ooS/[_ohk:ko00000_oQnJ/01Ol0003oaOC^olGdk_o5m>ko000000?o[<G/00?o0000oi>Mf_nC
WMX00onCWMX00ol0003oPhG=oh>5c@02oh>5c@;o00001_mRLL`01_l0003oG6_8oea[b?mLJlSo=Uo>
o`0000Co>6;@00Go0000odM_e_m7KmKoAfoFo`000004of:6h0[o00000oo6fNP01_l0003ofNKNomWV
g_l0003ofNKNo`0000?oi>gF00Go0000onO_d_oWkm;oinoBo`00000Qooooo`03o`000?oooooooooo
00Sooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool3o`0003?o
oooo1?l000001?lHF];o0000od][dOl00003oe=ce@03o`000?mWQMgoIhGM00;oIhGM00Go0000ohBQ
i_n4XNKoQ:7Vo`000004ojFok005o`000?o3f^[o`m[Zol?Jj_l000001?oGj^802Ol0003oh_;Hon;b
f?oRl]So0000onOfd?l0003oj>7;o`000006onWQbP07o`000?oVh<koi^3>onKPc_l0003oglg6o`00
0006omS<cP05o`000?o7bM_oalWKolO9fol000000_o4`ML5oj6mk@06o`000?m_003o0000o`0W/Ol0
2I_o00000_lS>K001Ol0003oEDn^oeE?[_mECjko000000CoMf:]00?o0000ohm_Zon?Kj/00on?Kj/0
0ol0003oX7^Zoj1kZP06o`0000?o[hJY00Co0000okbAZ_nlTJ[o_96Z1Ol00002olVMZP03o`000?oG
Zjcoej^/00;oej^/00?o0000onFl[OoU_:d00_oU_:d01ol0003olm:^oo?B[_l0003olM>bo`000?oh
k:h00_l000000ooQnJ_o0000o`000005o`000003ojc5k?l0003oTigJ00CoTigJ00?o0000oh>5cOn3
QLd01?n3QLd00ol0003oHW7<of9ac003of9ac003o`000?mLJlSoG6_800?oG6_80_l00003ocQRd005
o`000?m7KmKoAfoFodM_e_l000001?mRQ^04ohBTj@03o`000?nX`^coZ<;/00;oZ<;/00Go0000olKI
j?o6fNSoa]WXo`000003omWVgP;o00000ooTkMH01Ol0003oinoBonO_d_oWkm;o0000027ooooo00?o
0000ooooooooool02?ooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool0<Oooool2o`0000Cooooo0_lHF]82o`0000?oDg?E00?o
0000ofN5gOmWQMd00_mWQMd01Ol0003oQ:7VohBQi_n4XNKo000000CoYKo/00Go0000ol?Jj_o3f^[o
`m[Zo`000003omOZhP03o`000?oRl]Soh_;H00;oh_;H0_l00003onSQb`03o`000?oYhL[ojN7:00?o
jN7:00Co0000onKPc_oVh<ko00000ooOcLH00ol0003of<c>omS<cP04omS<cP03o`000?o7bM_o0000
00Coa<7G00?o0000oj6mkOnQ_Nd00_nQ_Nd02?l0003o001oo`0W/Ol0003o00VKo`000?lS>K3o0000
1?mECjh01Ol0003oMf:]ogMR[OmgHZgo000000CoSfn[1?l00003oj1kZP03o`000?n_QZWo[hJY00?o
[hJY00?o0000okbAZ_nlTJX00_nlTJX01?l0003obIf[olVMZoo9WJ/4o`0000?oej^/00?o0000onFl
[OoU_:d00_oU_:d01Ol0003olm:^oo?B[_ocdZko000000;on>b^00?o0000on7iZol000000_n[mO00
1?l0003oZlG]oj_5kOn[aNd3o`0000CoTigJ00?o0000oh>5cOn3QLd01On3QLd00ol0003oHW7<of9a
c003of9ac003o`000?mLJlSoG6_800?oG6_80_mNK<T01?l0003o>6;@ocQRd?l00003odM_eP03o`00
0?mRQ^3oHXKP00;oHXKP00Go0000ohBTjOn4Y>WoQ:CYo`000004ojS2k005o`000?o6fNSoa]WXolKI
j?l000001?oIi]h01Ol0003oi>gFonC]e_oTkMKo000000?oinoB00?o0000ooooooooool07oooool0
0ol0003oooooooooo`08ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;_ooool3o`0000Kooooo00?o0000oaQJd_lHF]800_l00002oe=c
e@05o`000?mWQMgoIhGMofN5gOl000001?n4XNH00ol0003oYKo/ojFok002ojFok005o`000?o3f^[o
`m[Zol?Jj_l000000ooGj^801?l0003oh_;Hon;bf?oRl]P2o`0000Coj>7;00?o0000onWQb_oYhLX0
1?oYhLX2o`0000Goglg600?o0000omS<c_oHc<h01?oHc<h00ol0003oa<7GolC1e`04olC1e`;o0000
0onQ_Nd01_l0003o001oo`000?l02I_o0000ob<i/0;o00000omECjh00ol0003oMf:]ogMR[@02ogMR
[@Co000000?oSg2/o`000?nPNjX01?nPNjX00ol0003o[hJYojn6Z@03ojn6Z@03o`000?nlTJ[o_96Z
00;o_96Z00?o0000olVMZoo9WJ/00oo9WJ/00ol0003oeZ^/o`000002omN[[005o`000?oU_:goiKb]
onFl[Ol000001?ocdZh00ol0003on>b^o`000002o`000003oj_el?l0003o000000?oZlG]00Co0000
oi^Ne_nKW]KoVikF0_l000000onCWM[o0000oh>5c@06oh>5c@03o`000?mjN<Go000000?oHW7<00?o
0000oea[b?mLJlP01?mLJlP3oei/b@03o`000?lhH]3o000000?oAfoF00?o0000of:6h?mRQ^000_mR
Q^001Ol0003oQ:CYohBTjOn4Y>Wo000000CoZ<;/00Go0000olKIj?o6fNSoa]WXo`000004omWVgP;o
00000_oTkMH00ol0003oinoBonO_dP02o`0002;ooooo00?o0000ooooooooool01oooool00004oiRH
V?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`?o
00002Oooool00ol0003o65[BoaQJdP02obMVf003o`000?mCLmGo000000?oIhGM00?o0000ohBQi_n4
XNH00_n4XNH00ol0003oYKo/ojFok002ojFok005o`000?o3f^[o`m[Zol?Jj_l000000ooGj^801_l0
003oh_;Hon;bf?l0003ohmo@o`0000Coj>7;00?o0000onWQb_oYhLX01?oYhLX00ol0003oglg6omo=
aP04omo=aP03o`000?oHc<kof<c>00?of<c>00Co0000om6ob?oA_lSo00001_o4`ML01?l0003oXKg]
oj6mkOnQ_Nd2o`0000;o00VK00?o8cV`o`000?l000000omECjh00ol0003oMf:]ogMR[@02ogMR[@03
o`000?n?L:coSg2/00;oSg2/00?o0000oj1kZ_nPNjX00onPNjX00ol0003o[hJYojn6Z@03ojn6Z@03
o`000?nlTJ[o_96Z00;o_96Z00?o0000olVMZoo9WJ/00oo9WJ/00ol0003oeZ^/omJ[[002o`0000Co
iKb]00Co0000oo?B[_ocdZkolm:^0ol000001?oJl97o0000oj_el?l00003oj_5k@;o00001OnKW]H2
o`0000OoPhG=00Go0000ogYhaOmjN<GoNWS5o`000002of9ac003o`000?mLJlSoG6_800?oG6_800?o
0000oei/bOmNK<T00_mNK<T00olhH]3o0000odM_eP03odM_eP05o`000?mRQ^3oHXKPof:6h?l00000
0on4Y>T00ol0003oZ<;/ojS2k002ojS2k005o`000?o6fNSoa]WXolKIj?l000001?oIi]h2o`0000;o
i>gF00Go0000onO_d_l0003of_o@o`00000Rooooo`03o`000?oooooooooo00Oooooo00001?lb<S;o
0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`?o00003Oooool00ol0
003o65[BoaQJdP02obMVf0;o00000omWQMd00ol0003oQ:7VohBQiP02ohBQiP05o`000?nU_ncoYKo/
ojFok?l000001?o3f^X01ol0003oen[RomOZh_oGj^;o0000on;bf?l000000_oSgm000ol0003oj>7;
onSQb`03onSQb`03o`000?oYhL[ojN7:00;ojN7:0_l00007omo=aP05o`000?oHc<kof<c>omS<c_l0
00001?oA_lP00ol0003oa<7GolC1e`04olC1e`03o`000?nQ_NgoXKg]00?o00000_l02I/00ol0003o
6c6[o`000003oeE?[P03o`000?mgHZgoMf:]00;o00001On?L:`00ol0003oX7^Zoj1kZP02oj1kZP03
o`000?n_QZWo[hJY00?o[hJY00?o0000okbAZ_nlTJX00_nlTJX00ol0003obIf[olVMZ`02olVMZ`03
o`000?oFZjcoeZ^/00;oeZ^/0_l00003onFl[@04o`000?ocdZkolm:^oo?B[P?o000000?of_2Ao`00
0?l000000_n[aNd2o`0000KoVikF00?o0000oi69aol000001_n3QLd00ol0003oNWS5ogYha@03ogYh
a@03o`000?mRLLco000000GoG6_800?o0000oei/bOmNK<T00omNK<T2o`0000?oAfoF00Go0000of:6
h?mRQ^3oHXKPo`000003ohBTj@03o`000?nX`^coZ<;/00;oZ<;/00Go0000olKIj?o6fNSoa]WXo`00
0004omWVgP04o`000?oTkMKo0000onC]eP;o000000?of_o@o`000?ooool08_ooool00ol0003ooooo
ooooo`07ooooo`006Oooool2o`0002Kooooo0ol0000@ooooo`03o`000?lHF];o65[B00?o9fKH0_l0
0002ofN5g@03o`000?n4XNKoQ:7V00;oQ:7V00Go0000ojFok?nU_ncoYKo/o`000004ol?JjP04o`00
0?oGj^;oen[RomOZhP;o00001?oSgm000ol0003oj>7;onSQb`02onSQb`05o`000?oYhL[ojN7:onWQ
b_l000000_oRcL<00ol0003oglg6omo=aP05omo=aP03o`000?oHc<ko000000KodKo80_l00005olC1
e`;o00000onR_nh2o`09V`04o`000?lK<J_o6c6[o`0000;oEDn^00Go0000ogMR[Ol0003oN6:]o`00
0005ohm`[003o`000?nPNj[oX7^Z00;oX7^Z00?o0000ojn6ZOn_QZT00_n_QZT00ol0003o_96ZokbA
ZP03okbAZP03o`000?o9WJ_obIf[00;obIf[00?o0000omJ[[?oFZj`00_oFZj`00ol0003oiKf^o`00
0002o`0000?olm:^00Co0000oo[[Z?l0003of_2A0ol000000on[aNgo0000oi^NeP05oi^NeP;o0000
0onARLL00ol0003oPhG=oh>5c@03oh>5c@03o`000?mjN<GoNWS500CoNWS500?o0000oea[b?mLJlP0
1?mLJlP00ol0003oGVc9oei/b@03oei/b@;oIWK>00Co0000odM_e_m7KmKo00000omRQ^001Ol0003o
Q:CYohBTjOn4Y>Wo000000CoZ<;/00Go0000olKIj?o6fNSoa]WXo`000004omWVgP03o`000?oTkMKo
i>gF00;o00000_oJom000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo000Hoooo
o`03o`000?oooooooooo02?ooooo0ol0000Cooooo`04o`000?lHF];o65[Bo`0000;o9fKH0_m:PN@0
0ol0003oIhGMo`000004ohBQiP05o`000?nU_ncoYKo/ojFok?l000000oo3f^X01?l0003oen[RomOZ
h_oGj^82o`0000Gohmo@00?o0000onSQbooXhL/00_oXhL/01?l0003ojN7:onWQb_l00004on;=``03
o`000?oOcLKoglg600Goglg600?o0000om6ob?oA_lP01ooA_lP01Ol0003oa<7GolC1eoo4`MOo0000
00;o`;WC0_l000000onR_nko0000o`09V`02o`000003oa/aZol0003oEDn^00;oEDn^00Go0000ogQR
[OmhHZgoN6:]o`000004ohm`[003o`000?nPNj[oX7^Z00?oX7^Z00Go0000ojn6ZOn_QZWo[hJYo`00
0004okbAZP03o`000?o9WJ_obIf[00?obIf[00Go0000omJ[[?oFZjcoeZ^/o`000004onFm[P06o`00
0?ocdZkolm:^oo?B[_l0003on^^X0_l00002ojW5kP;o00001_nKW]H00ol0003oTHW7oi69a`04oi69
a`05o`000?n3QLgoPhG=oh>5cOl000001omjN<D00omgLl;o0000oea[b003oea[b003o`000?mNK<Wo
GVc900?oGVc900Oo0000ofIfc_mVM/koIWK>o`000?m7KmKo000000?oHXKP00?o0000ohBTjOn4Y>T0
0_n4Y>T01Ol0003oZ<;/ojS2k?nX`^co000000?oa]WX00?o0000omWVg_oIi]h00_oIi]h01ol0003o
i>gFo`000?oIoMSo0000om[od?l000009?ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0
003oooooooooo`0Pooooo`?o00005oooool00ol0003o65[BoaQJdP03obMVf0;oBX7T0_l00003ohBQ
iP03o`000?nU_ncoYKo/00;oYKo/00Co0000ol?Jj_o3f^[o`m[Z1?l000000ooIfmWo0000on?Od004
on?Od003o`000?oXhL_oj>7;00?oj>7;0_l00006on;=``03o`000?oOcLKoglg600Coglg600?o0000
omJm`Ol000002?oA_lP00ol0003oa<7Go`000005ol2id`;o000000?o00VKo`000?l000000_lK<J/0
1?l0003oEDn^oeE?[_l00003ogQR[@03o`000?n?L:coSg2/00;oSg2/00?o0000oj1kZ_nPNjX00onP
NjX01Ol0003o[hJYojn6ZOn_QZWo000000Co_96Z00?o0000olVMZoo9WJ/00_o9WJ/00ol0003oeZ^/
omJ[[002omJ[[003o`000?oU_JkoiKf^00;oiKf^00Go0000oo?B[_ocdZko0000oo[[Z005o`0000;o
XZ3B00Co0000oi^Ne_nKW]KoVikF0_l00008oi69a`03o`000?n3QLgo000000OoNWS500Co0000ogMc
`_mgLl;o00000omLJlP00ol0003oGVc9oei/b@03oei/b@03o`000?mVM/koIWK>00;oIWK>0_l00003
of:6h003o`000?n4Y>WoQ:CY00;oQ:CY00Go0000ojS2k?nX`^coZ<;/o`000003olKIj003o`000?oI
i]kofNKN00;ofNKN0_l000001OoIoMSo0000o`000?oJom3o000002Cooooo00?o0000ooooooooool0
1oooool001Sooooo00?o0000ooooooooool07Oooool3o`0001[ooooo00Co0000oaQJd_lHF];o0000
0_lWI]P3odZ1i0?o000000?oQ:7Vo`000?nU_n`00onU_n`00ol0003o`m[Zol?JjP02o`0000CofM_I
00?o0000on?Od?oSgm001?oSgm000ol0003oj>7;onSQb`02onSQb`03o`000?oRcL?oh/g300Goh/g3
00?o0000omo=a_oOcLH00ooOcLH01Ol0003oe[g1omJm`OoF_L7o000000SodKo80_l00008ol2id`09
o`000?oAEP3o0000oa/aZol0003oEDn^o`000?mFCjoo000000;oN6:]00?o0000ohm`[?n?L:`00_n?
L:`00ol0003oX7^Zoj1kZP03oj1kZP05o`000?n_QZWo[hJYojn6ZOl000001?nlTJX00ol0003obIf[
olVMZ`02olVMZ`03o`000?oFZjcoeZ^/00;oeZ^/00[o0000onFm[_oU_JkoiKf^o`000?ocdjoo0000
oo?B[_l0003on^^X0ol00005oj:PdP03o`000?nKW]Ko000000[oTHW70_l00007ogYha@03o`000?mg
Ll;oMg?200;oMg?200Co0000oea[b?mLJlSo00001OmNK<T00ol0003oIWK>ofIfcP03ofIfcP;o0000
0_mRQ^000ol0003oQ:CYohBTj@02ohBTj@05o`000?nX`^coZ<;/ojS2k?l000000oo6fNP01?l0003o
fNKNomWVg_oIi]h2o`0000;ofOgH00?o0000om[od?l000009Oooool00ol0003oooooooooo`07oooo
o`006?ooool00ol0003oooooooooo`0Jooooo`?o00007Oooool01?l0003o65[BoaQJd_l00002obMV
f003o`000?m:PNCoBX7T00?oNJ?]1Ol000001_nU_nco0000o`000?l0003oaM;To`0000GofM_I00?o
0000on?Od?oSgm000ooSgm000ol0003oj>7;onSQb`02onSQb`03o`000?oRcL?oh/g300Koh/g300Go
0000omo=a_oOcLKoglg6o`000005omJm`@;o00001_oA_lP01?l0003ob[?4o`000?l00006ol2id`03
o`000?l0093o000000;o6c6[00Co0000oeI?[omFCjoo00000omhHZd00ol0003oSg2/ohm`[002ohm`
[003o`000?nPNj[oX7^Z00;oX7^Z00Go0000ojn6ZOn_QZWo[hJYo`000004okbAZP03o`000?o9WJ_o
bIf[00;obIf[00Go0000omJ[[?oFZjcoeZ^/o`000004onFm[P05o`000?ocdjoolm>_o`000?ojjjP0
0_l00007oj:PdP;o00002OnARLL2o`000003ohao`?l0003oNWS500GoNWS500?o0000ogMc`_mgLl80
1?mgLl82o`0000GoGVc900?o0000ofIfc_mVM/h01?mVM/h2ogJ7e`03o`000?mRQ^3o000000CoQ:CY
00Go0000ojS2k?nX`^coZ<;/o`000003olKIj008o`000?oIi]ko0000o`000?oCm^Go0000omWmf?l0
0002om[od0;o00009?ooool00ol0003oooooooooo`07ooooo`006?ooool2o`0001Sooooo0ol0000Q
ooooo`04o`000?lHF];o65[Bo`0000;o9fKH0om:PN@3ogVSk@CoYL3/0_l00004olGBi003o`000?oI
fmWofM_I00;ofM_I00?o0000on?Od?oSgm000ooSgm001ol0003oj>7;onSQbooXhL_o0000on7=a?l0
00002?oRcL<00ol0003oglg6o`000008omJm`@03o`000?oA_lSodKo800;odKo800?o0000olZca?o:
/l@00_o:/l@2o`0000Go`;WC00Go0000om5F0?lK<J_o6c6[o`000003oeI?[`04o`000?mhHZgoN6:]
o`0000CoSg2/00?o0000oj1kZ_nPNjX03_l000000oo9WJ_o0000omJ[[003omJ[[005o`000?oU_Jko
iKf^onFm[_l000000oocdjl01?l0003on^^Xo`000?l00005oj:PdP;o000000?oWHk3o`000?nARLL0
1onARLL00ol0003oS7o0ohao`002ohao`003o`000?mjN<GoNWS500;oNWS500?o0000ogMc`_mgLl80
1_mgLl800ol0003oGVc9oei/b@03oei/b@03o`000?mVM/koIWK>00?oIWK>00Co0000ogJ7eomfQmOo
MXOG0_l00004ohBTj@05o`000?nX`^coZ<;/ojS2k?l000000oo6fNP2o`0000;odoKU00Ko0000omWm
f?oIoMSo0000om[od?l00002ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_oo
ool001Sooooo00?o0000ooooooooool05?ooool3o`0002Cooooo00Co0000oaQJd_lHF];o00000_lW
I]P01?l0003oBX7TodZ1i?l00003ogVSk@CoYL3/00?o0000olGBi?o5d^@00_o5d^@00ol0003ofM_I
omWKf@02omWKf@03o`000?oSgm3ohmo@00?ohmo@00Co0000onSQbooXhL_o00000ooQcL@00ol0003o
h/g3on;=``06on;=``;o00002OoF_L401?l0003odKo8om6ob?l00007olZca0;o00000oo0^M<4o`00
0005oa`a[?l0003oETn_oeI?[ol000000_mhHZd01?l0003oSg2/ohm`[?n?L:`4o`0000;oXGj]00Go
0000ojn8[?n_R:co[hR/o`000004okbC[003o`000?o9WjgobIn]00?o00000ooFZj`01Ol0003oiKf^
onFm[_oU_Jko000000;olm>_0ol000000ooEjXCoXZ3Boj:PdP02oj:PdP;o00001?nMS/<00ol0003o
THW7oi69a`03oi69a`;o00001_n<Ol001?l0003oNWS5ogYhaOl00008ogMc`P;o00001OmNK<T00ol0
003oIWK>ofIfcP03ofIfcP03o`000?mfQmOoMXOG00;oMXOG1?l000000on4Y>Wo0000ojS2k002ojS2
k003o`000?o6fNSo000000;o00000ooCm^D00ol0003ofOgHo`000002om[od004o`000?oooooooooo
o`0002Cooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool04_ooool3o`00
02Oooooo00Co0000oaQJd_lHF];o00000_lWI]P01?l0003oBX7TodZ1i?l00003ogVSk@03o`000?nU
`>coYL3/00;oYL3/00Go0000olGBi?o5d^CoaM;To`000005omWKf@03o`000?oSgm3ohmo@00?ohmo@
0_l00005on7=a003o`000?oRcL?oh/g300Goh/g300?o0000omRl__l000002OoF_L400ol0003odKo8
o`000009olZca0;o000000Oo`;WCo`000?l0093o002@o`000?lL<Jco000000;oETn_00Go0000ogQR
[OmhHZgoN6:]ohm`[002o`000003oi1c[_l0003oXGj]00?oXGj]00Go0000ojn8[?n_R:co[hR/o`00
0004okbC[006o`000?o9WjgobIn]olVO[Ol0003oeZf_0ol00004onFm[P03o`000?ocdjoolm>_00Co
00000_nRX=82o`0000OoWHk300?o0000oi69aonARLL00_l00008ohao`003o`000?mjN<Go000000So
Mg?200Co0000ogQd`omhM<?o00000omNK<T00ol0003oIWK>ofIfcP03ofIfcP03o`000?mfQmOoMXOG
00?oMXOG00Co0000ohbRhon<X^?oS:;S1ol00002ol;RkP04o`000?oCm^GodoKUo`0000;ofOgH00Co
0000om[od?oJom3o00000oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo
000Gooooo`03o`000?oooooooooo00oooooo0ol0000[ooooo`04o`000?lHF];o65[Bo`0000;o9fKH
00Co0000odZ1i?m:PNCo00000_miXnd00ol0003oYL3/ojG0k002ojG0k003o`000?o5d^CoaM;T00;o
aM;T00?o0000omWKfOoIfmT00_oIfmT00ol0003ohmo@on?Od002on?Od0;o00001ooQcL@00ol0003o
h/g3on;=``03on;=``04o`000?oH_;kof;bnomRl_P;o00002?oF_L400ol0003ob[?4olZca00:olZc
a003o`000?nk/]3o^k;@00;o00000_lL<J`01?l0003oETn_oeI?[ol00002ogQR[@05o`000?n@Ljko
T7>^oi1c[_l000001?nQOZd01Ol0003o[hR/ojn8[?n_R:co000000Co_9>/00Go0000olVO[Oo9Wjgo
bIn]o`000003omJ][`;o00000_oU_Jh01Ol0003olm>_oo?C[ol0003onN^Y00;o000000?oXZ3Bo`00
0?l000002OnMS/<00ol0003oTHW7o`00000:ohao`0;o00002?mgLl800ol0003oN7C3ogQd``02ogQd
``04o`000?mNK<WoGVc9o`0000GoIWK>00?o0000ogJ7eomfQmL00_mfQmL00ol0003oS:;SohbRh`03
ohbRh`05o`000?nX`^goZ<;]ojS2kOl000000_o2h^h01ol0003odoKUom?fiOoCm^Go0000omWmf?l0
00000_oJom000ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool001Oooooo00?o0000ooooooooool03?ooool3o`0002kooooo0_l000001OlHF];o0000
obMVf?lWI]So000000;oBX7T00Go0000ogVSkOmiXngoNJ?]o`000003ojG0k003o`000?o5d^CoaM;T
00;oaM;T00?o0000omWKfOoIfmT00_oIfmT01ol0003ohmo@on?Od?oSgm3o0000omg=bOl000001ooQ
cL@00ol0003oh/g3on;=``02on;=``03o`000?oH_;kof;bn00Cof;bn00?o0000omJm`OoF_L401OoF
_L401?l0003ocK2mo`000?l00009olZca008o`000?o2ZL7o`ZW1o`000?l0093o0000oa`a[?l00002
oeI?[`04o`000?mhHZgo0000o`0000CoT7>^00Go0000oj5n[OnQOZgoXGj]o`000003ojn8[003o`00
0?nlTjco_9>/00;o_9>/00Co0000olVO[Oo9Wjgo00001?oF[Jl01ol0003ohkjao`000?oU_Jko0000
oo?C[ol000000_oijjT3o`0000_oWHk30_l0000:ohao`003o`000?n:Nkgo000000OoMg?200?o0000
ogQd`omhM<<01?mhM<<00ol0003oGVc9o`000004ofIfcP03o`000?mfQmOoMXOG00?oMXOG00?o0000
ohbRhon<X^<00_n<X^<01Ol0003oZ<;]ojS2kOnX`^go000000?o`^;^00Co0000om?fiOoCm^Go0000
0_oIoMP01?l0003of_o@om[od?l00006ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool001Oooooo0_l0000:ooooo`?o0000<Oooool2o`0m_@;o00000_lWI]P01?l0003oBX7T
odZ1i?l00003ogVSk@03o`000?nU`>coYL3/00;oYL3/00Go0000olGBi?o5d^CoaM;To`000004omWK
f@04o`000?oSgm3ohmo@o`0000?ogLg900?o0000on7=a?oQcL@01OoQcL@01Ol0003oh/g3on;=`ooR
cL?o000000Oof;bn00?o0000omJm`OoF_L400ooF_L400ol0003ocK2molf`_@02olf`_@?o00001Oo:
/l@00ol0003o`ZW1ol:Y`@03ol:Y`@04o`000?lL<Jco736/o`0000;oETn_00Co0000ogYV/OmjI[7o
00000on@Ljh01Ol0003oXGj]oj5n[OnQOZgo000000?o[hR/00?o0000okbC[?nlTj`00_nlTj`01?l0
003obIn]olVO[Ol00004omJ][`?ohkja00Go0000oo?C[oocdjoo0000ooW[Z@02o`000003ojNC`Ol0
003oWHk300OoWHk30ol000000onJQKco0000ohao`007ohao`0;o00000on:Nkd00ol0003oMg?2ogMc
`P03ogMc`P03o`000?mhM<?oN7C300KoN7C300?o0000ofIfc_mVM/h00omVM/h00ol0003oMXOGogJ7
e`02ogJ7e`03o`000?n<X^?oS:;S00?oS:;S00Go0000ojS2kOnX`^goZ<;]o`000002ol;RkP05o`00
0?oCm^GodoKUom?fiOl000000_oIoMP00ol0003of_o@o`000007ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003Gooooo
0_l0?Kd01OlHF];o0000obMVf?lWI]So000000;oBX7T00Co0000ogVSkOmiXngo00001?nU`>`00ol0
003oaM;TolGBi002olGBi003o`000?oIfmWofM_I00;ofM_I0_l00005omg=b@03o`000?oQcLCohLg4
00GohLg400?o0000on;=`ol000002OoH_;h2o`0000;oe[g100?o0000olf`_Oo=/;d01_o=/;d2o`00
00?ob[?400?o0000ol:Y`Oo2ZL400oo2ZL42o`000003oa`a[?l0003oETn_00;o00000_mjI[401Ol0
003oT7>^oi1c[_n@Ljko000000CoXGj]00Co0000ojn8[?n_R:co00000onlTj`01Ol0003obIn]olVO
[Oo9Wjgo000000?oeZf_00Oo0000on>n/OoS_[7ohkjao`000?ocdjoo000000;onN^Y00Co0000ojNC
`OnWTl7o00001_nMS/<2o`0000GoVXFl00?o0000ohao`?n<Ol001?n<Ol000ol0003oRW^mohYk_@04
ohYk_@05o`000?mgLl;oMg?2ogMc`_l000002OmhM<<00omlO<Oo0000ofIfcP03ofIfcP03o`000?mf
QmOoMXOG00;oMXOG00?o0000ohbRhon<X^<00on<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^
00Co0000om?fiOoCm^Go00000_oIoMP01?l0003of_o@om[od?l00008ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool00oooool3o`0003Wo
oooo0_l0?Kd2o`000005obMVf?l0003oBX7TodZ1i?l000000omiXnd01Ol0003oYL3/ojG0k?nU`>co
000000CoaM;T00Co0000omWKfOoIfmWofM_I0_l00007omg=b@03o`000?oQcLCohLg400GohLg40_l0
000;omRl_P03o`000?oF_L7o000000[ocK2m0_l000000oo:/lCo0000ol:Y`@05ol:Y`@04o`000?lL
<Jco736/o`0000;oFUJc00Co0000ogYV/OmjI[7o00000_n@Ljh00ol0003oXGj]oj5n[@02oj5n[@04
o`000?n_R:co[hR/o`0000?o_9>/00Go0000olVO[Oo9WjgobIn]o`000003omJ][`05o`000?oS_[7o
hkjaon>n/Ooadk<00_l000000ooijjWo0000o`000003ojNC`@04o`000?nMS/?oWHk3oif>``;o0000
1onJQK`00ol0003oS7o0ohao`003ohao`003o`000?n:NkgoRW^m00KoRW^m00?o0000ogMc`_l00000
2OmhM<<01?l0003oO7c7ogalaol00002ofIfcP03o`000?mfQmOoMXOG00;oMXOG00?o0000ohbRhon<
X^<00on<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Go0000om?fiOoCm^GodoKUo`000002
omWmf0?o00002_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Foooo
o`04o`000?ooooooooooooooo`?o0000?Oooool00ol0?Kgo057<o`1Ac002o`0000;oBX7T00Go0000
ogVSkOmiXngoNJ?]o`000004ojG0k005o`000?o5d^CoaM;TolGBi?l000000_oIfmT00ol0003oeLgA
o`000008omg=b@03o`000?oQcLCohLg400CohLg400?o0000omRl__l000002ooH_;h00ol0003ocK2m
olf`_@0;olf`_@03o`000?o2ZL7o`ZW100Go`ZW100Co0000oa`a[?lL<Jco00000_mJE[<01?l0003o
NVJaogYV/Ol00002oi1c[P03o`000?nQOZgoXGj]00;oXGj]00Co0000ojn8[?n_R:co00000onlTj`0
1Ol0003obIn]olVO[Oo9Wjgo000000;oeZf_00[o0000on>n/OoS_[7ohkjao`000?oadk?o0000ooW[
ZOl0003oe^^61?nWTl44o`0000[oVXFl00?o0000ohao`?n<Ol000_l00009ohYk_@;o00002OmhM<<0
0ol0003oO7c7ogala`02ogala`03o`000?mVM/ko000000CoMXOG00?o0000ohbRhon<X^<00on<X^<0
1Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Ko0000om?fiOoCm^GodoKUo`000?oIoMP3o`0000co
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`005_ooool4o`00047ooooo
00Go03fmo`1Ac?l0DLco9fKHo`000002odZ1i004o`000?miXngoNJ?]o`0000CoYL3/00?o0000olGB
i?o5d^@00_o5d^@2o`0000?oeLgA00?o0000omg=bOoMcLT01OoMcLT00ol0003ohLg4on7=a003on7=
a004o`000?oH_;kof;bnomRl_P;o00002OoH_;h01?l0003ocZnjo`000?l0000:olf`_@03o`000?o4
YK[oa:Fj00Go000000Oo`ZW1o`000?l0003o9Sbbo`000?mJE[?o000000?oNVJa00Co0000oi1c[_n@
Ljko00000onQOZd00ol0003o[hR/o`000003o`000005okbC[?l0003obIn]olVO[Ol000000ooF[Jl0
1?l0003ohkjaon>n/Ol00002oo7C/`04o`000?oijjWo0000o`0000;oYi?10ol0000=oiZ5_003o`00
0?n<Ol3o000000[oRW^m00?o0000ohYl__l000002?mhM<<00ol0003oO7c7ogala`04ogala`;o0000
1?mfQmL00ol0003oS:;SohbRh`02ohbRh`05o`000?nX`^goZ<;]ojS2kOl000000oo2h^h01?l0003o
doKUom?fiOl00002omWmf0;o00003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo000Fooooo`?o0000@oooool00ol0?Kgo057<o`1Ac002o`000003odZ1i?l0003oNJ?]00;o
NJ?]00Go0000ojG0k?nU`>coYL3/o`000003olGBi0;o00001OoEcM400ol0003ogLg9omg=b@05omg=
b@05o`000?oQcLCohLg4on7=a?l000001_oH_;h2o`0000Kof;bn00?o0000olj_^_o>[kX00_o>[kX2
o`0000OocK2m00?o0000olBU^_o4YKX01_o4YKX01Ol0003o/D80o`000?lV?;;o000000;oFUJc00Go
0000ogYV/OmjI[7o0000oi1c[P07o`000004ok2=/_l0003o_9NbokbG/PGo00000ooF[Jl01ol0003o
hkjaon>n/Ol0003olM>co`000?ohk;001Ol00002ojJ<^P03o`000?nJQKcoVXFl00_oVXFl0_l0000:
ohYk_@05o`000?n:O;koRWbnohYl__l000001_mhM<<00ol0003oO7c7ogala`05ogala`;oQH[@00Co
0000ogJ7eomfQmOo00001On<X^<01Ol0003oZ<;]ojS2kOnX`^go000000;o`^;^00Co0000om?fiOoC
m^GodoKU1?l0000?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool000co
oooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04;ooooo00Co03fmo`1Ac?l0
003o97_V0_l00003ogVSk@03o`000?nU`>coYL3/00;oYL3/0ol000000oo5b]ko0000omG=d@05omG=
d@03o`000?oMcLWogLg900GogLg900?o0000on7=a?l000002OoH_;h00ol0003of;bnomRl_P03omRl
_P03o`000?o>[k[ocZnj00CocZnj0_l00005olf`_@03o`000?o4YK[oa:Fj00Soa:Fj00Ko0000obHl
/_lV?;;o0000oeYF/ol00002ogYV/@;o000000?oTgZeo`000?nRQ;<00_nRQ;<01?l0003o/8fbok2=
/_l00003okbG/P03o`000?o7Xk?oaj>c00Co00000_oS_[401_l0003olM>coo7C/ol0003on>b`o`00
00OoYXbj00?o0000oiZ5_?nJQK`01onJQK`3o`000003oiV2^Ol0003oRW^m00OoRW^m0_l00005ohYl
_P03o`000?mhM<?oN7C300;oN7C300?o0000ogalaomlO<L01OmlO<L01ol0003oQH[@ohF:d?n5R]3o
0000ogJ7eol000001?n<X^<00ol0003oZ<;]ojS2k@02ojS2k@04o`000?o2h^ko`^;^o`0000;odoKU
1?l0000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool000kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`11ooooo`04o`000?l0?Kgo057<o`0000;o97_V
1?l00002ojG0k0?o00001?o5b]h00ol0003oeLgAomG=d@04omG=d@03o`000?oMcLWogLg900GogLg9
0_l0000:omRl_P;o00000_oH_;h00ol0003ocZnjolj_^P07olj_^P;o00000oo=/;d00ol0003oa:Fj
olBU^P08olBU^P0:ok520?l0003o9Sbbo`000?mJE[?o0000ogYV/Ol0003oOg2ho`0000;oTgZe00Co
0000oj:4/onRQ;?o00000_n`SK801Ol0003o_9NbokbG/_nlUk;o000000;oaj>c00?o0000om>`]_oC
/;H00_l000001OoS_[7o0000oo7C/ol0003on>b`00;o00001onVS;X00ol0003oVXFloiZ5_004oiZ5
_0?o00001OnIP[T00ol0003oRW^mohYk_@04ohYk_@03o`000?n:O;koRWbn00GoRWbn00Go0000ogQd
`omhM<?oN7C3o`000007ogala`03o`000?n5R]3oQH[@00?oQH[@0_l00004ohbRh`05o`000?nX`^go
Z<;]ojS2kOl000000_o2h^h01?l0003odoKUom?fiOoCm^D3o`0001;ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo047ooooo0_l000001?l0DLco0000obAki_l00002offVl`?o00000_nU`>d00ol0003oaL[N
olG:gP03olG:gP03o`000?oEcM7oeLgA00CoeLgA00?o0000omg=bOoMcLT01?oMcLT00ol0003oeKk3
o`00000;omRl_P03o`000?oH_;ko000000_ocZnj0ol0000<olBU^P06o`000?lV?;;o9Sbbo`000?mJ
E[?o00000omoL;P00ol0003oTgZeo`000002oj:4/`04o`000?n`SK;o/8fbo`0000?o_9Nb00Co0000
olNS/oo7Xk?o00000_oC/;H01_l0003ogl2io`000?oadk?o0000ooS//0;o00002?nVS;X00ol0003o
VXFloiZ5_002oiZ5_0;o00002?nIP[T00ol0003oRW^mohYk_@02ohYk_@;o00002On:O;h00ol0003o
N7C3o`000007ogala`03o`000?n5R]3oQH[@00CoQH[@00?o0000oiBQgOl000000_l000000on<X^?o
0000ojS2k@02ojS2k@03o`000?o2h^ko`^;^00Ko00005?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00[ooooo0_l00012ooooo`06o`0m
_Ol0003o057<o`000?lTNnKo00000_m]Y_<00ol0003oYL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N
00?oaL[N00?o0000omG=dOoEcM401?oEcM400ol0003ogLg9omg=b@02omg=b@05o`000?oE_/?oeKk3
omFn`ol000002ooH_;h2o`0000gocZnj00?o0000olBU^_o4YKX02_o4YKX01_na@P3o0000obHl/_l0
003oFUJco`0000?oOg2h00?o0000oi=j]Ol000000_nRQ;<01?l0003o/8fbok2=/_l00003okbG/P03
o`000?o7Xk?o000000?odk2f0_oO`;T01_l0003olM>co`000?l0003ofo:Eo`0000WoYXbj1?l0000;
oiV2^@04o`000?n:NkgoRW^mo`0000_oRWbn0_l00007ogala`03o`000?n5R]3oQH[@00CoQH[@00?o
0000oiBQgOnDXMd00onDXMd3o`0000;oZ<;]1?l000001?nko>Go0000o`000?l0000Fooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01?ooool000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`10ooooo`06o`0m_Ol0003o057<o`000?lTNnKo00000_m]Y_<00ol0003o
YL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N00?oaL[N00?o0000omG=dOoEcM401?oEcM401?l0003o
gLg9omg=bOl00005omFn``;o00002OoH_;h01?l0003ocZnko`000?l0000;olj_^P03o`000?o5Y;So
aJBh00Go00001_o4YKX01_l0003o9SbbobHl/_l0003oI6>lo`0000;oOg2h00Co0000oi=j]OnCN[Go
00000_nRQ;<00ol0003o/8fbo`000002okbG/P04o`000?o7Xk?oaj>co`0000;odk2f00Ko0000omo0
^OoO`;WojmBmo`000?ohk;02o`0000SoYXbj0ol0000>oiV2^@03o`000?n:Nkgo000000_oRWbn00?o
0000ohf2`_l000001_mlO<L00ol0003oQH[@ohF:d004ohF:d003o`000?nDXMgoU:7M00?oU:7M00Co
0000ojO2kOnW`^goYl;]0ol000000onjj?Go0000ok_li@03o`0001Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo043ooooo00Ko03fmo`000?l0DLco0000obAki_l00002offVl`03o`000?nU`>goYL3]00;o
YL3]00?o0000olG:g_o5b]h00oo5b]h00ol0003oeLgAomG=d@04omG=d@03o`000?oMcLWo000000Oo
eKk300?o0000omRl__oH_;h01OoH_;h00ol0003ocZnkolj_^`02olj_^`;o00002?o>[kX00ol0003o
aJBholFT^006olFT^0Go000000Ooa:Fjo`000?l0003o9Sbbo`000?mTHkco000000?oOg2h00?o0000
oi=j]Ol000000_nRQ;<00ol0003o/8fbo`000002okbG/P06o`000?o7Xk?oaj>co`000?oC/;Ko0000
0_oO`;T00ol0003ojmBmo`000002o`0000CoYXbj1Ol00002ojF:]`03o`000?nIP[WoVH:i00coVH:i
0_l0000:ohYl_P;o00000on=P/800ol0003oO7c7ogala`02ogala`03o`000?n5R]3oQH[@00CoQH[@
00?o0000oiBQgOnDXMd00onDXMd00ol0003oYl;]ojO2k@02ojO2k@05o`000?njj?Go^^Seo`000?nk
o>D00ol0000Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool000kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`10ooooo`06o`000?l0DLco057<o`000?lT
NnKo00000_m]Y_<00ol0003oYL3]ojG0k@02ojG0k@03o`000?o5b]koaL[N00;oaL[N00?o0000omG=
dOoEcM401OoEcM42o`0000SoeKk30_l00004omRl_P03o`000?o>[k_ocZnk00GocZnk0ol00005olj_
^P03o`000?o5Y;SoaJBh00_oaJBh1?l000001?liDKoo0000ofAS_?l00002ogm`^003o`000?nCN[Go
000000;oXXBc00?o0000ok2=/_l000000_nlUk800ol0003oaj>co`000002om>`]P04o`000?oO`;Wo
0000on_D_@;o000000?ofo:Eo`000?l000000ol00008ojF:]`03o`000?nIP[WoVH:i00SoVH:i0ol0
00000onIPk[o0000ohYl_P08ohYl_P03o`000?n=P/;oSH;200CoSH;200Co0000ogalaomlO<Oo0000
1_n5R]000ol0003oU:7MoiBQg@03oiBQg@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go
0000ok_li@03o`0001_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00
3?ooool00omEEEGoIVIVo`00000Aooooo`;o0000@Oooool00ol0003o057<o`000002obAkiP04o`00
0?m]Y_?oKJKco`0000CoYL3]00?o0000olG:g_o5b]h00_o5b]h00ol0003oeLgAomG=d@03omG=d@04
o`000?o?`<cocl3<o`0000WoeKk300Go0000omRl__oH_;kof;bno`00000:olj_^`;o00000oo>[kX0
0ol0003oaJBholFT^00<olFT^00;o`000?nkV[Oo03:ho`000?liDKoo0000ofAS_?l0003oOg2ho`00
0?nCN[D03?l000001_oC/;Ko0000o`000?o[e;go0000oo;/_`;o00003OnUR[L00ol0003oVH:ioiV2
^@05oiV2^@?o00001OnIPkX00ol0003oRWbnohYl_P04ohYl_P;o00001on=P/800ol0003oO7c7o`00
0006ohF:d003o`000?nDXMgoU:7M00?oU:7M00?o0000ojO2kOnW`^d00_nW`^d01Ol0003o^^Seok[X
mOl0003o^ocU00?o00007Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo
000Rooooo`03o`000?oooooooooo03oooooo00Go0000o`1Ac?l0003o97_Vo`000003offVl`05o`00
0?nU`>goYL3]ojG0kOl000001Oo5b]h01Ol0003oeLgAomG=dOoEcM7o000000Cocl3<00?o0000omFn
`ooE_/<01ooE_/<00ol0003of;bno`00000=olj_^`?o00003oo5Y;P01?l0003o^iZgo`000?l0<[P2
o`000003ofAS_?l0003oOg2h00;o000000KoV8W2o`000?nUT;oo0000ok2H__l00002okZP_P08o`00
0?o4Z/3o0000oljf`ol0003ogl2io`000?o[e;d3o`0000koYHZg00?o0000oiV2^OnIP[T00_nIP[T3
o`0000SoVH>j00?o0000ohYl__n:O;h00on:O;h00ol0003oSH;2ohf2`P07ohf2`P;o00001on5R]00
0ol0003oU:7MoiBQg@02oiBQg@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go0000ok_l
i@03o`0001oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`008oooool0
0ol0003oooooooooo`0oooooo`05o`000?l0DLco0000obAki_l000000om]Y_<01Ol0003oYL3]ojG0
kOnU`>go000000GoaL[N00?o0000omG=dOl000001_o?`<`2o`0000SoeKk30_l0000?olj_^`03o`00
0?o5Y;SoaJBh00coaJBh00Oo0000ok^J]onkV[Oo^iZgo`000?l0<[So000000;oI6>l00?o0000ohV2
a_l000000_nHRL82o`000004ok2H__l0003o^Z2nokZP_P;oa:[00_o>]/<2o`000005on_D_Ol0003o
0000on7k/ol000003onUR[L4o`0000coVH>j00?o0000ohYl__n:O;h00_l00009ohf2`P04o`000?nC
SL_oThg;o`0000GoQH[@00?o0000oiBQgOnDXMd00_nDXMd00ol0003oYl;]ojO2k@02ojO2k@05o`00
0?njj?Go^^Seo`000?nko>D00ol0000Pooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool002Cooooo0_l00010ooooo`?o000000?o97_Vo`000?m]Y_<00_m]Y_<01Ol0003oYL3]
ojG0kOnU`>go000000CoaL[N0_l00009olo0c003o`000?oE_/?oeKk300GoeKk300?o0000olba_ol0
00000_l0000<olj_^`03o`000?o4Y;Soa:Bh00?o00002Oo5Y;P00ol0003o^iZgok^J]`02ok^J]`03
o`000?l0<[So>E6o00;o00000_n9P/H03Ol0003oV8W2o`000?l0003o/9Rno`000?njX;ko0000olBZ
`?l0003oc[K3o`000?oGa<L00_l000001?obk;oo0000o`000?l0000=ojF:]`?o00003onIPkX00ol0
003oRWbno`000009ohf2`P;o00001?nCSL/01Ol0003oQH[@ohF:d?n5R]3o000000CoU:7M00?o0000
ojO2kOnW`^d00_nW`^d01Ol0003o^^Seok[XmOl0003o^ocU00?o00008_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo000Vooooo`03o`000?oooooooooo03oooooo0_l00000
0olTNnKo0000offVl`02offVl`06o`000?nU`>goYL3]ojG0kOl0003oaL[N0_l00003ol;2fP03o`00
0?o?`<cocl3<00Kocl3<0_l00004omFn``03o`000?o</Kooc;6o00?oc;6o0_l00009olj_^`03o`00
0?o4Y;Soa:Bh00Coa:Bh1?l00005olFT^003o`000?nkV[Oo^iZg00?o^iZg0_l0<[P2oeYdd`03o`00
0?n9P/KoRH;600;o000000CoYI2oo`000?l0003o^Z2n0_l000000oo>]/?o0000omO4a`05o`0000;o
/96f00?o0000ojF:]onUR[L01OnUR[L5o`0000;oYHZh00?o0000oiV3^_nIPkX03OnIPkX2o`0000Wo
SH;200?o0000oi>=bonCSL/01OnCSL/00ol0003oQH[@o`000004oiBQg@03o`000?nW`^goYl;]00;o
Yl;]00Go0000ok[XmOnjj?Go0000ok_li@02o`0002Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`03ooooo`009oooool00ol0003oooooooooo`0oooooo`04o`0cXol0003o0000o`00
00?oKJKc00?o0000ojG0kOnU`>d00_l00006ol;2fP03o`000?o?`<cocl3<00Oocl3<00Co0000omFn
`ooE_/?o00002?o</Kl2o`0000OocZnk00?o0000olBT^?o4Y;P02?o4Y;P3o`000003olFT^?l0003o
^iZg00Ko^iZg00So03:ho`000?mJM=?oFWCCo`000?n9P/Ko0000oiR9`PCo000000Coa:[0o`000?l0
003oelC70_l000000ooTj=Co0000o`000003ok2A]P03o`000?nUR[OoYHZg00Go00002?nUR[P00ol0
003oVH>joiV3^P09oiV3^P?o000000?oVhRno`000?n=P/801_n=P/82o`0000SoThg;0ol00003oiBQ
g@03o`000?nW`^goYl;]00;oYl;]00Go0000ok[XmOnjj?Go0000ok_li@02o`0002Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00:?ooool00ol0003oooooooooo`10oooo
o`03o`0cXol0LM[o000000Go00000onU`Nd6ol;2fP;o00002?o?`<`00ol0003oeKk3o`00000:olba
_`?o00000oo>[k/00ol0003oa:BholBT^00<olBT^0co00000_mJM=<00ol0003oRH;6o`000006o`00
0005omO4aol0003o0000onCXe?oMnmP02?l0000=ojF:^003o`000?nIPk[oVH>j00KoVH>j0ol00005
oi^8_P03o`000?n=P/;oSH;200?oSH;200?o0000oi>=bonCSL/01_nCSL/2o`0000?oVj7I00?o0000
oiBQgOl000001?nW`^d01_l0003o^^Seok[XmOl0003o^ocUo`0002Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`03ooooo`00:Oooool2o`00047ooooo00?o0000o`1af_l0LMX01?mR
[?T4ojG1k@03o`000?o2`][o`/;J00Co`/;J00?o0000olo0c?o?`<`01_o?`<`00ol0003oc;6oolba
_`0<olba_`;o000000?ocZnko`000?o4Y;P03_o4Y;P00ol0003o^iZgok^J]`06ok^J]`?o00000_mJ
M=<:o`0000;ogO_H00?o0000ok2B]on`T[L00on`T[L00ol0003oYHZhojF:^00=ojF:^003o`000?nI
Pk[oVH>j00?oVH>j0ol00009oi^8_P03o`000?n=P/;oSH;200;o00002?nCSL/00ol0003oVj7Ioi^Q
f@03oi^Qf@Co00000_nW`^d00ol0003o^^Seok[Xm@03o`0002_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`10ooooo`03o`0cXol0LM[o
000000?oHZci00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003o`/;Jol;2fP03ol;2fP03o`000?o?`<co
cl3<00Gocl3<00Co0000olReaol0003o00003Oo</Kl00ol0003oa:BholBT^00>olBT^003o`000?nk
V[Oo^iZg00So^iZg3Ol000000onkoLko/9:gok2B]`05ok2B]`03o`000?nUR[SoYHZh00koYHZh00?o
0000oiV3^_l000000_l0000<oi^8_P03o`000?n=P/;o000000SoThg;0_l00005oi^Qf@03o`000?nW
`^goYl;]00;oYl;]1_l0000^ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool002cooooo00?o0000ooooooooool0@Oooool00ol0003o077Jo`000003of:/n@04o`000?nU`Ngo
YL7]ojG1k@;o00001?o2`]X2o`0000Cocl3<00?o0000olReaoo8]LL00_o8]LL2o`0000_oc;6o00?o
0000ol>V_?o3Y[`01?l0000:olBT^003o`000?nkV[Oo^iZg00[o^iZg2ol00008ok2B]`03o`000?nU
R[SoYHZh00coYHZh1?l0000?oi^8_P;o00001onCSL/2o`0000GoVj7I0_l00004ojO2k@03o`000?n[
j_WoZn[i00?o0000<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000]
ooooo`03o`000?oooooooooo047ooooo00?o03>So`1af_l000000omR[?T00ol0003oYL7]ojG1k@02
ojG1k@03o`000?o2`][o`/;J00?o`/;J00Co0000olo0c?o?`<co00001oo8]LL3o`0000Ooc;6o00?o
0000ol>V_?o3Y[`01Oo3Y[`4o`0000Goa:Bh00?o0000ok^J]onkV[L03OnkV[L2o`000003ofc1o_l0
003oS=cn00?o00002_n`T[L00ol0003oYHZhojF:^007ojF:^0Co00000_nVS[`00ol0003oVhRnoi^8
_P0;oi^8_P?o000000?oWY77o`000?nCSL/01?nCSL/2o`0000KoVj7I00?o0000ojO2kOnW`^d00_nW
`^d2o`000004oj_ZnOl0003o0000o`0003;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`00;_ooool2o`0004?ooooo00?o0000o`1af_l000000_mR[?T2o`0000?oYL7]00?o
0000ol;2f_o2`]X00oo2`]X00ol0003ocl3<o`00000:olRea`;o00001Oo</Kl00ol0003o`jJlol>V
_009ol>V_0Co000000?oa:Bho`000?nkV[L03onkV[L4o`0000go/9:g00?o0000ojF:^?nUR[P00onU
R[P4o`0000OoYXjl00?o0000oi^8__nKR;h01onKR;h3o`0000GoWY7700Go0000oi>=bonCSL_oThg;
o`000006oi^Qf@;o00001?nW`^d00ol0003oZn[io`000003o`0003Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`02ooooo`00<?ooool00ol0003oooooooooo`11ooooo`04o`0cXol0
003o0000o`0000;oHZci00Co0000ojG1kOnU`NgoYL7]0_l00003ol;2fP;o00003Oo8]LL2o`0000?o
c;6o00?o0000ol>V_?o3Y[`03Oo3Y[`2o`000003ok^J]ol0003o000000Ko00001onkV[L00ol0003o
/9:gok2B]`0>ok2B]`03o`000?nUR[So000000?o00002onVS[`00ol0003oVhRnoi^8_P05oi^8_P;o
00002?nNTLL01?l0003oThg;o`000?l00005oi^Qf@;o00001?nW`^d2o`000004oj_ZnOl0003o0000
o`0003Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00<Oooool00ol0
003oooooooooo`12ooooo`03o`000?l0LM[o000000;oHZci0_l00003ojG1k@03o`000?o2`][o0000
00?o_[_F0ol0000;olRea`?o00004Oo3Y[`00ol0003o^YfkokZM^`07okZM^a[o00003onVS[`00ol0
003oVhRnoi^8_P02oi^8_P?o00002_nNTLL2o`0000KoVj7I00?o0000ojO2kOnW`^d00onW`^d00ol0
003oZn[io`000002o`0003Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`00<_ooool00ol0003oooooooooo`12ooooo`Co00000_mR[?T01Ol0003oYL7]ojG1kOnU`Ngo0000
00Oo_[_F0ol0000:olRea`03o`000?o3Y[co`jJl00oo`jJl00?o0000okZM^onjWK/03_njWK/00ol0
003o/IFkok6E^`0>ok6E^`03o`000?nVS[coYXjl00ooYXjl1?l0000:oijAa`?o00000_nSXmH01?l0
003oVj7Ioi^QfOnKXMT2o`0000CoYl;]0_l000001?n[j_Wo0000o`000?l0000kooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool003?ooooo0_l00014ooooo`?o00000_mR[?T0
0ol0003oYL7]o`000002ojG1k@03o`000?nn^mKo_[_F00Ko_[_F0_l00008olRea`03o`000?o1[<Go
`Jc500Co00002oo3Y[`00ol0003o^YfkokZM^`0>okZM^`03o`000?naUK_o/IFk00ko/IFk00?o0000
ojJ>_?nVS[`03?nVS[`4o`0000[oWY770ol00006oj>SeP03o`000?nKXMWo000000GoYl;]00?o0000
oj_ZnOl000000_l0000nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
03Gooooo00?o0000ooooooooool0@oooool00ol0IKgo0000o`000002o`0000KoYL7]0_l00006okjk
eP?o00001?o8]LL00ol0003o`Jc5ol6/a@05ol6/a@Go00001Oo3Y[`00ol0003o^YfkokZM^`0?okZM
^`03o`000?naUK_o/IFk00oo/IFk00?o0000ojJ>_?nVS[`01OnVS[`6o`0000?oZ9O400?o0000oijA
aonNTLL01_nNTLL2o`0000WoXj?F0ol00003ojO2k@Ko0000@?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo04Gooooo0omJ/o/00ol0003o
YL7]ojG1k@04ojG1k@?o00001_nn^mH3o`000003olReaol0003o`Jc500_o`Jc51?l000000oo3Y[co
0000okZM^`0@okZM^`03o`000?naUK_o/IFk00oo/IFk00?o0000ojJ>_?nVS[`01Ol0000:ojRGa003
o`000?nNTLOoWY7700;oWY770ol00008oj>SeP?o00000onW`^d01?l0003oYl;]o`000?n[j_T3o`00
04;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool00ol0003o
ooooooooo`16ooooo`04o`000?mJ/o_oF[?koeZcn`;o00001OnU`Nd2o`0000Oo_[_F00?o0000ol6/
aOo1[<D03oo1[<D2o`000003okZM^ol0003o000000Ko00002?njWK/00ol0003o/IFkok6E^`06ok6E
^`co00003onXUl@00ol0003oWY77o`000002o`0000WoXj?F0_l00006ojO2k@Go0000AOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000hooooo`;o0000B?ooool01?l0IKgo
0000oeZcnomJ/o/3o`0000CoYL7]0_l00005okjkeP03o`000?nj]=Co^[CD00Go00002oo1[<D00ol0
003o^J?3okVS``07okVS`a7o00002OnaW<<00ol0003oZ9O4ojRGa00>ojRGa0?o00002OnSXmH3o`00
00GoYl;]1Ol00019ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool003[o
oooo00?o0000ooooooooool0B?ooool2o`0000;oF[?k0_l00004ojG1k@?o000000?o_[_Fo`000?nj
]=@01onj]=@4o`0000Oo`Jc500?o0000okVS`oniXl<03oniXl<00ol0003o/Ic3ok6L``0?ok6L``03
o`000?nXUlCoZ9O400WoZ9O41Ol00002ojVVd`03o`000?nSXmKoXj?F00GoXj?F0_l00005ojO2k@Go
0000COooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000kooooo`03o`00
0?oooooooooo04Wooooo0_l00002oeZcn`;o00001OnU`Nd00ol0003o^[CDokZde00;okZde0Go0000
00?o`Jc5o`000?niXl<04OniXl<00ol0003o/Ic3ok6L``0@ok6L``03o`000?nXUlCoZ9O400CoZ9O4
1?l00008ojVVd`03o`000?nSXmKoXj?F00;oXj?F0_l00004ojO2k@Ko0000Coooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo000looooo`;o0000Boooool3o`000006oeZcnol0
003o0000o`000?nU`Ngo00000onU`Nd4o`0000co^[CD0_l00002okVS``?o00003OniXl<00ol0003o
/Ic3ok6L``0@ok6L``03o`000?nXUlCo000000Co00003?nYY]<00ol0003oXj?Fo`000002o`0000?o
Yl;]1_l0001Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003kooooo
00?o0000ooooooooool0Boooool2o`000003oeZcnol0003o000000SoYL7]1?l00009okZde003o`00
0?ne[m?o]JoC00?o]JoC2Ol00004okVS``03o`000?naW<?o/Ic300Oo/Ic32ol0000?ojVVd`Go0000
0_nW`^d3o`000003oiOVo?l0003o000005Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`01ooooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?mH^ocoF;_l00;oF;_l0_l0
0008ojG1k@?o00001_nj]=@00ol0003o]JoCokF_d`0<okF_d`ko00002On_Z]800ol0003oZJKCojVV
d`07ojVVd`Oo00000onV`^d4o`000004oiOVo?l0003o0000o`0005[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`1>ooooo`03o`000?mH
^ocoF;_l00?oF;_l1?l00005ojG1k@Co000000?o^[CDo`000?ne[m<04_ne[m<00ol0003o[j[BojnZ
dP0AojnZdP03o`000?nYY]?oZJKC00Ko00001OnV`^d5o`000003oh3Mo?l0003o000000;o0000GOoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o0000D_ooool2
o`0000CoF;_l1?l00005ojG1k@;o00001?ne[m<00ol0003o]JoCokF_d`0<okF_d`03o`000?n_Z];o
[j[B00co[j[B2?l00006ojK2k@Go000000?oP=glo`000?l000000ol0001Rooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool00_ooool3o`0000;oF;_l1?l00002ojG1k@03o`000?nU`^koYL;^00?oYL;^2_l00004okF_
d`03o`000?n_Z];o[j[B00;o[j[B2_l00005ojK2kP04o`000?nV`^goY/;]ojK2k@Go000000?oP=gl
o`000?l000000ol0001Xooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0014oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool01_ooool4o`000003oeRko?l0003o0000
013oYL;^2Ol0000;ojK2kPSo000000?oP=glo`000?l000000ol0001^ooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`7ooooo0015ooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool02_ooool2o`0000KoGLKk2ol00004ojG2kP03o`000?nV`^koY/;^00;oY/;^5?l0001cooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`;o0000COooool00ol0003ooooo
ooooo`0Gooooo`KoGLKk3ol00022ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0018ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004[ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00Boooool2o`0004Sooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool0/oooool01Ol0003ooooooooooooooooo0000007ooooo001@
ooooo`;o0000@oooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`00007ooooo001B
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]Oooool00ol0003oooooo`000001
ooooo`00Doooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ooooool00Ol0000005Cooooo0_l0000oooooo`03o`000?oooooooooo0;Kooooo0Ol00001ooooo`7o
0000001Fooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0]oooool2o`000000Eooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;Kooooo0ol0000005Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`2booooo`Co00000oooool005Wooooo0_l0000joooo
o`03o`000?oooooooooo0:kooooo1?l00007ooooo`00Foooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo0:[ooooo1?l0000;ooooo`00G?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo0:Kooooo1?l0000?ooooo`00GOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo0:;ooooo1?l0000Cooooo`00G_ooool2o`0003Gooooo00?o0000ooooooooool0W_ooool4
o`0001Oooooo001Pooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0V_ooool4o`00
01_ooooo001Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0V?ooool3o`0001oo
oooo001Rooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0U?ooool4o`0002;ooooo
001Sooooo`;o0000;oooool00ol0003oooooooooo`2@ooooo`Co00009_ooool006Gooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`2<ooooo`Co0000:_ooool006Kooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`28ooooo`Co0000;_ooool006Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`24ooooo`Co0000<_ooool006Sooooo0_l0000Zooooo`03o`00
0?oooooooooo083ooooo1?l0000fooooo`00J_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo07cooooo1?l0000jooooo`00Joooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo07Sooooo1?l0000nooooo`00K?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
07Cooooo1?l00012ooooo`00KOooool2o`0002Gooooo00?o0000ooooooooool0L?ooool4o`0004Ko
oooo001_ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0K?ooool4o`0004[ooooo
001`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0J?ooool4o`0004kooooo001a
ooooo`;o00008Oooool00ol0003oooooooooo`1Tooooo`Co0000D_ooool007?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000E_ooool007Cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1Looooo`Co0000F_ooool007Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`1Iooooo`?o0000G_ooool007Kooooo0_l0000Looooo`03o`000?oo
oooooooo05Gooooo1?l0001Qooooo`00N?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo057ooooo1?l0001Uooooo`00NOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04gooooo1?l0001Yooooo`00N_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wo
oooo1?l0001]ooooo`00Noooool2o`0001Oooooo00?o0000ooooooooool0AOooool4o`00077ooooo
001mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@Oooool4o`0007Gooooo001n
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?Oooool4o`0007Wooooo001ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Oooool4o`0007gooooo0020ooooo`;o
00004_ooool00ol0003oooooooooo`0eooooo`Co0000POooool008;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0aooooo`Co0000QOooool008?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0^ooooo`Co0000ROooool008Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Zooooo`Co0000SOooool008Gooooo0_l0000<ooooo`03o`000?oooooooooo
02Kooooo1?l0002Aooooo`00Qoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;o
oooo1?l0002Eooooo`00R?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo
1?l0002Iooooo`00ROooool2o`0000Sooooo00?o0000ooooooooool06oooool3o`0009gooooo002;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool4o`000:3ooooo002<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool4o`000:Cooooo002=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool4o`000:Sooooo002>ooooo`;o0000
0oooool00ol0003oooooooooo`0;ooooo`Co0000[?ooool0093ooooo00Co0000oooooooooooo0000
2Oooool4o`000;3ooooo002Aooooo`03o`000?oooooo000000Gooooo1?l0002dooooo`00T_ooool2
o`000003ooooool0003o000000;o0000^?ooool009?ooooo0_l0002looooo`00oooooomBooooo`00
oooooomBooooo`00oooooomBooooo`00\
\>"],
  ImageRangeCache->{{{0, 336.375}, {289.062, 0}} -> {-0.069124, -0.00614572, \
0.00379525, 0.00379525}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tFor ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  ", the eigenmodes obviously  have  \[Theta]-dependence ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\) = 
        cos\ m\ \[Theta]\  + \ \[ImaginaryI]\ sin\ m\ \[Theta]\)]],
  ". As discussed above in relation to Eq. ",
  ButtonBox["(4.4.19)",
    ButtonData:>"(4.4.19)",
    ButtonStyle->"Hyperlink"],
  "  the real and imaginary parts simply correspond to oscillations that are \
shifted in \[Theta] by 90\[Degree].  Just as for the cylindrically symmetric \
(",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  ") modes, there are radial nodes where the drumhead is stationary. However, \
there are also locations in \[Theta] where nodes occur. This can be seen in \
Cell ",
  ButtonBox["4.42",
    ButtonData:>"Cell 4.42",
    ButtonStyle->"Hyperlink"],
  ", which plots the real part of the ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, \ n = 2\)]],
  " mode. For this mode, the line ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \[Pi]/2\)]],
  " (the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-axis) is stationary."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(j1\  = \ BesselJZeros[1, 3];\)\), "\[IndentingNewLine]", 
    \(\(\(\[Psi][r_, \[Theta]_]\  := \ 
        BesselJ[1, j1[\([2]\)]\ r]\ Cos[\[Theta]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[
        ParametricPlot3D[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], 
            Cos[t] \[Psi][r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2\ Pi}, 
          PlotRange \[Rule] {\(-1\), 1}, PlotPoints \[Rule] 25, 
          BoxRatios \[Rule] {1, 1, 1/2}], {t, 0, 
          1.8\ Pi, \  .2\ Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.42"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65756 m .51694 .65827 L .43899 .65168 L p .081 .631 .827 r
F P
0 g
s
.51694 .65827 m .51723 .65756 L .59269 .6505 L p .537 .827 .999 r
F P
0 g
s
.59269 .6505 m .59527 .65394 L .51694 .65827 L p .537 .827 .999 r
F P
0 g
s
.59527 .65394 m .59269 .6505 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44204 .65368 m .43899 .65168 L .36521 .63435 L p .362 0 0 r
F P
0 g
s
.43899 .65168 m .44204 .65368 L .51723 .65756 L p .081 .631 .827 r
F P
0 g
s
.51753 .65658 m .51723 .65756 L .44204 .65368 L p .149 .68 .861 r
F P
0 g
s
.51723 .65756 m .51753 .65658 L .59008 .64689 L p .574 .841 .995 r
F P
0 g
s
.59008 .64689 m .59269 .6505 L .51723 .65756 L p .574 .841 .995 r
F P
0 g
s
.59269 .6505 m .59008 .64689 L .65915 .62672 L p .674 .757 .914 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59269 .6505 L p .674 .757 .914 r
F P
0 g
s
.36521 .63435 m .37084 .6389 L .44204 .65368 L p .362 0 0 r
F P
0 g
s
.44513 .65536 m .44204 .65368 L .37084 .6389 L p .311 0 0 r
F P
0 g
s
.44204 .65368 m .44513 .65536 L .51753 .65658 L p .149 .68 .861 r
F P
0 g
s
.51783 .65487 m .51753 .65658 L .44513 .65536 L p .3 .769 .938 r
F P
0 g
s
.51753 .65658 m .51783 .65487 L .58743 .64286 L p .62 .847 .986 r
F P
0 g
s
.58743 .64286 m .59008 .64689 L .51753 .65658 L p .62 .847 .986 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72958 .60506 L p .644 .661 .851 r
F P
0 g
s
.72958 .60506 m .73799 .61332 L .67023 .63881 L p .644 .661 .851 r
F P
0 g
s
.59008 .64689 m .58743 .64286 L .65355 .62061 L p .691 .762 .906 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59008 .64689 L p .691 .762 .906 r
F P
0 g
s
.37084 .6389 m .36521 .63435 L .29943 .6068 L p .538 0 0 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72114 .5969 L p .657 .666 .847 r
F P
0 g
s
.72114 .5969 m .72958 .60506 L .66471 .63279 L p .657 .666 .847 r
F P
0 g
s
.37084 .6389 m .37656 .6431 L .44513 .65536 L p .311 0 0 r
F P
0 g
s
.44829 .65602 m .44513 .65536 L .37656 .6431 L p .141 0 0 r
F P
0 g
s
.44513 .65536 m .44829 .65602 L .51783 .65487 L p .3 .769 .938 r
F P
0 g
s
.51814 .65195 m .51783 .65487 L .44829 .65602 L p .482 .839 .994 r
F P
0 g
s
.51783 .65487 m .51814 .65195 L .58475 .63819 L p .665 .84 .967 r
F P
0 g
s
.58475 .63819 m .58743 .64286 L .51783 .65487 L p .665 .84 .967 r
F P
0 g
s
.58743 .64286 m .58475 .63819 L .6479 .61445 L p .706 .767 .899 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58743 .64286 L p .706 .767 .899 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71268 .58908 L p .672 .677 .847 r
F P
0 g
s
.71268 .58908 m .72114 .5969 L .65915 .62672 L p .672 .677 .847 r
F P
0 g
s
.29943 .6068 m .30742 .61363 L .37084 .6389 L p .538 0 0 r
F P
0 g
s
.37656 .6431 m .37084 .6389 L .30742 .61363 L p .501 0 0 r
F P
0 g
s
.58203 .63266 m .58475 .63819 L .51814 .65195 L p .7 .823 .941 r
F P
0 g
s
.58475 .63819 m .58203 .63266 L .64221 .60824 L p .719 .77 .893 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58475 .63819 L p .719 .77 .893 r
F P
0 g
s
.44829 .65602 m .45152 .65499 L .51814 .65195 L p .482 .839 .994 r
F P
0 g
s
.51845 .64742 m .51814 .65195 L .45152 .65499 L p .623 .848 .985 r
F P
0 g
s
.51814 .65195 m .51845 .64742 L .58203 .63266 L p .7 .823 .941 r
F P
0 g
s
.37656 .6431 m .38241 .64606 L .44829 .65602 L p .141 0 0 r
F P
0 g
s
.44714 .65584 m .38241 .64606 L p .43125 .65237 L .17 .678 .903 r
F P
0 g
s
.45152 .65499 m .44714 .65584 L .43125 .65237 L .17 .678 .903 r
F
.38241 .64606 m .38842 .64696 L .45152 .65499 L p F P
0 g
s
.38842 .64696 m .3946 .64511 L .4015 .64586 L p .489 .812 1 r
F P
0 g
s
.4015 .64586 m .45484 .65171 L p .41531 .64888 L .489 .812 1 r
F P
0 g
s
.41531 .64888 m .38842 .64696 L .4015 .64586 L .489 .812 1 r
F
.45152 .65499 m .44829 .65602 L .44714 .65584 L p .17 .678 .903 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70422 .58182 L p .688 .694 .851 r
F P
0 g
s
.70422 .58182 m .71268 .58908 L .65355 .62061 L p .688 .694 .851 r
F P
0 g
s
.57927 .62613 m .58203 .63266 L .51845 .64742 L p .722 .798 .911 r
F P
0 g
s
.58203 .63266 m .57927 .62613 L .63648 .60198 L p .728 .772 .888 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58203 .63266 L p .728 .772 .888 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69575 .57534 L p .704 .716 .859 r
F P
0 g
s
.69575 .57534 m .70422 .58182 L .6479 .61445 L p .704 .716 .859 r
F P
0 g
s
.45152 .65499 m .45484 .65171 L .51845 .64742 L p .623 .848 .985 r
F P
0 g
s
.51878 .641 m .51845 .64742 L .45484 .65171 L p .7 .814 .936 r
F P
0 g
s
.51845 .64742 m .51878 .641 L .57927 .62613 L p .722 .798 .911 r
F P
0 g
s
.73799 .61332 m .72958 .60506 L .78355 .56836 L p .596 .591 .817 r
F P
0 g
s
.78355 .56836 m .79464 .57831 L .73799 .61332 L p .596 .591 .817 r
F P
0 g
s
.30742 .61363 m .31555 .62007 L .37656 .6431 L p .501 0 0 r
F P
0 g
s
.37656 .6431 m .31555 .62007 L p .36245 .6383 L .356 0 0 r
F P
0 g
s
.31555 .62007 m .32387 .62515 L .38241 .64606 L p .356 0 0 r
F P
0 g
s
.33243 .62793 m .38842 .64696 L p .34683 .63291 L 0 .506 .823 r
F P
0 g
s
.32387 .62515 m .33208 .62781 L p .34683 .63291 L 0 .506 .823 r
F P
0 g
s
.33208 .62781 m .33243 .62793 L p .34683 .63291 L 0 .506 .823 r
F P
0 g
s
.38241 .64606 m .37701 .64333 L p .36245 .6383 L .356 0 0 r
F P
0 g
s
.37701 .64333 m .37656 .6431 L p .36245 .6383 L .356 0 0 r
F P
0 g
s
.45484 .65171 m .45152 .65499 L .38842 .64696 L p .489 .812 1 r
F P
0 g
s
.72958 .60506 m .72114 .5969 L .77246 .55864 L p .608 .597 .814 r
F P
0 g
s
.77246 .55864 m .78355 .56836 L .72958 .60506 L p .608 .597 .814 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68727 .56977 L p .72 .744 .871 r
F P
0 g
s
.68727 .56977 m .69575 .57534 L .64221 .60824 L p .72 .744 .871 r
F P
0 g
s
.57647 .61852 m .57927 .62613 L .51878 .641 L p .733 .771 .883 r
F P
0 g
s
.57927 .62613 m .57647 .61852 L .6307 .59568 L p .733 .773 .885 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57927 .62613 L p .733 .773 .885 r
F P
0 g
s
.30742 .61363 m .29943 .6068 L .24558 .56996 L p .534 0 0 r
F P
0 g
s
.45484 .65171 m .45824 .64577 L .51878 .641 L p .7 .814 .936 r
F P
0 g
s
.5191 .63255 m .51878 .641 L .45824 .64577 L p .734 .77 .882 r
F P
0 g
s
.51878 .641 m .5191 .63255 L .57647 .61852 L p .733 .771 .883 r
F P
0 g
s
.72114 .5969 m .71268 .58908 L .7614 .54965 L p .625 .612 .817 r
F P
0 g
s
.7614 .54965 m .77246 .55864 L .72114 .5969 L p .625 .612 .817 r
F P
0 g
s
.45824 .64577 m .45484 .65171 L .3946 .64511 L p .665 .811 .953 r
F P
0 g
s
.38842 .64696 m .38241 .64606 L .32387 .62515 L p 0 .506 .823 r
F P
0 g
s
.71268 .58908 m .70422 .58182 L .75042 .54183 L p .647 .637 .827 r
F P
0 g
s
.75042 .54183 m .7614 .54965 L .71268 .58908 L p .647 .637 .827 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .6788 .56517 L p .733 .776 .887 r
F P
0 g
s
.6788 .56517 m .68727 .56977 L .63648 .60198 L p .733 .776 .887 r
F P
0 g
s
.57363 .60984 m .57647 .61852 L .5191 .63255 L p .735 .745 .86 r
F P
0 g
s
.57647 .61852 m .57363 .60984 L .62488 .58932 L p .732 .773 .885 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57647 .61852 L p .732 .773 .885 r
F P
0 g
s
.45824 .64577 m .46173 .63695 L .5191 .63255 L p .734 .77 .882 r
F P
0 g
s
.51944 .62205 m .5191 .63255 L .46173 .63695 L p .746 .73 .837 r
F P
0 g
s
.5191 .63255 m .51944 .62205 L .57363 .60984 L p .735 .745 .86 r
F P
0 g
s
.70422 .58182 m .69575 .57534 L .7395 .53555 L p .673 .673 .842 r
F P
0 g
s
.7395 .53555 m .75042 .54183 L .70422 .58182 L p .673 .673 .842 r
F P
0 g
s
.24558 .56996 m .25567 .5787 L .30742 .61363 L p .534 0 0 r
F P
0 g
s
.31555 .62007 m .31234 .61753 L p .30288 .61131 L .493 0 0 r
F P
0 g
s
.25567 .5787 m .26591 .58703 L .31555 .62007 L p .493 0 0 r
F P
0 g
s
.31555 .62007 m .26591 .58703 L p .31677 .62048 L 0 .207 .636 r
F P
0 g
s
.32387 .62515 m .32244 .62427 L p .31677 .62048 L 0 .207 .636 r
F P
0 g
s
.32244 .62427 m .31555 .62007 L p .31677 .62048 L 0 .207 .636 r
F P
0 g
s
.30742 .61363 m .25567 .5787 L p .30288 .61131 L .493 0 0 r
F P
0 g
s
.28714 .59846 m .33243 .62793 L p .2845 .59887 L 0 .449 .851 r
F P
0 g
s
.26591 .58703 m .27 .58973 L p .27914 .59574 L 0 .207 .636 r
F P
0 g
s
.27638 .59395 m .27844 .59481 L p .2845 .59887 L 0 .449 .851 r
F P
0 g
s
.27844 .59481 m .28714 .59846 L p .2845 .59887 L 0 .449 .851 r
F P
0 g
s
.27638 .59395 m .32387 .62515 L p .27914 .59574 L 0 .207 .636 r
F P
0 g
s
.27 .58973 m .27638 .59395 L p .27914 .59574 L 0 .207 .636 r
F P
0 g
s
.31234 .61753 m .30742 .61363 L p .30288 .61131 L .493 0 0 r
F P
0 g
s
.3946 .64511 m .40097 .63999 L .45824 .64577 L p .665 .811 .953 r
F P
0 g
s
.46173 .63695 m .45824 .64577 L .40097 .63999 L p .736 .77 .88 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .6703 .56156 L p .742 .811 .906 r
F P
0 g
s
.6703 .56156 m .6788 .56517 L .6307 .59568 L p .742 .811 .906 r
F P
0 g
s
.57076 .60015 m .57363 .60984 L .51944 .62205 L p .73 .72 .841 r
F P
0 g
s
.57363 .60984 m .57076 .60015 L .61901 .58292 L p .726 .771 .889 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57363 .60984 L p .726 .771 .889 r
F P
0 g
s
.46173 .63695 m .46529 .62526 L .51944 .62205 L p .746 .73 .837 r
F P
0 g
s
.51978 .60967 m .51944 .62205 L .46529 .62526 L p .748 .699 .805 r
F P
0 g
s
.51944 .62205 m .51978 .60967 L .57076 .60015 L p .73 .72 .841 r
F P
0 g
s
.3946 .64511 m .38842 .64696 L .33243 .62793 L p .375 .734 .99 r
F P
0 g
s
.69575 .57534 m .68727 .56977 L .72867 .53107 L p .703 .72 .862 r
F P
0 g
s
.72867 .53107 m .7395 .53555 L .69575 .57534 L p .703 .72 .862 r
F P
0 g
s
.40097 .63999 m .40751 .63134 L .46173 .63695 L p .736 .77 .88 r
F P
0 g
s
.46529 .62526 m .46173 .63695 L .40751 .63134 L p .763 .731 .823 r
F P
0 g
s
.56785 .58962 m .57076 .60015 L .51978 .60967 L p .72 .699 .829 r
F P
0 g
s
.57076 .60015 m .56785 .58962 L .61309 .57646 L p .712 .768 .896 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57076 .60015 L p .712 .768 .896 r
F P
0 g
s
.46529 .62526 m .46891 .61094 L .51978 .60967 L p .748 .699 .805 r
F P
0 g
s
.52012 .59571 m .51978 .60967 L .46891 .61094 L p .743 .674 .783 r
F P
0 g
s
.51978 .60967 m .52012 .59571 L .56785 .58962 L p .72 .699 .829 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66178 .55885 L p .74 .846 .929 r
F P
0 g
s
.66178 .55885 m .6703 .56156 L .62488 .58932 L p .74 .846 .929 r
F P
0 g
s
.68727 .56977 m .6788 .56517 L .7179 .52854 L p .735 .778 .887 r
F P
0 g
s
.7179 .52854 m .72867 .53107 L .68727 .56977 L p .735 .778 .887 r
F P
0 g
s
.40751 .63134 m .4142 .61917 L .46529 .62526 L p .763 .731 .823 r
F P
0 g
s
.46891 .61094 m .46529 .62526 L .4142 .61917 L p .773 .701 .783 r
F P
0 g
s
.46891 .61094 m .47258 .59442 L .52012 .59571 L p .743 .674 .783 r
F P
0 g
s
.52047 .58062 m .52012 .59571 L .47258 .59442 L p .735 .654 .769 r
F P
0 g
s
.52012 .59571 m .52047 .58062 L .56492 .57846 L p .705 .679 .822 r
F P
0 g
s
.56492 .57846 m .56785 .58962 L .52012 .59571 L p .705 .679 .822 r
F P
0 g
s
.33243 .62793 m .34124 .62762 L .3946 .64511 L p .375 .734 .99 r
F P
0 g
s
.40097 .63999 m .3946 .64511 L .34124 .62762 L p .63 .79 .959 r
F P
0 g
s
.56785 .58962 m .56492 .57846 L .60713 .56996 L p .688 .761 .908 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56785 .58962 L p .688 .761 .908 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65322 .5569 L p .723 .878 .953 r
F P
0 g
s
.65322 .5569 m .66178 .55885 L .61901 .58292 L p .723 .878 .953 r
F P
0 g
s
.6788 .56517 m .6703 .56156 L .70717 .52795 L p .763 .845 .913 r
F P
0 g
s
.70717 .52795 m .7179 .52854 L .6788 .56517 L p .763 .845 .913 r
F P
0 g
s
.4142 .61917 m .42102 .60378 L .46891 .61094 L p .773 .701 .783 r
F P
0 g
s
.47258 .59442 m .46891 .61094 L .42102 .60378 L p .775 .679 .758 r
F P
0 g
s
.47258 .59442 m .47629 .57633 L .52047 .58062 L p .735 .654 .769 r
F P
0 g
s
.52082 .5649 m .52047 .58062 L .47629 .57633 L p .723 .638 .763 r
F P
0 g
s
.52047 .58062 m .52082 .5649 L .56197 .56695 L p .684 .661 .821 r
F P
0 g
s
.56197 .56695 m .56492 .57846 L .52047 .58062 L p .684 .661 .821 r
F P
0 g
s
.42102 .60378 m .42793 .58573 L .47258 .59442 L p .775 .679 .758 r
F P
0 g
s
.47629 .57633 m .47258 .59442 L .42793 .58573 L p .772 .662 .742 r
F P
0 g
s
.56492 .57846 m .56197 .56695 L .60112 .5634 L p .651 .75 .922 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56492 .57846 L p .651 .75 .922 r
F P
0 g
s
.47629 .57633 m .48001 .55743 L .52082 .5649 L p .723 .638 .763 r
F P
0 g
s
.52117 .54915 m .52082 .5649 L .48001 .55743 L p .706 .624 .763 r
F P
0 g
s
.52082 .5649 m .52117 .54915 L .55901 .55538 L p .656 .643 .826 r
F P
0 g
s
.55901 .55538 m .56197 .56695 L .52082 .5649 L p .656 .643 .826 r
F P
0 g
s
.34124 .62762 m .35033 .62364 L .40097 .63999 L p .63 .79 .959 r
F P
0 g
s
.40751 .63134 m .40097 .63999 L .35033 .62364 L p .738 .771 .88 r
F P
0 g
s
.79464 .57831 m .78355 .56836 L .82289 .52421 L p .528 .536 .807 r
F P
0 g
s
.82289 .52421 m .83625 .53514 L .79464 .57831 L p .528 .536 .807 r
F P
0 g
s
.42793 .58573 m .43489 .5658 L .47629 .57633 L p .772 .662 .742 r
F P
0 g
s
.48001 .55743 m .47629 .57633 L .43489 .5658 L p .765 .65 .734 r
F P
0 g
s
.78355 .56836 m .77246 .55864 L .80959 .51366 L p .541 .543 .806 r
F P
0 g
s
.80959 .51366 m .82289 .52421 L .78355 .56836 L p .541 .543 .806 r
F P
0 g
s
.43489 .5658 m .44188 .54492 L .48001 .55743 L p .765 .65 .734 r
F P
0 g
s
.48374 .53853 m .48001 .55743 L .44188 .54492 L p .755 .64 .733 r
F P
0 g
s
.48001 .55743 m .48374 .53853 L .52117 .54915 L p .706 .624 .763 r
F P
0 g
s
.77246 .55864 m .7614 .54965 L .79641 .50419 L p .562 .562 .811 r
F P
0 g
s
.79641 .50419 m .80959 .51366 L .77246 .55864 L p .562 .562 .811 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64461 .55549 L p .68 .899 .975 r
F P
0 g
s
.64461 .55549 m .65322 .5569 L .61309 .57646 L p .68 .899 .975 r
F P
0 g
s
.6703 .56156 m .66178 .55885 L .69647 .52916 L p .776 .914 .933 r
F P
0 g
s
.69647 .52916 m .70717 .52795 L .6703 .56156 L p .776 .914 .933 r
F P
0 g
s
.33243 .62793 m .32387 .62515 L .27638 .59395 L p 0 .449 .851 r
F P
0 g
s
.44188 .54492 m .44885 .52411 L .48374 .53853 L p .755 .64 .733 r
F P
0 g
s
.48746 .52046 m .48374 .53853 L .44885 .52411 L p .74 .631 .739 r
F P
0 g
s
.48374 .53853 m .48746 .52046 L .52152 .53395 L p .683 .612 .77 r
F P
0 g
s
.52152 .53395 m .52117 .54915 L .48374 .53853 L p .683 .612 .77 r
F P
0 g
s
.52117 .54915 m .52152 .53395 L .55602 .54405 L p .617 .624 .835 r
F P
0 g
s
.55602 .54405 m .55901 .55538 L .52117 .54915 L p .617 .624 .835 r
F P
0 g
s
.7614 .54965 m .75042 .54183 L .78339 .49641 L p .593 .594 .823 r
F P
0 g
s
.78339 .49641 m .79641 .50419 L .7614 .54965 L p .593 .594 .823 r
F P
0 g
s
.56197 .56695 m .55901 .55538 L .59506 .55679 L p .596 .73 .938 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56197 .56695 L p .596 .73 .938 r
F P
0 g
s
.44885 .52411 m .4558 .50437 L .48746 .52046 L p .74 .631 .739 r
F P
0 g
s
.49117 .50399 m .48746 .52046 L .4558 .50437 L p .717 .623 .751 r
F P
0 g
s
.48746 .52046 m .49117 .50399 L .52187 .51985 L p .65 .598 .783 r
F P
0 g
s
.52187 .51985 m .52152 .53395 L .48746 .52046 L p .65 .598 .783 r
F P
0 g
s
.35033 .62364 m .35966 .61571 L .40751 .63134 L p .738 .771 .88 r
F P
0 g
s
.4142 .61917 m .40751 .63134 L .35966 .61571 L p .782 .743 .817 r
F P
0 g
s
.75042 .54183 m .7395 .53555 L .77055 .49086 L p .633 .641 .841 r
F P
0 g
s
.77055 .49086 m .78339 .49641 L .75042 .54183 L p .633 .641 .841 r
F P
0 g
s
.52152 .53395 m .52187 .51985 L .55303 .53327 L p .561 .6 .849 r
F P
0 g
s
.55303 .53327 m .55602 .54405 L .52152 .53395 L p .561 .6 .849 r
F P
0 g
s
.4558 .50437 m .4627 .48663 L .49117 .50399 L p .717 .623 .751 r
F P
0 g
s
.49488 .4898 m .49117 .50399 L .4627 .48663 L p .682 .613 .772 r
F P
0 g
s
.49117 .50399 m .49488 .4898 L .52222 .50733 L p .601 .58 .802 r
F P
0 g
s
.52222 .50733 m .52187 .51985 L .49117 .50399 L p .601 .58 .802 r
F P
0 g
s
.7395 .53555 m .72867 .53107 L .75789 .48789 L p .682 .703 .863 r
F P
0 g
s
.75789 .48789 m .77055 .49086 L .7395 .53555 L p .682 .703 .863 r
F P
0 g
s
.41856 .5067 m .42838 .48659 L .4558 .50437 L p .794 .671 .729 r
F P
0 g
s
.4558 .50437 m .44885 .52411 L .41856 .5067 L p .794 .671 .729 r
F P
0 g
s
.4627 .48663 m .4558 .50437 L .42838 .48659 L p .777 .667 .742 r
F P
0 g
s
.35966 .61571 m .36922 .60385 L .4142 .61917 L p .782 .743 .817 r
F P
0 g
s
.42102 .60378 m .4142 .61917 L .36922 .60385 L p .802 .721 .775 r
F P
0 g
s
.25567 .5787 m .24558 .56996 L .20758 .52532 L p 0 .14 .657 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63593 .55436 L p .603 .897 .987 r
F P
0 g
s
.63593 .55436 m .64461 .55549 L .60713 .56996 L p .603 .897 .987 r
F P
0 g
s
.40867 .52805 m .41856 .5067 L .44885 .52411 L p .804 .676 .723 r
F P
0 g
s
.44885 .52411 m .44188 .54492 L .40867 .52805 L p .804 .676 .723 r
F P
0 g
s
.66178 .55885 m .65322 .5569 L .68576 .5319 L p .755 .965 .932 r
F P
0 g
s
.68576 .5319 m .69647 .52916 L .66178 .55885 L p .755 .965 .932 r
F P
0 g
s
.42838 .48659 m .43812 .46877 L .4627 .48663 L p .777 .667 .742 r
F P
0 g
s
.46957 .47171 m .4627 .48663 L .43812 .46877 L p .749 .662 .765 r
F P
0 g
s
.4627 .48663 m .46957 .47171 L .49488 .4898 L p .682 .613 .772 r
F P
0 g
s
.55901 .55538 m .55602 .54405 L .58896 .55013 L p .517 .697 .951 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55901 .55538 L p .517 .697 .951 r
F P
0 g
s
.39874 .54953 m .40867 .52805 L .44188 .54492 L p .81 .683 .723 r
F P
0 g
s
.44188 .54492 m .43489 .5658 L .39874 .54953 L p .81 .683 .723 r
F P
0 g
s
.36922 .60385 m .37896 .58839 L .42102 .60378 L p .802 .721 .775 r
F P
0 g
s
.42793 .58573 m .42102 .60378 L .37896 .58839 L p .81 .704 .748 r
F P
0 g
s
.38882 .56999 m .39874 .54953 L .43489 .5658 L p .812 .692 .731 r
F P
0 g
s
.43489 .5658 m .42793 .58573 L .38882 .56999 L p .812 .692 .731 r
F P
0 g
s
.49857 .47841 m .49488 .4898 L .46957 .47171 L p .626 .597 .801 r
F P
0 g
s
.49488 .4898 m .49857 .47841 L .52257 .49679 L p .525 .553 .827 r
F P
0 g
s
.52257 .49679 m .52222 .50733 L .49488 .4898 L p .525 .553 .827 r
F P
0 g
s
.52187 .51985 m .52222 .50733 L .55002 .52328 L p .481 .565 .864 r
F P
0 g
s
.55002 .52328 m .55303 .53327 L .52187 .51985 L p .481 .565 .864 r
F P
0 g
s
.37896 .58839 m .38882 .56999 L .42793 .58573 L p .81 .704 .748 r
F P
0 g
s
.43812 .46877 m .44776 .45412 L .46957 .47171 L p .749 .662 .765 r
F P
0 g
s
.47639 .46024 m .46957 .47171 L .44776 .45412 L p .701 .652 .798 r
F P
0 g
s
.46957 .47171 m .47639 .46024 L .49857 .47841 L p .626 .597 .801 r
F P
0 g
s
.34124 .62762 m .33243 .62793 L .28714 .59846 L p .352 .669 .975 r
F P
0 g
s
.72867 .53107 m .7179 .52854 L .74538 .4877 L p .737 .779 .887 r
F P
0 g
s
.74538 .4877 m .75789 .48789 L .72867 .53107 L p .737 .779 .887 r
F P
0 g
s
.55602 .54405 m .55303 .53327 L .5828 .54342 L p .405 .643 .954 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55602 .54405 L p .405 .643 .954 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62716 .55321 L p .48 .86 .981 r
F P
0 g
s
.62716 .55321 m .63593 .55436 L .60112 .5634 L p .48 .86 .981 r
F P
0 g
s
.44776 .45412 m .45733 .44334 L .47639 .46024 L p .701 .652 .798 r
F P
0 g
s
.4832 .45263 m .47639 .46024 L .45733 .44334 L p .617 .63 .842 r
F P
0 g
s
.47639 .46024 m .4832 .45263 L .50227 .47016 L p .531 .567 .836 r
F P
0 g
s
.50227 .47016 m .49857 .47841 L .47639 .46024 L p .531 .567 .836 r
F P
0 g
s
.52222 .50733 m .52257 .49679 L .54699 .51428 L p .363 .513 .873 r
F P
0 g
s
.54699 .51428 m .55002 .52328 L .52222 .50733 L p .363 .513 .873 r
F P
0 g
s
.49857 .47841 m .50227 .47016 L .52293 .48846 L p .404 .505 .848 r
F P
0 g
s
.52293 .48846 m .52257 .49679 L .49857 .47841 L p .404 .505 .848 r
F P
0 g
s
.65322 .5569 m .64461 .55549 L .675 .53575 L p .683 .977 .897 r
F P
0 g
s
.675 .53575 m .68576 .5319 L .65322 .5569 L p .683 .977 .897 r
F P
0 g
s
.7179 .52854 m .70717 .52795 L .73301 .49028 L p .79 .864 .904 r
F P
0 g
s
.73301 .49028 m .74538 .4877 L .7179 .52854 L p .79 .864 .904 r
F P
0 g
s
.4069 .46814 m .41892 .45144 L .43812 .46877 L p .834 .73 .75 r
F P
0 g
s
.43812 .46877 m .42838 .48659 L .4069 .46814 L p .834 .73 .75 r
F P
0 g
s
.44776 .45412 m .43812 .46877 L .41892 .45144 L p .809 .73 .777 r
F P
0 g
s
.41892 .45144 m .43079 .43806 L .44776 .45412 L p .809 .73 .777 r
F P
0 g
s
.45733 .44334 m .44776 .45412 L .43079 .43806 L p .763 .725 .818 r
F P
0 g
s
.39475 .48725 m .4069 .46814 L .42838 .48659 L p .848 .73 .733 r
F P
0 g
s
.42838 .48659 m .41856 .5067 L .39475 .48725 L p .848 .73 .733 r
F P
0 g
s
.20758 .52532 m .21937 .53552 L .25567 .5787 L p 0 .14 .657 r
F P
0 g
s
.26591 .58703 m .25567 .5787 L .21937 .53552 L p 0 .182 .694 r
F P
0 g
s
.28714 .59846 m .29821 .59976 L .34124 .62762 L p .352 .669 .975 r
F P
0 g
s
.35033 .62364 m .34124 .62762 L .29821 .59976 L p .611 .759 .95 r
F P
0 g
s
.43079 .43806 m .44254 .42873 L .45733 .44334 L p .763 .725 .818 r
F P
0 g
s
.46685 .43689 m .45733 .44334 L .44254 .42873 L p .674 .707 .872 r
F P
0 g
s
.45733 .44334 m .46685 .43689 L .4832 .45263 L p .617 .63 .842 r
F P
0 g
s
.55303 .53327 m .55002 .52328 L .5766 .53665 L p .257 .561 .934 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55303 .53327 L p .257 .561 .934 r
F P
0 g
s
.38248 .5077 m .39475 .48725 L .41856 .5067 L p .855 .731 .726 r
F P
0 g
s
.41856 .5067 m .40867 .52805 L .38248 .5077 L p .855 .731 .726 r
F P
0 g
s
.49002 .44904 m .4832 .45263 L .46685 .43689 L p .458 .573 .882 r
F P
0 g
s
.4832 .45263 m .49002 .44904 L .50598 .46521 L p .366 .501 .861 r
F P
0 g
s
.50598 .46521 m .50227 .47016 L .4832 .45263 L p .366 .501 .861 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61831 .55172 L p .314 .775 .946 r
F P
0 g
s
.61831 .55172 m .62716 .55321 L .59506 .55679 L p .314 .775 .946 r
F P
0 g
s
.52257 .49679 m .52293 .48846 L .54395 .50642 L p .197 .429 .859 r
F P
0 g
s
.54395 .50642 m .54699 .51428 L .52257 .49679 L p .197 .429 .859 r
F P
0 g
s
.70717 .52795 m .69647 .52916 L .72071 .49545 L p .826 .942 .901 r
F P
0 g
s
.72071 .49545 m .73301 .49028 L .70717 .52795 L p .826 .942 .901 r
F P
0 g
s
.50227 .47016 m .50598 .46521 L .52328 .48246 L p .213 .418 .845 r
F P
0 g
s
.52328 .48246 m .52293 .48846 L .50227 .47016 L p .213 .418 .845 r
F P
0 g
s
.37014 .52832 m .38248 .5077 L .40867 .52805 L p .857 .734 .726 r
F P
0 g
s
.40867 .52805 m .39874 .54953 L .37014 .52832 L p .857 .734 .726 r
F P
0 g
s
.64461 .55549 m .63593 .55436 L .66416 .54021 L p .555 .931 .825 r
F P
0 g
s
.66416 .54021 m .675 .53575 L .64461 .55549 L p .555 .931 .825 r
F P
0 g
s
.44254 .42873 m .45421 .4239 L .46685 .43689 L p .674 .707 .872 r
F P
0 g
s
.47636 .43494 m .46685 .43689 L .45421 .4239 L p .5 .645 .921 r
F P
0 g
s
.46685 .43689 m .47636 .43494 L .49002 .44904 L p .458 .573 .882 r
F P
0 g
s
.29821 .59976 m .30962 .59724 L .35033 .62364 L p .611 .759 .95 r
F P
0 g
s
.35966 .61571 m .35033 .62364 L .30962 .59724 L p .739 .773 .88 r
F P
0 g
s
.55002 .52328 m .54699 .51428 L .57035 .52982 L p .077 .447 .88 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55002 .52328 L p .077 .447 .88 r
F P
0 g
s
.35778 .54792 m .37014 .52832 L .39874 .54953 L p .855 .738 .734 r
F P
0 g
s
.39874 .54953 m .38882 .56999 L .35778 .54792 L p .855 .738 .734 r
F P
0 g
s
.21937 .53552 m .23132 .54531 L .26591 .58703 L p 0 .182 .694 r
F P
0 g
s
.27638 .59395 m .26591 .58703 L .23132 .54531 L p 0 .301 .788 r
F P
0 g
s
.30962 .59724 m .32133 .5906 L .35966 .61571 L p .739 .773 .88 r
F P
0 g
s
.36922 .60385 m .35966 .61571 L .32133 .5906 L p .8 .765 .821 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60936 .54959 L p .119 .644 .878 r
F P
0 g
s
.60936 .54959 m .60031 .54655 L .60337 .54745 L p .149 0 0 r
F P
0 g
s
.60936 .54959 m .61831 .55172 L .6148 .55153 L p .119 .644 .878 r
F P
0 g
s
.63593 .55436 m .62716 .55321 L .64693 .54674 L p .386 .836 .733 r
F P
0 g
s
.64693 .54674 m .65321 .54468 L p .65074 .54606 L .386 .836 .733 r
F P
0 g
s
.65074 .54606 m .63593 .55436 L .64693 .54674 L .386 .836 .733 r
F
.64213 .54857 m .65321 .54468 L .64189 .54839 L p 0 0 0 r
F P
0 g
s
.64189 .54839 m .62716 .55321 L p .64213 .54857 L 0 0 0 r
F P
0 g
s
.62716 .55321 m .61831 .55172 L .63384 .54966 L p 0 0 0 r
F P
0 g
s
.63384 .54966 m .64213 .54857 L p .63871 .54963 L 0 0 0 r
F P
0 g
s
.63871 .54963 m .62716 .55321 L .63384 .54966 L 0 0 0 r
F
.6309 .55126 m .64213 .54857 L p .61998 .5515 L F P
0 g
s
.61998 .5515 m .61831 .55172 L p .61884 .5517 L 0 0 0 r
F P
0 g
s
.6309 .55126 m .61998 .5515 L .61884 .5517 L 0 0 0 r
F
.61831 .55172 m .61725 .55146 L p .6309 .55126 L F P
0 g
s
.61725 .55146 m .60936 .54959 L p .62107 .5505 L 0 0 0 r
F P
0 g
s
.61233 .54982 m .60936 .54959 L p .61031 .54983 L .149 0 0 r
F P
0 g
s
.61952 .55223 m .61233 .54982 L .61031 .54983 L .149 0 0 r
F
.60337 .54745 m .61952 .55223 L p .60936 .54959 L F P
0 g
s
.6148 .55153 m .58896 .55013 L p .60936 .54959 L .119 .644 .878 r
F P
0 g
s
.60031 .54655 m .60936 .54959 L .60534 .54865 L p 0 .487 .786 r
F P
0 g
s
.60534 .54865 m .5828 .54342 L p .60031 .54655 L 0 .487 .786 r
F P
0 g
s
.59116 .54238 m .60031 .54655 L .59595 .54472 L p 0 .329 .686 r
F P
0 g
s
.59595 .54472 m .5766 .53665 L p .59116 .54238 L 0 .329 .686 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59116 .54238 L p 0 .329 .686 r
F P
0 g
s
.59116 .54238 m .58192 .53694 L .58578 .53974 L p .421 0 0 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .60031 .54655 L p 0 .487 .786 r
F P
0 g
s
.58578 .53974 m .59634 .54741 L p .59116 .54238 L .421 0 0 r
F P
0 g
s
.60031 .54655 m .59116 .54238 L .5947 .5442 L p .3 0 0 r
F P
0 g
s
.5947 .5442 m .608 .55104 L p .60031 .54655 L .3 0 0 r
F P
0 g
s
.608 .55104 m .61952 .55223 L .60438 .54775 L p .3 0 0 r
F P
0 g
s
.60438 .54775 m .60031 .54655 L p .60158 .54729 L .3 0 0 r
F P
0 g
s
.608 .55104 m .60438 .54775 L .60158 .54729 L .3 0 0 r
F
.6309 .55126 m .62614 .55133 L .62107 .5505 L 0 0 0 r
F
.62614 .55133 m .61725 .55146 L .62107 .5505 L F
.61952 .55223 m .6309 .55126 L .61233 .54982 L p .149 0 0 r
F P
0 g
s
.64213 .54857 m .6309 .55126 L .64249 .54884 L p 0 0 0 r
F P
0 g
s
.64249 .54884 m .64582 .54814 L p .64213 .54857 L 0 0 0 r
F P
0 g
s
.69647 .52916 m .68576 .5319 L .70845 .50281 L p .824 .992 .866 r
F P
0 g
s
.70845 .50281 m .72071 .49545 L .69647 .52916 L p .824 .992 .866 r
F P
0 g
s
.34548 .56542 m .35778 .54792 L .38882 .56999 L p .847 .745 .751 r
F P
0 g
s
.38882 .56999 m .37896 .58839 L .34548 .56542 L p .847 .745 .751 r
F P
0 g
s
.40639 .4357 m .41977 .42454 L .43079 .43806 L p .86 .824 .811 r
F P
0 g
s
.43079 .43806 m .41892 .45144 L .40639 .4357 L p .86 .824 .811 r
F P
0 g
s
.44254 .42873 m .43079 .43806 L .41977 .42454 L p .806 .824 .865 r
F P
0 g
s
.52293 .48846 m .52328 .48246 L .54088 .49975 L p 0 .309 .801 r
F P
0 g
s
.54088 .49975 m .54395 .50642 L .52293 .48846 L p 0 .309 .801 r
F P
0 g
s
.49686 .44942 m .49002 .44904 L .47636 .43494 L p .181 .439 .869 r
F P
0 g
s
.49002 .44904 m .49686 .44942 L .50971 .46348 L p .099 .368 .832 r
F P
0 g
s
.50971 .46348 m .50598 .46521 L .49002 .44904 L p .099 .368 .832 r
F P
0 g
s
.41977 .42454 m .43299 .41732 L .44254 .42873 L p .806 .824 .865 r
F P
0 g
s
.45421 .4239 m .44254 .42873 L .43299 .41732 L p .693 .802 .932 r
F P
0 g
s
.32133 .5906 m .3333 .57987 L .36922 .60385 L p .8 .765 .821 r
F P
0 g
s
.37896 .58839 m .36922 .60385 L .3333 .57987 L p .831 .754 .779 r
F P
0 g
s
.39282 .45012 m .40639 .4357 L .41892 .45144 L p .887 .818 .774 r
F P
0 g
s
.41892 .45144 m .4069 .46814 L .39282 .45012 L p .887 .818 .774 r
F P
0 g
s
.3333 .57987 m .34548 .56542 L .37896 .58839 L p .831 .754 .779 r
F P
0 g
s
.50598 .46521 m .50971 .46348 L .52364 .47873 L p 0 .275 .78 r
F P
0 g
s
.52364 .47873 m .52328 .48246 L .50598 .46521 L p 0 .275 .78 r
F P
0 g
s
.65321 .54468 m .66416 .54021 L .63593 .55436 L p .386 .836 .733 r
F P
0 g
s
.45421 .4239 m .46583 .42375 L .47636 .43494 L p .5 .645 .921 r
F P
0 g
s
.48589 .43741 m .47636 .43494 L .46583 .42375 L p .188 .486 .899 r
F P
0 g
s
.47636 .43494 m .48589 .43741 L .49686 .44942 L p .181 .439 .869 r
F P
0 g
s
.43299 .41732 m .44609 .41448 L .45421 .4239 L p .693 .802 .932 r
F P
0 g
s
.46583 .42375 m .45421 .4239 L .44609 .41448 L p .465 .708 .974 r
F P
0 g
s
.54699 .51428 m .54395 .50642 L .56404 .52294 L p 0 .312 .791 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54699 .51428 L p 0 .312 .791 r
F P
0 g
s
.37907 .46691 m .39282 .45012 L .4069 .46814 L p .9 .811 .752 r
F P
0 g
s
.4069 .46814 m .39475 .48725 L .37907 .46691 L p .9 .811 .752 r
F P
0 g
s
.68576 .5319 m .675 .53575 L .69617 .51178 L p .772 .995 .798 r
F P
0 g
s
.69617 .51178 m .70845 .50281 L .68576 .5319 L p .772 .995 .798 r
F P
0 g
s
.23132 .54531 m .2435 .55371 L .27638 .59395 L p 0 .301 .788 r
F P
0 g
s
.28714 .59846 m .27638 .59395 L .2435 .55371 L p .139 .472 .894 r
F P
0 g
s
.79641 .50419 m .78339 .49641 L .80039 .44805 L p .526 .564 .837 r
F P
0 g
s
.78339 .49641 m .77055 .49086 L .78632 .44375 L p .586 .623 .855 r
F P
0 g
s
.78632 .44375 m .80039 .44805 L .78339 .49641 L p .586 .623 .855 r
F P
0 g
s
.77055 .49086 m .75789 .48789 L .77254 .44265 L p .659 .697 .874 r
F P
0 g
s
.77254 .44265 m .78632 .44375 L .77055 .49086 L p .659 .697 .874 r
F P
0 g
s
.80959 .51366 m .79641 .50419 L .81473 .45509 L p .481 .522 .823 r
F P
0 g
s
.80039 .44805 m .81473 .45509 L .79641 .50419 L p .526 .564 .837 r
F P
0 g
s
.36517 .48502 m .37907 .46691 L .39475 .48725 L p .904 .807 .741 r
F P
0 g
s
.39475 .48725 m .38248 .5077 L .36517 .48502 L p .904 .807 .741 r
F P
0 g
s
.52328 .48246 m .52364 .47873 L .53779 .49423 L p 0 .163 .693 r
F P
0 g
s
.53779 .49423 m .54088 .49975 L .52328 .48246 L p 0 .163 .693 r
F P
0 g
s
.44609 .41448 m .45912 .41621 L .46583 .42375 L p .465 .708 .974 r
F P
0 g
s
.47746 .42821 m .46583 .42375 L .45912 .41621 L p .095 .485 .898 r
F P
0 g
s
.46583 .42375 m .47746 .42821 L .48589 .43741 L p .188 .486 .899 r
F P
0 g
s
.82289 .52421 m .80959 .51366 L .82932 .46427 L p .45 .497 .815 r
F P
0 g
s
.81473 .45509 m .82932 .46427 L .80959 .51366 L p .481 .522 .823 r
F P
0 g
s
.75789 .48789 m .74538 .4877 L .75901 .44497 L p .739 .779 .886 r
F P
0 g
s
.75901 .44497 m .77254 .44265 L .75789 .48789 L p .739 .779 .886 r
F P
0 g
s
.50377 .45342 m .49686 .44942 L .48589 .43741 L p 0 .218 .735 r
F P
0 g
s
.49686 .44942 m .50377 .45342 L .51348 .4647 L p 0 .171 .701 r
F P
0 g
s
.51348 .4647 m .50971 .46348 L .49686 .44942 L p 0 .171 .701 r
F P
0 g
s
.54395 .50642 m .54088 .49975 L .55769 .51601 L p 0 .175 .681 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54395 .50642 L p 0 .175 .681 r
F P
0 g
s
.83625 .53514 m .82289 .52421 L .84412 .4748 L p .435 .488 .815 r
F P
0 g
s
.82932 .46427 m .84412 .4748 L .82289 .52421 L p .45 .497 .815 r
F P
0 g
s
.49549 .44395 m .48589 .43741 L .47746 .42821 L p 0 .232 .737 r
F P
0 g
s
.48589 .43741 m .49549 .44395 L .50377 .45342 L p 0 .218 .735 r
F P
0 g
s
.50971 .46348 m .51348 .4647 L .524 .47708 L p 0 .102 .641 r
F P
0 g
s
.524 .47708 m .52364 .47873 L .50971 .46348 L p 0 .102 .641 r
F P
0 g
s
.74538 .4877 m .73301 .49028 L .74569 .45073 L p .813 .861 .884 r
F P
0 g
s
.74569 .45073 m .75901 .44497 L .74538 .4877 L p .813 .861 .884 r
F P
0 g
s
.35116 .50331 m .36517 .48502 L .38248 .5077 L p .902 .803 .74 r
F P
0 g
s
.38248 .5077 m .37014 .52832 L .35116 .50331 L p .902 .803 .74 r
F P
0 g
s
.84412 .4748 m .85906 .48583 L .83625 .53514 L p .435 .488 .815 r
F P
0 g
s
.675 .53575 m .66416 .54021 L .68381 .52165 L p .676 .955 .714 r
F P
0 g
s
.68381 .52165 m .69617 .51178 L .675 .53575 L p .676 .955 .714 r
F P
0 g
s
.41555 .41447 m .4294 .4099 L .43299 .41732 L p .782 .937 .931 r
F P
0 g
s
.43299 .41732 m .41977 .42454 L .41555 .41447 L p .782 .937 .931 r
F P
0 g
s
.44609 .41448 m .43299 .41732 L .4294 .4099 L p .598 .877 .992 r
F P
0 g
s
.2435 .55371 m .25599 .55978 L .28714 .59846 L p .139 .472 .894 r
F P
0 g
s
.29821 .59976 m .28714 .59846 L .25599 .55978 L p .406 .632 .946 r
F P
0 g
s
.40152 .4226 m .41555 .41447 L .41977 .42454 L p .87 .94 .862 r
F P
0 g
s
.41977 .42454 m .40639 .4357 L .40152 .4226 L p .87 .94 .862 r
F P
0 g
s
.4294 .4099 m .44311 .40931 L .44609 .41448 L p .598 .877 .992 r
F P
0 g
s
.45912 .41621 m .44609 .41448 L .44311 .40931 L p .272 .691 .968 r
F P
0 g
s
.45912 .41621 m .47212 .4224 L .47746 .42821 L p .095 .485 .898 r
F P
0 g
s
.48915 .43688 m .47746 .42821 L .47212 .4224 L p 0 .201 .694 r
F P
0 g
s
.47746 .42821 m .48915 .43688 L .49549 .44395 L p 0 .232 .737 r
F P
0 g
s
.73301 .49028 m .72071 .49545 L .73252 .45966 L p .869 .927 .861 r
F P
0 g
s
.73252 .45966 m .74569 .45073 L .73301 .49028 L p .869 .927 .861 r
F P
0 g
s
.33709 .52065 m .35116 .50331 L .37014 .52832 L p .895 .801 .748 r
F P
0 g
s
.37014 .52832 m .35778 .54792 L .33709 .52065 L p .895 .801 .748 r
F P
0 g
s
.52364 .47873 m .524 .47708 L .53468 .48977 L p 0 .026 .561 r
F P
0 g
s
.53468 .48977 m .53779 .49423 L .52364 .47873 L p 0 .026 .561 r
F P
0 g
s
.38728 .43369 m .40152 .4226 L .40639 .4357 L p .91 .928 .813 r
F P
0 g
s
.40639 .4357 m .39282 .45012 L .38728 .43369 L p .91 .928 .813 r
F P
0 g
s
.54088 .49975 m .53779 .49423 L .55128 .50901 L p 0 .055 .57 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54088 .49975 L p 0 .055 .57 r
F P
0 g
s
.58192 .53694 m .59116 .54238 L .58658 .53961 L p .375 0 0 r
F P
0 g
s
.58658 .53961 m .57035 .52982 L p .58192 .53694 L .375 0 0 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58192 .53694 L p .375 0 0 r
F P
0 g
s
.58192 .53694 m .5726 .53016 L .57666 .53391 L p .51 0 0 r
F P
0 g
s
.57666 .53391 m .58458 .54122 L p .58192 .53694 L .51 0 0 r
F P
0 g
s
.44311 .40931 m .45671 .41284 L .45912 .41621 L p .272 .691 .968 r
F P
0 g
s
.47212 .4224 m .45912 .41621 L .45671 .41284 L p 0 .394 .805 r
F P
0 g
s
.25599 .55978 m .2688 .5627 L .29821 .59976 L p .406 .632 .946 r
F P
0 g
s
.30962 .59724 m .29821 .59976 L .2688 .5627 L p .612 .73 .93 r
F P
0 g
s
.32306 .53596 m .33709 .52065 L .35778 .54792 L p .881 .8 .766 r
F P
0 g
s
.35778 .54792 m .34548 .56542 L .32306 .53596 L p .881 .8 .766 r
F P
0 g
s
.51077 .46049 m .50377 .45342 L .49549 .44395 L p 0 .007 .537 r
F P
0 g
s
.50377 .45342 m .51077 .46049 L .51729 .4684 L p 0 0 .521 r
F P
0 g
s
.51348 .4647 m .50377 .45342 L p .51611 .46709 L 0 0 .521 r
F P
0 g
s
.51679 .46791 m .51348 .4647 L p .51611 .46709 L 0 0 .521 r
F P
0 g
s
.51348 .4647 m .51729 .4684 L .52437 .47715 L p 0 0 .488 r
F P
0 g
s
.524 .47708 m .51348 .4647 L p .52226 .47474 L 0 0 .488 r
F P
0 g
s
.52437 .47715 m .52423 .47712 L p .52226 .47474 L 0 0 .488 r
F P
0 g
s
.52423 .47712 m .524 .47708 L p .52226 .47474 L 0 0 .488 r
F P
0 g
s
.51788 .46983 m .52117 .47392 L p .51501 .46597 L .607 .127 0 r
F P
0 g
s
.51501 .46597 m .51241 .46261 L .51433 .46515 L .607 .127 0 r
F
.51501 .46597 m .51433 .46515 L .51788 .46983 L F
.51077 .46049 m .51205 .46218 L p .51241 .46261 L F P
0 g
s
.51205 .46218 m .51788 .46983 L p .51241 .46261 L .607 .127 0 r
F P
0 g
s
.51729 .4684 m .51679 .46791 L p .51611 .46709 L 0 0 .521 r
F P
0 g
s
.66416 .54021 m .65321 .54468 L .67132 .53158 L p .554 .888 .635 r
F P
0 g
s
.67132 .53158 m .68381 .52165 L .66416 .54021 L p .554 .888 .635 r
F P
0 g
s
.5052 .45392 m .49549 .44395 L .48915 .43688 L p 0 .008 .529 r
F P
0 g
s
.49549 .44395 m .5052 .45392 L .51077 .46049 L p 0 .007 .537 r
F P
0 g
s
.37284 .44692 m .38728 .43369 L .39282 .45012 L p .929 .914 .782 r
F P
0 g
s
.39282 .45012 m .37907 .46691 L .37284 .44692 L p .929 .914 .782 r
F P
0 g
s
.21937 .53552 m .20758 .52532 L .18911 .47507 L p .04 .309 .797 r
F P
0 g
s
.72071 .49545 m .70845 .50281 L .71943 .4713 L p .896 .97 .821 r
F P
0 g
s
.71943 .4713 m .73252 .45966 L .72071 .49545 L p .896 .97 .821 r
F P
0 g
s
.2688 .5627 m .28195 .5619 L .30962 .59724 L p .612 .73 .93 r
F P
0 g
s
.32133 .5906 m .30962 .59724 L .28195 .5619 L p .74 .775 .881 r
F P
0 g
s
.30914 .54833 m .32306 .53596 L .34548 .56542 L p .856 .798 .794 r
F P
0 g
s
.34548 .56542 m .3333 .57987 L .30914 .54833 L p .856 .798 .794 r
F P
0 g
s
.45671 .41284 m .47027 .4204 L .47212 .4224 L p 0 .394 .805 r
F P
0 g
s
.48518 .43267 m .47212 .4224 L .47027 .4204 L p 0 .129 .603 r
F P
0 g
s
.47212 .4224 m .48518 .43267 L .48915 .43688 L p 0 .201 .694 r
F P
0 g
s
.5726 .53016 m .58192 .53694 L .57722 .53326 L p .471 0 0 r
F P
0 g
s
.57722 .53326 m .56404 .52294 L p .5726 .53016 L .471 0 0 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .5726 .53016 L p .471 0 0 r
F P
0 g
s
.5726 .53016 m .56321 .5221 L .56736 .52666 L p .569 .014 0 r
F P
0 g
s
.56736 .52666 m .57274 .53257 L p .5726 .53016 L .569 .014 0 r
F P
0 g
s
.28195 .5619 m .29541 .5571 L .32133 .5906 L p .74 .775 .881 r
F P
0 g
s
.3333 .57987 m .32133 .5906 L .29541 .5571 L p .813 .792 .833 r
F P
0 g
s
.50096 .44912 m .48915 .43688 L .48518 .43267 L p 0 0 .499 r
F P
0 g
s
.48915 .43688 m .50096 .44912 L .5052 .45392 L p 0 .008 .529 r
F P
0 g
s
.29541 .5571 m .30914 .54833 L .3333 .57987 L p .813 .792 .833 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53779 .49423 L p .525 .039 0 r
F P
0 g
s
.53779 .49423 m .53468 .48977 L .54482 .50197 L p .525 .039 0 r
F P
0 g
s
.53468 .48977 m .524 .47708 L p .53001 .48433 L .552 .078 0 r
F P
0 g
s
.53153 .48616 m .53447 .48953 L p .53001 .48433 L .552 .078 0 r
F P
0 g
s
.53447 .48953 m .53468 .48977 L p .53001 .48433 L .552 .078 0 r
F P
0 g
s
.52474 .47847 m .52834 .48316 L p .5261 .47977 L .626 .145 0 r
F P
0 g
s
.524 .47708 m .52437 .47715 L .53153 .48616 L p .552 .078 0 r
F P
0 g
s
.52437 .47715 m .52462 .47804 L p .5261 .47977 L .626 .145 0 r
F P
0 g
s
.52462 .47804 m .52474 .47847 L p .5261 .47977 L .626 .145 0 r
F P
0 g
s
.35822 .46136 m .37284 .44692 L .37907 .46691 L p .935 .901 .767 r
F P
0 g
s
.37907 .46691 m .36517 .48502 L .35822 .46136 L p .935 .901 .767 r
F P
0 g
s
.70845 .50281 m .69617 .51178 L .70634 .48494 L p .895 .988 .773 r
F P
0 g
s
.70634 .48494 m .71943 .4713 L .70845 .50281 L p .895 .988 .773 r
F P
0 g
s
.65321 .54468 m .64213 .54857 L .65866 .5407 L p .416 .808 .576 r
F P
0 g
s
.65866 .5407 m .67132 .53158 L .65321 .54468 L p .416 .808 .576 r
F P
0 g
s
.18911 .47507 m .20206 .4862 L .21937 .53552 L p .04 .309 .797 r
F P
0 g
s
.23132 .54531 m .21937 .53552 L .20206 .4862 L p .085 .338 .812 r
F P
0 g
s
.4322 .40708 m .4456 .40883 L .44311 .40931 L p .245 .75 .885 r
F P
0 g
s
.44311 .40931 m .4294 .4099 L .4322 .40708 L p .245 .75 .885 r
F P
0 g
s
.45671 .41284 m .44311 .40931 L .4456 .40883 L p 0 .487 .776 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56321 .5221 L p .54 .011 0 r
F P
0 g
s
.56321 .5221 m .5726 .53016 L .55769 .51601 L p .54 .011 0 r
F P
0 g
s
.41865 .4086 m .4322 .40708 L .4294 .4099 L p .527 .919 .903 r
F P
0 g
s
.4294 .4099 m .41555 .41447 L .41865 .4086 L p .527 .919 .903 r
F P
0 g
s
.47027 .4204 m .45671 .41284 L .45888 .41398 L p 0 .228 .624 r
F P
0 g
s
.4456 .40883 m .45888 .41398 L .45671 .41284 L p 0 .487 .776 r
F P
0 g
s
.47027 .4204 m .48385 .43164 L .48518 .43267 L p 0 .129 .603 r
F P
0 g
s
.49833 .4464 m .48518 .43267 L .48385 .43164 L p .546 .041 0 r
F P
0 g
s
.48518 .43267 m .49833 .4464 L .50096 .44912 L p 0 0 .499 r
F P
0 g
s
.40492 .41307 m .41865 .4086 L .41555 .41447 L p .707 .985 .867 r
F P
0 g
s
.41555 .41447 m .40152 .4226 L .40492 .41307 L p .707 .985 .867 r
F P
0 g
s
.34346 .47597 m .35822 .46136 L .36517 .48502 L p .932 .889 .766 r
F P
0 g
s
.36517 .48502 m .35116 .50331 L .34346 .47597 L p .932 .889 .766 r
F P
0 g
s
.51788 .46983 m .51077 .46049 L .5052 .45392 L p .604 .122 0 r
F P
0 g
s
.52117 .47392 m .51729 .4684 L .51077 .46049 L p .607 .127 0 r
F P
0 g
s
.51507 .46645 m .5052 .45392 L .50096 .44912 L p .607 .123 0 r
F P
0 g
s
.5052 .45392 m .51507 .46645 L .51788 .46983 L p .604 .122 0 r
F P
0 g
s
.53468 .48977 m .53153 .48616 L .5383 .49486 L p .594 .107 0 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53468 .48977 L p .594 .107 0 r
F P
0 g
s
.45888 .41398 m .4721 .42243 L .47027 .4204 L p 0 .228 .624 r
F P
0 g
s
.48385 .43164 m .47027 .4204 L .4721 .42243 L p .497 0 0 r
F P
0 g
s
.51729 .4684 m .52117 .47392 L .52474 .47847 L p .615 .135 0 r
F P
0 g
s
.52474 .47847 m .52437 .47715 L .51729 .4684 L p .615 .135 0 r
F P
0 g
s
.59634 .54741 m .608 .55104 L .59116 .54238 L p .421 0 0 r
F P
0 g
s
.69617 .51178 m .68381 .52165 L .69319 .4997 L p .87 .99 .73 r
F P
0 g
s
.69319 .4997 m .70634 .48494 L .69617 .51178 L p .87 .99 .73 r
F P
0 g
s
.20206 .4862 m .21515 .49697 L .23132 .54531 L p .085 .338 .812 r
F P
0 g
s
.2435 .55371 m .23132 .54531 L .21515 .49697 L p .187 .411 .847 r
F P
0 g
s
.64582 .54814 m .65866 .5407 L .64213 .54857 L p 0 0 0 r
F P
0 g
s
.51294 .46402 m .50096 .44912 L .49833 .4464 L p .615 .128 0 r
F P
0 g
s
.50096 .44912 m .51294 .46402 L .51507 .46645 L p .607 .123 0 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55375 .51286 L p .588 .077 0 r
F P
0 g
s
.55375 .51286 m .56321 .5221 L .55128 .50901 L p .588 .077 0 r
F P
0 g
s
.39099 .41997 m .40492 .41307 L .40152 .4226 L p .809 1 .827 r
F P
0 g
s
.40152 .4226 m .38728 .43369 L .39099 .41997 L p .809 1 .827 r
F P
0 g
s
.52834 .48316 m .53153 .48616 L .52437 .47715 L p .626 .145 0 r
F P
0 g
s
.78632 .44375 m .77254 .44265 L .77083 .39817 L p .639 .702 .892 r
F P
0 g
s
.77254 .44265 m .75901 .44497 L .75714 .40305 L p .74 .778 .884 r
F P
0 g
s
.75714 .40305 m .77083 .39817 L .77254 .44265 L p .74 .778 .884 r
F P
0 g
s
.80039 .44805 m .78632 .44375 L .78485 .39713 L p .536 .621 .884 r
F P
0 g
s
.77083 .39817 m .78485 .39713 L .78632 .44375 L p .639 .702 .892 r
F P
0 g
s
.32861 .48973 m .34346 .47597 L .35116 .50331 L p .922 .878 .775 r
F P
0 g
s
.35116 .50331 m .33709 .52065 L .32861 .48973 L p .922 .878 .775 r
F P
0 g
s
.4721 .42243 m .48529 .43389 L .48385 .43164 L p .497 0 0 r
F P
0 g
s
.49749 .44596 m .48385 .43164 L .48529 .43389 L p .587 .077 0 r
F P
0 g
s
.48385 .43164 m .49749 .44596 L .49833 .4464 L p .546 .041 0 r
F P
0 g
s
.75901 .44497 m .74569 .45073 L .74371 .41177 L p .823 .84 .86 r
F P
0 g
s
.74371 .41177 m .75714 .40305 L .75901 .44497 L p .823 .84 .86 r
F P
0 g
s
.81473 .45509 m .80039 .44805 L .79922 .39968 L p .444 .548 .867 r
F P
0 g
s
.78485 .39713 m .79922 .39968 L .80039 .44805 L p .536 .621 .884 r
F P
0 g
s
.58458 .54122 m .59634 .54741 L .58192 .53694 L p .51 0 0 r
F P
0 g
s
.51163 .46269 m .49833 .4464 L .49749 .44596 L p .626 .136 0 r
F P
0 g
s
.49833 .4464 m .51163 .46269 L .51294 .46402 L p .615 .128 0 r
F P
0 g
s
.21515 .49697 m .22844 .50645 L .2435 .55371 L p .187 .411 .847 r
F P
0 g
s
.25599 .55978 m .2435 .55371 L .22844 .50645 L p .329 .512 .885 r
F P
0 g
s
.37687 .42864 m .39099 .41997 L .38728 .43369 L p .866 .995 .802 r
F P
0 g
s
.38728 .43369 m .37284 .44692 L .37687 .42864 L p .866 .995 .802 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54425 .50265 L p .621 .124 0 r
F P
0 g
s
.54425 .50265 m .55375 .51286 L .54482 .50197 L p .621 .124 0 r
F P
0 g
s
.74569 .45073 m .73252 .45966 L .73048 .42406 L p .884 .882 .826 r
F P
0 g
s
.73048 .42406 m .74371 .41177 L .74569 .45073 L p .884 .882 .826 r
F P
0 g
s
.53153 .48616 m .52834 .48316 L .53174 .48769 L p .637 .153 0 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53153 .48616 L p .637 .153 0 r
F P
0 g
s
.6309 .55126 m .61952 .55223 L .63279 .55314 L p 0 0 0 r
F P
0 g
s
.63279 .55314 m .64582 .54814 L .6309 .55126 L p 0 0 0 r
F P
0 g
s
.82932 .46427 m .81473 .45509 L .81395 .40534 L p .372 .491 .85 r
F P
0 g
s
.79922 .39968 m .81395 .40534 L .81473 .45509 L p .444 .548 .867 r
F P
0 g
s
.68381 .52165 m .67132 .53158 L .67992 .51456 L p .828 .983 .701 r
F P
0 g
s
.67992 .51456 m .69319 .4997 L .68381 .52165 L p .828 .983 .701 r
F P
0 g
s
.31376 .50166 m .32861 .48973 L .33709 .52065 L p .902 .865 .793 r
F P
0 g
s
.33709 .52065 m .32306 .53596 L .31376 .50166 L p .902 .865 .793 r
F P
0 g
s
.57274 .53257 m .58458 .54122 L .5726 .53016 L p .569 .014 0 r
F P
0 g
s
.48529 .43389 m .49851 .44786 L .49749 .44596 L p .587 .077 0 r
F P
0 g
s
.51123 .46256 m .49749 .44596 L .49851 .44786 L p .636 .145 0 r
F P
0 g
s
.49749 .44596 m .51123 .46256 L .51163 .46269 L p .626 .136 0 r
F P
0 g
s
.45357 .41323 m .46561 .41967 L .45888 .41398 L p .355 0 0 r
F P
0 g
s
.45888 .41398 m .4456 .40883 L .45357 .41323 L p .355 0 0 r
F P
0 g
s
.4721 .42243 m .45888 .41398 L .46561 .41967 L p .487 0 0 r
F P
0 g
s
.44143 .40921 m .45357 .41323 L .4456 .40883 L p .161 0 0 r
F P
0 g
s
.4456 .40883 m .4322 .40708 L .44143 .40921 L p .161 0 0 r
F P
0 g
s
.46561 .41967 m .47756 .42845 L .4721 .42243 L p .487 0 0 r
F P
0 g
s
.48529 .43389 m .4721 .42243 L .47756 .42845 L p .568 .03 0 r
F P
0 g
s
.52511 .48046 m .51788 .46983 L .51507 .46645 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .52117 .47392 L .51788 .46983 L closepath p .661 .178 0 r
F P
0 g
s
.73252 .45966 m .71943 .4713 L .71738 .43937 L p .922 .908 .791 r
F P
0 g
s
.71738 .43937 m .73048 .42406 L .73252 .45966 L p .922 .908 .791 r
F P
0 g
s
.84412 .4748 m .82932 .46427 L .829 .41339 L p .326 .455 .838 r
F P
0 g
s
.81395 .40534 m .829 .41339 L .82932 .46427 L p .372 .491 .85 r
F P
0 g
s
.52511 .48046 m .51507 .46645 L .51294 .46402 L closepath p .661 .178 0 r
F P
0 g
s
.22844 .50645 m .24199 .51381 L .25599 .55978 L p .329 .512 .885 r
F P
0 g
s
.2688 .5627 m .25599 .55978 L .24199 .51381 L p .486 .619 .908 r
F P
0 g
s
.52511 .48046 m .52474 .47847 L .52117 .47392 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .51294 .46402 L .51163 .46269 L closepath p .661 .178 0 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .5347 .49175 L p .645 .157 0 r
F P
0 g
s
.5347 .49175 m .54425 .50265 L .5383 .49486 L p .645 .157 0 r
F P
0 g
s
.4322 .40708 m .41865 .4086 L .42915 .40752 L p 0 0 0 r
F P
0 g
s
.41671 .40792 m .42915 .40752 L .41865 .4086 L p .3 .788 .736 r
F P
0 g
s
.42915 .40752 m .41671 .40792 L .42692 .40781 L p .002 0 0 r
F P
0 g
s
.42915 .40752 m .44143 .40921 L .43233 .40711 L p 0 0 0 r
F P
0 g
s
.45357 .41323 m .44143 .40921 L .45208 .41418 L p .353 0 0 r
F P
0 g
s
.45208 .41418 m .45671 .41634 L p .4558 .41544 L .353 0 0 r
F P
0 g
s
.45357 .41323 m .45208 .41418 L .4558 .41544 L .353 0 0 r
F
.44662 .41149 m .45671 .41634 L .45343 .41481 L p .195 0 0 r
F P
0 g
s
.45343 .41481 m .44143 .40921 L p .44662 .41149 L .195 0 0 r
F P
0 g
s
.43995 .40901 m .44662 .41149 L p .44143 .40921 L .195 0 0 r
F P
0 g
s
.44662 .41149 m .43643 .4077 L .44036 .40843 L p .006 .54 .846 r
F P
0 g
s
.44036 .40843 m .46294 .41262 L p .44662 .41149 L .006 .54 .846 r
F P
0 g
s
.43769 .4087 m .42915 .40752 L p .43904 .40976 L .195 0 0 r
F P
0 g
s
.43643 .4077 m .44662 .41149 L .43904 .40976 L p .002 0 0 r
F P
0 g
s
.43904 .40976 m .42915 .40752 L p .43266 .40761 L .002 0 0 r
F P
0 g
s
.43266 .40761 m .43643 .4077 L .43904 .40976 L .002 0 0 r
F
.42692 .40781 m .43643 .4077 L p .42915 .40752 L F P
0 g
s
.43233 .40711 m .4322 .40708 L p .42915 .40752 L 0 0 0 r
F P
0 g
s
.47756 .42845 m .48947 .43934 L .48529 .43389 L p .568 .03 0 r
F P
0 g
s
.49851 .44786 m .48529 .43389 L .48947 .43934 L p .616 .106 0 r
F P
0 g
s
.36256 .43828 m .37687 .42864 L .37284 .44692 L p .897 .984 .792 r
F P
0 g
s
.37284 .44692 m .35822 .46136 L .36256 .43828 L p .897 .984 .792 r
F P
0 g
s
.56321 .5221 m .55375 .51286 L .56085 .52169 L p .606 .079 0 r
F P
0 g
s
.56085 .52169 m .57274 .53257 L .56321 .5221 L p .606 .079 0 r
F P
0 g
s
.61952 .55223 m .608 .55104 L .61958 .55507 L p .092 0 0 r
F P
0 g
s
.61958 .55507 m .63279 .55314 L .61952 .55223 L p .092 0 0 r
F P
0 g
s
.29899 .51095 m .31376 .50166 L .32306 .53596 L p .869 .847 .82 r
F P
0 g
s
.32306 .53596 m .30914 .54833 L .29899 .51095 L p .869 .847 .82 r
F P
0 g
s
.52511 .48046 m .52834 .48316 L .52474 .47847 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .51163 .46269 L .51123 .46256 L closepath p .661 .178 0 r
F P
0 g
s
.67132 .53158 m .65866 .5407 L .66647 .52844 L p .769 .973 .693 r
F P
0 g
s
.66647 .52844 m .67992 .51456 L .67132 .53158 L p .769 .973 .693 r
F P
0 g
s
.24199 .51381 m .25583 .51832 L .2688 .5627 L p .486 .619 .908 r
F P
0 g
s
.28195 .5619 m .2688 .5627 L .25583 .51832 L p .629 .711 .906 r
F P
0 g
s
.85906 .48583 m .84412 .4748 L .84433 .42299 L p .306 .443 .835 r
F P
0 g
s
.829 .41339 m .84433 .42299 L .84412 .4748 L p .326 .455 .838 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48316 L closepath p .661 .178 0 r
F P
0 g
s
.28437 .517 m .29899 .51095 L .30914 .54833 L p .818 .82 .851 r
F P
0 g
s
.30914 .54833 m .29541 .5571 L .28437 .517 L p .818 .82 .851 r
F P
0 g
s
.48947 .43934 m .50135 .45199 L .49851 .44786 L p .616 .106 0 r
F P
0 g
s
.51177 .46366 m .49851 .44786 L .50135 .45199 L p .644 .153 0 r
F P
0 g
s
.49851 .44786 m .51177 .46366 L .51123 .46256 L p .636 .145 0 r
F P
0 g
s
.55375 .51286 m .54425 .50265 L .54894 .509 L p .631 .125 0 r
F P
0 g
s
.54894 .509 m .56085 .52169 L .55375 .51286 L p .631 .125 0 r
F P
0 g
s
.41865 .4086 m .40492 .41307 L .41671 .40792 L p .3 .788 .736 r
F P
0 g
s
.71943 .4713 m .70634 .48494 L .70431 .45693 L p .942 .923 .761 r
F P
0 g
s
.70431 .45693 m .71738 .43937 L .71943 .4713 L p .942 .923 .761 r
F P
0 g
s
.52511 .48046 m .51123 .46256 L .51177 .46366 L closepath p .661 .178 0 r
F P
0 g
s
.25583 .51832 m .26996 .51946 L .28195 .5619 L p .629 .711 .906 r
F P
0 g
s
.29541 .5571 m .28195 .5619 L .26996 .51946 L p .74 .777 .883 r
F P
0 g
s
.26996 .51946 m .28437 .517 L .29541 .5571 L p .74 .777 .883 r
F P
0 g
s
.608 .55104 m .59634 .54741 L .60621 .55352 L p .272 0 0 r
F P
0 g
s
.60621 .55352 m .61958 .55507 L .608 .55104 L p .272 0 0 r
F P
0 g
s
.52511 .48046 m .5347 .49175 L .53174 .48769 L closepath p .661 .178 0 r
F P
0 g
s
.54425 .50265 m .5347 .49175 L .53702 .49505 L p .648 .158 0 r
F P
0 g
s
.53702 .49505 m .54894 .509 L .54425 .50265 L p .648 .158 0 r
F P
0 g
s
.3481 .44806 m .36256 .43828 L .35822 .46136 L p .911 .97 .797 r
F P
0 g
s
.35822 .46136 m .34346 .47597 L .3481 .44806 L p .911 .97 .797 r
F P
0 g
s
.50135 .45199 m .51322 .4659 L .51177 .46366 L p .644 .153 0 r
F P
0 g
s
.52511 .48046 m .51177 .46366 L .51322 .4659 L closepath p .661 .178 0 r
F P
0 g
s
.84433 .42299 m .85986 .43317 L .85906 .48583 L p .306 .443 .835 r
F P
0 g
s
.59634 .54741 m .58458 .54122 L .59273 .54834 L p .419 0 0 r
F P
0 g
s
.59273 .54834 m .60621 .55352 L .59634 .54741 L p .419 0 0 r
F P
0 g
s
.65866 .5407 m .64582 .54814 L .65281 .54025 L p .686 .956 .708 r
F P
0 g
s
.65281 .54025 m .66647 .52844 L .65866 .5407 L p .686 .956 .708 r
F P
0 g
s
.40411 .41004 m .41671 .40792 L .40492 .41307 L p .489 .892 .76 r
F P
0 g
s
.40492 .41307 m .39099 .41997 L .40411 .41004 L p .489 .892 .76 r
F P
0 g
s
.52511 .48046 m .53702 .49505 L .5347 .49175 L closepath p .661 .178 0 r
F P
0 g
s
.48639 .43814 m .49614 .44769 L .48947 .43934 L p .597 .069 0 r
F P
0 g
s
.48947 .43934 m .47756 .42845 L .48639 .43814 L p .597 .069 0 r
F P
0 g
s
.50135 .45199 m .48947 .43934 L .49614 .44769 L p .627 .122 0 r
F P
0 g
s
.70634 .48494 m .69319 .4997 L .6912 .47574 L p .95 .935 .743 r
F P
0 g
s
.6912 .47574 m .70431 .45693 L .70634 .48494 L p .95 .935 .743 r
F P
0 g
s
.49614 .44769 m .50584 .45811 L .50135 .45199 L p .627 .122 0 r
F P
0 g
s
.51322 .4659 m .50135 .45199 L .50584 .45811 L p .647 .157 0 r
F P
0 g
s
.47658 .42967 m .46669 .42238 L .47121 .42586 L p .448 0 0 r
F P
0 g
s
.47658 .42967 m .48639 .43814 L .48251 .43388 L p .547 0 0 r
F P
0 g
s
.48639 .43814 m .47658 .42967 L .49116 .44341 L p .528 0 0 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47658 .42967 L p .448 0 0 r
F P
0 g
s
.47121 .42586 m .48419 .43581 L p .47658 .42967 L .448 0 0 r
F P
0 g
s
.48251 .43388 m .47756 .42845 L p .47658 .42967 L .547 0 0 r
F P
0 g
s
.47756 .42845 m .46561 .41967 L .47658 .42967 L p .547 0 0 r
F P
0 g
s
.50584 .45811 m .5155 .46914 L .51322 .4659 L p .647 .157 0 r
F P
0 g
s
.52511 .48046 m .51322 .4659 L .5155 .46914 L closepath p .661 .178 0 r
F P
0 g
s
.58458 .54122 m .57274 .53257 L .57917 .53964 L p .521 0 0 r
F P
0 g
s
.57917 .53964 m .59273 .54834 L .58458 .54122 L p .521 0 0 r
F P
0 g
s
.52511 .48046 m .53535 .49474 L .5375 .4972 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .53249 .49131 L .53535 .49474 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .52913 .48712 L .53249 .49131 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .5255 .48249 L .52913 .48712 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .52185 .47773 L .5255 .48249 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47773 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .5155 .46914 L .51844 .47318 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .53854 .49738 L .53702 .49505 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .53915 .49856 L .53854 .49738 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .53879 .4985 L .53915 .49856 L closepath p .661 .178 0 r
F P
0 g
s
.52511 .48046 m .5375 .4972 L .53879 .4985 L closepath p .661 .178 0 r
F P
0 g
s
.45671 .41634 m .46669 .42238 L .46312 .41989 L p .353 0 0 r
F P
0 g
s
.46312 .41989 m .45357 .41323 L p .45671 .41634 L .353 0 0 r
F P
0 g
s
.45671 .41634 m .44662 .41149 L .45086 .4131 L p 0 .374 .74 r
F P
0 g
s
.46561 .41967 m .45357 .41323 L .46669 .42238 L p .47 0 0 r
F P
0 g
s
.45086 .4131 m .47008 .42042 L p .45671 .41634 L 0 .374 .74 r
F P
0 g
s
.46669 .42238 m .45671 .41634 L .46113 .41889 L p 0 .222 .633 r
F P
0 g
s
.47281 .42623 m .46561 .41967 L p .46669 .42238 L .47 0 0 r
F P
0 g
s
.46113 .41889 m .47717 .42815 L p .46669 .42238 L 0 .222 .633 r
F P
0 g
s
.46669 .42238 m .47658 .42967 L .47281 .42623 L p .47 0 0 r
F P
0 g
s
.54894 .509 m .53702 .49505 L .53854 .49738 L p .645 .154 0 r
F P
0 g
s
.57274 .53257 m .56085 .52169 L .5656 .52781 L p .583 .044 0 r
F P
0 g
s
.5656 .52781 m .57917 .53964 L .57274 .53257 L p .583 .044 0 r
F P
0 g
s
.56085 .52169 m .54894 .509 L .55204 .51346 L p .621 .111 0 r
F P
0 g
s
.53854 .49738 m .55204 .51346 L .54894 .509 L p .645 .154 0 r
F P
0 g
s
.33354 .45711 m .3481 .44806 L .34346 .47597 L p .91 .952 .812 r
F P
0 g
s
.34346 .47597 m .32861 .48973 L .33354 .45711 L p .91 .952 .812 r
F P
0 g
s
.55204 .51346 m .5656 .52781 L .56085 .52169 L p .621 .111 0 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .5155 .46914 L p .644 .157 0 r
F P
0 g
s
.5155 .46914 m .50584 .45811 L .5117 .46583 L p .644 .157 0 r
F P
0 g
s
.64582 .54814 m .63279 .55314 L .63895 .54904 L p .56 .92 .742 r
F P
0 g
s
.63895 .54904 m .65281 .54025 L .64582 .54814 L p .56 .92 .742 r
F P
0 g
s
.39134 .4134 m .40411 .41004 L .39099 .41997 L p .631 .955 .781 r
F P
0 g
s
.39099 .41997 m .37687 .42864 L .39134 .4134 L p .631 .955 .781 r
F P
0 g
s
.20206 .4862 m .18911 .47507 L .19318 .42214 L p .307 .431 .824 r
F P
0 g
s
.55204 .51346 m .53854 .49738 L .53915 .49856 L p .638 .146 0 r
F P
0 g
s
.69319 .4997 m .67992 .51456 L .67799 .49465 L p .948 .945 .74 r
F P
0 g
s
.67799 .49465 m .6912 .47574 L .69319 .4997 L p .948 .945 .74 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50584 .45811 L p .619 .123 0 r
F P
0 g
s
.50584 .45811 m .49614 .44769 L .50491 .45842 L p .619 .123 0 r
F P
0 g
s
.51854 .47462 m .52185 .47773 L .51844 .47318 L p .637 .153 0 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51854 .47462 L p .637 .153 0 r
F P
0 g
s
.77083 .39817 m .75714 .40305 L .73899 .36488 L p .74 .776 .882 r
F P
0 g
s
.75714 .40305 m .74371 .41177 L .72639 .37616 L p .82 .809 .841 r
F P
0 g
s
.72639 .37616 m .73899 .36488 L .75714 .40305 L p .82 .809 .841 r
F P
0 g
s
.78485 .39713 m .77083 .39817 L .75187 .35758 L p .627 .72 .913 r
F P
0 g
s
.73899 .36488 m .75187 .35758 L .77083 .39817 L p .74 .776 .882 r
F P
0 g
s
.53915 .49856 m .55332 .51569 L .55204 .51346 L p .638 .146 0 r
F P
0 g
s
.55332 .51569 m .53915 .49856 L .53879 .4985 L p .627 .137 0 r
F P
0 g
s
.31893 .46466 m .33354 .45711 L .32861 .48973 L p .895 .926 .833 r
F P
0 g
s
.32861 .48973 m .31376 .50166 L .31893 .46466 L p .895 .926 .833 r
F P
0 g
s
.63279 .55314 m .61958 .55507 L .62489 .55402 L p .365 .831 .776 r
F P
0 g
s
.62489 .55402 m .63895 .54904 L .63279 .55314 L p .365 .831 .776 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49614 .44769 L p .582 .072 0 r
F P
0 g
s
.49614 .44769 m .48639 .43814 L .49806 .45095 L p .582 .072 0 r
F P
0 g
s
.5656 .52781 m .55204 .51346 L .55332 .51569 L p .594 .083 0 r
F P
0 g
s
.74371 .41177 m .73048 .42406 L .71402 .39113 L p .871 .826 .8 r
F P
0 g
s
.71402 .39113 m .72639 .37616 L .74371 .41177 L p .871 .826 .8 r
F P
0 g
s
.52588 .48389 m .52562 .48293 L p .5241 .48117 L .627 .145 0 r
F P
0 g
s
.52185 .47773 m .51854 .47462 L .52588 .48389 L p .627 .145 0 r
F P
0 g
s
.5255 .48249 m .52588 .48389 L .53322 .49296 L p .616 .136 0 r
F P
0 g
s
.52628 .48401 m .52588 .48389 L .51854 .47462 L p .554 .08 0 r
F P
0 g
s
.51519 .47081 m .52628 .48401 L p .52008 .47649 L .554 .08 0 r
F P
0 g
s
.51854 .47462 m .51542 .47107 L p .52008 .47649 L .554 .08 0 r
F P
0 g
s
.51542 .47107 m .51519 .47081 L p .52008 .47649 L .554 .08 0 r
F P
0 g
s
.5255 .48249 m .52185 .47773 L p .5241 .48117 L .627 .145 0 r
F P
0 g
s
.52562 .48293 m .5255 .48249 L p .5241 .48117 L .627 .145 0 r
F P
0 g
s
.19318 .42214 m .20655 .43366 L .20206 .4862 L p .307 .431 .824 r
F P
0 g
s
.21515 .49697 m .20206 .4862 L .20655 .43366 L p .337 .448 .827 r
F P
0 g
s
.79922 .39968 m .78485 .39713 L .76511 .35428 L p .489 .64 .922 r
F P
0 g
s
.75187 .35758 m .76511 .35428 L .78485 .39713 L p .627 .72 .913 r
F P
0 g
s
.37842 .41743 m .39134 .4134 L .37687 .42864 L p .733 .989 .805 r
F P
0 g
s
.37687 .42864 m .36256 .43828 L .37842 .41743 L p .733 .989 .805 r
F P
0 g
s
.53879 .4985 m .55266 .5155 L .55332 .51569 L p .627 .137 0 r
F P
0 g
s
.55266 .5155 m .53879 .4985 L .5375 .4972 L p .616 .129 0 r
F P
0 g
s
.52913 .48712 m .5255 .48249 L p .53121 .49024 L .616 .136 0 r
F P
0 g
s
.53188 .49105 m .52913 .48712 L p .53121 .49024 L .616 .136 0 r
F P
0 g
s
.53249 .49131 m .52913 .48712 L p .53552 .49539 L .608 .128 0 r
F P
0 g
s
.53552 .49539 m .53827 .49895 L .53644 .49651 L .608 .128 0 r
F
.53863 .49938 m .53644 .49651 L p .53827 .49895 L F P
0 g
s
.53644 .49651 m .53249 .49131 L p .53552 .49539 L .608 .128 0 r
F P
0 g
s
.5375 .4972 m .55009 .51288 L .55266 .5155 L p .616 .129 0 r
F P
0 g
s
.55009 .51288 m .5375 .4972 L .53535 .49474 L p .608 .124 0 r
F P
0 g
s
.52913 .48712 m .53322 .49296 L .54001 .5012 L p .608 .128 0 r
F P
0 g
s
.53535 .49474 m .54577 .508 L .55009 .51288 L p .608 .124 0 r
F P
0 g
s
.54577 .508 m .53535 .49474 L .53249 .49131 L p .605 .124 0 r
F P
0 g
s
.53249 .49131 m .54001 .5012 L .54577 .508 L p .605 .124 0 r
F P
0 g
s
.53737 .49706 m .54765 .50901 L p .53446 .49434 L 0 0 .516 r
F P
0 g
s
.53322 .49296 m .53376 .4935 L p .53446 .49434 L 0 0 .516 r
F P
0 g
s
.53376 .4935 m .53737 .49706 L p .53446 .49434 L 0 0 .516 r
F P
0 g
s
.54001 .5012 m .53863 .49938 L p .53827 .49895 L .608 .128 0 r
F P
0 g
s
.52628 .48401 m .53737 .49706 L p .52807 .48639 L 0 0 .484 r
F P
0 g
s
.52738 .48561 m .52721 .48536 L .52807 .48639 L 0 0 .484 r
F
.52721 .48536 m .52628 .48401 L .52807 .48639 L F
.52588 .48389 m .52599 .48392 L p .52738 .48561 L F P
0 g
s
.52599 .48392 m .52628 .48401 L p .52738 .48561 L 0 0 .484 r
F P
0 g
s
.53322 .49296 m .53188 .49105 L p .53121 .49024 L .616 .136 0 r
F P
0 g
s
.73048 .42406 m .71738 .43937 L .70179 .40924 L p .903 .833 .767 r
F P
0 g
s
.70179 .40924 m .71402 .39113 L .73048 .42406 L p .903 .833 .767 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48639 .43814 L p .528 0 0 r
F P
0 g
s
.67992 .51456 m .66647 .52844 L .66461 .51246 L p .937 .958 .755 r
F P
0 g
s
.66461 .51246 m .67799 .49465 L .67992 .51456 L p .937 .958 .755 r
F P
0 g
s
.57917 .53964 m .5656 .52781 L .56761 .53074 L p .518 0 0 r
F P
0 g
s
.55332 .51569 m .56761 .53074 L .5656 .52781 L p .594 .083 0 r
F P
0 g
s
.61958 .55507 m .60621 .55352 L .61067 .5547 L p .096 .653 .765 r
F P
0 g
s
.61067 .5547 m .62489 .55402 L .61958 .55507 L p .096 .653 .765 r
F P
0 g
s
.51519 .47081 m .51854 .47462 L .5117 .46583 L p .594 .107 0 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51519 .47081 L p .594 .107 0 r
F P
0 g
s
.81395 .40534 m .79922 .39968 L .77871 .35472 L p .349 .55 .908 r
F P
0 g
s
.76511 .35428 m .77871 .35472 L .79922 .39968 L p .489 .64 .922 r
F P
0 g
s
.20655 .43366 m .22 .44486 L .21515 .49697 L p .337 .448 .827 r
F P
0 g
s
.22844 .50645 m .21515 .49697 L .22 .44486 L p .394 .49 .839 r
F P
0 g
s
.30435 .47004 m .31893 .46466 L .31376 .50166 L p .862 .89 .855 r
F P
0 g
s
.31376 .50166 m .29899 .51095 L .30435 .47004 L p .862 .89 .855 r
F P
0 g
s
.59273 .54834 m .57917 .53964 L .58197 .54273 L p .389 0 0 r
F P
0 g
s
.56761 .53074 m .58197 .54273 L .57917 .53964 L p .518 0 0 r
F P
0 g
s
.60621 .55352 m .59273 .54834 L .59634 .55088 L p 0 .41 .684 r
F P
0 g
s
.59634 .55088 m .61067 .5547 L .60621 .55352 L p 0 .41 .684 r
F P
0 g
s
.58197 .54273 m .59634 .55088 L .59273 .54834 L p .389 0 0 r
F P
0 g
s
.56761 .53074 m .55332 .51569 L .55266 .5155 L p .554 .048 0 r
F P
0 g
s
.71738 .43937 m .70431 .45693 L .68962 .42966 L p .921 .837 .745 r
F P
0 g
s
.68962 .42966 m .70179 .40924 L .71738 .43937 L p .921 .837 .745 r
F P
0 g
s
.36535 .42153 m .37842 .41743 L .36256 .43828 L p .801 .999 .833 r
F P
0 g
s
.36256 .43828 m .3481 .44806 L .36535 .42153 L p .801 .999 .833 r
F P
0 g
s
.22 .44486 m .23359 .45497 L .22844 .50645 L p .394 .49 .839 r
F P
0 g
s
.24199 .51381 m .22844 .50645 L .23359 .45497 L p .47 .552 .857 r
F P
0 g
s
.42612 .40478 m .43643 .4077 L .41671 .40792 L p .203 .73 .76 r
F P
0 g
s
.41671 .40792 m .40411 .41004 L .42612 .40478 L p .203 .73 .76 r
F P
0 g
s
.28985 .47274 m .30435 .47004 L .29899 .51095 L p .81 .841 .874 r
F P
0 g
s
.29899 .51095 m .28437 .517 L .28985 .47274 L p .81 .841 .874 r
F P
0 g
s
.51181 .46602 m .51519 .47081 L .50491 .45842 L p .525 .039 0 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51181 .46602 L p .525 .039 0 r
F P
0 g
s
.66647 .52844 m .65281 .54025 L .65103 .52793 L p .912 .972 .791 r
F P
0 g
s
.65103 .52793 m .66461 .51246 L .66647 .52844 L p .912 .972 .791 r
F P
0 g
s
.829 .41339 m .81395 .40534 L .7927 .35838 L p .233 .471 .881 r
F P
0 g
s
.77871 .35472 m .7927 .35838 L .81395 .40534 L p .349 .55 .908 r
F P
0 g
s
.55266 .5155 m .56669 .53021 L .56761 .53074 L p .554 .048 0 r
F P
0 g
s
.56669 .53021 m .55266 .5155 L .55009 .51288 L p 0 0 .49 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46669 .42238 L p 0 .222 .633 r
F P
0 g
s
.23359 .45497 m .24735 .46331 L .24199 .51381 L p .47 .552 .857 r
F P
0 g
s
.25583 .51832 m .24199 .51381 L .24735 .46331 L p .56 .626 .874 r
F P
0 g
s
.2755 .47251 m .28985 .47274 L .28437 .517 L p .739 .778 .885 r
F P
0 g
s
.28437 .517 m .26996 .51946 L .2755 .47251 L p .739 .778 .885 r
F P
0 g
s
.58197 .54273 m .56761 .53074 L .56669 .53021 L p 0 .108 .578 r
F P
0 g
s
.70431 .45693 m .6912 .47574 L .67745 .45137 L p .93 .84 .734 r
F P
0 g
s
.67745 .45137 m .68962 .42966 L .70431 .45693 L p .93 .84 .734 r
F P
0 g
s
.24735 .46331 m .26132 .46929 L .25583 .51832 L p .56 .626 .874 r
F P
0 g
s
.26996 .51946 m .25583 .51832 L .26132 .46929 L p .653 .704 .885 r
F P
0 g
s
.26132 .46929 m .2755 .47251 L .26996 .51946 L p .653 .704 .885 r
F P
0 g
s
.53737 .49706 m .53322 .49296 L .52588 .48389 L p 0 0 .484 r
F P
0 g
s
.65281 .54025 m .63895 .54904 L .63726 .54 L p .86 .983 .851 r
F P
0 g
s
.63726 .54 m .65103 .52793 L .65281 .54025 L p .86 .983 .851 r
F P
0 g
s
.5084 .46002 m .51181 .46602 L .49806 .45095 L p 0 .055 .57 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .5084 .46002 L p 0 .055 .57 r
F P
0 g
s
.55009 .51288 m .56286 .52621 L .56669 .53021 L p 0 0 .49 r
F P
0 g
s
.56286 .52621 m .55009 .51288 L .54577 .508 L p 0 .001 .521 r
F P
0 g
s
.41569 .40246 m .42612 .40478 L .40411 .41004 L p .396 .853 .824 r
F P
0 g
s
.40411 .41004 m .39134 .4134 L .41569 .40246 L p .396 .853 .824 r
F P
0 g
s
.84433 .42299 m .829 .41339 L .80705 .36455 L p .159 .419 .859 r
F P
0 g
s
.7927 .35838 m .80705 .36455 L .829 .41339 L p .233 .471 .881 r
F P
0 g
s
.35218 .42509 m .36535 .42153 L .3481 .44806 L p .838 .989 .861 r
F P
0 g
s
.3481 .44806 m .33354 .45711 L .35218 .42509 L p .838 .989 .861 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45671 .41634 L p 0 .374 .74 r
F P
0 g
s
.54765 .50901 m .54001 .5012 L .53322 .49296 L p 0 0 .516 r
F P
0 g
s
.59634 .55088 m .58197 .54273 L .58083 .54152 L p 0 .353 .762 r
F P
0 g
s
.56669 .53021 m .58083 .54152 L .58197 .54273 L p 0 .108 .578 r
F P
0 g
s
.52668 .48231 m .52628 .48401 L .51519 .47081 L p 0 .021 .556 r
F P
0 g
s
.51519 .47081 m .51181 .46602 L .52668 .48231 L p 0 .021 .556 r
F P
0 g
s
.54577 .508 m .55636 .51897 L .56286 .52621 L p 0 .001 .521 r
F P
0 g
s
.55636 .51897 m .54577 .508 L .54001 .5012 L p 0 .001 .53 r
F P
0 g
s
.54001 .5012 m .54765 .50901 L .55636 .51897 L p 0 .001 .53 r
F P
0 g
s
.6912 .47574 m .67799 .49465 L .66519 .47317 L p .932 .844 .734 r
F P
0 g
s
.66519 .47317 m .67745 .45137 L .6912 .47574 L p .932 .844 .734 r
F P
0 g
s
.63895 .54904 m .62489 .55402 L .6233 .54777 L p .75 .971 .928 r
F P
0 g
s
.6233 .54777 m .63726 .54 L .63895 .54904 L p .75 .971 .928 r
F P
0 g
s
.58083 .54152 m .56669 .53021 L .56286 .52621 L p 0 .181 .673 r
F P
0 g
s
.61067 .5547 m .59634 .55088 L .59503 .54853 L p .182 .655 .933 r
F P
0 g
s
.58083 .54152 m .59503 .54853 L .59634 .55088 L p 0 .353 .762 r
F P
0 g
s
.62489 .55402 m .61067 .5547 L .60921 .55068 L p .53 .881 .984 r
F P
0 g
s
.60921 .55068 m .6233 .54777 L .62489 .55402 L p .53 .881 .984 r
F P
0 g
s
.50495 .45267 m .5084 .46002 L .49116 .44341 L p 0 .175 .681 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50495 .45267 L p 0 .175 .681 r
F P
0 g
s
.59503 .54853 m .60921 .55068 L .61067 .5547 L p .182 .655 .933 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44662 .41149 L p .006 .54 .846 r
F P
0 g
s
.85986 .43317 m .84433 .42299 L .82171 .37234 L p .132 .4 .85 r
F P
0 g
s
.80705 .36455 m .82171 .37234 L .84433 .42299 L p .159 .419 .859 r
F P
0 g
s
.40514 .40046 m .41569 .40246 L .39134 .4134 L p .557 .934 .876 r
F P
0 g
s
.39134 .4134 m .37842 .41743 L .40514 .40046 L p .557 .934 .876 r
F P
0 g
s
.33893 .42755 m .35218 .42509 L .33354 .45711 L p .846 .959 .882 r
F P
0 g
s
.33354 .45711 m .31893 .46466 L .33893 .42755 L p .846 .959 .882 r
F P
0 g
s
.67799 .49465 m .66461 .51246 L .65281 .49378 L p .926 .849 .748 r
F P
0 g
s
.65281 .49378 m .66519 .47317 L .67799 .49465 L p .926 .849 .748 r
F P
0 g
s
.54158 .49862 m .53737 .49706 L .52628 .48401 L p 0 .093 .633 r
F P
0 g
s
.52628 .48401 m .52668 .48231 L .54158 .49862 L p 0 .093 .633 r
F P
0 g
s
.52708 .47833 m .52668 .48231 L .51181 .46602 L p 0 .154 .685 r
F P
0 g
s
.51181 .46602 m .5084 .46002 L .52708 .47833 L p 0 .154 .685 r
F P
0 g
s
.73899 .36488 m .72639 .37616 L .69416 .34667 L p .806 .779 .828 r
F P
0 g
s
.72639 .37616 m .71402 .39113 L .68358 .36344 L p .844 .775 .785 r
F P
0 g
s
.68358 .36344 m .69416 .34667 L .72639 .37616 L p .844 .775 .785 r
F P
0 g
s
.56286 .52621 m .57576 .536 L .58083 .54152 L p 0 .181 .673 r
F P
0 g
s
.57576 .536 m .56286 .52621 L .55636 .51897 L p 0 .214 .721 r
F P
0 g
s
.75187 .35758 m .73899 .36488 L .70494 .33347 L p .739 .774 .881 r
F P
0 g
s
.69416 .34667 m .70494 .33347 L .73899 .36488 L p .806 .779 .828 r
F P
0 g
s
.50148 .44392 m .50495 .45267 L .48419 .43581 L p 0 .312 .791 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50148 .44392 L p 0 .312 .791 r
F P
0 g
s
.59503 .54853 m .58083 .54152 L .57576 .536 L p .04 .459 .879 r
F P
0 g
s
.71402 .39113 m .70179 .40924 L .67315 .38323 L p .865 .768 .754 r
F P
0 g
s
.67315 .38323 m .68358 .36344 L .71402 .39113 L p .865 .768 .754 r
F P
0 g
s
.76511 .35428 m .75187 .35758 L .71598 .32411 L p .628 .747 .933 r
F P
0 g
s
.70494 .33347 m .71598 .32411 L .75187 .35758 L p .739 .774 .881 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43643 .4077 L p .209 .691 .931 r
F P
0 g
s
.43643 .4077 m .42612 .40478 L .45573 .40475 L p .209 .691 .931 r
F P
0 g
s
.55539 .51374 m .54765 .50901 L .53737 .49706 L p 0 .159 .69 r
F P
0 g
s
.53737 .49706 m .54158 .49862 L .55539 .51374 L p 0 .159 .69 r
F P
0 g
s
.32566 .42844 m .33893 .42755 L .31893 .46466 L p .828 .91 .894 r
F P
0 g
s
.31893 .46466 m .30435 .47004 L .32566 .42844 L p .828 .91 .894 r
F P
0 g
s
.82171 .37234 m .8366 .38074 L .85986 .43317 L p .132 .4 .85 r
F P
0 g
s
.66461 .51246 m .65103 .52793 L .64027 .51194 L p .91 .856 .775 r
F P
0 g
s
.64027 .51194 m .65281 .49378 L .66461 .51246 L p .91 .856 .775 r
F P
0 g
s
.55636 .51897 m .56708 .52652 L .57576 .536 L p 0 .214 .721 r
F P
0 g
s
.56708 .52652 m .55636 .51897 L .54765 .50901 L p 0 .203 .722 r
F P
0 g
s
.39449 .39845 m .40514 .40046 L .37842 .41743 L p .674 .971 .912 r
F P
0 g
s
.37842 .41743 m .36535 .42153 L .39449 .39845 L p .674 .971 .912 r
F P
0 g
s
.54765 .50901 m .55539 .51374 L .56708 .52652 L p 0 .203 .722 r
F P
0 g
s
.70179 .40924 m .68962 .42966 L .6628 .40522 L p .875 .762 .734 r
F P
0 g
s
.6628 .40522 m .67315 .38323 L .70179 .40924 L p .875 .762 .734 r
F P
0 g
s
.77871 .35472 m .76511 .35428 L .72734 .31862 L p .464 .683 .961 r
F P
0 g
s
.71598 .32411 m .72734 .31862 L .76511 .35428 L p .628 .747 .933 r
F P
0 g
s
.60921 .55068 m .59503 .54853 L .58875 .54134 L p .419 .705 .982 r
F P
0 g
s
.57576 .536 m .58875 .54134 L .59503 .54853 L p .04 .459 .879 r
F P
0 g
s
.49799 .43382 m .50148 .44392 L .47717 .42815 L p .077 .447 .88 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49799 .43382 L p .077 .447 .88 r
F P
0 g
s
.52749 .47179 m .52708 .47833 L .5084 .46002 L p 0 .297 .794 r
F P
0 g
s
.5084 .46002 m .50495 .45267 L .52749 .47179 L p 0 .297 .794 r
F P
0 g
s
.65103 .52793 m .63726 .54 L .62756 .52652 L p .878 .862 .82 r
F P
0 g
s
.62756 .52652 m .64027 .51194 L .65103 .52793 L p .878 .862 .82 r
F P
0 g
s
.54583 .49699 m .54158 .49862 L .52668 .48231 L p 0 .261 .77 r
F P
0 g
s
.52668 .48231 m .52708 .47833 L .54583 .49699 L p 0 .261 .77 r
F P
0 g
s
.68962 .42966 m .67745 .45137 L .65245 .42843 L p .879 .757 .724 r
F P
0 g
s
.65245 .42843 m .6628 .40522 L .68962 .42966 L p .879 .757 .724 r
F P
0 g
s
.3124 .42742 m .32566 .42844 L .30435 .47004 L p .789 .847 .895 r
F P
0 g
s
.30435 .47004 m .28985 .47274 L .3124 .42742 L p .789 .847 .895 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42612 .40478 L p .394 .802 .98 r
F P
0 g
s
.42612 .40478 m .41569 .40246 L .44846 .39682 L p .394 .802 .98 r
F P
0 g
s
.58875 .54134 m .57576 .536 L .56708 .52652 L p .147 .468 .892 r
F P
0 g
s
.6233 .54777 m .60921 .55068 L .60175 .54161 L p .679 .826 .954 r
F P
0 g
s
.58875 .54134 m .60175 .54161 L .60921 .55068 L p .419 .705 .982 r
F P
0 g
s
.63726 .54 m .6233 .54777 L .61471 .5366 L p .813 .86 .883 r
F P
0 g
s
.61471 .5366 m .62756 .52652 L .63726 .54 L p .813 .86 .883 r
F P
0 g
s
.7927 .35838 m .77871 .35472 L .73904 .31675 L p .269 .582 .943 r
F P
0 g
s
.72734 .31862 m .73904 .31675 L .77871 .35472 L p .464 .683 .961 r
F P
0 g
s
.60175 .54161 m .61471 .5366 L .6233 .54777 L p .679 .826 .954 r
F P
0 g
s
.38374 .39612 m .39449 .39845 L .36535 .42153 L p .747 .97 .93 r
F P
0 g
s
.36535 .42153 m .35218 .42509 L .38374 .39612 L p .747 .97 .93 r
F P
0 g
s
.20655 .43366 m .19318 .42214 L .22154 .37026 L p .47 .516 .823 r
F P
0 g
s
.67745 .45137 m .66519 .47317 L .64207 .45167 L p .876 .754 .724 r
F P
0 g
s
.64207 .45167 m .65245 .42843 L .67745 .45137 L p .876 .754 .724 r
F P
0 g
s
.29919 .4243 m .3124 .42742 L .28985 .47274 L p .737 .778 .886 r
F P
0 g
s
.28985 .47274 m .2755 .47251 L .29919 .4243 L p .737 .778 .886 r
F P
0 g
s
.49447 .4225 m .49799 .43382 L .47008 .42042 L p .257 .561 .934 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49447 .4225 L p .257 .561 .934 r
F P
0 g
s
.56321 .51457 m .55539 .51374 L .54158 .49862 L p .07 .353 .825 r
F P
0 g
s
.54158 .49862 m .54583 .49699 L .56321 .51457 L p .07 .353 .825 r
F P
0 g
s
.56708 .52652 m .57789 .52974 L .58875 .54134 L p .147 .468 .892 r
F P
0 g
s
.57789 .52974 m .56708 .52652 L .55539 .51374 L p .148 .424 .864 r
F P
0 g
s
.22154 .37026 m .23436 .38158 L .20655 .43366 L p .47 .516 .823 r
F P
0 g
s
.22 .44486 m .20655 .43366 L .23436 .38158 L p .491 .527 .822 r
F P
0 g
s
.5279 .46258 m .52749 .47179 L .50495 .45267 L p .174 .418 .856 r
F P
0 g
s
.50495 .45267 m .50148 .44392 L .5279 .46258 L p .174 .418 .856 r
F P
0 g
s
.55539 .51374 m .56321 .51457 L .57789 .52974 L p .148 .424 .864 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41569 .40246 L p .539 .865 .995 r
F P
0 g
s
.41569 .40246 m .40514 .40046 L .44112 .38881 L p .539 .865 .995 r
F P
0 g
s
.28605 .41904 m .29919 .4243 L .2755 .47251 L p .678 .71 .872 r
F P
0 g
s
.2755 .47251 m .26132 .46929 L .28605 .41904 L p .678 .71 .872 r
F P
0 g
s
.23436 .38158 m .24718 .39262 L .22 .44486 L p .491 .527 .822 r
F P
0 g
s
.23359 .45497 m .22 .44486 L .24718 .39262 L p .524 .553 .828 r
F P
0 g
s
.60175 .54161 m .58875 .54134 L .57789 .52974 L p .472 .644 .932 r
F P
0 g
s
.55012 .49174 m .54583 .49699 L .52708 .47833 L p .186 .405 .842 r
F P
0 g
s
.52708 .47833 m .52749 .47179 L .55012 .49174 L p .186 .405 .842 r
F P
0 g
s
.66519 .47317 m .65281 .49378 L .6316 .47372 L p .868 .753 .734 r
F P
0 g
s
.6316 .47372 m .64207 .45167 L .66519 .47317 L p .868 .753 .734 r
F P
0 g
s
.24718 .39262 m .26006 .40286 L .23359 .45497 L p .524 .553 .828 r
F P
0 g
s
.24735 .46331 m .23359 .45497 L .26006 .40286 L p .568 .594 .839 r
F P
0 g
s
.27301 .4118 m .28605 .41904 L .26132 .46929 L p .62 .647 .855 r
F P
0 g
s
.26132 .46929 m .24735 .46331 L .27301 .4118 L p .62 .647 .855 r
F P
0 g
s
.26006 .40286 m .27301 .4118 L .24735 .46331 L p .568 .594 .839 r
F P
0 g
s
.80705 .36455 m .7927 .35838 L .75108 .31801 L p .097 .475 .894 r
F P
0 g
s
.73904 .31675 m .75108 .31801 L .7927 .35838 L p .269 .582 .943 r
F P
0 g
s
.37292 .39318 m .38374 .39612 L .35218 .42509 L p .779 .939 .932 r
F P
0 g
s
.35218 .42509 m .33893 .42755 L .37292 .39318 L p .779 .939 .932 r
F P
0 g
s
.49094 .41016 m .49447 .4225 L .46294 .41262 L p .405 .643 .954 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49094 .41016 L p .405 .643 .954 r
F P
0 g
s
.65281 .49378 m .64027 .51194 L .62103 .49336 L p .851 .752 .753 r
F P
0 g
s
.62103 .49336 m .6316 .47372 L .65281 .49378 L p .851 .752 .753 r
F P
0 g
s
.52831 .4508 m .5279 .46258 L .50148 .44392 L p .343 .505 .875 r
F P
0 g
s
.50148 .44392 m .49799 .43382 L .52831 .4508 L p .343 .505 .875 r
F P
0 g
s
.61471 .5366 m .60175 .54161 L .58874 .52805 L p .667 .719 .888 r
F P
0 g
s
.57789 .52974 m .58874 .52805 L .60175 .54161 L p .472 .644 .932 r
F P
0 g
s
.58874 .52805 m .57789 .52974 L .56321 .51457 L p .434 .568 .889 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40514 .40046 L p .638 .887 .986 r
F P
0 g
s
.40514 .40046 m .39449 .39845 L .43372 .38074 L p .638 .887 .986 r
F P
0 g
s
.57108 .511 m .56321 .51457 L .54583 .49699 L p .34 .491 .864 r
F P
0 g
s
.54583 .49699 m .55012 .49174 L .57108 .511 L p .34 .491 .864 r
F P
0 g
s
.69416 .34667 m .68358 .36344 L .64085 .34336 L p .811 .735 .781 r
F P
0 g
s
.68358 .36344 m .67315 .38323 L .6331 .36351 L p .822 .719 .752 r
F P
0 g
s
.6331 .36351 m .64085 .34336 L .68358 .36344 L p .822 .719 .752 r
F P
0 g
s
.64027 .51194 m .62756 .52652 L .61035 .50949 L p .822 .751 .785 r
F P
0 g
s
.61035 .50949 m .62103 .49336 L .64027 .51194 L p .822 .751 .785 r
F P
0 g
s
.70494 .33347 m .69416 .34667 L .64872 .32589 L p .786 .754 .824 r
F P
0 g
s
.64085 .34336 m .64872 .32589 L .69416 .34667 L p .811 .735 .781 r
F P
0 g
s
.62756 .52652 m .61471 .5366 L .59957 .52124 L p .768 .744 .831 r
F P
0 g
s
.58874 .52805 m .59957 .52124 L .61471 .5366 L p .667 .719 .888 r
F P
0 g
s
.56321 .51457 m .57108 .511 L .58874 .52805 L p .434 .568 .889 r
F P
0 g
s
.55441 .48273 m .55012 .49174 L .52749 .47179 L p .381 .497 .852 r
F P
0 g
s
.52749 .47179 m .5279 .46258 L .55441 .48273 L p .381 .497 .852 r
F P
0 g
s
.59957 .52124 m .61035 .50949 L .62756 .52652 L p .768 .744 .831 r
F P
0 g
s
.67315 .38323 m .6628 .40522 L .62541 .3856 L p .826 .707 .733 r
F P
0 g
s
.62541 .3856 m .6331 .36351 L .67315 .38323 L p .826 .707 .733 r
F P
0 g
s
.36203 .38938 m .37292 .39318 L .33893 .42755 L p .781 .89 .923 r
F P
0 g
s
.33893 .42755 m .32566 .42844 L .36203 .38938 L p .781 .89 .923 r
F P
0 g
s
.48739 .39708 m .49094 .41016 L .45573 .40475 L p .517 .697 .951 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48739 .39708 L p .517 .697 .951 r
F P
0 g
s
.71598 .32411 m .70494 .33347 L .65674 .3116 L p .738 .772 .881 r
F P
0 g
s
.64872 .32589 m .65674 .3116 L .70494 .33347 L p .786 .754 .824 r
F P
0 g
s
.82171 .37234 m .80705 .36455 L .76345 .32168 L p 0 .4 .848 r
F P
0 g
s
.75108 .31801 m .76345 .32168 L .80705 .36455 L p .097 .475 .894 r
F P
0 g
s
.6628 .40522 m .65245 .42843 L .61775 .40873 L p .824 .697 .724 r
F P
0 g
s
.61775 .40873 m .62541 .3856 L .6628 .40522 L p .824 .697 .724 r
F P
0 g
s
.52872 .4367 m .52831 .4508 L .49799 .43382 L p .465 .562 .869 r
F P
0 g
s
.49799 .43382 m .49447 .4225 L .52872 .4367 L p .465 .562 .869 r
F P
0 g
s
.72734 .31862 m .71598 .32411 L .66496 .30076 L p .645 .777 .944 r
F P
0 g
s
.65674 .3116 m .66496 .30076 L .71598 .32411 L p .738 .772 .881 r
F P
0 g
s
.59957 .52124 m .58874 .52805 L .57108 .511 L p .606 .633 .852 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39449 .39845 L p .698 .883 .966 r
F P
0 g
s
.39449 .39845 m .38374 .39612 L .42626 .3726 L p .698 .883 .966 r
F P
0 g
s
.65245 .42843 m .64207 .45167 L .61008 .43184 L p .817 .69 .723 r
F P
0 g
s
.61008 .43184 m .61775 .40873 L .65245 .42843 L p .817 .69 .723 r
F P
0 g
s
.57895 .50281 m .57108 .511 L .55012 .49174 L p .515 .563 .843 r
F P
0 g
s
.55012 .49174 m .55441 .48273 L .57895 .50281 L p .515 .563 .843 r
F P
0 g
s
.3511 .38455 m .36203 .38938 L .32566 .42844 L p .764 .834 .906 r
F P
0 g
s
.32566 .42844 m .3124 .42742 L .3511 .38455 L p .764 .834 .906 r
F P
0 g
s
.55872 .47009 m .55441 .48273 L .5279 .46258 L p .509 .549 .833 r
F P
0 g
s
.5279 .46258 m .52831 .4508 L .55872 .47009 L p .509 .549 .833 r
F P
0 g
s
.48382 .38358 m .48739 .39708 L .44846 .39682 L p .596 .73 .938 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48382 .38358 L p .596 .73 .938 r
F P
0 g
s
.57108 .511 m .57895 .50281 L .59957 .52124 L p .606 .633 .852 r
F P
0 g
s
.64207 .45167 m .6316 .47372 L .60237 .45382 L p .805 .684 .73 r
F P
0 g
s
.60237 .45382 m .61008 .43184 L .64207 .45167 L p .805 .684 .73 r
F P
0 g
s
.52913 .42072 m .52872 .4367 L .49447 .4225 L p .55 .599 .856 r
F P
0 g
s
.49447 .4225 m .49094 .41016 L .52913 .42072 L p .55 .599 .856 r
F P
0 g
s
.61035 .50949 m .59957 .52124 L .57895 .50281 L p .7 .66 .807 r
F P
0 g
s
.73904 .31675 m .72734 .31862 L .67341 .29338 L p .486 .745 .986 r
F P
0 g
s
.66496 .30076 m .67341 .29338 L .72734 .31862 L p .645 .777 .944 r
F P
0 g
s
.8366 .38074 m .82171 .37234 L .77612 .32692 L p 0 .374 .832 r
F P
0 g
s
.76345 .32168 m .77612 .32692 L .82171 .37234 L p 0 .4 .848 r
F P
0 g
s
.6316 .47372 m .62103 .49336 L .59461 .4736 L p .785 .678 .746 r
F P
0 g
s
.59461 .4736 m .60237 .45382 L .6316 .47372 L p .785 .678 .746 r
F P
0 g
s
.62103 .49336 m .61035 .50949 L .5868 .49018 L p .753 .672 .771 r
F P
0 g
s
.57895 .50281 m .5868 .49018 L .61035 .50949 L p .7 .66 .807 r
F P
0 g
s
.5868 .49018 m .59461 .4736 L .62103 .49336 L p .753 .672 .771 r
F P
0 g
s
.34014 .3786 m .3511 .38455 L .3124 .42742 L p .735 .777 .887 r
F P
0 g
s
.3124 .42742 m .29919 .4243 L .34014 .3786 L p .735 .777 .887 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38374 .39612 L p .73 .863 .944 r
F P
0 g
s
.38374 .39612 m .37292 .39318 L .41873 .36438 L p .73 .863 .944 r
F P
0 g
s
.5868 .49018 m .57895 .50281 L .55441 .48273 L p .618 .598 .808 r
F P
0 g
s
.55441 .48273 m .55872 .47009 L .5868 .49018 L p .618 .598 .808 r
F P
0 g
s
.56301 .45419 m .55872 .47009 L .52831 .4508 L p .591 .58 .809 r
F P
0 g
s
.52831 .4508 m .52872 .4367 L .56301 .45419 L p .591 .58 .809 r
F P
0 g
s
.48023 .36997 m .48382 .38358 L .44112 .38881 L p .651 .75 .922 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48023 .36997 L p .651 .75 .922 r
F P
0 g
s
.52954 .40338 m .52913 .42072 L .49094 .41016 L p .609 .626 .843 r
F P
0 g
s
.49094 .41016 m .48739 .39708 L .52954 .40338 L p .609 .626 .843 r
F P
0 g
s
.32916 .37151 m .34014 .3786 L .29919 .4243 L p .702 .725 .868 r
F P
0 g
s
.29919 .4243 m .28605 .41904 L .32916 .37151 L p .702 .725 .868 r
F P
0 g
s
.75108 .31801 m .73904 .31675 L .68211 .28925 L p .269 .655 .967 r
F P
0 g
s
.67341 .29338 m .68211 .28925 L .73904 .31675 L p .486 .745 .986 r
F P
0 g
s
.59461 .4736 m .5868 .49018 L .55872 .47009 L p .679 .616 .778 r
F P
0 g
s
.64085 .34336 m .6331 .36351 L .5844 .35187 L p .782 .69 .763 r
F P
0 g
s
.6331 .36351 m .62541 .3856 L .5801 .37251 L p .779 .672 .746 r
F P
0 g
s
.5801 .37251 m .5844 .35187 L .6331 .36351 L p .779 .672 .746 r
F P
0 g
s
.56729 .43567 m .56301 .45419 L .52872 .4367 L p .644 .599 .789 r
F P
0 g
s
.52872 .4367 m .52913 .42072 L .56729 .43567 L p .644 .599 .789 r
F P
0 g
s
.55872 .47009 m .56301 .45419 L .59461 .4736 L p .679 .616 .778 r
F P
0 g
s
.62541 .3856 m .61775 .40873 L .57583 .39393 L p .772 .658 .737 r
F P
0 g
s
.57583 .39393 m .5801 .37251 L .62541 .3856 L p .772 .658 .737 r
F P
0 g
s
.64872 .32589 m .64085 .34336 L .58873 .33278 L p .778 .712 .789 r
F P
0 g
s
.5844 .35187 m .58873 .33278 L .64085 .34336 L p .782 .69 .763 r
F P
0 g
s
.61775 .40873 m .61008 .43184 L .57156 .41529 L p .761 .647 .736 r
F P
0 g
s
.57156 .41529 m .57583 .39393 L .61775 .40873 L p .761 .647 .736 r
F P
0 g
s
.52996 .38531 m .52954 .40338 L .48739 .39708 L p .651 .647 .833 r
F P
0 g
s
.48739 .39708 m .48382 .38358 L .52996 .38531 L p .651 .647 .833 r
F P
0 g
s
.60237 .45382 m .59461 .4736 L .56301 .45419 L p .718 .628 .756 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37292 .39318 L p .743 .836 .922 r
F P
0 g
s
.37292 .39318 m .36203 .38938 L .41113 .35609 L p .743 .836 .922 r
F P
0 g
s
.61008 .43184 m .60237 .45382 L .56729 .43567 L p .743 .638 .743 r
F P
0 g
s
.56729 .43567 m .57156 .41529 L .61008 .43184 L p .743 .638 .743 r
F P
0 g
s
.4766 .35656 m .48023 .36997 L .43372 .38074 L p .688 .761 .908 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .4766 .35656 L p .688 .761 .908 r
F P
0 g
s
.77612 .32692 m .78901 .33274 L .8366 .38074 L p 0 .374 .832 r
F P
0 g
s
.65674 .3116 m .64872 .32589 L .59313 .31584 L p .766 .739 .829 r
F P
0 g
s
.58873 .33278 m .59313 .31584 L .64872 .32589 L p .778 .712 .789 r
F P
0 g
s
.56301 .45419 m .56729 .43567 L .60237 .45382 L p .718 .628 .756 r
F P
0 g
s
.31817 .36335 m .32916 .37151 L .28605 .41904 L p .668 .68 .852 r
F P
0 g
s
.28605 .41904 m .27301 .4118 L .31817 .36335 L p .668 .68 .852 r
F P
0 g
s
.57156 .41529 m .56729 .43567 L .52913 .42072 L p .68 .615 .776 r
F P
0 g
s
.52913 .42072 m .52954 .40338 L .57156 .41529 L p .68 .615 .776 r
F P
0 g
s
.30717 .35426 m .31817 .36335 L .27301 .4118 L p .637 .643 .839 r
F P
0 g
s
.27301 .4118 m .26006 .40286 L .30717 .35426 L p .637 .643 .839 r
F P
0 g
s
.66496 .30076 m .65674 .3116 L .59762 .30147 L p .736 .771 .881 r
F P
0 g
s
.59313 .31584 m .59762 .30147 L .65674 .3116 L p .766 .739 .829 r
F P
0 g
s
.53037 .36713 m .52996 .38531 L .48382 .38358 L p .682 .666 .828 r
F P
0 g
s
.48382 .38358 m .48023 .36997 L .53037 .36713 L p .682 .666 .828 r
F P
0 g
s
.29615 .34446 m .30717 .35426 L .26006 .40286 L p .61 .615 .832 r
F P
0 g
s
.26006 .40286 m .24718 .39262 L .29615 .34446 L p .61 .615 .832 r
F P
0 g
s
.57583 .39393 m .57156 .41529 L .52954 .40338 L p .706 .629 .769 r
F P
0 g
s
.52954 .40338 m .52996 .38531 L .57583 .39393 L p .706 .629 .769 r
F P
0 g
s
.76345 .32168 m .75108 .31801 L .69106 .28791 L p .063 .536 .895 r
F P
0 g
s
.68211 .28925 m .69106 .28791 L .75108 .31801 L p .269 .655 .967 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36203 .38938 L p .742 .805 .902 r
F P
0 g
s
.36203 .38938 m .3511 .38455 L .40346 .34772 L p .742 .805 .902 r
F P
0 g
s
.47294 .34365 m .4766 .35656 L .42626 .3726 L p .712 .768 .896 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47294 .34365 L p .712 .768 .896 r
F P
0 g
s
.2851 .3342 m .29615 .34446 L .24718 .39262 L p .588 .598 .829 r
F P
0 g
s
.24718 .39262 m .23436 .38158 L .2851 .3342 L p .588 .598 .829 r
F P
0 g
s
.5801 .37251 m .57583 .39393 L .52996 .38531 L p .724 .644 .769 r
F P
0 g
s
.27399 .32374 m .2851 .3342 L .23436 .38158 L p .572 .59 .833 r
F P
0 g
s
.23436 .38158 m .22154 .37026 L .27399 .32374 L p .572 .59 .833 r
F P
0 g
s
.5844 .35187 m .5801 .37251 L .53037 .36713 L p .737 .661 .775 r
F P
0 g
s
.52996 .38531 m .53037 .36713 L .5801 .37251 L p .724 .644 .769 r
F P
0 g
s
.67341 .29338 m .66496 .30076 L .6022 .28991 L p .674 .799 .941 r
F P
0 g
s
.59762 .30147 m .6022 .28991 L .66496 .30076 L p .736 .771 .881 r
F P
0 g
s
.53079 .34946 m .53037 .36713 L .48023 .36997 L p .704 .685 .829 r
F P
0 g
s
.48023 .36997 m .4766 .35656 L .53079 .34946 L p .704 .685 .829 r
F P
0 g
s
.58873 .33278 m .5844 .35187 L .53079 .34946 L p .746 .682 .789 r
F P
0 g
s
.53037 .36713 m .53079 .34946 L .5844 .35187 L p .737 .661 .775 r
F P
0 g
s
.59313 .31584 m .58873 .33278 L .53121 .33283 L p .75 .707 .811 r
F P
0 g
s
.53079 .34946 m .53121 .33283 L .58873 .33278 L p .746 .682 .789 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .3511 .38455 L p .733 .775 .886 r
F P
0 g
s
.3511 .38455 m .34014 .3786 L .39573 .33928 L p .733 .775 .886 r
F P
0 g
s
.46924 .33147 m .47294 .34365 L .41873 .36438 L p .726 .771 .889 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46924 .33147 L p .726 .771 .889 r
F P
0 g
s
.53121 .33283 m .53079 .34946 L .4766 .35656 L p .72 .705 .835 r
F P
0 g
s
.4766 .35656 m .47294 .34365 L .53121 .33283 L p .72 .705 .835 r
F P
0 g
s
.68211 .28925 m .67341 .29338 L .6069 .28117 L p .561 .804 .99 r
F P
0 g
s
.6022 .28991 m .6069 .28117 L .67341 .29338 L p .674 .799 .941 r
F P
0 g
s
.59762 .30147 m .59313 .31584 L .53164 .31768 L p .747 .737 .842 r
F P
0 g
s
.53121 .33283 m .53164 .31768 L .59313 .31584 L p .75 .707 .811 r
F P
0 g
s
.77612 .32692 m .76345 .32168 L .70025 .28873 L p 0 .445 .827 r
F P
0 g
s
.69106 .28791 m .70025 .28873 L .76345 .32168 L p .063 .536 .895 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34014 .3786 L p .72 .747 .874 r
F P
0 g
s
.34014 .3786 m .32916 .37151 L .38792 .33076 L p .72 .747 .874 r
F P
0 g
s
.46549 .32017 m .46924 .33147 L .41113 .35609 L p .732 .773 .885 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46549 .32017 L p .732 .773 .885 r
F P
0 g
s
.53164 .31768 m .53121 .33283 L .47294 .34365 L p .73 .726 .846 r
F P
0 g
s
.47294 .34365 m .46924 .33147 L .53164 .31768 L p .73 .726 .846 r
F P
0 g
s
.6022 .28991 m .59762 .30147 L .53207 .30432 L p .734 .77 .882 r
F P
0 g
s
.53164 .31768 m .53207 .30432 L .59762 .30147 L p .747 .737 .842 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32916 .37151 L p .703 .722 .865 r
F P
0 g
s
.32916 .37151 m .31817 .36335 L .38005 .32217 L p .703 .722 .865 r
F P
0 g
s
.69106 .28791 m .68211 .28925 L .61173 .27506 L p .391 .762 .992 r
F P
0 g
s
.6069 .28117 m .61173 .27506 L .68211 .28925 L p .561 .804 .99 r
F P
0 g
s
.53207 .30432 m .53164 .31768 L .46924 .33147 L p .735 .748 .863 r
F P
0 g
s
.46924 .33147 m .46549 .32017 L .53207 .30432 L p .735 .748 .863 r
F P
0 g
s
.46168 .30984 m .46549 .32017 L .40346 .34772 L p .733 .773 .885 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46168 .30984 L p .733 .773 .885 r
F P
0 g
s
.6069 .28117 m .6022 .28991 L .53252 .29293 L p .704 .805 .928 r
F P
0 g
s
.53207 .30432 m .53252 .29293 L .6022 .28991 L p .734 .77 .882 r
F P
0 g
s
.78901 .33274 m .77612 .32692 L .70967 .29093 L p 0 .413 .805 r
F P
0 g
s
.70025 .28873 m .70967 .29093 L .77612 .32692 L p 0 .445 .827 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31817 .36335 L p .685 .701 .859 r
F P
0 g
s
.31817 .36335 m .30717 .35426 L .3721 .3135 L p .685 .701 .859 r
F P
0 g
s
.53252 .29293 m .53207 .30432 L .46549 .32017 L p .733 .771 .884 r
F P
0 g
s
.46549 .32017 m .46168 .30984 L .53252 .29293 L p .733 .771 .884 r
F P
0 g
s
.45782 .30051 m .46168 .30984 L .39573 .33928 L p .728 .772 .888 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45782 .30051 L p .728 .772 .888 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30717 .35426 L p .667 .684 .857 r
F P
0 g
s
.30717 .35426 m .29615 .34446 L .36408 .30475 L p .667 .684 .857 r
F P
0 g
s
.70025 .28873 m .69106 .28791 L .61669 .27121 L p .21 .677 .942 r
F P
0 g
s
.61173 .27506 m .61669 .27121 L .69106 .28791 L p .391 .762 .992 r
F P
0 g
s
.61173 .27506 m .6069 .28117 L .53297 .2835 L p .649 .83 .97 r
F P
0 g
s
.53252 .29293 m .53297 .2835 L .6069 .28117 L p .704 .805 .928 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29615 .34446 L p .65 .673 .858 r
F P
0 g
s
.29615 .34446 m .2851 .3342 L .35599 .29592 L p .65 .673 .858 r
F P
0 g
s
.53297 .2835 m .53252 .29293 L .46168 .30984 L p .723 .794 .907 r
F P
0 g
s
.70967 .29093 m .71927 .29362 L .78901 .33274 L p 0 .413 .805 r
F P
0 g
s
.46168 .30984 m .45782 .30051 L .53297 .2835 L p .723 .794 .907 r
F P
0 g
s
.45389 .29209 m .45782 .30051 L .38792 .33076 L p .719 .77 .893 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45389 .29209 L p .719 .77 .893 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .2851 .3342 L p .635 .667 .863 r
F P
0 g
s
.2851 .3342 m .27399 .32374 L .34782 .287 L p .635 .667 .863 r
F P
0 g
s
.61669 .27121 m .61173 .27506 L .53343 .27592 L p .566 .836 .996 r
F P
0 g
s
.53297 .2835 m .53343 .27592 L .61173 .27506 L p .649 .83 .97 r
F P
0 g
s
.70967 .29093 m .70025 .28873 L .62177 .26911 L p .083 .599 .884 r
F P
0 g
s
.61669 .27121 m .62177 .26911 L .70025 .28873 L p .21 .677 .942 r
F P
0 g
s
.53343 .27592 m .53297 .2835 L .45782 .30051 L p .705 .813 .932 r
F P
0 g
s
.44989 .28444 m .45389 .29209 L .38005 .32217 L p .706 .767 .899 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44989 .28444 L p .706 .767 .899 r
F P
0 g
s
.45782 .30051 m .45389 .29209 L .53343 .27592 L p .705 .813 .932 r
F P
0 g
s
.44584 .27737 m .44989 .28444 L .3721 .3135 L p .691 .762 .906 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44584 .27737 L p .691 .762 .906 r
F P
0 g
s
.62177 .26911 m .61669 .27121 L .53391 .26992 L p .469 .817 .998 r
F P
0 g
s
.53343 .27592 m .53391 .26992 L .61669 .27121 L p .566 .836 .996 r
F P
0 g
s
.53391 .26992 m .53343 .27592 L .45389 .29209 L p .678 .826 .954 r
F P
0 g
s
.45389 .29209 m .44989 .28444 L .53391 .26992 L p .678 .826 .954 r
F P
0 g
s
.62177 .26911 m .62697 .2681 L .70967 .29093 L p .083 .599 .884 r
F P
0 g
s
.71927 .29362 m .70967 .29093 L .62697 .2681 L p .038 .565 .863 r
F P
0 g
s
.44172 .27062 m .44584 .27737 L .36408 .30475 L p .674 .757 .914 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44172 .27062 L p .674 .757 .914 r
F P
0 g
s
.53439 .2651 m .53391 .26992 L .44989 .28444 L p .646 .83 .971 r
F P
0 g
s
.44989 .28444 m .44584 .27737 L .53439 .2651 L p .646 .83 .971 r
F P
0 g
s
.53391 .26992 m .53439 .2651 L .62177 .26911 L p .469 .817 .998 r
F P
0 g
s
.62697 .2681 m .62177 .26911 L .53439 .2651 L p .387 .785 .986 r
F P
0 g
s
.43754 .26392 m .44172 .27062 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.62697 .2681 m .63227 .26744 L .71927 .29362 L p .038 .565 .863 r
F P
0 g
s
.53488 .26102 m .53439 .2651 L .44584 .27737 L p .612 .827 .982 r
F P
0 g
s
.44584 .27737 m .44172 .27062 L .53488 .26102 L p .612 .827 .982 r
F P
0 g
s
.53439 .2651 m .53488 .26102 L .62697 .2681 L p .387 .785 .986 r
F P
0 g
s
.63227 .26744 m .62697 .2681 L .53488 .26102 L p .344 .761 .978 r
F P
0 g
s
.53539 .25714 m .53488 .26102 L .44172 .27062 L p .585 .817 .987 r
F P
0 g
s
.44172 .27062 m .43754 .26392 L .53539 .25714 L p .585 .817 .987 r
F P
0 g
s
.53488 .26102 m .53539 .25714 L .63227 .26744 L p .344 .761 .978 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00001?nEdO`5o`0000KoF<;j2ol0000Vooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0;oooool001;ooooo1_l00005ooooo`03o`000?oooooooooo00Go
oooo0_l00004ooooo`03o`000?oooooooooo07Wooooo2_l0000=oiGAo0Oo00000_nLdo/4o`0000So
HlSl2OmH`_X;o`0001_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0_ooooo`00
7Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
M?ooool4o`0000?oYl3[00?o0000oiGAo?nEdO`02_nEdO`3o`0000OoW=?k1Ol00004ojGDn003o`00
0?mhdOooN=7o00GoN=7o2Ol00007of?8o0;o00000omH`_X7o`0001Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0L?ooool3o`0000KoYl3[0ol00003oiGAo003o`000?nL
do_oW=?k00WoW=?k1?l00008ojGDn0Co00005_mhdOl7o`0000Co5IWR0_l9T=`3o`00017ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4o`0000KoYl3[0ol00002
ojc1j@03o`000?nLdo_oW=?k00OoW=?k0_l0000:ojGDn0Ko00000on]do@00ol0003oT=Knoi3FoP0H
oi3FoP05o`000?mT`ogoI<?mofC3oOle[O401OlEVN82o`V@g0?o00003_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`1Vooooo`Co00001onW`>/3o`0000Go[<7Y0_l00002
oicCn`03o`000?nUe?SoYMCh00WoYMCh1_l00006ojgCm0Co00001_n@e_hDo`0000SoI<?m00?o0000
oaFIh_lEVN800olEVN801?l9T=co0000o`000?l0000;ooooo`03o`000?oooooooooo03?ooooo0_l0
000^ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o00002_ooool00ol0003oooooooooo`1Q
ooooo`Co00002?nW`>/3o`0000Go[<7Y0ol000000on``nOo0000ojGDn009ojGDn0Co00001on]do@5
o`0000?o]=3^00?o0000ojKDn?nVe?P05_nVe?P00ol0003oSlgmoho=o@02oho=o@WoI<?m0_l00003
oaFIhP03o`V@g?l0003o000000;o00002?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02cooooo000Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0GOooool3o`00
00SoYl3[1?l00005ojc1j@?o00001On``nL00ol0003oYMChojGDn003ojGDn0?o00001_n]do@6o`00
00Go]=3^0ol00006ojKDn1?o00002on?cOd00ol0003oI<?mofC3o@05ofC3o@05o`000?lEVN;o5IWR
oaFIh_l9T=`00ol00005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool0
02Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hooooo`Co00002?nW`>/3o`00
00Oo[<7Y0_l00007ok33i`;o000000?oYMCho`000?n]do@02?n]do@3o`0000Oo]=3^1?l00002okW;
j003o`000?ndc^go]<k]01Ko]<k]00Co0000ojc<l?n/c?3o[<c`1?l0000:oho=o@;o00001?mT`od0
1?l0003o5IWRoaFIh_l9T=`3o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000:
ojO0j`;o00001on/`NT3o`0000Ko/<?W0ol00002okC4iP03o`000?n]doCo[M?d00Co[M?d0_l00008
okC@kPCo00001_nibnP00ol0003o]<k]okC>k@0EokC>k@03o`000?n/c?3o[<c`00So[<c`1Ol00009
oho=o@?o000000CoI<?mo`000?l0003o2I3L1?l0000fooooo`03o`000?oooooooooo02[ooooo000T
ooooo`;o00003_ooool00ol0003oooooooooo`1Aooooo`;o00000_nRZ]`00ol0003oYl3[ojO0j`05
ojO0j`;o00001on/`NT3o`0000Ko/<?W0ol00005okC4iP;o000000?o[M?do`000?ndd>h02?ndd>h4
o`0000[o^L_X00?o0000okC>kOndc^d02Ondc^d=o`0000oo[<c`1_l00003oho=o@04o`000?ml__co
O;klogbno0?oA:Og0_l@RND5o`0003Cooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@
ooooo`03o`000?oooooooooo04kooooo0_l00005oj:Zg003o`000?nW`>_oYl3[00;oYl3[00?o0000
ojc1jOn/`NT01_n/`NT2o`0000Oo/<?W0_l00005okC4iP?o000000?o^<GTo`000?ndd>h01ondd>h2
o`0000go^L_X0ol00002okC>k@Wo00003?nkaN400ol0003o_<GQokc5h@02okc5h@Oo00002_n/c?03
o`0000KoO;kl0om4YoL01?l0003o48WUoa29iOl0LM<3o`0003?ooooo00?o0000ooooooooool0:?oo
ool002Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1;ooooo`;o00001onRZ]`3
o`0000Wo[<7Y00?o0000ok33ion``nL01On``nL3o`0000Go]<CV0_l00005okS5i003o`000?ndd>ko
]=3^00;o]=3^00?o0000okW;j?nibnP02_nibnP5o`0000;o^lGR00?o0000ok_5hOnkaN405?nkaN40
0ol0003o_<GQokc5h@0:okc5h@Oo00000on/c?001?l0003oYLKaojG6lOnUa_47ogbno0;o000000Ko
A:Ogoa29iOl@RNGo48WUo`1adol0JLh2o`00033ooooo0_l0000Zooooo`008oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04Sooooo0_l00007oj:Zg0;o00000_nV[=/00ol0003o[<7Y
ojc1j@04ojc1j@;o00001on``nL2o`0000Go]<CV0ol00006okS5i0;o000000?o]=3^okW;j?nibnP0
2OnibnP5o`0000Oo^lGR00?o0000ok_5hOnkaN402?nkaN4<o`0001Co_<GQ0ol00006ojG6l@03o`00
0?ml__coO;kl00?oO;kl0_l00002odBWm`05o`000?l@RNGo48WUo`1adol0JLh00_l0000`ooooo`03
o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
AOooool2o`0000OoXZ[L0_l00005ojJ/f`05o`000?n/`NWo[<7Yojc1jOl000001on``nL3o`0000Go
]<CV0_l00007okS5i0;o000000?o^/GSo`000?nibnP01_nibnP5o`0000[o^lGR0ol00002ok_5h@So
00002ono_=L01?l0003oa;gDolBme?o4_M@5o`0000ko_<GQ00?o0000okc5hOl000001onUa_401?l0
003oO;klo`000?l00002ogbno004o`000?m4YoOoA:Ogo`0000;o48WU00?o0000o`1Yc_l00000<?oo
ool00ol0003oooooooooo`0Vooooo`008oooool2o`0001Cooooo00?o0000ooooooooool0@Oooool3
o`0000OoXZ[L0_l00007ojJ/f`;o00002?n``nL2o`0000Go]<CV0ol00006okS5i0?o00001?njaN<0
1?l0003o^L_XokW;j?nibnP3o`0000_o^lGR1?l00002okbog003o`000?no_=Oo_kcG01?o_kcG00?o
0000olBme?o4_M@01_o4_M@5o`0000So_<GQ00?o0000okc5hOnlaN400_nlaN42o`0000?oYLKa1Ol0
0003ogbno0;o00000_m4YoL00ol0003o48WUoa29i@03o`0002kooooo00?o0000ooooooooool09_oo
ool002?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`;o00002?nRZ]`2
o`0000OoYZcK0_l000000onZ[m_o0000ok33i`05ok33i`03o`000?nda>Ko]<CV00Co]<CV0_l00007
okS5i0;o00001_njaN<3o`0000go^lGR0ol00006okbog003o`000?no_=Oo_kcG01;o_kcG00?o0000
olBme?o4_M@03?o4_M@5o`0000;o_<GQ00?o0000okc5hOnlaN401OnlaN43o`0000GoYLKa0_l00003
ogbno0;o00000_m4YoL00ol0003o48WUo`000003o`0002gooooo00?o0000ooooooooool09Oooool0
02?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0kooooo`;o00002?nRZ]`2o`00
00SoYZcK00?o0000ojZ_fonZ[m/00_nZ[m/01Ol0003o/<?Wok33ion``nOo000000Ko]<CV0_l00007
okS5i0;o00001_njaN<2o`000003ok_5h_l0003o^lGR00Wo^lGR1?l00009okbog003o`000?no_=Oo
_kcG01;o_kcG00?o0000olBme?o4_M@04Oo4_M@2o`0000Go_<GQ0ol00002okc5h@?o00001?nUa_44
o`0000;oO;kl0_l00002odBWm`03o`000?l@RNGo077C00?o0000:oooool00ol0003oooooooooo`0U
ooooo`008oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Sooooo0_l00008oj:Z
g0;o00002?nV[=/2o`0000GoZZoK0ol00006okC4iP03o`000?nhaNCo^<GT00Go^<GT0ol00005ok[5
h`?o00001?nkaN800ol0003o^lGRok_5hP04ok_5hP?o00003Onl_m`00ol0003o_kcGoknle`08oknl
e`_o00005?o4_M@00ol0003obL7Bo`000003o`0000So_<GQ0_l00003ojG6l@03o`000?nUa_7oYLKa
00;o00000_ml__`2o`0000;oA:Og0_l000001?l0LM?o06W>o`000?l0000Yooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
2?ooool002;ooooo0ol0000Hooooo`03o`000?oooooooooo03Gooooo0_l00008oj:Zg0;o00002?nV
[=/2o`0000GoZZoK0_l00003ojncf`05o`000?nda>Ko]<CVokC4i_l000001onhaN@2o`0000Ko^/GS
0_l00007ok_5hP03o`000?nkaN;o^lGR00;o^lGR00?o0000okbog?nl_m`03Onl_m`3o`000003oknl
eol0003o000000Oo00002_no]<l00ol0003oakK9olNfb@05o`0000coa;gD1?l000001?o9`M;o0000
o`000?l00009okc5h@;o000000?oYLKao`000?nUa_400onUa_4:o`000004o`1adol0JLko0000o`00
02Wooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Oooooo000Rooooo`03o`000?oooooooooo01Wooooo0_l0000coooo
o`;o00002?nRZ]`2o`0000SoYZcK0_l00006ojZ_f`03o`000?n_/m_o[k?K00?o[k?K0_l00008okS5
i0;o00001_njaN<2o`0000Wo^lGR0ol0000>okbog0Co00000_nj^MP00ol0003o_kC?okndc`0Aoknd
c`03o`000?o7]/WoakK900KoakK91?l00006olBme0?o00001oo9`M82o`0000Wo_<GQ1Ol00002oj2o
kP03o`000?mf[_KoMZkf00;oMZkf0om4U?401Ol0003o67WTo`000?l0003o06W>00;o00009oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`06ooooo`008_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02kooooo0ol00007
oj:Zg0;o00002?nV[=/2o`0000KoZZoK0_l00005ojncf`04o`000?nc^=go/kSMo`0000Go^<GT0_l0
0006ok[5h`;o00002?nkaN83o`000003ok_5h_l0003o_;oL00Wo_;oL1Ol00006okZif003o`000?no
]<oo_kC?017o_kC?00?o0000olNfbOo7]/T02_o7]/T6o`000003olBme?l0003obL7B00WobL7B0_l0
0009okc5h@;o00001?nP_nh00ol0003oMZkfogJ^mP02ogJ^mP?oA9Ca00?o0000oaQii?lHNN@00_l0
00000ol0JLko0000ooooo`0Vooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0;?ooool01Ol0003oTYOEoi:GeOnBUmGo000000CoXZ[L0_l00009ojJ/
f`03o`000?nZ[m_oZZoK00CoZZoK0_l00005ojncf`;o00001?nc^=d01?l0003o^<GTokS5i?nhaN@7
ok[5h`;o00002?nkaN82o`0000Co^lGR00?o0000okbog?nl_m`01?nl_m`4o`0000_o^[WH00?o0000
okndcono]<l04Ono]<l00ol0003oakK9olNfb@0:olNfb@?o00000_o7]/T2o`0000gobL7B0ol00004
okc5h@05o`000?nma^7o_LKQokg6hOl000001?nP_nh00ol0003oMZkfogJ^mP02ogJ^mP?oA9Ca00Go
0000oaQii?lHNNCo0000o`1Vf@03o`0002Kooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c008ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Zooooo`03o`000?nBUmGoTYOE00?oTYOE00Co0000oj:Z
g?nRZ]co00002OnV[=/2o`0000KoZZoK00?o0000ojncfon_/m/01?n_/m/00ol0003o/kSMok>hg@04
ok>hg@;o00001onjaN<2o`0000So^lGR0_l00007ok_5hP03o`000?nl_mco_;oL00?o00003onj^MP0
0ol0003o_kC?okndc`0@okndc`03o`000?o7]/WoakK900SoakK90ol00006olNfb@04o`000?o?_<Oo
0000o`0000gobL7B0_l000000onlaN7o0000okg6h@03okg6h@03o`000?nP_nkoX;o^00?oX;o^00?o
0000ogJ^m_mf[_H00_mf[_H01?l0003oA9CaodBDlOl00002oaQii003o`000?l0I]Wo06KI00?o0000
9?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0:ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:?ooool00ol0003o
TYOEoi:Ge@04oi:Ge@;o00002OnV[=/2o`0000KoZZoK0_l00005ojncf`;o00001_nc^=d00ol0003o
^;oOo`000005ok[5h`03o`000?nkaN;o^lGR00Ko^lGR0ol00008ok_5hP?o00004Onj^MP3o`000003
okndcol0003o0000013o00001oo7]/T3o`0000SoakK900?o0000olnlaoo?_<L00_o?_<L3o`0000co
bL7B00?o0000okg6hOnma^401?nma^42o`0000CoX;o^00?o0000ogJ^m_mf[_H00_mf[_H01?l0003o
A9CaodBDlOl00002oaQii003o`000?l0I]Wo06KI00;o05oD00?o0000ooooooooool08?ooool3o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o00008Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?nBUmGoTYOE00CoTYOE00Co0000oiJIe?nFVMCo00001_nV
[=/2o`0000KoZZoK0_l00006ojncf`03o`000?nc^=go/kSM00Co/kSM0_l00003okRog`04o`000?nj
aN?o^/GSo`0000So^lGR0_l00008ok_5hP?o000000?o^LGSo`000?nj^MP03?nj^MP5o`0000;o^;CE
00?o0000okj^bOnn[/T04?nn[/T00ol0003ob;33olR```05o`0000_oakK900?o0000olnlaoo?_<L0
1Oo?_<L2o`0000[obL7B00?o0000olk7donma^401Onma^42o`0000CoX;o^00?o0000ogJ^m_mf[_H0
0_mf[_H01?l0003oA9CaodBDlOl00002oaQii003o`000?l0I]Wo06KI00;o05oD00?o0000oooooooo
ool08_ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002Ooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000oi:GeOnBUmD0
1?nBUmD00ol0003oUYWDoiJIe002oiJIe003o`000?nV[=_oYZcK00;oYZcK00?o0000ojZ_fonZ[m/0
1OnZ[m/00ol0003o[k?Kojncf`04ojncf`;o00001_nc^=d00ol0003o^;oOokRog`03okRog`;o0000
2?nkaN82o`0000So^lGR0_l00004okW5h`03o`000?nj^MSo^[WH00Ko^[WH1Ol00007okRde@03o`00
0?nn[/Wo_Zk9013o_Zk900?o0000olR``ol000000_l00003olR```Co00001oo7]/T00ol0003ockc7
olnla`07olnla`;o00001oo9`M801Ol0003oc/OColk7doo>am?o000000Go_LKQ0_l00004oj2okP03
o`000?mf[_KoMZkf00;oMZkf00Co0000odBDlOm4U?7o00000_lHNN@00ol0003o06KIo`1Vf@02o`1O
e003o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool000Oooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Rooooo`03o`000?nBUmGoTYOE00CoTYOE00?o0000oiJIe?nFVM@01?nFVM@01?l0
003oYZcKojJ/fol00006ojZ_f`;o00001_n_/m/00ol0003o/kSMok>hg@05ok>hg@03o`000?nh_moo
^;oO00?o^;oO00Co0000ok_6h_nka^;o00001OnkaN82o`0000Oo^lGR0ol00007okW5h`03o`000?nj
^MSo^[WH00Go00003?nh]=D00ol0003o_Zk9okj^b@0?okj^b@?o00002_o8/<<5o`000003olNfbOl0
003ockc700_ockc70ol00003olW1dP03o`000?o>am?oc/OC00?oc/OC00?o0000okg6hOnma^400_nm
a^400ol0003o_LKQo`000004oj2okP03o`000?mf[_KoMZkf00;oMZkf00Co0000odBDlOm4U?7o0000
0_lHNN@00ol0003o06KIo`1Vf@02o`1Oe003o`000?oooooooooo027ooooo00?o0000ooooooooool0
7_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Pooooo`03o`000?nBUmGoTYOE00CoTYOE
00?o0000oiJIe?nFVM@01OnFVM@2o`0000KoZZoK0_l00006ojncf`;o00001_nc^=d2o`0000Co^;oO
0_l00004ok_6hP04o`000?nkaN;o^lGRo`0000So^lGR0_l00009okW5h`Co00004Onh]=D00ol0003o
_Zk9okj^b@0=okj^b@?o00004Oo8/<<2o`0000oockc70_l000000oo9`M;o0000olk7d`05olk7d`03
o`000?nma^7o_LKQ00;o_LKQ00?o0000okg6hOl000001?nP_nh00ol0003oMZkfogJ^mP02ogJ^mP04
o`000?m4U?7oA9Cao`0000;o67WT00?o0000o`1VfOl0I]T00_l0Gm@00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo0_l0000Uooooo`03o`000?oooooooooo01kooooo00?o0000oi:GeOnBUmD01?nBUmD00ol0
003oUYWDoiJIe005oiJIe004o`000?nLWMCoW9gDo`0000CoZZoK00?o0000ojncfon_/m/01On_/m/0
0ol0003o/kSMok>hg@05ok>hg@03o`000?nh_moo^;oO00?o^;oO00?o0000ok_6h_nka^801?nka^82
o`0000Oo^lGR0ol00008okW5h`?o000000?o]/CUo`000?nh]=D04_nh]=D00ol0003o_Zk9okj^b@0:
okj^b@?o00000_nn[/T00ol0003ob;33olR```0@olR```03o`000?oB^<3o000000;o00003Oo?_<L0
0ol0003oc/OColk7d`06olk7d`03o`000?nma^7o_LKQ00;o_LKQ00?o0000okg6hOl000001?nP_nh0
0ol0003oMZkfogJ^mP02ogJ^mP04o`000?m4U?7oA9Cao`0000;o67WT00Ko0000o`1VfOl0I]Wo0000
o`1Oe?l0000Rooooo`03o`000?oooooooooo01gooooo000Pooooo`;o00009oooool00ol0003ooooo
ooooo`0Looooo`03o`000?nBUmGoTYOE00CoTYOE00?o0000oiJIe?nFVM@01OnFVM@00ol0003oW9gD
oibMe002oibMe004o`000?nZ[m_oZZoKo`0000Ko[k?K0_l00006ok>hg@;o00001?nh_ml2o`0000Ko
^lKR00?o0000okg>i_l000001OnkaN82o`0000Wo^LGS0_l00004okK4i@03o`000?nh]=Go^;CE00co
^;CE1_l000000onn[/Wo0000o`00000?o`00017ob;3300?o0000om:h`?oB^<000ooB^<02o`0000_o
ckc70_l00008olk7d`05o`000?nma^7o_LKQokg6hOl000000_nma^400ol0003oX;o^oj2okP02oj2o
kP03o`000?mf[_KoMZkf00;oMZkf00Co0000odBDlOm4U?7o00000_lHNN@01_l0003o06KIo`1VfOl0
003o05oDo`00027ooooo0_l0000Nooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01[ooooo00?o0000oi:GeOnBUmD01?nBUmD00ol0003oUYWDoiJIe005oiJIe003o`000?nL
WMCoW9gD00CoW9gD0_l00006ojncf`03o`000?nc^=go/kSM00Go/kSM00?o0000okRogonh_ml00onh
_ml00ol0003o^lKRok_6hP04ok_6hP;o00000onmc^H00ol0003o^lGRok_5hP02o`0000So^LGS0ol0
0007okK4i@03o`000?nh]=Go^;CE00;o^;CE2Ol00005okB_e003o`000?nlZLKo_:W600Co_:W60ol0
0008okbYaP03o`000?o7[;koajbn00Co00002oo8/<<00ol0003od[S0om:h`005om:h`0;o00002?o?
_<L01?l0003of<K8omS6b?l00008olk7d`05o`000?nma^7o_LKQokg6hOl000000_nma^400ol0003o
X;o^oj2okP09o`000005odBDlOl0003o67WToaQii?l000000_l0I]T00ol0003o05oDo`00000Roooo
o`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06?ooool00ol0003oTYOEoi:Ge@04oi:Ge@03o`000?nFVMCoUYWD00GoUYWD00?o0000oibMe?nL
WM@01OnLWM@00ol0003oXjCFo`000004ojncf`03o`000?nc^=go/kSM00Co/kSM0_l00004okRog`;o
00001_nka^800ol0003o_LkVokg>iP03okg>iP;o00002?niaN<3o`0000So]/CU1ol0000>okB_e004
o`000?nlZLKo_:W6okbYaP?o00002onlZLH00ol0003oajbnolN/_P04olN/_PCo00001_o8/<<00ol0
003od[S0om:h`008om:h`0?o00001?o?_<L00ol0003of<K8omS6b002omS6b003o`000?o>am?oc/OC
00Koc/OC00Ko0000okg6hOnma^7o_LKQo`000?nma^43o`0000;oX;SY1OmmXn`2oeV<j0?o00000_lH
NN@01_l0003o06KIo`1VfOl0003o05oDo`00027ooooo00?o0000ooooooooool06oooool0023ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?nBUmGoTYOE00CoTYOE
00?o0000oiJIe?nFVM@01OnFVM@00ol0003oW9gDoibMe005oibMe005o`000?nSY=KoXjCFoj>Te_l0
00000_n_/m/7ok>hg@03o`000?nh_moo^;oO00?o^;oO00?o0000ok_6h_nka^801?nka^82o`0000Go
_LkV00Co0000okkFk?nne^co00001OniaN<2o`0000So]/CU0ol00002ok32j003o`000?nd[mCo]:oD
013o]:oD1?l0000=okbYaP03o`000?o7[;koajbn00Woajbn1?l00002olR```03o`000?oB^<3od[S0
00_od[S00_l000000oo?_<Oo0000omS6b005omS6b003o`000?o>am?oc/OC00Koc/OC00Ko0000okg6
hOnma^7o_LKQo`000?nma^45oj2hj@GoOJ?/1?mIS>P2o`000007oaQii?l0003o06KIo`1VfOl0003o
05oDo`00000Qooooo`03o`000?oooooooooo01[ooooo000Pooooo`;o0000:oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?nBUmGoTYOE00CoTYOE00?o0000oiJIe?nFVM@01OnFVM@00ol0003oW9gD
oibMe005oibMe003o`000?nSY=KoXjCF00?oXjCF0_l00006ok>hg@03o`000?nh_moo^;oO00?o^;oO
00?o0000ok_6h_nka^801?nka^800ol0003o_LkVokg>iP03okg>iP;o00001?nne^`00ol0003o^LGS
okW5h`02o`0000Ko]/CU1?l00006ok32j003o`000?nd[mCo]:oD00go]:oD0ol0000@okbYaP03o`00
0?o7[;koajbn00goajbn0ol0000?om:h`003o`000?oHa/Sof<K800Kof<K800?o0000olk7doo>am<0
1_o>am<01?l0003o_LKQo`000?l00002okg6h@CoX;SY00?o0000ogfSk?mmXn`00_mmXn`01?l0003o
FHcXoeV<j?mIS>P2oc]hh@?o00000_l0I]T00ol0003o05oDo`00000Pooooo`03o`000?oooooooooo
01[ooooo000Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003o
TYOEoi:Ge@04oi:Ge@03o`000?nFVMCoUYWD00GoUYWD00?o0000oibMe?nLWM@01OnLWM@00ol0003o
XjCFoj>TeP04oj>TeP03o`000?n[[][o000000Co/kSM00?o0000okRogonh_ml00_nh_ml2o`0000Go
^lKR0_l00005okg>iP03o`000?nne^co_]K/00Co_]K/0_l00006okK4i@?o00002_n``^P00ol0003o
]:oDokB_e00:okB_e0?o000000?o]:oDo`000?nlZLH04?nlZLH00ol0003oajbnolN/_P0>olN/_P04
o`000?oC];_o0000o`0000god[S00_l00008omS6b003o`000?o>am?oc/OC00Goc/OC0_l00002okg6
h@03o`000?nma^7o000000CoX;SY00?o0000ogfSk?mmXn`00_mmXn`4oeV<j0Co>gSQ0_l000001?l0
I]Wo0000o`1Oe?l0000Pooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04?ooool00ol0003oTYOEoi:Ge@04oi:Ge@03o`000?nFVMCoUYWD
00GoUYWD00?o0000oibMe?nLWM@01OnLWM@00ol0003oXjCFoj>TeP04oj>TeP05o`000?n[[][oZjkJ
oj^^f_l000000_nc^=d5okRog`03o`000?nka^;o^lKR00Co^lKR00?o0000okg>i_nmc^H00onmc^H2
o`0000Go_]K/0_l00002ok[Ll@04o`000?nfa>Go]/CUokK4i@;o00003On``^P00ol0003o]:oDokB_
e006okB_e0Wo000000?o_:W6o`000?l000001_l00007okbYaP03o`000?o7[;koajbn00koajbn00?o
0000om>d^ooC];/00_oC];/2o`0000[od[S000Co0000omg4`OoMa<7o00002?oHa/P00ol0003oc/OC
olk7d`03olk7d`03o`000?oAcmOo_LKQ00?o_LKQ00?o0000okg6hOl000000onP^>T00ol0003oOJ?/
ogfSk002ogfSk005o`000?mIS>SoFHcXoeV<j?l000000olkN>42obQ[f`?o000000?o05oDo`000?oo
ool07_ooool2o`0001[ooooo000Pooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
3_ooool2o`0000GoTYOE00?o0000oiJIe?nFVM@01OnFVM@00ol0003oW9gDoibMe005oibMe003o`00
0?nSY=KoXjCF00CoXjCF00?o0000oj^^f_n[[]X00on[[]X2o`0000Co^;oO00?o0000ok_6h_nka^80
0onka^82o`0000Go_LkV00?o0000okkFk?nne^`01?nne^`00ol0003o^]caok[Ll@02ok[Ll@?o0000
3_n``^P<o`0000Oo[Z[C00?o0000okVTa?niY<@01oniY<@:o`0000koajbn00?o0000om>d^ooC];/0
1?oC];/2o`0000Sod[S000Go0000omg4`OoMa<7ogLC1o`000008omS6b005o`000?o>am?oc/OColk7
dol000000ooAcmL4okg6h@;o00001?nP^>T01Ol0003oOJ?/ogfSk?mmXnco000000CoFHcX1?lkN>44
obQ[f`?o00007oooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo00gooooo0_mhQ=801Ol0003oTYOEoi:GeOnBUmGo000000OoUYWD00?o0000
oibMe?nLWM@01OnLWM@00ol0003oXjCFoj>TeP04oj>TeP03o`000?n[[][oZjkJ00CoZjkJ00?o0000
ok>ig_l000000_nh_ml6ok_6hP03o`000?nmc^Ko_LkV00Co_LkV00?o0000okkFk?nne^`00onne^`2
o`0000?o^]ca0_l00002ok;Rm`03o`000?n``^So/<;X00Oo/<;X1Ol00003ojJok003o`000?n^Z]?o
[Z[C00?o00002_n^Z]<00ol0003o^JC4okVTa00>okVTa003o`000?o5Z;coaJRl00?o00002oo7[;h0
0ol0003odkBkom>d^`06om>d^`;o00001OoB^<000ol0003ogLC1omg4`@03omg4`@03o`000?oHa/So
f<K800Kof<K800?o0000olk7dol000001?oAcmL01?l0003o_LKQokg6hOnma^42o`0000CoX;SY00?o
0000ogfSk?mmXn`00_mmXn`01Ol0003oFHcXoeV<j?mIS>So000000?o>gSQ00Co0000obQ[folXJm_o
:6_K0_lQI]T2o`0001oooooo00?o0000ooooooooool05oooool001oooooo0_l0000aooooo`03o`00
0?oooooooooo00_ooooo00Go0000ogR4d_mhQ=;oN8CBo`000002oi:Ge@OoUYWD00?o0000oibMe?nL
WM@01OnLWM@00ol0003oXjCFoj>TeP04oj>TeP03o`000?n[[][oZjkJ00CoZjkJ00Co0000ok>ig_nc
^Mko/kWN0_l00005ok_6hP03o`000?nmc^Ko_LkV00?o_LkV0_l00004okkFk0;o00001?njg?400ol0
003o/^;gok;Rm`03ok;Rm`04o`000?n``^So/<;Xok32j0Go00002?nV_n`3o`0000go[Z[C00?o0000
okVTa?niY<@03_niY<@00ol0003oaJRlolFX_003olFX_0?o00001oo7[;h00ol0003odkBkom>d^`09
om>d^`;o00000ooB^<000ol0003ogLC1omg4`@04omg4`@03o`000?oHa/Sof<K800Kof<K800?o0000
om7?eooAcmL01?oAcmL01?l0003o_LKQokg6hOnma^42o`0000CoX;SY00Go0000ogfSk?mmXncoOJ?/
o`000004oeV<j004o`000?lkN>7o>gSQoc]hh@Co:6_K0olQI]T00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
2_ooool00ol0003oN8CBogR4dP02ogR4dP03o`000?nFVMCoUYWD00GoUYWD00?o0000oibMe?nLWM@0
1OnLWM@00ol0003oXjCFoj>TeP04oj>TeP03o`000?n[[][oZjkJ00CoZjkJ00?o0000ok>ig_nc^Mh0
0_nc^Mh01?l0003o_<KSo`000?l00002ok_6hPKo_LkV00?o0000okkFk?nne^`00_nne^`2o`0000Co
^]ca0_l00006ok;Rm`Co00002_nV_n`3o`000003ojJok?l0003o[Z[C00go[Z[C00?o0000okVTa?ni
Y<@03_niY<@00ol0003oaJRlolFX_006olFX_0?o00001?o7[;h00ol0003odkBkom>d^`0;om>d^`;o
000000?od[S0o`000?oMa<401_oMa<400ol0003of<K8omS6b005omS6b003o`000?oAcmOodLoG00Co
dLoG00?o0000okg6hOnma^400_nma^400ol0003oX;SYoj2hj@02oj2hj@03o`000?mmXncoOJ?/00;o
OJ?/00Go0000oeV<j?mIS>SoFHcXo`000003oc]hh@04o`000?lXJm_o:6_KobQ[f`Co8FKI00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`007oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00Sooooo00?o0000ogR4d_mhQ=800omhQ=800ommQ];o0000oiJIe004oiJI
e003o`000?nLWMCoW9gD00KoW9gD00?o0000oj>Te_nSY=H00onSY=H00ol0003oZjkJoj^^fP04oj^^
fP03o`000?nc^Mko/kWN00;o/kWN00?o0000okc6honla^<00_nla^<2o`0000Go_LkV00Co0000okkF
k?nne^co_]K/0_l00004ok[Ll@;o00001_nbh_L2o`000003oj?So?l0003oY[o/00WoY[o/1ol00000
0on^Z]?o0000o`000005o`0000Ko[Z[C00?o0000okVTa?niY<@03_niY<@00ol0003oaJRlolFX_009
olFX_0?o000000?oajbno`000?oC];/03_oC];/00ol0003ogLC1omg4`@07omg4`@03o`000?oHa/So
f<K800?of<K800?o0000omkCc?l000001_oAcmL00ol0003o_LKQokg6h@02okg6h@05o`000?nP^>Wo
X;SYoj2hjOl000001?mmXn`00ol0003oFHcXoeV<j002oeV<j004o`000?lkN>7o>gSQo`0000?o:6_K
00Go0000ob5VfOlQI]Wo8FKIo`00000Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool01_ooool00ol0003oN8CBogR4dP03ogR4dP04o`00
0?mmQ];oOHKBo`0000?oUYWD00?o0000oibMe?nLWM@01_nLWM@00ol0003oXjCFoj>TeP03oj>TeP03
o`000?n[[][oZjkJ00CoZjkJ00?o0000ok>ig_nc^Mh00_nc^Mh00ol0003o_<KSokc6h`03okc6h`04
o`000?o3eNOo0000o`0000;o_LkV1?nne^`00ol0003o^]caok[Ll@02ok[Ll@;o00001_nbh_L2o`00
00CoXn?l00?o0000ojJok?nV_n`00_nV_n`7o`0000CoV;[`00?o0000ojJUeOnVYMD01_nVYMD7o`00
0003okVTa?l0003o000000co^JC400?o0000olFX_?o5Z;`03Oo5Z;`2o`0000oodkBk0_l00009omg4
`@05o`000?oHa/Sof<K8omS6b?l000000_oNdl`00ol0003odLoGom7?e`04om7?e`03o`000?nma^7o
_LKQ00;o_LKQ00?o0000oj2hjOnP^>T00_nP^>T00ol0003oOJ?/ogfSk002ogfSk005o`000?mIS>So
FHcXoeV<j?l000000olkN>401Ol0003o:6_KobQ[folXJm_o000000?o8FKI00?o0000ooooooooool0
6oooool3o`0001Kooooo000Oooooo`;o0000=Oooool2o`0000Kooooo00?o0000ogR4d_mhQ=800omh
Q=801Ol0003oOHKBogf6d_mmQ];o000000;oUYWD2?nLWM@00ol0003oXjCFoj>TeP03oj>TeP03o`00
0?n[[][oZjkJ00CoZjkJ00?o0000ok>ig_nc^Mh00_nc^Mh00ol0003o_<KSokc6h`03okc6h`03o`00
0?o3eNOo`mGW00;o`mGW0ol00002okkFk003o`000?njg?7o^]ca00;o^]ca00?o0000ok;Rmonbh_L0
0onbh_L3o`0000KoXn?l1ol00009oiRjl003o`000?nVYMGoYZGE00coYZGE00Co0000okBQa?ndXLCo
]:741Ol00007okVTa003o`000?o5Z;coaJRl00goaJRl00Co0000om:b^Ol0003o00003?oC];/01?l0
003ogl>komo3^ol00009omg4`@03o`000?oHa/So000000Cog]?<00?o0000om7?eooAcmL00ooAcmL0
0ol0003o_LKQokg6h@03okg6h@05o`000?nP^>WoX;SYoj2hjOl000001?mmXn`01Ol0003oFHcXoeV<
j?mIS>So000000?o>gSQ00Go0000obQ[folXJm_o:6_Ko`000003ob5Vf@03o`000?oooooooooo01go
oooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`02ooooo`03o`000?mhQ=;oN8CB00?oN8CB00?o0000ogf6d_mmQ]800ommQ]82o`0000OoW9gD
00?o0000oj>Te_nSY=H01?nSY=H00ol0003oZjkJoj^^fP03oj^^fP03o`000?nc^Mko/kWN00;o/kWN
00?o0000okc6honla^<00onla^<00ol0003o`mGWol?Ei`03ol?Ei`03o`000?o7hncoan?/00?o0000
0onjg?400ol0003o/^;gok;Rm`02ok;Rm`;o00001_nSho`3o`000004ohWMo_l0003o0000o`0000go
V;[`00?o0000ojJUeOnVYMD02onVYMD00ol0003o]:74okBQa006okBQa0Go00000_niY<@00ol0003o
aJRlolFX_00=olFX_004o`000?oB/[Wod[:iom:b^@;o00002_oC];/01Ol0003ogl>komo3^ooO`k_o
000000WogLC100?o0000omkCc?oNdl`00ooNdl`00ol0003odLoGom7?e`04om7?e`03o`000?nma^7o
_LKQ00;o_LKQ0_l00003oj2hj@05o`000?mmXncoOJ?/ogfSk?l000001?mIS>P01Ol0003o>gSQoc]h
hOlkN>7o000000?o:6_K00Co0000ob5VfOlQI]Wo00008?ooool00ol0003oooooooooo`0Cooooo`00
7_ooool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool000001OmhQ=800ol0003o
OHKBogf6dP03ogf6dP;oQXgC00?o0000oibMe?nLWM@00onLWM@00ol0003oXjCFoj>TeP04oj>TeP03
o`000?n[[][oZjkJ00?oZjkJ00?o0000ok>ig_nc^Mh00onc^Mh00ol0003o_<KSokc6h`02okc6h`03
o`000?o3eNOo`mGW00?o`mGW00Go0000olOSk?o7hncoan?/o`000002olO`kPCo00000onbh_L00ol0
003oXn?loj?So003oj?So0?o000000CoRMgno`000?l0003o00000_n9gOh00ol0003oV;[`oiRjl00;
oiRjl003o`000?nVYMGoYZGE00_oYZGE00?o0000okBQa?ndXL@02ondXL@4o`0000goaJRl00?o0000
om:b^OoB/[T01?oB/[T3o`0000KodkBk00?o0000omo3^ooO`k/00ooO`k/00ol0003ogLC1omg4`@06
omg4`@03o`000?oNdlcog]?<00Cog]?<00?o0000om7?eooAcmL00ooAcmL00ol0003o_LKQokg6h@02
okg6h@03o`000?nP^>Wo000000;oX;SY00?o0000ogfSk?mmXn`00_mmXn`01Ol0003oFHcXoeV<j?mI
S>So000000?o>gSQ00Go0000obQ[folXJm_o:6_Ko`000003ob5Vf@03o`000?oooooooooo01kooooo
00?o0000ooooooooool04_ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooool000001OmhQ=800ol0003oOHKBogf6dP03ogf6dP05o`00
0?n6SM?oQXgCohJ=dol000000onLWM@00ol0003oXjCFoj>TeP04oj>TeP03o`000?n[[][oZjkJ00?o
ZjkJ00?o0000ok>ig_nc^Mh00onc^Mh00ol0003o_<KSokc6h`02okc6h`03o`000?o3eNOo`mGW00?o
`mGW00Go0000olOSk?o7hncoan?/o`000003olO`kP04o`000?non>ko_oS^okohkPCo00000_nSho`3
o`000005ohWMo_l0003o0000o`000?n9gOh04ol000001?nVYMGo0000o`000?l00009ojJUe@03o`00
0?ndXLCo]:7400go]:7400?o0000ol:U_?l000000_l0000:olFX_003o`000?oB/[Wod[:i00Ood[:i
0_l00003om>d^`03o`000?oO`k_ogl>k00Gogl>k00?o0000omg4`OoMa<401?oMa<400ol0003oimG4
o`000005omkCc003o`000?oAcmOodLoG00CodLoG00Co0000okg6hOnma^7o_LKQ2ol00004oeV<j005
o`000?lkN>7o>gSQoc]hhOl000000olXJm/01?l0003o8FKIob5VfOl0000Pooooo`03o`000?oooooo
oooo01;ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0j
ooooo`03o`000?mhQ=;oN8CB00CoN8CB00?o0000ogf6d_mmQ]800ommQ]800ol0003oQXgCohJ=d`02
ohJ=d`03o`000?nLWMCo000000KoXjCF00?o0000oj^^f_n[[]X00on[[]X00ol0003o/kWNok>igP03
ok>igP03o`000?nla^?o_<KS00;o_<KS00?o0000ol?Eioo3eNL00oo3eNL01Ol0003oan?/olOSk?o7
hnco000000?oao3^00Go0000okohk_non>ko_oS^o`000003ojchj@_o00001_mTcOX00ol0003oQ;;c
ohBbl`09ohBbl`03o`000?nKX=OoVj3G00;oVj3G1ol00002ojJUe@03o`000?ndXLCo]:7400go]:74
00?o0000ol:U_?o2YK`00_o2YK`3o`0000OoaJRl00?o0000om:b^OoB/[T02OoB/[T2o`000003om>d
^ol0003ogl>k00Oogl>k00?o0000omg4`OoMa<400_oMa<401?l0003oimG4onOEa?l00006omkCc003
o`000?oAcmOodLoG00?odLoG00Go0000okg6hOl0003o0000okg7hP02oj>ci003o`000?nS/nCoXk?T
00CoRIkR1_l00003oc]hh@05o`000?lXJm_o:6_KobQ[fol000000olQI]T00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`004oooool01Ol@
413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0>_ooool00ol0003oN8CBogR4dP03
ogR4dP03o`000?mmQ];oOHKB00?oOHKB00?o0000ohJ=don6SM<01?n6SM<2o`0000GoXjCF00?o0000
oj^^f_n[[]X00on[[]X00ol0003o/kWNok>igP03ok>igP03o`000?nla^?o_<KS00;o_<KS00?o0000
ol?Eioo3eNL00oo3eNL01Ol0003oan?/olOSk?o7hnco000000?oao3^00Go0000okohk_non>ko_oS^
o`000002ojchj@;o000000CoS^oPo`000?l0003o00000_mUf]83o`000003ofC=n_l0003o000000Oo
00000_n4/_<00ol0003oQ;;cohBbl`05ohBbl`03o`000?nKX=OoVj3G00WoVj3G0ol0000>okBQa003
o`000?o2YKco`ZFl00Ko`ZFl0ol00004olFX_003o`000?oB/[Wod[:i00_od[:i00?o0000omo3^ooO
`k/02?oO`k/01Ol0003ogLC1omg4`OoMa<7o000000?oimG400?o0000omkCc?oNdl`00ooNdl`00ol0
003odLoGom7?e`03om7?e`;o00000onman801Ol0003oXk?Toj>ci?l0003oXk?T00GoRIkR1?maS=d3
o`000003oc]hhOl0003o:6_K00;o:6_K00Go0000ob5VfOlQI]Wo8FKIo`00000Oooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o0000>_ooool00ol0003oN8CBogR4dP04ogR4dP03o`000?mmQ];oOHKB00?oOHKB00?o
0000ohJ=don6SM<01?n6SM<2oi6HeP05o`000?nSY=KoXjCFoj>Te_l000001On[[]X00ol0003o/kWN
ok>igP03ok>igP03o`000?nla^?o_<KS00;o_<KS00?o0000ol?Eioo3eNL00oo3eNL01Ol0003oan?/
olOSk?o7hnco000000?oao3^00Ko0000okohk_non>ko_oS^o`000?n/n>T6o`000005ofGJd_l0003o
0000o`000?lc^/801_l00006ocF`kP03o`000?mWY?CoIjCd00Ko00000_n4/_<00ol0003oVj3Goi^P
e`0:oi^Pe`03o`000?n^WLKo[Yg600?o00002OndXL@00ol0003o`ZFlol:U_009ol:U_0Co00003_oB
/[T2o`0000[ogl>k00?o0000omg4`Ol000001?oWeL@00ol0003og]?<omkCc004omkCc003o`000?oA
cmOodLoG00;o000000?od]OLo`000?nman800_nman801?l0003oXk?Toj>ci?nS/n@2o`0000CoRIkR
1OmaS=d2oemmf@03o`000?lkN>7o000000?o:6_K00Co0000ob5VfOlQI]Wo00008Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0jooooo`03o`000?mhQ=;oN8CB00?oN8CB00?o0000ogf6d_mm
Q]800ommQ]800ol0003oQXgCohJ=d`04ohJ=d`07o`000?nAV=KoTISFoi6He_l0003oXjCFo`000005
oj^^fP03o`000?nc^Mko/kWN00?o/kWN00?o0000okc6honla^<00onla^<00ol0003o`mGWol?Ei`02
ol?Ei`05o`000?o7hncoan?/olOSk?l000000oo7l>h00ol0003o_oS^okohkP02o`000005ojchjOl0
003o0000o`000?n>kn005_l00007ofNTm0?o00003?nKX=L00ol0003o[Yg6ojjMaP03ojjMaPCo0000
1OndXL@00ol0003o`ZFlol:U_00<ol:U_0;o00003?oB/[T01?l0003ohL6ion71^Ol0000:omo3^`03
o`000?oWeLCoimG400CoimG400?o0000omkCc?oNdl`00ooNdl`00ol0003odLoGo`000003om;Gg005
o`000?nman;o_LORokg7h_l000000onS/n@2o`0000CoRIkR00?o0000og6<gOmaS=d00_maS=d4oemm
f@05o`000?lXJm_o:6_KobQ[fol000000olQI]T00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool001?ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo03Wooooo00?o0000ogR4d_mhQ=801?mhQ=800ol0003oOHKBogf6dP03
ogf6dP03o`000?n6SM?oQXgC00CoQXgC00?o0000oi6He_nAV=H00_nAV=H2o`0000CoZjkJ00?o0000
ok>ig_nc^Mh01?nc^Mh00ol0003o_<KSokc6h`02okc6h`03o`000?o3eNOo`mGW00;o`mGW00Go0000
olOSk?o7hncoan?/o`000003olO`kP03o`000?non>ko_oS^017o00000_o8knh01Ol0003oVN3moiWP
oOl0003oVN3m00Oo00002?mWY?@00ol0003oS9WKohbIf`03o`0000OoVj3G00?o0000ojjMa_n^WLH0
1on^WLH3o`000003okBQa?l0003o`ZFl00ko`ZFl00Co0000om6`^Ol0003o00002_oB/[T01Ol0003o
hL6ion71^OoQ`KWo000000Wogl>k00?o0000onOEa?oWeL@01OoWeL@00ol0003og]?<omkCc003omkC
c003o`000?oBemcod]OL00;od]OL00Go0000okg7h_nman;o_LORo`000004oj>ci003o`000?n9W^;o
RIkR00;oRIkR00?o0000og6<gOmaS=d00_maS=d00ol0003oGggIoemmf@02oemmf@;o00000_lXJm/0
1?l0003o8FKIob5VfOl0000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo00?o
0000ogR4d_mhQ=801?mhQ=800ol0003oOHKBogf6dP03ogf6dP03o`000?n6SM?oQXgC00CoQXgC00?o
0000oi6He_nAV=H00onAV=H01_l0003oWZGJo`000?l0003oZjkJo`0000Ko/kWN00?o0000okc6honl
a^<00_nla^<00ol0003o`mGWol?Ei`02ol?Ei`05o`000?o7hncoan?/olOSk?l000000oo7l>h00ol0
003o_oS^o`000005o`000003ok_mc_l0003oXOC700;o000000KocooCo`000?l0003o0000omk`g?l0
0004olS_kP?o00000_nacNh00ol0003oMkGiogNen@05o`000004od6?kol0003o0000o`0000?oIjCd
00?o0000ohbIfon<VM/00on<VM/3o`0000CoVj3G00?o0000ojjMa_n^WLH02_n^WLH3o`0000go`ZFl
00?o0000om6`^OoA/;T00_oA/;T2o`0000Sod[:i00?o0000on71^OoQ`KT00_oQ`KT00ol0003ogl>k
omo3^`05omo3^`03o`000?o[e[ko000000KoimG400?o0000omkCc?oNdl`00_oNdl`2o`0000Cod]OL
00Go0000okg7h_nman;o_LORo`000004oj>ci0;o00000on9W^800ol0003oLHcMog6<g@02og6<g@03
o`000?mOOMWoGggI00;oGggI0_mCM=H00ol0003o:6_Ko`000002ob5Vf@03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`004oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_l0000iooooo`03o`000?mhQ=;oN8CB00CoN8CB00?o0000ogf6d_mm
Q]800ommQ]800ol0003oQXgCohJ=d`04ohJ=d`03o`000?nAV=KoTISF00;oTISF00?o0000oijUf_nN
YMX00_nNYMX2o`0000Go/kWN00?o0000okc6honla^<00_nla^<00ol0003o`mGWol?Ei`02ol?Ei`05
o`000?o7hncoan?/olOSk?l000000oo7l>h3o`000004okohk_l0003ocOoEo`0000;o^og>0ol00002
olood`;o00000ooNl=`00ol0003ob>o^olS_kP02o`000003olkBgOl0003o/Lg^00?o/Lg^00Co0000
ogNenOmg]OWoMkGi1?l00003od6?k`?o000000?oIjCdo`000?n<VM/01_n<VM/3o`000003oi^Peol0
003o[Yg600co[Yg600?o0000okjS__l000000_l0000:ol:U_003o`000?oA/;WodK2i00CodK2i0_l0
0005om:b^@03o`000?oQ`KWohL6i00CohL6i00?o0000omo3^ooO`k/01?oO`k/00ol0003ojmJno`00
0007onOEa006o`000?oNdlcog]?<o`000?oRhM?o00001?oBem`01Ol0003o_LORokg7h_nman;o0000
00CoXk?T00?o0000ohVNh_l000000_n9W^800ol0003oLHcMog6<g@02og6<g@03o`000?mOOMWoGggI
00;oGggI1?mCM=H01Ol0003o8FKIob5VfOlQI]Wo0000027ooooo0_l00007ooooo`03o`000?oooooo
oooo00Gooooo000Mooooo`03o`000?oooooooooo03Oooooo0_l00005ogR4dP03o`000?mmQ];oOHKB
00?oOHKB00?o0000ohJ=don6SM<01?n6SM<00ol0003oTISFoi6HeP03oi6HeP03o`000?nNYM[oWZGJ
00;oWZGJ00?o0000ojfegol000000_l000000onc^Mko0000okc6h`03okc6h`03o`000?o3eNOo`mGW
00;o`mGW00Ko0000olOSk?o7hncoan?/o`000?o7l>h6o`0000;ocOoE00?o0000ok_mc_nkoLh00_l0
00000ooMo/go0000olood`02o`0000Gog_3L0_l00004olkBg@03o`000?nacNko/Lg^00;o/Lg^00Co
0000ogNenOmg]OWoMkGi1_l00003od6?k`;o00002_n<VM/2o`0000go[Yg600?o0000okjS__nnXkh0
0_nnXkh3o`0000Ko`ZFl00?o0000om6`^OoA/;T01ooA/;T2o`0000?od[:i00?o0000on71^OoQ`KT0
1OoQ`KT00ol0003ogl>komo3^`02omo3^`05o`000?o[e[kojmJnon_F__l000001_oWeL@00ol0003o
g]?<o`000002on;Qd`03o`000?oBemcod]OL00;od]OL00?o0000okg7h_nman800_nman800ol0003o
Xk?Toj>ci002oj>ci0;o00000_n9W^800ol0003oLHcMog6<g@02og6<g@03o`000?mOOMWoGggI00;o
GggI00?o0000oe=de_mCM=H00_mCM=H2o`000003ob5VfOl0003ooooo01oooooo00?o0000ooooool0
00001Oooool00omEEEGoIVIVo`000007ooooo`007Oooool00ol0003oooooooooo`0gooooo`;oCVkB
00?o0000ogR4d_mhQ=800_mhQ=800ol0003oOHKBogf6dP03ogf6dP03o`000?n6SM?oQXgC00CoQXgC
00?o0000oi6He_nAV=H00_nAV=H00ol0003oWZGJoijUfP02oijUfP03o`000?n]]Moo[KGO00?o[KGO
0ol00002okc6h`03o`000?o3eNOo`mGW00;o`mGW00?o0000olOSk?o7hn`00_o7hn`5o`0000;oe_gL
00?o0000olgoeOl000000_nkoLh02?l0003ogOk=omgncOl0003ocooCo`000?oXkM3o00001OoNl=`0
0ol0003oc];MolkBg@04olkBg@03o`000?nacNko/Lg^00[o000000?o4g;Qo`000?l000000_m1Snl0
0ol0003oMhoNo`000002o`0000OoS9WK00?o0000ojBIbOl000000_l00009ojjMaP03o`000?nnXkko
_Z>n00Go_Z>n0_l00004ol:U_003o`000?oA/;WodK2i00WodK2i0_l000000ooB/[Wo0000on71^@07
on71^@04o`000?oO`k_ogl>ko`0000CojmJn00?o0000onOEa?oWeL@01OoWeL@01Ol0003oh^7Con;Q
dooRhM?o000000Cod]OL00?o0000okg7h_nman800_nman800ol0003oXk?Toj>ci002oj>ci005o`00
0?n9W^;o0000ohVNh_l000001?maS=d00ol0003oGggIoemmf@02oemmf@03o`000?mCM=KoDgCF00;o
DgCF0_m>LMD00ol0003o8FKIo`00000Rooooo`03o`000?oooooooooo00cooooo000Looooo`03o`00
0?oooooooooo03Sooooo0om>K]801?l0003oN8CBogR4d_l00005ogf6dP03o`000?n6SM?oQXgC00Co
QXgC00?o0000oi6He_nAV=H00onAV=H00ol0003oWZGJoijUfP02oijUfP03o`000?n]]Moo[KGO00?o
[KGO00?o0000okc7h_nlan803Ol00002omSeh@07o`000?oFoMcoe_gLo`000?o=omGo0000ok_mcP02
o`0000?ogOk=0_l00003onS]d007o`000?oNl=cog_3Lomk`g?l0003og=;?o`000006olkBg@;o0000
0on/]=l01?l0003oOjG[ognUjomoYN/4o`0000;o4g;Q0_l000000om1Snoo0000ogN?gP02ogN?gP;o
00001On<VM/00ol0003oY9W9ojBIb@02ojBIb@?o00001On^WLH00ol0003o_Z>nokjS_P08okjS_P?o
000000?o`ZFlo`000?oA/;T03?oA/;T00ol0003ohL6ion71^@08on71^@03o`000?oO`k_o000000Go
jmJn00?o0000onOEa?oWeL@00ooWeL@2o`0000?oh^7C00?o0000om;Gg?oBem`00_oBem`00ol0003o
_LORokg7hP02okg7hP03o`000?nS/nCoXk?T00;oXk?T00?o0000ohVNh_n9W^800_l00004og6<g@03
o`000?mOOMWoGggI00;oGggI00?o0000oe=de_mCM=H00_mCM=H3odiae@;o00008Oooool3o`0000go
oooo000Looooo`03o`000?oooooooooo03Sooooo1?m>K]800ol0003oN8CBo`000005ogf6dP03o`00
0?n6SM?oQXgC00?oQXgC00?o0000oi6He_nAV=H00onAV=H00ol0003oWZGJoijUfP02oijUfP03o`00
0?n]]Moo[KGO00?o[KGO00?o0000okc7h_nlan800_nlan800ol0003obMSUolWHi@02olWHi@?o0000
00?odnSTo`000?oHmN400_oHmN401?l0003oe_gLomKmg?l00002olgoe@;o000000?oiO_:o`000?oM
o/d00_oMo/d00ol0003oj>g@onS]d002onS]d004o`000?oNl=cog_3Lo`0000?og=;?00Go0000olkB
gOo>d]goc];Mo`000002ol>id@03o`000?n/]=oo[;CO00;o[;CO00Co0000ognUjomoYN_oOjG[0ol0
00001?l0Cl[o0000oa=bhOlCL^42o`0000GoMhoN0_l00003ohbIf`03o`000?nTVLWoY9W900GoY9W9
0_l00003ojjMaP03o`000?nnXkko_Z>n00_o_Z>n0_l0000=om6`^@;o00002_oQ`KT00ol0003ojmJn
on_F_P04on_F_P03o`000?oWeLCoimG400;oimG400?o0000oncXb_l000000ooRhM<00ol0003od]OL
om;Gg002om;Gg003o`000?nman;o_LOR00;o_LOR00?o0000oj>ci?nS/n@00_nS/n@00ol0003oRIkR
ohVNhP02o`0000CoLHcM00?o0000oemmfOmOOMT00_mOOMT00ol0003oDgCFoe=deP02oe=deP05o`00
0?m>LMGoCW7EodiaeOl000007_ooool3o`0000;ooooo00?o0000ooooooooool02oooool001cooooo
0_l0000iooooo`GoCVkB00?o0000ogf6d_mmQ]800ommQ]800ol0003oQXgCohJ=d`04ohJ=d`03o`00
0?nAV=KoTISF00?oTISF00?o0000oijUf_nNYMX00_nNYMX00ol0003o[KGOojfeg`03ojfeg`05o`00
0?nlan;o_<ORokc7h_l000000_o9f>D3o`0000?odnST00Go0000omSehOoHmN7of?GQo`000003omKm
g003o`000?o=omGo000000;oiO_:00?o0000omgncOoMo/d00_l00005onS]d003o`000?oNl=co0000
00Gog=;?00?o0000olkBgOl000001?o3^M400ol0003o[;COojbdg`02ojbdg`03o`000?moYN_oOjG[
00Co000000?o04o:o`000?l000000_lCL^400ol0003oMhoNogN?gP04ogN?gPCo00002OnTVLT4o`00
00go_Z>n00?o0000olj_^_l000002ooA/;T01?l0003oh<6ion31^Ol00009on71^@03o`000?o[e[ko
jmJn00GojmJn00Co0000onOEa?oWeLCo00000_o/j<X00ol0003oh^7Con;Qd`02on;Qd`05o`000?oB
emcod]OLom;Gg?l000001?nman800ol0003oXk?Toj>ci002oj>ci005o`000?n9W^;oRIkRohVNh_l0
00001?maS=d00ol0003oGggIoemmf@02oemmf@03o`000?mCM=KoDgCF00;oDgCF00?o0000odiaeOm>
LMD00_m>LMD00ol0003oooooooooo`0Hooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`00
7?ooool00ol0003oooooooooo`0hooooo`03o`000?m>K];oCVkB00;oCVkB00?oEW;Co`000?mmQ]80
0ommQ]800ol0003oQXgCohJ=d`03ohJ=d`03o`000?nAV=KoTISF00?oTISF00?o0000oijUf_nNYMX0
0_nNYMX00ol0003o[KGOojfeg`03ojfeg`03o`000?nlan;o_<OR00;o_<OR0ol00002olWHi@05o`00
0?oCj>CodnSTom?Xi?l000000ooHmN400ol0003oe_gLomKmg003o`0000?oiO_:00Go0000omgncOl0
003okNW8o`000005onS]d0;o00001ooLd/l00ol0003o`kWAol>id@04ol>id@04o`000?n/]=oo[;CO
ojbdg`?o00000_meT^400ol0003o;W3No`000002o`1?bP?o000000?oEh7Oo`000?l000001_mgSmh0
0ol0003oY9W9ojBIb@0:ojBIb@;o00003?nnXkh00ol0003ocZnjolj_^P02o`0000WodK2i00Go0000
on31^OoP`KWoh<6io`000007on71^@03o`000?o^ek_o000000KojmJn00?o0000onOEa?l000000oo/
j<X00ol0003oh^7Con;Qd`02on;Qd`05o`000?oBemcod]OLom;Gg?l000001?nman800ol0003oXk?T
oj>ci002oj>ci004o`000?n9W^;oRIkRohVNhP;o00000omaS=d00ol0003oGggIoemmf@02oemmf@03
o`000?mCM=KoDgCF00;oDgCF00?o0000odiaeOm>LMD00_m>LMD00ol0003oooooooooo`0Eooooo`?o
00002?ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0hooooo`03o`00
0?m>K];oCVkB00;oCVkB0_mFL]<01?l0003oOHKBogf6d_l00006ohJ=d`03o`000?nAV=KoTISF00;o
TISF00?o0000oijUf_nNYMX00onNYMX00ol0003o[KGOojfeg`03ojfeg`03o`000?nlan;o000000;o
00001?o9f>D01Ol0003odnSTom?Xi?oCj>Co000000?of?GQ00?o0000omKmg?oFoM`00_l000000ooY
n<co0000onGkbP02onGkbP;o00000oo]jLP01ol0003oj>g@onS]d?oXkM3o0000on?Aa_l000001ooL
d/l2o`0000Ko`kWA00?o0000ojbdgol000000onMXML3ogFBh@04o`000?l^L=ko0000o`0000;o04o:
0_l00002oeN1g`03o`000?mgSmkoMhoN00?oMhoN00Co0000oiNDcol0003o00002OnTVLT01?l0003o
]j31o`000?l00009okjS_P03o`000?o>[k[ocZnj00?ocZnj0_l00006om6`^@03o`000?oP`KWoh<6i
00?oh<6i00?o0000on71^OoQ`KT01?oQ`KT00ol0003ok]Nko`000007on_F_P03o`000?o/j<[ok>S:
00;ok>S:00?o0000on;QdooRhM<00_oRhM<01Ol0003od]OLom;Gg?oBemco000000Co_LOR00?o0000
oj>ci?nS/n@00_nS/n@01ol0003oRIkRohVNh_n9W^;o0000og6<gOl000000_maS=d00ol0003oGggI
oemmf@02oemmf@03o`000?mCM=KoDgCF00;oDgCF00?o0000odiaeOm>LMD00_m>LMD00ol0003ooooo
ooooo`0Aooooo`Co00002oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003ooooooooo
o`0hooooo`03o`000?m>K];oCVkB00;oCVkB0omFL]<00ol0003oOHKBo`000005ohJ=d`03o`000?nA
V=KoTISF00?oTISF00?o0000oijUf_nNYMX00_nNYMX00ol0003o[KGOojfeg`03ojfeg`?o00000_nl
an801Ol0003obMSUolWHiOo9f>Go000000?odnST00Go0000omSehOoHmN7of?GQo`000003omKmg004
o`000?oYn<cojOS<o`0000;oiO_:0_l00004ongYb004o`000?oXkM3oj>g@o`0000?ohm7600?o0000
omcBcooLd/l00ooLd/l01?l0003ock[6olnja_l00006ol>id@03o`000?nMXMOoWJ7G00?oWJ7G00Go
0000ogFBhOmeT^7o0000obi`gP03o`000003o`1?b_l0003oEh7O00;oEh7O0_l00003ogN?gP04o`00
0?nGU<ooUiC?oiNDc`;o00001_nTVLT00ol0003o]j31okNP`@02okNP`@;o00001onnXkh00ol0003o
cZnjolj_^P05olj_^P03o`000?oA/;WodK2i00?odK2i00?o0000on31^OoP`KT01?oP`KT00ol0003o
hL6ion71^@02on71^@05o`000?o^ek_ok]NkonkG^ol000001_o[e[h00ol0003ok>S:oncXbP02oncX
bP03o`000?oRhM?oh^7C00;oh^7C00Go0000om;Gg?oBemcod]OLo`000002okg7hPWo00000_n9W^80
0ol0003oLHcMo`000002og6<g@03o`000?mOOMWoGggI00;oGggI00?o0000oe=de_mCM=H00_mCM=H0
0ol0003oCW7Eodiae@02odiae@03o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000odi^d_m>K]800_m>K]84oeIb
d`;o00001On6SM<00ol0003oTISFoi6HeP02oi6HeP03o`000?nNYM[oWZGJ00?oWZGJ00?o0000ojfe
gon]]Ml01?l00003okc7hP03o`000?o9f>GobMSU00;obMSU00Go0000om?Xi?oCj>CodnSTo`000003
omSeh@04o`000?oFoMcoe_gLo`0000?ojOS<00Co0000onGkb_oUnl[o00001Oo]jLP00ol0003oj>g@
o`000005on?AaP05o`000?oLd/oog=;?omcBcol000001?o?^/H00ol0003o`kWAol>id@03ol>id@;o
00001OnMXML01ol0003oMI;QogFBhOl0003o;W3No`000?l0;:h00_l000000ol/Jm_o0000oeN1g`02
oeN1g`;o000000?oMhoNo`000?nGU<l01?nGU<l00ol0003oY9W9ojBIb@03ojBIb@03o`000?ngX<7o
]j3100Co]j310_l00005okjS_P03o`000?o>[k[ocZnj00KocZnj0_l00002om6`^@03o`000?oP`KWo
h<6i00Koh<6i00Co0000on71^OoQ`KWo00001Oo^ek/00ol0003ojmJnon_F_P02on_F_P;o00001?o/
j<X00ol0003oh^7Con;Qd`02on;Qd`03o`000?oBemcod]OL00Co00000_nman800ol0003oZ;;OojRb
g`02ojRbg`03o`000?nFWm[o000000;o00000_maS=d00ol0003oLHcMo`000004oemmf@03o`000?mC
M=KoDgCF00;oDgCF00?o0000odiaeOm>LMD00_m>LMD00ol0003oooooooooo`0;ooooo`?o00004ooo
ool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0iooooo`05o`000?m>K];o
CVkBodi^d_l000001?mFL]<2ofAmeP;o00000_n6SM<00ol0003oTISFoi6HeP03oi6HeP03o`000?nN
YM[oWZGJ00?oWZGJ0ol00002ojfeg`03o`000?nlan;o_<OR00;o_<OR00Go0000olWHiOo9f>GobMSU
o`000003om?Xi006o`000?oHmN7of?GQomSehOl0003oe_gL0_l00004onWhc004o`000?oUnl[oiO_:
o`0000KokNW800?o0000on?Aa_oSdLH01OoSdLH00ol0003og=;?o`000006olnjaP05o`000?o3^M7o
`kWAol>idOl000000_ncY/`00ol0003oWJ7GoifQe`03oifQe`03o`000?meT^7o000000?o000000Go
02b^o`000?l0003o;6_Ko`000004oeN1g`;o00001_nGU<l2o`0000?oY9W900?o0000okNP`OngX<40
1_ngX<42o`0000?o_Z>n00?o0000olj_^_o>[kX02?o>[kX00ol0003odK2io`000009on31^@03o`00
0?oQ`KWo000000Gok]Nk00Oo0000on_F__o[e[kojmJno`000?oak<;o000000Cok>S:00?o0000on;Q
dooRhM<00_oRhM<3o`000003om3Lh_l0003o_LOR00;o_LOR00?o0000ojRbgonX/]l00_nX/]l00ol0
003oUYoJoiJOfP02oiJOfP;o00000_maS=d2o`0000CoGggI00?o0000oe=de_mCM=H00_mCM=H00ol0
003oCW7Eodiae@02odiae@03o`000?oooooooooo00Oooooo1?l0000Fooooo`03o`000?oooooooooo
00[ooooo000Kooooo`;o0000>Oooool00ol0003oCVkBodi^dP02odi^dP03o`000?mFL]?oEW;C00;o
EW;C1?mTOMH00ol0003oQXgCo`000004oi6HeP04o`000?nNYM[oWZGJoijUfP?o00001On]]Ml01Ol0
003o_<ORokc7h_nlan;o000000CobMSU00Go0000om?Xi?oCj>CodnSTo`000003omSeh@;o000000?o
j???o`000?oYn<`00_oYn<`01_l0003oiO_:onGkb_l0003oknK4o`0000GokNW800?o0000on?Aa_oS
dLH01_oSdLH00ol0003ock[6olnjaP06olnjaP03o`000?o3^M7o000000Co/jK<00?o0000oifQeonM
XML00onMXML00ol0003oGH3Lo`000002oaUNe003o`000?l0;:ko000000;o;6_K0_l00003oeN1g`03
o`000?nGU<ooUiC?00KoUiC?0ol0000;okNP`@?o00003?o>[kX2o`0000[oh<6i00?o0000onkG^oo^
ek/01Oo^ek/01_l0003ojmJnon_F__l0003olNc2o`0000Cok>S:00Co0000on;QdooRhM?oh^7C0_l0
0003om3LhP05o`000?nman;o_LORokg7h_l000001?nX/]l00ol0003oUYoJoiJOfP02oiJOfP;oQY3F
1?l00004oemmf@03o`000?mCM=KoDgCF00;oDgCF00?o0000odiaeOm>LMD00_m>LMD00ol0003ooooo
ooooo`04ooooo`?o00006_ooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003ooooooooo
o`0hooooo`03o`000?m>K];oCVkB00;oCVkB00?o0000oeIbdomFL]<00_mFL]<5ofAmeP;o00001?nA
V=H4o`0000;oWZGJ00?o0000ojfegon]]Ml00_n]]Ml00ol0003o_<ORokc7hP02okc7hP05o`000?o9
f>GobMSUolWHiOl000000ooCj>@01Ol0003of?GQomSehOoHmN7o000000?oj???00Oo0000onWhc?oY
n<cojOS<o`000?oUnl[o000000;oknK400?o0000ongYb?o]jLP00_o]jLP00ol0003oi/o0o`000007
on?AaP;o00002?o?^/H00ol0003o/jK<ok>Vc004ok>Vc00:o`000?nMXMOoWJ7GoifQeol0003oQi7F
o`000?mMP=co0000oaUNe0?o000000Go04c;oba[fol/Jm_o;6_Ko`000002oeN1g`04o`000?n2S=Go
0000o`0000OoUiC?00?o0000okNP`OngX<402ongX<42o`0000_ocZnj00?o0000omk0^ol000002OoP
`KT00ol0003ok]NkonkG^`05onkG^`03o`000?o[e[ko000000;olNc200?o0000oncXb_o/j<X00_o/
j<X01_l0003oh^7Co`000?l0003og^gLo`0000;od=cR00?o0000okg7h_nman800_nman800ol0003o
Z;;OojRbg`02ojRbg`03o`000?nFWm[oUYoJ00;oUYoJ1On6T=H2o`0000?oGggI00?o0000oe=de_mC
M=H00_mCM=H00ol0003oCW7Eodiae@02odiae@04o`000?ooooooooooooooo`?o00007Oooool00ol0
003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`000?m>K];oCVkB00;o
CVkB00?o0000oeIbdomFL]<00_mFL]<00ol0003oI7gFofAmeP02ofAmeP;oN8gK00?o0000oi6He_l0
00000_l00004oijUfP03o`000?n]]Moo[KGO00?o[KGO00?o0000okc7h_nlan800_nlan801Ol0003o
bMSUolWHiOo9f>Go000000;odnST00?o0000omSehOoHmN400_l00004onScc`04o`000?oYn<cojOS<
onWhc0;o00001?o_i/@01?l0003okNW8ongYb?l00003onK?`003o`000?oSdLKohm7600?ohm7600Co
0000omFj_ooE^[oo00001oo?^/H00ol0003o_jW3o`000005ok>Vc003o`000?nMXMOo000000?oQi7F
00Co0000oef0g?l0003o6EkD0ol000001ol0C<_o0000oba[fol/Jm_o0000oeN1gol000000on2S=D0
0ol0003oUiC?oiNDc`04oiNDc`04o`000?n]WLOo0000o`0000[o]j3100Co0000olR]__l0003o0000
2?o>[kX01Ol0003og/2komk0^ooN`;_o000000Ooh<6i00?o0000onkH^ol000001oo^ek/00ol0003o
lNc2oo7/`P02oo7/`P04o`000?o/j<[ok>S:oncXbP;o00000ooNkM`01?l0003od=cRom3Lh_l00003
okg7hP03o`000?nX/]ooZ;;O00;oZ;;O00?o0000oiJOf_nFWmX00_nFWmX00ol0003oQY3FohJ@eP03
ohJ@eP06og^5d_l0003o0000o`000?mOOMWo00001?mCM=H00ol0003oCW7Eodiae@02odiae@Co0000
8?ooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`000?m>
K];oCVkB00;oCVkB00Go0000oeIbdomFL]?oEW;Co`000005ofAmeP06ogR=fol0003o0000o`000?nA
V=Ko00001OnNYMX00ol0003o[KGOojfeg`02ojfeg`03o`000?nlan;o_<OR00;o_<OR00Go0000olWH
iOo9f>GobMSUo`000003om?Xi0?o000000?oiNgEo`000?oXlll00ooXlll01Ol0003ojOS<onWhc?oY
n<co000000GoknK400Co0000ongYb?o]jLSo00001?oVcl001Ol0003ohm76on?Aa_oSdLKo000000Co
eKZo00?o0000olnja_o?^/H00oo?^/H01Ol0003o_jW3oknY`onoZL?o000000Go/jK<0_l00004ohNA
eP04o`000?mMP=co0000oaUNe0;o00000_l0C</00ol0003o;6_Koba[f`02o`0000CoPXcE0_l00004
oiNDc`04o`000?n]WLOo[Ig7ojfMa`;o00001ongX<400ol0003ob:fnolR]_P02olR]_P03o`000?o>
[k[ocZnj00GocZnj00?o0000omk0^ooN`;/00_oN`;/00ol0003oh<6ion31^@04on31^@04o`000?o^
f;_ok]Rko`0000Kok]Nk00?o0000oo7/`_oak<800_oak<801Ol0003ok>S:oncXb_o/j<[o000000?o
g^gL00Go0000om3Lh_o@g>;od=cRo`000003okg7hP03o`000?nX/]ooZ;;O00;oZ;;O00?o0000oiJO
f_nFWmX00_nFWmX00ol0003oQY3FohJ@eP02ohJ@eP05o`000?mkQM;oNhGBo`000?mkQM800_l00004
oe=deP03o`000?m>LMGoCW7E00;oCW7E00?o0000ooooooooool08Oooool00ol0003oooooooooo`0:
ooooo`006_ooool3o`0003Wooooo00?o0000odi^d_m>K]800_m>K]801Ol0003oEW;CoeIbdomFL]?o
000000CoI7gF0_l00003ogR=f`;o00001?nNYMX00ol0003o[KGOojfeg`03ojfeg`03o`000?nlan;o
_<OR00;o_<OR00Co0000olWHiOo9f>Go00000_oCj>@2o`0000CoiNgE00Go0000onSccooXllooj???
o`000003onWhc0;o00001Oo_i/@00ol0003okNW8o`000005onK?`005o`000?oSdLKohm76on?Aa_l0
00001OoE^[l01Ol0003ock[6olnja_o?^/Ko000000Go_jW300?o0000ok>Vc?ncY/`00_ncY/`00ol0
003oX9S=o`000004ohNAeP04o`000?mMP=co0000oaUNe0;o00000_l0C</01?l0003o;6_Koba[fol0
0006oh:<e@;o000000?oUiC?o`000?n]WLL01On]WLL00ol0003o]j31okNP`@04okNP`@03o`000?o8
[Kkob:fn00?ob:fn0_l00004olj_^P03o`000?oN`;_og/2k00Cog/2k00?o0000on31^OoP`KT00_oP
`KT01Ol0003ok]RkonkH^oo^f;_o000000Gok]Nk0_l00004oo7/`P03o`000?o/j<[ok>S:00;o0000
0ooNkM`01?l0003od=cRom3Lh_l00004okg7hP03o`000?nX/]ooZ;;O00;oZ;;O00?o0000oiJOf_nF
WmX00_nFWmX00ol0003oQY3FohJ@eP02ohJ@eP06o`000?mkQM;oNhGBog^5d_l0003oNhGB0_l00003
oe=deP03o`000?m>LMGoCW7E00;oCW7E00?o0000ooooooooool08_ooool00ol0003oooooooooo`09
ooooo`006_ooool00ol0003oooooooooo`0iooooo`03o`000?m>K];oCVkB00;oCVkB00Ko0000oeIb
domFL]?oEW;Co`000?mTOMH3o`000003ofAme_mhSM_oN8gK00;oN8gK0_n?X=l3o`000003oijUf_l0
003o[KGO00?o[KGO00?o0000okc7h_nlan800_nlan801?l0003obMSUolWHiOo9f>D3o`000003omcS
f_l0003oiNgE00?oiNgE00Go0000onSccooXllooj???o`000002onWhc003o`000?o^hlCo000000Ko
knK400?o0000onK?`?oVcl001OoVcl000ol0003ohm76o`000007omFj_`03o`000?o?^/Ko000000Oo
_jW300Co0000ok>Vc?ncY/co00000onPV<d00ol0003oQi7FohNAeP02ohNAeP03o`000?mMP=co0000
00?o00000_l0C</01Ol0003o;6_Ko`000?mQOm[o000000KoPXcE0_l00007ojfMa`;o00000ongX<40
0ol0003ob:fnolR]_P06olR]_P;o00000_o>[kX00ol0003og/2komk0^`05omk0^`04o`000?oP`KWo
h<6io`0000Gok]Rk00Oo0000onkG^oo^ek_ok]Nko`000?ockkko000000ColNc200Go0000oncXb_l0
003oiOSBo`000003omk]g004o`000?o@g>;od=cRo`0000?o_LOR00?o0000ojRbgonX/]l00_nX/]l0
0ol0003oUYoJoiJOfP02oiJOfP03o`000?n6T=KoQY3F00?oQY3F00Ko0000og^5d_mkQM;oNhGBo`00
0?mkQM82og=od004o`000?mCM=KoDgCFo`0000CoCW7E00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`09ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Wooooo00?o0000odi^d_m>K]800_m>K]800ol0
003oEW;CoeIbd`03o`0000?oI7gF00?o0000ogR=fomhSM/00_mhSM/5ohnPg`Co00000_n]]Ml00ol0
003o_<ORokc7hP02okc7hPCo00001?oLhmX00ol0003oiNgEonG]e@02onG]e@07o`000?oXllooj???
onSccol0003ojOS<o`000003onkSa003o`000?o_i/CoknK400?oknK400?o0000onK?`?oVcl001_oV
cl02o`0000SoeKZo00?o0000oknY`onoZL<01onoZL<00ol0003o/jK<o`000004oj2Hc@;o00000on7
TMH2o`000004ocI[f?l0003o0000o`0000;o04c;0_l00002of5ofP;o00001On2S=D00ol0003o[Ig7
ojfMa`07ojfMa`;o000000?o]j31o`000?o8[Kh02Oo8[Kh00ol0003ocZnjo`000008omk0^`03o`00
0?oP`KWo000000Gok]Rk00Oo0000onkG^oo^ek_ok]Nko`000?ockkko000000ColNc20_l000000ooU
n=;o0000omk]g002omk]g005o`000?o@g>;od=cRom3Lh_l000000onman800ol0003oZ;;OojRbg`02
ojRbg`03o`000?nFWm[oUYoJ00;oUYoJ00?o0000ohJ@e_n6T=H00_n6T=H00ol0003oNhGBog^5dP03
og^5dP07o`000?mcOm3oLgo@og=od?l0003oDgCFo`000004odiae@03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02Oooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0>Oooool00ol0003oCVkBodi^dP02odi^dP?o0000
00?oEW;Co`000?mTOMH00omTOMH00ol0003oN8gKogR=f`02ogR=f`GoSj3O1?nW]>88o`0000;ocmOO
00?o0000omcSf_oLhmX00_oLhmX00ol0003oiNgEonG]e@02onG]e@04o`000?oXllooj???onScc`;o
00001?o^hl@00ol0003oknK4onoVa002onoVa003o`000?oWc[go000000Ooi/o000?o0000omVj^ol0
00001ooE^[l00ol0003oaZZmo`000008oknY``03o`000?nPV<goX9S=00GoX9S=00Oo0000ohNAe_n7
TMKo0000ofN1fOl0003o=V_H00?o00000_l0C</00ol0003oHGoJof5ofP02of5ofP03o`000?n2S=Go
PXcE00;oPXcE00?o0000oijIc_l000002On]WLL2o`0000_ob:fn00?o0000omk0^ooN`;/02?oN`;/0
0ol0003ok]RkonkH^`05onkH^`03o`000?o^ek_o000000?olnnn00Go0000oo7/`_oak<;olNc2o`00
0002onGhdP05o`000?oNkMcog^gLomk]g?l000000oo@g>801Ol0003o_LORokg7h_nman;o000000?o
Z;;O00?o0000oiJOf_nFWmX00onFWmX00ol0003oQY3FohJ@eP02ohJ@eP03o`000?mkQM;oNhGB00?o
NhGB0_l00003og=od0;o00001?m>LMD00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wo
oooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0iooooo`03o`000?m>K];o000000;o00001?mFL]<00ol0003oI7gFofAmeP02ofAmeP03o`00
0?mhSM_oN8gK00;oN8gK00?o0000ohnPgon?X=l00_n?X=l5ojNdhP03o`000?nman;o_LOR00;o_LOR
00Go0000oloGgoo?emoocmOOo`000004omcSfP05o`000?oUkMGoiNgEonG]eOl000001?oXlll00ol0
003ok^?4onkSa003onkSa005o`000?o_i/CoknK4onoVa?l000000ooWc[d00ol0003oi/o0onK?`003
onK?`005o`000?oI^[_ofKZkomVj^ol000001OoE^[l01?l0003oaZZmolJZ_Oo6Z[d2o`0000Ko_jW3
00?o0000ojjLaOl000001_nPV<d2o`0000?oIh7I00?o0000ocI[f?l000000_l000001?l0C<_o0000
obmWeol00003of5ofP;o00000_n2S=D01?l0003oWYW>oijIc_l00008ojfMa`03o`000?o0[<Go0000
00[ob:fn0_l00009omk0^`03o`000?o^f;_ok]Rk00Kok]Rk00?o0000oo?___ockkh00_ockkh00ol0
003olNc2oo7/`P02o`0000;oiOSB00Go0000omk]g?oNkMcog^gLo`000002om3LhP05o`000?nman;o
_LORokg7h_l000001?nX/]l00ol0003oUYoJoiJOfP02oiJOfP03o`000?n6T=KoQY3F00?oQY3F00?o
0000og^5d_mkQM800omkQM800ol0003oLgo@o`000003og=od0;o00000om>LMD00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Wooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0hooooo`?o00000_m>K]800ol0003oEW;CoeIbd`02
oeIbd`03o`000?mTOMKoI7gF00;oI7gF00Go0000ogR=fomhSM_oN8gKo`000005ohnPg`GoYkCR00?o
0000okg7h_nman800_nman801Ol0003ocmOOoloGgoo?emoo000000Cog>?J00Go0000onG]eOoUkMGo
iNgEo`000003onScc`;o00001Oo^hl@01?l0003oknK4onoVa?l00005onO>_@05o`000?oVcl3oi/o0
onK?`?l000001OoI^[/00ol0003oeKZoomFj_`02omFj_`03o`000?o6Z[goaZZm00?oaZZm00?o0000
oknY`onoZL<00_noZL<01?l0003o[Yc5ojjLaOn^W<D2o`0000GoX9S=0_l00003ofN1f@03o`000?lf
JmSo000000;o00000ol_ImL00ol0003oHGoJof5ofP02of5ofP;o00001?nNVLh2o`0000Go[Ig700Go
0000ol2/aOo0[<Go`:c5o`000008olR]_P04o`000?oI`<3ofL30o`0000Oog/2k00?o0000ongI_ol0
00001oo^f;/00ol0003olnnnoo?__P02oo?__P04o`000?oak<;o0000o`0000?oiOSB00Co0000omk]
g?oNkMco00000oo@g>801Ol0003o_LORokg7h_nman;o000000CoZ;;O00?o0000oiJOf_nFWmX00_nF
WmX00ol0003oQY3FohJ@eP02ohJ@eP03o`000?mkQM;oNhGB00?oNhGB00Co0000og=od?mcOm3o0000
0omcOm02ofmld0;o000000?oCW7Eo`000?ooool08oooool00ol0003oooooooooo`09ooooo`000ooo
ool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool3o`0003Kooooo
0ol00002ooooo`04o`Y?c?l0003oCVkBo`0000CoEW;C00?o0000ofAme_mTOMH00_mTOMH01Ol0003o
N8gKogR=fomhSM_o000000GoSj3O00?o0000ojNdh_nW]>800_nW]>800ol0003o_LORokg7hP02okg7
hP05o`000?o?emoocmOOoloGgol000001?oLhmX01Ol0003oiNgEonG]eOoUkMGo000000;oj???00?o
0000oncPa_l000001_o^hl@2o`0000Koiljm00Go0000onK?`?oVcl3oi/o0o`000006omVj^`04o`00
0?oE^[ooeKZoo`0000OoaZZm0_l00002oknY``03o`000?n^W<Go[Yc500?o[Yc500?o0000oj2HcOnP
V<d00_nPV<d00ol0003oQXgCo`000003ofN1f@05o`000?lfJmSo0000o`000?l0@/D00ol_ImL00ol0
003oHGoJof5ofP02of5ofP03o`000?nNVLkoWYW>00CoWYW>00?o0000ojfMaon]WLL00_n]WLL00ol0
003o`:c5ol2/a@02ol2/a@;o00001_o8[Kh01Ol0003ofL30omW0`?oI`<3o000000Kog/2k00?o0000
ongI_ol000001_o^f;/2o`0000Colnnn0_l000001OoUo<Go0000onGhd_oUn=;o000000?og^gL00Go
0000om3Lh_o@g>;od=cRo`000003okg7hP05o`000?nX/]ooZ;;OojRbgol000001OnFWmX00ol0003o
QY3FohJ@eP02ohJ@eP03o`000?mkQM;oNhGB00?oNhGB00Oo0000og=od?mcOm3oLgo@o`000?mcOm3o
000000CoKgc@0_l0000Tooooo`03o`000?oooooooooo00Wooooo0003ooooo`03oa0@4?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`?o00001Oooool2o`Y?
c0;o00001?mFL]<00ol0003oI7gFofAmeP02ofAmeP05o`000?mhSM_oN8gKogR=fol000001?n?X=l0
0ol0003oYkCRojNdhP03ojNdhP03o`000?nman;o_LOR00;o_LOR00Go0000oloGgoo?emoocmOOo`00
0003omcSfP03o`000?oUkMGoiNgE00;oiNgE00?o0000onSccol000000oo/h<H00ol0003ok^?4onkS
a003onkSa003o`000?oWc[goiljm00Koiljm00?o0000onK?`?l000002?oI^[/00ol0003oeKZoo`00
0009olJZ_@03o`000?noZL?o000000Ko[Yc50_l00002oj2Hc@04o`000?n6SM?oQXgCo`0000?oIh7I
0ol00002o`12a@04o`000?l_ImOo;fOGo`0000?oHGoJ00?o0000oh>@eol000001OnNVLh01?l0003o
[Ig7ojfMaol00007ol2/a@03o`000?o8[Kkob:fn00;ob:fn00?o0000omW0`?oI`<000ooI`<000ol0
003og/2komk0^`02omk0^`05o`000?o]fKookMVoongI_ol000001?o^f;/00ol0003ol_6mo`000004
oo?__P04o`000?oUo<GoiOc5o`0000;oiOSB00Go0000omk]g?oNkMcog^gLo`000002om3LhP05o`00
0?nman;o_LORokg7h_l000001?nX/]l00ol0003oUYoJoiJOfP02oiJOfP03o`000?n6T=KoQY3F00?o
QY3F00?o0000og^5d_mkQM800_mkQM800ol0003oLgo@og=od003og=od0;o00001Om_O=000ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool3o`0000Sooooo00?o0000o`Y?c?l:
Cl`00_l00002oeIbd`03o`000?mTOMKoI7gF00?oI7gF00Go0000ogR=fomhSM_oN8gKo`000004ohnP
g`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7h_nman800_nman800ol0003ocmOOoloGg`02oloG
g`05o`000?oLhm[og>?JomcSf_l000001?oUkMD2o`0000Cok>3600?o0000onkSa?o^hl@00oo^hl@0
0ol0003oiljmonO>_@07onO>_@;o00002OoI^[/00ol0003oaZZmolJZ_@09olJZ_@03o`000?n^W<Go
[Yc500Oo[Yc50_l00004ohJ=d`;o00000_mWPMT3o`0000;o04;500Ko0000obmWeol_ImOo0000of5o
f_l00003oh>@e`03o`000?nNVLkoWYW>00?oWYW>00?o0000ojfMaol000002?o0[<D01?l0003ob:fn
olR]__l00007omW0`004o`000?oN`;_og/2ko`0000GokMVo00Co0000onkH^oo^f;_o00000_oblKd0
1?l0003olnnnoo?___ockkh2o`000003onGlaOl0003oiOSB00;oiOSB00Go0000omk]g?oNkMco0000
om3LhP09o`0000;oZ;;O00?o0000oiJOf_nFWmX00_nFWmX00ol0003oQY3FohJ@eP02ohJ@eP03o`00
0?mkQM;oNhGB00?oNhGB00?o0000og=od?mcOm000omcOm02o`0000GoKgc@00?o0000ooooooooool0
8oooool00ol0003oooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo
00?o0000ooooooooool0;Oooool3o`0000cooooo0_l:Cl`2oaEFc`03o`000?mFL]?o000000GoI7gF
00Go0000ogR=fomhSM_oN8gKo`000004ohnPg`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7h_nm
an800_nman800ol0003ocmOOoloGg`02oloGg`05o`000?oLhm[og>?JomcSf_l000000ooUkMD2o`00
00Gok>3600?o0000onkSa?o^hl@00_o^hl@00ol0003oi/fmo`000008onO>_@03o`000?oJ^kWo0000
00SofKZk00?o0000ol^[^_l000002Oo6Z[d00ol0003o]io0o`000008ojjLa@;o00001On6SM<01?l0
003oIh7Io`000?lbKM/2o`0000;o04;500Co0000obmWeol_ImOo00001On3T=L00ol0003oWYW>oijI
cP03oijIcP03o`000?o0[<Go`:c500So`:c500?o0000olR]__l000002?oI`<000ol0003og/2ko`00
0005ongI_`03o`000?o^f;_o000000?ol_6m00?o0000oo?___ockkh00_l00002onGla@06o`000?oU
n=;oiOSBonGhd_l0003og^gL0ol00002ol[Mi`05o`000?nlan?o_<OSokc7hol000000_n^/m`3o`00
00CoUYoJ00?o0000ohJ@e_n6T=H00_n6T=H00ol0003oNhGBog^5dP02og^5dP03o`000?mcOm3oLgo@
00CoLgo@0_l00004ofmld003o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool001Wo
oooo00?o0000ooooooooool0:_ooool3o`0000oooooo00?o0000o`Y?c?l:Cl`00_lEE/l2o`0000Go
I7gF00Go0000ogR=fomhSM_oN8gKo`000004ohnPg`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7
h_nman800_nman801Ol0003ocmOOoloGgoo?emoo000000Cog>?J00Ko0000onG]eOoUkMGo0000onKM
bol00005oncPaP05o`000?o^hlCok^?4onkSa?l000000ooVcKd00ol0003oiljmonO>_@04onO>_@05
o`000?oJ^kWof[^iomZk^Ol000001_oI^[/01?l0003obj^jol^[^_o;ZkX2o`0000KoaZZm00Co0000
okNO`?ngWl3o]io00_l00006ojjLa@03o`000?nIU<go000000GoQXgC0_l00002oc9]f`;o00000_l0
@/D01?l0003o;fOGo`000?l00005oh>@e`03o`000?nNVLkoWYW>00;oWYW>00?o0000ok>Xc_l00000
2Oo0[<D00ol0003ofL30omW0`008omW0`003o`000?o]fKookMVo00GokMVo00?o0000oo;a_OoblKd0
0_oblKd01ol0003olnnno`000?oNoK[o0000onGlaOl000000ooUn=83o`000005om?ai_l0003ob]gW
ol[Miol000000onlan<00ol0003o[[?Lojjcg002ojjcg003o`000?nRY=Oo000000?o00001On6T=H0
0ol0003oNhGBog^5dP02og^5dP03o`000?mcOm3oLgo@00CoLgo@00?o0000ofmld?l000000om_O=00
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Iooooo`;o0000:?ooool3o`00
01;ooooo00?o0000o`Y?c?l:Cl`00olEE/l2o`0000?oI7gF00?o0000ogR=fomhSM/00_mhSM/00ol0
003oSj3OohnPg`02ohnPg`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7h_nman800_nman801Ol0
003ocmOOoloGgoo?emoo000000Cog>?J00?o0000onG]eOl000000_oVgL/00ol0003ok>36oncPaP03
oncPaP04o`000?o^hlCok^?4o`0000Goi/fm00?o0000onO>_OoWc[d00ooWc[d00ol0003of[^iomZk
^@02omZk^@03o`000?oI^[_ofKZk00?ofKZk00?o0000ol^[^_o;ZkX00oo;ZkX00ol0003oaZZmolJZ
_@03olJZ_@03o`000?ngWl3o]io000?o]io000?o0000ojjLaOn^W<D00_n^W<D01?l0003oVIC=oiVD
cOnIU<d2o`0000CoQXgC0_l00002oc9]f`;o000000?o04;5o`000?l000000_mGOMd00ol0003oPi3G
oh>@e`03oh>@e`04o`000?nNVLkoWYW>o`0000?o/jS>00?o0000ol2/aOo0[<D01_o0[<D2o`0000Wo
fL3000?o0000ongI_oo]fKl01Oo]fKl00ol0003ol_6moo;a_@02oo;a_@;o000000Gog_fjo`000?oU
o<GoiOc5o`000002onGhdP;o00000_oClNH01?l0003ob]gWol[Miol00003okc7h`03o`000?n^/mco
[[?L00;o[[?L00?o0000oj:TeonRY=L00onRY=L2o`0000?oQY3F00?o0000og^5d_mkQM800omkQM80
0ol0003oLgo@og=od003og=od007o`000?m_O=3oKgc@ofmld?l0003oKgc@o`00000Wooooo`03o`00
0?oooooooooo00Sooooo000Iooooo`03o`000?oooooooooo02Cooooo0ol0000Fooooo`03o`000?l:
Clco000000;o5EK?0_l_JMP2o`000003ofAme_l0003oN8gK00?oN8gK00?o0000ohnPgon?X=l00_n?
X=l00ol0003oYkCRojNdhP02ojNdhP03o`000?nman;o_LOR00;o_LOR00Go0000oloGgoo?emoocmOO
o`000004omcSfP;o00001?oVgL/00ol0003ok>36oncPaP03oncPaP;o00001_oVcKd00ol0003oiljm
onO>_@02onO>_@03o`000?oJ^kWof[^i00Cof[^i00Go0000omVj^ooI^[_ofKZko`000007ol^[^P;o
00000_o6Z[d00ol0003o]io0okNO`005okNO`0;o00000_n^W<D00ol0003oVIC=oiVDc@03oiVDc@07
o`000?n6SM?oQXgCohJ=dol0003oG8?Oo`000002oc9]f`;o00000_lAF]<01?l0003oEggMoeMmgOl0
0005oh>@e`03o`000?nNVLko000000Co/jS>0_l00005ol2/a@04o`000?oB`<Sod/38o`0000OofL30
00?o0000onSKa_l000001Oo]fKl2o`0000Col_6m00Co0000omkm^_oNoK[o00000_oUo<D3o`000004
om;mgOl0003odo7Vo`0000?ob]gW00Go0000okc7honlan?o_<OSo`000003ojjcg003o`000?nRY=Oo
XZCG00CoXZCG00?o0000oiNHd_l000000_n6T=H00ol0003oNhGBog^5dP02og^5dP03o`000?mcOm3o
Lgo@00CoLgo@00?o0000ofmld?m_O=000_m_O=02o`0002Oooooo00?o0000ooooooooool02?ooool0
01Sooooo00?o0000ooooooooool08_ooool3o`0001Wooooo00?o0000o`Y?c?l:Cl`00olEE/l3obmY
f0;o00001?mhSM/00ol0003oSj3OohnPg`02ohnPg`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7
h_nman800_nman801Ol0003ocmOOoloGgoo?emoo000000?og>?J0_l00005onKMb`03o`000?o/h<Ko
k>3600?ok>3600?o0000onK=_OoVcKd01_oVcKd01?l0003oiljmonO>_Ol00008omZk^@04o`000?oI
^[_ofKZko`0000Wobj^j00?o0000olJZ_Ol000002OngWl000ol0003o[Yc5o`000006oiVDc@;o0000
00OoQXgCo`000?mLPmooG8?Oo`000?lbKM_oX2<000;o00000_lAF]<01?l0003oEggMoeMmgOl00005
oh>@e`03o`000?ncZ<ko/jS>00Go/jS>00Go0000ol2/aOo0[<Go`:c5o`000004om;0b003o`000?oI
`<3ofL3000?ofL3000Go0000onSKa_oXflKoj=_6o`000003ongI_`03o`000?o_mL7o000000Col_6m
00?o0000omkm^_oNoKX00ol00003om;mg@04o`000?oClNKodo7Vo`0000;ob]gW00Go0000okc7honl
an?o_<OSo`000004ojjcg003o`000?nRY=OoXZCG00?oXZCG00Oo0000oiNHd_nGV=;oUiSBo`000?n6
T=Ko000000CoNhGB00?o0000og=od?mcOm000omcOm000ol0003oKgc@ofmld003ofmld003o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000ooooooooool08?ooool2
o`0001cooooo00Co0000o`Y?c?l:Clco00000_lEE/l4obmYf0;o00000_mhSM/00ol0003oSj3OohnP
g`03ohnPg`03o`000?nW]>;oYkCR00;oYkCR00?o0000okg7h_nman800_nman801_l0003ocmOOoloG
goo?emoo0000omcSfP;o000000?og]SAo`000?oVgL/01?oVgL/00ol0003ok>36oncPaP03oncPaP03
o`000?oVcKgoi/fm00Ooi/fm00?o0000onO>_Ol000002OoJ^kT00ol0003ofKZko`00000:ol^[^P03
o`000?ngWl3o]io000Wo]io00_l00008oiVDc@;o00000omLPml2o`000003o`00Qol0003o000000;o
4E[C00Co0000oeMmgOmGOMgo00000on3T=L01?l0003oVj;Joi^Rf_l00006ok>XcP03o`000?o0[<Go
000000Kod/3800Go0000omW0`?oI`<3ofL30o`000004onSKaP05o`000?o]fKookMVoongI_ol00000
0_o_mL401?l0003ol_6moo;a_Ol00002omkm^P;o000000GoaOk<o`000?oBoMgod_gMo`000002om?a
iP04o`000?o:gNOob]gWo`0000?o_<OS00?o0000ojjcg?n^/m`00_n^/m`00ol0003oXZCGoj:Te`03
oj:Te`03o`000?nGV=;oUiSB00?oUiSB0_l00003og^5dP03o`000?mcOm3oLgo@00CoLgo@00?o0000
ofmld?m_O=000om_O=02o`0002Sooooo00?o0000ooooooooool01oooool001Sooooo00?o0000oooo
ooooool07Oooool3o`0001oooooo00?o0000o`Y?c?l000000_lEE/l01?l0003o;fWHobmYf?l_JMP2
oeB3hP03o`000?mhSM_o000000CoSj3O00?o0000ojNdh_nW]>800onW]>801Ol0003o_LORokg7h_nm
an;o000000CocmOO0_l00003omkHd@03o`000?oVgL_oi]g;00?oi]g;00?o0000oncPa_o/h<H00_o/
h<H00ol0003oiLfoo`000009onK=_@;o00002_oJ^kT2o`0000[obj^j00Co0000okfQ_Ol0003o0000
2?ngWl001?l0003oYYW8o`000?l00007oiVDc@;o00001?mLPml01?l0003o0027o`000?l00002oa5J
d`06o`000?mGOMgoEggMo`000?n3T=Oo00001?nKX]X00ol0003o/jS>ok>XcP04ok>XcP03o`000?oB
`<Sod/3800Kod/3800?o0000omW0`?l000001_oXflH00ol0003okMVoo`000003onoe`@04o`000?ob
lKgo0000o`0000;og_fj00?o0000olGnc?l000000_oBoMd01?l0003odo7Vom?ai_l00003ol[Mi`05
o`000?nlan?o_<OSokc7hol000000on^/m`00ol0003oXZCGoj:Te`03oj:Te`03o`000?nGV=;oUiSB
00CoUiSB00?o0000ohn?col000000_mkQM800ol0003oLgo@og=od003og=od003o`000?m_O=3oKgc@
00?oKgc@00Co0000oooooooooooo00009oooool00ol0003oooooooooo`07ooooo`006?ooool2o`00
01_ooooo0ol0000Rooooo`04o`000?l:Clco2To<o`0000;o5EK?0ol_JMP00ol0003oE8?RoeB3hP02
o`0000CoSj3O00?o0000ojNdh_nW]>800_nW]>800ol0003o_LORokg7hP02okg7hP04o`000?o?emoo
cmOOoloGg`;o00001OoNf=400ol0003oi]g;onKMb`02onKMb`05o`000?o/h<Kok>36oncPa_l00000
0ooUcKl00ol0003oi/fmonK=_@06onK=_@03o`000?oK^kWo000000Wof[^i00Co0000olf]^Ol0003o
00001oo;ZkX00ol0003o_J6mokfQ_@02okfQ_@?o00001OngWl001?l0003oYYW8ojJIb?nVVLP3o`00
00CoVIC=00Co0000og^@gOl0003o00000omLPml2o`000006o`0c^?l0003o4E[Coa5Jdol0003oEggM
0_l00006oi^RfP03o`000?ncZ<ko/jS>00?o/jS>0_l00008om;0b003o`000?oXflKoj=_600Koj=_6
00?o0000onoe`Oo_mL400_o_mL42o`000006om?k/ol0003og_fjo`000?o5o/co00000_oBoMd01?l0
003odo7Vom?ai_l00003ol[Mi`05o`000?nlan?o_<OSokc7hol000001?n^/m`00ol0003oXZCGoj:T
e`03oj:Te`03o`000?nGV=;oUiSB00?oUiSB00Oo0000ohn?con?SlooSho?o`000?mkQM;o000000Go
Lgo@00?o0000ofmld?m_O=000om_O=001?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
00Oooooo000Hooooo`03o`000?oooooooooo01Oooooo0ol0000Uooooo`04o`000?l:Clco2To<o`00
00;o5EK?00Co0000obmYf?l_JMSo;fWH0omDPn84o`000003ohnPgol0003oYkCR00?oYkCR00?o0000
okg7h_nman800_nman84o`000003om7AfOl0003og]SA00Cog]SA00?o0000onKMbooVgL/00ooVgL/0
0ol0003ok>36o`000005onG=_`03o`000?oVcKgoi/fm00Coi/fm00Go0000om^k^OoK^kWofk^io`00
0007omZk^@03o`000?o=[KWocJfi00;ocJfi0_l00005ol^[^P03o`000?nmXKgo_J6m00Go_J6m0_l0
0002okNO`003o`000?nVVLSoYYW800GoYYW80_l00002oiVDc@04o`000?mkT=goNi3Mog^@g@;o0000
0_mLPml2o`000003o`0c^?l0003o000000;o00000_m_TN<00ol0003oVj;Joi^RfP04oi^RfP05o`00
0?ncZ<ko/jS>ok>Xc_l000000_o4_]@00ol0003od/38om;0b005om;0b003o`000?oXflKoj=_600Ko
j=_600?o0000onoe`Oo_mL400_o_mL401?l0003odo^co`000?oNoKX2o`000004olGnc?l0003od_gM
o`0000?odo7V00Go0000ol[Mioo:gNOob]gWo`000002okc7h`03o`000?n^/mco[[?L00;o[[?L00?o
0000oj:TeonRY=L00onRY=L00ol0003oUiSBoiNHdP03oiNHdP03o`000?n?SlooSho?00?oSho?0_l0
0005og=od003o`000?m_O=3oKgc@00?oKgc@00Go0000ooooooooooooooooo`00000Vooooo`03o`00
0?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01Cooooo0ol0000Yooooo`06o`000?l:
Clco2To<o`000?lEE/oo00000ol_JMP00ol0003oE8?RoeB3hP04ogbNj0Go000000CoYkCRo`000?nm
an;o_LOR0ol00004om7Af@03o`000?oNf=7og]SA00?og]SA00?o0000onKMbooVgL/00ooVgL/2o`00
00OoiLfo00?o0000onK=_OoVcKd00ooVcKd00ol0003ofk^iom^k^@02om^k^@;o00001OoJ^kT00ol0
003ocJfiolf]^@04olf]^@;o00000oo;ZkX00ol0003o_J6mokfQ_@07okfQ_@?o00002OnVVLP3o`00
00GoNi3M00Wo0000oeb3gol0003o4g;Qo`000?l0<kSo0000obE/gOl000000om_TN<00ol0003oVj;J
oi^RfP04oi^RfP03o`000?ncZ<ko000000Coa;kD00?o0000om;0b?oB`<P00ooB`<P00ol0003oh=cA
o`000006onSKaP;o00000oo_mL42o`000006om?k/ol0003o0000o`000?o5o/co00000_oBoMd01?l0
003odo7Vom?ai_l00003ol[Mi`05o`000?nlan?o_<OSokc7hol000000on^/m`00ol0003oXZCGoj:T
e`03oj:Te`03o`000?nGV=;oUiSB00?oUiSB00?o0000ohn?con?Sll01?n?Sll01?l0003oRX_>o`00
0?l00002og=od003o`000?m_O=3oKgc@00?oKgc@00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0
000/ooooo`04o`000?l:Clco2To<o`0000;o5EK?00Co0000obmYf?l_JMSo00000omDPn84ogbNj0Co
XKKW1?l00002okg6hP03o`000?oAdMWodM7I00?odM7I00?o0000omkHdOoNf=400ooNf=400ol0003o
i]g;onKMb`02onKMb`03o`000?oUcKooiLfo00KoiLfo00?o0000onK=_OoVcKd00_oVcKd00ol0003o
fk^iom^k^@05om^k^@05o`000?oJ^kWof[^iomZk^Ol000002Oo=[KT3o`0000co_J6m0_l0000:ojJI
b0;o00001OmkT=d3o`000006oa=bhOl0003o0000o`000?lUK=go00000om_TN<00ol0003oVj;Joi^R
fP04oi^RfP03o`000?o4_]Coa;kD00Coa;kD00Go0000om;0b?oB`<Sod/38o`000003on3Ld@03o`00
0?oXflKoj=_600;oj=_600?o0000onWhb_l000000_o_mL42o`0000;odo^c0_l000001Oo5o/co0000
om;mgOoBoMgo000000;odo7V00Go0000ol[Mioo:gNOob]gWo`000003okc7h`03o`000?n^/mco[[?L
00;o[[?L00?o0000oj:TeonRY=L00_nRY=L00ol0003oUiSBoiNHdP03oiNHdP03o`000?n?SlooSho?
00CoSho?00?o0000ohZ;c_n:Rlh00_n:Rlh00ol0003oLgo@o`000005ofmld003o`000?oooooooooo
00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool00ol0003o
ooooooooo`0?ooooo`?o0000;oooool01?l0003o2To<o`Y?c?l00002oaEFc`05o`000?l_JMSo;fWH
obmYf?l000000_mDPn84ogbNj003o`000?nQ]^OoXKKW00;oXKKW1Onma^800ol0003odM7Iom7Af@03
om7Af@03o`000?oNf=7og]SA00?og]SA00?o0000onKMbooVgL/00_oVgL/00ol0003oiLfoonG=_`07
onG=_`04o`000?oVcKgoi/fmo`0000Wofk^i00Co0000omZk^OoJ^kWo00002oo=[KT00ol0003o_J6m
okfQ_@0:okfQ_@04o`000?n^W<Go0000o`0000SoYYW800?o0000ohnIfOl000000_l00004og^@g@;o
000000Ko4g;Qo`000?l0003o0000obE/gOl00003ofnAh`07o`000?nKX][oVj;Joi^Rf_l0003oZ[SS
o`000007olBne003o`000?oB`<So000000Coh=cA00Go0000onSKa_oXflKoj=_6o`000002onWhbP04
o`000?o_mL7o0000olCi/@Co000000GoaOk<o`000?oBoMgod_gMo`000003om?aiP05o`000?o:gNOo
b]gWol[Miol000000_nlan<00ol0003o[[?Lojjcg002ojjcg003o`000?nRY=OoXZCG00?oXZCG00?o
0000oiNHd_nGV=800onGV=800ol0003oSho?ohn?c`03ohn?c`03o`000?n:RlkoRX_>00CoRX_>00?o
0000ofmld?m_O=000om_O=000ol0003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool01oooool001Oooooo0_l0000=ooooo`?o0000<oooool2o`000004o`Y?c?l0003o
5EK?o`0000?o;fWH00Co0000oeB3h_mDPn;o00001?mlW^P01Ol0003oXKKWoj6fionQ]^Oo000000Go
_LKR00?o0000om7AfOoAdMT00_oAdMT00ol0003og]SAomkHd@03omkHd@07o`000?oVgL_oi]g;onKM
bol0003ohLc4o`000009onG=_`03o`000?oVcKgo000000[ofk^i00?o0000omZk^Ol000002oo=[KT0
0ol0003o`J>ko`000002o`0000So_J6m00Co0000ojjLaOn^W<Go[Yc50ol00005ojJIb003o`000?n?
VMWoSiWI00;oSiWI0_l00002og^@g@03o`000?m1Snoo000000;o000000Co03Jho`000?l0003o0000
0om_TN<00ol0003oVj;Jo`000003ojZhh`03o`000?o4_]Coa;kD00Goa;kD00?o0000on3LdOoPg=40
1?oPg=400ol0003oj=_6o`000003onWhbP;o000000Goa?Vao`000?l0003o[OBfo`000002olGnc003
o`000?oBoMgo000000?odo7V00Go0000ol[Mioo:gNOob]gWo`000003okc7h`05o`000?n^/mco[[?L
ojjcg?l000001OnRY=L00ol0003oUiSBoiNHdP03oiNHdP03o`000?n?SlooSho?00?oSho?00?o0000
ohZ;c_n:Rlh01On:Rlh2o`0000CoKgc@00?o0000ooooooooool01_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000foooo
o`;o02>X0_l00002oaEFc`04o`000?l_JMSo;fWHo`0000?oE8?R00Go0000ogbNj?mlW^SoO9kXo`00
0004oj6fi`03o`000?nma^;o_LKR00;o_LKR00?o0000om7AfOoAdMT00_oAdMT00ol0003og]SAomkH
d@03omkHd@04o`000?oVgL_oi]g;o`0000?ohLc400?o0000onG=_ooUcKl01ooUcKl2o`0000_ofk^i
0_l0000;olf]^@03o`000?o1Xk_o`J>k00;o`J>k0_l00006okfQ_@03o`000?n^W<Go[Yc500Co[Yc5
0_l00002ojJIb003o`000?n?VMWoSiWI00GoSiWI1?l00002od6?k`05o`000?n=303o0000o`000?lU
Mn@01Ol00005ojZhh`03o`000?o4_]Coa;kD00?oa;kD0_l00007on3Ld@03o`000?oYn<[ojOS:00;o
jOS:00Ko0000olCi/Oo4nK7o0000ojgd]_l00002olGnc0go000000?o_<OSo`000?n^/m`00on^/m`0
0ol0003oXZCGoj:Te`02oj:Te`03o`000?nGV=;oUiSB00?oUiSB00?o0000ohn?con?Sll00on?Sll0
0ol0003oRX_>ohZ;cP05ohZ;cP04o`000?n7RLkoQhW>o`0000;oKgc@00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooo
oooo00Kooooo0ol0000jooooo`;o02>X00Co0000oaEFcolEE/oo00000ol_JMP01?l0003oE8?RoeB3
h_l00003ogbNj003o`000?nQ]^OoXKKW00;oXKKW00?o0000okg6h_nma^800_nma^800ol0003odM7I
om7Af@03om7Af@03o`000?oNf=7og]SA00?og]SA0_l00005on7<a003o`000?oUcKooiLfo00KoiLfo
00?o0000omZl^ol000002_oK^kT01?l0003ocjjio`000?l00008olf]^@03o`000?o1Xk_o`J>k00Go
`J>k0_l00003okfQ_@03o`000?n^W<Go[Yc500Oo[Yc50ol0000:ohnIf@;o00000om1Snl01Ol0003o
02j/o`000?lUMnCo000000?oN:C^00?o0000ojZhhonZ^><00onZ^><01Ol0003oa;kDolBne?o4_]Co
000000;od=cR00?o0000on3LdOoPg=400_oPg=400ol0003og?_Io`000003onWhbPCo000000?o[OBf
o`000?l000000ol00003olKYkP05o`000?o3f>Wo`mSYol?HjOl000000onlan<4o`0000;o[[?L00?o
0000oj:TeonRY=L00onRY=L00ol0003oUiSBoiNHdP02oiNHdP03o`000?n?SlooSho?00CoSho?00?o
0000ohZ;c_n:Rlh01?n:Rlh00ol0003oQhW>ohN9cP02ohN9cP03o`000?m_O=3o000000_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`03
ooooo`?o0000?_ooool2o`0SZ003o`000?lEE/oo000000?o;fWH00Co0000oeB3h_mDPn;o00000oml
W^P00ol0003oXKKWoj6fi`02oj6fi`03o`000?nma^;o_LKR00;o_LKR00?o0000om7AfOoAdMT00ooA
dMT00ol0003og]SAomkHd@03omkHd@03o`000?oQc<CohLc400GohLc400?o0000onG=_ooUcKl01?oU
cKl01Ol0003of[bkomZl^ooJ_;_o000000Sofk^i00?o0000oln^^Oo?[[T00_o?[[T3o`0000GocJfi
00?o0000ol6S^oo1Xk/01oo1Xk/4o`0000_o[Yc50ol00008ohnIf@03o`000?mWY?Co000000;o0000
00?o@Ho_o`000?l0;Z`00ol00003ogRTkP03o`000?nZ^>?oZ[SS00?oZ[SS00?o0000olBne?l00000
1?o@g>801?l0003oh=cAon3LdOl00002omckf@03o`000?oYn<[ojOS:00So000000?o`OO^o`000?o6
jNh00_o6jNh01Ol0003o`mSYol?HjOo3f>Wo000000?o_<OS00?o0000ok>hg?nc^=`00_nc^=`3o`00
00CoXZCG00?o0000oiNHd_nGV=800_nGV=800ol0003oSho?ohn?c`04ohn?c`03o`000?n:RlkoRX_>
00CoRX_>00?o0000ohN9c_n7RLh01?n7RLh00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool01_ooool001Kooooo00Co0000oooooooooooooooo0ol00012oooo
o`05o`0SZ?l0;[7o0000oaEFcol000000_l_JMP01Ol0003oE8?RoeB3h_mDPn;o000000?oO9kX00?o
0000oj6fionQ]^L00_nQ]^L00ol0003o_LKRokg6hP02okg6hP03o`000?oAdMWodM7I00;odM7I00?o
0000omkHdOoNf=400_oNf=42o`0000OohLc400?o0000onG=_ooUcKl00ooUcKl00ol0003of[bkomZl
^`03omZl^`;o00001_oK^kT00ol0003ocjjioln^^@05oln^^@;o00000oo=[KT00ol0003o`J>kol6S
^`0:ol6S^`?o00002On^W<D00ol0003oWIoEoifOe@04o`0000CoSiWI00?o0000ofNTm?mWY?@00_mW
Y?@2o`000003od6?kol0003o2WGQ00;o00000omhY>h01?l0003oZ[SSojZhhonZ^><3o`0000God=cR
00?o0000on3LdOl000001?oLnmT2o`000004ojod]Ol0003o0000o`0000;o[_[U00?o0000ol7gk_l0
00000oo6jNh01Ol0003o`mSYol?HjOo3f>Wo000000?o_<OS00?o0000ok>hg?nc^=`00_nc^=`01?l0
003o[:cGojb/eon/[=L2o`000003oj:Teol0003oUiSB00CoUiSB00?o0000ohn?con?Sll00on?Sll0
0ol0003oRX_>ohZ;cP04ohZ;cP03o`000?n7RLkoQhW>00GoQhW>00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo000Fooooo`Co0000A_ooool01?l0
8jSo02jao`000?l00003obmYf004o`000?mDPn;oE8?Ro`0000?oO9kX00?o0000oj6fionQ]^L00_nQ
]^L00ol0003o_LKRokg6hP02okg6hP03o`000?oAdMWodM7I00;odM7I00Go0000omkHdOoNf=7og]SA
o`000002om_<b`03o`000?oQc<CohLc400GohLc400Go0000onG=_ooUcKooiLfoo`000008omZl^`03
o`000?oK^kWofk^i00;ofk^i00?o0000oln^^Oo?[[T02?o?[[T3o`0000go`J>k00?o0000okBO`ond
Wl<00ol00006ojjLa@03o`000?nMWmGoWIoE00CoWIoE1?l000000on?VMWo0000ofNTm004ofNTm0Co
000000?o2WGQo`000?l000001Ol00003ojgCm003o`000?o@g>;od=cR00?od=cR00?o0000omckfOoL
nmT00ooLnmT00ol0003o[oBeo`000002o`000005ojkjiOl0003o0000ol7gk_l000000oo6jNh01Ol0
003o`mSYol?HjOo3f>Wo000000?o_<OS00?o0000ok>hg?nc^=`00_nc^=`00ol0003o[:cGojb/e`03
ojb/e`;o00001OnGV=800ol0003oSho?ohn?c`03ohn?c`03o`000?n:RlkoRX_>00CoRX_>00?o0000
ohN9c_n7RLh01On7RLh00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01_ooool001Kooooo0_l00019ooooo`03o`0SZ?l0;[7o000000?o;fWH00Co0000oeB3
h_mDPn;o00000omlW^P00ol0003oXKKWoj6fi`02oj6fi`03o`000?nma^;o_LKR00;o_LKR00?o0000
om7AfOoAdMT00_oAdMT01?l0003og]SAomkHdOl00004om_<b`03o`000?oQc<CohLc400GohLc400?o
0000onG=_ol000002_oJ_;/01?l0003ofk^iom^k^Ol0000=oln^^@03o`000?o1Xk_o`J>k00_o`J>k
00?o0000okBO`ondWl<00ondWl<3o`0000?o[Yc500?o0000oifOeOnMWmD02?nMWmD5o`0000GoIjCd
0ol00004of^dn`03o`000?n]doCo[M?d00?o[M?d00Ko0000om3Lh_l0003o0000okohkOl00002omck
f@Ko00000_n^n^D01?l0003o`OO^ol7gk_l00003olKYkP05o`000?o3f>Wo`mSYol?HjOl000000onl
an<00ol0003o/kSLok>hg002ok>hg003o`000?n/[=Oo[:cG00?o[:cG00Co0000ojFSdonUXm?o0000
0onGV=800ol0003oSho?ohn?c`03ohn?c`03o`000?n:RlkoRX_>00CoRX_>00?o0000ohN9c_n7RLh0
1On7RLh00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool000cooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00Ko
02>Xo`0^/Ol0003o0000obmYf?l00003oeB3hP05o`000?mlW^SoO9kXogbNj?l000000onQ]^L00ol0
003o_LKRokg6hP02okg6hP03o`000?oAdMWodM7I00?odM7I0_l00005om_<b`03o`000?oQc<CohLc4
00KohLc40_l0000;omZl^`03o`000?oK^kWo000000gocjji00?o0000ol>V^ol000000_l00009ol6S
^`03o`000?ndWl?o]9o300Ko]9o31?l0000;oifOe@04o`000?n4/_?oQ;;cohBbl`Go000000CoIjCd
o`000?l0003o00001?m[]?/01ol0003o[M?dojgCm?n]doCo0000ojgCm?l000001?non>d5o`000003
ohk^dol0003o[_[U00;o00000_o1mnh01Ol0003oa^W^olKYk_o6jNko000000;o`mSY0_l00003okc7
h`03o`000?nc^=co/kSL00;o/kSL00?o0000ojb/eon/[=L00on/[=L00ol0003oYJ?CojFSd`02ojFS
d`03o`000?nGV=;o000000KoSho?00?o0000ohZ;c_n:Rlh00on:Rlh00ol0003oQhW>ohN9cP05ohN9
cP03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05oooo
o`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00Ko02>Xo`1=bOl0
CLWo0000obmYf?l00002oeB3hP05o`000?mlW^SoO9kXogbNj?l000001?nQ]^L01Ol0003o_LKRokg6
h_nma^;o000000CodM7I0_l00007om_<b`03o`000?oQc<CohLc400GohLc400?o0000omRn`?l00000
2ooJ_;/2o`0000cocjji00?o0000ol>V^oo3Y[/00oo3Y[/3o`0000Go`J>k00?o0000okBO`ondWl<0
2_ndWl<4o`0000SoWIoE00?o0000ohBblon4/_<01_n4/_<<o`0000;oQn7k00Go0000okohkOnon>go
0000okohk@03o`000005ohk^dol0003o0000ojkjiOl000000oo1mnh01Ol0003oa^W^olKYk_o6jNko
000000;o`mSY00?o0000okc7honlan<00_nlan<00ol0003o/kSLok>hg002ok>hg003o`000?n/[=Oo
[:cG00?o[:cG00?o0000ojFSdonUXm<00onUXm<3o`0000GoSho?00?o0000ohZ;c_n:Rlh01?n:Rlh0
0ol0003oQhW>ohN9cP04ohN9cP03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
04Kooooo0_l00003o`1=b@;o000000?oE8?Ro`000?mlW^P00_mlW^P00ol0003oXKKWoj6fi`02oj6f
i`03o`000?nma^;o_LKR00;o_LKR1?l000000oo@b]Go0000om_<b`07om_<b`03o`000?oQc<CohLc4
00?ohLc400Go0000omRn`?oH_/3of;k0o`00000:omZl^`03o`000?o?/K_o000000;o00002Oo?[[T0
0ol0003o`jJkol>V^`06ol>V^`;o00000oo1Xk/00ol0003o]9o3okBO``0:okBO``04o`000?nWY=?o
YjCCojNTd`Oo00000_nMWmD00ol0003oQ;;cohBbl`08ohBbl`03o`000?m@a_;oD<Kb00?o;ZO^00Go
0000ohOQnon7hO_o0000ohOQn`04o`000005of;F^ol0003o0000ohk^dol000000_n^n^D01Ol0003o
`OO^ol7gk_o1mnko000000?oa^W^00Co0000ol?HjOo3f>Wo00001?nlan<00ol0003o/kSLok>hg002
ok>hg003o`000?n/[=Oo[:cG00?o[:cG00?o0000ojFSdonUXm<00onUXm<01Ol0003oWicAoinLdOnO
W=7o000000?oSho?00?o0000ohZ;c_n:Rlh01?n:Rlh00ol0003oQhW>ohN9cP04ohN9cP03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`003_ooool0
0ol0003oooooooooo`0:ooooo`;o0000Aoooool02Ol08jSo02jao`1=bOl0CLWo0000ob=hi?l0003o
E8?Ro`000002ogbNj003o`000?nQ]^OoXKKW00;oXKKW00Co0000okg6h_nma^;o_LKR0_l00005om3:
e@03o`000?oKc<_oflc;00Koflc;00Go0000on7<a?oQc<CohLc4o`000005omRn`0;o00001ooJ_;/0
0ol0003ock6kolna^`03olna^`;o00001_o?[[T00ol0003o`jJkol>V^`09ol>V^`Co00003?ndWl<0
0ol0003oYjCCojNTd`08ojNTdaWo000000?oN]cko`000?l000002Ol000000oo1mnko0000olKYkP02
olKYkP04o`000?o3f>Wo`mSYo`0000Co_<OS00?o0000ok>hg?nc^=`00_nc^=`00ol0003o[:cGojb/
e`03ojb/e`03o`000?nUXm?oYJ?C00?oYJ?C00?o0000oinLdOnOW=400onOW=400ol0003oSho?o`00
0006ohZ;cP03o`000?n7RLkoQhW>00CoQhW>00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0AOooool01Ol08jSo02jao`1=bOl0CLWo000000;o8gST0ol000000omlW^So0000oj6f
i`03oj6fi`?o000000?o_LKQo`000?o@b]D01Oo@b]D00ol0003oflc;om_<b`05om_<b`05o`000?oQ
c<CohLc4on7<a?l000001ooH_/000ol0003of[bkomZl^`04omZl^`03o`000?o?/K_ock6k00Gock6k
0_l00004oln^^@03o`000?o3Y[_o`jJk00co`jJk00Co0000okBO`ol0003o00002OndWl<00ol0003o
YjCCojNTd`0:ojNTd`03o`000?nH^_3oV;[`00WoV;[`00?o0000og[Lnomjg?/01Omjg?/4o`000005
oi[Uo?l0003o0000o`000?n^i_T00_l00003okWPl`Co000000Goa^W^o`000?o3f>Wo`mSYo`000004
okc7h`03o`000?nc^=co/kSL00;o/kSL00?o0000ojb/eon/[=L00on/[=L00ol0003oYJ?CojFSd`03
ojFSd`03o`000?nOW=7oWicA00CoWicA0ol00005ohZ;cP03o`000?n7RLkoQhW>00CoQhW>00?o0000
ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool01ol08jSo02jao`1=bOl0CLWo
0000ob=hi?l000000_mWXO87o`0000Co_LKQ00?o0000om3:eOo@b]D01?o@b]D00ol0003oflc;om_<
b`05om_<b`03o`000?oQc<Co000000Wof;k00_l00003omZl^`03o`000?o?/K_ock6k00Sock6k0ol0
00000oo?[[Wo0000ol>V^`0=ol>V^`04o`000?niXl?o^J?3okVS``Oo00000_ndWl<00ol0003oYjCC
ojNTd`0:ojNTd`03o`000?nH^_3oV;[`00[oV;[`00?o0000og[Lnomjg?/01?l00002oi[Uo0?o0000
0_n^i_T2o`0000?o^N3c0_l00003okgHk@?o000000?o`mSYo`000?nlan<00onlan<00ol0003o/kSL
ok>hg002ok>hg003o`000?n/[=Oo[:cG00;o[:cG0_l00004ojFSd`;o00001_nOW=401Ol0003oViS@
oi^Hd?nKV=3o000000?oRX_>00?o0000ohN9c_n7RLh01?n7RLh00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`15ooooo`07o`0SZ?l0003o04g9o`1=bOl0003o8gSTo`000002ofNQ
lP03o`000?nL^^koW;[^00;oW;[^00?o0000okg6hOnma^400onma^400ol0003od<[Eom3:e@04om3:
e@03o`000?oKc<_oflc;00Goflc;0_l0000;omRn`004o`000?oJ_;_of[bko`0000gock6k00?o0000
ol>V^oo3Y[/03?o3Y[/00ol0003o^J?3okVS``09okVS``[o00001_nWY=<00ol0003oV;[`oiRjl004
oiRjl0So00001?nJiO`2o`0000?o[^Ki0_l00003okWPl`;o00000onmf>d2o`0000;o_LoW0ol00003
okc7h`03o`000?nc^=co/kSL00;o/kSL00?o0000ojb/eon/[=L00_n/[=L00ol0003oYJ?CojFSd`03
ojFSd`03o`000?nOW=7oWicA00GoWicA00?o0000oi^Hd?nKV=000onKV=000ol0003oRX_>o`000006
ohN9cP03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05
ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000A_ooool2o`0000;o04g900?o0000ob=h
i?l000000_mWXO800ol0003oW;[^oibjkP02oibjkP03o`000?nma^7o_LKQ00?o_LKQ00?o0000om3:
eOo@b]D00oo@b]D00ol0003oflc;om_<b`05om_<b`03o`000?oD`LOo000000_of;k000?o0000omZl
^ol000003Oo?/K/00ol0003oaJVmolFY_@03o`0000Wo`jJk00?o0000okVS`oniXl<02oniXl<00ol0
003o[jWBojnYdP05ojnYdPgo00001onV_n`00ol0003oV^Glo`000002o`0000?o[^Ki0_l00003okWP
l`;o00001?nmf>d01Ol0003o_LoWokg?ionmcnOo000000?o^lKS00?o0000okc7hol000001?nc^=`0
0ol0003o[:cGojb/e`02ojb/e`03o`000?nUXm?oYJ?C00?oYJ?C00?o0000oinLdOnOW=401?nOW=42
o`0000KoViS@0_l00006ohN9cP03o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`14ooooo`;o000000Go04g9o`00
0?lSN>Co8gSTo`000002ofNQlP03o`000?nL^^koW;[^00;oW;[^00?o0000okg6hOnma^400_nma^40
0ol0003od<[Eom3:e@04om3:e@03o`000?oKc<_oflc;00?oflc;00Co0000omC1aooD`LOoe<770_l0
000:omRn`0;o00003Oo?/K/00ol0003oaJVmolFY_@03olFY_@Co00001Oo3Y[/00ol0003o^J?3okVS
``0;okVS``03o`000?n_ZM;o[jWB00_o[jWB00?o0000ojJok?nV_n`02_nV_n`3o`0000Co[^Ki0_l0
0004okWPl`03o`000?nmf>go_MS]00;o_MS]0_l00002okg?i`;o00001?nka^<3o`0000?o/kSL00?o
0000ojb/eon/[=L00_n/[=L00ol0003oYJ?CojFSd`03ojFSd`03o`000?nOW=7oWicA00CoWicA00?o
0000oi^Hd?nKV=001OnKV=000ol0003oV9OAo`000005ohN9cP03o`000?oooooooooo01kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`14
ooooo`04o`0^/Ol0003o04g9o`0000;o8gST00Co0000ofNQl_mWXO;o00001?nL^^h00ol0003o_LKQ
okg6h@02okg6h@03o`000?o@b]God<[E00Cod<[E00Go0000om_<booKc<_oflc;o`000006omC1a`03
o`000?oH_/3of;k000Oof;k000?o0000olnd_ol000000_l00009olna^`03o`000?o5ZKgoaJVm00So
aJVm0ol000000oo3Y[_o0000okVS``0=okVS``03o`000?n_ZM;o[jWB00_o[jWB00?o0000ojJok?nV
_n`01OnV_n`5o`0000?o/<;X00Co0000ojkVnOl0003o00001?nih?<2o`0000?o_MS]0_l00002okg?
i`;o00001Onka^<01ol0003o^;kNokRng_nh_]ko0000ok>hg?l000001?n/[=L00ol0003oYJ?CojFS
d`03ojFSd`03o`000?nOW=7oWicA00CoWicA00?o0000oi^Hd?nKV=001OnKV=001Ol0003oV9OAoiRG
dOnHUm7o000000?oQhW>00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo000Tooooo`;o0000AOooool01?l0003o04g9o`1=bOl00002ob=hi003o`00
0?mWXO;o000000CoW;[^00?o0000okg6hOnma^400onma^400ol0003od<[Eom3:e@04om3:e@03o`00
0?oKc<_o000000Soe<770_l00006omRn`003o`000?o?];oockBo00?ockBo0ol00006olna^`03o`00
0?o5ZKgoaJVm00_oaJVm0_l000000oniXl?o0000o`000005o`0000Ko^J?300?o0000ojnYd_n_ZM80
3?n_ZM800ol0003oY[o/o`000004o`0000Oo/<;X0ol00004okWPl`;o00000onmf>d2o`0000?o_LoW
00?o0000ok_6honka^<00onka^<2o`0000Co^;kN0ol00003ojb/e`03o`000?nUXm?oYJ?C00;oYJ?C
0_l00005oinLd@;o00001_nKV=02o`0000GoV9OA00?o0000ohN9c_l000009?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Cooooo000Vooooo`03o`000?oooooooooo04?ooooo00Co
0000o`1=bOl0CLWo00000_lSN>@00ol0003oIj7bo`000004oibjkP03o`000?nma^7o_LKQ00?o_LKQ
00?o0000om3:eOo@b]D01?o@b]D00ol0003oe<77omC1a`09omC1a`03o`000?oH_/3of;k000?of;k0
00?o0000olnd_oo?];l01_o?];l2o`0000Cock6k00?o0000olFY_Oo5ZKd03?o5ZKd00ol0003o_:O4
okbWa006okbWa1Oo00002?n``^P4o`0000?o]/CU00Co0000okWPlol0003o00000onmf>d2o`0000?o
_LoW0_l00005ok_6h`03o`000?nh_]ko^;kN00?o^;kN00Oo0000okBgfond]m_o];OKo`000?n/[=Oo
000000CoYJ?C00?o0000oinLdOnOW=401?nOW=400ol0003oViS@oi^Hd005oi^Hd003o`000?nHUm7o
V9OA00GoV9OA0_l0000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool0
02Oooooo00?o0000ooooooooool0@oooool00ol0003o04g9o`000002ob=hi004o`000?mWXO;oIj7b
o`0000CoW;[^00?o0000okg6hOnma^400_nma^400ol0003od<[Eom3:e@03om3:e@04o`000?o<`m;o
c<?Bo`0000[oe<770_l00002omRn`003o`000?o?];oockBo00WockBo1?l0000?olFY_@03o`000?nl
YlCo_:O400co_:O400?o0000okB]d_nd[M803?nd[M800ol0003o/<;Xok32j004ok32j0?o00001onf
a>D2o`0000Co_MS]00?o0000okg?ionmcnL00_nmcnL00ol0003o^lKSok_6h`03ok_6h`;o00001?nh
_]h2o`0000Co];OK0ol00003ojFSd`03o`000?nOW=7oWicA00CoWicA00?o0000oi^Hd?nKV=001?nK
V=02o`0000KoV9OA0_l0000Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool002Sooooo00?o0000ooooooooool0@oooool00ol0003o04g9o`000002ob=hi004o`000?mWXO;o
Ij7bo`0000CoW;[^00?o0000okg6hOnma^400_nma^401Ol0003od<[Eom3:eOo@b]Go000000Coc<?B
0_l0000:omC1a`03o`000?oH_/3o000000kockBo00Co0000olFY_Oo5ZKgo00003?o5ZKd00ol0003o
_:O4okbWa00<okbWa003o`000?nd[M;o]:gB00go]:gB00?o0000ok32j?l000000ol00007okK4i@?o
00000_niaN<01?l0003o_MS]o`000?l00003okg?i`;o00001?nka^<2o`0000Co^;kN0_l00004okBg
f`;o00000on`/MT00ol0003oYJ?Co`000006oinLd@03o`000?nKV=3oViS@00CoViS@00?o0000oiRG
dOnHUm401OnHUm400ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01?ooool002Wooooo0_l00014ooooo`?o00000_lSN>@01?l0003oIj7bofNQl_l00003oibj
kP03o`000?nma^7o_LKQ00?o_LKQ00?o0000om3:eOl000001oo<`m800ol0003oe<77omC1a`08omC1
a`03o`000?o?];oockBo00gockBo00Co0000olJ]`_o6[L;oaZg21Ol00006olFY_@03o`000?nlYlCo
_:O400go_:O400?o0000okB]d_nd[M802Ond[M86o`0000So]/CU0ol00005okW5h`;o00000onmcnL2
o`0000Go^lKS00?o0000okRng_nh_]h00onh_]h00ol0003o];OKokBgf`03okBgf`03o`000?n`/MWo
/;7I00?o/;7I0_l00005oinLd@;o00001_nKV=000ol0003oV9OAoiRGd@04oiRGd@;o0000;Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooooooo
04?ooooo0_l00002ob=hi003o`000?mWXO;o000000CoW;[^00?o0000okg6hOnma^400_nma^42o`00
00Woc<?B0_l00008omC1a`03o`000?o=^<Ko000000;o00002_o?];l00ol0003oaZg2olJ]`P07olJ]
`PGo000000?oaJVmo`000?nlYl@03_nlYl@01?l0003o]:gBokB]d_nd[M88o`0000Co^;;D00?o0000
okK4iOnfa>D01Onfa>D2o`0000Go^LGS0ol00002ok_5hP03o`000?nmcnOo000000Go^lKS0_l00004
okRngP;o00001?nd]m/2o`0000Co/;7I0_l00002ojb]f005o`000?nOW=7oWicAoinLdOl000001_nK
V=02o`0000GoV9OA0_l0000_ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool002cooooo00?o0000ooooooooool0@oooool5o`000003ofNQl_l0003oW;[^00?oW;[^00Co0000
okg6hOl0003o00000onmaN400ol0003oc<?Bolc3dP07olc3dP03o`000?oD`LOoe<7700Coe<7700?o
0000olfha_o=^<H00oo=^<H3o`0000OockBo00?o0000olJ]`_o6[L803?o6[L82o`000003okbWa?l0
003o0000013o00003?nh/]@00ol0003o]/CUokK4i@02okK4i@?o00001OniaN<2o`0000Go^lGR0_l0
0005ok_6h`03o`000?nh_]ko^;kN00;o^;kN0_l00004okBgf`;o00001?n`/MT2o`0000Go[:gH00?o
0000oinLdOl000001_nKV=000ol0003oV9OAoiRGd@03oiRGd@;o0000<_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo000]ooooo`03o`000?oooooooooo04Cooooo1_l00002
oibjkP?o00001_nmaN42o`0000Soc<?B0_l00003omC1a`03o`000?o=^<KocKS600OocKS60ol00004
olnd_`03o`000?o6[L;oaZg200goaZg200?o0000okj/b?nn[<P03Onn[<P00ol0003o^;;DokRbe00>
okRbe0Co00001OniaN<3o`0000Go^lGR0_l000000onkaN;o0000ok_6h`02ok_6h`;o00001?nh_]h0
0ol0003o];OKokBgf`02okBgf`;o00001On`/MT00ol0003o[:gHojb]f005ojb]f0;o00001OnKV=02
o`0000GoV9OA00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00?ooooo000^ooooo`;o0000AOooool3o`000004o`1bfOmJZoWo0000o`0000CoW<;c1onmaN42
o`0000Soc<?B00?o0000omC1aol000003Oo=^<H4o`00013oaZg200?o0000okj/b?nn[<P03Onn[<P0
0ol0003o^;;DokRbe00;okRbe0Co00001_niaN<2o`0000Go^lGR0ol00004ok_5hP03o`000?nka^?o
000000Co^;kN0_l00004okBgf`03o`000?n`/MWo/;7I00?o/;7I0_l00006ojb]f0;o00000_nXZ]P0
1Ol0003oViS@oi^Hd?nKV=3o000000GoV9OA0_l0000gooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0A?ooool4o`000003oeZ[nOnL`_?o
W<;c00?oW<;c0_l00006okg5h@03o`000?o<`m;oc<?B00Koc<?B00?o0000olfha_o=^<H03oo=^<H0
1?l0003oaZg2olJ]`_l0000=olJ]`P03o`000?nn[<So_Zc800go_Zc800?o0000okRbe?nh/]@01Onh
/]@6o`0000?o^[SG00?o0000okW5honiaN<00_niaN<2o`0000Go^lGR0_l00007ok_5hP;o00000onh
_]h2o`0000Co];OK0_l00004ok2af@;o00001_n/[MP2o`0000GoZ:[H00?o0000oi^Hd?l000001?nH
Um42o`0003Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool0
0ol0003oooooooooo`15ooooo`05ogh00?l0003o07;Io`000?mJZoT01OnL`_<00ol0003o_LGQokg5
h@04okg5h@;o00001_o<`m800ol0003ob;kAolRnd@03o`0000cocKS600Co0000olFcb?o5/lSoaK?8
1Ol00007olJ]`P03o`000?nn[<So_Zc800ko_Zc800?o0000okRbe?nh/]@01Ol0000:okZhe`Co0000
1OnkaN82o`0000Ko^lGR0ol00002ok[5h`03o`000?nh_]ko000000Co];OK0_l00004ok2af@;o0000
1_n/[MP2o`0000OoZ:[H0_l00004oiRGd@03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`03ooooo`00<_ooool00ol0003oooooooooo`15ooooo`Co000000?o
FZ_io`000?l000000onL`_<2o`0000Ko_LGQ0_l00003olc3dP03o`000?o8_]7ob;kA00Cob;kA0ol0
0008olfhaP03o`000?o5/lSoaK?800OoaK?81Ol00002olJ]`P03o`000?nn[<So_Zc800Ko_Zc82ol0
000=okZhe`?o00001_nkaN82o`0000Ko^lGR0_l00005ok[5h`;o00001?nd]m/00ol0003o/;7Iok2a
f@02ok2af@;o00001_n/[MP2o`0000KoZ:[H0ol00002ojBYf@04o`000?nHUm7o0000o`0003kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<oooool2o`0004Oooooo00Go
OP00o`000?l0L]Wo0000oeZ[n@02o`0000?oW<;c0_l00006okg5h@03o`000?o<`m;o000000[ob;kA
0ol00004olfhaP03o`000?o5/lSoaK?800goaK?82ol00008oknbcP03o`000?nj^=Oo^[SG00So^[SG
1Ol00002okbng004o`000?nkaN;o^lGRok_5hP?o00001_nkaN82o`0000Co^/GS0ol00002okS5i004
o`000?nd]m_o0000o`0000Co/;7I00?o0000ojb]f?n/[MP00on/[MP3o`0000KoZ:[H0_l00005ojBY
f@;o0000@Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000eooooo`03
o`000?oooooooooo04Gooooo1Ol000000omJZoWo0000oic2l`03oic2l`03o`000?nmaN7o_LGQ00Co
_LGQ00?o0000olRndOo8_]403?o8_]43o`000003olfha_l0003oaK?8013oaK?800?o0000oknbc_no
//h03_no//h00ol0003o^[SGokZhe`04okZhe`Co00002?nl_]`3o`0000Ko^lGR0ol00004ok[5h`;o
00001OnhaN@2o`0000Co/;7I0_l00004ojb]f0;o00001_nXZ]P3o`0000CoY:WI0ol00013ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0
A_ooool4o`000003oeZ[nOl0003o000000?oW<;c0_l00003okg5h@04o`000?nlaN7o_<GQokc5h@?o
00003?o8_]400ol0003oaK?8olFcb002olFcb003o`000?o5/lSoaK?800_oaK?800?o0000oknbc_no
//h03_no//h01?l0003o^[SGokZheonj^=L3o`0000[o_;kL0ol00006ok_5hP;o00001?njaN<3o`00
00Co^<GT0ol00002okC4iP04o`000?n`/MWo0000o`0000Co[:gH0_l00006ojRZf0;o00001OnTZMT2
o`0004Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00
04Oooooo1Ol000000omJZoWo0000o`000003oic2l`03o`000?nmaN7o000000Oo_<GQ0ol00009olRn
d@03o`000?o3^m;o`k_B00?o`k_B2Ol00003olFcb003o`000?no//ko_k;>00Ko_k;>2ol0000;okbn
g0Co00000_nkaN800ol0003o^lGRok_5hP02ok_5hP;o00001?njaN<2o`0000Co^<GT0ol00004okC4
iP?o00001?n/[MP2o`0000KoZ:[H0_l00004ojBYf@?o0000B_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo04Kooooo00CoF`00o`000?l0
003o00000_mJZoT00ol0003oW<;coic2l`02o`0000_o_<GQ0ol00005olRnd@03o`000?o3^m;o`k_B
00go`k_B1?l000000ono//ko0000o`000005o`0000Wo_[[F00?o0000okbng?nl_]`01_nl_]`4o`00
00Oo^lGR1?l00003ok[5h`?o00001?nhaN@2o`0000Co]<CV0ol00003ok33i`04o`000?n/[MSo0000
o`0000GoZ:[H0ol00004ojBYf@;o0000C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo000jooooo`03o`000?oooooooooo04Sooooo1_l00004oj7:m@?o00002OnlaN43o`00
00;ob;kA00?o0000ol>kd_o3^m804?o3^m800ol0003o_[[FokjjeP0?okjjeP03o`000?nl_]co_;kL
00?o_;kL0ol00009ok_5hP?o00001?njaN<2o`0000Co^<GT0ol00003okC4iP?o00001On``nL3o`00
00GoZ:[H0_l00005ojBYf@;o0000D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo000kooooo`03o`000?oooooooooo04[ooooo00Go0000oenkoOmO^ogoGk_mo`000005oj7:
m@Co00002?nlaN42o`0000Co`k_B00?o0000ol>kd_o3^m802oo3^m800ol0003o_[[FokjjeP0@okjj
eP03o`000?nl_]co_;kL00?o00002?nkaN84o`0000;o^<cY00?o0000ok[5hol000000_l00004okS5
i0;o00000onda>H3o`0000Go/<?W0ol00003ojc1j@03o`000?nXZ]So000000;o00001?nTZMT3o`00
05?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00??ooool2o`0004co
oooo00?oF`00o`000?mO^od00_mO^od3o`0000CoXL[e0ol00006okc5h@03o`000?nlaN7o_<GQ00?o
_<GQ2Ol00004ol>kdP03o`000?nn^]Ko_[[F00Ko_[[F3?l00008ok_5hPCo00001Onhc>T3o`0000Co
^<GT0ol00002okC4iP?o00001On``nL3o`0000Go[<7Y0ol00005ojBYf@;o0000Eoooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000nooooo`03o`000?oooooooooo04cooooo
00?o087Bo`000?l000000_mO^od3o`0000CoXL[e0ol00002okc5h@03o`000?nlaN7o_<GQ00go_<GQ
1?l000000onn^]Ko0000o`000006o`0000[o^lGQ00?o0000ok_5h_nkaN800onkaN84o`0000Co^<cY
1Ol00002ok?Bl003o`000?nhaNCo000000;o00000_nda>H3o`0000Co/<?W1?l00004ojc1j@Co0000
0onW`>/00ol0003oY:WIo`000002o`0005[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00?oooool00ol0003oooooooooo`1>ooooo`03o`21d_l0003o000000;oGk_m0ol0
0004oj7:m@;o00004onlaN400ol0003o^lGQok_5h@0Aok_5h@04o`000?nkaN;o^lGRok_5hP;o0000
1?nhc>T4o`0000Go/m;`1?l00002okC4iP?o00001?n``nL3o`0000Co[<7Y1?l00005ojO0j`Co0000
GOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oo
oooooooo053ooooo0ol00002oenko@?o000000?oXL[eo`000?nZco<01OnZco<9o`0000Co_<GQ00?o
0000ok_5hOnkaN402?nkaN4<o`0000Go^<cY0ol00003ok?Bl0Ko000000?oZ]Ogo`000?l000000ol0
0004ok33i`?o00000_n/`NT5o`0000CoYl3[1Ol0001Rooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool0047ooooo0_l0001Cooooo`?o00000_mO^od00ol0003oZ/ocoj[?l`0>
oj[?l`Go00000_nkaN48o`0000[o/m3_00Co0000okS<jOnhc>Wo^<cY0_l00002ok?Bl0Go000000?o
Z]Ogo`000?l000001?l00003oikHo003o`000?n``nOo/<?W00?o000000?o[<7Yo`000?l000000_l0
0004ojO0j`Go0000J?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0013
ooooo`03o`000?oooooooooo05?ooooo1_l00002ogg?o`[o00001OnZco<00ol0003o/m3_ok?@k`07
ok?@k`_o000000Co^<cYok?Bl?ncd_3o/m;`2_l00006oikHo0[o00000onW`>/5o`0006kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`1G
ooooo`co000000?oOLooo`000?l000000ol00003ok?@k`Oo00001OnOfO`6o`000003ok?Bl?l0003o
000000Go00000onNf?`?o`0000;oYl3[1Ol0001cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00Oooool004Gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`04oooo
o`[o00001OnOfO`5o`0000GoNmKn2Ol000000onNf?co0000o`00000=o`000003ohWCool0003o0000
00Oo0000NOooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00A_ooool2o`0005Ko
oooo00?o0000ooooooooool02Oooool01?l0003o:jgWo`000?l00005og_FoQOo000000?oRM?oo`00
0?l000002ol00023ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0018ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool08?ooool:o`00097ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00Boooool2o`00057ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004kooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
Coooool2o`0004gooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool0057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`30ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0<3ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Cooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo0000007ooooo001Doooo
o`;o0000B?ooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`00007ooooo001Foooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0`oooool00ol0003oooooo`000001oooo
o`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0<?ooooo00?o0000oooooooo
ool00Ol0000005Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`34ooooo`7o0000
0Oooool1o`000000FOooool2o`0004?ooooo00?o0000ooooooooool0aOooool2o`000000Foooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo0ol0000005cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`30ooooo`Co00000oooool005gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`2looooo`Co00001oooool005kooooo0_l0000nooooo`03o`00
0?oooooooooo0;Sooooo1?l0000;ooooo`00H?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;Cooooo1?l0000?ooooo`00HOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo0;7ooooo0ol0000Cooooo`00H_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
0:gooooo1?l0000Fooooo`00Hoooool2o`0003Wooooo00?o0000ooooooooool0ZOooool4o`0001[o
oooo001Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOooool4o`0001kooooo
001Vooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`0002;ooooo001W
ooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00009_ooool006Wooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2Jooooo`Co0000:_ooool006[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`2Fooooo`Co0000;_ooool006_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Booooo`Co0000<_ooool006cooooo0_l0000_ooooo`03o`000?oo
oooooooo08kooooo1?l0000fooooo`00K_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo08[ooooo1?l0000jooooo`00Koooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
08Oooooo0ol0000nooooo`00L?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?o
oooo1?l00011ooooo`00LOooool2o`0002[ooooo00?o0000ooooooooool0Ooooool4o`0004Gooooo
001cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Noooool4o`0004Wooooo001d
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004gooooo001eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00057ooooo001fooooo`;o
00009Oooool00ol0003oooooooooo`1_ooooo`Co0000EOooool007Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1[ooooo`Co0000FOooool007Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Wooooo`Co0000GOooool007[ooooo0_l0000Qooooo`03o`000?oooooo
oooo06?ooooo1?l0001Qooooo`00O?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
063ooooo0ol0001Uooooo`00OOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05co
oooo1?l0001Xooooo`00O_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Sooooo
1?l0001/ooooo`00Ooooool2o`0001cooooo00?o0000ooooooooool0E?ooool4o`00073ooooo0021
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`0007Cooooo0022oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool4o`0007Sooooo0023ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007cooooo0024ooooo`;o0000
5oooool00ol0003oooooooooo`14ooooo`Co0000P?ooool008Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`10ooooo`Co0000Q?ooool008Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0looooo`Co0000R?ooool008Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0iooooo`?o0000S?ooool008Wooooo0_l0000Booooo`03o`000?oooooooooo03Go
oooo1?l0002?ooooo`00Roooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo
1?l0002Cooooo`00S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo1?l0
002Gooooo`00SOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo1?l0002K
ooooo`00S_ooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`0009oooooo002@ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`000:?ooooo002Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:Oooooo002Booooo`;o00002?oo
ool00ol0003oooooooooo`0Jooooo`Co0000Zoooool009Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`Co0000[oooool009Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000/oooool009Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`?o0000]oooool009Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo
1?l0002jooooo`00VOooool01?l0003oooooooooool00009ooooo`Co0000__ooool009[ooooo00?o
0000ooooool000001Oooool4o`000<;ooooo002Kooooo`;o000000?oooooo`000?l000000_l00036
ooooo`00W?ooool2o`000<[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65641 m .51694 .65827 L .43899 .65168 L p .286 .744 .953 r
F P
0 g
s
.51694 .65827 m .51723 .65641 L .59268 .64991 L p .575 .818 .99 r
F P
0 g
s
.59268 .64991 m .59527 .65394 L .51694 .65827 L p .575 .818 .99 r
F P
0 g
s
.59527 .65394 m .59268 .64991 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44208 .65206 L .51723 .65641 L p .286 .744 .953 r
F P
0 g
s
.44208 .65206 m .43899 .65168 L .36521 .63435 L p 0 .48 .744 r
F P
0 g
s
.51753 .65434 m .51723 .65641 L .44208 .65206 L p .333 .771 .966 r
F P
0 g
s
.51723 .65641 m .51753 .65434 L .59005 .64573 L p .6 .826 .986 r
F P
0 g
s
.59005 .64573 m .59268 .64991 L .51723 .65641 L p .6 .826 .986 r
F P
0 g
s
.59268 .64991 m .59005 .64573 L .65915 .62672 L p .67 .756 .915 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59268 .64991 L p .67 .756 .915 r
F P
0 g
s
.36521 .63435 m .37093 .63691 L .44208 .65206 L p 0 .48 .744 r
F P
0 g
s
.44208 .65206 m .4452 .65217 L .51753 .65434 L p .333 .771 .966 r
F P
0 g
s
.4452 .65217 m .44208 .65206 L .37093 .63691 L p 0 .524 .78 r
F P
0 g
s
.51784 .65165 m .51753 .65434 L .4452 .65217 L p .431 .811 .991 r
F P
0 g
s
.51753 .65434 m .51784 .65165 L .5874 .6412 L p .633 .829 .976 r
F P
0 g
s
.5874 .6412 m .59005 .64573 L .51753 .65434 L p .633 .829 .976 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72962 .60566 L p .647 .675 .863 r
F P
0 g
s
.72962 .60566 m .73799 .61332 L .67023 .63881 L p .647 .675 .863 r
F P
0 g
s
.59005 .64573 m .5874 .6412 L .65355 .62061 L p .684 .76 .909 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59005 .64573 L p .684 .76 .909 r
F P
0 g
s
.30757 .61138 m .31583 .61564 L .366 .63502 L p 0 .331 .668 r
F P
0 g
s
.37093 .63691 m .36521 .63435 L .3116 .61189 L p .298 0 0 r
F P
0 g
s
.37093 .63691 m .3116 .61189 L .31897 .61503 L .298 0 0 r
F
.37093 .63691 m .37673 .63916 L .4452 .65217 L p 0 .524 .78 r
F P
0 g
s
.29943 .6068 m .30757 .61138 L .37093 .63691 L p .298 0 0 r
F P
0 g
s
.37673 .63916 m .37093 .63691 L .34385 .626 L p 0 .331 .668 r
F P
0 g
s
.34385 .626 m .30757 .61138 L p .34559 .62665 L 0 .331 .668 r
F P
0 g
s
.37673 .63916 m .34385 .626 L .34559 .62665 L 0 .331 .668 r
F
.35895 .63202 m .30757 .61138 L .366 .63502 L F
.366 .63502 m .37673 .63916 L p .35895 .63202 L F P
0 g
s
.44839 .65143 m .4452 .65217 L .37673 .63916 L p .114 .636 .882 r
F P
0 g
s
.37673 .63916 m .38264 .64039 L .44839 .65143 L p .114 .636 .882 r
F P
0 g
s
.37673 .63916 m .31583 .61564 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.38264 .64039 m .37719 .63925 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.37719 .63925 m .37673 .63916 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.33288 .62004 m .3887 .63996 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.31583 .61564 m .32425 .61877 L .35028 .62841 L p 0 .464 .796 r
F P
0 g
s
.34861 .62779 m .31583 .61564 L .35028 .62841 L 0 .464 .796 r
F
.32425 .61877 m .33252 .61999 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.33252 .61999 m .33288 .62004 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.35028 .62841 m .38264 .64039 L p .34861 .62779 L 0 .464 .796 r
F P
0 g
s
.3116 .61189 m .29943 .6068 L p .31897 .61503 L .298 0 0 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72121 .59807 L p .658 .68 .859 r
F P
0 g
s
.72121 .59807 m .72962 .60566 L .66471 .63279 L p .658 .68 .859 r
F P
0 g
s
.4452 .65217 m .44839 .65143 L .51784 .65165 L p .431 .811 .991 r
F P
0 g
s
.51815 .64796 m .51784 .65165 L .44839 .65143 L p .544 .835 .999 r
F P
0 g
s
.51784 .65165 m .51815 .64796 L .58471 .63614 L p .665 .823 .959 r
F P
0 g
s
.58471 .63614 m .5874 .6412 L .51784 .65165 L p .665 .823 .959 r
F P
0 g
s
.5874 .6412 m .58471 .63614 L .6479 .61445 L p .697 .764 .903 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .5874 .6412 L p .697 .764 .903 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71278 .59074 L p .671 .689 .859 r
F P
0 g
s
.71278 .59074 m .72121 .59807 L .65915 .62672 L p .671 .689 .859 r
F P
0 g
s
.58199 .63037 m .58471 .63614 L .51815 .64796 L p .692 .809 .938 r
F P
0 g
s
.58471 .63614 m .58199 .63037 L .64221 .60824 L p .708 .767 .898 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58471 .63614 L p .708 .767 .898 r
F P
0 g
s
.44839 .65143 m .45164 .64932 L .51815 .64796 L p .544 .835 .999 r
F P
0 g
s
.51846 .64298 m .51815 .64796 L .45164 .64932 L p .635 .829 .975 r
F P
0 g
s
.51815 .64796 m .51846 .64298 L .58199 .63037 L p .692 .809 .938 r
F P
0 g
s
.45164 .64932 m .44839 .65143 L .38264 .64039 L p .342 .755 .979 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70433 .58388 L p .684 .704 .862 r
F P
0 g
s
.70433 .58388 m .71278 .59074 L .65355 .62061 L p .684 .704 .862 r
F P
0 g
s
.57923 .62378 m .58199 .63037 L .51846 .64298 L p .71 .79 .914 r
F P
0 g
s
.58199 .63037 m .57923 .62378 L .63648 .60198 L p .716 .769 .894 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58199 .63037 L p .716 .769 .894 r
F P
0 g
s
.45164 .64932 m .45497 .64538 L .51846 .64298 L p .635 .829 .975 r
F P
0 g
s
.51879 .63645 m .51846 .64298 L .45497 .64538 L p .692 .802 .933 r
F P
0 g
s
.51846 .64298 m .51879 .63645 L .57923 .62378 L p .71 .79 .914 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69586 .57763 L p .697 .723 .869 r
F P
0 g
s
.69586 .57763 m .70433 .58388 L .6479 .61445 L p .697 .723 .869 r
F P
0 g
s
.38264 .64039 m .3887 .63996 L .45164 .64932 L p .342 .755 .979 r
F P
0 g
s
.45497 .64538 m .45164 .64932 L .3887 .63996 L p .543 .809 .995 r
F P
0 g
s
.73799 .61332 m .72962 .60566 L .78364 .56952 L p .606 .614 .833 r
F P
0 g
s
.78364 .56952 m .79464 .57831 L .73799 .61332 L p .606 .614 .833 r
F P
0 g
s
.72962 .60566 m .72121 .59807 L .77262 .56091 L p .617 .619 .831 r
F P
0 g
s
.77262 .56091 m .78364 .56952 L .72962 .60566 L p .617 .619 .831 r
F P
0 g
s
.57643 .61632 m .57923 .62378 L .51879 .63645 L p .72 .768 .891 r
F P
0 g
s
.57923 .62378 m .57643 .61632 L .6307 .59568 L p .72 .77 .892 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57923 .62378 L p .72 .77 .892 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68739 .5721 L p .71 .746 .88 r
F P
0 g
s
.68739 .5721 m .69586 .57763 L .64221 .60824 L p .71 .746 .88 r
F P
0 g
s
.45497 .64538 m .45837 .63929 L .51879 .63645 L p .692 .802 .933 r
F P
0 g
s
.51911 .62827 m .51879 .63645 L .45837 .63929 L p .722 .767 .889 r
F P
0 g
s
.51879 .63645 m .51911 .62827 L .57643 .61632 L p .72 .768 .891 r
F P
0 g
s
.30757 .61138 m .29943 .6068 L .24558 .56996 L p 0 .252 .686 r
F P
0 g
s
.3887 .63996 m .3949 .63729 L .45497 .64538 L p .543 .809 .995 r
F P
0 g
s
.45837 .63929 m .45497 .64538 L .3949 .63729 L p .664 .799 .947 r
F P
0 g
s
.72121 .59807 m .71278 .59074 L .76164 .55289 L p .631 .633 .834 r
F P
0 g
s
.76164 .55289 m .77262 .56091 L .72121 .59807 L p .631 .633 .834 r
F P
0 g
s
.3887 .63996 m .38264 .64039 L .32425 .61877 L p .188 .64 .942 r
F P
0 g
s
.5736 .60797 m .57643 .61632 L .51911 .62827 L p .723 .747 .87 r
F P
0 g
s
.57643 .61632 m .5736 .60797 L .62488 .58932 L p .72 .77 .892 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57643 .61632 L p .72 .77 .892 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .6789 .56737 L p .721 .772 .893 r
F P
0 g
s
.6789 .56737 m .68739 .5721 L .63648 .60198 L p .721 .772 .893 r
F P
0 g
s
.45837 .63929 m .46184 .63087 L .51911 .62827 L p .722 .767 .889 r
F P
0 g
s
.51945 .61843 m .51911 .62827 L .46184 .63087 L p .735 .735 .851 r
F P
0 g
s
.51911 .62827 m .51945 .61843 L .5736 .60797 L p .723 .747 .87 r
F P
0 g
s
.71278 .59074 m .70433 .58388 L .75069 .54581 L p .65 .655 .842 r
F P
0 g
s
.75069 .54581 m .76164 .55289 L .71278 .59074 L p .65 .655 .842 r
F P
0 g
s
.3949 .63729 m .40126 .63198 L .45837 .63929 L p .664 .799 .947 r
F P
0 g
s
.46184 .63087 m .45837 .63929 L .40126 .63198 L p .723 .767 .888 r
F P
0 g
s
.24558 .56996 m .25585 .57634 L .30757 .61138 L p 0 .252 .686 r
F P
0 g
s
.31583 .61564 m .30757 .61138 L .25585 .57634 L p 0 .292 .722 r
F P
0 g
s
.70433 .58388 m .69586 .57763 L .73979 .53997 L p .672 .685 .855 r
F P
0 g
s
.73979 .53997 m .75069 .54581 L .70433 .58388 L p .672 .685 .855 r
F P
0 g
s
.3949 .63729 m .3887 .63996 L .33288 .62004 L p .462 .756 .993 r
F P
0 g
s
.57074 .5988 m .5736 .60797 L .51945 .61843 L p .721 .726 .855 r
F P
0 g
s
.5736 .60797 m .57074 .5988 L .61901 .58292 L p .714 .769 .895 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .5736 .60797 L p .714 .769 .895 r
F P
0 g
s
.46184 .63087 m .46538 .62011 L .51945 .61843 L p .735 .735 .851 r
F P
0 g
s
.51978 .60705 m .51945 .61843 L .46538 .62011 L p .738 .708 .822 r
F P
0 g
s
.51945 .61843 m .51978 .60705 L .57074 .5988 L p .721 .726 .855 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67038 .56342 L p .726 .8 .91 r
F P
0 g
s
.67038 .56342 m .6789 .56737 L .6307 .59568 L p .726 .8 .91 r
F P
0 g
s
.40126 .63198 m .40777 .62382 L .46184 .63087 L p .723 .767 .888 r
F P
0 g
s
.46538 .62011 m .46184 .63087 L .40777 .62382 L p .751 .736 .839 r
F P
0 g
s
.69586 .57763 m .68739 .5721 L .72895 .53559 L p .696 .725 .872 r
F P
0 g
s
.72895 .53559 m .73979 .53997 L .69586 .57763 L p .696 .725 .872 r
F P
0 g
s
.46538 .62011 m .46897 .60722 L .51978 .60705 L p .738 .708 .822 r
F P
0 g
s
.52012 .59439 m .51978 .60705 L .46897 .60722 L p .736 .686 .802 r
F P
0 g
s
.51978 .60705 m .52012 .59439 L .56784 .58893 L p .713 .708 .844 r
F P
0 g
s
.56784 .58893 m .57074 .5988 L .51978 .60705 L p .713 .708 .844 r
F P
0 g
s
.57074 .5988 m .56784 .58893 L .61309 .57646 L p .702 .765 .901 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57074 .5988 L p .702 .765 .901 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66184 .5602 L p .725 .829 .929 r
F P
0 g
s
.66184 .5602 m .67038 .56342 L .62488 .58932 L p .725 .829 .929 r
F P
0 g
s
.33288 .62004 m .34172 .61881 L .3949 .63729 L p .462 .756 .993 r
F P
0 g
s
.40126 .63198 m .3949 .63729 L .34172 .61881 L p .637 .783 .951 r
F P
0 g
s
.40777 .62382 m .41441 .61281 L .46538 .62011 L p .751 .736 .839 r
F P
0 g
s
.46897 .60722 m .46538 .62011 L .41441 .61281 L p .762 .71 .803 r
F P
0 g
s
.25585 .57634 m .26627 .58239 L .31583 .61564 L p 0 .292 .722 r
F P
0 g
s
.32425 .61877 m .31583 .61564 L .26627 .58239 L p 0 .412 .825 r
F P
0 g
s
.68739 .5721 m .6789 .56737 L .71815 .53279 L p .722 .774 .894 r
F P
0 g
s
.71815 .53279 m .72895 .53559 L .68739 .5721 L p .722 .774 .894 r
F P
0 g
s
.46897 .60722 m .47261 .59254 L .52012 .59439 L p .736 .686 .802 r
F P
0 g
s
.52047 .58078 m .52012 .59439 L .47261 .59254 L p .729 .668 .789 r
F P
0 g
s
.52012 .59439 m .52047 .58078 L .56493 .57855 L p .7 .691 .838 r
F P
0 g
s
.56493 .57855 m .56784 .58893 L .52012 .59439 L p .7 .691 .838 r
F P
0 g
s
.56784 .58893 m .56493 .57855 L .60713 .56996 L p .682 .76 .91 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56784 .58893 L p .682 .76 .91 r
F P
0 g
s
.41441 .61281 m .42116 .5992 L .46897 .60722 L p .762 .71 .803 r
F P
0 g
s
.47261 .59254 m .46897 .60722 L .42116 .5992 L p .766 .69 .778 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65325 .55758 L p .711 .854 .95 r
F P
0 g
s
.65325 .55758 m .66184 .5602 L .61901 .58292 L p .711 .854 .95 r
F P
0 g
s
.34172 .61881 m .35079 .61463 L .40126 .63198 L p .637 .783 .951 r
F P
0 g
s
.40777 .62382 m .40126 .63198 L .35079 .61463 L p .725 .768 .888 r
F P
0 g
s
.47261 .59254 m .47628 .57657 L .52047 .58078 L p .729 .668 .789 r
F P
0 g
s
.52082 .56666 m .52047 .58078 L .47628 .57657 L p .719 .653 .783 r
F P
0 g
s
.52047 .58078 m .52082 .56666 L .56198 .56786 L p .682 .675 .837 r
F P
0 g
s
.56198 .56786 m .56493 .57855 L .52047 .58078 L p .682 .675 .837 r
F P
0 g
s
.6789 .56737 m .67038 .56342 L .70737 .53156 L p .744 .829 .917 r
F P
0 g
s
.70737 .53156 m .71815 .53279 L .6789 .56737 L p .744 .829 .917 r
F P
0 g
s
.42116 .5992 m .428 .58342 L .47261 .59254 L p .766 .69 .778 r
F P
0 g
s
.47628 .57657 m .47261 .59254 L .428 .58342 L p .764 .674 .763 r
F P
0 g
s
.56493 .57855 m .56198 .56786 L .60112 .5634 L p .652 .75 .922 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57855 L p .652 .75 .922 r
F P
0 g
s
.26627 .58239 m .27687 .58727 L .32425 .61877 L p 0 .412 .825 r
F P
0 g
s
.33288 .62004 m .32425 .61877 L .27687 .58727 L p .177 .575 .937 r
F P
0 g
s
.79464 .57831 m .78364 .56952 L .82304 .52587 L p .547 .566 .826 r
F P
0 g
s
.82304 .52587 m .83625 .53514 L .79464 .57831 L p .547 .566 .826 r
F P
0 g
s
.428 .58342 m .43488 .56609 L .47628 .57657 L p .764 .674 .763 r
F P
0 g
s
.47997 .55991 m .47628 .57657 L .43488 .56609 L p .759 .662 .755 r
F P
0 g
s
.47628 .57657 m .47997 .55991 L .52082 .56666 L p .719 .653 .783 r
F P
0 g
s
.52116 .55249 m .52082 .56666 L .47997 .55991 L p .704 .641 .783 r
F P
0 g
s
.52082 .56666 m .52116 .55249 L .55902 .55712 L p .657 .66 .841 r
F P
0 g
s
.55902 .55712 m .56198 .56786 L .52082 .56666 L p .657 .66 .841 r
F P
0 g
s
.35079 .61463 m .36008 .60725 L .40777 .62382 L p .725 .768 .888 r
F P
0 g
s
.41441 .61281 m .40777 .62382 L .36008 .60725 L p .768 .747 .834 r
F P
0 g
s
.78364 .56952 m .77262 .56091 L .80987 .51691 L p .558 .572 .824 r
F P
0 g
s
.80987 .51691 m .82304 .52587 L .78364 .56952 L p .558 .572 .824 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64461 .5554 L p .681 .871 .971 r
F P
0 g
s
.64461 .5554 m .65325 .55758 L .61309 .57646 L p .681 .871 .971 r
F P
0 g
s
.43488 .56609 m .4418 .54797 L .47997 .55991 L p .759 .662 .755 r
F P
0 g
s
.48368 .54324 m .47997 .55991 L .4418 .54797 L p .75 .653 .754 r
F P
0 g
s
.47997 .55991 m .48368 .54324 L .52116 .55249 L p .704 .641 .783 r
F P
0 g
s
.77262 .56091 m .76164 .55289 L .7968 .5088 L p .577 .589 .829 r
F P
0 g
s
.7968 .5088 m .80987 .51691 L .77262 .56091 L p .577 .589 .829 r
F P
0 g
s
.67038 .56342 m .66184 .5602 L .69661 .53178 L p .755 .885 .937 r
F P
0 g
s
.69661 .53178 m .70737 .53156 L .67038 .56342 L p .755 .885 .937 r
F P
0 g
s
.52151 .53875 m .52116 .55249 L .48368 .54324 L p .683 .629 .79 r
F P
0 g
s
.52116 .55249 m .52151 .53875 L .55605 .54656 L p .624 .644 .85 r
F P
0 g
s
.55605 .54656 m .55902 .55712 L .52116 .55249 L p .624 .644 .85 r
F P
0 g
s
.56198 .56786 m .55902 .55712 L .59506 .55679 L p .609 .735 .935 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56198 .56786 L p .609 .735 .935 r
F P
0 g
s
.76164 .55289 m .75069 .54581 L .78384 .50207 L p .603 .618 .839 r
F P
0 g
s
.78384 .50207 m .7968 .5088 L .76164 .55289 L p .603 .618 .839 r
F P
0 g
s
.4418 .54797 m .44872 .52988 L .48368 .54324 L p .75 .653 .754 r
F P
0 g
s
.48738 .52721 m .48368 .54324 L .44872 .52988 L p .735 .646 .76 r
F P
0 g
s
.48368 .54324 m .48738 .52721 L .52151 .53875 L p .683 .629 .79 r
F P
0 g
s
.36008 .60725 m .36955 .5967 L .41441 .61281 L p .768 .747 .834 r
F P
0 g
s
.42116 .5992 m .41441 .61281 L .36955 .5967 L p .789 .728 .795 r
F P
0 g
s
.75069 .54581 m .73979 .53997 L .77102 .49714 L p .637 .659 .854 r
F P
0 g
s
.77102 .49714 m .78384 .50207 L .75069 .54581 L p .637 .659 .854 r
F P
0 g
s
.27687 .58727 m .28772 .59021 L .33288 .62004 L p .177 .575 .937 r
F P
0 g
s
.34172 .61881 m .33288 .62004 L .28772 .59021 L p .438 .702 .977 r
F P
0 g
s
.44872 .52988 m .45562 .51262 L .48738 .52721 L p .735 .646 .76 r
F P
0 g
s
.49109 .51247 m .48738 .52721 L .45562 .51262 L p .714 .639 .772 r
F P
0 g
s
.48738 .52721 m .49109 .51247 L .52186 .52588 L p .653 .618 .802 r
F P
0 g
s
.52186 .52588 m .52151 .53875 L .48738 .52721 L p .653 .618 .802 r
F P
0 g
s
.36955 .5967 m .37918 .58325 L .42116 .5992 L p .789 .728 .795 r
F P
0 g
s
.428 .58342 m .42116 .5992 L .37918 .58325 L p .799 .713 .769 r
F P
0 g
s
.25585 .57634 m .24558 .56996 L .20758 .52532 L p 0 .326 .805 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .6359 .55343 L p .628 .875 .988 r
F P
0 g
s
.6359 .55343 m .64461 .5554 L .60713 .56996 L p .628 .875 .988 r
F P
0 g
s
.52151 .53875 m .52186 .52588 L .55305 .53642 L p .577 .625 .863 r
F P
0 g
s
.55305 .53642 m .55605 .54656 L .52151 .53875 L p .577 .625 .863 r
F P
0 g
s
.37918 .58325 m .38892 .5674 L .428 .58342 L p .799 .713 .769 r
F P
0 g
s
.43488 .56609 m .428 .58342 L .38892 .5674 L p .802 .701 .753 r
F P
0 g
s
.66184 .5602 m .65325 .55758 L .68583 .53324 L p .747 .933 .949 r
F P
0 g
s
.68583 .53324 m .69661 .53178 L .66184 .5602 L p .747 .933 .949 r
F P
0 g
s
.73979 .53997 m .72895 .53559 L .75834 .49431 L p .678 .711 .873 r
F P
0 g
s
.75834 .49431 m .77102 .49714 L .73979 .53997 L p .678 .711 .873 r
F P
0 g
s
.55902 .55712 m .55605 .54656 L .58896 .55013 L p .548 .711 .947 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55902 .55712 L p .548 .711 .947 r
F P
0 g
s
.38892 .5674 m .39873 .54985 L .43488 .56609 L p .802 .701 .753 r
F P
0 g
s
.4418 .54797 m .43488 .56609 L .39873 .54985 L p .801 .693 .745 r
F P
0 g
s
.39873 .54985 m .40855 .53146 L .4418 .54797 L p .801 .693 .745 r
F P
0 g
s
.44872 .52988 m .4418 .54797 L .40855 .53146 L p .796 .687 .744 r
F P
0 g
s
.45562 .51262 m .46251 .49698 L .49109 .51247 L p .714 .639 .772 r
F P
0 g
s
.49479 .49956 m .49109 .51247 L .46251 .49698 L p .682 .631 .791 r
F P
0 g
s
.49109 .51247 m .49479 .49956 L .52222 .51428 L p .61 .605 .821 r
F P
0 g
s
.52222 .51428 m .52186 .52588 L .49109 .51247 L p .61 .605 .821 r
F P
0 g
s
.40855 .53146 m .41835 .51314 L .44872 .52988 L p .796 .687 .744 r
F P
0 g
s
.45562 .51262 m .44872 .52988 L .41835 .51314 L p .786 .682 .75 r
F P
0 g
s
.41835 .51314 m .42811 .4958 L .45562 .51262 L p .786 .682 .75 r
F P
0 g
s
.46251 .49698 m .45562 .51262 L .42811 .4958 L p .769 .679 .763 r
F P
0 g
s
.52186 .52588 m .52222 .51428 L .55004 .52691 L p .512 .599 .878 r
F P
0 g
s
.55004 .52691 m .55305 .53642 L .52186 .52588 L p .512 .599 .878 r
F P
0 g
s
.72895 .53559 m .71815 .53279 L .74579 .49373 L p .723 .775 .894 r
F P
0 g
s
.74579 .49373 m .75834 .49431 L .72895 .53559 L p .723 .775 .894 r
F P
0 g
s
.42811 .4958 m .43781 .4803 L .46251 .49698 L p .769 .679 .763 r
F P
0 g
s
.46936 .48361 m .46251 .49698 L .43781 .4803 L p .742 .674 .785 r
F P
0 g
s
.46251 .49698 m .46936 .48361 L .49479 .49956 L p .682 .631 .791 r
F P
0 g
s
.28772 .59021 m .29884 .59055 L .34172 .61881 L p .438 .702 .977 r
F P
0 g
s
.35079 .61463 m .34172 .61881 L .29884 .59055 L p .621 .758 .944 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62711 .55144 L p .548 .857 .997 r
F P
0 g
s
.62711 .55144 m .6359 .55343 L .60112 .5634 L p .548 .857 .997 r
F P
0 g
s
.49849 .48891 m .49479 .49956 L .46936 .48361 L p .632 .619 .819 r
F P
0 g
s
.49479 .49956 m .49849 .48891 L .52257 .50427 L p .547 .585 .844 r
F P
0 g
s
.52257 .50427 m .52222 .51428 L .49479 .49956 L p .547 .585 .844 r
F P
0 g
s
.55605 .54656 m .55305 .53642 L .5828 .54342 L p .466 .673 .954 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55605 .54656 L p .466 .673 .954 r
F P
0 g
s
.65325 .55758 m .64461 .5554 L .67499 .53558 L p .708 .96 .945 r
F P
0 g
s
.67499 .53558 m .68583 .53324 L .65325 .55758 L p .708 .96 .945 r
F P
0 g
s
.20758 .52532 m .21958 .53321 L .25585 .57634 L p 0 .326 .805 r
F P
0 g
s
.26627 .58239 m .25585 .57634 L .21958 .53321 L p 0 .358 .827 r
F P
0 g
s
.43781 .4803 m .44745 .46737 L .46936 .48361 L p .742 .674 .785 r
F P
0 g
s
.4762 .47303 m .46936 .48361 L .44745 .46737 L p .698 .667 .816 r
F P
0 g
s
.46936 .48361 m .4762 .47303 L .49849 .48891 L p .632 .619 .819 r
F P
0 g
s
.71815 .53279 m .70737 .53156 L .73333 .49541 L p .767 .845 .91 r
F P
0 g
s
.73333 .49541 m .74579 .49373 L .71815 .53279 L p .767 .845 .91 r
F P
0 g
s
.52222 .51428 m .52257 .50427 L .54702 .5182 L p .422 .562 .89 r
F P
0 g
s
.54702 .5182 m .55004 .52691 L .52222 .51428 L p .422 .562 .89 r
F P
0 g
s
.29884 .59055 m .31022 .58781 L .35079 .61463 L p .621 .758 .944 r
F P
0 g
s
.36008 .60725 m .35079 .61463 L .31022 .58781 L p .726 .77 .888 r
F P
0 g
s
.5022 .4808 m .49849 .48891 L .4762 .47303 L p .552 .597 .852 r
F P
0 g
s
.49849 .48891 m .5022 .4808 L .52292 .49605 L p .45 .551 .867 r
F P
0 g
s
.52292 .49605 m .52257 .50427 L .49849 .48891 L p .45 .551 .867 r
F P
0 g
s
.44745 .46737 m .45703 .45758 L .4762 .47303 L p .698 .667 .816 r
F P
0 g
s
.48304 .46559 m .4762 .47303 L .45703 .45758 L p .624 .649 .855 r
F P
0 g
s
.4762 .47303 m .48304 .46559 L .5022 .4808 L p .552 .597 .852 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61824 .54916 L p .438 .812 .993 r
F P
0 g
s
.61824 .54916 m .62711 .55144 L .59506 .55679 L p .438 .812 .993 r
F P
0 g
s
.55305 .53642 m .55004 .52691 L .5766 .53665 L p .359 .619 .95 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55305 .53642 L p .359 .619 .95 r
F P
0 g
s
.39448 .49396 m .40655 .47771 L .42811 .4958 L p .835 .737 .756 r
F P
0 g
s
.42811 .4958 m .41835 .51314 L .39448 .49396 L p .835 .737 .756 r
F P
0 g
s
.43781 .4803 m .42811 .4958 L .40655 .47771 L p .82 .737 .772 r
F P
0 g
s
.40655 .47771 m .41852 .46341 L .43781 .4803 L p .82 .737 .772 r
F P
0 g
s
.44745 .46737 m .43781 .4803 L .41852 .46341 L p .795 .736 .798 r
F P
0 g
s
.64461 .5554 m .6359 .55343 L .66409 .53841 L p .632 .957 .924 r
F P
0 g
s
.66409 .53841 m .67499 .53558 L .64461 .5554 L p .632 .957 .924 r
F P
0 g
s
.38233 .51126 m .39448 .49396 L .41835 .51314 L p .842 .738 .749 r
F P
0 g
s
.41835 .51314 m .40855 .53146 L .38233 .51126 L p .842 .738 .749 r
F P
0 g
s
.70737 .53156 m .69661 .53178 L .72094 .49918 L p .8 .913 .917 r
F P
0 g
s
.72094 .49918 m .73333 .49541 L .70737 .53156 L p .8 .913 .917 r
F P
0 g
s
.31022 .58781 m .32186 .58176 L .36008 .60725 L p .726 .77 .888 r
F P
0 g
s
.36955 .5967 m .36008 .60725 L .32186 .58176 L p .783 .766 .838 r
F P
0 g
s
.41852 .46341 m .43039 .45181 L .44745 .46737 L p .795 .736 .798 r
F P
0 g
s
.45703 .45758 m .44745 .46737 L .43039 .45181 L p .751 .731 .834 r
F P
0 g
s
.37012 .52866 m .38233 .51126 L .40855 .53146 L p .844 .74 .749 r
F P
0 g
s
.40855 .53146 m .39873 .54985 L .37012 .52866 L p .844 .74 .749 r
F P
0 g
s
.21958 .53321 m .23172 .54077 L .26627 .58239 L p 0 .358 .827 r
F P
0 g
s
.27687 .58727 m .26627 .58239 L .23172 .54077 L p .094 .445 .88 r
F P
0 g
s
.52257 .50427 m .52292 .49605 L .54397 .51039 L p .297 .506 .89 r
F P
0 g
s
.54397 .51039 m .54702 .5182 L .52257 .50427 L p .297 .506 .89 r
F P
0 g
s
.35792 .54522 m .37012 .52866 L .39873 .54985 L p .841 .744 .757 r
F P
0 g
s
.39873 .54985 m .38892 .5674 L .35792 .54522 L p .841 .744 .757 r
F P
0 g
s
.32186 .58176 m .33373 .57241 L .36955 .5967 L p .783 .766 .838 r
F P
0 g
s
.37918 .58325 m .36955 .5967 L .33373 .57241 L p .814 .758 .8 r
F P
0 g
s
.43039 .45181 m .44216 .44349 L .45703 .45758 L p .751 .731 .834 r
F P
0 g
s
.46659 .45131 m .45703 .45758 L .44216 .44349 L p .672 .715 .88 r
F P
0 g
s
.45703 .45758 m .46659 .45131 L .48304 .46559 L p .624 .649 .855 r
F P
0 g
s
.34576 .56005 m .35792 .54522 L .38892 .5674 L p .832 .75 .774 r
F P
0 g
s
.38892 .5674 m .37918 .58325 L .34576 .56005 L p .832 .75 .774 r
F P
0 g
s
.33373 .57241 m .34576 .56005 L .37918 .58325 L p .814 .758 .8 r
F P
0 g
s
.48988 .46142 m .48304 .46559 L .46659 .45131 L p .496 .608 .893 r
F P
0 g
s
.48304 .46559 m .48988 .46142 L .50592 .47537 L p .422 .551 .88 r
F P
0 g
s
.50592 .47537 m .5022 .4808 L .48304 .46559 L p .422 .551 .88 r
F P
0 g
s
.5022 .4808 m .50592 .47537 L .52328 .4897 L p .305 .492 .877 r
F P
0 g
s
.52328 .4897 m .52292 .49605 L .5022 .4808 L p .305 .492 .877 r
F P
0 g
s
.55004 .52691 m .54702 .5182 L .57035 .52982 L p .228 .544 .928 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55004 .52691 L p .228 .544 .928 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60928 .54636 L p .303 .735 .969 r
F P
0 g
s
.60928 .54636 m .61824 .54916 L .58896 .55013 L p .303 .735 .969 r
F P
0 g
s
.69661 .53178 m .68583 .53324 L .70856 .50471 L p .81 .966 .906 r
F P
0 g
s
.70856 .50471 m .72094 .49918 L .69661 .53178 L p .81 .966 .906 r
F P
0 g
s
.6359 .55343 m .62711 .55144 L .65308 .54124 L p .523 .918 .889 r
F P
0 g
s
.65308 .54124 m .66409 .53841 L .6359 .55343 L p .523 .918 .889 r
F P
0 g
s
.44216 .44349 m .45388 .43884 L .46659 .45131 L p .672 .715 .88 r
F P
0 g
s
.47615 .44871 m .46659 .45131 L .45388 .43884 L p .532 .668 .924 r
F P
0 g
s
.46659 .45131 m .47615 .44871 L .48988 .46142 L p .496 .608 .893 r
F P
0 g
s
.52292 .49605 m .52328 .4897 L .5409 .50354 L p .137 .424 .866 r
F P
0 g
s
.5409 .50354 m .54397 .51039 L .52292 .49605 L p .137 .424 .866 r
F P
0 g
s
.23172 .54077 m .24406 .54719 L .27687 .58727 L p .094 .445 .88 r
F P
0 g
s
.28772 .59021 m .27687 .58727 L .24406 .54719 L p .277 .56 .931 r
F P
0 g
s
.54702 .5182 m .54397 .51039 L .56404 .52294 L p .081 .45 .882 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54702 .5182 L p .081 .45 .882 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .60022 .54282 L p .154 .632 .925 r
F P
0 g
s
.60022 .54282 m .60928 .54636 L .5828 .54342 L p .154 .632 .925 r
F P
0 g
s
.49677 .46047 m .48988 .46142 L .47615 .44871 L p .289 .517 .901 r
F P
0 g
s
.48988 .46142 m .49677 .46047 L .50967 .47255 L p .222 .462 .877 r
F P
0 g
s
.50967 .47255 m .50592 .47537 L .48988 .46142 L p .222 .462 .877 r
F P
0 g
s
.40595 .44734 m .41933 .43789 L .43039 .45181 L p .837 .819 .832 r
F P
0 g
s
.43039 .45181 m .41852 .46341 L .40595 .44734 L p .837 .819 .832 r
F P
0 g
s
.44216 .44349 m .43039 .45181 L .41933 .43789 L p .784 .815 .877 r
F P
0 g
s
.39244 .45943 m .40595 .44734 L .41852 .46341 L p .865 .816 .799 r
F P
0 g
s
.41852 .46341 m .40655 .47771 L .39244 .45943 L p .865 .816 .799 r
F P
0 g
s
.50592 .47537 m .50967 .47255 L .52364 .48519 L p .108 .396 .85 r
F P
0 g
s
.52364 .48519 m .52328 .4897 L .50592 .47537 L p .108 .396 .85 r
F P
0 g
s
.68583 .53324 m .67499 .53558 L .69616 .51154 L p .789 .993 .878 r
F P
0 g
s
.69616 .51154 m .70856 .50471 L .68583 .53324 L p .789 .993 .878 r
F P
0 g
s
.41933 .43789 m .43258 .43165 L .44216 .44349 L p .784 .815 .877 r
F P
0 g
s
.45388 .43884 m .44216 .44349 L .43258 .43165 L p .686 .792 .93 r
F P
0 g
s
.37878 .47342 m .39244 .45943 L .40655 .47771 L p .879 .812 .778 r
F P
0 g
s
.40655 .47771 m .39448 .49396 L .37878 .47342 L p .879 .812 .778 r
F P
0 g
s
.62711 .55144 m .61824 .54916 L .64196 .54358 L p .39 .85 .85 r
F P
0 g
s
.64196 .54358 m .65308 .54124 L .62711 .55144 L p .39 .85 .85 r
F P
0 g
s
.45388 .43884 m .46556 .43802 L .47615 .44871 L p .532 .668 .924 r
F P
0 g
s
.48574 .44971 m .47615 .44871 L .46556 .43802 L p .302 .56 .927 r
F P
0 g
s
.47615 .44871 m .48574 .44971 L .49677 .46047 L p .289 .517 .901 r
F P
0 g
s
.7968 .5088 m .78384 .50207 L .80098 .45503 L p .547 .594 .852 r
F P
0 g
s
.78384 .50207 m .77102 .49714 L .78695 .45149 L p .598 .644 .867 r
F P
0 g
s
.78695 .45149 m .80098 .45503 L .78384 .50207 L p .598 .644 .867 r
F P
0 g
s
.80987 .51691 m .7968 .5088 L .81524 .46079 L p .508 .557 .841 r
F P
0 g
s
.80098 .45503 m .81524 .46079 L .7968 .5088 L p .547 .594 .852 r
F P
0 g
s
.24406 .54719 m .25664 .55172 L .28772 .59021 L p .277 .56 .931 r
F P
0 g
s
.29884 .59055 m .28772 .59021 L .25664 .55172 L p .468 .665 .948 r
F P
0 g
s
.77102 .49714 m .75834 .49431 L .77315 .45055 L p .659 .706 .882 r
F P
0 g
s
.77315 .45055 m .78695 .45149 L .77102 .49714 L p .659 .706 .882 r
F P
0 g
s
.43258 .43165 m .44573 .42898 L .45388 .43884 L p .686 .792 .93 r
F P
0 g
s
.46556 .43802 m .45388 .43884 L .44573 .42898 L p .512 .723 .968 r
F P
0 g
s
.82304 .52587 m .80987 .51691 L .8297 .46828 L p .482 .536 .835 r
F P
0 g
s
.81524 .46079 m .8297 .46828 L .80987 .51691 L p .508 .557 .841 r
F P
0 g
s
.365 .48847 m .37878 .47342 L .39448 .49396 L p .885 .808 .768 r
F P
0 g
s
.39448 .49396 m .38233 .51126 L .365 .48847 L p .885 .808 .768 r
F P
0 g
s
.52328 .4897 m .52364 .48519 L .53781 .49761 L p 0 .319 .807 r
F P
0 g
s
.53781 .49761 m .5409 .50354 L .52328 .4897 L p 0 .319 .807 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59108 .53835 L p .007 .513 .864 r
F P
0 g
s
.59108 .53835 m .60022 .54282 L .5766 .53665 L p .007 .513 .864 r
F P
0 g
s
.83625 .53514 m .82304 .52587 L .84432 .47686 L p .469 .528 .836 r
F P
0 g
s
.8297 .46828 m .84432 .47686 L .82304 .52587 L p .482 .536 .835 r
F P
0 g
s
.54397 .51039 m .5409 .50354 L .55769 .51601 L p 0 .346 .815 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54397 .51039 L p 0 .346 .815 r
F P
0 g
s
.75834 .49431 m .74579 .49373 L .75955 .4524 L p .725 .775 .893 r
F P
0 g
s
.75955 .4524 m .77315 .45055 L .75834 .49431 L p .725 .775 .893 r
F P
0 g
s
.84432 .47686 m .85906 .48583 L .83625 .53514 L p .469 .528 .836 r
F P
0 g
s
.67499 .53558 m .66409 .53841 L .68368 .51908 L p .736 .992 .839 r
F P
0 g
s
.68368 .51908 m .69616 .51154 L .67499 .53558 L p .736 .992 .839 r
F P
0 g
s
.35114 .50365 m .365 .48847 L .38233 .51126 L p .884 .805 .767 r
F P
0 g
s
.38233 .51126 m .37012 .52866 L .35114 .50365 L p .884 .805 .767 r
F P
0 g
s
.50371 .46246 m .49677 .46047 L .48574 .44971 L p .013 .364 .835 r
F P
0 g
s
.49677 .46047 m .50371 .46246 L .51345 .47211 L p 0 .323 .81 r
F P
0 g
s
.51345 .47211 m .50967 .47255 L .49677 .46047 L p 0 .323 .81 r
F P
0 g
s
.74579 .49373 m .73333 .49541 L .74612 .45704 L p .788 .844 .894 r
F P
0 g
s
.74612 .45704 m .75955 .4524 L .74579 .49373 L p .788 .844 .894 r
F P
0 g
s
.61824 .54916 m .60928 .54636 L .6307 .54495 L p .243 .759 .813 r
F P
0 g
s
.6307 .54495 m .64196 .54358 L .61824 .54916 L p .243 .759 .813 r
F P
0 g
s
.25664 .55172 m .26949 .55371 L .29884 .59055 L p .468 .665 .948 r
F P
0 g
s
.31022 .58781 m .29884 .59055 L .26949 .55371 L p .621 .735 .928 r
F P
0 g
s
.44573 .42898 m .45883 .43004 L .46556 .43802 L p .512 .723 .968 r
F P
0 g
s
.47727 .44094 m .46556 .43802 L .45883 .43004 L p .246 .576 .942 r
F P
0 g
s
.46556 .43802 m .47727 .44094 L .48574 .44971 L p .302 .56 .927 r
F P
0 g
s
.50967 .47255 m .51345 .47211 L .524 .48235 L p 0 .268 .772 r
F P
0 g
s
.524 .48235 m .52364 .48519 L .50967 .47255 L p 0 .268 .772 r
F P
0 g
s
.49539 .45401 m .48574 .44971 L .47727 .44094 L p .008 .383 .844 r
F P
0 g
s
.48574 .44971 m .49539 .45401 L .50371 .46246 L p .013 .364 .835 r
F P
0 g
s
.33724 .51802 m .35114 .50365 L .37012 .52866 L p .876 .803 .774 r
F P
0 g
s
.37012 .52866 m .35792 .54522 L .33724 .51802 L p .876 .803 .774 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58185 .53286 L p 0 .394 .794 r
F P
0 g
s
.58185 .53286 m .59108 .53835 L .57035 .52982 L p 0 .394 .794 r
F P
0 g
s
.73333 .49541 m .72094 .49918 L .73281 .46425 L p .838 .905 .884 r
F P
0 g
s
.73281 .46425 m .74612 .45704 L .73333 .49541 L p .838 .905 .884 r
F P
0 g
s
.26949 .55371 m .28262 .55271 L .31022 .58781 L p .621 .735 .928 r
F P
0 g
s
.32186 .58176 m .31022 .58781 L .28262 .55271 L p .726 .772 .889 r
F P
0 g
s
.5409 .50354 m .53781 .49761 L .55128 .50901 L p 0 .243 .738 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .5409 .50354 L p 0 .243 .738 r
F P
0 g
s
.32338 .53073 m .33724 .51802 L .35792 .54522 L p .861 .8 .79 r
F P
0 g
s
.35792 .54522 m .34576 .56005 L .32338 .53073 L p .861 .8 .79 r
F P
0 g
s
.52364 .48519 m .524 .48235 L .53469 .49252 L p 0 .207 .72 r
F P
0 g
s
.53469 .49252 m .53781 .49761 L .52364 .48519 L p 0 .207 .72 r
F P
0 g
s
.66409 .53841 m .65308 .54124 L .6711 .52665 L p .657 .967 .801 r
F P
0 g
s
.6711 .52665 m .68368 .51908 L .66409 .53841 L p .657 .967 .801 r
F P
0 g
s
.41514 .42653 m .42901 .42285 L .43258 .43165 L p .763 .907 .939 r
F P
0 g
s
.43258 .43165 m .41933 .43789 L .41514 .42653 L p .763 .907 .939 r
F P
0 g
s
.44573 .42898 m .43258 .43165 L .42901 .42285 L p .621 .857 .988 r
F P
0 g
s
.40111 .43312 m .41514 .42653 L .41933 .43789 L p .842 .918 .885 r
F P
0 g
s
.41933 .43789 m .40595 .44734 L .40111 .43312 L p .842 .918 .885 r
F P
0 g
s
.28262 .55271 m .29601 .54849 L .32186 .58176 L p .726 .772 .889 r
F P
0 g
s
.33373 .57241 m .32186 .58176 L .29601 .54849 L p .793 .789 .849 r
F P
0 g
s
.30961 .54107 m .32338 .53073 L .34576 .56005 L p .835 .797 .815 r
F P
0 g
s
.34576 .56005 m .33373 .57241 L .30961 .54107 L p .835 .797 .815 r
F P
0 g
s
.60928 .54636 m .60022 .54282 L .61932 .54492 L p .093 .65 .78 r
F P
0 g
s
.61932 .54492 m .6307 .54495 L .60928 .54636 L p .093 .65 .78 r
F P
0 g
s
.42901 .42285 m .44277 .42241 L .44573 .42898 L p .621 .857 .988 r
F P
0 g
s
.45883 .43004 m .44573 .42898 L .44277 .42241 L p .391 .734 .991 r
F P
0 g
s
.21958 .53321 m .20758 .52532 L .18911 .47507 L p .181 .422 .857 r
F P
0 g
s
.29601 .54849 m .30961 .54107 L .33373 .57241 L p .793 .789 .849 r
F P
0 g
s
.45883 .43004 m .47192 .43474 L .47727 .44094 L p .246 .576 .942 r
F P
0 g
s
.48903 .44729 m .47727 .44094 L .47192 .43474 L p 0 .371 .829 r
F P
0 g
s
.47727 .44094 m .48903 .44729 L .49539 .45401 L p .008 .383 .844 r
F P
0 g
s
.38692 .4421 m .40111 .43312 L .40595 .44734 L p .882 .913 .843 r
F P
0 g
s
.40595 .44734 m .39244 .45943 L .38692 .4421 L p .882 .913 .843 r
F P
0 g
s
.72094 .49918 m .70856 .50471 L .71957 .47364 L p .87 .949 .862 r
F P
0 g
s
.71957 .47364 m .73281 .46425 L .72094 .49918 L p .87 .949 .862 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57254 .52628 L p 0 .285 .726 r
F P
0 g
s
.57254 .52628 m .58185 .53286 L .56404 .52294 L p 0 .285 .726 r
F P
0 g
s
.44277 .42241 m .45644 .42533 L .45883 .43004 L p .391 .734 .991 r
F P
0 g
s
.47192 .43474 m .45883 .43004 L .45644 .42533 L p .105 .535 .912 r
F P
0 g
s
.51074 .46691 m .50371 .46246 L .49539 .45401 L p 0 .192 .704 r
F P
0 g
s
.50371 .46246 m .51074 .46691 L .51728 .47366 L p 0 .172 .69 r
F P
0 g
s
.51728 .47366 m .51345 .47211 L .50371 .46246 L p 0 .172 .69 r
F P
0 g
s
.51345 .47211 m .51728 .47366 L .52437 .48088 L p 0 .143 .664 r
F P
0 g
s
.52437 .48088 m .524 .48235 L .51345 .47211 L p 0 .143 .664 r
F P
0 g
s
.37256 .45281 m .38692 .4421 L .39244 .45943 L p .902 .904 .815 r
F P
0 g
s
.39244 .45943 m .37878 .47342 L .37256 .45281 L p .902 .904 .815 r
F P
0 g
s
.50516 .46107 m .49539 .45401 L .48903 .44729 L p 0 .197 .703 r
F P
0 g
s
.49539 .45401 m .50516 .46107 L .51074 .46691 L p 0 .192 .704 r
F P
0 g
s
.53781 .49761 m .53469 .49252 L .54482 .50197 L p 0 .153 .661 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53781 .49761 L p 0 .153 .661 r
F P
0 g
s
.65308 .54124 m .64196 .54358 L .65837 .53356 L p .558 .926 .776 r
F P
0 g
s
.65837 .53356 m .6711 .52665 L .65308 .54124 L p .558 .926 .776 r
F P
0 g
s
.60022 .54282 m .59108 .53835 L .6078 .54316 L p 0 .53 .747 r
F P
0 g
s
.6078 .54316 m .61932 .54492 L .60022 .54282 L p 0 .53 .747 r
F P
0 g
s
.18911 .47507 m .20227 .48411 L .21958 .53321 L p .181 .422 .857 r
F P
0 g
s
.23172 .54077 m .21958 .53321 L .20227 .48411 L p .216 .442 .864 r
F P
0 g
s
.70856 .50471 m .69616 .51154 L .70633 .48464 L p .88 .977 .835 r
F P
0 g
s
.70633 .48464 m .71957 .47364 L .70856 .50471 L p .88 .977 .835 r
F P
0 g
s
.524 .48235 m .52437 .48088 L .53153 .48811 L p 0 .11 .63 r
F P
0 g
s
.53153 .48811 m .53469 .49252 L .524 .48235 L p 0 .11 .63 r
F P
0 g
s
.45644 .42533 m .47008 .43153 L .47192 .43474 L p .105 .535 .912 r
F P
0 g
s
.48505 .44276 m .47192 .43474 L .47008 .43153 L p 0 .321 .778 r
F P
0 g
s
.47192 .43474 m .48505 .44276 L .48903 .44729 L p 0 .371 .829 r
F P
0 g
s
.50091 .45652 m .48903 .44729 L .48505 .44276 L p 0 .184 .684 r
F P
0 g
s
.48903 .44729 m .50091 .45652 L .50516 .46107 L p 0 .197 .703 r
F P
0 g
s
.35806 .46448 m .37256 .45281 L .37878 .47342 L p .91 .893 .801 r
F P
0 g
s
.37878 .47342 m .365 .48847 L .35806 .46448 L p .91 .893 .801 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56317 .51865 L p 0 .194 .664 r
F P
0 g
s
.56317 .51865 m .57254 .52628 L .55769 .51601 L p 0 .194 .664 r
F P
0 g
s
.59108 .53835 m .58185 .53286 L .59617 .53942 L p 0 .408 .711 r
F P
0 g
s
.59617 .53942 m .6078 .54316 L .59108 .53835 L p 0 .408 .711 r
F P
0 g
s
.20227 .48411 m .21554 .49285 L .23172 .54077 L p .216 .442 .864 r
F P
0 g
s
.24406 .54719 m .23172 .54077 L .21554 .49285 L p .294 .495 .883 r
F P
0 g
s
.64196 .54358 m .6307 .54495 L .64549 .53911 L p .441 .87 .768 r
F P
0 g
s
.64549 .53911 m .65837 .53356 L .64196 .54358 L p .441 .87 .768 r
F P
0 g
s
.34344 .47627 m .35806 .46448 L .365 .48847 L p .908 .883 .798 r
F P
0 g
s
.365 .48847 m .35114 .50365 L .34344 .47627 L p .908 .883 .798 r
F P
0 g
s
.53469 .49252 m .53153 .48811 L .5383 .49486 L p 0 .082 .596 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53469 .49252 L p 0 .082 .596 r
F P
0 g
s
.69616 .51154 m .68368 .51908 L .69303 .49653 L p .871 .992 .812 r
F P
0 g
s
.69303 .49653 m .70633 .48464 L .69616 .51154 L p .871 .992 .812 r
F P
0 g
s
.43189 .41777 m .44533 .41964 L .44277 .42241 L p .395 .814 .972 r
F P
0 g
s
.44277 .42241 m .42901 .42285 L .43189 .41777 L p .395 .814 .972 r
F P
0 g
s
.45644 .42533 m .44277 .42241 L .44533 .41964 L p .146 .632 .919 r
F P
0 g
s
.47008 .43153 m .48373 .44072 L .48505 .44276 L p 0 .321 .778 r
F P
0 g
s
.49827 .45357 m .48505 .44276 L .48373 .44072 L p 0 .156 .651 r
F P
0 g
s
.48505 .44276 m .49827 .45357 L .50091 .45652 L p 0 .184 .684 r
F P
0 g
s
.41832 .41856 m .43189 .41777 L .42901 .42285 L p .596 .927 .964 r
F P
0 g
s
.42901 .42285 m .41514 .42653 L .41832 .41856 L p .596 .927 .964 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55373 .51006 L p 0 .122 .612 r
F P
0 g
s
.55373 .51006 m .56317 .51865 L .55128 .50901 L p 0 .122 .612 r
F P
0 g
s
.51787 .47318 m .51074 .46691 L .50516 .46107 L p 0 .065 .583 r
F P
0 g
s
.51074 .46691 m .51787 .47318 L .52117 .47667 L p 0 .059 .579 r
F P
0 g
s
.52117 .47667 m .51728 .47366 L .51074 .46691 L p 0 .059 .579 r
F P
0 g
s
.44533 .41964 m .45867 .42427 L .45644 .42533 L p .146 .632 .919 r
F P
0 g
s
.47008 .43153 m .45644 .42533 L .45867 .42427 L p 0 .424 .815 r
F P
0 g
s
.51728 .47366 m .52117 .47667 L .52474 .48041 L p 0 .051 .57 r
F P
0 g
s
.52474 .48041 m .52437 .48088 L .51728 .47366 L p 0 .051 .57 r
F P
0 g
s
.51506 .47019 m .50516 .46107 L .50091 .45652 L p 0 .065 .581 r
F P
0 g
s
.50516 .46107 m .51506 .47019 L .51787 .47318 L p 0 .065 .583 r
F P
0 g
s
.58185 .53286 m .57254 .52628 L .58445 .53362 L p 0 .295 .671 r
F P
0 g
s
.58445 .53362 m .59617 .53942 L .58185 .53286 L p 0 .295 .671 r
F P
0 g
s
.40459 .42175 m .41832 .41856 L .41514 .42653 L p .73 .975 .925 r
F P
0 g
s
.41514 .42653 m .40111 .43312 L .40459 .42175 L p .73 .975 .925 r
F P
0 g
s
.32876 .48735 m .34344 .47627 L .35114 .50365 L p .897 .871 .804 r
F P
0 g
s
.35114 .50365 m .33724 .51802 L .32876 .48735 L p .897 .871 .804 r
F P
0 g
s
.21554 .49285 m .22897 .50054 L .24406 .54719 L p .294 .495 .883 r
F P
0 g
s
.25664 .55172 m .24406 .54719 L .22897 .50054 L p .402 .569 .903 r
F P
0 g
s
.45867 .42427 m .47195 .43159 L .47008 .43153 L p 0 .424 .815 r
F P
0 g
s
.48373 .44072 m .47008 .43153 L .47195 .43159 L p 0 .247 .702 r
F P
0 g
s
.52437 .48088 m .52474 .48041 L .52834 .48417 L p 0 .041 .558 r
F P
0 g
s
.52834 .48417 m .53153 .48811 L .52437 .48088 L p 0 .041 .558 r
F P
0 g
s
.51293 .46789 m .50091 .45652 L .49827 .45357 L p 0 .061 .574 r
F P
0 g
s
.50091 .45652 m .51293 .46789 L .51506 .47019 L p 0 .065 .581 r
F P
0 g
s
.6307 .54495 m .61932 .54492 L .63245 .54268 L p .302 .794 .772 r
F P
0 g
s
.63245 .54268 m .64549 .53911 L .6307 .54495 L p .302 .794 .772 r
F P
0 g
s
.3907 .42691 m .40459 .42175 L .40111 .43312 L p .809 .987 .885 r
F P
0 g
s
.40111 .43312 m .38692 .4421 L .3907 .42691 L p .809 .987 .885 r
F P
0 g
s
.78695 .45149 m .77315 .45055 L .77152 .40705 L p .643 .711 .897 r
F P
0 g
s
.77315 .45055 m .75955 .4524 L .75775 .41139 L p .726 .775 .891 r
F P
0 g
s
.75775 .41139 m .77152 .40705 L .77315 .45055 L p .726 .775 .891 r
F P
0 g
s
.68368 .51908 m .6711 .52665 L .67963 .50847 L p .846 .999 .801 r
F P
0 g
s
.67963 .50847 m .69303 .49653 L .68368 .51908 L p .846 .999 .801 r
F P
0 g
s
.80098 .45503 m .78695 .45149 L .78557 .40583 L p .558 .645 .892 r
F P
0 g
s
.77152 .40705 m .78557 .40583 L .78695 .45149 L p .643 .711 .897 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54423 .50068 L p 0 .067 .571 r
F P
0 g
s
.54423 .50068 m .55373 .51006 L .54482 .50197 L p 0 .067 .571 r
F P
0 g
s
.57254 .52628 m .56317 .51865 L .57265 .52583 L p 0 .199 .631 r
F P
0 g
s
.57265 .52583 m .58445 .53362 L .57254 .52628 L p 0 .199 .631 r
F P
0 g
s
.75955 .4524 m .74612 .45704 L .7442 .41886 L p .798 .828 .875 r
F P
0 g
s
.7442 .41886 m .75775 .41139 L .75955 .4524 L p .798 .828 .875 r
F P
0 g
s
.31407 .49694 m .32876 .48735 L .33724 .51802 L p .876 .858 .819 r
F P
0 g
s
.33724 .51802 m .32338 .53073 L .31407 .49694 L p .876 .858 .819 r
F P
0 g
s
.81524 .46079 m .80098 .45503 L .7999 .40754 L p .482 .585 .881 r
F P
0 g
s
.78557 .40583 m .7999 .40754 L .80098 .45503 L p .558 .645 .892 r
F P
0 g
s
.47195 .43159 m .4852 .44136 L .48373 .44072 L p 0 .247 .702 r
F P
0 g
s
.49743 .45241 m .48373 .44072 L .4852 .44136 L p 0 .121 .612 r
F P
0 g
s
.48373 .44072 m .49743 .45241 L .49827 .45357 L p 0 .156 .651 r
F P
0 g
s
.53153 .48811 m .52834 .48417 L .53174 .48769 L p 0 .032 .547 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53153 .48811 L p 0 .032 .547 r
F P
0 g
s
.51162 .46643 m .49827 .45357 L .49743 .45241 L p 0 .052 .563 r
F P
0 g
s
.49827 .45357 m .51162 .46643 L .51293 .46789 L p 0 .061 .574 r
F P
0 g
s
.22897 .50054 m .24262 .50651 L .25664 .55172 L p .402 .569 .903 r
F P
0 g
s
.26949 .55371 m .25664 .55172 L .24262 .50651 L p .522 .648 .914 r
F P
0 g
s
.74612 .45704 m .73281 .46425 L .73081 .42921 L p .854 .868 .85 r
F P
0 g
s
.73081 .42921 m .7442 .41886 L .74612 .45704 L p .854 .868 .85 r
F P
0 g
s
.61932 .54492 m .6078 .54316 L .61926 .54378 L p .143 .688 .775 r
F P
0 g
s
.61926 .54378 m .63245 .54268 L .61932 .54492 L p .143 .688 .775 r
F P
0 g
s
.8297 .46828 m .81524 .46079 L .81453 .41175 L p .423 .538 .869 r
F P
0 g
s
.7999 .40754 m .81453 .41175 L .81524 .46079 L p .482 .585 .881 r
F P
0 g
s
.37664 .43349 m .3907 .42691 L .38692 .4421 L p .855 .983 .856 r
F P
0 g
s
.38692 .4421 m .37256 .45281 L .37664 .43349 L p .855 .983 .856 r
F P
0 g
s
.29944 .50439 m .31407 .49694 L .32338 .53073 L p .844 .839 .841 r
F P
0 g
s
.32338 .53073 m .30961 .54107 L .29944 .50439 L p .844 .839 .841 r
F P
0 g
s
.24262 .50651 m .25649 .51019 L .26949 .55371 L p .522 .648 .914 r
F P
0 g
s
.28262 .55271 m .26949 .55371 L .25649 .51019 L p .634 .719 .909 r
F P
0 g
s
.56317 .51865 m .55373 .51006 L .56079 .51623 L p 0 .124 .594 r
F P
0 g
s
.56079 .51623 m .57265 .52583 L .56317 .51865 L p 0 .124 .594 r
F P
0 g
s
.52511 .48046 m .51787 .47318 L .51506 .47019 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52117 .47667 L .51787 .47318 L closepath p 0 .003 .518 r
F P
0 g
s
.6711 .52665 m .65837 .53356 L .66609 .5196 L p .805 .999 .807 r
F P
0 g
s
.66609 .5196 m .67963 .50847 L .6711 .52665 L p .805 .999 .807 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53469 .49073 L p 0 .028 .54 r
F P
0 g
s
.53469 .49073 m .54423 .50068 L .5383 .49486 L p 0 .028 .54 r
F P
0 g
s
.4852 .44136 m .49846 .45315 L .49743 .45241 L p 0 .121 .612 r
F P
0 g
s
.51122 .46593 m .49743 .45241 L .49846 .45315 L p 0 .042 .551 r
F P
0 g
s
.49743 .45241 m .51122 .46593 L .51162 .46643 L p 0 .052 .563 r
F P
0 g
s
.28494 .50921 m .29944 .50439 L .30961 .54107 L p .795 .813 .866 r
F P
0 g
s
.30961 .54107 m .29601 .54849 L .28494 .50921 L p .795 .813 .866 r
F P
0 g
s
.52511 .48046 m .51506 .47019 L .51293 .46789 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52474 .48041 L .52117 .47667 L closepath p 0 .003 .518 r
F P
0 g
s
.84432 .47686 m .8297 .46828 L .82943 .41791 L p .384 .509 .861 r
F P
0 g
s
.81453 .41175 m .82943 .41791 L .8297 .46828 L p .423 .538 .869 r
F P
0 g
s
.25649 .51019 m .27061 .51116 L .28262 .55271 L p .634 .719 .909 r
F P
0 g
s
.29601 .54849 m .28262 .55271 L .27061 .51116 L p .726 .774 .891 r
F P
0 g
s
.73281 .46425 m .71957 .47364 L .71753 .442 L p .892 .896 .825 r
F P
0 g
s
.71753 .442 m .73081 .42921 L .73281 .46425 L p .892 .896 .825 r
F P
0 g
s
.27061 .51116 m .28494 .50921 L .29601 .54849 L p .726 .774 .891 r
F P
0 g
s
.52511 .48046 m .51293 .46789 L .51162 .46643 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52834 .48417 L .52474 .48041 L closepath p 0 .003 .518 r
F P
0 g
s
.6078 .54316 m .59617 .53942 L .60593 .54208 L p 0 .553 .762 r
F P
0 g
s
.60593 .54208 m .61926 .54378 L .6078 .54316 L p 0 .553 .762 r
F P
0 g
s
.4534 .42097 m .46547 .42703 L .45867 .42427 L p 0 .454 .781 r
F P
0 g
s
.45867 .42427 m .44533 .41964 L .4534 .42097 L p 0 .454 .781 r
F P
0 g
s
.47195 .43159 m .45867 .42427 L .46547 .42703 L p 0 .298 .705 r
F P
0 g
s
.46547 .42703 m .47746 .43499 L .47195 .43159 L p 0 .298 .705 r
F P
0 g
s
.4852 .44136 m .47195 .43159 L .47746 .43499 L p 0 .176 .635 r
F P
0 g
s
.55373 .51006 m .54423 .50068 L .54891 .50518 L p 0 .067 .563 r
F P
0 g
s
.54891 .50518 m .56079 .51623 L .55373 .51006 L p 0 .067 .563 r
F P
0 g
s
.44123 .41686 m .4534 .42097 L .44533 .41964 L p .08 .623 .846 r
F P
0 g
s
.44533 .41964 m .43189 .41777 L .44123 .41686 L p .08 .623 .846 r
F P
0 g
s
.36243 .44085 m .37664 .43349 L .37256 .45281 L p .879 .972 .842 r
F P
0 g
s
.37256 .45281 m .35806 .46448 L .36243 .44085 L p .879 .972 .842 r
F P
0 g
s
.52511 .48046 m .51162 .46643 L .51122 .46593 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48417 L closepath p 0 .003 .518 r
F P
0 g
s
.47746 .43499 m .48941 .44467 L .4852 .44136 L p 0 .176 .635 r
F P
0 g
s
.49846 .45315 m .4852 .44136 L .48941 .44467 L p 0 .089 .58 r
F P
0 g
s
.85906 .48583 m .84432 .47686 L .84456 .42531 L p .367 .5 .86 r
F P
0 g
s
.82943 .41791 m .84456 .42531 L .84432 .47686 L p .384 .509 .861 r
F P
0 g
s
.42893 .41465 m .44123 .41686 L .43189 .41777 L p .276 .774 .883 r
F P
0 g
s
.43189 .41777 m .41832 .41856 L .42893 .41465 L p .276 .774 .883 r
F P
0 g
s
.71957 .47364 m .70633 .48464 L .70429 .45659 L p .915 .914 .803 r
F P
0 g
s
.70429 .45659 m .71753 .442 L .71957 .47364 L p .915 .914 .803 r
F P
0 g
s
.59617 .53942 m .58445 .53362 L .59251 .53746 L p 0 .406 .725 r
F P
0 g
s
.59251 .53746 m .60593 .54208 L .59617 .53942 L p 0 .406 .725 r
F P
0 g
s
.54423 .50068 m .53469 .49073 L .53701 .49308 L p 0 .028 .537 r
F P
0 g
s
.53701 .49308 m .54891 .50518 L .54423 .50068 L p 0 .028 .537 r
F P
0 g
s
.65837 .53356 m .64549 .53911 L .65238 .52906 L p .744 .993 .833 r
F P
0 g
s
.65238 .52906 m .66609 .5196 L .65837 .53356 L p .744 .993 .833 r
F P
0 g
s
.48941 .44467 m .50132 .45575 L .49846 .45315 L p 0 .089 .58 r
F P
0 g
s
.51176 .46641 m .49846 .45315 L .50132 .45575 L p 0 .034 .542 r
F P
0 g
s
.49846 .45315 m .51176 .46641 L .51122 .46593 L p 0 .042 .551 r
F P
0 g
s
.52511 .48046 m .51122 .46593 L .51176 .46641 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53469 .49073 L .53174 .48769 L closepath p 0 .003 .518 r
F P
0 g
s
.84456 .42531 m .85986 .43317 L .85906 .48583 L p .367 .5 .86 r
F P
0 g
s
.58445 .53362 m .57265 .52583 L .57902 .53001 L p 0 .271 .673 r
F P
0 g
s
.57902 .53001 m .59251 .53746 L .58445 .53362 L p 0 .271 .673 r
F P
0 g
s
.34808 .4483 m .36243 .44085 L .35806 .46448 L p .888 .956 .84 r
F P
0 g
s
.35806 .46448 m .34344 .47627 L .34808 .4483 L p .888 .956 .84 r
F P
0 g
s
.4165 .41413 m .42893 .41465 L .41832 .41856 L p .452 .882 .892 r
F P
0 g
s
.41832 .41856 m .40459 .42175 L .4165 .41413 L p .452 .882 .892 r
F P
0 g
s
.50132 .45575 m .51322 .46785 L .51176 .46641 L p 0 .034 .542 r
F P
0 g
s
.52511 .48046 m .51176 .46641 L .51322 .46785 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53701 .49308 L .53469 .49073 L closepath p 0 .003 .518 r
F P
0 g
s
.70633 .48464 m .69303 .49653 L .69102 .47217 L p .925 .928 .791 r
F P
0 g
s
.69102 .47217 m .70429 .45659 L .70633 .48464 L p .925 .928 .791 r
F P
0 g
s
.57265 .52583 m .56079 .51623 L .5655 .52003 L p 0 .163 .62 r
F P
0 g
s
.5655 .52003 m .57902 .53001 L .57265 .52583 L p 0 .163 .62 r
F P
0 g
s
.64549 .53911 m .63245 .54268 L .6385 .53607 L p .649 .969 .875 r
F P
0 g
s
.6385 .53607 m .65238 .52906 L .64549 .53911 L p .649 .969 .875 r
F P
0 g
s
.56079 .51623 m .54891 .50518 L .552 .50802 L p 0 .085 .575 r
F P
0 g
s
.552 .50802 m .5655 .52003 L .56079 .51623 L p 0 .085 .575 r
F P
0 g
s
.50583 .46007 m .51549 .47015 L .51322 .46785 L p 0 .028 .538 r
F P
0 g
s
.51322 .46785 m .50132 .45575 L .50583 .46007 L p 0 .028 .538 r
F P
0 g
s
.52511 .48046 m .51322 .46785 L .51549 .47015 L closepath p 0 .003 .518 r
F P
0 g
s
.54891 .50518 m .53701 .49308 L .53853 .49459 L p 0 .033 .541 r
F P
0 g
s
.53853 .49459 m .552 .50802 L .54891 .50518 L p 0 .033 .541 r
F P
0 g
s
.52511 .48046 m .53534 .49091 L .53748 .49323 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53248 .48787 L .53534 .49091 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52913 .48432 L .53248 .48787 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .5255 .48052 L .52913 .48432 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52185 .47671 L .5255 .48052 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47671 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .51549 .47015 L .51844 .47318 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53853 .49459 L .53701 .49308 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53913 .49513 L .53853 .49459 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53878 .49467 L .53913 .49513 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53748 .49323 L .53878 .49467 L closepath p 0 .003 .518 r
F P
0 g
s
.49612 .45047 m .50583 .46007 L .50132 .45575 L p 0 .071 .566 r
F P
0 g
s
.50132 .45575 m .48941 .44467 L .49612 .45047 L p 0 .071 .566 r
F P
0 g
s
.48635 .44157 m .49612 .45047 L .48941 .44467 L p 0 .133 .605 r
F P
0 g
s
.48941 .44467 m .47746 .43499 L .48635 .44157 L p 0 .133 .605 r
F P
0 g
s
.40392 .415 m .4165 .41413 L .40459 .42175 L p .59 .947 .888 r
F P
0 g
s
.40459 .42175 m .3907 .42691 L .40392 .415 L p .59 .947 .888 r
F P
0 g
s
.47652 .43353 m .48635 .44157 L .47746 .43499 L p 0 .218 .653 r
F P
0 g
s
.47746 .43499 m .46547 .42703 L .47652 .43353 L p 0 .218 .653 r
F P
0 g
s
.33365 .45516 m .34808 .4483 L .34344 .47627 L p .884 .936 .847 r
F P
0 g
s
.34344 .47627 m .32876 .48735 L .33365 .45516 L p .884 .936 .847 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51549 .47015 L p 0 .028 .54 r
F P
0 g
s
.51549 .47015 m .50583 .46007 L .5117 .46583 L p 0 .028 .54 r
F P
0 g
s
.552 .50802 m .53853 .49459 L .53913 .49513 L p 0 .041 .55 r
F P
0 g
s
.63245 .54268 m .61926 .54378 L .62447 .54003 L p .503 .905 .916 r
F P
0 g
s
.62447 .54003 m .6385 .53607 L .63245 .54268 L p .503 .905 .916 r
F P
0 g
s
.69303 .49653 m .67963 .50847 L .67766 .4878 L p .925 .939 .792 r
F P
0 g
s
.67766 .4878 m .69102 .47217 L .69303 .49653 L p .925 .939 .792 r
F P
0 g
s
.46661 .42644 m .47652 .43353 L .46547 .42703 L p 0 .329 .711 r
F P
0 g
s
.46547 .42703 m .4534 .42097 L .46661 .42644 L p 0 .329 .711 r
F P
0 g
s
.20227 .48411 m .18911 .47507 L .19318 .42214 L p .376 .496 .853 r
F P
0 g
s
.51855 .47264 m .52185 .47671 L .51844 .47318 L p 0 .032 .547 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51855 .47264 L p 0 .032 .547 r
F P
0 g
s
.53913 .49513 m .55326 .50899 L .552 .50802 L p 0 .041 .55 r
F P
0 g
s
.55326 .50899 m .53913 .49513 L .53878 .49467 L p 0 .051 .561 r
F P
0 g
s
.5655 .52003 m .552 .50802 L .55326 .50899 L p 0 .115 .606 r
F P
0 g
s
.3912 .41687 m .40392 .415 L .3907 .42691 L p .69 .98 .883 r
F P
0 g
s
.3907 .42691 m .37664 .43349 L .3912 .41687 L p .69 .98 .883 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50583 .46007 L p 0 .068 .573 r
F P
0 g
s
.50583 .46007 m .49612 .45047 L .50491 .45842 L p 0 .068 .573 r
F P
0 g
s
.45662 .42036 m .46661 .42644 L .4534 .42097 L p 0 .46 .773 r
F P
0 g
s
.4534 .42097 m .44123 .41686 L .45662 .42036 L p 0 .46 .773 r
F P
0 g
s
.31918 .46079 m .33365 .45516 L .32876 .48735 L p .866 .909 .859 r
F P
0 g
s
.32876 .48735 m .31407 .49694 L .31918 .46079 L p .866 .909 .859 r
F P
0 g
s
.61926 .54378 m .60593 .54208 L .6103 .54053 L p .3 .777 .924 r
F P
0 g
s
.6103 .54053 m .62447 .54003 L .61926 .54378 L p .3 .777 .924 r
F P
0 g
s
.19318 .42214 m .20672 .43194 L .20227 .48411 L p .376 .496 .853 r
F P
0 g
s
.21554 .49285 m .20227 .48411 L .20672 .43194 L p .399 .508 .854 r
F P
0 g
s
.57902 .53001 m .5655 .52003 L .56748 .52115 L p 0 .231 .686 r
F P
0 g
s
.55326 .50899 m .56748 .52115 L .5655 .52003 L p 0 .115 .606 r
F P
0 g
s
.52588 .48003 m .5255 .48052 L .52185 .47671 L p 0 .04 .558 r
F P
0 g
s
.52185 .47671 m .51855 .47264 L .52588 .48003 L p 0 .04 .558 r
F P
0 g
s
.53878 .49467 m .5526 .508 L .55326 .50899 L p 0 .051 .561 r
F P
0 g
s
.5526 .508 m .53878 .49467 L .53748 .49323 L p 0 .06 .572 r
F P
0 g
s
.67963 .50847 m .66609 .5196 L .66418 .50252 L p .914 .949 .808 r
F P
0 g
s
.66418 .50252 m .67766 .4878 L .67963 .50847 L p .914 .949 .808 r
F P
0 g
s
.60593 .54208 m .59251 .53746 L .59605 .53742 L p .069 .591 .875 r
F P
0 g
s
.59605 .53742 m .6103 .54053 L .60593 .54208 L p .069 .591 .875 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49612 .45047 L p 0 .126 .617 r
F P
0 g
s
.49612 .45047 m .48635 .44157 L .49806 .45095 L p 0 .126 .617 r
F P
0 g
s
.59251 .53746 m .57902 .53001 L .58176 .53083 L p 0 .394 .783 r
F P
0 g
s
.56748 .52115 m .58176 .53083 L .57902 .53001 L p 0 .231 .686 r
F P
0 g
s
.58176 .53083 m .59605 .53742 L .59251 .53746 L p 0 .394 .783 r
F P
0 g
s
.44653 .41523 m .45662 .42036 L .44123 .41686 L p .05 .6 .831 r
F P
0 g
s
.44123 .41686 m .42893 .41465 L .44653 .41523 L p .05 .6 .831 r
F P
0 g
s
.5332 .48749 m .52913 .48432 L .5255 .48052 L p 0 .05 .569 r
F P
0 g
s
.5255 .48052 m .52588 .48003 L .5332 .48749 L p 0 .05 .569 r
F P
0 g
s
.53748 .49323 m .55003 .5051 L .5526 .508 L p 0 .06 .572 r
F P
0 g
s
.55003 .5051 m .53748 .49323 L .53534 .49091 L p 0 .064 .58 r
F P
0 g
s
.77152 .40705 m .75775 .41139 L .73958 .37358 L p .726 .773 .89 r
F P
0 g
s
.75775 .41139 m .7442 .41886 L .72686 .38354 L p .797 .804 .857 r
F P
0 g
s
.72686 .38354 m .73958 .37358 L .75775 .41139 L p .797 .804 .857 r
F P
0 g
s
.30472 .46465 m .31918 .46079 L .31407 .49694 L p .834 .874 .873 r
F P
0 g
s
.31407 .49694 m .29944 .50439 L .30472 .46465 L p .834 .874 .873 r
F P
0 g
s
.78557 .40583 m .77152 .40705 L .75255 .36685 L p .633 .726 .915 r
F P
0 g
s
.73958 .37358 m .75255 .36685 L .77152 .40705 L p .726 .773 .89 r
F P
0 g
s
.20672 .43194 m .22032 .44146 L .21554 .49285 L p .399 .508 .854 r
F P
0 g
s
.22897 .50054 m .21554 .49285 L .22032 .44146 L p .444 .541 .861 r
F P
0 g
s
.53998 .49447 m .53248 .48787 L .52913 .48432 L p 0 .059 .578 r
F P
0 g
s
.52913 .48432 m .5332 .48749 L .53998 .49447 L p 0 .059 .578 r
F P
0 g
s
.53534 .49091 m .54572 .50049 L .55003 .5051 L p 0 .064 .58 r
F P
0 g
s
.54572 .50049 m .53534 .49091 L .53248 .48787 L p 0 .064 .582 r
F P
0 g
s
.7442 .41886 m .73081 .42921 L .71434 .3965 L p .846 .821 .824 r
F P
0 g
s
.71434 .3965 m .72686 .38354 L .7442 .41886 L p .846 .821 .824 r
F P
0 g
s
.56748 .52115 m .55326 .50899 L .5526 .508 L p 0 .15 .644 r
F P
0 g
s
.5152 .46798 m .51855 .47264 L .5117 .46583 L p 0 .082 .596 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .5152 .46798 L p 0 .082 .596 r
F P
0 g
s
.37833 .41927 m .3912 .41687 L .37664 .43349 L p .759 .991 .884 r
F P
0 g
s
.37664 .43349 m .36243 .44085 L .37833 .41927 L p .759 .991 .884 r
F P
0 g
s
.53248 .48787 m .53998 .49447 L .54572 .50049 L p 0 .064 .582 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48635 .44157 L p 0 .203 .674 r
F P
0 g
s
.48635 .44157 m .47652 .43353 L .49116 .44341 L p 0 .203 .674 r
F P
0 g
s
.7999 .40754 m .78557 .40583 L .7658 .36337 L p .523 .664 .925 r
F P
0 g
s
.75255 .36685 m .7658 .36337 L .78557 .40583 L p .633 .726 .915 r
F P
0 g
s
.73081 .42921 m .71753 .442 L .70194 .41198 L p .878 .83 .796 r
F P
0 g
s
.70194 .41198 m .71434 .3965 L .73081 .42921 L p .878 .83 .796 r
F P
0 g
s
.66609 .5196 m .65238 .52906 L .65055 .51534 L p .888 .957 .84 r
F P
0 g
s
.65055 .51534 m .66418 .50252 L .66609 .5196 L p .888 .957 .84 r
F P
0 g
s
.22032 .44146 m .23403 .4501 L .22897 .50054 L p .444 .541 .861 r
F P
0 g
s
.24262 .50651 m .22897 .50054 L .23403 .4501 L p .505 .59 .873 r
F P
0 g
s
.43634 .41095 m .44653 .41523 L .42893 .41465 L p .216 .73 .879 r
F P
0 g
s
.42893 .41465 m .4165 .41413 L .43634 .41095 L p .216 .73 .879 r
F P
0 g
s
.29032 .46635 m .30472 .46465 L .29944 .50439 L p .786 .829 .885 r
F P
0 g
s
.29944 .50439 m .28494 .50921 L .29032 .46635 L p .786 .829 .885 r
F P
0 g
s
.81453 .41175 m .7999 .40754 L .77938 .36292 L p .414 .596 .92 r
F P
0 g
s
.7658 .36337 m .77938 .36292 L .7999 .40754 L p .523 .664 .925 r
F P
0 g
s
.5526 .508 m .56655 .51946 L .56748 .52115 L p 0 .15 .644 r
F P
0 g
s
.56655 .51946 m .5526 .508 L .55003 .5051 L p 0 .178 .678 r
F P
0 g
s
.52628 .4785 m .52588 .48003 L .51855 .47264 L p 0 .109 .628 r
F P
0 g
s
.51855 .47264 m .5152 .46798 L .52628 .4785 L p 0 .109 .628 r
F P
0 g
s
.58176 .53083 m .56748 .52115 L .56655 .51946 L p 0 .306 .763 r
F P
0 g
s
.23403 .4501 m .24787 .45731 L .24262 .50651 L p .505 .59 .873 r
F P
0 g
s
.25649 .51019 m .24262 .50651 L .24787 .45731 L p .578 .649 .884 r
F P
0 g
s
.71753 .442 m .70429 .45659 L .68961 .42931 L p .897 .836 .777 r
F P
0 g
s
.68961 .42931 m .70194 .41198 L .71753 .442 L p .897 .836 .777 r
F P
0 g
s
.27602 .46568 m .29032 .46635 L .28494 .50921 L p .725 .775 .892 r
F P
0 g
s
.28494 .50921 m .27061 .51116 L .27602 .46568 L p .725 .775 .892 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47652 .43353 L p 0 .301 .742 r
F P
0 g
s
.47652 .43353 m .46661 .42644 L .48419 .43581 L p 0 .301 .742 r
F P
0 g
s
.51183 .46252 m .5152 .46798 L .50491 .45842 L p 0 .153 .661 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51183 .46252 L p 0 .153 .661 r
F P
0 g
s
.24787 .45731 m .26187 .46261 L .25649 .51019 L p .578 .649 .884 r
F P
0 g
s
.27061 .51116 m .25649 .51019 L .26187 .46261 L p .654 .713 .891 r
F P
0 g
s
.36534 .42171 m .37833 .41927 L .36243 .44085 L p .802 .986 .89 r
F P
0 g
s
.36243 .44085 m .34808 .4483 L .36534 .42171 L p .802 .986 .89 r
F P
0 g
s
.26187 .46261 m .27602 .46568 L .27061 .51116 L p .654 .713 .891 r
F P
0 g
s
.65238 .52906 m .6385 .53607 L .63676 .5254 L p .838 .958 .889 r
F P
0 g
s
.63676 .5254 m .65055 .51534 L .65238 .52906 L p .838 .958 .889 r
F P
0 g
s
.42604 .40737 m .43634 .41095 L .4165 .41413 L p .376 .834 .913 r
F P
0 g
s
.4165 .41413 m .40392 .415 L .42604 .40737 L p .376 .834 .913 r
F P
0 g
s
.55003 .5051 m .56273 .51504 L .56655 .51946 L p 0 .178 .678 r
F P
0 g
s
.56273 .51504 m .55003 .5051 L .54572 .50049 L p 0 .191 .698 r
F P
0 g
s
.53734 .48922 m .5332 .48749 L .52588 .48003 L p 0 .14 .661 r
F P
0 g
s
.52588 .48003 m .52628 .4785 L .53734 .48922 L p 0 .14 .661 r
F P
0 g
s
.59605 .53742 m .58176 .53083 L .58061 .52816 L p .059 .513 .894 r
F P
0 g
s
.56655 .51946 m .58061 .52816 L .58176 .53083 L p 0 .306 .763 r
F P
0 g
s
.82943 .41791 m .81453 .41175 L .79327 .36509 L p .323 .536 .905 r
F P
0 g
s
.77938 .36292 m .79327 .36509 L .81453 .41175 L p .414 .596 .92 r
F P
0 g
s
.70429 .45659 m .69102 .47217 L .67727 .44765 L p .906 .839 .768 r
F P
0 g
s
.67727 .44765 m .68961 .42931 L .70429 .45659 L p .906 .839 .768 r
F P
0 g
s
.6385 .53607 m .62447 .54003 L .62284 .53202 L p .744 .939 .949 r
F P
0 g
s
.62284 .53202 m .63676 .5254 L .6385 .53607 L p .744 .939 .949 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46661 .42644 L p 0 .416 .817 r
F P
0 g
s
.46661 .42644 m .45662 .42036 L .47717 .42815 L p 0 .416 .817 r
F P
0 g
s
.54572 .50049 m .55625 .50818 L .56273 .51504 L p 0 .191 .698 r
F P
0 g
s
.55625 .50818 m .54572 .50049 L .53998 .49447 L p 0 .187 .7 r
F P
0 g
s
.54758 .49936 m .53998 .49447 L .5332 .48749 L p 0 .168 .686 r
F P
0 g
s
.5332 .48749 m .53734 .48922 L .54758 .49936 L p 0 .168 .686 r
F P
0 g
s
.6103 .54053 m .59605 .53742 L .59471 .5334 L p .337 .723 .984 r
F P
0 g
s
.58061 .52816 m .59471 .5334 L .59605 .53742 L p .059 .513 .894 r
F P
0 g
s
.53998 .49447 m .54758 .49936 L .55625 .50818 L p 0 .187 .7 r
F P
0 g
s
.50842 .45606 m .51183 .46252 L .49806 .45095 L p 0 .243 .738 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50842 .45606 L p 0 .243 .738 r
F P
0 g
s
.62447 .54003 m .6103 .54053 L .6088 .53474 L p .581 .87 .995 r
F P
0 g
s
.6088 .53474 m .62284 .53202 L .62447 .54003 L p .581 .87 .995 r
F P
0 g
s
.58061 .52816 m .56655 .51946 L .56273 .51504 L p 0 .358 .818 r
F P
0 g
s
.59471 .5334 m .6088 .53474 L .6103 .54053 L p .337 .723 .984 r
F P
0 g
s
.35225 .4237 m .36534 .42171 L .34808 .4483 L p .823 .966 .898 r
F P
0 g
s
.34808 .4483 m .33365 .45516 L .35225 .4237 L p .823 .966 .898 r
F P
0 g
s
.52667 .47547 m .52628 .4785 L .5152 .46798 L p 0 .204 .717 r
F P
0 g
s
.5152 .46798 m .51183 .46252 L .52667 .47547 L p 0 .204 .717 r
F P
0 g
s
.69102 .47217 m .67766 .4878 L .66488 .46603 L p .908 .843 .769 r
F P
0 g
s
.66488 .46603 m .67727 .44765 L .69102 .47217 L p .908 .843 .769 r
F P
0 g
s
.41562 .40427 m .42604 .40737 L .40392 .415 L p .515 .906 .935 r
F P
0 g
s
.40392 .415 m .3912 .41687 L .41562 .40427 L p .515 .906 .935 r
F P
0 g
s
.84456 .42531 m .82943 .41791 L .80747 .36928 L p .264 .496 .892 r
F P
0 g
s
.79327 .36509 m .80747 .36928 L .82943 .41791 L p .323 .536 .905 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45662 .42036 L p .055 .539 .89 r
F P
0 g
s
.45662 .42036 m .44653 .41523 L .47008 .42042 L p .055 .539 .89 r
F P
0 g
s
.50498 .4485 m .50842 .45606 L .49116 .44341 L p 0 .346 .815 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50498 .4485 L p 0 .346 .815 r
F P
0 g
s
.67766 .4878 m .66418 .50252 L .6524 .48342 L p .901 .847 .781 r
F P
0 g
s
.6524 .48342 m .66488 .46603 L .67766 .4878 L p .901 .847 .781 r
F P
0 g
s
.56273 .51504 m .57555 .52212 L .58061 .52816 L p 0 .358 .818 r
F P
0 g
s
.57555 .52212 m .56273 .51504 L .55625 .50818 L p 0 .372 .837 r
F P
0 g
s
.59471 .5334 m .58061 .52816 L .57555 .52212 L p .211 .563 .937 r
F P
0 g
s
.54153 .48888 m .53734 .48922 L .52628 .4785 L p 0 .262 .767 r
F P
0 g
s
.52628 .4785 m .52667 .47547 L .54153 .48888 L p 0 .262 .767 r
F P
0 g
s
.33909 .4248 m .35225 .4237 L .33365 .45516 L p .821 .932 .904 r
F P
0 g
s
.33365 .45516 m .31918 .46079 L .33909 .4248 L p .821 .932 .904 r
F P
0 g
s
.85986 .43317 m .84456 .42531 L .82194 .37477 L p .242 .483 .888 r
F P
0 g
s
.80747 .36928 m .82194 .37477 L .84456 .42531 L p .264 .496 .892 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44653 .41523 L p .209 .657 .949 r
F P
0 g
s
.44653 .41523 m .43634 .41095 L .46294 .41262 L p .209 .657 .949 r
F P
0 g
s
.4051 .40142 m .41562 .40427 L .3912 .41687 L p .622 .944 .947 r
F P
0 g
s
.3912 .41687 m .37833 .41927 L .4051 .40142 L p .622 .944 .947 r
F P
0 g
s
.52708 .47059 m .52667 .47547 L .51183 .46252 L p 0 .313 .802 r
F P
0 g
s
.51183 .46252 m .50842 .45606 L .52708 .47059 L p 0 .313 .802 r
F P
0 g
s
.55625 .50818 m .56691 .5131 L .57555 .52212 L p 0 .372 .837 r
F P
0 g
s
.56691 .5131 m .55625 .50818 L .54758 .49936 L p 0 .355 .829 r
F P
0 g
s
.66418 .50252 m .65055 .51534 L .6398 .49881 L p .883 .85 .806 r
F P
0 g
s
.6398 .49881 m .6524 .48342 L .66418 .50252 L p .883 .85 .806 r
F P
0 g
s
.55528 .50174 m .54758 .49936 L .53734 .48922 L p 0 .315 .804 r
F P
0 g
s
.53734 .48922 m .54153 .48888 L .55528 .50174 L p 0 .315 .804 r
F P
0 g
s
.54758 .49936 m .55528 .50174 L .56691 .5131 L p 0 .355 .829 r
F P
0 g
s
.6088 .53474 m .59471 .5334 L .58845 .5256 L p .483 .725 .978 r
F P
0 g
s
.57555 .52212 m .58845 .5256 L .59471 .5334 L p .211 .563 .937 r
F P
0 g
s
.50151 .43979 m .50498 .4485 L .48419 .43581 L p .081 .45 .882 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50151 .43979 L p .081 .45 .882 r
F P
0 g
s
.3259 .42462 m .33909 .4248 L .31918 .46079 L p .802 .886 .906 r
F P
0 g
s
.31918 .46079 m .30472 .46465 L .3259 .42462 L p .802 .886 .906 r
F P
0 g
s
.65055 .51534 m .63676 .5254 L .62709 .51131 L p .85 .851 .844 r
F P
0 g
s
.62709 .51131 m .6398 .49881 L .65055 .51534 L p .85 .851 .844 r
F P
0 g
s
.58845 .5256 m .57555 .52212 L .56691 .5131 L p .275 .551 .926 r
F P
0 g
s
.73958 .37358 m .72686 .38354 L .69455 .35386 L p .786 .778 .845 r
F P
0 g
s
.72686 .38354 m .71434 .3965 L .68385 .36866 L p .824 .776 .808 r
F P
0 g
s
.68385 .36866 m .69455 .35386 L .72686 .38354 L p .824 .776 .808 r
F P
0 g
s
.82194 .37477 m .8366 .38074 L .85986 .43317 L p .242 .483 .888 r
F P
0 g
s
.62284 .53202 m .6088 .53474 L .60137 .52502 L p .675 .811 .948 r
F P
0 g
s
.58845 .5256 m .60137 .52502 L .6088 .53474 L p .483 .725 .978 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43634 .41095 L p .358 .752 .986 r
F P
0 g
s
.43634 .41095 m .42604 .40737 L .45573 .40475 L p .358 .752 .986 r
F P
0 g
s
.71434 .3965 m .70194 .41198 L .67328 .38589 L p .846 .772 .779 r
F P
0 g
s
.67328 .38589 m .68385 .36866 L .71434 .3965 L p .846 .772 .779 r
F P
0 g
s
.75255 .36685 m .73958 .37358 L .70543 .34194 L p .726 .771 .889 r
F P
0 g
s
.69455 .35386 m .70543 .34194 L .73958 .37358 L p .786 .778 .845 r
F P
0 g
s
.63676 .5254 m .62284 .53202 L .61426 .5202 L p .787 .843 .894 r
F P
0 g
s
.61426 .5202 m .62709 .51131 L .63676 .5254 L p .787 .843 .894 r
F P
0 g
s
.60137 .52502 m .61426 .5202 L .62284 .53202 L p .675 .811 .948 r
F P
0 g
s
.39449 .39854 m .4051 .40142 L .37833 .41927 L p .697 .954 .952 r
F P
0 g
s
.37833 .41927 m .36534 .42171 L .39449 .39854 L p .697 .954 .952 r
F P
0 g
s
.54576 .48595 m .54153 .48888 L .52667 .47547 L p .091 .387 .846 r
F P
0 g
s
.52667 .47547 m .52708 .47059 L .54576 .48595 L p .091 .387 .846 r
F P
0 g
s
.70194 .41198 m .68961 .42931 L .66278 .40488 L p .858 .767 .761 r
F P
0 g
s
.66278 .40488 m .67328 .38589 L .70194 .41198 L p .858 .767 .761 r
F P
0 g
s
.52748 .46363 m .52708 .47059 L .50842 .45606 L p .122 .417 .863 r
F P
0 g
s
.50842 .45606 m .50498 .4485 L .52748 .46363 L p .122 .417 .863 r
F P
0 g
s
.7658 .36337 m .75255 .36685 L .71654 .33314 L p .634 .748 .931 r
F P
0 g
s
.70543 .34194 m .71654 .33314 L .75255 .36685 L p .726 .771 .889 r
F P
0 g
s
.3127 .42289 m .3259 .42462 L .30472 .46465 L p .767 .832 .902 r
F P
0 g
s
.30472 .46465 m .29032 .46635 L .3127 .42289 L p .767 .832 .902 r
F P
0 g
s
.49802 .42998 m .50151 .43979 L .47717 .42815 L p .228 .544 .928 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49802 .42998 L p .228 .544 .928 r
F P
0 g
s
.68961 .42931 m .67727 .44765 L .65231 .42481 L p .862 .763 .752 r
F P
0 g
s
.65231 .42481 m .66278 .40488 L .68961 .42931 L p .862 .763 .752 r
F P
0 g
s
.56691 .5131 m .57765 .51453 L .58845 .5256 L p .275 .551 .926 r
F P
0 g
s
.57765 .51453 m .56691 .5131 L .55528 .50174 L p .266 .509 .901 r
F P
0 g
s
.56306 .50097 m .55528 .50174 L .54153 .48888 L p .202 .453 .875 r
F P
0 g
s
.54153 .48888 m .54576 .48595 L .56306 .50097 L p .202 .453 .875 r
F P
0 g
s
.60137 .52502 m .58845 .5256 L .57765 .51453 L p .513 .669 .934 r
F P
0 g
s
.77938 .36292 m .7658 .36337 L .72792 .32748 L p .509 .702 .957 r
F P
0 g
s
.71654 .33314 m .72792 .32748 L .7658 .36337 L p .634 .748 .931 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42604 .40737 L p .484 .817 .999 r
F P
0 g
s
.42604 .40737 m .41562 .40427 L .44846 .39682 L p .484 .817 .999 r
F P
0 g
s
.29953 .41946 m .3127 .42289 L .29032 .46635 L p .724 .774 .893 r
F P
0 g
s
.29032 .46635 m .27602 .46568 L .29953 .41946 L p .724 .774 .893 r
F P
0 g
s
.55528 .50174 m .56306 .50097 L .57765 .51453 L p .266 .509 .901 r
F P
0 g
s
.67727 .44765 m .66488 .46603 L .64182 .44474 L p .86 .76 .752 r
F P
0 g
s
.64182 .44474 m .65231 .42481 L .67727 .44765 L p .86 .76 .752 r
F P
0 g
s
.38378 .3954 m .39449 .39854 L .36534 .42171 L p .742 .94 .949 r
F P
0 g
s
.36534 .42171 m .35225 .4237 L .38378 .3954 L p .742 .94 .949 r
F P
0 g
s
.20672 .43194 m .19318 .42214 L .22154 .37026 L p .503 .557 .844 r
F P
0 g
s
.28641 .4143 m .29953 .41946 L .27602 .46568 L p .675 .717 .881 r
F P
0 g
s
.27602 .46568 m .26187 .46261 L .28641 .4143 L p .675 .717 .881 r
F P
0 g
s
.52789 .45451 m .52748 .46363 L .50498 .4485 L p .281 .5 .891 r
F P
0 g
s
.50498 .4485 m .50151 .43979 L .52789 .45451 L p .281 .5 .891 r
F P
0 g
s
.22154 .37026 m .23447 .38035 L .20672 .43194 L p .503 .557 .844 r
F P
0 g
s
.22032 .44146 m .20672 .43194 L .23447 .38035 L p .519 .565 .842 r
F P
0 g
s
.4945 .41916 m .49802 .42998 L .47008 .42042 L p .359 .619 .95 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .4945 .41916 L p .359 .619 .95 r
F P
0 g
s
.55003 .4801 m .54576 .48595 L .52708 .47059 L p .286 .484 .877 r
F P
0 g
s
.52708 .47059 m .52748 .46363 L .55003 .4801 L p .286 .484 .877 r
F P
0 g
s
.66488 .46603 m .6524 .48342 L .63127 .46368 L p .851 .759 .76 r
F P
0 g
s
.63127 .46368 m .64182 .44474 L .66488 .46603 L p .851 .759 .76 r
F P
0 g
s
.23447 .38035 m .24739 .3902 L .22032 .44146 L p .519 .565 .842 r
F P
0 g
s
.23403 .4501 m .22032 .44146 L .24739 .3902 L p .547 .587 .846 r
F P
0 g
s
.61426 .5202 m .60137 .52502 L .58843 .51201 L p .665 .725 .894 r
F P
0 g
s
.57765 .51453 m .58843 .51201 L .60137 .52502 L p .513 .669 .934 r
F P
0 g
s
.27335 .40753 m .28641 .4143 L .26187 .46261 L p .627 .665 .867 r
F P
0 g
s
.26187 .46261 m .24787 .45731 L .27335 .40753 L p .627 .665 .867 r
F P
0 g
s
.79327 .36509 m .77938 .36292 L .73959 .32475 L p .366 .634 .957 r
F P
0 g
s
.72792 .32748 m .73959 .32475 L .77938 .36292 L p .509 .702 .957 r
F P
0 g
s
.24739 .3902 m .26035 .39939 L .23403 .4501 L p .547 .587 .846 r
F P
0 g
s
.24787 .45731 m .23403 .4501 L .26035 .39939 L p .583 .621 .855 r
F P
0 g
s
.26035 .39939 m .27335 .40753 L .24787 .45731 L p .583 .621 .855 r
F P
0 g
s
.58843 .51201 m .57765 .51453 L .56306 .50097 L p .479 .606 .9 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41562 .40427 L p .581 .852 .995 r
F P
0 g
s
.41562 .40427 m .4051 .40142 L .44112 .38881 L p .581 .852 .995 r
F P
0 g
s
.6524 .48342 m .6398 .49881 L .62065 .48065 L p .834 .757 .779 r
F P
0 g
s
.62065 .48065 m .63127 .46368 L .6524 .48342 L p .834 .757 .779 r
F P
0 g
s
.62709 .51131 m .61426 .5202 L .59921 .50537 L p .753 .747 .847 r
F P
0 g
s
.58843 .51201 m .59921 .50537 L .61426 .5202 L p .665 .725 .894 r
F P
0 g
s
.37299 .39175 m .38378 .3954 L .35225 .4237 L p .761 .909 .941 r
F P
0 g
s
.35225 .4237 m .33909 .4248 L .37299 .39175 L p .761 .909 .941 r
F P
0 g
s
.57088 .49665 m .56306 .50097 L .54576 .48595 L p .403 .546 .884 r
F P
0 g
s
.54576 .48595 m .55003 .4801 L .57088 .49665 L p .403 .546 .884 r
F P
0 g
s
.6398 .49881 m .62709 .51131 L .60996 .49477 L p .804 .755 .807 r
F P
0 g
s
.60996 .49477 m .62065 .48065 L .6398 .49881 L p .804 .755 .807 r
F P
0 g
s
.59921 .50537 m .60996 .49477 L .62709 .51131 L p .753 .747 .847 r
F P
0 g
s
.56306 .50097 m .57088 .49665 L .58843 .51201 L p .479 .606 .9 r
F P
0 g
s
.49097 .40751 m .4945 .41916 L .46294 .41262 L p .466 .673 .954 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49097 .40751 L p .466 .673 .954 r
F P
0 g
s
.5283 .44329 m .52789 .45451 L .50151 .43979 L p .407 .559 .893 r
F P
0 g
s
.50151 .43979 m .49802 .42998 L .5283 .44329 L p .407 .559 .893 r
F P
0 g
s
.80747 .36928 m .79327 .36509 L .75156 .32455 L p .238 .561 .936 r
F P
0 g
s
.73959 .32475 m .75156 .32455 L .79327 .36509 L p .366 .634 .957 r
F P
0 g
s
.55431 .47121 m .55003 .4801 L .52748 .46363 L p .433 .547 .871 r
F P
0 g
s
.52748 .46363 m .52789 .45451 L .55431 .47121 L p .433 .547 .871 r
F P
0 g
s
.59921 .50537 m .58843 .51201 L .57088 .49665 L p .615 .654 .865 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .4051 .40142 L p .649 .864 .981 r
F P
0 g
s
.4051 .40142 m .39449 .39854 L .43372 .38074 L p .649 .864 .981 r
F P
0 g
s
.36214 .3874 m .37299 .39175 L .33909 .4248 L p .76 .867 .927 r
F P
0 g
s
.33909 .4248 m .3259 .42462 L .36214 .3874 L p .76 .867 .927 r
F P
0 g
s
.48741 .39524 m .49097 .40751 L .45573 .40475 L p .548 .711 .947 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48741 .39524 L p .548 .711 .947 r
F P
0 g
s
.52871 .4302 m .5283 .44329 L .49802 .42998 L p .501 .598 .883 r
F P
0 g
s
.49802 .42998 m .4945 .41916 L .52871 .4302 L p .501 .598 .883 r
F P
0 g
s
.57872 .48861 m .57088 .49665 L .55003 .4801 L p .539 .596 .859 r
F P
0 g
s
.55003 .4801 m .55431 .47121 L .57872 .48861 L p .539 .596 .859 r
F P
0 g
s
.57088 .49665 m .57872 .48861 L .59921 .50537 L p .615 .654 .865 r
F P
0 g
s
.69455 .35386 m .68385 .36866 L .64103 .34807 L p .795 .741 .803 r
F P
0 g
s
.68385 .36866 m .67328 .38589 L .63318 .36591 L p .808 .728 .775 r
F P
0 g
s
.63318 .36591 m .64103 .34807 L .68385 .36866 L p .808 .728 .775 r
F P
0 g
s
.67328 .38589 m .66278 .40488 L .6254 .38529 L p .813 .716 .758 r
F P
0 g
s
.6254 .38529 m .63318 .36591 L .67328 .38589 L p .813 .716 .758 r
F P
0 g
s
.60996 .49477 m .59921 .50537 L .57872 .48861 L p .696 .675 .825 r
F P
0 g
s
.70543 .34194 m .69455 .35386 L .64898 .33238 L p .77 .756 .841 r
F P
0 g
s
.64103 .34807 m .64898 .33238 L .69455 .35386 L p .795 .741 .803 r
F P
0 g
s
.66278 .40488 m .65231 .42481 L .61766 .40548 L p .813 .707 .749 r
F P
0 g
s
.61766 .40548 m .6254 .38529 L .66278 .40488 L p .813 .707 .749 r
F P
0 g
s
.55861 .45938 m .55431 .47121 L .52789 .45451 L p .534 .583 .85 r
F P
0 g
s
.52789 .45451 m .5283 .44329 L .55861 .45938 L p .534 .583 .85 r
F P
0 g
s
.82194 .37477 m .80747 .36928 L .76381 .3263 L p .154 .509 .912 r
F P
0 g
s
.75156 .32455 m .76381 .3263 L .80747 .36928 L p .238 .561 .936 r
F P
0 g
s
.65231 .42481 m .64182 .44474 L .60991 .42562 L p .806 .7 .748 r
F P
0 g
s
.60991 .42562 m .61766 .40548 L .65231 .42481 L p .806 .7 .748 r
F P
0 g
s
.62065 .48065 m .60996 .49477 L .58655 .477 L p .745 .684 .792 r
F P
0 g
s
.57872 .48861 m .58655 .477 L .60996 .49477 L p .696 .675 .825 r
F P
0 g
s
.71654 .33314 m .70543 .34194 L .65707 .31926 L p .725 .769 .888 r
F P
0 g
s
.64898 .33238 m .65707 .31926 L .70543 .34194 L p .77 .756 .841 r
F P
0 g
s
.35123 .3822 m .36214 .3874 L .3259 .42462 L p .745 .82 .911 r
F P
0 g
s
.3259 .42462 m .3127 .42289 L .35123 .3822 L p .745 .82 .911 r
F P
0 g
s
.64182 .44474 m .63127 .46368 L .60216 .44481 L p .795 .695 .754 r
F P
0 g
s
.60216 .44481 m .60991 .42562 L .64182 .44474 L p .795 .695 .754 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39449 .39854 L p .692 .858 .961 r
F P
0 g
s
.39449 .39854 m .38378 .3954 L .42626 .3726 L p .692 .858 .961 r
F P
0 g
s
.63127 .46368 m .62065 .48065 L .59437 .4622 L p .776 .69 .769 r
F P
0 g
s
.58655 .477 m .59437 .4622 L .62065 .48065 L p .745 .684 .792 r
F P
0 g
s
.59437 .4622 m .60216 .44481 L .63127 .46368 L p .776 .69 .769 r
F P
0 g
s
.52912 .41556 m .52871 .4302 L .4945 .41916 L p .569 .626 .869 r
F P
0 g
s
.4945 .41916 m .49097 .40751 L .52912 .41556 L p .569 .626 .869 r
F P
0 g
s
.48383 .38261 m .48741 .39524 L .44846 .39682 L p .609 .735 .935 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48383 .38261 L p .609 .735 .935 r
F P
0 g
s
.58655 .477 m .57872 .48861 L .55431 .47121 L p .625 .621 .827 r
F P
0 g
s
.55431 .47121 m .55861 .45938 L .58655 .477 L p .625 .621 .827 r
F P
0 g
s
.72792 .32748 m .71654 .33314 L .66533 .30892 L p .648 .772 .939 r
F P
0 g
s
.65707 .31926 m .66533 .30892 L .71654 .33314 L p .725 .769 .888 r
F P
0 g
s
.5629 .44492 m .55861 .45938 L .5283 .44329 L p .602 .606 .827 r
F P
0 g
s
.5283 .44329 m .52871 .4302 L .5629 .44492 L p .602 .606 .827 r
F P
0 g
s
.34029 .37609 m .35123 .3822 L .3127 .42289 L p .722 .773 .893 r
F P
0 g
s
.3127 .42289 m .29953 .41946 L .34029 .37609 L p .722 .773 .893 r
F P
0 g
s
.59437 .4622 m .58655 .477 L .55861 .45938 L p .679 .635 .799 r
F P
0 g
s
.8366 .38074 m .82194 .37477 L .77631 .3293 L p .127 .49 .903 r
F P
0 g
s
.76381 .3263 m .77631 .3293 L .82194 .37477 L p .154 .509 .912 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38378 .3954 L p .717 .842 .942 r
F P
0 g
s
.38378 .3954 m .37299 .39175 L .41873 .36438 L p .717 .842 .942 r
F P
0 g
s
.52954 .39981 m .52912 .41556 L .49097 .40751 L p .618 .647 .856 r
F P
0 g
s
.49097 .40751 m .48741 .39524 L .52954 .39981 L p .618 .647 .856 r
F P
0 g
s
.55861 .45938 m .5629 .44492 L .59437 .4622 L p .679 .635 .799 r
F P
0 g
s
.48023 .36987 m .48383 .38261 L .44112 .38881 L p .652 .75 .922 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48023 .36987 L p .652 .75 .922 r
F P
0 g
s
.73959 .32475 m .72792 .32748 L .6738 .30139 L p .53 .752 .977 r
F P
0 g
s
.66533 .30892 m .6738 .30139 L .72792 .32748 L p .648 .772 .939 r
F P
0 g
s
.60216 .44481 m .59437 .4622 L .5629 .44492 L p .715 .645 .778 r
F P
0 g
s
.32932 .36905 m .34029 .37609 L .29953 .41946 L p .695 .73 .877 r
F P
0 g
s
.29953 .41946 m .28641 .4143 L .32932 .36905 L p .695 .73 .877 r
F P
0 g
s
.5672 .42833 m .5629 .44492 L .52871 .4302 L p .648 .621 .809 r
F P
0 g
s
.52871 .4302 m .52912 .41556 L .5672 .42833 L p .648 .621 .809 r
F P
0 g
s
.60991 .42562 m .60216 .44481 L .5672 .42833 L p .738 .653 .765 r
F P
0 g
s
.5629 .44492 m .5672 .42833 L .60216 .44481 L p .715 .645 .778 r
F P
0 g
s
.61766 .40548 m .60991 .42562 L .57149 .41021 L p .754 .661 .759 r
F P
0 g
s
.5672 .42833 m .57149 .41021 L .60991 .42562 L p .738 .653 .765 r
F P
0 g
s
.6254 .38529 m .61766 .40548 L .57579 .39128 L p .764 .672 .76 r
F P
0 g
s
.57149 .41021 m .57579 .39128 L .61766 .40548 L p .754 .661 .759 r
F P
0 g
s
.63318 .36591 m .6254 .38529 L .5801 .37226 L p .77 .684 .768 r
F P
0 g
s
.57579 .39128 m .5801 .37226 L .6254 .38529 L p .764 .672 .76 r
F P
0 g
s
.52995 .38343 m .52954 .39981 L .48741 .39524 L p .653 .664 .848 r
F P
0 g
s
.48741 .39524 m .48383 .38261 L .52995 .38343 L p .653 .664 .848 r
F P
0 g
s
.31832 .36113 m .32932 .36905 L .28641 .4143 L p .667 .692 .864 r
F P
0 g
s
.28641 .4143 m .27335 .40753 L .31832 .36113 L p .667 .692 .864 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37299 .39175 L p .727 .821 .923 r
F P
0 g
s
.37299 .39175 m .36214 .3874 L .41113 .35609 L p .727 .821 .923 r
F P
0 g
s
.64103 .34807 m .63318 .36591 L .58443 .35384 L p .771 .7 .785 r
F P
0 g
s
.5801 .37226 m .58443 .35384 L .63318 .36591 L p .77 .684 .768 r
F P
0 g
s
.57149 .41021 m .5672 .42833 L .52912 .41556 L p .68 .634 .796 r
F P
0 g
s
.52912 .41556 m .52954 .39981 L .57149 .41021 L p .68 .634 .796 r
F P
0 g
s
.47659 .35729 m .48023 .36987 L .43372 .38074 L p .682 .76 .91 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47659 .35729 L p .682 .76 .91 r
F P
0 g
s
.77631 .3293 m .78901 .33274 L .8366 .38074 L p .127 .49 .903 r
F P
0 g
s
.64898 .33238 m .64103 .34807 L .58881 .33665 L p .766 .72 .81 r
F P
0 g
s
.58443 .35384 m .58881 .33665 L .64103 .34807 L p .771 .7 .785 r
F P
0 g
s
.75156 .32455 m .73959 .32475 L .68248 .29648 L p .379 .7 .983 r
F P
0 g
s
.6738 .30139 m .68248 .29648 L .73959 .32475 L p .53 .752 .977 r
F P
0 g
s
.30729 .35246 m .31832 .36113 L .27335 .40753 L p .641 .661 .854 r
F P
0 g
s
.27335 .40753 m .26035 .39939 L .30729 .35246 L p .641 .661 .854 r
F P
0 g
s
.65707 .31926 m .64898 .33238 L .59325 .32118 L p .752 .743 .844 r
F P
0 g
s
.58881 .33665 m .59325 .32118 L .64898 .33238 L p .766 .72 .81 r
F P
0 g
s
.57579 .39128 m .57149 .41021 L .52954 .39981 L p .703 .646 .79 r
F P
0 g
s
.29624 .3432 m .30729 .35246 L .26035 .39939 L p .619 .638 .847 r
F P
0 g
s
.26035 .39939 m .24739 .3902 L .29624 .3432 L p .619 .638 .847 r
F P
0 g
s
.53037 .36695 m .52995 .38343 L .48383 .38261 L p .68 .68 .843 r
F P
0 g
s
.48383 .38261 m .48023 .36987 L .53037 .36695 L p .68 .68 .843 r
F P
0 g
s
.52954 .39981 m .52995 .38343 L .57579 .39128 L p .703 .646 .79 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36214 .3874 L p .727 .796 .907 r
F P
0 g
s
.36214 .3874 m .35123 .3822 L .40346 .34772 L p .727 .796 .907 r
F P
0 g
s
.28514 .33356 m .29624 .3432 L .24739 .3902 L p .6 .623 .846 r
F P
0 g
s
.24739 .3902 m .23447 .38035 L .28514 .33356 L p .6 .623 .846 r
F P
0 g
s
.5801 .37226 m .57579 .39128 L .52995 .38343 L p .719 .659 .789 r
F P
0 g
s
.47292 .34508 m .47659 .35729 L .42626 .3726 L p .702 .765 .901 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47292 .34508 L p .702 .765 .901 r
F P
0 g
s
.27399 .32374 m .28514 .33356 L .23447 .38035 L p .587 .617 .849 r
F P
0 g
s
.23447 .38035 m .22154 .37026 L .27399 .32374 L p .587 .617 .849 r
F P
0 g
s
.66533 .30892 m .65707 .31926 L .59777 .30778 L p .723 .768 .889 r
F P
0 g
s
.59325 .32118 m .59777 .30778 L .65707 .31926 L p .752 .743 .844 r
F P
0 g
s
.52995 .38343 m .53037 .36695 L .5801 .37226 L p .719 .659 .789 r
F P
0 g
s
.58443 .35384 m .5801 .37226 L .53037 .36695 L p .731 .675 .796 r
F P
0 g
s
.76381 .3263 m .75156 .32455 L .69138 .29382 L p .233 .629 .957 r
F P
0 g
s
.68248 .29648 m .69138 .29382 L .75156 .32455 L p .379 .7 .983 r
F P
0 g
s
.53079 .35085 m .53037 .36695 L .48023 .36987 L p .699 .696 .844 r
F P
0 g
s
.48023 .36987 m .47659 .35729 L .53079 .35085 L p .699 .696 .844 r
F P
0 g
s
.58881 .33665 m .58443 .35384 L .53079 .35085 L p .738 .693 .809 r
F P
0 g
s
.53037 .36695 m .53079 .35085 L .58443 .35384 L p .731 .675 .796 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35123 .3822 L p .721 .772 .893 r
F P
0 g
s
.35123 .3822 m .34029 .37609 L .39573 .33928 L p .721 .772 .893 r
F P
0 g
s
.6738 .30139 m .66533 .30892 L .60237 .29663 L p .671 .79 .938 r
F P
0 g
s
.59777 .30778 m .60237 .29663 L .66533 .30892 L p .723 .768 .889 r
F P
0 g
s
.4692 .33344 m .47292 .34508 L .41873 .36438 L p .714 .769 .895 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .4692 .33344 L p .714 .769 .895 r
F P
0 g
s
.59325 .32118 m .58881 .33665 L .53122 .33558 L p .739 .715 .829 r
F P
0 g
s
.53079 .35085 m .53122 .33558 L .58881 .33665 L p .738 .693 .809 r
F P
0 g
s
.53122 .33558 m .53079 .35085 L .47659 .35729 L p .712 .713 .849 r
F P
0 g
s
.47659 .35729 m .47292 .34508 L .53122 .33558 L p .712 .713 .849 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34029 .37609 L p .71 .749 .882 r
F P
0 g
s
.34029 .37609 m .32932 .36905 L .38792 .33076 L p .71 .749 .882 r
F P
0 g
s
.77631 .3293 m .76381 .3263 L .70049 .2929 L p .133 .57 .925 r
F P
0 g
s
.69138 .29382 m .70049 .2929 L .76381 .3263 L p .233 .629 .957 r
F P
0 g
s
.59777 .30778 m .59325 .32118 L .53165 .32148 L p .735 .74 .856 r
F P
0 g
s
.53122 .33558 m .53165 .32148 L .59325 .32118 L p .739 .715 .829 r
F P
0 g
s
.68248 .29648 m .6738 .30139 L .60708 .28776 L p .587 .797 .98 r
F P
0 g
s
.60237 .29663 m .60708 .28776 L .6738 .30139 L p .671 .79 .938 r
F P
0 g
s
.46544 .3225 m .4692 .33344 L .41113 .35609 L p .72 .77 .892 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46544 .3225 L p .72 .77 .892 r
F P
0 g
s
.53165 .32148 m .53122 .33558 L .47292 .34508 L p .72 .731 .859 r
F P
0 g
s
.47292 .34508 m .4692 .33344 L .53165 .32148 L p .72 .731 .859 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32932 .36905 L p .696 .728 .875 r
F P
0 g
s
.32932 .36905 m .31832 .36113 L .38005 .32217 L p .696 .728 .875 r
F P
0 g
s
.60237 .29663 m .59777 .30778 L .53208 .30881 L p .721 .768 .889 r
F P
0 g
s
.53165 .32148 m .53208 .30881 L .59777 .30778 L p .735 .74 .856 r
F P
0 g
s
.46163 .31234 m .46544 .3225 L .40346 .34772 L p .72 .77 .892 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46163 .31234 L p .72 .77 .892 r
F P
0 g
s
.53208 .30881 m .53165 .32148 L .4692 .33344 L p .723 .75 .873 r
F P
0 g
s
.4692 .33344 m .46544 .3225 L .53208 .30881 L p .723 .75 .873 r
F P
0 g
s
.69138 .29382 m .68248 .29648 L .6119 .28101 L p .472 .778 .997 r
F P
0 g
s
.60708 .28776 m .6119 .28101 L .68248 .29648 L p .587 .797 .98 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31832 .36113 L p .681 .71 .87 r
F P
0 g
s
.31832 .36113 m .30729 .35246 L .3721 .3135 L p .681 .71 .87 r
F P
0 g
s
.78901 .33274 m .77631 .3293 L .7098 .29308 L p .101 .548 .912 r
F P
0 g
s
.70049 .2929 m .7098 .29308 L .77631 .3293 L p .133 .57 .925 r
F P
0 g
s
.60708 .28776 m .60237 .29663 L .53253 .29771 L p .695 .795 .927 r
F P
0 g
s
.53208 .30881 m .53253 .29771 L .60237 .29663 L p .721 .768 .889 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30729 .35246 L p .666 .696 .868 r
F P
0 g
s
.30729 .35246 m .29624 .3432 L .36408 .30475 L p .666 .696 .868 r
F P
0 g
s
.53253 .29771 m .53208 .30881 L .46544 .3225 L p .72 .769 .891 r
F P
0 g
s
.45776 .30295 m .46163 .31234 L .39573 .33928 L p .716 .769 .894 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45776 .30295 L p .716 .769 .894 r
F P
0 g
s
.46544 .3225 m .46163 .31234 L .53253 .29771 L p .72 .769 .891 r
F P
0 g
s
.70049 .2929 m .69138 .29382 L .61684 .27608 L p .351 .735 .986 r
F P
0 g
s
.6119 .28101 m .61684 .27608 L .69138 .29382 L p .472 .778 .997 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29624 .3432 L p .652 .686 .869 r
F P
0 g
s
.29624 .3432 m .28514 .33356 L .35599 .29592 L p .652 .686 .869 r
F P
0 g
s
.6119 .28101 m .60708 .28776 L .53298 .2882 L p .652 .815 .962 r
F P
0 g
s
.53253 .29771 m .53298 .2882 L .60708 .28776 L p .695 .795 .927 r
F P
0 g
s
.7098 .29308 m .71927 .29362 L .78901 .33274 L p .101 .548 .912 r
F P
0 g
s
.53298 .2882 m .53253 .29771 L .46163 .31234 L p .711 .786 .91 r
F P
0 g
s
.45384 .29429 m .45776 .30295 L .38792 .33076 L p .708 .767 .898 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45384 .29429 L p .708 .767 .898 r
F P
0 g
s
.46163 .31234 m .45776 .30295 L .53298 .2882 L p .711 .786 .91 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28514 .33356 L p .64 .682 .874 r
F P
0 g
s
.28514 .33356 m .27399 .32374 L .34782 .287 L p .64 .682 .874 r
F P
0 g
s
.61684 .27608 m .6119 .28101 L .53345 .28016 L p .594 .823 .987 r
F P
0 g
s
.53298 .2882 m .53345 .28016 L .6119 .28101 L p .652 .815 .962 r
F P
0 g
s
.44985 .28624 m .45384 .29429 L .38005 .32217 L p .697 .764 .903 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44985 .28624 L p .697 .764 .903 r
F P
0 g
s
.7098 .29308 m .70049 .2929 L .62188 .27254 L p .261 .691 .964 r
F P
0 g
s
.61684 .27608 m .62188 .27254 L .70049 .2929 L p .351 .735 .986 r
F P
0 g
s
.53345 .28016 m .53298 .2882 L .45776 .30295 L p .696 .801 .93 r
F P
0 g
s
.45776 .30295 m .45384 .29429 L .53345 .28016 L p .696 .801 .93 r
F P
0 g
s
.4458 .27863 m .44985 .28624 L .3721 .3135 L p .684 .76 .909 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .4458 .27863 L p .684 .76 .909 r
F P
0 g
s
.62188 .27254 m .61684 .27608 L .53392 .27338 L p .529 .817 .998 r
F P
0 g
s
.53345 .28016 m .53392 .27338 L .61684 .27608 L p .594 .823 .987 r
F P
0 g
s
.53392 .27338 m .53345 .28016 L .45384 .29429 L p .675 .811 .948 r
F P
0 g
s
.45384 .29429 m .44985 .28624 L .53392 .27338 L p .675 .811 .948 r
F P
0 g
s
.71927 .29362 m .7098 .29308 L .62703 .26986 L p .226 .669 .954 r
F P
0 g
s
.62188 .27254 m .62703 .26986 L .7098 .29308 L p .261 .691 .964 r
F P
0 g
s
.4417 .27127 m .4458 .27863 L .36408 .30475 L p .67 .756 .915 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .4417 .27127 L p .67 .756 .915 r
F P
0 g
s
.5344 .26754 m .53392 .27338 L .44985 .28624 L p .65 .815 .963 r
F P
0 g
s
.44985 .28624 m .4458 .27863 L .5344 .26754 L p .65 .815 .963 r
F P
0 g
s
.53392 .27338 m .5344 .26754 L .62188 .27254 L p .529 .817 .998 r
F P
0 g
s
.62703 .26986 m .62188 .27254 L .5344 .26754 L p .474 .802 1 r
F P
0 g
s
.43754 .26392 m .4417 .27127 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.62703 .26986 m .63227 .26744 L .71927 .29362 L p .226 .669 .954 r
F P
0 g
s
.53489 .26227 m .5344 .26754 L .4458 .27863 L p .625 .813 .972 r
F P
0 g
s
.4458 .27863 m .4417 .27127 L .53489 .26227 L p .625 .813 .972 r
F P
0 g
s
.5344 .26754 m .53489 .26227 L .62703 .26986 L p .474 .802 1 r
F P
0 g
s
.63227 .26744 m .62703 .26986 L .53489 .26227 L p .445 .787 .998 r
F P
0 g
s
.53539 .25714 m .53489 .26227 L .4417 .27127 L p .605 .806 .977 r
F P
0 g
s
.4417 .27127 m .43754 .26392 L .53539 .25714 L p .605 .806 .977 r
F P
0 g
s
.53489 .26227 m .53539 .25714 L .63227 .26744 L p .445 .787 .998 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00001?nJc_X5o`0000KoLLWo2ol0000Vooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0;oooool001;ooooo1_l00005ooooo`03o`000?oooooooooo00Go
oooo0_l00004ooooo`03o`000?oooooooooo07Wooooo2_l0000=oi[>nPOo00001OnOd?P00ol0003o
NLgoogW=o`03ogW=o`?o00002OmabOl;o`0001_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0_ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0M?ooool4o`0000?oYl3[00?o0000oi[>n_nJc_X02_nJc_X3o`0000coWm3h
1Ol0000@ogW=o`Wo00000omabOl7o`0001Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0^ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0L?ooool3o`0000KoYl3[0ol00003oi[>nP03o`000?nOd?SoWm3h00goWm3h1ol0
0004ojK@mP03o`000?n7dOooQm7o00GoQm7o2Ol0000:ogW=o`Go00001?liZo@3o`00017ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4o`0000KoYl3[0ol00002
oj_1jP03o`000?nOd?SoWm3h00_oWm3h1_l00007ojK@mPGo00005_n7dOl7o`0000Co@[3f1OliZo@3
o`0000kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool4o`00
00OoYl3[0ol00006oj_1jP03o`000?nOd?SoWm3h00GoWm3h0ol00008ojK@mPOo00001?n/co800ol0
003oV=;loiSBo00<oiSBo0ko00000omI_?`5od:`mP03o`000?liZoCo>J_d00;o>J_d0ol0000;oooo
o`03o`000?oooooooooo03?ooooo0_l0000^ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o
00002_ooool00ol0003oooooooooo`1Qooooo`Co00002?nW`>/3o`0000SoZl7Z0_l00002oio@n003
o`000?nVd?KoY]3f00OoY]3f1_l00008ojc?lPCo00006_nHd_`01?l0003oN<OoogS7oomhaol5oeVl
o0Go@[3f00Co0000ocV[m?liZoCo>J_d1?l00008ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0;?ooool002Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Moooo
o`?o00002?nW`>/4o`0000SoZl7Z0ol000000on_`^So0000ojK@mP06ojK@mPCo00002_n/co85o`00
00?o//g^00?o0000ojK@m_nVd?H02onVd?H=o`0000SoN<Oo00?o0000oeVlo?mI_?`00_mI_?`01?l0
003o@[3fod:`m_m2/?H2o`0000?o>J_d0ol00005ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0:oooool002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hoooo
o`Co00002?nW`>/3o`0000WoZl7Z0ol00004ojo2j0;o000000?oY]3fo`000?l000002on/co86o`00
00Oo//g^00?o0000ojK@m_nVd?H05onVd?H01Ol0003oU/cjoiK<n_nFc?[o000000WoN<Oo0_l00003
oeVlo005o`000?m2/?Ko@[3fod:`m_l000000oliZo@3o`0000;ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05Cooooo0ol0000:ojO0j`;o00002On[`NX3o`0000Co[l;X0ol000000onb`nOo0000ojc?lP0:
ojc?lP?o00002onbcNh3o`0000KoY]3f4ol00009oiK<nP?o00001omhaol00ol0003oFKcloeVlo002
o`0000;o@[3f0_l00002ocV[m0?o0000=oooool00ol0003oooooooooo`0Zooooo`009?ooool2o`00
00kooooo00?o0000ooooooooool0DOooool2o`0000;oXjkO00?o0000ojO0jonW`>/01OnW`>/2o`00
00WoZl7Z0ol00004ojo2j0?o00001Onb`nL00ol0003o[<obojc?lP04ojc?lP;o00002onbcNh5o`00
00;o]/WX00?o0000ok7;kOnabnd05_nabnd01Ol0003oZl[`oj_:l?n[b_3o000000[oU/cj1Ol00004
ogS7o`;o000000GoFKclo`000?l0003o0000od:`mP06o`0003Gooooo00?o0000ooooooooool0:Ooo
ool002?ooooo0_l0000@ooooo`03o`000?oooooooooo04kooooo0_l00005oj>^g`03o`000?nW`>_o
Yl3[00;oYl3[00?o0000oj_1j_n[`NX01on[`NX3o`0000Go[l;X0_l00008ok;3i`;o000000?o[<ob
o`000?nbcNh02_nbcNh5o`0000Oo]/WX00?o0000ok7;kOnabnd05Onabnd00ol0003oZl[`oj_:l008
oj_:l0Co00001_nFc?X5o`0000?oN<Oo3?l0000cooooo`03o`000?oooooooooo02Sooooo000Toooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Boooool2o`0000OoXjkO0ol00009oj_1
jP?o00001On_`^P3o`0000Oo//?W0ol000000onea>Go0000ok;=kP07ok;=kPGo00002_nfbNP3o`00
00?o/L_]5Ol0000?oj_:l0Ko00001?nFc?X3o`0000?oHK?k0_lkXO@01?l0003o8Y7/ob:Ak?lRTN`3
oaV<j@;o0000<?ooool2o`0002[ooooo000Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool2o`0000OoXjkO0_l00002ojJ_gP03o`000?n[`N[oZl7Z00CoZl7Z0ol00006ojo2
j0;o00001onb`nL3o`0000Go]LCU00?o0000ok;=k_nbcNh00_nbcNh3o`0000[o]/WX1Ol00002okS4
i003o`000?nha>?o^<CS01Go^<CS00Co0000okW4honia>?o^LCS1Ol0000=oj_:l0Co00000on7`?X5
of6cn`03o`000?lkXOCo>j7d00?o8Y7/0olIS>T2o`00033ooooo00?o0000ooooooooool09oooool0
02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001onS[]l2o`00
00GoYZoN00Co0000oj_1j_n[`N[oZl7Z0_l00006ojo2j0?o00001_nb`nL3o`0000Oo]LCU0_l00000
0onbcNko0000okK9j009okK9j0Go00001onha>@00ol0003o^<CSokS4h`0DokS4h`03o`000?nia>?o
^LCS00Oo^LCS1Ol00009oj_:l003o`000?nUaO3oYLG`00GoQl3j00Go0000of6cnol0003o0000of6c
n`03oc^Qm0?o8Y7/0olIS>T00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Kooooo000S
ooooo`;o00005?ooool00ol0003oooooooooo`11ooooo`?o00001onS[]l2o`0000OoYZoN0ol00007
ojo2j0;o00001_nb`nL3o`0000Oo]LCU0ol000000onga>Co0000okK9j007okK9j0Co00003?nha>@0
0ol0003o^<CSokS4h`0DokS4h`03o`000?nia>?o^LCS00co^LCS1Ol00003oj_:l003o`000?nUaO3o
YLG`00?oYLG`00?o0000ohO0n_l000001?l00003of6cn`03o`000?lkXOCo>j7d00;o8Y7/00?o0000
oaV<jOlIS>T00_l0000^ooooo`03o`000?oooooooooo02Kooooo000Sooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0?_ooool2o`0000SoXjkO0_l00007ojJ_gP;o000000?oZ[;No`00
0?n_`^P01On_`^P00ol0003o//?Wok;3i`05ok;3i`;o00002?nea>D2o`0000Go]lCT00?o0000okK9
j?nfbNP00_nfbNP2o`0000oo^<CT0ol00002okS4haCo00005?nia><3o`0000GoYLG`1Ol00003ohO0
nP;o00000omQ/o/00ol0003o>j7doc^Qm002ob:Ak003o`000?lIS>Wo6HcY00;o0000;Oooool00ol0
003oooooooooo`0Uooooo`008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03_o
oooo0_l00008oj>^g`;o00002?nV[mh00ol0003oZ[;NojZbgP02ojZbgP05o`000?n_`^So[l;Xojo2
j?l000001_nb`nL3o`0000Oo]LCU0ol00006okO4i0;o000000?o]/WXokS4i?nha>@03Onha>@5o`00
00;o^KoO00?o0000okbmfonl_M/04onl_M/01?l0003o`;kHol2nf?o0_]P7o`0000_o^LCS00?o0000
okW4honia><01?l00005ojG5l0;o00000_n7`?X01?l0003oQl3jo`000?l00002of6cn`03o`000?lk
XOCo>j7d00;o8Y7/00?o0000oaV<jOlIS>T00_l0000[ooooo`03o`000?oooooooooo02Gooooo000S
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool2o`0000SoXjkO0_l00008
ojJ_gP;o00001OnZ/]h3o`0000Ko//?W0_l00007okG4i@?o00001_nga>@3o`000003okS5i?l0003o
^<CT00_o^<CT1?l00007okVog`03o`000?nl_M_o_;gK01?o_;gK00?o0000ol2nf?o0_]P02?o0_]P7
o`0000?o^LCS00?o0000okW4hol000000_l000000onia>?o0000o`000007ojG5l0;o000000CoQl3j
o`000?n7`?[oQl3j0_l00002of6cn`05o`000?lkXOCo0000o`000?lRTN`00_l000000olIS>Wo0000
o`00000Yooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd02?ooool002;ooooo0ol0000Hooooo`03o`000?oooooooooo03Go
oooo0_l00008oj>^g`;o00002?nV[mh2o`0000GoZ[;N0_l00003ojjegP05o`000?nb`nOo//?Wok;3
iol000002?nea>D2o`0000Oo]lCT0_l00005okS5i003o`000?nha>Co^<CT00Go^<CT1?l0000;okVo
g`03o`000?nl_M_o_;gK01;o_;gK00?o0000ol2nf?o0_]P04?o0_]P5o`0000Ko^LCS0_l00007ojG5
l0;o00001?n7`?X2o`0000;oHK?k00Go0000oc^Qm?l0003o0000ob:Ak002o`000003oaV<jOl0003o
000002Wooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Oooooo000Rooooo`03o`000?oooooooooo01Wooooo0_l0000c
ooooo`;o00002?nS[]l2o`0000SoYZoN0_l00006ojZbgP03o`000?n^]Mko[[GN00?o[[GN0_l00008
okG4i@?o00001_nga>@3o`0000Oo^<GT00?o0000okS4i?nha>@00_nha>@3o`0000co^KoO1?l00002
okbmfa?o00004Oo0_]P4o`000003olG1eol0003o^LCS00Oo^LCS0ol00006ojG5l0;o00001?n7`?X2
o`0000;oHK?k1?l000001?lRTNco0000oaV<jOlIS>T2o`0002Oooooo00?o0000ooooooooool01Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01_ooool002;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`?o00001onS[]l2o`0000SoYZoN0_l0
0006ojZbgP;o00001On^]Mh01?l0003o/[[Ook:jgol00006okG4i@03o`000?nga>Co]lCT00Go]lCT
0_l0000:okS5i0?o00003?ni_ml5o`0000?o^;_K00?o0000okfge?nm]m@04_nm]m@00ol0003oa;S?
olBhc`05o`0000Oo`;kH0ol00002ol2nf003o`000?o5`MOoaL7G00;oaL7G0_l00008okW4h`;o0000
1OnUaO03o`0000;oQl3j3?l00002oaV<j@03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0/ooooo`05o`000?nFWMWoUYgI
oiJMfOl000001?nS[]l2o`0000WoYZoN00?o0000ojZbg_nZ/]h01?nZ/]h2o`0000Go[[GN0_l00004
ok:jg`05o`000?nea>Go]LCUokG4iOl000001onga>@2o`0000Wo^<GT0ol000000onhaNCo0000okVo
g`07okVog`Go00002?nh^m/00ol0003o_KODokfge00Aokfge003o`000?o4^<ooa;S?00Koa;S?1ol0
0004ol2nf003o`000?o5`MOoaL7G00GoaL7G0_l00008okW4h`;o00001?nUaO001?l0003oYLG`o`00
0?l00003oh:cm006o`000?mMX_CoGJ;doefRm?l0003o?8o_1Ol000000olIS>Wo0000o`00000Voooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_oo
ool00ol0003oUYgIoiJMf@03oiJMf@04o`000?nS[]ooXjkOo`0000WoYZoN0_l00006ojZbgP03o`00
0?n^]Mko[[GN00Co[[GN00?o0000ok:jgonb^]l01?nb^]l2o`0000Oo]lCT0ol00008okS5i0?o0000
1OnhaN@01?l0003o^KoOokVogoni_ml4o`0000go^;_K00?o0000okfge?nm]m@04Onm]m@00ol0003o
a;S?olBhc`07olBhc`So00000_o0_]P00ol0003oaL7GolG1e`07olG1e`;o00002?nia><2o`000003
ojG5l?l0003o000000?oX[o^1?n2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_00?o9h;Yo`00
0?l000001?l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00[ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0X
ooooo`03o`000?nFWMWoUYgI00CoUYgI0_l00009ojJ_gP;o00001_nZ/]h2o`0000Go[[GN0_l00006
ok:jg`03o`000?ne_n7o000000Go]lCT0_l00009okS5i0;o00001onhaN@4o`0001;o^;_K00?o0000
okfge?nm]m@04Onm]m@00ol0003oa;S?olBhc`04olBhc`?o00002?o4^<l2o`0000coaL7G0_l00008
okW4h`04o`000?nR_nkoX[o^o`0000?oX[o^1?n2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_
0olWP^T2ob1mi`;o00008_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00[ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`03ooooo`;o00008Oooool00ol0003oooooooooo`0Vooooo`03o`000?nFWMWoUYgI00Co
UYgI00Co0000oiVOf?nIWmSo00001_nV[mh2o`0000KoZ[;N0_l00006ojjegP03o`000?nb^]oo/[[O
00Co/[[O0_l00003okFoh@05o`000?nga>Co]lCTokO4i?l000002?nhaN@3o`0000Ko^<GT0ol00000
0onfa>Go0000okRkf`0@okRkf`Co000000?o_KODo`000?l000004?l00004olBhc`?o00003?o4^<l0
1?l0003obkg=o`000?l0000;olG1e`;o00001?nia><01?l0003o^LGSokW5honiaN<2oj:okP05o`00
0?nR_nkoX[o^oj:ok_l000000on2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_0olWP^T3ob1m
i`03o`000?oooooooooo02;ooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Wooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Tooooo`03
o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP00_nIWmP00ol0003oYZoNojJ_gP02ojJ_gP03
o`000?nZ/]koZ[;N00GoZ[;N00?o0000ojjeg_n^]Mh01?n^]Mh2o`0000Ko/[[O00?o0000okFohOne
_n400one_n42o`0000Wo^<GT0_l00007okS5i0;o00001?nfa>D00ol0003o^;_KokRkf`08okRkf`Oo
00000onf]]T00ol0003o_;7?okbac`0@okbac`03o`000?o5/lSo000000Go00002oo4^<l00ol0003o
bkg=ol^mc@02ol^mc@?o00002_o5`ML2o`000003okW4hol0003o^LGS00Co^LGS00?o0000oj:ok_l0
00000onR_nh01Ol0003oP[?doh:cm?n2/oCo000000?oGJ;d00Co0000ocb?kollSnoo?8o_0olWP^T3
ob1mi`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP01?nIWmP0
1?l0003oYZoNojJ_g_l00006ojZbgP;o00001_n^]Mh00ol0003o/[[Ook:jg`04ok:jg`;o00001One
_n401?l0003o^<GTokS5i?l00005okS5i0?o00001_nhaN@3o`0000Oo]/CU00Co0000okRkfonh^m_o
^;_K1_l0000:okJff@03o`000?nl/Loo_;7?00oo_;7?0ol00006olFcb0Co00001oo4^<l00ol0003o
bkg=ol^mc@05ol^mc@;o00002_o5`ML00ol0003o^LGSokW5h`05okW5h`;o00001?nR_nh01Ol0003o
P[?doh:cm?n2/oCo000000?oGJ;d00Go0000ocb?kollSnoo?8o_o`000002obN2j@?o87gW00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo023ooooo00?o0000oiJMfOnFWMT01?nFWMT00ol0003oVIoHoiVOf005oiVOf0;o00001_nZ/]h2
o`0000Ko[[GN0_l00006ok:jg`03o`000?ne_n7o]KoQ00Co]KoQ00?o0000okS5i?nhaN@00_nhaN@0
0ol0003o^<GTokS5i002o`0000Oo^<GT0_l00009okK4i@Co00004Onf]]T00ol0003o_;7?okbac`0=
okbac`;o000000?o_;7?o`000?o5/lP02_o5/lP5o`0000;oa;S?00?o0000ol^mcOo;_Ld01oo;_Ld2
o`0000SoaL7G00?o0000olW7f?niaN<01_niaN<2o`0000CoX[o^00Go0000oh:cm?n2/oCoP[?do`00
0003oefRm005o`000?llSnoo?8o_ocb?kol000000_lWP^T01?l0003o87gWob1miol0000Sooooo`03
o`000?oooooooooo01gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo0_l0000Uooooo`03o`000?oooooooooo01kooooo00?o0000oiJMfOnFWMT01?nFWMT00ol0003o
VIoHoiVOf005oiVOf004o`000?nNXmSoWZ?Ho`0000CoZ[;N00?o0000ojjeg_n^]Mh01On^]Mh00ol0
003o/[[Ook:jg`04ok:jg`;o00001One_n42o`0000Go^<GT0_l00007okS5i0?o00002?nfa>D3o`00
0003ok?3i_l0003o][KI01;o][KI00?o0000okbaconl/Ll02_nl/Ll3o`0000;o_;7?00?o0000olFc
b?o5/lP03oo5/lP2o`0000cobkg=0ol00004olG1e`05o`000?o9amSobLOHolW7f?l000001_niaN<2
o`0000CoX[o^00Go0000oh:cm?n2/oCoP[?do`000003oefRm005o`000?llSnoo?8o_ocb?kol00000
0_lWP^T01?l0003o87gWob1miol0000Rooooo`03o`000?oooooooooo01gooooo000Pooooo`;o0000
9oooool00ol0003oooooooooo`0Looooo`03o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP0
1OnIWmP00ol0003oWZ?HoijSf002oijSf004o`000?nZ/]koZ[;No`0000Ko[[GN0_l00005ok:jg`;o
00001_ne_n400ol0003o^<GTokS5i004okS5i003o`000?njbnSo000000Go^<GT0_l00009okK4i@;o
00001?nc`nH00ol0003o][KIokJff@0<okJff@Ko000000?o_;7?o`000?l000002Ol00005okbac`03
o`000?o5/lSoaK?8013oaK?800Co0000oljja_l0003o00003?o;_Ld2o`000003olG1eol0003obLOH
00CobLOH00?o0000okW5honiaN<01?niaN<00ol0003oX[o^oj:okP03oj:okP05o`000?n2/oCoP[?d
oh:cm?l000000omMX_@01Ol0003o?8o_ocb?kollSnoo000000;o9h;Y00Co0000ob1miolPONOo0000
8Oooool2o`0001kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06_oo
ool00ol0003oUYgIoiJMf@04oiJMf@03o`000?nIWmSoVIoH00GoVIoH00?o0000oijSf?nNXmP01?nN
XmP2o`0000Ko[[GN00?o0000ok:jgonb^]l01?nb^]l00ol0003o]KoQokFoh@04okFoh@;o00001Onh
aN@2o`0000?o^/_X00Go0000okS5i?nhaNCo^<GTo`000008okK4i@?o00001onc`nH00ol0003o][KI
okJff@02okJff@Wo00001Onb/]P00ol0003o^jc;ok^/b`04ok^/b`co00004Oo5/lP00ol0003oc[[6
oljjaP02oljjaP;o00003?o;_Ld00ol0003obLOHolW7f005olW7f003o`000?niaN?o^LGS00Co^LGS
00?o0000oj:ok_nR_nh00onR_nh01Ol0003oP[?doh:cm?n2/oCo000000?oGJ;d00Go0000ocb?koll
Snoo?8o_o`000002obN2j@04o`000?lPONOo87gWo`0002;ooooo00?o0000ooooooooool06oooool0
023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?nFWMWoUYgI
00CoUYgI00?o0000oiVOf?nIWmP01OnIWmP00ol0003oWZ?HoijSf004oijSf004o`000?nTZM[oY:WJ
o`0000Co[[GN00?o0000ok:jgonb^]l00onb^]l2o`0000Ko]KoQ00?o0000okS5i?nhaN@01?nhaN@0
0ol0003o^/_Xok[;j003ok[;j0;o00002?nfa>D3o`0000So/l?V1ol0000>ok:bf004o`000?nk[<_o
^jc;ok^/b`?o00002onk[</00ol0003oaJo4olF_a004o`0000_oaK?800?o0000oljja_o>^/H01?o>
^/H2o`0000[obkg=00?o0000om;6c_o9amP01_o9amP00ol0003o^LGSokW5h`04okW5h`03o`000?nR
_nkoX[o^00?oX[o^00Go0000oh:cm?n2/oCoP[?do`000003oefRm005o`000?llSnoo?8o_ocb?kol0
00000_lWP^T01?l0003o87gWob1miol0000Qooooo`03o`000?oooooooooo01_ooooo000Pooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003oUYgIoiJMf@04oiJMf@03
o`000?nIWmSoVIoH00GoVIoH00?o0000oijSf?nNXmP01?nNXmP00ol0003oY:WJojBYfP02ojBYfP03
o`000?n^]Mko[[GN00Ko/[[O00?o0000okFohOne_n401One_n400ol0003o^<GTokS5i003okS5i0;o
00001OnjbnP01?l0003o^];/ok[Bk?l00005okK4i@;o00002?nc`nH3o`0000;o[/;X00?o0000ok:b
f?nb/]P03onb/]P00ol0003o^jc;o`000002o`0000go^jc;00?o0000olF_a?o5[l@01Oo5[l@4o`00
00KoaK?800?o0000oljja_o>^/H01oo>^/H2o`0000Oobkg=00Go0000om;6c_oBa/kod/K>o`000006
olW7f003o`000?niaN?o^LGS00Co^LGS00?o0000oj:ok_nR_nh00onR_nh01Ol0003oP[?doh:cm?n2
/oCo000000?oGJ;d00Go0000ocb?kollSnoo?8o_o`000002obN2j@04o`000?lPONOo87gWo`00027o
oooo00?o0000ooooooooool06_ooool0023ooooo0_l0000[ooooo`03o`000?oooooooooo01Cooooo
00?o0000oiJMfOnFWMT01?nFWMT00ol0003oVIoHoiVOf005oiVOf003o`000?nNXmSoWZ?H00CoWZ?H
00?o0000ojBYf_nTZMX01?nTZMX2o`0000Go/[[O00?o0000okFohOne_n401?ne_n42o`0000Go^<GT
00?o0000ok[;j?njbnP00onjbnP2o`0000Co^];/00?o0000okK4iOnfa>D00_l00006ok?3iPCo0000
1_n^`^P00ol0003o/[;Hok:bf00=ok:bf0?o00004?nk[</00ol0003oaJo4olF_a009olF_a0Co0000
0_o5/lP00ol0003oc[[6oljjaP09oljjaP;o00001?o;_Ld00ol0003od/K>om;6cP03om;6cP03o`00
0?o9amSobLOH00CobLOH00?o0000okW5honiaN<00oniaN<2o`0000?oX[o^2ol00003ocb?k`04o`00
0?lWP^Wo9h;Yo`0000;o87gW00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`00
8?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo00?o0000oiJMfOnFWMT0
1?nFWMT00ol0003oVIoHoiVOf004oiVOf0;o00001_nNXmP00ol0003oY:WJojBYfP04ojBYfP03o`00
0?nZ/MgoZ[7M00;o00000_nb^]l7okFoh@03o`000?nhaNCo^<GT00?o^<GT0_l00004ok[;j0;o0000
1_njd^`2o`0000Ko/l?V0ol0000:ojk2j003o`000?nb/]So/[;H00Ko/[;H2Ol000001?nk[<_o0000
o`000?l0000=ok^/b`03o`000?o5[lCoaJo400goaJo40ol0000=oljjaP;o000000?obkg=o`000?oB
a/h01_oBa/h00ol0003obLOHolW7f004olW7f003o`000?niaN?o^LGS00?o^LGS1?l00002oj:ijPCo
QJW/1?mYV>/6o`0000;o9h;Y00Co0000ob1miolPONOo00008?ooool00ol0003oooooooooo`0Ioooo
o`008?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o0000oiJMfOnF
WMT01?nFWMT00ol0003oVIoHoiVOf004oiVOf003o`000?nNXmSoWZ?H00GoWZ?H00?o0000ojBYf_nT
ZMX01?nTZMX00ol0003oZ[7MojZag@03ojZag@;o00001_ne_n400ol0003o^<GTokS5i003okS5i003
o`000?njbnSo^/_X00?o^/_X00?o0000ok[Bk?njd^`01?njd^`2o`0000;o]mOa00Co0000ok?3i_nc
`nKo/l?V0_l0000<ojk2j0[o000000Co[ZkGo`000?l0003o00001?n^[]L00ol0003o^:S9okRXb@02
okRXb@Wo00000onk[</00ol0003oaJo4olF_a00?olF_a004o`000?o@]l;o0000o`0000goc[[60_l0
0008om;6cP03o`000?o9amSobLOH00CobLOH00Oo0000okW5honiaN?o^LGSo`000?niaN?o000000Go
X[WZ1?n5ZN`4ofVHj`CoDXWW0ol000001OlWP^Wo0000ob1miolPONOo000001oooooo0_l0000Joooo
o`008?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo0_l00005oiJMf@03
o`000?nIWmSoVIoH00CoVIoH00?o0000oijSf?nNXmP01OnNXmP00ol0003oY:WJojBYfP04ojBYfP03
o`000?nZ/MgoZ[7M00?oZ[7M00Co0000ok6jh?na^^3o00001?ne_n45okS5i0;o00001?njbnP2o`00
00Ko^];/00?o0000okOGlOngeo400_ngeo43o`0000_o[/;X1?l00002ojJok003o`000?n^[]Oo[ZkG
00?o[ZkG0ol00007ojj^e`03o`000?nhZ<Wo^:S900_o^:S91?l0000@olF_a003o`000?o@]l;od;O2
00;od;O20_l0000;oljjaP03o`000?oHaLOo000000Sod/K>00?o0000olW7f?o9amP01?o9amP00ol0
003o^LGSo`000003okW5h`03o`000?nR^N[oX[WZ00;oX[WZ00Go0000ohFYk?n5ZNcoQJW/o`000004
ofVHj`CoDXWW0_m3O^@3o`0000;o87gW00?o0000ooooooooool07Oooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo0_n0S]P01Ol0
003oUYgIoiJMfOnFWMWo000000KoVIoH00?o0000oijSf?nNXmP01OnNXmP00ol0003oY:WJojBYfP04
ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6jh?na^^000_na^^000ol0003o]KoQokFoh@05
okS5i003o`000?njbnSo^/_X00?o^/_X00?o0000ok[Bk?njd^`01?njd^`2o`0000?o]mOa0_l00002
ok7KmP03o`000?n^`^So[/;X00Go[/;X1?l00006ojJok003o`000?n^[]Oo[ZkG00?o00002_n^[]L0
0ol0003o^:S9okRXb@0>okRXb@03o`000?o3[<;o`jc200?o00002oo5[l@00ol0003od;O2om2g`P04
om2g`P;o00002?o>^/H01Ol0003of<G7omS5aooHaLOo000000Sod/K>00?o0000olW7f?o9amP00oo9
amP2o`0000Co^LGS00?o0000oj:ij_nR^NX00_nR^NX00ol0003oQJW/ohFYk002ohFYk0CoJIS[00?o
0000oe:9iomBRNL00_mBRNL4od=ni0;o000000?o87gWo`000?ooool07_ooool00ol0003ooooooooo
o`0Gooooo`007oooool2o`00037ooooo00?o0000ooooooooool02oooool01Ol0003oP8kHoh2>f?n0
S]So000000;oUYgI1_nIWmP00ol0003oWZ?HoijSf005oijSf003o`000?nTZM[oY:WJ00CoY:WJ00?o
0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh0;o00001?nhaN@00ol0003o^/_Xok[;
j002ok[;j0;o00001Onjd^`2o`0000Co]mOa00?o0000ok7Km_nafoH00onafoH01?l0003o[/;Xojk2
j?n^`^P3o`0000[oY[o/0ol0000=ojj^e`03o`000?nhZ<Wo^:S900ko^:S900?o0000ol>/`_o3[<80
0oo3[<83o`0000OoaJo400?o0000om2g`_o@]l801oo@]l82o`0000Koc[[600?o0000omS5aooHaLL0
0_oHaLL00ol0003od/K>om;6cP06om;6cP07o`000?o9amSobLOHolW7f?l0003oc<gKo`000005okW5
h`03o`000?nR^N[oX[WZ00;oX[WZ00Go0000ohFYk?n5ZNcoQJW/o`000004ofVHj`CoDXWW00Co0000
od=ni?m3O^Co@gkT0_lmNn<3o`0001oooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`03o`000?n0S]SoP8kH00;oP8kH0_l00005
oiVOf003o`000?nNXmSoWZ?H00GoWZ?H00?o0000ojBYf_nTZMX01?nTZMX00ol0003oZ[7MojZag@03
ojZag@03o`000?na^^3o/K[P00Co/K[P00Co0000okS5i?nhaNCo00000_nhaN@5ok[;j003o`000?nj
d^co^];/00Co^];/00?o0000okOGlOngeo400_ngeo42o`0000Ko/M_f0ol0000;ojJok0?o000000?o
Y[o/o`000?n^[]L03On^[]L00ol0003o^:S9okRXb@0>okRXb@03o`000?o3[<;o`jc200Ko`jc20ol0
0004olF_a003o`000?o@]l;od;O200Wod;O20_l00003oljjaP03o`000?oHaLOof<G700Cof<G700?o
0000om;6c_oBa/h01_oBa/h00ol0003obLOHo`000003olc=f`03o`000?niaN?o^LGS00;o^LGS0_l0
0003oj:ijP03o`000?n5ZNcoQJW/00;oQJW/00Go0000ofVHjomYV>_oJIS[o`000003oe:9i`03o`00
0?m3O^Co@gkT00;o@gkT1?lmNn<00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo
000Oooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003oP8kHoh2>
f003oh2>f0;oQ93G00Go0000oiVOf?nIWmSoVIoHo`000007oijSf003o`000?nTZM[oY:WJ00CoY:WJ
00?o0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT
0ol00003ok[;j0Ko^];/0_l00003okOGl@;o00001_nafoH2o`000003ojKMnol0003oY[o/00WoY[o/
5_l000000onhZ<Wo0000o`00000<okRXb@03o`000?o3[<;o`jc200[o`jc20ol000000oo5[lCo0000
om2g`P0<om2g`P;o000000?oc[[6o`000?oHaLL01_oHaLL00ol0003od/K>om;6cP05om;6cP;o0000
1?o<cM/00ol0003o^LGSokW5h`03okW5h`;o00000onR^NX01Ol0003oQJW/ohFYk?n5ZNco000000?o
JIS[00?o0000oe:9iomBRNL00_mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Kooooo00?o0000oh2>f?n0S]P00on0S]P01Ol0003oQ93GohB@eon4T=Oo0000
00;oVIoH1onNXmP00ol0003oY:WJojBYfP04ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6j
h?na^^001?na^^000ol0003o^<GTokS5i002okS5i004o`000?nndNWo_]7YokkAj@?o00001Onjd^`0
1?l0003o]mOaokOGlOngeo42o`0000Ko/M_f0_l00004ojKMn`03o`000?nV_ncoY[o/00;oY[o/1ol0
0004oi^lk`03o`000?nWZMWoYjWI00coYjWI00Co0000ok>Ub_ncYL[o/jG:1Ol00007okRXb@03o`00
0?o3[<;o`jc200go`jc20_l0000?om2g`P03o`000?oHaLOof<G700Oof<G700?o0000om;6c_oBa/h0
0ooBa/h00ol0003of=;Bo`000005olc=f`03o`000?niaN?o^LGS00;o^LGS0_l00003oj:ijP03o`00
0?n5ZNcoQJW/00;oQJW/00Go0000ofVHjomYV>_oJIS[o`000003oe:9i`05o`000?m3O^Co@gkTod=n
i?l000001?lmNn<00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eooooo`;o
00001_ooool00ol0003oP8kHoh2>f003oh2>f003o`000?n4T=OoQ93G00;oQ93G0_l00006oijSf003
o`000?nTZM[oY:WJ00CoY:WJ00?o0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003
o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01?l0003o`]g]o`000?l00002ok[B
k0Co]mOa00?o0000ok7Km_nafoH00onafoH3o`0000KoY]gk1ol00009oi^lk`03o`000?nWZMWoYjWI
00coYjWI00?o0000ok>Ub_ncYLX01_ncYLX5o`0000;o^:S900?o0000ol>/`_o3[<803Oo3[<801?l0
003od;Boo`000?l0000=om2g`P;o00002OoHaLL01Ol0003od/K>om;6c_oBa/ko000000?of=;B00?o
0000olc=foo<cM/00_o<cM/00ol0003o^LGSokW5h`03okW5h`;o00000_nR^NX00ol0003oQJW/ohFY
k002ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o
?G_S00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00;ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93G
ohB@e`03ohB@e`;oS9KH0_l00003oijSf003o`000?nTZM[oY:WJ00CoY:WJ00?o0000ojZagOnZ/Md0
0onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT0
0onndNT01?l0003o`]g]ol;MkOo2gNd4o`0000;o]mOa00?o0000ok7Km_nafoH00_nafoH2o`0000Ko
Y]gk0ol000001?nDf_ko0000o`000?l0000=oi^lk`03o`000?nWZMWoYjWI00_oYjWI00?o0000ok>U
b_ncYLX02oncYLX3o`0000ko`jc200?o0000om2d_oo@];l00_o@];l2o`0000[od;O200Co0000om_4
`_oKa<;o00002OoHaLL00ol0003od/K>o`000004omSBdP03o`000?o<cM_oc<gK00?oc<gK00?o0000
okW5honiaN<00_niaN<00ol0003oX[WZo`000002oj:ijP05o`000?n5ZNcoQJW/ohFYk?l000001?mY
V>/01Ol0003oDXWWoe:9iomBRNOo000000?o@gkT00Go0000ocekholmNn?o?G_So`00000Pooooo`03
o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo03Sooooo00Go0000oooooooooooo
ooooo`000005oh2>f003o`000?n4T=OoQ93G00;oQ93G00?o0000ohbFf?n<U]P00_n<U]P00ol0003o
WZ?HoijSf006ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6jh?na^^001?na^^000ol0003o
^<GTokS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo`]g]o`000004ol;X
l0?o00000onafoH00ol0003oY]gkojKMn`03ojKMn`?o000000CoU=[no`000?l0003o00000_nDf_h0
0ol0003oVkc_oi^lk`05oi^lk`Oo000000CoYjWIo`000?l0003o00002OnWZMT00ol0003o/jG:ok>U
bP0=ok>UbP03o`000?o1ZL;o`JW200?o00002Oo3[<800ol0003od;Boom2d_`04om2d_`?o00001_o@
]l800ol0003oflC2om_4`P02om_4`P03o`000?oHaLOof<G700Oof<G700?o0000omSBd_oHd]800ooH
d]800ol0003oc<gKolc=f`03olc=f`03o`000?niaN?o^LGS00?o^LGS00Go0000oj:ij_l0003oX[WZ
o`000004ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mBRNL01Ol0003o@gkTod=ni?m3O^Co0000
00?o?G_S00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000005oh2>
f003o`000?n4T=OoQ93G00?oQ93G00?o0000ohbFf?n<U]P00on<U]P2o`0000GoY:WJ00?o0000ojZa
gOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkA
jOnndNT00onndNT01Ol0003o`]g]ol;MkOo2gNgo000000Co`^S`00Co0000okg`l_nml?;o_O3b1?l0
0002ojKMn`?o000000CoU=[no`000?l0003o00000onDf_h:o`0000KoS;Kb00?o0000oijUfonNYM/0
0_nNYM/7o`0000;oYjWI00?o0000ok>Ub_ncYLX03?ncYLX00ol0003o`JW2ol6Y`P04ol6Y`PCo0000
1Oo3[<800ol0003od;Boom2d_`07om2d_`;o00001?o@]l800ol0003oflC2om_4`P03om_4`P03o`00
0?oHaLOof<G700Kof<G700?o0000omSBd_oHd]801?oHd]800ol0003oc<gKolc=f`03olc=f`03o`00
0?niaN?o^LGS00;o^LGS00?o0000oj:ij_l000000_nR^NX01Ol0003oQJW/ohFYk?n5ZNco000000Co
JIS[00Go0000oe:9iomBRNOoDXWWo`000003od=ni005o`000?lmNn?o?G_Socekhol000008?ooool0
0ol0003oooooooooo`0Booooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0>_ooool00ol0003oP8kHoh2>f004oh2>f003o`000?n4T=OoQ93G00;oQ93G00?o0000
ohbFf?n<U]P01?n<U]P2oiFNfP05o`000?nTZM[oY:WJojBYf_l000001OnZ/Md00ol0003o/K[Pok6j
h004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01Ol0003o`]g]ol;M
kOo2gNgo000000Co`^S`00Go0000okg`l_nml?;o_O3bo`000003ok;dl`Oo000000?oU=[no`000?l0
00000ol00004og_Ao`03o`000?n<]_;oS;Kb00WoS;Kb00?o0000oijUfonNYM/02OnNYM/3o`0000ko
/jG:00?o0000ol6Y`_o1ZL802?o1ZL83o`000003ol>/`_l0003od;Bo00_od;Bo0_l000000oo@]l;o
0000om_4`P06om_4`P03o`000?oHaLOof<G700Cof<G700?o0000on3Dbol000001OoHd]800ol0003o
c<gKolc=f`03olc=f`03o`000?niaN?o^LGS00?o^LGS00Go0000oj:ij_l0003oX[WZo`000004ohFY
k005o`000?mYV>_oJIS[ofVHjol000000omBRNL00ol0003o@gkTod=ni002od=ni005o`000?lmNn?o
?G_Socekhol000008?ooool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool00ooo
ool001?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03[ooooo00?o
0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`000?n<U]SoS9KH00?oS9KH00Go
0000oiFNf_nEW][oUIkJo`000002ojBYfPGoZ[7M00?o0000ok6jh?na^^001?na^^000ol0003o^<GT
okS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo`]g]o`000004ol;Xl005
o`000?nml?;o_O3bokg`l_l000000onbm?<00ol0003oWo7bo`000006o`0000GoNm7o1_l000000on<
]_;o0000o`000003o`0000GoS;Kb00?o0000oijUfonNYM/02_nNYM/00ol0003o[Z;;ojjRb`05o`00
00Oo/jG:00?o0000ol6Y`_o1ZL802oo1ZL83o`0000god;Bo0_l00008om_4`P03o`000?oHaLOof<G7
00;of<G700Co0000on3DbooPe<_o00001_oHd]800ol0003oc<gKolc=f`03olc=f`03o`000?niaN?o
^LGS00;o^LGS00?o0000oj:ij_nR^NX00_l00004ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mB
RNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000ooooooooool07Oooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05o`000?ooooooooooooooool00000
1Oooool3o`0003[ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`00
0?n<U]SoS9KH00CoS9KH00?o0000oiFNf_nEW]X00_nEW]X2o`0000CoZ[7M00?o0000ok6jh?na^^00
1?na^^000ol0003o^<GTokS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo
`]g]o`000004ol;Xl005o`000?nml?;o_O3bokg`l_l000000_nbm?<4o`000003oioal_l0003o0000
00?oPnO_1_l00006oe_0o003o`000?mg[?CoMjcd00?oMjcd1_l0000<oijUf`03o`000?n^X/_o[Z;;
00Go[Z;;1Ol000000oncYL[o0000ol6Y`P0>ol6Y`P04o`000?o>/koo0000o`0000_od;Bo00?o0000
omc3`?l000002?oKa<801Ol0003of<G7omS5aooHaLOo000000?oh=C;00?o0000omSBd_oHd]800ooH
d]800ol0003oc<gKolc=f`03olc=f`04o`000?niaN?o^LGSokW5h`go00000_mYV>/01Ol0003oDXWW
oe:9iomBRNOo000000?o@gkT00Go0000ocekholmNn?o?G_So`00000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo03[ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@
e`03o`000?n<U]SoS9KH00?oS9KH00?o0000oiFNf_nEW]X00onEW]X01?l0003oX:[Mo`000?l00002
ojZag@Ko/K[P00?o0000okS5i?nhaN@00_nhaN@00ol0003o_]7YokkAj@03okkAj@05o`000?o2gNgo
`]g]ol;MkOl000001?o2j?000ol0003o_O3bokg`lP02o`000004ok;dlol0003o0000o`0000;oWo7b
0_l00002oh?Wk`?o00000_mPeNT4o`000003oe_0o?l0003o000000;o00000_mK`?`00ol0003oMjcd
ogN/m007ogN/m003o`000?nAX=koTJ3N00Go00001OnNYM/00ol0003o[Z;;ojjRb`0:ojjRb`;o0000
3_o1ZL800ol0003oc[>ooljc_`02oljc_`03o`000?o@];ood;Bo00Ood;Bo00Go0000omc3`?oL`l3o
g<?0o`000008om_4`P03o`000?oHaLOo000000Coh=C;00?o0000omSBd_oHd]801?oHd]800ol0003o
c<gKolc=f`02olc=f`Co00000_nia^@3ojBfi@03o`000?n>YNCoSZGT00?oSZGT0_mkUN43o`0000Co
DXWW00Go0000od=ni?m3O^Co@gkTo`000003ocekh`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`004oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oP8kHoh2>f003oh2>f003o`000?n4T=OoQ93G
00?oQ93G00?o0000ohbFf?n<U]P01?n<U]P00ol0003oUIkJoiFNfP02oiFNfP03o`000?nPZ]goX:[M
00;oX:[M0_l00005ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01Ol0
003o`]g]ol;MkOo2gNgo000000Co`^S`00?o0000okg`l_nml?801Ol00003oioalP04o`000?n3inoo
PnO_oh?Wk`Ko00001Olg^^401?l0003o=JSbocFXl_leZ?84o`000003ogN/m?l0003o000000GoMjcd
00?o0000oi6Pg_nAX=h01OnAX=h4o`000003oijUfol0003o[Z;;00co[Z;;00?o0000okbW`ol00000
0_l0000:ol6Y`P03o`000?o>/kooc[>o00?oc[>o0_l00007om2d_`03o`000?oL`l3og<?000;og<?0
00?o0000om_4`_oKa<801_oKa<800ol0003oh=C;on3Db`04on3Db`03o`000?oHd];of=;B00?of=;B
00?o0000olc=foo<cM/00_l000000oo<dmoo0000okW6i003okW6i005o`000?nT]^GoY;KUojBfiOl0
00001?n>YN@5og^Eh@;o00000_mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000oooo
ooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`03o`000?n0S]SoP8kH
00CoP8kH00?o0000ohB@eon4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ
00?oUIkJ00?o0000oj2ZgOnPZ]d00_nPZ]d00ol0003o[;OQo`000002o`000003ok6jh?l0003o^<GT
00?o^<GT00?o0000okkAjOnndNT00onndNT01Ol0003o`]g]ol;MkOo2gNgo000000Co`^S`00?o0000
okg`l_l000000_l00002ok;dl`03oioal_l0003o000000Oo00001?mchN@8o`0000;o=JSb0_l00002
ocFXlP03o`000?mKW_?oFikc00Go000000?oMjcdo`000?nAX=h02OnAX=h2o`0000go[Z;;00?o0000
okbW`onlYl<00_nlYl<3o`0000Ko`JW200?o0000oljc_oo>/kl01_o>/kl2o`0000Cod;Bo00?o0000
omc3`?oL`l001?oL`l000ol0003oflC2om_4`P05om_4`P03o`000?oPe<_oh=C;00Goh=C;00?o0000
omSBd_oHd]800_oHd]800ol0003oc<gKo`000003olcCg`03o`000?nia^Co^LKT00;o^LKT00Co0000
ojBfiOnT]^GoY;KU0_l00003ohjUi003o`000?mkUN7oNiGQ00;oNiGQ0_m/RMh3o`0000Co@gkT00Co
0000ocekholmNn?o00008_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
000Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Wooooo00?o0000oh2>f?n0S]P0
0on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`000?n<U]SoS9KH00CoS9KH00?o0000oiFNf_nEW]X0
0_nEW]X00ol0003oX:[Moj2Zg@02oj2Zg@03o`000?n/]n7o[;OQ00?o[;OQ0ol00003okS5i0Go_]7Y
00Go0000ol;MkOo2gNgo`]g]o`000004ol;Xl0?o000000?o_O3bo`000?l000000ol00002ol;mhP03
o`000?n`n^;o000000;oUo;S00?o0000og?Qi?l000004ol00006oe^Nl`;o00002onAX=h00ol0003o
YIk?ojFNc`03o`0000So[Z;;00?o0000okbW`onlYl<01OnlYl<2o`0000Co`JW200?o0000oljc_oo>
/kl02?o>/kl01Ol0003od;Boom2d_oo@];oo000000Oog<?000?o0000om_4`_oKa<800ooKa<800ol0
003oiMK6o`000006on3Db`03o`000?oHd];of=;B00;of=;B0_l00004olcCg`03o`000?nia^Co^LKT
00;o^LKT00Oo0000ojBfiOnT]^GoY;KUo`000?n>YNCo000000;oSZGT00?o0000og^EhOmkUN400_mk
UN45ofb9gP;o00000_m3O^@01Ol0003o?G_SocekholmNn?o0000027ooooo0_l00007ooooo`03o`00
0?oooooooooo00Gooooo000Mooooo`03o`000?oooooooooo03Oooooo0_l00005oh2>f003o`000?n4
T=OoQ93G00?oQ93G00?o0000ohbFf?n<U]P00on<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nP
Z]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i005o`0000;o_]7Y00?o
0000ol;MkOo2gNd00_o2gNd2ol;Xl0Oo00000_o=o><02?l0003o`_gRol;mh_o2oN;o0000ok3jh_l0
003oUo;S1?l00002ok[ik003o`000?nHkOKo000001?o00000omKW_<00ol0003oP9WRoh2IhP03o`00
00KoTJ3N00?o0000ojFNconUW/l00onUW/l3o`0000Co[Z;;00?o0000okbW`onlYl<02?nlYl<3o`00
0003ol6Y`_l0003oc[>o00[oc[>o0_l000000oo@];oo0000omc3`007omc3`005o`000?oKa<;oflC2
om_4`_l000000_oUe/H00ol0003oh=C;on3Db`05on3Db`06o`000?oHd];of=;Bo`000?oJg]Wo0000
1?o<dml00ol0003o^LKTokW6i002okW6i007o`000?nT]^GoY;KUojBfiOl0003oSZGTo`000002ohjU
i003o`000?mkUN7oNiGQ00;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh2of:2g0?o00000olmNn<00ol0
003oooooooooo`0Nooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool001go
oooo00?o0000ooooooooool0=oooool2of1nfP;o00000_n0S]P00ol0003oQ93GohB@e`03ohB@e`03
o`000?n<U]SoS9KH00?oS9KH00?o0000oiFNf_nEW]X00onEW]X00ol0003oX:[Moj2Zg@02oj2Zg@03
o`000?n/]n7o[;OQ00?o[;OQ00?o0000okW6i?nia^@00_nia^@01?l0003oa=CVolCDi_o4e>H<o`00
00;od_OU00Co0000olglhoo=o>?o00000oo2oN800ol0003o/?[Ro`000002o`000003ololh_l0003o
^_W/00;o^_W/0ol000000oo3j?3o0000oikKo003oikKo004o`000?mT^ogoI;_mofBko@Co00000_l0
J]42o`0000;o>X_]0_l00002oe^Nl`03o`000?n0VN;oP9WR00;oP9WR0ol00003oi6PgP03o`000?nU
W/ooYIk?00KoYIk?0ol000000on^X/_o0000okbW``0<okbW``;o00003Oo>/kl00ol0003og<?0omc3
`008omc3`003o`000?oKa<;o000000CoiMK600?o0000on3DbooPe</01?oPe</00ol0003of=;Bo`00
0002om[Nf@03o`000?o<dmooc=?O00;oc=?O00?o0000okW6i?nia^@00_nia^@01Ol0003oY;KUojBf
iOnT]^Go000000;oSZGT00?o0000ohjUi?l000001?mkUN400ol0003oK8WNofb9gP02ofb9gPGoHX;L
0_l00002ocekh`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool001cooooo00?o
0000ooooooooool0>?ooool4of1nfP03o`000?n0S]So000000GoQ93G00?o0000ohbFf?n<U]P00on<
U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nPZ]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/
]n401Ol0003o^LKTokW6i?nia^Co000000Goa=CV00?o0000olgRioo=h^L00ol00003om;^i`04o`00
0?oBmnGod_OUo`0000;ocOcS00Co0000ol;mh_o2oN;o`_gR0ol00004ololhP03o`000?njnNco^_W/
00;o00001?o3j?000ol0003oW]_loikKo005o`000003ofBkoOl0003o6XSY00;o00000ol0J]401?l0
003o>X_]ocZ;kOljRnd3o`0000OoP9WR1?l0000;ojFNc`;o00003OnlYl<00ol0003obk71o`00000<
oljc_`;o00002_oL`l000ol0003oiMK6onGFaP03onGFaP03o`000?oPe<_oh=C;00Goh=C;00Go0000
om[NfOoJg]Wof]kIo`000004olcCg`03o`000?nia^Co^LKT00;o^LKT00Go0000ojBfiOnT]^GoY;KU
o`000003ohjUi0;o00001?mkUN400ol0003oK8WNofb9gP02ofb9gP03o`000?mRP]coHX;L00;oHX;L
0_mMOm`3o`00027ooooo0ol0000=ooooo`007?ooool00ol0003oooooooooo`0hooooo`GoH7kJ00?o
0000ohB@eon4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ00?oUIkJ00?o
0000oj2ZgOnPZ]d00_nPZ]d00ol0003o[;OQojbgh@03ojbgh@03o`000?nia^Co^LKT00;o^LKT00?o
0000olCDi_o4e>H00_o4e>H5o`0000Cod^kW00Co0000om;giOoBmnGo00000_o=o><01?l0003o`_gR
ol;mh_o2oN82o`000003om[kfol0003ococR00;ococR1?l000000ooGjn;o0000ol?Xl003ol?Xl0?o
00000_n_b^h00ol0003oPkWgoh>im`09o`000003oaAchOl0003o000000?o>X_]00?o0000oh2Ih_n0
VN801on0VN800ol0003oYIk?ojFNc`0:ojFNc`04o`000?ngYLOo0000o`0000[o_:O300?o0000ol^a
`Oo;/L400_l00009oljc_`04o`000?oL`/3og<;0o`0000Wog<?000?o0000onGFa_oUe/H01?oUe/H0
0ol0003oh=C;on3Db`03on3Db`;o00000ooJg]T00ol0003oc=?OolcCg`02olcCg`03o`000?nia^Co
^LKT00;o^LKT00?o0000ojBfiOnT]^D00_nT]^D00ol0003oSZGTohjUi002o`0000CoNiGQ00?o0000
ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2g002of:2g0CoGGoL00?o0000ooooooooool07?ooool3
o`0000;ooooo00?o0000ooooooooool02oooool001cooooo0_l0000iooooo`03o`000?mPO][oH7kJ
00;oH7kJ00?oIX;Jo`000?n4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ
00;oUIkJ00?o0000oj2ZgOnPZ]d00onPZ]d00ol0003o[;OQojbgh@03ojbgh@05o`000?nia^Co^LKT
okW6i?l000000oo4e>H3o`0000?ocN;W00Go0000om;^iooBk^Ood^kWo`000003om;gi@05o`000?o=
o>?ocOcSo`000?o2oN800_l00003om[kf`03o`000?o?o>;ococR00;o00001OoGjn84o`000003olS@
h?l0003o[l[^00?o[l[^00?o0000oh>imon3^OL00_n3^OL2ocjCl@Go00000_lDLn42o`000003ocZ;
kOl0003oJ8oT00?o00001On0VN801?l0003oVY_Co`000?l00008ojFNc`03o`000?ngYLOo]jG700;o
]jG70_l00007okbW``03o`000?o;/L7obk7100?obk710_l00007oljc_`05o`000?oL`/3og<;0omc2
`?l000001ooL`l000ol0003oimK4o`000005onGFaP03o`000?oPe<_oh=C;00;oh=C;00?o0000onCU
dol000000ooJg]T00ol0003oc=?OolcCg`03olcCg`05o`000?nia^Co^LKTokW6i?l000001?nT]^D0
1?l0003oSZGTohjUi?n>YN@2o`0000?oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2
g002of:2g003o`000?mMOmcoGGoL00;oGGoL00?o0000ooooooooool06?ooool3o`0000Gooooo00?o
0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02
of1nfP;oIX;J00Co0000ohB@eon4T=Oo00001On<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nP
Z]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i002okW6i0Co000000?o
a=CVo`000?o=h^L00_o=h^L00ol0003od^kWom;^i`02om;^i`04o`000?oBmnGod_OUo`0000;ocOcS
0ol000001_oQn=Oo0000om[kfooJnm_o0000ololhP;o000000?ohNWGo`000?oGjn801?oGjn800ol0
003ob=3PolS@h003olS@h003o`000?n_b^ko[l[^00;o[l[^00?o0000oh>imon3^OL01?l000000oln
To7o0000o`0]XP02o`0000?o57?Q0ol00003ofR?i0;o00000on0VN801?l0003oVY_CoiZKdonJVm<3
o`0000GoYIk?00?o0000okNUaongYLL01?ngYLL2o`0000Go_:O300?o0000ol^a`Oo;/L401Oo;/L40
0ol0003oc[>ooljc_`03oljc_`03o`000?oL`/3og<;000?og<;000?o0000omc3`?oL`l001?oL`l00
0ol0003oimK4o`000006onGFaP04o`000?oPe<_oh=C;o`0000;oi>GC00Go0000om[NfOoJg]Wof]kI
o`000005olcCg`05o`000?nia^Co^LKTokW6i?l000001?nT]^D00ol0003oSZGTohjUi002ohjUi005
o`000?mkUN7oNiGQog^EhOl000001?m/RMh00ol0003oHX;Lof:2g002of:2g003o`000?mMOmcoGGoL
00;oGGoL00?o0000ooooooooool05Oooool3o`0000Sooooo00?o0000ooooooooool02oooool001co
oooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP?oIX;J00?o0000ohB@eol0
00001On<U]P00ol0003oUIkJoiFNfP02oiFNfP03o`000?nPZ]goX:[M00?oX:[M00?o0000ojbghOn/
]n400on/]n400ol0003o^LKTokW6i003o`0000Coa=CV00Co0000olgRioo=h^Oo00001?oBk^L01Ol0
003od_OUom;giOl0003ocOcS00;o00000ooQn=L01?l0003of__Kom[kfooJnm/2o`0000CohNWG00Co
0000omO[h_oGjn;oen_R0_l00006olS@h003o`000?n_b^ko[l[^00Co00000_n8Zn`00ol0003oCHo]
odf?k@02o`000003o`0]X_l0003o000000;o00000_lDLn400ol0003oJ8oTofR?i003ofR?i0Co0000
1_nJVm<2o`0000?oYIk?00?o0000okNUaongYLL01_ngYLL2o`0000?o_:O300?o0000ol^a`Oo;/L40
1_o;/L42o`0000;oc[>o00?o0000omc2`?oL`/001OoL`/000ol0003og<?0omc3`002omc3`005o`00
0?oWe/CoimK4onOFa?l000001OoUe/H00ol0003oh=C;o`000003onCUd`03o`000?oJg]Wof]kI00;o
f]kI00?o0000olcCgoo<dml00_o<dml01Ol0003o^LKTokW6i?nia^Co000000CoY;KU00?o0000ohjU
i?n>YN@00_n>YN@2o`0000;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2g002of:2
g003o`000?mMOmcoGGoL00;oGGoL00?o0000ooooooooool04Oooool4o`0000_ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP04
o`000?mVP][oIX;JofJ2fP;o00001?n<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nPZ]goX:[M
00?oX:[M00?o0000ojbghOn/]n400_n/]n44o`000003okW6i?l0003oa=CV00?oa=CV00Go0000olgR
ioo=h^OocN;Wo`000003om;^i`04o`000?oBmnGod_OUom;gi@;o000000?ohoCGo`000?oQn=L00_oQ
n=L00ol0003of__Kom[kf`02o`0000GohNWG00Co0000omO[h_oGjn;o00000_oFdM@00ol0003ob=3P
olS@h004olS@h0;o00000on/]n401Ol0003oR:_/ohR[k?n8Znco000000;oCHo]00?o0000o`9Rf?l0
00000_l000001Ol0F=3o0000oaAchOl0003oAgoT00;o00001OmXSn@00ol0003oVY_CoiZKd`06oiZK
d`?o00002ongYLL3o`0000_obk7100?o0000oljc_ol000002?oL`/001?l0003og<?0omc3`?l00004
onOFa003o`000?oUe/KoiMK600CoiMK600?o0000onCUdooTiM<00_oTiM<00ol0003of]kIom[Nf@02
om[Nf@03o`000?o<dmooc=?O00;oc=?O00Go0000okW6i?nia^Co^LKTo`000004ojBfi@03o`000?n>
YNCoSZGT00;oSZGT0_l00002og^Eh@03o`000?m/RMkoK8WN00;oK8WN00?o0000of:2g?mRP]`00_mR
P]`00ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oo
oooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000of1nf_mPO][oH7kJo`00
0004ofJ2fP;oLH[L0ol000000on<U]So0000oiFNfP03oiFNfP03o`000?nPZ]goX:[M00?oX:[M00Co
0000ojbghOn/]n7o[;OQ0ol00003okW6i003o`000?o4e>Koa=CV00;oa=CV00Go0000olgRioo=h^Oo
cN;Wo`000003om;^i`05o`000?oBmnGod_OUom;giOl000000ooSm=L01?l0003ohOSGon7heooQn=L3
o`000003onKWd?l0003ohNWG00CohNWG00?o0000omO[h_l000001?oFdM@01Ol0003ob=3PolS@h?o8
d>3o000000;o`;_E00?o0000ojbghOn/]n400_n/]n401Ol0003oR:_/ohR[k?n8Znco000000;oCHo]
00?o0000o`9Rf?l000000_l000001?l0F=3o0000o`000?l00002odMoi0;o00000omXSn@01?l0003o
R9GIo`000?l00007oiZKd`03o`000?ngYLOo]jG700_o]jG70_l0000;ol^a`@;o00002OoL`/000ol0
003og<?0o`000005onOFa003o`000?oUe/KoiMK600?oiMK600?o0000onCUdooTiM<00_oTiM<00ol0
003of]kIom[Nf@02om[Nf@03o`000?o<dmooc=?O00;oc=?O00Go0000okW6i?nia^Co^LKTo`000004
ojBfi@03o`000?n>YNCoSZGT00;oSZGT00Go0000og^EhOl0003oNiGQo`000004ofb9gP03o`000?mR
P]coHX;L00;oHX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0;ooooo`?o00004ooo
ool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0iooooo`05o`000?mPO][o
H7kJof1nf_l000001?mVP]X5og6:g0;o00001?nEW]X00ol0003oX:[Moj2Zg@03oj2Zg@Co000000?o
[;OQo`000?nia^@00onia^@00ol0003oa=CVolCDiP02olCDiP05o`000?o=h^OocN;WolgRiol00000
0ooBk^L01?l0003od_OUo`000?l00003on?de`04o`000?oQn=OohOSGon7he`;o00001?oVim000ol0
003ohNWGon7Ye`02on7Ye`;o00001_oFdM@00ol0003ob=3Po`000004ol2ke@03o`000?n/]n7o[;OQ
00;o[;OQ00?o0000ohR[k?n8Zn`03?l00004odMoi004o`000?mXSnCoJ8oTo`0000?oR9GI00?o0000
oiZKdonJVm<01?nJVm<01?l0003o[J;<o`000?l0000:okNUa`03o`000?o6/<Co000000[obk7100?o
0000omW2`_l000002OoL`/000ol0003oimK4onOFa004onOFa003o`000?oUe/KoiMK600;oiMK60_l0
0005onCUd`05o`000?oJg]Wof]kIom[NfOl000001?o<dml01Ol0003o^LKTokW6i?nia^Co000000Co
Y;KU00?o0000ohjUi?n>YN@00_n>YN@00ol0003oNiGQog^Eh@02o`0000CoK8WN00?o0000of:2g?mR
P]`00_mRP]`00ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00Oooooo1?l0000Fooooo`03
o`000?oooooooooo00[ooooo000Kooooo`;o0000>Oooool00ol0003oH7kJof1nfP02of1nfP03o`00
0?mVP][oIX;J00;oIX;J1OmaR]`2oh6Gg`04o`000?nEW][oUIkJo`0000CoX:[M0ol00004ojbgh@03
o`000?nia^Co^LKT00;o^LKT00Go0000olCDi_o4e>Koa=CVo`000003olgRi`04o`000?oBk^Ood^kW
om;^i`?o000000?oh^oHo`000?oSm=L00_oSm=L00ol0003ohOSGon7he`02o`0000Goi^O@00Oo0000
on7YeooQjMOohNWGo`000?oMd<co000000Ooe]7D00?o0000ol2keOo0^mD01?o0^mD01?l0003o[;OQ
ojbghOn/]n43o`0000?oOY_T0_m9Q>H5o`000004o`0n_?l0003o7f[Lo`0000?oAgoT0ol00004ohRE
f@;o00001?nJVm<01?l0003o[J;<ojfRc?n]X/`2o`0000Oo]jG700Co0000olJ`a?o6/<Coa[340_l0
0007ol^a`@05o`000?oI`/;ofL;2omW2`_l000002?oL`/000ol0003oimK4onOFa005onOFa006o`00
0?oUe/KoiMK6o`000?oZjLgo00001OoTiM<01Ol0003of]kIom[NfOoJg]Wo000000?oc=?O3_l00000
0on>YNCo0000og^Eh@02og^Eh@03o`000?m/RMkoK8WN00;oK8WN00?o0000of:2g?mRP]`00_mRP]`0
0ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00Cooooo0ol0000Jooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000of1nf_mPO]X00_mPO]X00ol0
003oIX;JofJ2fP02ofJ2fP03o`000?maR]coLH[L00;oLH[L0on1Uml01?l0003oUIkJo`000?nPZ]d3
o`000003oj2ZgOl0003o[;OQ00?o[;OQ00?o0000okW6i?nia^@00_nia^@00ol0003oa=CVolCDiP02
olCDiP04o`000?o=h^OocN;Wo`0000;od^kW0_l00004on;_f009o`000?oSm=OohoCGon?deol0003o
hOSGo`000?oXi<go000000Goi^O@00Co0000on7YeooQjMOo00000ooMd<`00ol0003oe]7DomKAe003
omKAe004o`000?o;_<cobkc<o`0000Go`;_E00?o0000ojbghOl000000onOY]X4ogjKi004o`000?m9
Q>Ko0000o`=Me@?o000000?o03jlo`000?lOJ]`00_l00003odMoi003o`000?n8UMWoR9GI00CoR9GI
0_l000000onJVm?o0000ojfRc005ojfRc003o`000?ngYLOo]jG700Co]jG700?o0000olJ`a?o6/<@0
0oo6/<@00ol0003obk71ol^a`@03ol^a`@03o`000?oI`/;ofL;200?ofL;200?o0000omc2`?oL`/00
1?oL`/000ol0003oj=O4o`000006onOFa003o`000?oUe/Ko000000;oj^W=00?o0000onCUdooTiM<0
0ooTiM<01?l0003of]kIom[NfOoJg]T4o`000003olWHi?l0003o^LKT00;o^LKT00?o0000ojRdhOnX
]>400_nX]>401?l0003oVJCMoiVTgOnIY=d3o`0000;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0
003oHX;Lof:2g002of:2g003o`000?mMOmcoGGoL00;oGGoL00Co0000oooooooooooooooo0ol0000M
ooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000of1n
f_mPO]X00_mPO]X00ol0003oIX;JofJ2fP02ofJ2fP03o`000?maR]coLH[L00;oLH[L1?n1Uml3o`00
00?oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i002okW6i005o`000?o4e>Koa=CV
olCDi_l000000oo=h^L3o`000003omgXfol0003oh^oH00?oh^oH00Co0000on?deooSm=OohoCG0_l0
0002onSTc@03o`000?oVim3oi^O@00Coi^O@0_l00005omg@c005o`000?oFdMCoe]7DomKAe?l00000
1?o;_<`00ol0003o`;_Eol2ke@03ol2ke@03o`000?nOY][oWjKJ00?oWjKJ00So0000ogjKi?mnVnCo
OY_To`000?m9Q>Ko0000o`=Me@Co000000?o053=oamZg?lOJ]`00_l000001?m7OnCo0000ofj<g_l0
0006ohREf@;o00001on]X/`2o`0000?o]jG700?o0000olJ`a?o6/<@01Oo6/<@2o`0000?obk7100?o
0000omW2`_oI`/801?oI`/800ol0003og<;0omc2`002omc2`005o`000?oXelCoj=O4onSGa?l00000
1_oWe/@01Ol0003oj^W=on[YcOoZjLgo000000Goi>GC00?o0000om[NfOoJg]T00_l00003olWHi005
o`000?nia^Co^LKTokW6i?l000001?nX]>400ol0003oVJCMoiVTg@03oiVTg@;oS9SJ1?l00003ofb9
gP03o`000?mRP]coHX;L00;oHX;L00?o0000oeeog?mMOm`00_mMOm`4o`00023ooooo00?o0000oooo
ooooool02_ooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP03
o`000?mVP][oIX;J00;oIX;J00?o0000og6:g?maR]`00_maR]`4o`0000;oTjKR0ol000000onPZ]go
0000ojbgh@03ojbgh@03o`000?nia^Co^LKT00;o^LKT00?o0000olCDi_o4e>H00_o4e>H4o`0000Co
gNSK00?o0000on;_f?oRkmP00_oRkmP00ol0003ohoCGon?de`02o`0000Coj>C=00?o0000onKWd?oV
im000_oVim02o`0000OogM3<00?o0000omKAe?l000001_o;_<`01Ol0003o`;_Eol2keOo0^mGo0000
00;o/Z[@00?o0000oinVf_nOY]X00_nOY]X01?l0003oOY_TogjKi?mnVn@8o`000004o`1@cOl0003o
7f[LoamZg0;o00000_m^S=h2o`0000GoR9GI00?o0000ojfRc?n]X/`01on]X/`2o`000003okNUaol0
003oa[3400Soa[3400?o0000ol^a`Ol000002?oI`/801Ol0003og<;0omc2`?oL`/3o000000?oj=O4
00?o0000onOFa?oWe/@01?oWe/@00ol0003oj^W=on[Yc@02on[Yc@03o`000?oTiM?oi>GC00;oi>GC
0ol000000ooFin;o0000olWHi002olWHi005o`000?nia^Co^LKTokW6i?l000001?nX]>400ol0003o
VJCMoiVTg@02oiVTg@03o`000?n<V=[oS9SJ00;oS9SJ0ol00002ofb9gP03o`000?mRP]coHX;L00;o
HX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[o
oooo000Jooooo`?o0000>Oooool00ol0003oH7kJof1nfP02of1nfP03o`000?mVP][oIX;J00;oIX;J
00Co0000og6:g?maR]coLH[L0_l00003oh6Gg`GoTjKR1?l00002ojbgh@03o`000?nia^Co^LKT00;o
^LKT00?o0000olCDi_l000000ol00002omGOg`03o`000?oMj=_ogNSK00;ogNSK00Go0000on;_f?oR
kmSoh^oHo`000003on?de`03o`000?oXi<goj>C=00?oj>C=00Oo0000onKWd?oVim3oi^O@o`000?oQ
clOo000000SogM3<00?o0000ol^lc?o;_<`01_o;_<`00ol0003o`;_Eo`000004ok:Zd003o`000?nO
Y][oWjKJ00;oWjKJ00Go0000ogjKi?l0003oK8gQo`000002ocQfh0Co00000_l0D<d01?l0003o7f[L
oamZg?l00004ofj<gP03o`000?n8UMWoR9GI00;oR9GI00?o0000oinNdol000002On]X/`00ol0003o
a[34olJ`a009olJ`a0;o00002OoI`/800ol0003og<;0o`000005onSGa003o`000?oWe/CoimK400;o
imK40_l00004on[Yc@04o`000?oTiM?oi>GConCUd`;o00000ooFin801Ol0003obMSTolWHi?o9f>Co
000000?o^LKT00?o0000ojRdhOnX]>400_nX]>400ol0003oVJCMoiVTg@02oiVTg@03o`000?n<V=[o
S9SJ00;oS9SJ0_n2S]L2o`000003ofb9g_l0003oHX;L00?oHX;L00?o0000oeeog?mMOm`00_mMOm`0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo
03Wooooo00?o0000of1nf_mPO]X00_mPO]X00ol0003oIX;JofJ2fP02ofJ2fPGo00001?n1Uml5oi>V
hPCoYkKT2Ol00002olWDhP05o`000?oEgmooeMoOomGOgol000001?oMj=/01Ol0003oh^oHon;_f?oR
kmSo000000;ohoCG0_l00005onSTc@04o`000?oVim3oi^O@o`0000?ohLo700?o0000omg@c?oMd<`0
1OoMd<`2o`0000Sobkc<00?o0000ok:Zd?nbZ]001?nbZ]001?l0003oWjKJoinVf_nOY]X3o`0000;o
K8gQ00?o0000ocQfh?lhM^001?l00002o`1@c@05o`000?lOJ]co0000odUkh?l000000om^S=h2o`00
00;oR9GI00?o0000oinNdonOW]<00_l00007ojfRc003o`000?nn[l[o000000Woa[3400?o0000omG1
aol000002OoI`/800ol0003oj=O4onSGa004onSGa007o`000?oWe/CoimK4onOFa?l0003ok>g:o`00
0004on[Yc@06o`000?oTiM?o0000o`000?oNl]co00000_oFin801Ol0003obMSTolWHi?o9f>Co0000
00?o^LKT00?o0000ojRdhOnX]>400_nX]>400ol0003oVJCMoiVTg@03oiVTg@05o`000?n<V=[oS9SJ
ohbHf_l000000on2S]L3o`0000CoHX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Wooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0>Oooool00ol0003oH7kJof1n
fP02of1nfP03o`000?mVP][oIX;J00?o00000omaR]`00ol0003oPIOOoh6Gg`02oh6Gg`03o`000?nC
Y^;oTjKR00;oTjKR1OnW]^@00ol0003o^LKTokW6i002okW6i003o`000?o9e>;obMCR00;obMCR00Go
0000omGOgooEgmooeMoOo`000004omgXf`07o`000?oRkmSoh^oHon;_f?l0003ohoCGo`000002onSR
c003o`000?oXi<goj>C=00?oj>C=0_l00005on7?a`03o`000?oMd<cogM3<00?ogM3<00Co0000om6l
aOoA_<Go00001oo;_<`00ol0003o_Jc8o`000005ok:Zd003o`000?nOY][o000000?oSISJ00Co0000
ofb=hOm/SN7o00000_lhM^05o`000003o`1@cOl0003oBG_P00;oBG_P00?o0000ofj<g_m^S=h00_m^
S=h2o`0000GoWikC00?o0000ojfRc?n]X/`00on]X/`01?l0003o_Zo:okj_b_nn[lX2o`0000Koa[34
00Go0000omG1aooE`LOoeL77o`000008omW2`P03o`000?oXelCoj=O400Goj=O400?o0000onOFa?l0
00000_o/kLX00ol0003oj^W=on[Yc@02on[Yc@;o00000_oNl]`01Ol0003oe^ORomKWh_oFin;o0000
00?obMST00Go0000okW6i?nia^Co^LKTo`000004ojRdh@03o`000?nIY=goVJCM00;oVJCM00?o0000
ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`02oh:>e`?o00000omRP]`00ol0003oGGoLoeeog002
oeeog003o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00004oiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>Oooool0
1?l0003oH7kJof1nf_mPO]X4o`000003ofJ2f_l0003oLH[L00?oLH[L00?o0000oh6Ggon1Uml00_n1
Uml00ol0003oTjKRoi>VhP02oi>VhPGoYkKT00?o0000okW6i?nia^@00_nia^@00ol0003obMCRolWD
hP02olWDhP05o`000?oEgmooeMoOomGOgol000000ooMj=/00ol0003oh^oHon;_f002on;_f0;o0000
0ooXh/`00ol0003oj>C=onSTc@03onSTc@03o`000?oQclOohLo700GohLo700Go0000omg@c?oMd<co
gM3<o`000004om6la@03o`000?o;_<cobkc<00?obkc<00Go0000okf/b?nm[<So_Jc8o`000005ok:Z
d003o`000?n=V=[oSISJ00?oSISJ00Go0000ofb=hOm/SN7o0000ocQfh007o`000005oaMSf?m9Nn3o
BG_PodUkh?l000001?m^S=h00ol0003oWikCoinNd`04oinNd`;o00000_n]X/`00ol0003o_Zo:okj_
bP04okj_bP03o`000?o6/<Coa[3400?oa[3400?o0000omG1aooE`LL00_oE`LL00ol0003ofL;2omW2
`P04omW2`P03o`000?oVf<Oo000000Ooj=O400?o0000onc]b_o/kLX00_o/kLX01Ol0003oj^W=on[Y
cOoZjLgo000000?og_;L00Go0000omKWh_oFin;oe^ORo`000003olWHi005o`000?nia^Co^LKTokW6
i?l000000onX]>400ol0003oVJCMoiVTg@03oiVTg@03o`000?n<V=[oS9SJ00;oS9SJ00?o0000oh:>
eon2S]L00on2S]L00ol0003oNhWEo`000003o`0000CoGGoL00?o0000ooooooooool08_ooool00ol0
003oooooooooo`09ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0>Oooool5o`0000CoIX;J00?o0000og6:g?maR]`00_maR]`00ol0003o
PIOOoh6Gg`02oh6Gg`03o`000?nCY^;oTjKR00;oTjKR00?o0000ojNfi?nW]^@00_nW]^@00ol0003o
^LKTokW6i002okW6i005o`000?o9e>;obMCRolWDh_l000001?oEgml01Ol0003ogNSKomgXfooMj=_o
000000?oh^oH0_l00004onSRc003o`000?oXi<goj>C=00?oj>C=00?o0000on7?aooQclL01_oQclL0
0ol0003ogM3<o`000006om6la@05o`000?o;_<cobkc<ol^lc?l000001Onm[<P00ol0003o/Z[@ok:Z
d002ok:Zd003o`000?nQW]7o000000CoSISJ00?o0000ofb=hOm/SN400_l000000olKIMWo0000o`00
0003o`0000;o5f?H00Co0000odUkh?m9Nn3o00000om^S=h00ol0003oRISKo`000006oinNd`03o`00
0?n]X/co000000Oo_Zo:0_l00002olJ`a003o`000?oE`LOoeL7700CoeL7700?o0000omW2`_oI`/80
0_oI`/801?l0003oi]S7onKHaol00006onSGa0;o00001?o/kLX00ol0003oj^W=on[Yc@02o`0000?o
g_;L00Co0000omKWh_oFin;o00000oo9f>@01Ol0003o^LKTokW6i?nia^Co000000CoZ;CQ00?o0000
oiVTgOnIY=d00onIY=d01Ol0003oS9SJohbHf_n<V=[o000000GoPXkG00?o0000og^9eOl000000omk
RMD2o`0000?oGGoL00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`000oooool0
0ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool4
o`000003of1nf_l0003oIX;J00?oIX;J00?o0000og6:g?maR]`00_maR]`00ol0003oPIOOoh6Gg`02
oh6Gg`05o`000?nCY^;oTjKRoi>Vh_l000001OnW]^@01Ol0003o^LKTokW6i?nia^Co000000CobMCR
00?o0000omGOgooEgml00_oEgml01Ol0003ogNSKomgXfooMj=_o000000;oh^oH00?o0000onGNcOl0
00001OoXh/`01ol0003oj>C=onSTcOoXi<go0000on;>a?l000002?oQclL00ol0003odKc5om6la@06
om6la@03o`000?o;_<co000000Oo_Jc800Co0000ok:Zd?nbZ]3o00000onQW]400ol0003oSISJohfH
fP02ohfHfP06o`000?m/SN7o0000odimh?l0003o6fGI1Ol00002oaMSf006o`000?m9Nn3oBG_Po`00
0?m^S=ko00000on9V=/2o`0000GoWikC00?o0000okj_b_nn[lX02?nn[lX00ol0003oa[34o`000007
omG1a`05o`000?oI`/;ofL;2omW2`_l000000ooVf<L00ol0003oj=O4onSGa002onSGa003o`000?o/
l<[o000000Cok>g:00Co0000on[YcOl0003o00000ooNl]`01Ol0003oe^ORomKWh_oFin;o000000?o
bMST00Go0000okW6i?nia^Co^LKTo`000004ojRdh@03o`000?nIY=goVJCM00;oVJCM00?o0000ohbH
f_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mkRMGo000000?oNhWE0_mhQmH2o`00
0003oeeog?l0003ooooo02?ooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000oooooooo
ool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool2obi/
f`;o00001?mVP]X00ol0003oLH[Log6:g002og6:g003o`000?n1UmooPIOO00;oPIOO00Go0000oi>V
h_nCY^;oTjKRo`000004ojNfi003o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>80
1Ol0003oeMoOomGOgooEgmoo000000CogNSK00?o0000on;_f?l000000_oUg/d00ol0003oj>;<onSR
c003onSRc004o`000?oXi<goj>C=o`0000?oh/k400?o0000on7?aooQclL01OoQclL00ol0003oeKc1
o`000007om6la@03o`000?nm[<So_Jc800Oo_Jc800?o0000ok:Zd?l000001?nQW]42o`0000?oSISJ
0_l00002odimh003o`000?lKIMWo000000Co00000_lGHmP01?l0003oBG_PodUkh?l00006ohVHf`;o
00000onOW]<00ol0003o/ZcCo`000009okj_bP03o`000?oE`LOoeL7700OoeL7700?o0000omW2`_l0
00001OoVf<L01?l0003oj=O4onSGa?l00002onc`bP03o`000?o/kL[ok>g:00;ok>g:0_l000000ooQ
n]Go0000omkbg002omkbg005o`000?oFin;oe^ORomKWh_l000000oo9f>@01Ol0003o^LKTokW6i?ni
a^Co000000?oZ;CQ00?o0000oiVTgOnIY=d00onIY=d00ol0003oS9SJohbHfP02ohbHfP03o`000?n2
S]OoPXkG00?oPXkG00Ko0000og^9eOmkRMGo0000og^9eOl00004ogR7eP;o00009?ooool00ol0003o
ooooooooo`09ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<oooool3o`0000Gooooo0ol^K=/2o`0000?oIX;J00?o0000og6:g?maR]`0
0_maR]`01Ol0003oPIOOoh6Ggon1Umoo000000CoTjKR00?o0000ojNfi?nW]^@00_nW]^@00ol0003o
^LKTokW6i002okW6i003o`000?o9e>;obMCR00;obMCR00Go0000omGOgooEgmooeMoOo`000004omgX
f`;o00001?oUg/d00ol0003oj>;<onSRc002onSRc003o`000?oXi<go000000Goh/k400?o0000on7?
aooQclL00ooQclL01Ol0003oeKc1omFl`OoE_<7o000000KodKc500Co0000olB]`ol0003o00001onm
[<P00ol0003oXIkAoj6Nd@05oj6Nd@06o`000?n=V=[oSISJo`000?mcSMgo00000_m>ON000ol0003o
6fGIo`000004o`0000;o5f?H00Go0000odUkh?l0003oIh_Ro`000006ohVHf`03o`000?nOW]?o0000
00?o/ZcC00?o0000okj_b_nn[lX01_nn[lX2o`0000WoeL7700?o0000onKHaooVf<L01?oVf<L00ol0
003oj=O4o`000003onc`bP04o`000?o/kL[ok>g:onc]bP;o00000_oQn]D01Ol0003og_;Lomkbg?oN
l]co000000;oe^OR00Go0000olWHi?o9f>CobMSTo`000003okW6i003o`000?nX]>7oZ;CQ00;oZ;CQ
00?o0000oiVTgOnIY=d00_nIY=d00ol0003oS9SJohbHfP02ohbHfP03o`000?n2S]OoPXkG00?oPXkG
00?o0000og^9eOmkRMD00_mkRMD2o`0000GoN8OF00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo033ooooo0ol00008ooooo`03o`000?l^K=_o;VcK00;o=g7M0_l000000omVP][o0000
og6:g003og6:g005o`000?n1UmooPIOOoh6Ggol000001?nCY^800ol0003oYkKTojNfi002ojNfi003
o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>801Ol0003oeMoOomGOgooEgmoo0000
00?ogNSK0_l00005onGNc@03o`000?oXh/coj>;<00?oj>;<00?o0000on;>a?oRc/@01OoRc/@01Ol0
003ohLo7on7?aooQclOo000000GoeKc100?o0000om6laOoA_<D00_oA_<D00ol0003oa:g3olB]``02
olB]``;o00001Onm[<P01?l0003o[Z7:o`000?l00005oj6Nd@;o00000omcSMd2o`000004odimh?l0
003o0000o`1AcPCo000000?o5f?Ho`000?l000000omWRn82o`0000GoRISK00?o0000ok:/donb[=<0
0onb[=<2o`0000Go_Zo:00Co0000olg1c_o=`Lko00001ooE`LL2o`0000Ooi]S700?o0000onc`b_o/
l<X00_o/l<X02?l0003ok>g:onc]b_l0003og_g?o`000?oQn]Go00000ooNl]`01Ol0003oe^ORomKW
h_oFin;o000000?obMST00Go0000okW6i?nia^Co^LKTo`000003ojRdh@03o`000?nIY=goVJCM00?o
VJCM00?o0000ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mkRMGoNhWE00?o
NhWE00?o0000ogR7e_mhQmH00omhQmH00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00So
oooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0]ooooo`?o
00003?ooool3obi/f`?o=g7M0_l00003og6:g003o`000?n1UmooPIOO00;oPIOO00?o0000oi>Vh_nC
Y^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9
e>800_o9e>801_l0003oeMoOomGOgooEgmoo0000omgXf`;o000000?oh=_Ao`000?oUg/d01?oUg/d0
0ol0003oj>;<onSRc002onSRc0;o00002?oRc/@00ol0003ohLo7o`000007omFl`@04o`000?oA_<Go
dKc5o`0000Ooa:g300Go0000okf/b?nm[<So_Jc8o`000004ojjQbP;o00001?nQW]42o`0000CoLhgM
00Go0000odimh?l0003o0000o`1AcP04o`0000;o<g?O00?o0000ofN;h_mWRn800_mWRn801Ol0003o
RISKohVHfon9V=_o000000;oWJOM00?o0000ok:/donb[=<00onb[=<01Ol0003o_Zo:okj_b_nn[l[o
000000CocL7>00?o0000omG1aooE`LL00ooE`LL01?l0003oh]W>on;Ic_l00006onKHa`03o`000?o/
l<[ok?3:00;ok?3:00Go0000onc]b_l0003og_g?o`000002on7je@05o`000?oNl]cog_;Lomkbg?l0
00000ooFin801Ol0003obMSTolWHi?o9f>Co000000?o^LKT00Go0000ojRdhOnX]>7oZ;CQo`000005
oiVTg@05o`000?n<V=[oS9SJohbHf_l000001_n2S]L00ol0003oNhWEog^9e@02og^9e@;o00001?mh
QmH00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooo
oooo02[ooooo0ol0000?ooooo`03o`000?l^K=_o;VcK00Co=g7M0_l00002og6:g003o`000?n1Umoo
PIOO00;oPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co
^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>801?l0003oeMoOomGOgooEgml2o`0000?oh=_A00?o
0000onGNcOoUg/d00ooUg/d01Ol0003oj>;<onSRc?oXh/co000000;oh/k400?o0000on;>a?oRc/@0
1_oRc/@2o`0000SoeKc100?o0000om6laOl000002?o4[L<2o`000003okf/b?l0003o[Z7:00Go[Z7:
00Oo0000oj6NdOnQW]7oXIkAo`000?n<UMSo000000CoLhgM0_l000001olSK=go0000o`1Ac_l0003o
012Do`000?l0D<d00_lcLml00ol0003oIh_RofN;hP02ofN;hP03o`000?n9V=_o000000CoWJOM00?o
0000ok:/donb[=<00onb[=<00ol0003o_Zo:o`000006olg1cP05o`000?oE`LOoeL77omG1aol00000
1?oRfLh00ol0003oi]S7onKHa`02onKHa`;o00001?o/l<X2o`0000;og_g?00Co0000on7jeOoQn]Go
00000ooNl]`01Ol0003oe^ORomKWh_l0003obMST00Wo00000_nX]>400ol0003oVJCMoiVTg@02oiVT
g@03o`000?n<V=[oS9SJ00;oS9SJ00?o0000oh:>eon2S]L00on2S]L00ol0003oNhWEog^9e@03og^9
e@03o`000?mhQmKo000000?oN8OF00?o0000ooooooooool09?ooool00ol0003oooooooooo`08oooo
o`006Oooool2o`0002Sooooo0ol0000Booooo`04o`000?l^K=_o;VcKo`0000?o=g7M0_m;O^83o`00
00CoPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co^LKT
00;o^LKT00Go0000olWDh_o9e>;obMCRo`000003omGOg`;o00001OoPfm400ol0003oiMk=onGNc@02
onGNc@04o`000?oXh/coj>;<o`0000Coh/k400?o0000on;>a?oRc/@01OoRc/@00ol0003oekboo`00
0008omFl`@03o`000?o4[L?oa:g300Woa:g300?o0000ojjQb_n^XLX01_n^XLX3o`0000?oS9GH0_l0
0003og>=g@;o000000[o8fcMo`000?l0003o0000o`0@U?l0003o053=o`000?lcLmoo00000omWRn82
o`0000KoWJOM00?o0000ok:/donb[=<00onb[=<2o`0000OocL7>00?o0000omG1aol000001OoRfLh0
1ol0003oi]S7onKHaooVf<Oo0000onWbc_l000001?o/l<X01?l0003og_g?omkmcol00002on7je@06
o`000?oNl]cog_;Lomkbg?l0003oe^OR1?l00002olCHj005o`000?nia^Co^LKTokW6i?l000000_n]
]]l3o`0000CoVJCM00?o0000ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mk
RMGoNhWE00;oNhWE00Oo0000ogR7e_mhQmKoN8OFo`000?mhQmKo000002Oooooo00?o0000oooooooo
ool02?ooool001Wooooo00?o0000ooooooooool09?ooool3o`0001Kooooo00?o0000obi/fol^K=/0
0olgLMd01?l0003oBgkRod]nh_m;O^82o`0000?oPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003o
YkKTojNfi002ojNfi005o`000?nia^Co^LKTokW6i?l000001?o9e>801_l0003oeMoOo`000?l0003o
f=KGo`0000Goh=_A00?o0000onGNcOoUg/d00ooUg/d2o`0000Koh/k400?o0000on;>a?oRc/@00ooR
c/@01Ol0003oekboomNl_ooG_;oo000000OoeKc100?o0000olV^_ol000002Oo4[L<01?l0003o]Z?5
o`000?l00007ojjQbP;o00001?n<UMP2o`000004og>=gOl0003oC87So`0000;o8fcM0_l000002?l0
49Co0000o`000?l0003o<g?Oo`000?mWRn;o00000omjVnH00ol0003oWJOMoifWg@03oifWg@05o`00
0?nb[=?o/ZcCok:/dol000000_o0_mP00ol0003ocL7>olg1cP05olg1cP03o`000?oRfLkoh]W>00Go
h]W>00?o0000onKHaol000000ooYl/h00ol0003ok?3:onc`bP02o`0000;og_g?00Co0000on7jeOoQ
n]Go00000_oNl]`3o`0000;oc>WZ00Co0000olCHj?o4f>So00000onia^@00ol0003o[KKOojffg`02
ojffg`03o`000?nSZ=[o000000;o000000?oVJCMo`000?n<V=X00_n<V=X00ol0003oPXkGoh:>e`03
oh:>e`03o`000?mkRMGoNhWE00?oNhWE00?o0000ogR7e_mhQmH00_mhQmH2o`0002Oooooo00?o0000
ooooooooool02?ooool001Sooooo00?o0000ooooooooool08_ooool3o`0001Wooooo00Co0000obi/
fol^K=_o00000olgLMd3od]nhP;oIY7W1?l00003oi>VhP03o`000?nW]^CoYkKT00;oYkKT00?o0000
okW6i?nia^@00_nia^@00ol0003obMCRolWDhP02olWDhP;o00000ooHe]L00ol0003oh=_Aon3Kd@03
on3Kd@03o`000?oUg/goiMk=00?oiMk=00?o0000on;>a?oRc/@01OoRc/@00ol0003oh/k4on;>a002
on;>a003o`000?oG_;ooekbo00?oekbo00?o0000omFl`OoE_<400ooE_<401?l0003obJjoolV^_oo9
[[l2o`0000Koa:g300?o0000okJSaOnfXlD00_nfXlD2o`0000Go[Z7:00Co0000oibJd_l0003o0000
1?n<UMP2o`0000;oC87S0_l000000olSK=go0000o`000002o`000004o`1Je?l0003o0000o`0000Go
NY_V00?o0000oifWgOnMYmd00onMYmd00ol0003o/ZcCo`000004ol2of003o`000?o=`LkocL7>00?o
cL7>0_l00008on;IcP03o`000?oYl/kojO;>00;ojO;>00Co0000onc`b_l0003o00000ooNoLl00ol0
003ohO[Eon7je@03o`000005ologiol0003oc>WZolcYj_l000000_o4f>P01Ol0003o^LKTokW6i?ni
a^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X2o`0000?oS9SJ00?o0000oh:>eon2S]L00on2
S]L00ol0003oNhWEog^9e@02og^9e@03o`000?mhQmKoN8OF00?oN8OF00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool0
1?l0003o;VcKobi/fol00003ocMag@04o`000?m;O^;oBgkRo`0000CoIY7W0_l00002oi>VhP03o`00
0?nW]^CoYkKT00;oYkKT00?o0000okW6i?nia^@00_nia^@00ol0003obMCRolWDhP03o`0000Gof=KG
00?o0000on3KdOoPfm400_oPfm400ol0003oiMk=onGNc@02onGNc@;o00002?oRc/@01Ol0003oh/k4
on;>a?oRc/Co000000Koekbo00?o0000omFl`OoE_<400_oE_<400ol0003obJjoolV^_`03olV^_`03
o`000?o4[L?oa:g300?oa:g300?o0000okJSaOnfXlD01?nfXlD01Ol0003o[Z7:ojjQb_n^XL[o0000
00CoW9[B0_l00003ohbEf0;o00000om<PN<2o`000006o`1Hd?l0003o0000o`000?l0F]Co00000_m4
P^H00ol0003oNY_VogZKiP02ogZKiP03o`000?nMYmgoWJOM00?oWJOM00?o0000ol2of?o0_mP01?o0
_mP01Ol0003ocL7>olg1c_o=`Lko000000;ofMWH00?o0000on;Ic_oRfLh00ooRfLh00ol0003ohoCG
o`000004onWbcP;o000000Kof?o=o`000?oNoLoog_g?o`000?oQn]D2o`0000?ocoOW00Co0000olcY
j_o<jN[o00000oo4f>P01?l0003o^LKTokW6i?l00004ojffg`03o`000?nSZ=[oXjSJ00CoXjSJ00Ko
0000oiZNe_l0003o0000ohbHf_l00005oh:>e`03o`000?mkRMGoNhWE00;oNhWE00?o0000ogR7e_mh
QmH00omhQmH2o`0002Sooooo00?o0000ooooooooool01oooool001Sooooo00?o0000ooooooooool0
7Oooool3o`0001oooooo00Co0000obi/fol^K=_o00000_lgLMd01?l0003oBgkRod]nh_m;O^84ofJA
i`;oQJGY0ol00004ojNfi003o`000?nia^Co^LKT00Go00000_o;d=d00ol0003of=KGomSFe`03omSF
e`03o`000?oPfm7oh=_A00;oh=_A00Go0000onGNcOoUg/goiMk=o`000002on3=aP03o`000?oRc/Co
h/k400Koh/k400?o0000on;>a?l000002?oG_;l01?l0003oeKc1omFl`Ol00007olV^_`;o00000_o4
[L<00ol0003o]Z?5okJSa@06okJSa@;o000000?o[Z7:o`000?nLV]801OnLV]801Ol0003oS9GHohbE
f?l0003oK8oS00;o00000_m<PN<2o`000003o`1Hd?l04I3o000000?o00000_m4P^H00ol0003oNY_V
ogZKiP02ogZKiP04o`000?nMYmgo0000o`0000;oZ[WT00?o0000ol2of?o0_mP01?o0_mP00ol0003o
cL7>o`000004omWIf005o`000?oRfLkoh]W>on;Ic_l000000_oSm=L01?l0003ojO;>onWbc_oYl/h2
o`0000;of?o=00?o0000omkmcooNoLl00_l000001Oo9o^3o0000ologioo?mnOo000000;oc>WZ00Go
0000olCHj?o4f>Soa=SXo`000003okW6i003o`000?n]]]oo[KKO00;o[KKO00?o0000oj>Xf_nSZ=X0
0onSZ=X00ol0003oVYkFoiZNeP02oiZNeP;o00001?n2S]L00ol0003oNhWEog^9e@03og^9e@03o`00
0?mhQmKoN8OF00;oN8OF00Co0000oooooooooooo00009oooool00ol0003oooooooooo`07ooooo`00
6?ooool2o`0001_ooooo0ol0000Rooooo`04o`000?l^K=_o;VcKo`0000?o=g7M00Co0000od]nh_m;
O^;o00000omVTNL01?l0003oQJGYohFUjOn5YNT8o`0000;o^LKT00?o0000ol_@gOo;d=d00_o;d=d0
0ol0003of=KGomSFe`03omSFe`03o`000?oPfm7oh=_A00?oh=_A00?o0000onGNcOl000001?oPcLH0
0ol0003oh/k4on;>a006on;>a0;o00002OoG_;l00ol0003oeKc1o`000009olV^_`03o`000?o4[L?o
000000[o]Z?50_l00007oibJdP?o00000om/Sn<2o`000006odb1hol0003o0000o`1Hd?l0003o01fK
0ol00002odB2iP03o`000?mjVnKoNY_V00?o00001OnZ^N@00ol0003o`;oHol2of004ol2of003o`00
0?oIfMSofMWH00CofMWH00?o0000on;Ic_l000000ooSm=L02Ol0003ojO;>onWbc_l0003oc_o>o`00
0?oHolgo0000omkmc`02o`0000;obOkP00Co0000ologioo?mnOo00000oo<jNX01?l0003oa=SXolCH
j?l00003okW6i003o`000?n]]]oo[KKO00;o[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0003oVYkF
oiZNeP03oiZNeP04o`000?nCU]Co0000o`0000;oPXkG00?o0000og^9eOmkRMD00_mkRMD00ol0003o
N8OFogR7eP03ogR7eP04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01oooool001So
oooo00?o0000ooooooooool05oooool3o`0002Gooooo00Go0000obi/fol^K=_o;VcKo`000002ocMa
g@04o`000?m;O^;oBgkRo`0000CoIY7W0on5YNT5oj:hj0Go^LKT00?o0000ol_@gOo;d=d00oo;d=d0
0ol0003of=KGomSFe`02omSFe`03o`000?oPfm7oh=_A00?oh=_A0_l00006on3=aP03o`000?oRc/Co
h/k400Goh/k400?o0000omRm_ol000002OoG_;l00ol0003obJjoolV^_`09olV^_`03o`000?nfXlGo
]Z?500Wo]Z?500Co0000ojNNcOl0003o00001onLV]82o`0000CoK8oS0_l000001olDLn7o0000o`00
0?l0003o01fKo`000?l0GmH01Ol00002oh>[k`03o`000?nZ^NCoZ[WT00CoZ[WT00Oo0000ol2of?o0
_mSo`;oHo`000?o9enCo000000OofMWH00?o0000on?deooSm=L00_oSm=L01Ol0003ojO;>o`000?o>
olko000000;of?o=0_l000001?nloMKo0000olWnh?l00002ologi`05o`000?o<jN[oc>WZolcYj_l0
00000_o4f>P01Ol0003o^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0
003oVYkFoiZNeP03oiZNeP03o`000?nCU]CoTiKD00;oTiKD00?o0000oh:>eol000001?mkRMD00ol0
003oN8OFogR7eP03ogR7eP05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o0000:Oooool01?l0003o;VcKobi/fol00002
ocMag@05o`000?m;O^;oBgkRod]nh_l000000omVTNL01?l0003oQJGYohFUjOn5YNT4oj:hj003o`00
0?nia^Co^LKT00?o^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`03omSFe`03o`00
0?oPfm7oh=_A00;oh=_A00?o0000on3=a_oPcLH01_oPcLH00ol0003oh/k4on;>a003on;>a005o`00
0?oH_Koof;foomRm_ol000002?oG_;l01?l0003objnno`000?l00008olV^_`03o`000?nlYL;o0000
00;o00001onfXlD01?l0003oYik=ojNNcOnWW/d3o`0000CoW9[B00Co0000oh>Ih?l0003o00001?m/
Sn<2o`000004oaAchOl0003o0000o`0MV`?o00000_m6SNd01Ol0003oPj__oh>[kon3Znoo000000Ko
Z[WT00?o0000ol2of?l000000oo9en@00ol0003ofMWHomWIf002omWIf003o`000?oFmN?o000000Co
hoCG0_l00002olkocP08o`000?oHolgof?o=o`000?nloMKo0000olWnh?l00002ologi`05o`000?o<
jN[oc>WZolcYj_l000000oo4f>P01Ol0003o^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nS
Z=X00onSZ=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD0_l00003og^9e@03
o`000?mhQmKoN8OF00?oN8OF00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0000/ooooo`04o`00
0?l^K=_o;VcKo`0000?o=g7M00Co0000od]nh_m;O^;o00000omVTNL01Ol0003oQJGYohFUjOn5YNWo
000000CoX[SX00?o0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oo
f=KG00?of=KG00?o0000on3KdOoPfm400_oPfm400ol0003oh<g6on3=aP06on3=aP03o`000?oRc/Co
h/k400;oh/k400?o0000omRm_ooH_Kl00ooH_Kl00ol0003oekboomNl_`04omNl_`03o`000?o;[kko
bjnn00;objnn0_l00005olV^_`03o`000?nlYL;o_:G200?o_:G20ol00003okJSa@03o`000?nWW/go
Yik=00GoYik=0_l00002oibJdP04o`000?n3VN3oPiWPoh>Ih0?o000000?oK8oSo`000?ljRnd01_l0
00001Ol0Fm7o0000odJ=kOm6SNgo000000?oPj__00?o0000ojZii?nZ^N@00onZ^N@2o`0000GobMOT
00Co0000omWIf?oIfMSo00000_oFmN<01?l0003ohoCGon?deooSm=L2o`0000;oc_o>00So0000omSo
cOl0003o0000okcme_l0003obOkPo`0000?ocoOW00Co0000olcYj_o<jN[o00000oo4f>P01Ol0003o
^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0003oVYkFoiZNeP02oiZN
eP03o`000?nCU]CoTiKD00GoTiKD00?o0000ohjBd_l000000_mkRMD00ol0003oN8OFogR7eP03ogR7
eP03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`005oooool00ol0003oooooooooo`0?ooooo`?o0000;oooool01Ol0003o;VcKobi/fol^K=_o0000
00;o=g7M00Co0000od]nh_m;O^;o00000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000CoX[SX00?o
0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oof=KG00?of=KG00Oo
0000on3KdOoPfm7oh=_Ao`000?oLc<[o000000Soh<g600Go0000on;>a?oRc/Coh/k4o`000006omRm
_`03o`000?oG_;ooekbo00;oekbo00?o0000ol^___o;[kh01Oo;[kh2o`0000?obJjo00?o0000okbU
`_nlYL801_nlYL84o`0000WoYik=0ol00006oh>Ih0?o00000_ljRnd5o`000005o`1KdOl0003o0000
odJ=kOl000000on3Znl00ol0003oZ[WTo`000002o`000003ojc?l_l0003obMOT00CobMOT00?o0000
omWIf?l000001?oFmN<01Ol0003ohoCGo`000?nno]Go000000;oc_o>0_l00002okcmeP04o`000?o9
o^3obOkPo`0000;ocoOW00Go0000olcYj_o<jN[oc>WZo`000002olCHj005o`000?nia^Co^LKTokW6
i?l000001?n]]]l00ol0003oXjSJoj>XfP03oj>XfP03o`000?nJW]KoVYkF00;oVYkF00?o0000oi>F
e?nCU]@01OnCU]@01ol0003oSY;BohjBd_n>T];o0000og^9eOl000001?mhQmH00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo0_l0000=
ooooo`?o0000<oooool2o`000005obi/fol0003o=g7MocMagOl000000om;O^801Ol0003oIY7WofJA
iomVTNOo000000?oQJGY00Go0000oj:hj?nR^>SoX[SXo`000005okW6i003o`000?o;d=gobm3M00;o
bm3M00?o0000omSFeooHe]L00_oHe]L01?l0003oh=_Aon3KdOl00003omc<bP03o`000?oPcLKoh<g6
00Koh<g600?o0000on;>a?l000002?oH_Kl01Ol0003oekboomNl_ooG_;oo000000Wobjnn0_l00000
0oo9[[oo0000okbU`P0:okbU`P;o00002_nWW/d2o`0000OoPiWP0_l00003ocZ;k@Go00000_lfT>l6
o`0000Go[<ob00?o0000olWGi?o9en@00oo9en@00ol0003oe_GSomKeh`03omKeh`;o000000?o__kE
o`000?o>olh00ol00002okcmeP04o`000?o9o^3obOkPo`0000;ocoOW00Go0000olcYj_o<jN[oc>WZ
o`000003olCHj004o`000?nia^Co^LKTo`0000Go[KKO00?o0000oj>Xf_nSZ=X00_nSZ=X00ol0003o
VYkFoiZNeP03oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]800on>T]82o`0000Co
N8OF00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000fooooo`;o05?>0_l00003ocMag@04o`00
0?m;O^;oBgkRo`0000?oIY7W00Go0000ohFUjOn5YNWoQJGYo`000004oj:hj003o`000?nia^Co^LKT
00;o^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`03omSFe`;o00001OoLc<X00ol0
003oh<g6on3=aP06on3=aP;o00002OoH_Kl00ol0003oekboo`00000<ol^__P03o`000?nlYL;o_:G2
00[o_:G200?o0000ojjQb_l000000_l00007ojNNc@03o`000?nCWmco000000;o00001?n3VN001?l0
003oFikco`000?l00003ocZ;k@Go000000?o=Y3_o`000?mk^OX00omk^OX00ol0003o[<obojc?lP03
ojc?lP06o`000?o9enCo0000o`000?nnl?;o00001OoFmN<00ol0003o__kEokkne@02o`000005ojSg
cOl0003o_?gFokcme_l000000_o9o^001?l0003ocoOWologiol00003olcYjP05o`000?o4f>Soa=SX
olCHj?l000000onia^@00ol0003o[KKOojffg`02ojffg`03o`000?nSZ=[oXjSJ00?oXjSJ00?o0000
oiZNe_nJW]H00_nJW]H00ol0003oTiKDoi>Fe004oi>Fe003o`000?n>T];oSY;B00CoSY;B00?o0000
ohb@dol000000_mhQmH00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003[ooooo0ol0Dlh2o`00
0005ocMagOl0003oBgkRod]nh_l000000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000CoX[SX00?o
0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oof=KG00;of=KG0_l0
0007omc<bP03o`000?oPcLKoh<g600Coh<g600Co0000omNn`OoG_/7o00002OoH_Kl00ol0003objnn
ol^__P0;ol^__P03o`000?noYl7o000000;o00002?nlYL800ol0003o[Z7:ojjQbP02ojjQbP?o0000
1?nWW/d00ol0003oTioLoi>Og002oi>Og0;o00000_n3VN001?l0003oFikcoe^NlomKW_<4o`000003
o`63gOl0003o000000Co00001?mk^OX01ol0003o[<obojc?l_n/co;o0000ojc?l_l000001?nnl?85
o`0000?o__kE00?o0000ojSgcOl000000_nloMHAo`000003okW6i?l0003o[KKO00?o[KKO00?o0000
oj>Xf_nSZ=X00onSZ=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000
ohjBd_n>T]801?n>T]801ol0003oS93Cohb@don<T=?o0000ogR7e_l000002oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0
000nooooo`;o05?>0_l0Fm<2o`0000?oBgkR00Co0000ofJAiomVTNOo00001?n5YNT01Ol0003oX[SX
oj:hj?nR^>So000000Co^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`02o`000003
omG<d?l0003og<c:00Kog<c:00?o0000on3=a_oPcLH00ooPcLH00ol0003oekk1omNn`@02omNn`@03
o`000?oH_Koof;fo00Kof;fo00?o0000olfa__l000000_l00008ol^__P03o`000?noYl7o_jO100?o
_jO10_l00006okbU`P03o`000?n^XL[o[Z7:00Go[Z7:1?l00007oi>Og0Co00001OmKW_<2o`0000?o
0H?M0_l000000ol?PnCo0000o`000006o`0000;oU=kn00?o0000okk`l_nnl?800_nnl?801Ol0003o
Y_SOojKhgol0003o__kE00?o000000?oZ?O=o`000?l000001?l00002oko^lP05o`000?o1h^oo`N;_
ol7Rkol000000onne>X01?l0003o^<KTokS6i?nha^@3o`0000Co[KKO00?o0000oj>Xf_nSZ=X00_nS
Z=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]801?n>
T]800ol0003oS93Cohb@d`03ohb@d`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo0_l0
Dlh2o`1Kd`05ocMagOl0003oBgkRod]nh_l000000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000?o
X[SX00?o0000okW6i?nia^@00onia^@00ol0003obm3Mol_@g@02ol_@g@;o00001?oEc=000ol0003o
g<c:omc<bP05omc<bP05o`000?oPcLKoh<g6on3=a_l000001_oG_/42o`0000Gof;fo00?o0000olfa
__o=/Kh00oo=/Kh2o`0000Kobjnn00?o0000oknW`OnoYl401OnoYl42o`0000?o_:G200?o0000ojjQ
b_n^XLX02On^XLX3o`0000SoTioL1?l00004oe^Nl`?o00000_l1Pmd3o`0000?oE[Wk00?o0000oiCN
o_nDg_h00_nDg_h4o`000003oh3Wj_l0003o000000Wo00000_nemO401?l0003o_nkboko^l_l00003
ol7Rk`05o`000?nne>[o_]CZokkDj_l000000onha^@01?l0003o/[WOok:igonb^Ml2o`000003ojff
gol0003oXjSJ00CoXjSJ00Go0000oiZNe_nJW]KoVYkFo`000006oi>Fe003o`000?n>T];oSY;B00Co
SY;B00?o0000ohb@don<T=<01?n<T=<00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`;o05?>0_l0Fm<2o`000003od]n
h_l0003oIY7W00;oIY7W00Go0000ohFUjOn5YNWoQJGYo`000004oj:hj003o`000?nia^Co^LKT00;o
^LKT00Co0000ol_@gOo;d=gobm3M0_l00006omG<d003o`000?oLc<[og<c:00Gog<c:00?o0000on3=
a_l000002OoG_/400ol0003of;foomRm_`02omRm_`03o`000?o=/KkocK6n00GocK6n0_l00004ol^_
_P03o`000?noYl7o_jO100Oo_jO11?l0000;ojjQbP03o`000?nOY=WoWjCI00Co00001?nCWm`01?l0
003oMjcdogN/m?mg[?@6o`000003obNQk?l0003o000000co00000on0inX2o`000003og3Na?l0003o
000000?o000000?oXOC/o`000?l000000_nemO401?l0003o_nkboko^l_l00003ol7Rk`05o`000?nn
e>[o_]CZokkDj_l000000onha^@00ol0003o/[WOok:ig`03ok:ig`?o00001?nSZ=X00ol0003oVYkF
oiZNeP02oiZNeP03o`000?nCU]CoTiKD00?oTiKD00?o0000ohjBd_n>T]801?n>T]800ol0003oS93C
ohb@d`04ohb@d`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`005_ooool2o`0004Wooooo0_l0Dlh01_l0Fm?o677QoaQahOl0003oBgkRo`0000;o
IY7W00?o0000ohFUjOn5YNT00_n5YNT01Ol0003oX[SXoj:hj?nR^>So000000Co^LKT00Ko0000ol_@
gOo;d=go0000ol_9fOl00007omG<d003o`000?oLc<[og<c:00Gog<c:0_l0000:omNn`@04o`000?oH
_Koof;foo`0000[ocK6n1?l0000=oknW`@03o`000?n^XL[o[Z7:00Wo[Z7:00?o0000oinTfOnOY=T0
1?nOY=T4o`000003oi>Og?l0003oMjcd00KoMjcd6Ol00002oj7dk003o`000?nemO7o]OGa00;o0000
0_nok_801Ol0003o`N;_ol7Rkoo1h^oo000000?o_]CZ00Go0000okS6i?nha^Co^<KTo`000005ok:i
g`04o`000?n/[m[o[:oJojb_fP;o000000?oXjSJo`000?nJW]H00onJW]H00ol0003oTiKDoi>Fe004
oi>Fe003o`000?n>T];oSY;B00?oSY;B00?o0000ohb@don<T=<01?n<T=<00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool000cooooo1?l000000ol@
413oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l0Dlh01?l0Fm?o677QoaQahOlHLN42
o`000003ofJAiol0003oQJGY00?oQJGY00Go0000oj:hj?nR^>SoX[SXo`000005okW6i0;o00000oo;
bMT00ol0003oeLc@omG<d005omG<d003o`000?oLc<[og<c:00Cog<c:00?o0000omBoa_l000002_oG
_/400ol0003of;foo`00000=olfa_P03o`000?noYl7o_jO100_o_jO100?o0000okBTb?ndY<P01?l0
0005ojjQbP03o`000?nOY=WoWjCI00SoWjCI2?l00003ogN/m003o`000?m=_?SoCKch00;oCKch1ol0
00000oln`]3o0000o`000006o`0000?oXOC/00Co0000okGelOnemO7o00000onok_801Ol0003o`N;_
ol7Rkoo1h^oo000000?o_]CZ00Go0000okS6i?nha^Co^<KTo`000005ok:ig`03o`000?n/[m[o[:oJ
00?o[:oJ0ol00003oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]800on>T]800ol0
003oS93Cohb@d`04ohb@d`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oo
oooo00?o05?>o`000?l0Fm<00_lHLN401Ol0003oAXo^o`000?mVTNOo000000?oQJGY00?o0000oj:h
j?nR^>P00_nR^>P00ol0003o^LKTokW6i003o`0000GoblWI00?o0000omG<d?oEc=001?oEc=000ol0
003og<c:omc<bP03omc<bP05o`000?oD_lKoe;o6omBoa_l000002_oG_/400ol0003ocK6nolfa_P0<
olfa_P03o`000?o2ZL7o`ZW100?o00002?noYl400ol0003o]:C8okBTb004okBTb0Co000000?o[Z7:
o`000?nOY=T02_nOY=T00ol0003oS;KbohbflP04ohbflQ7o000000CoHmWIo`000?l0003oQN_S0_l0
0002oj7dk0;o00000_nemO401Ol0003o_nkboko^l_nok_;o000000?o`N;_00?o0000okkDj_nne>X0
0_l00003okS6i003o`000?nb^Moo/[WO00?o/[WO00?o0000ojb_f_n/[mX00on/[mX01ol0003oYZOG
ojJWeonVYmOo0000oiZNe_l000001_nCU]@00ol0003oSY;BohjBdP03ohjBdP03o`000?n<T=?oS93C
00CoS93C00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo000>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool01?l0003o
05?>o`000?l0Fm<2oaQah@03o`000?m6SnkoAXo^00co00000_niaN<00ol0003oblWIol_9f@04ol_9
f@03o`000?oEc=3oeLc@00CoeLc@00Go0000omc<b_oLc<[og<c:o`000005omBoaP;o00002?oG_/40
1?l0003ocK?0o`000?l0000:olfa_P03o`000?o2ZL7o`ZW100Co`ZW10ol00004oknW`@03o`000?nd
Y<So]:C800Wo]:C82Ol00005oinTf@03o`000?n<]_;oS;Kb00SoS;Kb00?o0000og3?o_m`coh01?m`
coh;o`000003oj7dk?l0003o]OGa00;o]OGa00Go0000oko^l_nok_;o_nkbo`000003ol7Rk`04o`00
0?nne>[o_]CZo`0000Co^<KT00?o0000ok:igonb^Ml00_nb^Ml2o`0000Go[:oJ00?o0000ojJWeonV
YmL00_nVYmL3o`0000GoTiKD00?o0000ohjBd_n>T]801?n>T]800ol0003oS93Cohb@d`03ohb@d`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00
3_ooool00ol0003oooooooooo`0:ooooo`;o0000Aoooool01?l0003o05?>o`000?l0Fm<2oaQah@03
o`000?m6Snko000000CoMj[b00Go0000oijlkOnN_>goW[c]o`000005okW5h`03o`000?o;bMWoblWI
00?oblWI00?o0000omG<d?oEc=001OoEc=000ol0003og<c:o`000008omBoaP03o`000?oG_/7oekk1
00Coekk100?o0000olfc`?o=/l000_o=/l02o`0000SocK6n00?o0000ol:Y`Oo2ZL401oo2ZL43o`00
0003oknW`Ol0003o]:C800_o]:C800?o0000ojRXeonXZ=L01OnXZ=LGo`0000CoS=_o0ol00003oj3O
o0Co000000?o]OGao`000?nok_800_nok_801Ol0003o`N;_ol7Rkoo1h^oo000000;o_]CZ00?o0000
okS6i?nha^@00_nha^@00ol0003o/[WOok:ig`02ok:ig`03o`000?n/[m[o[:oJ00?o[:oJ0_l00004
ojJWe`05o`000?nQX]GoXJ;Eoj6ReOl000000onCU]@00ol0003oSY;BohjBdP04ohjBdP03o`000?n<
T=?oS93C00?oS93C00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool0
1?l0003o05?>o`000?l0Fm<2oaQah@03o`000?m6Snko000000CoMj[b00Go0000oijlkOnN_>goW[c]
o`000005okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=001OoEc=02o`0000Woe;o6
0_l00004omNn`@03o`000?o=/l3ocK?000CocK?00_l00005olfa_P03o`000?o2ZL7o`ZW100_o`ZW1
0_l0000<okBTb003o`000?nXZ=OoZ:SG00[oZ:SG00?o0000oi^lkonK_>l02OnK_>l00ol0003oS=_o
ohcKo`04ohcKo`?o00000onPgo`3o`0000?o[]kh1?l000000onok_;o0000ol7Rk`02ol7Rk`04o`00
0?nne>[o_]CZo`0000Co^<KT00?o0000ok:igonb^Ml00_nb^Ml00ol0003o[:oJojb_fP03ojb_fP03
o`000?nVYmOoYZOG00?oYZOG00?o0000oj6ReOnQX]D00onQX]D00ol0003oTiKDo`000006ohjBdP03
o`000?n<T=?oS93C00?oS93C00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
AOooool01?l0003o05?>o`000?l0Fm<2oaQah@03o`000?m6Snko000000CoMj[b00Go0000oijlkOnN
_>goW[c]o`000005okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=001?oEc=000ol0
003od<;<o`00000:omBoaP04o`000?oG_/7oekk1o`0000WocK?00_l00003olfa_P03o`000?o2ZL7o
`ZW100co`ZW100?o0000okRWb?nhYlP01Ol00005okBTb003o`000?nXZ=OoZ:SG00[oZ:SG00?o0000
oi^lkonK_>l02_nK_>l00ol0003oS=_oohcKo`03o`0000?oX=ol0ol00003ojkNn0?o00000onff_<4
o`000005ol7Rkol0003o_]CZokkDj_l000001?nha^@00ol0003o/[WOok:ig`02ok:ig`03o`000?n/
[m[o[:oJ00?o[:oJ00?o0000ojJWeonVYmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@?o00001On>
T]800ol0003oS93Cohb@d`03ohb@d`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04Gooooo0_l000001?l0Fm?o0000oaQahOl00002odJ?kP03o`000?mgZ_;oMj[b00;oMj[b00Go
0000oijlkOnN_>goW[c]o`000004okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=00
0ooEc=001?l0003od<;<om32c?o@`/`2o`0000Woe;o600?o0000omNn`Ol000002oo=/l02o`000003
olfa__l0003o`ZW100co`ZW100?o0000okRWb?nhYlP01_nhYlP4o`000003okBTb?l0003oZ:SG00co
Z:SG00?o0000oi^lkonK_>l01?nK_>l8o`0000CoX=ol0_l00004ojkNn0;o00001?nff_<2o`0000?o
^MC]0ol000000onne>[o0000okS6i003okS6i004o`000?nb^Moo/[WOok:ig`;o00001?n/[mX2o`00
00CoYZOG0_l00006oj6Re@05o`000?nMW]CoWIkDoifNe?l000000on>T]800ol0003oS93Cohb@d`03
ohb@d`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05
ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000A_ooool2o`000004o`1Kdol0003o677Q
o`0000;oAXo^00Go0000ogNZl_mgZ_;oMj[bo`000003oijlk@03o`000?niaN?o^LGS00?o^LGS00?o
0000ol_9fOo;bMT00oo;bMT01Ol0003oeLc@omG<d?oEc=3o000000Kod<;<00?o0000omBoa_oD_lH0
1ooD_lH00ol0003ocK?0olfc`00<olfc`003o`000?o2ZL7o`ZW100co`ZW100?o0000okRWb?nhYlP0
2_nhYlPFo`0000OoY[o/00?o0000oj3Oo?l000000_l00004ojkNn0;o00001?nff_<2o`0000?o^MC]
0_l00002okW<j0?o00000onha^@01Ol0003o/[WOok:igonb^Moo000000Go[:oJ00?o0000ojJWeonV
YmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@;o00001OnMW]@00ol0003oSY;Bo`000005ohb@d`03
o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
8_ooool00ol0003oooooooooo`14ooooo`;o000000Co05_Co`000?lHLN7o00000_m6Snh01Ol0003o
Mj[bogNZl_mgZ_;o000000?oW[c]00?o0000okW5honiaN<00oniaN<00ol0003oblWIol_9f@03ol_9
f@03o`000?oEc=3o000000Sod<;<0_l00007omBoaP03o`000?o<]/Co000000;o00002_o=/l000ol0
003o`jc3ol>/``05o`0000Oo`ZW100?o0000okRWb?nhYlP02onhYlP00ol0003o[ZcFojj/eP0;ojj/
eP03o`000?nV_ncoY[o/00[oY[o/0ol00004ojkNn0?o00000onff_<3o`0000?o^MC]0_l00002okW<
j0;o00000onhaN@00ol0003o^<KTo`000003ok:ig`03o`000?n/[m[o[:oJ00?o[:oJ00?o0000ojJW
eonVYmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@03o`000?nMW]CoWIkD00GoWIkD0_l00005ohb@
d`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04oooo
o`008oooool00ol0003oooooooooo`15ooooo`05o`000?l0Fm?o0000oaQahOl000000_m6Snh01Ol0
003oMj[bogNZl_mgZ_;o000000?oW[c]00?o0000okW5honiaN<00_niaN<00ol0003oblWIol_9f@03
ol_9f@;o00002oo@`/`00ol0003oe;o6omBoaP03omBoaP03o`000?o<]/Coc;K400?oc;K40ol00006
olfc`003o`000?o3[<?o`jc300Ko`jc31Ol000000oo2ZL7o0000okRWb00=okRWb003o`000?n^[=Ko
[ZcF00_o[ZcF00?o0000ojJok?nV_n`01OnV_n`5o`0000?o[/;X00Co0000ojkNn?l0003o00001?nf
f_<2o`0000Co^MC]0_l00003okW<j003o`000?nhaNCo^<GT00?o^<GT1?l000000onb^Moo0000ojb_
fP03ojb_fP;o00001OnVYmL00ol0003oXJ;Eoj6Re@04oj6Re@03o`000?nMW]CoWIkD00GoWIkD00Co
0000oi^MeOnKWMGo00000on<T=<00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01?ooool002Cooooo0_l00016ooooo`Co00000_m6Snh00ol0003oMj[bogNZ
lP02ogNZlP05o`000?nN_>goW[c]oijlkOl000001?niaN<01Ol0003oblWIol_9fOo;bMWo000000?o
b<CF00?o0000om32c?o@`/`02?o@`/`2o`0000;oe;o600?o0000olbfa?o<]/@01oo<]/@2o`0000Co
cK?000?o0000ol>/`oo3[<<02oo3[<<2o`0000;o^:O81_l00006okRWb003o`000?n^[=Ko[ZcF00co
[ZcF00?o0000ojJok?l000001?l00007ojk2j0?o00001?nff_<2o`0000Co^MC]0_l00003okW<j0;o
00001?nhaN@2o`0000?o]KkQ0ol00003ojb_fP03o`000?nVYmOoYZOG00CoYZOG00?o0000oj6ReOnQ
X]D00onQX]D2o`0000KoWIkD0_l00004oi^Me@03o`000?n<T=?o000002Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15ooooo`?o0000
0_m6Snh00ol0003oMj[bogNZlP02ogNZlP04o`000?nN_>goW[c]o`0000Go^LGS00?o0000ol_9fOl0
00001Oo8a=H2o`0000[od<;<00?o0000omBoa_l000002oo<]/@3o`000003olfc`?l0003o`jc300go
`jc300?o0000okZ[bOnjZlT01_njZlTGo`0000So[/;X1?l00003ok?3iP04o`000?nff_?o0000o`00
00Co^MC]0_l00003okW<j0;o00001OnhaN@00ol0003o]KkQokFnh@02okFnh@07o`000?nb^Mko/[WN
ok:ig_l0003o[:oJo`000005ojJWe`;o00001OnQX]D00ol0003oWIkDoifNe005oifNe003o`000?nK
WMGoVigE00CoVigE0_l0000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool002Oooooo00?o0000ooooooooool0AOooool00ol0B[So0000o`000002odJ?kP05o`000?mgZ_;o
Mj[bogNZl_l000000onN_>d00ol0003o^LGSokW5h`02okW5h`;o00002?o8a=H00ol0003od<;<om32
c008om32c003o`000?o<]/Coc;K400goc;K400?o0000ol>/`oo3[<<03Oo3[<<00ol0003o^Z_9okZ[
b@0<okZ[b@03o`000?nc/=Ko/k3F00co/k3F00?o0000ojk2j?n^`^P01?n^`^P3o`0000Oo/l?V0_l0
0004okWDk@;o00000onic>P2o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000GoYZOG00?o
0000oj6ReOnQX]D00onQX]D2o`0000KoWIkD0_l00005oi^Me@;o0000:?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Cooooo000Xooooo`03o`000?oooooooooo04Kooooo00Go04Zh
o`000?m6SnkoAXo^o`000003ogNZlP06o`000?nN_>goW[c]oijlkOl0003o^LGS0_l00003okW5h`03
o`000?o8a=Kob<CF00Gob<CF0_l00008om32c003o`000?o9^/_o000000;o00002oo<]/@01?l0003o
a;37olB`aoo4/<L5o`0000Ko`jc300?o0000okZ[bOnjZlT03OnjZlT00ol0003o/k3Fok>`eP0=ok>`
eP03o`000?n^`^So000000?o00001onc`nH3o`0000;o]/CU00Co0000okWDkOl0003o00000onic>P2
o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000;o[kCL00Go0000ojJWeonVYmOoYZOGo`00
0005oj6Re@03o`000?nMW]CoWIkD00GoWIkD00?o0000oi^MeOnKWMD01?nKWMD00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool002Wooooo0_l00017
ooooo`03o`1:^?l0003o000000;o00000omgZ_800ol0003oW[c]oijlk@02o`0000Ko^LGS0_l00007
olS4eP03o`000?o@`/cod<;<00Cod<;<00?o0000olVjboo9^//00oo9^//2o`0000Soc;K400?o0000
olB`aoo4/<L01oo4/<L5o`000003ol>/`ol0003o^Z_900ko^Z_900?o0000ok>`e_nc/=H02Onc/=H6
o`0000So/l?V0ol00005okK4i@;o00001?nic>P00ol0003o^<GTokS5i004okS5i003o`000?ne_^7o
]KkQ00;o]KkQ00?o0000ok:ig_nb^Mh00onb^Mh00ol0003o[kCLojndg003ojndg003o`000?nVYmOo
000000GoXJ;E00?o0000oifNe?nMW]@01?nMW]@2o`0000GoVigE0_l0000]ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0A_ooool00ol0
B[So;I?_o`000006o`0000?oW/;a1oniaN<2o`0000Kob<CF0_l00003om32c003o`000?o9^/_obK[;
00KobK[;0_l00006olbfa003o`000?o4/<Ooa;3700coa;370_l000000onjZlWo0000o`000005o`00
00Oo^Z_900Co0000ok>`e_nc/=Ko/k3F2?l00004okJef003o`000?nc`nKo/l?V00Go/l?V0_l00005
okK4i@?o00000_nhaN@01?l0003o^LcXo`000?l00005okS5i0;o00000one_^42o`0000Co/[WN0_l0
0006ojndg0?o00000onQX]D2o`0000KoWIkD00?o0000oi^MeOnKWMD00onKWMD2o`0002oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`16
ooooo`04o`1:^?l0003o;I?_obfCk`CoL;?j1?nN`_42o`0000Ko^LGS00?o0000olS4e_o8a=H01Oo8
a=H00ol0003od<;<o`00000;olVjb`?o00000oo<]/@00ol0003oa;37olB`a`0=olB`a`03o`000?nl
[lgo_:o=00Ko_:o=2ol0000<okJef003o`000?nc`nKo/l?V00;o/l?V0ol00005okK4i@;o00001Onh
aN@2o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000Ko[kCL0_l00003oj^`f`03o`000?nQ
X]Go000000KoWIkD0_l00004oi^Me@;o0000<_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo000]ooooo`03o`000?oooooooooo04Oooooo00Co04ZhobfCkol]Tnoo00000om`
/oX00ol0003oW/;aoik2l@02oik2l@03o`000?niaN?o^LGS00Co^LGS0_l00006olS4eP03o`000?o9
^/_obK[;00gobK[;0ol0000@olB`a`03o`000?nl[lgo_:o=00go_:o=00?o0000okJef?nf]MP03_nf
]MP4o`0000Go]/CU0ol00004okS5i0?o000000?o^<GTo`000?nhaN@00onhaN@00ol0003o]KkQokFn
h@02okFnh@03o`000?nb^Mko/[WN00;o/[WN0_l00006ojndg0;o00001On[/=/2o`0000KoWIkD00?o
0000oi^MeOnKWMD00onKWMD00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool002kooooo0_l00018ooooo`;o00000_l]Tnl01Ol0003oL;?jog2cn_m`
/o[o000000?oW/;a0_l00006okW5h`;o00000oo8a=H01?l0003oa;oEolBoeOo4_mD3o`0000cobK[;
00?o0000olB`aoo4/<L00_l0000;olB`a`03o`000?nl[lgo_:o=00ko_:o=00?o0000okJef?nf]MP0
2_nf]MP5o`0000Ko]/CU0_l00005okS5i0;o00001OnhaN@01?l0003o^<GTo`000?l00003okFnh@;o
00001?nb^Mh00ol0003o[kCLojndg004ojndg0;o00001On[/=/2o`0000;oZ:kK00Co0000oifNe?nM
W]CoWIkD0_l00004oi^Me@;o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo0_l000000ol]Tnoo0000o`000002og2cnP;o
00000onN`_42o`0000Ko^LGS00?o0000olS4e_l000001oo4_mD3o`0000WobK[;00?o0000ol>ecOo3
]Ld00_o3]Ld8o`0000?oa;3700?o0000okb_cOnl[ld03_nl[ld01?l0003o][GHokJef?nf]MP9o`00
00Co^;WJ00?o0000okK4iOnfa>D00_nfa>D2o`0000Co^<GT0ol00007okS5i0;o00000one_^42o`00
00Co/[WN0_l00005ojndg0;o00001On[/=/2o`0000GoZ:kK00?o0000oifNe?l000001?nKWMD2o`00
03Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003o
ooooooooo`17ooooo`?o000000?o;I?_o`000?m`/oX00_m`/oX2o`0000?oW/;a00?o0000okW5honi
aN<01?niaN<00ol0003oa;oEolBoe@09olBoe@?o00001Oo9^//00ol0003o`kG=ol>ec@0;ol>ec@Co
000000?o_:o=o`000?l000004Ol0000>okRifPCo00000onhaN@3o`0000Oo^<GT0ol00002okO4i003
o`000?ne_^7o000000Co/[WN0_l00005ojndg0;o00001On[/=/2o`0000OoZ:kK0_l00004oi^Me@03
o`000?oooooooooo03[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00
<_ooool00ol0003oooooooooo`18ooooo`;o000000?o;I?_o`000?l000000om`/oX01?l0003oW/;a
oik2lOnN`_42o`0000?o^LGS00?o0000okW4honia><00ol0000:olBoe@?o000000?obK[;o`000?o3
]Ld04?o3]Ld00ol0003o_;GBokbedP0>okbedP03o`000?nh^M[o^;WJ00co^;WJ1?l00004okS5i0;o
00001onhaN@3o`0000Go]lCT0_l00004ok:igP03o`000?n_]=co[kCL00?o[kCL0_l00005oj^`f`;o
00001_nX[]/3o`0000;oYJcL00Co0000oi^MeOl0003o0000?_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo000cooooo`;o0000BOooool3o`000003obfCkol0003oL;?j00;o
L;?j0_l00003oik2l@03o`000?niaN?o000000Ko^LCS0ol0000:olBoe@03o`000?o3]Lgo`kG=013o
`kG=00?o0000okbed_nl]M803_nl]M800ol0003o^;WJokRifP06okRifPKo00000oni_mh00ol0003o
^<GTo`000002o`0000Ko^<GT0ol00005okO4i0?o00000_nea>D01?l0003o/[WNo`000?l00004ojnd
g0;o00001?n[/=/3o`0000KoZ:kK0_l00005ojF/g0;o0000@Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo04Sooooo1Ol00003og2cnP03
o`000?nN`_7oW/;a00;o00002_nia><2o`0000Soa;oE00Co0000ol2le_o0_=Ko`;cF1_l00008ol>e
c@03o`000?nl]M;o_;GB00oo_;GB00Co0000okRif_nh^M[o^;WJ1Ol00008okVogP?o00001onhaN@2
o`0000Go]lCT0ol00005okG4i@;o00001?n_]=`2o`0000CoZk3K0_l00006ojR^f`?o00001?nU[=`3
o`0004?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0
003oooooooooo`19ooooo`04o`1fbol0003o;I?_o`0000;oL;?j0ol00003oj?8l`;o00002Onia><3
o`0000Coa;oE00?o0000ol2le_o0_=H02?o0_=H6o`0000;o`kG=00?o0000okbed_nl]M801_nl]M8<
o`0000Wo^KoN1Ol00002okS4i003o`000?nhaNCo^<GT00;o^<GT0ol00004okO4i0?o00001Onea>D3
o`0000;o//?W00Co0000ojndg?l0003o00001?n[/=/2o`0000KoZ:kK0_l00005ojF/g0;o0000Aooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000gooooo`;o0000C?ooool3
o`0000CoM/7n1OnSb?<3o`0000So^LCS0ol000000oo4_mGo0000ol2leP0?ol2leP?o000000?o_;GB
o`000?l000001Ol00009okblf@03o`000?ni_mko^KoN00Go^KoN1?l00008okS4i0Co00001?nga>@3
o`0000Go]LCU0ol00004ok;3i`?o00001?n[/=/2o`0000KoZ:kK0_l00004ojF/g0?o0000B_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo
04_ooooo00?o05B[o`000?mf`Oh01Omf`Oh00ol0003oXlScoj?8l`02oj?8l`?o00002?nia><00ol0
003o`;cFol2leP0Aol2leP03o`000?nl_=Wo_;cI00oo_;cI00?o0000okVog_ni_mh00_ni_mh2o`00
00_o^<CT0ol00004okO4i0?o00001Onea>D3o`0000Co//?W0ol00003ojo2j004o`000?n[/=_o0000
o`0000GoZ:kK0ol00004ojF/g0;o0000C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo000jooooo`03o`000?oooooooooo04gooooo0ol00005ogK1oP;o00000onSb?<3o`00
00Go^LCS00?o0000okW4honia><00onia><9o`0000Co`;cF00?o0000okblfOnl_=T01_nl_=T;o`00
0003okVog_nha>Co^<CT00Wo^<CT1Ol00002okG:j@03o`000?nga>Co000000;o00001Onea>D3o`00
00Co//?W0ol00005ojo2j0?o00001OnX[]/2o`0000GoYJcL0_l0001@ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool003_ooooo00?o0000ooooooooool0C_ooool00ol0E:_o
0000o`000003o`0000?oM/7n0ol00002oj?8l`?o000000?o^LCSo`000?nia><03_nia><4o`0000;o
_;cI1ol0000:okS4h`03o`000?nha>Co^<CT00Go^<CT1Ol00005okG:j@Co00001Onea>D3o`0000Co
//?W0ol00004ojo2j0Co00000on[`NX00ol0003oZ:kKo`000002o`0000CoYJcL0ol0001Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003cooooo0_l0001@ooooo`03o`1D
Zol0003o000000Co00000omf`Oh3o`0000;oXlSc00?o0000okW4honia><04Onia><00ol0003o^<CS
okS4h`0AokS4h`04o`000?nha>Co^<CTokS4i0Co00001Oneb^T5o`0000?o/Lo`00?o0000okG4iOne
a>D00ol00004ok;3i`?o00000on_`^P4o`0000KoZl7Z0ol00005ojF/g0;o0000Eoooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000nooooo`03o`000?oooooooooo053ooooo
0ol000001?l`Xo7o0000o`000?l00003ogK1oP03o`000?nYc?;oZLcb00GoZLcb2Ol00004okW4h`03
o`000?nha>?o^<CS00So^<CS3Ol00005okG:j@Go00001_naco05o`0000Co//?W0ol00003ojo2j0?o
00001_n[`NX4o`0000?oYl3[00?o0000ojF/g?l000000_l0001Jooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00Oooool003oooooo00?o0000ooooooooool0D_ooool3o`000003oc2S
lOl0003o000000GoRlon1ol00006ojW<lPGo00000_nha><8o`0000[o/Lg^00Co0000okG:jOneb^Wo
]L[Y0ol00006ok7?l0Ko00000onZd_D00ol0003o//?Wok;3i`03o`0000;o[l;X1?l00005oj_1jPCo
00001OnW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00
@?ooool00ol0003oooooooooo`1Dooooo`03o`000?mG`O[oEl7j00?oEl7j0ol00006oh_?oPOo0000
0onYc?800ol0003o/Lg^ok7=kP07ok7=kP_o000000?o]L[Yo`000?naco001Onaco05o`0000KoZ];e
1_l000000on_`^So0000o`000002o`0000CoZl7Z1Ol00004ojO0j`Go0000H_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o0000FOooool6oeO1nPGo00001_n;
coh3o`0000?o/Lg^1ol0000:oj;Dn@03o`000?naco3o/Lo`00;o/Lo`1?l00003oj[Bm@So000000?o
X]Cio`000?l000001?l00004oj_1jPCo00001?nW`>/5o`0006Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo00;ooooo00Co0000oeO1n_mG`O[oEl7j1Ol00003oh_?oP03o`000?nRe?WoX]Ci00OoX]Ci3?l0
00000onaco3o0000oj[Bm@0Ao`0000CoVM?l00?o0000oj_1j_l000000ol00003ojO0j`Go0000K_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool02?ooool2o`000004oeO1n_l0003o0000o`0000?oX]Ci7_l0
0007oiWCo0So00000_nW`>/5o`0007?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`00AOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo6Ol00002
oiWCo0go000000?oTm7mo`000?l000001ol0001iooooo`03o`000?oooooooooo00Sooooo0Ol00001
ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Goooooa;o000000?oTm7mo`00
0?l000002ol00023ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0018ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool08?ooool:o`00097ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00Boooool2o`00057ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004kooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
Coooool2o`0004gooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool0057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`30ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0<3ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Cooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo0000007ooooo001Doooo
o`;o0000B?ooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`00007ooooo001Foooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0`oooool00ol0003oooooo`000001oooo
o`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0<?ooooo00?o0000oooooooo
ool00Ol0000005Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`34ooooo`7o0000
0Oooool1o`000000FOooool2o`0004?ooooo00?o0000ooooooooool0aOooool2o`000000Foooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo0ol0000005cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`30ooooo`Co00000oooool005gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`2looooo`Co00001oooool005kooooo0_l0000nooooo`03o`00
0?oooooooooo0;Sooooo1?l0000;ooooo`00H?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;Cooooo1?l0000?ooooo`00HOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo0;7ooooo0ol0000Cooooo`00H_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
0:gooooo1?l0000Fooooo`00Hoooool2o`0003Wooooo00?o0000ooooooooool0ZOooool4o`0001[o
oooo001Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOooool4o`0001kooooo
001Vooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`0002;ooooo001W
ooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00009_ooool006Wooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2Jooooo`Co0000:_ooool006[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`2Fooooo`Co0000;_ooool006_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Booooo`Co0000<_ooool006cooooo0_l0000_ooooo`03o`000?oo
oooooooo08kooooo1?l0000fooooo`00K_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo08[ooooo1?l0000jooooo`00Koooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
08Oooooo0ol0000nooooo`00L?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?o
oooo1?l00011ooooo`00LOooool2o`0002[ooooo00?o0000ooooooooool0Ooooool4o`0004Gooooo
001cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Noooool4o`0004Wooooo001d
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004gooooo001eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00057ooooo001fooooo`;o
00009Oooool00ol0003oooooooooo`1_ooooo`Co0000EOooool007Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1[ooooo`Co0000FOooool007Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Wooooo`Co0000GOooool007[ooooo0_l0000Qooooo`03o`000?oooooo
oooo06?ooooo1?l0001Qooooo`00O?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
063ooooo0ol0001Uooooo`00OOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05co
oooo1?l0001Xooooo`00O_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Sooooo
1?l0001/ooooo`00Ooooool2o`0001cooooo00?o0000ooooooooool0E?ooool4o`00073ooooo0021
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`0007Cooooo0022oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool4o`0007Sooooo0023ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007cooooo0024ooooo`;o0000
5oooool00ol0003oooooooooo`14ooooo`Co0000P?ooool008Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`10ooooo`Co0000Q?ooool008Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0looooo`Co0000R?ooool008Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0iooooo`?o0000S?ooool008Wooooo0_l0000Booooo`03o`000?oooooooooo03Go
oooo1?l0002?ooooo`00Roooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo
1?l0002Cooooo`00S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo1?l0
002Gooooo`00SOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo1?l0002K
ooooo`00S_ooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`0009oooooo002@ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`000:?ooooo002Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:Oooooo002Booooo`;o00002?oo
ool00ol0003oooooooooo`0Jooooo`Co0000Zoooool009Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`Co0000[oooool009Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000/oooool009Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`?o0000]oooool009Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo
1?l0002jooooo`00VOooool01?l0003oooooooooool00009ooooo`Co0000__ooool009[ooooo00?o
0000ooooool000001Oooool4o`000<;ooooo002Kooooo`;o000000?oooooo`000?l000000_l00036
ooooo`00W?ooool2o`000<[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51724 .65343 m .51694 .65827 L .43899 .65168 L p .588 .786 .974 r
F P
0 g
s
.51694 .65827 m .51724 .65343 L .59265 .64836 L p .636 .778 .949 r
F P
0 g
s
.59265 .64836 m .59527 .65394 L .51694 .65827 L p .636 .778 .949 r
F P
0 g
s
.59527 .65394 m .59265 .64836 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44218 .64783 m .43899 .65168 L .36521 .63435 L p .523 .769 .987 r
F P
0 g
s
.43899 .65168 m .44218 .64783 L .51724 .65343 L p .588 .786 .974 r
F P
0 g
s
.51755 .64847 m .51724 .65343 L .44218 .64783 L p .597 .789 .973 r
F P
0 g
s
.51724 .65343 m .51755 .64847 L .59 .64269 L p .642 .78 .947 r
F P
0 g
s
.59 .64269 m .59265 .64836 L .51724 .65343 L p .642 .78 .947 r
F P
0 g
s
.59265 .64836 m .59 .64269 L .65915 .62672 L p .661 .753 .918 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59265 .64836 L p .661 .753 .918 r
F P
0 g
s
.36521 .63435 m .37116 .6317 L .44218 .64783 L p .523 .769 .987 r
F P
0 g
s
.4454 .64384 m .44218 .64783 L .37116 .6317 L p .534 .773 .986 r
F P
0 g
s
.44218 .64783 m .4454 .64384 L .51755 .64847 L p .597 .789 .973 r
F P
0 g
s
.51786 .64323 m .51755 .64847 L .4454 .64384 L p .612 .79 .967 r
F P
0 g
s
.51755 .64847 m .51786 .64323 L .58732 .63685 L p .651 .78 .942 r
F P
0 g
s
.58732 .63685 m .59 .64269 L .51755 .64847 L p .651 .78 .942 r
F P
0 g
s
.59 .64269 m .58732 .63685 L .65355 .62061 L p .667 .755 .916 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59 .64269 L p .667 .755 .916 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72971 .60722 L p .653 .72 .897 r
F P
0 g
s
.72971 .60722 m .73799 .61332 L .67023 .63881 L p .653 .72 .897 r
F P
0 g
s
.37116 .6317 m .37718 .62889 L .4454 .64384 L p .534 .773 .986 r
F P
0 g
s
.44866 .63948 m .4454 .64384 L .37718 .62889 L p .559 .777 .98 r
F P
0 g
s
.4454 .64384 m .44866 .63948 L .51786 .64323 L p .612 .79 .967 r
F P
0 g
s
.51817 .63758 m .51786 .64323 L .44866 .63948 L p .632 .787 .956 r
F P
0 g
s
.51786 .64323 m .51817 .63758 L .58462 .63077 L p .66 .778 .936 r
F P
0 g
s
.58462 .63077 m .58732 .63685 L .51786 .64323 L p .66 .778 .936 r
F P
0 g
s
.37116 .6317 m .36521 .63435 L .29943 .6068 L p .469 .734 .985 r
F P
0 g
s
.58732 .63685 m .58462 .63077 L .6479 .61445 L p .673 .757 .914 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58732 .63685 L p .673 .757 .914 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72139 .60113 L p .658 .721 .895 r
F P
0 g
s
.72139 .60113 m .72971 .60722 L .66471 .63279 L p .658 .721 .895 r
F P
0 g
s
.37718 .62889 m .38326 .62566 L .44866 .63948 L p .559 .777 .98 r
F P
0 g
s
.45196 .63457 m .44866 .63948 L .38326 .62566 L p .593 .779 .969 r
F P
0 g
s
.44866 .63948 m .45196 .63457 L .51817 .63758 L p .632 .787 .956 r
F P
0 g
s
.51849 .6314 m .51817 .63758 L .45196 .63457 L p .652 .78 .942 r
F P
0 g
s
.51817 .63758 m .51849 .6314 L .58189 .62439 L p .67 .773 .927 r
F P
0 g
s
.58189 .62439 m .58462 .63077 L .51817 .63758 L p .67 .773 .927 r
F P
0 g
s
.29943 .6068 m .30795 .60551 L .37116 .6317 L p .469 .734 .985 r
F P
0 g
s
.37718 .62889 m .37116 .6317 L .30795 .60551 L p .481 .739 .984 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71302 .59512 L p .664 .726 .895 r
F P
0 g
s
.71302 .59512 m .72139 .60113 L .65915 .62672 L p .664 .726 .895 r
F P
0 g
s
.58462 .63077 m .58189 .62439 L .64221 .60824 L p .677 .758 .912 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58462 .63077 L p .677 .758 .912 r
F P
0 g
s
.38326 .62566 m .38943 .62176 L .45196 .63457 L p .593 .779 .969 r
F P
0 g
s
.4553 .62893 m .45196 .63457 L .38943 .62176 L p .628 .776 .952 r
F P
0 g
s
.45196 .63457 m .4553 .62893 L .51849 .6314 L p .652 .78 .942 r
F P
0 g
s
.51881 .6246 m .51849 .6314 L .4553 .62893 L p .669 .77 .926 r
F P
0 g
s
.51849 .6314 m .51881 .6246 L .57913 .61766 L p .677 .767 .918 r
F P
0 g
s
.57913 .61766 m .58189 .62439 L .51849 .6314 L p .677 .767 .918 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70461 .58926 L p .669 .732 .897 r
F P
0 g
s
.70461 .58926 m .71302 .59512 L .65355 .62061 L p .669 .732 .897 r
F P
0 g
s
.30795 .60551 m .31654 .60408 L .37718 .62889 L p .481 .739 .984 r
F P
0 g
s
.38326 .62566 m .37718 .62889 L .31654 .60408 L p .513 .748 .98 r
F P
0 g
s
.58189 .62439 m .57913 .61766 L .63648 .60198 L p .681 .759 .911 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58189 .62439 L p .681 .759 .911 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69617 .58362 L p .675 .74 .9 r
F P
0 g
s
.69617 .58362 m .70461 .58926 L .6479 .61445 L p .675 .74 .9 r
F P
0 g
s
.38943 .62176 m .39568 .61699 L .4553 .62893 L p .628 .776 .952 r
F P
0 g
s
.4587 .62244 m .4553 .62893 L .39568 .61699 L p .659 .769 .931 r
F P
0 g
s
.4553 .62893 m .4587 .62244 L .51881 .6246 L p .669 .77 .926 r
F P
0 g
s
.51913 .61712 m .51881 .6246 L .4587 .62244 L p .683 .759 .909 r
F P
0 g
s
.51881 .6246 m .51913 .61712 L .57635 .61056 L p .683 .759 .909 r
F P
0 g
s
.57635 .61056 m .57913 .61766 L .51881 .6246 L p .683 .759 .909 r
F P
0 g
s
.73799 .61332 m .72971 .60722 L .78387 .57256 L p .636 .691 .884 r
F P
0 g
s
.78387 .57256 m .79464 .57831 L .73799 .61332 L p .636 .691 .884 r
F P
0 g
s
.31654 .60408 m .32523 .60218 L .38326 .62566 L p .513 .748 .98 r
F P
0 g
s
.38943 .62176 m .38326 .62566 L .32523 .60218 L p .558 .757 .971 r
F P
0 g
s
.57913 .61766 m .57635 .61056 L .6307 .59568 L p .683 .76 .91 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57913 .61766 L p .683 .76 .91 r
F P
0 g
s
.72971 .60722 m .72139 .60113 L .77307 .56688 L p .641 .693 .883 r
F P
0 g
s
.77307 .56688 m .78387 .57256 L .72971 .60722 L p .641 .693 .883 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68769 .57824 L p .679 .75 .904 r
F P
0 g
s
.68769 .57824 m .69617 .58362 L .64221 .60824 L p .679 .75 .904 r
F P
0 g
s
.39568 .61699 m .40202 .6112 L .4587 .62244 L p .659 .769 .931 r
F P
0 g
s
.46213 .61503 m .4587 .62244 L .40202 .6112 L p .684 .759 .908 r
F P
0 g
s
.4587 .62244 m .46213 .61503 L .51913 .61712 L p .683 .759 .909 r
F P
0 g
s
.51946 .60898 m .51913 .61712 L .46213 .61503 L p .693 .747 .892 r
F P
0 g
s
.51913 .61712 m .51946 .60898 L .57353 .60309 L p .686 .751 .901 r
F P
0 g
s
.57353 .60309 m .57635 .61056 L .51913 .61712 L p .686 .751 .901 r
F P
0 g
s
.30795 .60551 m .29943 .6068 L .24558 .56996 L p .451 .697 .972 r
F P
0 g
s
.57635 .61056 m .57353 .60309 L .62488 .58932 L p .682 .76 .91 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57635 .61056 L p .682 .76 .91 r
F P
0 g
s
.32523 .60218 m .33404 .59956 L .38943 .62176 L p .558 .757 .971 r
F P
0 g
s
.39568 .61699 m .38943 .62176 L .33404 .59956 L p .606 .762 .954 r
F P
0 g
s
.72139 .60113 m .71302 .59512 L .76224 .5614 L p .647 .699 .884 r
F P
0 g
s
.76224 .5614 m .77307 .56688 L .72139 .60113 L p .647 .699 .884 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67916 .57313 L p .683 .761 .91 r
F P
0 g
s
.67916 .57313 m .68769 .57824 L .63648 .60198 L p .683 .761 .91 r
F P
0 g
s
.40202 .6112 m .40844 .6043 L .46213 .61503 L p .684 .759 .908 r
F P
0 g
s
.46561 .6067 m .46213 .61503 L .40844 .6043 L p .702 .748 .887 r
F P
0 g
s
.46213 .61503 m .46561 .6067 L .51946 .60898 L p .693 .747 .892 r
F P
0 g
s
.51979 .60022 m .51946 .60898 L .46561 .6067 L p .699 .735 .878 r
F P
0 g
s
.51946 .60898 m .51979 .60022 L .57069 .59527 L p .686 .742 .894 r
F P
0 g
s
.57069 .59527 m .57353 .60309 L .51946 .60898 L p .686 .742 .894 r
F P
0 g
s
.24558 .56996 m .25635 .5702 L .30795 .60551 L p .451 .697 .972 r
F P
0 g
s
.31654 .60408 m .30795 .60551 L .25635 .5702 L p .462 .702 .971 r
F P
0 g
s
.71302 .59512 m .70461 .58926 L .7514 .55627 L p .655 .709 .887 r
F P
0 g
s
.7514 .55627 m .76224 .5614 L .71302 .59512 L p .655 .709 .887 r
F P
0 g
s
.57353 .60309 m .57069 .59527 L .61901 .58292 L p .68 .759 .911 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57353 .60309 L p .68 .759 .911 r
F P
0 g
s
.33404 .59956 m .34296 .59597 L .39568 .61699 L p .606 .762 .954 r
F P
0 g
s
.40202 .6112 m .39568 .61699 L .34296 .59597 L p .65 .763 .932 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .6706 .56831 L p .684 .771 .917 r
F P
0 g
s
.6706 .56831 m .67916 .57313 L .6307 .59568 L p .684 .771 .917 r
F P
0 g
s
.40844 .6043 m .41495 .59629 L .46561 .6067 L p .702 .748 .887 r
F P
0 g
s
.46913 .59753 m .46561 .6067 L .41495 .59629 L p .715 .736 .868 r
F P
0 g
s
.46561 .6067 m .46913 .59753 L .51979 .60022 L p .699 .735 .878 r
F P
0 g
s
.70461 .58926 m .69617 .58362 L .74054 .55161 L p .665 .724 .893 r
F P
0 g
s
.74054 .55161 m .7514 .55627 L .70461 .58926 L p .665 .724 .893 r
F P
0 g
s
.52013 .59092 m .51979 .60022 L .46913 .59753 L p .701 .724 .867 r
F P
0 g
s
.51979 .60022 m .52013 .59092 L .56782 .58714 L p .684 .734 .888 r
F P
0 g
s
.56782 .58714 m .57069 .59527 L .51979 .60022 L p .684 .734 .888 r
F P
0 g
s
.25635 .5702 m .2672 .57029 L .31654 .60408 L p .462 .702 .971 r
F P
0 g
s
.32523 .60218 m .31654 .60408 L .2672 .57029 L p .495 .714 .969 r
F P
0 g
s
.34296 .59597 m .352 .59125 L .40202 .6112 L p .65 .763 .932 r
F P
0 g
s
.40844 .6043 m .40202 .6112 L .352 .59125 L p .685 .759 .908 r
F P
0 g
s
.57069 .59527 m .56782 .58714 L .61309 .57646 L p .675 .757 .913 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57069 .59527 L p .675 .757 .913 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66198 .56374 L p .682 .781 .925 r
F P
0 g
s
.66198 .56374 m .6706 .56831 L .62488 .58932 L p .682 .781 .925 r
F P
0 g
s
.69617 .58362 m .68769 .57824 L .72968 .54749 L p .674 .741 .901 r
F P
0 g
s
.72968 .54749 m .74054 .55161 L .69617 .58362 L p .674 .741 .901 r
F P
0 g
s
.41495 .59629 m .42153 .58726 L .46913 .59753 L p .715 .736 .868 r
F P
0 g
s
.47269 .58763 m .46913 .59753 L .42153 .58726 L p .722 .726 .854 r
F P
0 g
s
.46913 .59753 m .47269 .58763 L .52013 .59092 L p .701 .724 .867 r
F P
0 g
s
.52047 .58123 m .52013 .59092 L .47269 .58763 L p .7 .714 .86 r
F P
0 g
s
.52013 .59092 m .52047 .58123 L .56493 .57878 L p .679 .726 .885 r
F P
0 g
s
.56493 .57878 m .56782 .58714 L .52013 .59092 L p .679 .726 .885 r
F P
0 g
s
.2672 .57029 m .27816 .56991 L .32523 .60218 L p .495 .714 .969 r
F P
0 g
s
.33404 .59956 m .32523 .60218 L .27816 .56991 L p .542 .73 .961 r
F P
0 g
s
.352 .59125 m .36115 .5853 L .40844 .6043 L p .685 .759 .908 r
F P
0 g
s
.41495 .59629 m .40844 .6043 L .36115 .5853 L p .711 .753 .885 r
F P
0 g
s
.56782 .58714 m .56493 .57878 L .60713 .56996 L p .666 .755 .916 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56782 .58714 L p .666 .755 .916 r
F P
0 g
s
.68769 .57824 m .67916 .57313 L .7188 .54397 L p .683 .761 .911 r
F P
0 g
s
.7188 .54397 m .72968 .54749 L .68769 .57824 L p .683 .761 .911 r
F P
0 g
s
.42153 .58726 m .42817 .57738 L .47269 .58763 L p .722 .726 .854 r
F P
0 g
s
.47627 .57719 m .47269 .58763 L .42817 .57738 L p .724 .717 .844 r
F P
0 g
s
.47269 .58763 m .47627 .57719 L .52047 .58123 L p .7 .714 .86 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65332 .55939 L p .677 .79 .934 r
F P
0 g
s
.65332 .55939 m .66198 .56374 L .61901 .58292 L p .677 .79 .934 r
F P
0 g
s
.52081 .57128 m .52047 .58123 L .47627 .57719 L p .695 .706 .856 r
F P
0 g
s
.52047 .58123 m .52081 .57128 L .56201 .57026 L p .671 .719 .885 r
F P
0 g
s
.56201 .57026 m .56493 .57878 L .52047 .58123 L p .671 .719 .885 r
F P
0 g
s
.36115 .5853 m .37041 .57814 L .41495 .59629 L p .711 .753 .885 r
F P
0 g
s
.42153 .58726 m .41495 .59629 L .37041 .57814 L p .73 .746 .865 r
F P
0 g
s
.27816 .56991 m .28923 .56879 L .33404 .59956 L p .542 .73 .961 r
F P
0 g
s
.34296 .59597 m .33404 .59956 L .28923 .56879 L p .595 .744 .948 r
F P
0 g
s
.56493 .57878 m .56201 .57026 L .60112 .5634 L p .654 .751 .921 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57878 L p .654 .751 .921 r
F P
0 g
s
.67916 .57313 m .6706 .56831 L .7079 .54104 L p .691 .782 .921 r
F P
0 g
s
.7079 .54104 m .7188 .54397 L .67916 .57313 L p .691 .782 .921 r
F P
0 g
s
.79464 .57831 m .78387 .57256 L .82343 .53023 L p .609 .669 .882 r
F P
0 g
s
.82343 .53023 m .83625 .53514 L .79464 .57831 L p .609 .669 .882 r
F P
0 g
s
.42817 .57738 m .43486 .56686 L .47627 .57719 L p .724 .717 .844 r
F P
0 g
s
.47989 .56644 m .47627 .57719 L .43486 .56686 L p .723 .71 .838 r
F P
0 g
s
.47627 .57719 m .47989 .56644 L .52081 .57128 L p .695 .706 .856 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .6446 .55517 L p .668 .796 .943 r
F P
0 g
s
.6446 .55517 m .65332 .55939 L .61309 .57646 L p .668 .796 .943 r
F P
0 g
s
.37041 .57814 m .37977 .56985 L .42153 .58726 L p .73 .746 .865 r
F P
0 g
s
.42817 .57738 m .42153 .58726 L .37977 .56985 L p .742 .739 .849 r
F P
0 g
s
.52115 .56127 m .52081 .57128 L .47989 .56644 L p .687 .699 .856 r
F P
0 g
s
.52081 .57128 m .52115 .56127 L .55907 .56168 L p .659 .712 .887 r
F P
0 g
s
.55907 .56168 m .56201 .57026 L .52081 .57128 L p .659 .712 .887 r
F P
0 g
s
.78387 .57256 m .77307 .56688 L .81061 .52543 L p .614 .671 .881 r
F P
0 g
s
.81061 .52543 m .82343 .53023 L .78387 .57256 L p .614 .671 .881 r
F P
0 g
s
.28923 .56879 m .30044 .56667 L .34296 .59597 L p .595 .744 .948 r
F P
0 g
s
.352 .59125 m .34296 .59597 L .30044 .56667 L p .644 .754 .929 r
F P
0 g
s
.6706 .56831 m .66198 .56374 L .69697 .53866 L p .695 .803 .932 r
F P
0 g
s
.69697 .53866 m .7079 .54104 L .6706 .56831 L p .695 .803 .932 r
F P
0 g
s
.43486 .56686 m .4416 .55599 L .47989 .56644 L p .723 .71 .838 r
F P
0 g
s
.48352 .55564 m .47989 .56644 L .4416 .55599 L p .718 .705 .837 r
F P
0 g
s
.47989 .56644 m .48352 .55564 L .52115 .56127 L p .687 .699 .856 r
F P
0 g
s
.56201 .57026 m .55907 .56168 L .59506 .55679 L p .639 .746 .926 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56201 .57026 L p .639 .746 .926 r
F P
0 g
s
.77307 .56688 m .76224 .5614 L .7978 .52094 L p .623 .679 .883 r
F P
0 g
s
.7978 .52094 m .81061 .52543 L .77307 .56688 L p .623 .679 .883 r
F P
0 g
s
.37977 .56985 m .3892 .56062 L .42817 .57738 L p .742 .739 .849 r
F P
0 g
s
.43486 .56686 m .42817 .57738 L .3892 .56062 L p .748 .734 .839 r
F P
0 g
s
.25635 .5702 m .24558 .56996 L .20758 .52532 L p .47 .671 .951 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63582 .55101 L p .654 .798 .951 r
F P
0 g
s
.63582 .55101 m .6446 .55517 L .60713 .56996 L p .654 .798 .951 r
F P
0 g
s
.30044 .56667 m .31179 .56338 L .352 .59125 L p .644 .754 .929 r
F P
0 g
s
.36115 .5853 m .352 .59125 L .31179 .56338 L p .685 .76 .908 r
F P
0 g
s
.5215 .55138 m .52115 .56127 L .48352 .55564 L p .675 .694 .86 r
F P
0 g
s
.52115 .56127 m .5215 .55138 L .55611 .55313 L p .644 .706 .892 r
F P
0 g
s
.55611 .55313 m .55907 .56168 L .52115 .56127 L p .644 .706 .892 r
F P
0 g
s
.76224 .5614 m .7514 .55627 L .78502 .51698 L p .635 .693 .887 r
F P
0 g
s
.78502 .51698 m .7978 .52094 L .76224 .5614 L p .635 .693 .887 r
F P
0 g
s
.3892 .56062 m .39869 .55071 L .43486 .56686 L p .748 .734 .839 r
F P
0 g
s
.4416 .55599 m .43486 .56686 L .39869 .55071 L p .75 .729 .833 r
F P
0 g
s
.4416 .55599 m .44837 .54507 L .48352 .55564 L p .718 .705 .837 r
F P
0 g
s
.48718 .54503 m .48352 .55564 L .44837 .54507 L p .708 .701 .841 r
F P
0 g
s
.48352 .55564 m .48718 .54503 L .5215 .55138 L p .675 .694 .86 r
F P
0 g
s
.66198 .56374 m .65332 .55939 L .686 .53674 L p .695 .822 .943 r
F P
0 g
s
.686 .53674 m .69697 .53866 L .66198 .56374 L p .695 .822 .943 r
F P
0 g
s
.7514 .55627 m .74054 .55161 L .77227 .51371 L p .649 .712 .893 r
F P
0 g
s
.77227 .51371 m .78502 .51698 L .7514 .55627 L p .649 .712 .893 r
F P
0 g
s
.55907 .56168 m .55611 .55313 L .58896 .55013 L p .619 .739 .932 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55907 .56168 L p .619 .739 .932 r
F P
0 g
s
.31179 .56338 m .32325 .55883 L .36115 .5853 L p .685 .76 .908 r
F P
0 g
s
.37041 .57814 m .36115 .5853 L .32325 .55883 L p .718 .762 .887 r
F P
0 g
s
.20758 .52532 m .22014 .5272 L .25635 .5702 L p .47 .671 .951 r
F P
0 g
s
.2672 .57029 m .25635 .5702 L .22014 .5272 L p .48 .675 .951 r
F P
0 g
s
.39869 .55071 m .40823 .54043 L .4416 .55599 L p .75 .729 .833 r
F P
0 g
s
.44837 .54507 m .4416 .55599 L .40823 .54043 L p .747 .725 .832 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62697 .54682 L p .636 .796 .959 r
F P
0 g
s
.62697 .54682 m .63582 .55101 L .60112 .5634 L p .636 .796 .959 r
F P
0 g
s
.52185 .54178 m .5215 .55138 L .48718 .54503 L p .659 .69 .867 r
F P
0 g
s
.5215 .55138 m .52185 .54178 L .55312 .54469 L p .624 .699 .899 r
F P
0 g
s
.55312 .54469 m .55611 .55313 L .5215 .55138 L p .624 .699 .899 r
F P
0 g
s
.74054 .55161 m .72968 .54749 L .75955 .51124 L p .666 .735 .901 r
F P
0 g
s
.75955 .51124 m .77227 .51371 L .74054 .55161 L p .666 .735 .901 r
F P
0 g
s
.44837 .54507 m .45516 .53443 L .48718 .54503 L p .708 .701 .841 r
F P
0 g
s
.49085 .53487 m .48718 .54503 L .45516 .53443 L p .694 .698 .849 r
F P
0 g
s
.48718 .54503 m .49085 .53487 L .52185 .54178 L p .659 .69 .867 r
F P
0 g
s
.32325 .55883 m .33484 .55303 L .37041 .57814 L p .718 .762 .887 r
F P
0 g
s
.37977 .56985 m .37041 .57814 L .33484 .55303 L p .742 .762 .869 r
F P
0 g
s
.65332 .55939 m .6446 .55517 L .67497 .53514 L p .69 .837 .953 r
F P
0 g
s
.67497 .53514 m .686 .53674 L .65332 .55939 L p .69 .837 .953 r
F P
0 g
s
.40823 .54043 m .4178 .53014 L .44837 .54507 L p .747 .725 .832 r
F P
0 g
s
.45516 .53443 m .44837 .54507 L .4178 .53014 L p .739 .722 .835 r
F P
0 g
s
.55611 .55313 m .55312 .54469 L .5828 .54342 L p .595 .73 .938 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55611 .55313 L p .595 .73 .938 r
F P
0 g
s
.22014 .5272 m .23277 .52894 L .2672 .57029 L p .48 .675 .951 r
F P
0 g
s
.27816 .56991 m .2672 .57029 L .23277 .52894 L p .508 .688 .949 r
F P
0 g
s
.72968 .54749 m .7188 .54397 L .74687 .50964 L p .684 .762 .911 r
F P
0 g
s
.74687 .50964 m .75955 .51124 L .72968 .54749 L p .684 .762 .911 r
F P
0 g
s
.33484 .55303 m .34652 .54607 L .37977 .56985 L p .742 .762 .869 r
F P
0 g
s
.3892 .56062 m .37977 .56985 L .34652 .54607 L p .759 .761 .854 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61805 .5425 L p .612 .789 .966 r
F P
0 g
s
.61805 .5425 m .62697 .54682 L .59506 .55679 L p .612 .789 .966 r
F P
0 g
s
.5222 .53262 m .52185 .54178 L .49085 .53487 L p .638 .686 .878 r
F P
0 g
s
.52185 .54178 m .5222 .53262 L .55011 .53646 L p .6 .693 .908 r
F P
0 g
s
.55011 .53646 m .55312 .54469 L .52185 .54178 L p .6 .693 .908 r
F P
0 g
s
.45516 .53443 m .46198 .52437 L .49085 .53487 L p .694 .698 .849 r
F P
0 g
s
.49455 .52537 m .49085 .53487 L .46198 .52437 L p .675 .695 .861 r
F P
0 g
s
.49085 .53487 m .49455 .52537 L .5222 .53262 L p .638 .686 .878 r
F P
0 g
s
.6446 .55517 m .63582 .55101 L .66389 .5337 L p .679 .846 .963 r
F P
0 g
s
.66389 .5337 m .67497 .53514 L .6446 .55517 L p .679 .846 .963 r
F P
0 g
s
.4178 .53014 m .42739 .52018 L .45516 .53443 L p .739 .722 .835 r
F P
0 g
s
.46198 .52437 m .45516 .53443 L .42739 .52018 L p .727 .72 .844 r
F P
0 g
s
.7188 .54397 m .7079 .54104 L .73419 .5089 L p .7 .79 .92 r
F P
0 g
s
.73419 .5089 m .74687 .50964 L .7188 .54397 L p .7 .79 .92 r
F P
0 g
s
.34652 .54607 m .35827 .53816 L .3892 .56062 L p .759 .761 .854 r
F P
0 g
s
.39869 .55071 m .3892 .56062 L .35827 .53816 L p .769 .759 .844 r
F P
0 g
s
.23277 .52894 m .24549 .53024 L .27816 .56991 L p .508 .688 .949 r
F P
0 g
s
.28923 .56879 m .27816 .56991 L .24549 .53024 L p .549 .707 .944 r
F P
0 g
s
.55312 .54469 m .55011 .53646 L .5766 .53665 L p .567 .719 .944 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55312 .54469 L p .567 .719 .944 r
F P
0 g
s
.35827 .53816 m .37008 .52955 L .39869 .55071 L p .769 .759 .844 r
F P
0 g
s
.40823 .54043 m .39869 .55071 L .37008 .52955 L p .773 .758 .839 r
F P
0 g
s
.42739 .52018 m .43699 .51089 L .46198 .52437 L p .727 .72 .844 r
F P
0 g
s
.46882 .51516 m .46198 .52437 L .43699 .51089 L p .707 .718 .857 r
F P
0 g
s
.46198 .52437 m .46882 .51516 L .49455 .52537 L p .675 .695 .861 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60906 .53795 L p .584 .778 .972 r
F P
0 g
s
.60906 .53795 m .61805 .5425 L .58896 .55013 L p .584 .778 .972 r
F P
0 g
s
.7079 .54104 m .69697 .53866 L .72152 .50896 L p .714 .817 .929 r
F P
0 g
s
.72152 .50896 m .73419 .5089 L .7079 .54104 L p .714 .817 .929 r
F P
0 g
s
.52255 .52403 m .5222 .53262 L .49455 .52537 L p .611 .681 .892 r
F P
0 g
s
.5222 .53262 m .52255 .52403 L .54708 .5285 L p .571 .685 .918 r
F P
0 g
s
.54708 .5285 m .55011 .53646 L .5222 .53262 L p .571 .685 .918 r
F P
0 g
s
.49826 .51671 m .49455 .52537 L .46882 .51516 L p .648 .692 .877 r
F P
0 g
s
.49455 .52537 m .49826 .51671 L .52255 .52403 L p .611 .681 .892 r
F P
0 g
s
.24549 .53024 m .25833 .5308 L .28923 .56879 L p .549 .707 .944 r
F P
0 g
s
.30044 .56667 m .28923 .56879 L .25833 .5308 L p .596 .727 .935 r
F P
0 g
s
.37008 .52955 m .38192 .52059 L .40823 .54043 L p .773 .758 .839 r
F P
0 g
s
.4178 .53014 m .40823 .54043 L .38192 .52059 L p .772 .756 .839 r
F P
0 g
s
.63582 .55101 m .62697 .54682 L .65273 .53225 L p .661 .849 .972 r
F P
0 g
s
.65273 .53225 m .66389 .5337 L .63582 .55101 L p .661 .849 .972 r
F P
0 g
s
.38192 .52059 m .39377 .51163 L .4178 .53014 L p .772 .756 .839 r
F P
0 g
s
.42739 .52018 m .4178 .53014 L .39377 .51163 L p .766 .755 .843 r
F P
0 g
s
.55011 .53646 m .54708 .5285 L .57035 .52982 L p .535 .705 .949 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55011 .53646 L p .535 .705 .949 r
F P
0 g
s
.43699 .51089 m .4466 .50257 L .46882 .51516 L p .707 .718 .857 r
F P
0 g
s
.47569 .50699 m .46882 .51516 L .4466 .50257 L p .68 .714 .874 r
F P
0 g
s
.46882 .51516 m .47569 .50699 L .49826 .51671 L p .648 .692 .877 r
F P
0 g
s
.69697 .53866 m .686 .53674 L .70884 .50969 L p .724 .842 .937 r
F P
0 g
s
.70884 .50969 m .72152 .50896 L .69697 .53866 L p .724 .842 .937 r
F P
0 g
s
.25833 .5308 m .27128 .53041 L .30044 .56667 L p .596 .727 .935 r
F P
0 g
s
.31179 .56338 m .30044 .56667 L .27128 .53041 L p .643 .745 .923 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .6 .5331 L p .552 .761 .975 r
F P
0 g
s
.6 .5331 m .60906 .53795 L .5828 .54342 L p .552 .761 .975 r
F P
0 g
s
.39377 .51163 m .40563 .50305 L .42739 .52018 L p .766 .755 .843 r
F P
0 g
s
.43699 .51089 m .42739 .52018 L .40563 .50305 L p .753 .753 .852 r
F P
0 g
s
.502 .509 m .49826 .51671 L .47569 .50699 L p .614 .687 .895 r
F P
0 g
s
.49826 .51671 m .502 .509 L .52291 .51609 L p .577 .675 .907 r
F P
0 g
s
.52291 .51609 m .52255 .52403 L .49826 .51671 L p .577 .675 .907 r
F P
0 g
s
.52255 .52403 m .52291 .51609 L .54403 .52084 L p .536 .676 .928 r
F P
0 g
s
.54403 .52084 m .54708 .5285 L .52255 .52403 L p .536 .676 .928 r
F P
0 g
s
.62697 .54682 m .61805 .5425 L .6415 .53059 L p .637 .844 .98 r
F P
0 g
s
.6415 .53059 m .65273 .53225 L .62697 .54682 L p .637 .844 .98 r
F P
0 g
s
.27128 .53041 m .28436 .52888 L .31179 .56338 L p .643 .745 .923 r
F P
0 g
s
.32325 .55883 m .31179 .56338 L .28436 .52888 L p .686 .761 .909 r
F P
0 g
s
.686 .53674 m .67497 .53514 L .69612 .5109 L p .727 .862 .945 r
F P
0 g
s
.69612 .5109 m .70884 .50969 L .686 .53674 L p .727 .862 .945 r
F P
0 g
s
.40563 .50305 m .41748 .49518 L .43699 .51089 L p .753 .753 .852 r
F P
0 g
s
.4466 .50257 m .43699 .51089 L .41748 .49518 L p .733 .75 .866 r
F P
0 g
s
.4466 .50257 m .45623 .49545 L .47569 .50699 L p .68 .714 .874 r
F P
0 g
s
.48259 .50001 m .47569 .50699 L .45623 .49545 L p .644 .708 .894 r
F P
0 g
s
.47569 .50699 m .48259 .50001 L .502 .509 L p .614 .687 .895 r
F P
0 g
s
.54708 .5285 m .54403 .52084 L .56404 .52294 L p .501 .69 .952 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54708 .5285 L p .501 .69 .952 r
F P
0 g
s
.28436 .52888 m .29755 .52614 L .32325 .55883 L p .686 .761 .909 r
F P
0 g
s
.33484 .55303 m .32325 .55883 L .29755 .52614 L p .721 .773 .893 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59087 .52787 L p .518 .741 .975 r
F P
0 g
s
.59087 .52787 m .6 .5331 L .5766 .53665 L p .518 .741 .975 r
F P
0 g
s
.61805 .5425 m .60906 .53795 L .63018 .52855 L p .607 .831 .985 r
F P
0 g
s
.63018 .52855 m .6415 .53059 L .61805 .5425 L p .607 .831 .985 r
F P
0 g
s
.41748 .49518 m .42931 .48835 L .4466 .50257 L p .733 .75 .866 r
F P
0 g
s
.45623 .49545 m .4466 .50257 L .42931 .48835 L p .703 .745 .884 r
F P
0 g
s
.50576 .50228 m .502 .509 L .48259 .50001 L p .569 .679 .914 r
F P
0 g
s
.502 .509 m .50576 .50228 L .52327 .50883 L p .535 .667 .922 r
F P
0 g
s
.52327 .50883 m .52291 .51609 L .502 .509 L p .535 .667 .922 r
F P
0 g
s
.83625 .53514 m .82343 .53023 L .84485 .48226 L p .577 .657 .891 r
F P
0 g
s
.84485 .48226 m .85906 .48583 L .83625 .53514 L p .577 .657 .891 r
F P
0 g
s
.29755 .52614 m .31084 .52219 L .33484 .55303 L p .721 .773 .893 r
F P
0 g
s
.34652 .54607 m .33484 .55303 L .31084 .52219 L p .749 .781 .879 r
F P
0 g
s
.52291 .51609 m .52327 .50883 L .54095 .5135 L p .497 .665 .937 r
F P
0 g
s
.54095 .5135 m .54403 .52084 L .52291 .51609 L p .497 .665 .937 r
F P
0 g
s
.67497 .53514 m .66389 .5337 L .68336 .51237 L p .723 .876 .952 r
F P
0 g
s
.68336 .51237 m .69612 .5109 L .67497 .53514 L p .723 .876 .952 r
F P
0 g
s
.82343 .53023 m .81061 .52543 L .83069 .47883 L p .582 .659 .89 r
F P
0 g
s
.83069 .47883 m .84485 .48226 L .82343 .53023 L p .582 .659 .89 r
F P
0 g
s
.81061 .52543 m .7978 .52094 L .81659 .47581 L p .594 .669 .892 r
F P
0 g
s
.81659 .47581 m .83069 .47883 L .81061 .52543 L p .594 .669 .892 r
F P
0 g
s
.31084 .52219 m .32421 .51713 L .34652 .54607 L p .749 .781 .879 r
F P
0 g
s
.35827 .53816 m .34652 .54607 L .32421 .51713 L p .769 .787 .868 r
F P
0 g
s
.45623 .49545 m .46589 .48968 L .48259 .50001 L p .644 .708 .894 r
F P
0 g
s
.48953 .49428 m .48259 .50001 L .46589 .48968 L p .596 .698 .915 r
F P
0 g
s
.48259 .50001 m .48953 .49428 L .50576 .50228 L p .569 .679 .914 r
F P
0 g
s
.7978 .52094 m .78502 .51698 L .80256 .47345 L p .611 .685 .895 r
F P
0 g
s
.80256 .47345 m .81659 .47581 L .7978 .52094 L p .611 .685 .895 r
F P
0 g
s
.42931 .48835 m .44115 .48278 L .45623 .49545 L p .703 .745 .884 r
F P
0 g
s
.46589 .48968 m .45623 .49545 L .44115 .48278 L p .663 .737 .904 r
F P
0 g
s
.32421 .51713 m .33764 .51115 L .35827 .53816 L p .769 .787 .868 r
F P
0 g
s
.37008 .52955 m .35827 .53816 L .33764 .51115 L p .782 .791 .86 r
F P
0 g
s
.78502 .51698 m .77227 .51371 L .78862 .47194 L p .633 .707 .9 r
F P
0 g
s
.78862 .47194 m .80256 .47345 L .78502 .51698 L p .633 .707 .9 r
F P
0 g
s
.54403 .52084 m .54095 .5135 L .55769 .51601 L p .464 .673 .954 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54403 .52084 L p .464 .673 .954 r
F P
0 g
s
.33764 .51115 m .35109 .50452 L .37008 .52955 L p .782 .791 .86 r
F P
0 g
s
.38192 .52059 m .37008 .52955 L .35109 .50452 L p .789 .794 .857 r
F P
0 g
s
.60906 .53795 m .6 .5331 L .61878 .52596 L p .573 .811 .989 r
F P
0 g
s
.61878 .52596 m .63018 .52855 L .60906 .53795 L p .573 .811 .989 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58167 .52223 L p .482 .717 .974 r
F P
0 g
s
.58167 .52223 m .59087 .52787 L .57035 .52982 L p .482 .717 .974 r
F P
0 g
s
.35109 .50452 m .36456 .49755 L .38192 .52059 L p .789 .794 .857 r
F P
0 g
s
.39377 .51163 m .38192 .52059 L .36456 .49755 L p .789 .796 .858 r
F P
0 g
s
.77227 .51371 m .75955 .51124 L .77476 .47144 L p .658 .733 .905 r
F P
0 g
s
.77476 .47144 m .78862 .47194 L .77227 .51371 L p .658 .733 .905 r
F P
0 g
s
.66389 .5337 m .65273 .53225 L .67053 .51383 L p .711 .883 .96 r
F P
0 g
s
.67053 .51383 m .68336 .51237 L .66389 .5337 L p .711 .883 .96 r
F P
0 g
s
.36456 .49755 m .37801 .49061 L .39377 .51163 L p .789 .796 .858 r
F P
0 g
s
.40563 .50305 m .39377 .51163 L .37801 .49061 L p .783 .796 .863 r
F P
0 g
s
.50955 .49654 m .50576 .50228 L .48953 .49428 L p .516 .667 .931 r
F P
0 g
s
.50576 .50228 m .50955 .49654 L .52363 .50223 L p .487 .656 .935 r
F P
0 g
s
.52363 .50223 m .52327 .50883 L .50576 .50228 L p .487 .656 .935 r
F P
0 g
s
.75955 .51124 m .74687 .50964 L .76098 .47202 L p .685 .762 .91 r
F P
0 g
s
.76098 .47202 m .77476 .47144 L .75955 .51124 L p .685 .762 .91 r
F P
0 g
s
.37801 .49061 m .39143 .48404 L .40563 .50305 L p .783 .796 .863 r
F P
0 g
s
.41748 .49518 m .40563 .50305 L .39143 .48404 L p .769 .794 .874 r
F P
0 g
s
.52327 .50883 m .52363 .50223 L .53784 .50648 L p .455 .651 .944 r
F P
0 g
s
.53784 .50648 m .54095 .5135 L .52327 .50883 L p .455 .651 .944 r
F P
0 g
s
.44115 .48278 m .45299 .47864 L .46589 .48968 L p .663 .737 .904 r
F P
0 g
s
.47559 .48533 m .46589 .48968 L .45299 .47864 L p .611 .722 .924 r
F P
0 g
s
.46589 .48968 m .47559 .48533 L .48953 .49428 L p .596 .698 .915 r
F P
0 g
s
.49651 .48977 m .48953 .49428 L .47559 .48533 L p .537 .683 .932 r
F P
0 g
s
.48953 .49428 m .49651 .48977 L .50955 .49654 L p .516 .667 .931 r
F P
0 g
s
.39143 .48404 m .40481 .47819 L .41748 .49518 L p .769 .794 .874 r
F P
0 g
s
.42931 .48835 m .41748 .49518 L .40481 .47819 L p .746 .79 .888 r
F P
0 g
s
.22014 .5272 m .20758 .52532 L .18911 .47507 L p .51 .66 .928 r
F P
0 g
s
.74687 .50964 m .73419 .5089 L .74726 .47368 L p .711 .791 .914 r
F P
0 g
s
.74726 .47368 m .76098 .47202 L .74687 .50964 L p .711 .791 .914 r
F P
0 g
s
.6 .5331 m .59087 .52787 L .60729 .5227 L p .535 .785 .99 r
F P
0 g
s
.60729 .5227 m .61878 .52596 L .6 .5331 L p .535 .785 .99 r
F P
0 g
s
.65273 .53225 m .6415 .53059 L .65763 .51502 L p .692 .881 .969 r
F P
0 g
s
.65763 .51502 m .67053 .51383 L .65273 .53225 L p .692 .881 .969 r
F P
0 g
s
.40481 .47819 m .41816 .47336 L .42931 .48835 L p .746 .79 .888 r
F P
0 g
s
.44115 .48278 m .42931 .48835 L .41816 .47336 L p .713 .781 .906 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .5724 .51615 L p .447 .692 .97 r
F P
0 g
s
.5724 .51615 m .58167 .52223 L .56404 .52294 L p .447 .692 .97 r
F P
0 g
s
.54095 .5135 m .53784 .50648 L .55128 .50901 L p .428 .655 .954 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54095 .5135 L p .428 .655 .954 r
F P
0 g
s
.73419 .5089 m .72152 .50896 L .73359 .47632 L p .734 .819 .918 r
F P
0 g
s
.73359 .47632 m .74726 .47368 L .73419 .5089 L p .734 .819 .918 r
F P
0 g
s
.18911 .47507 m .20281 .47866 L .22014 .5272 L p .51 .66 .928 r
F P
0 g
s
.23277 .52894 m .22014 .5272 L .20281 .47866 L p .518 .663 .927 r
F P
0 g
s
.41816 .47336 m .43148 .46977 L .44115 .48278 L p .713 .781 .906 r
F P
0 g
s
.45299 .47864 m .44115 .48278 L .43148 .46977 L p .668 .767 .924 r
F P
0 g
s
.45299 .47864 m .46486 .47598 L .47559 .48533 L p .611 .722 .924 r
F P
0 g
s
.48534 .48236 m .47559 .48533 L .46486 .47598 L p .548 .701 .94 r
F P
0 g
s
.47559 .48533 m .48534 .48236 L .49651 .48977 L p .537 .683 .932 r
F P
0 g
s
.51338 .49167 m .50955 .49654 L .49651 .48977 L p .457 .65 .942 r
F P
0 g
s
.50955 .49654 m .51338 .49167 L .52399 .49623 L p .436 .641 .943 r
F P
0 g
s
.52399 .49623 m .52363 .50223 L .50955 .49654 L p .436 .641 .943 r
F P
0 g
s
.6415 .53059 m .63018 .52855 L .64464 .51569 L p .664 .871 .977 r
F P
0 g
s
.64464 .51569 m .65763 .51502 L .6415 .53059 L p .664 .871 .977 r
F P
0 g
s
.52363 .50223 m .52399 .49623 L .53471 .49974 L p .413 .637 .947 r
F P
0 g
s
.53471 .49974 m .53784 .50648 L .52363 .50223 L p .413 .637 .947 r
F P
0 g
s
.72152 .50896 m .70884 .50969 L .71994 .47979 L p .752 .844 .92 r
F P
0 g
s
.71994 .47979 m .73359 .47632 L .72152 .50896 L p .752 .844 .92 r
F P
0 g
s
.59087 .52787 m .58167 .52223 L .59573 .51868 L p .496 .753 .987 r
F P
0 g
s
.59573 .51868 m .60729 .5227 L .59087 .52787 L p .496 .753 .987 r
F P
0 g
s
.20281 .47866 m .21656 .48212 L .23277 .52894 L p .518 .663 .927 r
F P
0 g
s
.24549 .53024 m .23277 .52894 L .21656 .48212 L p .539 .675 .926 r
F P
0 g
s
.50355 .48636 m .49651 .48977 L .48534 .48236 L p .472 .661 .944 r
F P
0 g
s
.49651 .48977 m .50355 .48636 L .51338 .49167 L p .457 .65 .942 r
F P
0 g
s
.43148 .46977 m .44477 .46758 L .45299 .47864 L p .668 .767 .924 r
F P
0 g
s
.46486 .47598 m .45299 .47864 L .44477 .46758 L p .61 .746 .941 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56306 .50964 L p .414 .667 .965 r
F P
0 g
s
.56306 .50964 m .5724 .51615 L .55769 .51601 L p .414 .667 .965 r
F P
0 g
s
.53784 .50648 m .53471 .49974 L .54482 .50197 L p .394 .637 .953 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53784 .50648 L p .394 .637 .953 r
F P
0 g
s
.21656 .48212 m .23037 .48517 L .24549 .53024 L p .539 .675 .926 r
F P
0 g
s
.25833 .5308 m .24549 .53024 L .23037 .48517 L p .571 .693 .924 r
F P
0 g
s
.70884 .50969 m .69612 .5109 L .70628 .48386 L p .763 .863 .923 r
F P
0 g
s
.70628 .48386 m .71994 .47979 L .70884 .50969 L p .763 .863 .923 r
F P
0 g
s
.46486 .47598 m .47676 .47478 L .48534 .48236 L p .548 .701 .94 r
F P
0 g
s
.49515 .48064 m .48534 .48236 L .47676 .47478 L p .478 .673 .95 r
F P
0 g
s
.48534 .48236 m .49515 .48064 L .50355 .48636 L p .472 .661 .944 r
F P
0 g
s
.63018 .52855 m .61878 .52596 L .63157 .5156 L p .629 .851 .984 r
F P
0 g
s
.63157 .5156 m .64464 .51569 L .63018 .52855 L p .629 .851 .984 r
F P
0 g
s
.44477 .46758 m .45807 .46684 L .46486 .47598 L p .61 .746 .941 r
F P
0 g
s
.47676 .47478 m .46486 .47598 L .45807 .46684 L p .543 .716 .953 r
F P
0 g
s
.58167 .52223 m .5724 .51615 L .58409 .51388 L p .457 .72 .981 r
F P
0 g
s
.58409 .51388 m .59573 .51868 L .58167 .52223 L p .457 .72 .981 r
F P
0 g
s
.23037 .48517 m .24425 .48757 L .25833 .5308 L p .571 .693 .924 r
F P
0 g
s
.27128 .53041 m .25833 .5308 L .24425 .48757 L p .608 .715 .921 r
F P
0 g
s
.69612 .5109 m .68336 .51237 L .6926 .48825 L p .767 .877 .927 r
F P
0 g
s
.6926 .48825 m .70628 .48386 L .69612 .5109 L p .767 .877 .927 r
F P
0 g
s
.51725 .48752 m .51338 .49167 L .50355 .48636 L p .4 .631 .947 r
F P
0 g
s
.51338 .49167 m .51725 .48752 L .52436 .49071 L p .388 .625 .947 r
F P
0 g
s
.52436 .49071 m .52399 .49623 L .51338 .49167 L p .388 .625 .947 r
F P
0 g
s
.52399 .49623 m .52436 .49071 L .53154 .49321 L p .375 .622 .948 r
F P
0 g
s
.53154 .49321 m .53471 .49974 L .52399 .49623 L p .375 .622 .948 r
F P
0 g
s
.51066 .48386 m .50355 .48636 L .49515 .48064 L p .408 .637 .949 r
F P
0 g
s
.50355 .48636 m .51066 .48386 L .51725 .48752 L p .4 .631 .947 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55366 .50275 L p .384 .644 .959 r
F P
0 g
s
.55366 .50275 m .56306 .50964 L .55128 .50901 L p .384 .644 .959 r
F P
0 g
s
.24425 .48757 m .25822 .48909 L .27128 .53041 L p .608 .715 .921 r
F P
0 g
s
.28436 .52888 m .27128 .53041 L .25822 .48909 L p .647 .739 .916 r
F P
0 g
s
.61878 .52596 m .60729 .5227 L .61843 .51457 L p .587 .823 .989 r
F P
0 g
s
.61843 .51457 m .63157 .5156 L .61878 .52596 L p .587 .823 .989 r
F P
0 g
s
.38596 .46433 m .40003 .46098 L .40481 .47819 L p .765 .835 .906 r
F P
0 g
s
.40481 .47819 m .39143 .48404 L .38596 .46433 L p .765 .835 .906 r
F P
0 g
s
.41816 .47336 m .40481 .47819 L .40003 .46098 L p .738 .828 .92 r
F P
0 g
s
.37183 .46833 m .38596 .46433 L .39143 .48404 L p .782 .837 .894 r
F P
0 g
s
.39143 .48404 m .37801 .49061 L .37183 .46833 L p .782 .837 .894 r
F P
0 g
s
.40003 .46098 m .41403 .45855 L .41816 .47336 L p .738 .828 .92 r
F P
0 g
s
.43148 .46977 m .41816 .47336 L .41403 .45855 L p .7 .814 .936 r
F P
0 g
s
.45807 .46684 m .47137 .46751 L .47676 .47478 L p .543 .716 .953 r
F P
0 g
s
.48872 .47489 m .47676 .47478 L .47137 .46751 L p .472 .681 .957 r
F P
0 g
s
.47676 .47478 m .48872 .47489 L .49515 .48064 L p .478 .673 .95 r
F P
0 g
s
.35763 .47268 m .37183 .46833 L .37801 .49061 L p .79 .836 .887 r
F P
0 g
s
.37801 .49061 m .36456 .49755 L .35763 .47268 L p .79 .836 .887 r
F P
0 g
s
.25822 .48909 m .27228 .4896 L .28436 .52888 L p .647 .739 .916 r
F P
0 g
s
.29755 .52614 m .28436 .52888 L .27228 .4896 L p .685 .761 .909 r
F P
0 g
s
.5724 .51615 m .56306 .50964 L .57239 .50831 L p .42 .686 .973 r
F P
0 g
s
.57239 .50831 m .58409 .51388 L .5724 .51615 L p .42 .686 .973 r
F P
0 g
s
.53471 .49974 m .53154 .49321 L .5383 .49486 L p .365 .622 .951 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53471 .49974 L p .365 .622 .951 r
F P
0 g
s
.41403 .45855 m .42798 .45726 L .43148 .46977 L p .7 .814 .936 r
F P
0 g
s
.44477 .46758 m .43148 .46977 L .42798 .45726 L p .65 .792 .95 r
F P
0 g
s
.34339 .47706 m .35763 .47268 L .36456 .49755 L p .79 .831 .884 r
F P
0 g
s
.36456 .49755 m .35109 .50452 L .34339 .47706 L p .79 .831 .884 r
F P
0 g
s
.50504 .47996 m .49515 .48064 L .48872 .47489 L p .41 .643 .952 r
F P
0 g
s
.49515 .48064 m .50504 .47996 L .51066 .48386 L p .408 .637 .949 r
F P
0 g
s
.68336 .51237 m .67053 .51383 L .67888 .49264 L p .763 .885 .932 r
F P
0 g
s
.67888 .49264 m .6926 .48825 L .68336 .51237 L p .763 .885 .932 r
F P
0 g
s
.27228 .4896 m .28642 .48901 L .29755 .52614 L p .685 .761 .909 r
F P
0 g
s
.31084 .52219 m .29755 .52614 L .28642 .48901 L p .719 .781 .902 r
F P
0 g
s
.32913 .48114 m .34339 .47706 L .35109 .50452 L p .782 .823 .884 r
F P
0 g
s
.35109 .50452 m .33764 .51115 L .32913 .48114 L p .782 .823 .884 r
F P
0 g
s
.42798 .45726 m .44187 .45722 L .44477 .46758 L p .65 .792 .95 r
F P
0 g
s
.45807 .46684 m .44477 .46758 L .44187 .45722 L p .59 .762 .961 r
F P
0 g
s
.31486 .48465 m .32913 .48114 L .33764 .51115 L p .768 .812 .888 r
F P
0 g
s
.33764 .51115 m .32421 .51713 L .31486 .48465 L p .768 .812 .888 r
F P
0 g
s
.28642 .48901 m .30062 .48733 L .31084 .52219 L p .719 .781 .902 r
F P
0 g
s
.32421 .51713 m .31084 .52219 L .30062 .48733 L p .747 .799 .894 r
F P
0 g
s
.30062 .48733 m .31486 .48465 L .32421 .51713 L p .747 .799 .894 r
F P
0 g
s
.60729 .5227 m .59573 .51868 L .60521 .51249 L p .541 .788 .989 r
F P
0 g
s
.60521 .51249 m .61843 .51457 L .60729 .5227 L p .541 .788 .989 r
F P
0 g
s
.44187 .45722 m .45573 .4585 L .45807 .46684 L p .59 .762 .961 r
F P
0 g
s
.47137 .46751 m .45807 .46684 L .45573 .4585 L p .523 .725 .965 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .5442 .49554 L p .359 .625 .953 r
F P
0 g
s
.5442 .49554 m .55366 .50275 L .54482 .50197 L p .359 .625 .953 r
F P
0 g
s
.67053 .51383 m .65763 .51502 L .66511 .4967 L p .75 .885 .941 r
F P
0 g
s
.66511 .4967 m .67888 .49264 L .67053 .51383 L p .75 .885 .941 r
F P
0 g
s
.47137 .46751 m .48472 .46947 L .48872 .47489 L p .472 .681 .957 r
F P
0 g
s
.50076 .47608 m .48872 .47489 L .48472 .46947 L p .406 .646 .955 r
F P
0 g
s
.48872 .47489 m .50076 .47608 L .50504 .47996 L p .41 .643 .952 r
F P
0 g
s
.56306 .50964 m .55366 .50275 L .56064 .50204 L p .388 .656 .964 r
F P
0 g
s
.56064 .50204 m .57239 .50831 L .56306 .50964 L p .388 .656 .964 r
F P
0 g
s
.52116 .48387 m .51725 .48752 L .51066 .48386 L p .354 .613 .948 r
F P
0 g
s
.51725 .48752 m .52116 .48387 L .52474 .48551 L p .35 .611 .948 r
F P
0 g
s
.52474 .48551 m .52436 .49071 L .51725 .48752 L p .35 .611 .948 r
F P
0 g
s
.52436 .49071 m .52474 .48551 L .52834 .48682 L p .345 .61 .948 r
F P
0 g
s
.52834 .48682 m .53154 .49321 L .52436 .49071 L p .345 .61 .948 r
F P
0 g
s
.51785 .482 m .51066 .48386 L .50504 .47996 L p .356 .615 .948 r
F P
0 g
s
.51066 .48386 m .51785 .482 L .52116 .48387 L p .354 .613 .948 r
F P
0 g
s
.59573 .51868 m .58409 .51388 L .59193 .50931 L p .493 .748 .985 r
F P
0 g
s
.59193 .50931 m .60521 .51249 L .59573 .51868 L p .493 .748 .985 r
F P
0 g
s
.45573 .4585 m .46958 .46105 L .47137 .46751 L p .523 .725 .965 r
F P
0 g
s
.48472 .46947 m .47137 .46751 L .46958 .46105 L p .456 .684 .964 r
F P
0 g
s
.53154 .49321 m .52834 .48682 L .53174 .48769 L p .342 .609 .948 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53154 .49321 L p .342 .609 .948 r
F P
0 g
s
.51503 .48002 m .50504 .47996 L .50076 .47608 L p .357 .617 .949 r
F P
0 g
s
.50504 .47996 m .51503 .48002 L .51785 .482 L p .356 .615 .948 r
F P
0 g
s
.65763 .51502 m .64464 .51569 L .65126 .50012 L p .727 .878 .951 r
F P
0 g
s
.65126 .50012 m .66511 .4967 L .65763 .51502 L p .727 .878 .951 r
F P
0 g
s
.55366 .50275 m .5442 .49554 L .54884 .4952 L p .361 .63 .956 r
F P
0 g
s
.54884 .4952 m .56064 .50204 L .55366 .50275 L p .361 .63 .956 r
F P
0 g
s
.58409 .51388 m .57239 .50831 L .57861 .50506 L p .447 .707 .978 r
F P
0 g
s
.57861 .50506 m .59193 .50931 L .58409 .51388 L p .447 .707 .978 r
F P
0 g
s
.46958 .46105 m .48342 .46476 L .48472 .46947 L p .456 .684 .964 r
F P
0 g
s
.49811 .47249 m .48472 .46947 L .48342 .46476 L p .396 .647 .958 r
F P
0 g
s
.48472 .46947 m .49811 .47249 L .50076 .47608 L p .406 .646 .955 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53469 .48808 L p .34 .61 .949 r
F P
0 g
s
.53469 .48808 m .5442 .49554 L .5383 .49486 L p .34 .61 .949 r
F P
0 g
s
.51289 .47806 m .50076 .47608 L .49811 .47249 L p .355 .617 .95 r
F P
0 g
s
.50076 .47608 m .51289 .47806 L .51503 .48002 L p .357 .617 .949 r
F P
0 g
s
.64464 .51569 m .63157 .5156 L .63735 .5026 L p .694 .863 .962 r
F P
0 g
s
.63735 .5026 m .65126 .50012 L .64464 .51569 L p .694 .863 .962 r
F P
0 g
s
.57239 .50831 m .56064 .50204 L .56525 .49985 L p .405 .669 .968 r
F P
0 g
s
.56525 .49985 m .57861 .50506 L .57239 .50831 L p .405 .669 .968 r
F P
0 g
s
.80256 .47345 m .78862 .47194 L .78745 .42885 L p .617 .71 .911 r
F P
0 g
s
.78862 .47194 m .77476 .47144 L .77335 .43054 L p .651 .735 .911 r
F P
0 g
s
.77335 .43054 m .78745 .42885 L .78862 .47194 L p .651 .735 .911 r
F P
0 g
s
.77476 .47144 m .76098 .47202 L .75936 .43345 L p .685 .762 .91 r
F P
0 g
s
.75936 .43345 m .77335 .43054 L .77476 .47144 L p .685 .762 .91 r
F P
0 g
s
.81659 .47581 m .80256 .47345 L .8017 .42828 L p .588 .687 .91 r
F P
0 g
s
.78745 .42885 m .8017 .42828 L .80256 .47345 L p .617 .71 .911 r
F P
0 g
s
.43106 .44609 m .44461 .44828 L .44187 .45722 L p .609 .8 .973 r
F P
0 g
s
.44187 .45722 m .42798 .45726 L .43106 .44609 L p .609 .8 .973 r
F P
0 g
s
.45573 .4585 m .44187 .45722 L .44461 .44828 L p .551 .764 .977 r
F P
0 g
s
.76098 .47202 m .74726 .47368 L .74548 .43755 L p .718 .787 .906 r
F P
0 g
s
.74548 .43755 m .75936 .43345 L .76098 .47202 L p .718 .787 .906 r
F P
0 g
s
.52511 .48046 m .52116 .48387 L .51785 .482 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52474 .48551 L .52116 .48387 L closepath p .328 .601 .946 r
F P
0 g
s
.5442 .49554 m .53469 .48808 L .53699 .48794 L p .341 .612 .95 r
F P
0 g
s
.53699 .48794 m .54884 .4952 L .5442 .49554 L p .341 .612 .95 r
F P
0 g
s
.48342 .46476 m .49728 .46942 L .49811 .47249 L p .396 .647 .958 r
F P
0 g
s
.51157 .47627 m .49811 .47249 L .49728 .46942 L p .352 .617 .951 r
F P
0 g
s
.49811 .47249 m .51157 .47627 L .51289 .47806 L p .355 .617 .95 r
F P
0 g
s
.44461 .44828 m .4581 .45154 L .45573 .4585 L p .551 .764 .977 r
F P
0 g
s
.46958 .46105 m .45573 .4585 L .4581 .45154 L p .49 .722 .974 r
F P
0 g
s
.41743 .44493 m .43106 .44609 L .42798 .45726 L p .66 .83 .965 r
F P
0 g
s
.42798 .45726 m .41403 .45855 L .41743 .44493 L p .66 .83 .965 r
F P
0 g
s
.52511 .48046 m .51785 .482 L .51503 .48002 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52834 .48682 L .52474 .48551 L closepath p .328 .601 .946 r
F P
0 g
s
.63157 .5156 m .61843 .51457 L .62338 .50394 L p .651 .838 .972 r
F P
0 g
s
.62338 .50394 m .63735 .5026 L .63157 .5156 L p .651 .838 .972 r
F P
0 g
s
.83069 .47883 m .81659 .47581 L .81607 .42867 L p .565 .67 .909 r
F P
0 g
s
.8017 .42828 m .81607 .42867 L .81659 .47581 L p .588 .687 .91 r
F P
0 g
s
.74726 .47368 m .73359 .47632 L .73168 .44277 L p .746 .809 .902 r
F P
0 g
s
.73168 .44277 m .74548 .43755 L .74726 .47368 L p .746 .809 .902 r
F P
0 g
s
.4581 .45154 m .47154 .45584 L .46958 .46105 L p .49 .722 .974 r
F P
0 g
s
.48342 .46476 m .46958 .46105 L .47154 .45584 L p .432 .68 .968 r
F P
0 g
s
.40373 .44469 m .41743 .44493 L .41403 .45855 L p .702 .85 .953 r
F P
0 g
s
.41403 .45855 m .40003 .46098 L .40373 .44469 L p .702 .85 .953 r
F P
0 g
s
.52511 .48046 m .51503 .48002 L .51289 .47806 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48682 L closepath p .328 .601 .946 r
F P
0 g
s
.84485 .48226 m .83069 .47883 L .83057 .42981 L p .55 .66 .909 r
F P
0 g
s
.81607 .42867 m .83057 .42981 L .83069 .47883 L p .565 .67 .909 r
F P
0 g
s
.56064 .50204 m .54884 .4952 L .55188 .49385 L p .369 .637 .958 r
F P
0 g
s
.55188 .49385 m .56525 .49985 L .56064 .50204 L p .369 .637 .958 r
F P
0 g
s
.47154 .45584 m .48495 .46107 L .48342 .46476 L p .432 .68 .968 r
F P
0 g
s
.49728 .46942 m .48342 .46476 L .48495 .46107 L p .383 .643 .959 r
F P
0 g
s
.73359 .47632 m .71994 .47979 L .71795 .4489 L p .769 .827 .898 r
F P
0 g
s
.71795 .4489 m .73168 .44277 L .73359 .47632 L p .769 .827 .898 r
F P
0 g
s
.38993 .44521 m .40373 .44469 L .40003 .46098 L p .734 .862 .941 r
F P
0 g
s
.40003 .46098 m .38596 .46433 L .38993 .44521 L p .734 .862 .941 r
F P
0 g
s
.52511 .48046 m .51289 .47806 L .51157 .47627 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53469 .48808 L .53174 .48769 L closepath p .328 .601 .946 r
F P
0 g
s
.85906 .48583 m .84485 .48226 L .84517 .43141 L p .544 .657 .909 r
F P
0 g
s
.83057 .42981 m .84517 .43141 L .84485 .48226 L p .55 .66 .909 r
F P
0 g
s
.61843 .51457 m .60521 .51249 L .60936 .50399 L p .599 .805 .979 r
F P
0 g
s
.60936 .50399 m .62338 .50394 L .61843 .51457 L p .599 .805 .979 r
F P
0 g
s
.84517 .43141 m .85986 .43317 L .85906 .48583 L p .544 .657 .909 r
F P
0 g
s
.54884 .4952 m .53699 .48794 L .5385 .4873 L p .343 .614 .951 r
F P
0 g
s
.5385 .4873 m .55188 .49385 L .54884 .4952 L p .343 .614 .951 r
F P
0 g
s
.48495 .46107 m .49835 .46708 L .49728 .46942 L p .383 .643 .959 r
F P
0 g
s
.51118 .47476 m .49728 .46942 L .49835 .46708 L p .348 .616 .951 r
F P
0 g
s
.49728 .46942 m .51118 .47476 L .51157 .47627 L p .352 .617 .951 r
F P
0 g
s
.37605 .44626 m .38993 .44521 L .38596 .46433 L p .755 .866 .93 r
F P
0 g
s
.38596 .46433 m .37183 .46833 L .37605 .44626 L p .755 .866 .93 r
F P
0 g
s
.52511 .48046 m .51157 .47627 L .51118 .47476 L closepath p .328 .601 .946 r
F P
0 g
s
.71994 .47979 m .70628 .48386 L .70424 .45571 L p .784 .841 .895 r
F P
0 g
s
.70424 .45571 m .71795 .4489 L .71994 .47979 L p .784 .841 .895 r
F P
0 g
s
.52511 .48046 m .53699 .48794 L .53469 .48808 L closepath p .328 .601 .946 r
F P
0 g
s
.60521 .51249 m .59193 .50931 L .59531 .50269 L p .542 .766 .98 r
F P
0 g
s
.59531 .50269 m .60936 .50399 L .60521 .51249 L p .542 .766 .98 r
F P
0 g
s
.36209 .4476 m .37605 .44626 L .37183 .46833 L p .767 .864 .921 r
F P
0 g
s
.37183 .46833 m .35763 .47268 L .36209 .4476 L p .767 .864 .921 r
F P
0 g
s
.49835 .46708 m .51173 .47363 L .51118 .47476 L p .348 .616 .951 r
F P
0 g
s
.52511 .48046 m .51118 .47476 L .51173 .47363 L closepath p .328 .601 .946 r
F P
0 g
s
.70628 .48386 m .6926 .48825 L .69054 .46286 L p .792 .851 .895 r
F P
0 g
s
.69054 .46286 m .70424 .45571 L .70628 .48386 L p .792 .851 .895 r
F P
0 g
s
.52511 .48046 m .5385 .4873 L .53699 .48794 L closepath p .328 .601 .946 r
F P
0 g
s
.59193 .50931 m .57861 .50506 L .58124 .50008 L p .484 .722 .976 r
F P
0 g
s
.58124 .50008 m .59531 .50269 L .59193 .50931 L p .484 .722 .976 r
F P
0 g
s
.57861 .50506 m .56525 .49985 L .56716 .49631 L p .429 .68 .968 r
F P
0 g
s
.56716 .49631 m .58124 .50008 L .57861 .50506 L p .429 .68 .968 r
F P
0 g
s
.56525 .49985 m .55188 .49385 L .55311 .49158 L p .382 .643 .959 r
F P
0 g
s
.55311 .49158 m .56716 .49631 L .56525 .49985 L p .382 .643 .959 r
F P
0 g
s
.50125 .46564 m .5132 .47296 L .51173 .47363 L p .344 .614 .951 r
F P
0 g
s
.51173 .47363 m .49835 .46708 L .50125 .46564 L p .344 .614 .951 r
F P
0 g
s
.52511 .48046 m .51173 .47363 L .5132 .47296 L closepath p .328 .601 .946 r
F P
0 g
s
.34805 .44895 m .36209 .4476 L .35763 .47268 L p .77 .857 .915 r
F P
0 g
s
.35763 .47268 m .34339 .47706 L .34805 .44895 L p .77 .857 .915 r
F P
0 g
s
.55188 .49385 m .5385 .4873 L .53909 .48619 L p .347 .616 .951 r
F P
0 g
s
.53909 .48619 m .55311 .49158 L .55188 .49385 L p .347 .616 .951 r
F P
0 g
s
.52511 .48046 m .5353 .48092 L .53744 .48289 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53246 .47891 L .5353 .48092 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52912 .47702 L .53246 .47891 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .5255 .47536 L .52912 .47702 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52185 .47405 L .5255 .47536 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47405 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .51549 .47281 L .51844 .47318 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .5132 .47296 L .51549 .47281 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53909 .48619 L .5385 .4873 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53873 .48468 L .53909 .48619 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53744 .48289 L .53873 .48468 L closepath p .328 .601 .946 r
F P
0 g
s
.48925 .45869 m .50125 .46564 L .49835 .46708 L p .371 .638 .958 r
F P
0 g
s
.49835 .46708 m .48495 .46107 L .48925 .45869 L p .371 .638 .958 r
F P
0 g
s
.6926 .48825 m .67888 .49264 L .67683 .47001 L p .792 .856 .898 r
F P
0 g
s
.67683 .47001 m .69054 .46286 L .6926 .48825 L p .792 .856 .898 r
F P
0 g
s
.47721 .45225 m .48925 .45869 L .48495 .46107 L p .408 .67 .968 r
F P
0 g
s
.48495 .46107 m .47154 .45584 L .47721 .45225 L p .408 .67 .968 r
F P
0 g
s
.46511 .44647 m .47721 .45225 L .47154 .45584 L p .452 .707 .977 r
F P
0 g
s
.47154 .45584 m .4581 .45154 L .46511 .44647 L p .452 .707 .977 r
F P
0 g
s
.45294 .4414 m .46511 .44647 L .4581 .45154 L p .502 .747 .983 r
F P
0 g
s
.4581 .45154 m .44461 .44828 L .45294 .4414 L p .502 .747 .983 r
F P
0 g
s
.5058 .46521 m .51549 .47281 L .5132 .47296 L p .341 .612 .95 r
F P
0 g
s
.5132 .47296 m .50125 .46564 L .5058 .46521 L p .341 .612 .95 r
F P
0 g
s
.33396 .45005 m .34805 .44895 L .34339 .47706 L p .765 .845 .912 r
F P
0 g
s
.34339 .47706 m .32913 .48114 L .33396 .45005 L p .765 .845 .912 r
F P
0 g
s
.55311 .49158 m .53909 .48619 L .53873 .48468 L p .352 .617 .951 r
F P
0 g
s
.67888 .49264 m .66511 .4967 L .66309 .47677 L p .783 .857 .906 r
F P
0 g
s
.66309 .47677 m .67683 .47001 L .67888 .49264 L p .783 .857 .906 r
F P
0 g
s
.4407 .43708 m .45294 .4414 L .44461 .44828 L p .552 .785 .985 r
F P
0 g
s
.44461 .44828 m .43106 .44609 L .4407 .43708 L p .552 .785 .985 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51549 .47281 L p .34 .61 .949 r
F P
0 g
s
.51549 .47281 m .5058 .46521 L .5117 .46583 L p .34 .61 .949 r
F P
0 g
s
.31982 .45068 m .33396 .45005 L .32913 .48114 L p .754 .829 .91 r
F P
0 g
s
.32913 .48114 m .31486 .48465 L .31982 .45068 L p .754 .829 .91 r
F P
0 g
s
.53873 .48468 m .55243 .48853 L .55311 .49158 L p .352 .617 .951 r
F P
0 g
s
.55243 .48853 m .53873 .48468 L .53744 .48289 L p .355 .617 .95 r
F P
0 g
s
.66511 .4967 m .65126 .50012 L .64931 .48281 L p .764 .852 .917 r
F P
0 g
s
.64931 .48281 m .66309 .47677 L .66511 .4967 L p .764 .852 .917 r
F P
0 g
s
.56716 .49631 m .55311 .49158 L .55243 .48853 L p .395 .646 .958 r
F P
0 g
s
.49605 .45777 m .5058 .46521 L .50125 .46564 L p .362 .631 .956 r
F P
0 g
s
.50125 .46564 m .48925 .45869 L .49605 .45777 L p .362 .631 .956 r
F P
0 g
s
.20281 .47866 m .18911 .47507 L .19318 .42214 L p .555 .662 .908 r
F P
0 g
s
.42837 .43347 m .4407 .43708 L .43106 .44609 L p .6 .818 .983 r
F P
0 g
s
.43106 .44609 m .41743 .44493 L .42837 .43347 L p .6 .818 .983 r
F P
0 g
s
.19318 .42214 m .20717 .42743 L .20281 .47866 L p .555 .662 .908 r
F P
0 g
s
.21656 .48212 m .20281 .47866 L .20717 .42743 L p .562 .664 .906 r
F P
0 g
s
.51856 .46746 m .52185 .47405 L .51844 .47318 L p .342 .609 .948 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51856 .46746 L p .342 .609 .948 r
F P
0 g
s
.53744 .48289 m .54987 .48492 L .55243 .48853 L p .355 .617 .95 r
F P
0 g
s
.54987 .48492 m .53744 .48289 L .5353 .48092 L p .357 .616 .949 r
F P
0 g
s
.65126 .50012 m .63735 .5026 L .63549 .4878 L p .735 .842 .93 r
F P
0 g
s
.63549 .4878 m .64931 .48281 L .65126 .50012 L p .735 .842 .93 r
F P
0 g
s
.30567 .45062 m .31982 .45068 L .31486 .48465 L p .735 .809 .91 r
F P
0 g
s
.31486 .48465 m .30062 .48733 L .30567 .45062 L p .735 .809 .91 r
F P
0 g
s
.58124 .50008 m .56716 .49631 L .5662 .49165 L p .453 .684 .965 r
F P
0 g
s
.55243 .48853 m .5662 .49165 L .56716 .49631 L p .395 .646 .958 r
F P
0 g
s
.48624 .45057 m .49605 .45777 L .48925 .45869 L p .39 .656 .964 r
F P
0 g
s
.48925 .45869 m .47721 .45225 L .48624 .45057 L p .39 .656 .964 r
F P
0 g
s
.20717 .42743 m .22116 .4326 L .21656 .48212 L p .562 .664 .906 r
F P
0 g
s
.23037 .48517 m .21656 .48212 L .22116 .4326 L p .577 .674 .906 r
F P
0 g
s
.52588 .46999 m .5255 .47536 L .52185 .47405 L p .345 .61 .948 r
F P
0 g
s
.52185 .47405 m .51856 .46746 L .52588 .46999 L p .345 .61 .948 r
F P
0 g
s
.5353 .48092 m .5456 .48098 L .54987 .48492 L p .357 .616 .949 r
F P
0 g
s
.5456 .48098 m .5353 .48092 L .53246 .47891 L p .356 .615 .948 r
F P
0 g
s
.63735 .5026 m .62338 .50394 L .62164 .49149 L p .695 .824 .944 r
F P
0 g
s
.62164 .49149 m .63549 .4878 L .63735 .5026 L p .695 .824 .944 r
F P
0 g
s
.59531 .50269 m .58124 .50008 L .58003 .4937 L p .518 .726 .968 r
F P
0 g
s
.5662 .49165 m .58003 .4937 L .58124 .50008 L p .453 .684 .965 r
F P
0 g
s
.29152 .44973 m .30567 .45062 L .30062 .48733 L p .712 .786 .91 r
F P
0 g
s
.30062 .48733 m .28642 .48901 L .29152 .44973 L p .712 .786 .91 r
F P
0 g
s
.22116 .4326 m .23517 .43742 L .23037 .48517 L p .577 .674 .906 r
F P
0 g
s
.24425 .48757 m .23037 .48517 L .23517 .43742 L p .599 .691 .907 r
F P
0 g
s
.41594 .4305 m .42837 .43347 L .41743 .44493 L p .642 .843 .977 r
F P
0 g
s
.41743 .44493 m .40373 .44469 L .41594 .4305 L p .642 .843 .977 r
F P
0 g
s
.53317 .47324 m .52912 .47702 L .5255 .47536 L p .35 .611 .948 r
F P
0 g
s
.5255 .47536 m .52588 .46999 L .53317 .47324 L p .35 .611 .948 r
F P
0 g
s
.53246 .47891 m .5399 .47699 L .5456 .48098 L p .356 .615 .948 r
F P
0 g
s
.5399 .47699 m .53246 .47891 L .52912 .47702 L p .353 .613 .948 r
F P
0 g
s
.62338 .50394 m .60936 .50399 L .60776 .49372 L p .644 .798 .957 r
F P
0 g
s
.60776 .49372 m .62164 .49149 L .62338 .50394 L p .644 .798 .957 r
F P
0 g
s
.60936 .50399 m .59531 .50269 L .59389 .49444 L p .584 .765 .965 r
F P
0 g
s
.58003 .4937 m .59389 .49444 L .59531 .50269 L p .518 .726 .968 r
F P
0 g
s
.5662 .49165 m .55243 .48853 L .54987 .48492 L p .405 .646 .955 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .5058 .46521 L p .36 .625 .953 r
F P
0 g
s
.5058 .46521 m .49605 .45777 L .50491 .45842 L p .36 .625 .953 r
F P
0 g
s
.52912 .47702 m .53317 .47324 L .5399 .47699 L p .353 .613 .948 r
F P
0 g
s
.27739 .44794 m .29152 .44973 L .28642 .48901 L p .685 .762 .91 r
F P
0 g
s
.28642 .48901 m .27228 .4896 L .27739 .44794 L p .685 .762 .91 r
F P
0 g
s
.59389 .49444 m .60776 .49372 L .60936 .50399 L p .584 .765 .965 r
F P
0 g
s
.23517 .43742 m .24921 .4417 L .24425 .48757 L p .599 .691 .907 r
F P
0 g
s
.25822 .48909 m .24425 .48757 L .24921 .4417 L p .626 .712 .908 r
F P
0 g
s
.26328 .44525 m .27739 .44794 L .27228 .4896 L p .655 .736 .909 r
F P
0 g
s
.27228 .4896 m .25822 .48909 L .26328 .44525 L p .655 .736 .909 r
F P
0 g
s
.24921 .4417 m .26328 .44525 L .25822 .48909 L p .626 .712 .908 r
F P
0 g
s
.47637 .44368 m .48624 .45057 L .47721 .45225 L p .425 .687 .973 r
F P
0 g
s
.47721 .45225 m .46511 .44647 L .47637 .44368 L p .425 .687 .973 r
F P
0 g
s
.40343 .42806 m .41594 .4305 L .40373 .44469 L p .677 .859 .969 r
F P
0 g
s
.40373 .44469 m .38993 .44521 L .40343 .42806 L p .677 .859 .969 r
F P
0 g
s
.54987 .48492 m .5624 .48618 L .5662 .49165 L p .405 .646 .955 r
F P
0 g
s
.5624 .48618 m .54987 .48492 L .5456 .48098 L p .409 .642 .952 r
F P
0 g
s
.51523 .4606 m .51856 .46746 L .5117 .46583 L p .365 .622 .951 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51523 .4606 L p .365 .622 .951 r
F P
0 g
s
.58003 .4937 m .5662 .49165 L .5624 .48618 L p .469 .681 .958 r
F P
0 g
s
.46642 .43712 m .47637 .44368 L .46511 .44647 L p .464 .72 .98 r
F P
0 g
s
.46511 .44647 m .45294 .4414 L .46642 .43712 L p .464 .72 .98 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49605 .45777 L p .386 .644 .959 r
F P
0 g
s
.49605 .45777 m .48624 .45057 L .49806 .45095 L p .386 .644 .959 r
F P
0 g
s
.39082 .42597 m .40343 .42806 L .38993 .44521 L p .703 .867 .959 r
F P
0 g
s
.38993 .44521 m .37605 .44626 L .39082 .42597 L p .703 .867 .959 r
F P
0 g
s
.5456 .48098 m .55599 .48028 L .5624 .48618 L p .409 .642 .952 r
F P
0 g
s
.55599 .48028 m .5456 .48098 L .5399 .47699 L p .407 .637 .949 r
F P
0 g
s
.52627 .46416 m .52588 .46999 L .51856 .46746 L p .375 .622 .948 r
F P
0 g
s
.51856 .46746 m .51523 .4606 L .52627 .46416 L p .375 .622 .948 r
F P
0 g
s
.59389 .49444 m .58003 .4937 L .575 .48633 L p .539 .717 .955 r
F P
0 g
s
.5624 .48618 m .575 .48633 L .58003 .4937 L p .469 .681 .958 r
F P
0 g
s
.45639 .43092 m .46642 .43712 L .45294 .4414 L p .505 .753 .985 r
F P
0 g
s
.45294 .4414 m .4407 .43708 L .45639 .43092 L p .505 .753 .985 r
F P
0 g
s
.5399 .47699 m .54741 .47437 L .55599 .48028 L p .407 .637 .949 r
F P
0 g
s
.54741 .47437 m .5399 .47699 L .53317 .47324 L p .399 .63 .948 r
F P
0 g
s
.53726 .46886 m .53317 .47324 L .52588 .46999 L p .387 .625 .947 r
F P
0 g
s
.52588 .46999 m .52627 .46416 L .53726 .46886 L p .387 .625 .947 r
F P
0 g
s
.53317 .47324 m .53726 .46886 L .54741 .47437 L p .399 .63 .948 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48624 .45057 L p .416 .667 .964 r
F P
0 g
s
.48624 .45057 m .47637 .44368 L .49116 .44341 L p .416 .667 .964 r
F P
0 g
s
.575 .48633 m .5624 .48618 L .55599 .48028 L p .475 .673 .951 r
F P
0 g
s
.37811 .42407 m .39082 .42597 L .37605 .44626 L p .721 .867 .95 r
F P
0 g
s
.37605 .44626 m .36209 .4476 L .37811 .42407 L p .721 .867 .95 r
F P
0 g
s
.51186 .45338 m .51523 .4606 L .50491 .45842 L p .394 .637 .953 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51186 .45338 L p .394 .637 .953 r
F P
0 g
s
.60776 .49372 m .59389 .49444 L .58767 .48512 L p .605 .749 .946 r
F P
0 g
s
.575 .48633 m .58767 .48512 L .59389 .49444 L p .539 .717 .955 r
F P
0 g
s
.44629 .42507 m .45639 .43092 L .4407 .43708 L p .546 .782 .986 r
F P
0 g
s
.4407 .43708 m .42837 .43347 L .44629 .42507 L p .546 .782 .986 r
F P
0 g
s
.74548 .43755 m .73168 .44277 L .71518 .41064 L p .749 .791 .887 r
F P
0 g
s
.73168 .44277 m .71795 .4489 L .70234 .41918 L p .771 .801 .877 r
F P
0 g
s
.70234 .41918 m .71518 .41064 L .73168 .44277 L p .771 .801 .877 r
F P
0 g
s
.75936 .43345 m .74548 .43755 L .72811 .40305 L p .72 .778 .898 r
F P
0 g
s
.71518 .41064 m .72811 .40305 L .74548 .43755 L p .749 .791 .887 r
F P
0 g
s
.71795 .4489 m .70424 .45571 L .68956 .42839 L p .785 .807 .87 r
F P
0 g
s
.68956 .42839 m .70234 .41918 L .71795 .4489 L p .785 .807 .87 r
F P
0 g
s
.62164 .49149 m .60776 .49372 L .60038 .48237 L p .663 .773 .931 r
F P
0 g
s
.58767 .48512 m .60038 .48237 L .60776 .49372 L p .605 .749 .946 r
F P
0 g
s
.70424 .45571 m .69054 .46286 L .67681 .43795 L p .793 .811 .867 r
F P
0 g
s
.67681 .43795 m .68956 .42839 L .70424 .45571 L p .793 .811 .867 r
F P
0 g
s
.77335 .43054 m .75936 .43345 L .74115 .39659 L p .685 .761 .909 r
F P
0 g
s
.72811 .40305 m .74115 .39659 L .75936 .43345 L p .72 .778 .898 r
F P
0 g
s
.36532 .42217 m .37811 .42407 L .36209 .4476 L p .73 .86 .942 r
F P
0 g
s
.36209 .4476 m .34805 .44895 L .36532 .42217 L p .73 .86 .942 r
F P
0 g
s
.55599 .48028 m .56647 .47849 L .575 .48633 L p .475 .673 .951 r
F P
0 g
s
.56647 .47849 m .55599 .48028 L .54741 .47437 L p .469 .661 .945 r
F P
0 g
s
.69054 .46286 m .67683 .47001 L .66408 .44748 L p .793 .813 .868 r
F P
0 g
s
.66408 .44748 m .67681 .43795 L .69054 .46286 L p .793 .813 .868 r
F P
0 g
s
.63549 .4878 m .62164 .49149 L .61312 .47803 L p .71 .791 .914 r
F P
0 g
s
.60038 .48237 m .61312 .47803 L .62164 .49149 L p .663 .773 .931 r
F P
0 g
s
.52667 .45771 m .52627 .46416 L .51523 .4606 L p .412 .636 .948 r
F P
0 g
s
.51523 .4606 m .51186 .45338 L .52667 .45771 L p .412 .636 .948 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47637 .44368 L p .451 .692 .969 r
F P
0 g
s
.47637 .44368 m .46642 .43712 L .48419 .43581 L p .451 .692 .969 r
F P
0 g
s
.78745 .42885 m .77335 .43054 L .75433 .39138 L p .647 .742 .918 r
F P
0 g
s
.74115 .39659 m .75433 .39138 L .77335 .43054 L p .685 .761 .909 r
F P
0 g
s
.67683 .47001 m .66309 .47677 L .65135 .4566 L p .786 .812 .874 r
F P
0 g
s
.65135 .4566 m .66408 .44748 L .67683 .47001 L p .786 .812 .874 r
F P
0 g
s
.58767 .48512 m .575 .48633 L .56647 .47849 L p .543 .701 .943 r
F P
0 g
s
.64931 .48281 m .63549 .4878 L .62587 .47217 L p .745 .802 .898 r
F P
0 g
s
.61312 .47803 m .62587 .47217 L .63549 .4878 L p .71 .791 .914 r
F P
0 g
s
.66309 .47677 m .64931 .48281 L .63862 .46494 L p .77 .809 .884 r
F P
0 g
s
.63862 .46494 m .65135 .4566 L .66309 .47677 L p .77 .809 .884 r
F P
0 g
s
.62587 .47217 m .63862 .46494 L .64931 .48281 L p .745 .802 .898 r
F P
0 g
s
.4361 .41951 m .44629 .42507 L .42837 .43347 L p .585 .807 .984 r
F P
0 g
s
.42837 .43347 m .41594 .4305 L .4361 .41951 L p .585 .807 .984 r
F P
0 g
s
.8017 .42828 m .78745 .42885 L .76765 .3874 L p .608 .721 .925 r
F P
0 g
s
.75433 .39138 m .76765 .3874 L .78745 .42885 L p .647 .742 .918 r
F P
0 g
s
.50847 .44573 m .51186 .45338 L .49806 .45095 L p .428 .655 .954 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50847 .44573 L p .428 .655 .954 r
F P
0 g
s
.54741 .47437 m .555 .47074 L .56647 .47849 L p .469 .661 .945 r
F P
0 g
s
.555 .47074 m .54741 .47437 L .53726 .46886 L p .455 .65 .943 r
F P
0 g
s
.5414 .46364 m .53726 .46886 L .52627 .46416 L p .434 .641 .944 r
F P
0 g
s
.52627 .46416 m .52667 .45771 L .5414 .46364 L p .434 .641 .944 r
F P
0 g
s
.53726 .46886 m .5414 .46364 L .555 .47074 L p .455 .65 .943 r
F P
0 g
s
.35245 .42007 m .36532 .42217 L .34805 .44895 L p .732 .848 .935 r
F P
0 g
s
.34805 .44895 m .33396 .45005 L .35245 .42007 L p .732 .848 .935 r
F P
0 g
s
.81607 .42867 m .8017 .42828 L .78114 .3846 L p .571 .7 .929 r
F P
0 g
s
.76765 .3874 m .78114 .3846 L .8017 .42828 L p .608 .721 .925 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46642 .43712 L p .487 .717 .972 r
F P
0 g
s
.46642 .43712 m .45639 .43092 L .47717 .42815 L p .487 .717 .972 r
F P
0 g
s
.60038 .48237 m .58767 .48512 L .57702 .47536 L p .607 .725 .928 r
F P
0 g
s
.56647 .47849 m .57702 .47536 L .58767 .48512 L p .543 .701 .943 r
F P
0 g
s
.42582 .41419 m .4361 .41951 L .41594 .4305 L p .62 .825 .979 r
F P
0 g
s
.41594 .4305 m .40343 .42806 L .42582 .41419 L p .62 .825 .979 r
F P
0 g
s
.57702 .47536 m .56647 .47849 L .555 .47074 L p .534 .683 .935 r
F P
0 g
s
.33951 .41761 m .35245 .42007 L .33396 .45005 L p .728 .83 .928 r
F P
0 g
s
.33396 .45005 m .31982 .45068 L .33951 .41761 L p .728 .83 .928 r
F P
0 g
s
.83057 .42981 m .81607 .42867 L .79479 .38279 L p .542 .684 .931 r
F P
0 g
s
.78114 .3846 m .79479 .38279 L .81607 .42867 L p .571 .7 .929 r
F P
0 g
s
.52706 .45051 m .52667 .45771 L .51186 .45338 L p .454 .651 .944 r
F P
0 g
s
.51186 .45338 m .50847 .44573 L .52706 .45051 L p .454 .651 .944 r
F P
0 g
s
.50504 .43762 m .50847 .44573 L .49116 .44341 L p .464 .673 .954 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50504 .43762 L p .464 .673 .954 r
F P
0 g
s
.61312 .47803 m .60038 .48237 L .58763 .47073 L p .66 .741 .91 r
F P
0 g
s
.57702 .47536 m .58763 .47073 L .60038 .48237 L p .607 .725 .928 r
F P
0 g
s
.555 .47074 m .56265 .46589 L .57702 .47536 L p .534 .683 .935 r
F P
0 g
s
.56265 .46589 m .555 .47074 L .5414 .46364 L p .513 .667 .932 r
F P
0 g
s
.84517 .43141 m .83057 .42981 L .80859 .38174 L p .524 .673 .932 r
F P
0 g
s
.79479 .38279 m .80859 .38174 L .83057 .42981 L p .542 .684 .931 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45639 .43092 L p .524 .74 .973 r
F P
0 g
s
.45639 .43092 m .44629 .42507 L .47008 .42042 L p .524 .74 .973 r
F P
0 g
s
.32652 .41464 m .33951 .41761 L .31982 .45068 L p .717 .809 .922 r
F P
0 g
s
.31982 .45068 m .30567 .45062 L .32652 .41464 L p .717 .809 .922 r
F P
0 g
s
.54558 .45739 m .5414 .46364 L .52667 .45771 L p .484 .656 .936 r
F P
0 g
s
.52667 .45771 m .52706 .45051 L .54558 .45739 L p .484 .656 .936 r
F P
0 g
s
.41546 .40902 m .42582 .41419 L .40343 .42806 L p .648 .836 .972 r
F P
0 g
s
.40343 .42806 m .39082 .42597 L .41546 .40902 L p .648 .836 .972 r
F P
0 g
s
.5414 .46364 m .54558 .45739 L .56265 .46589 L p .513 .667 .932 r
F P
0 g
s
.58763 .47073 m .57702 .47536 L .56265 .46589 L p .592 .7 .918 r
F P
0 g
s
.62587 .47217 m .61312 .47803 L .59829 .46454 L p .701 .753 .892 r
F P
0 g
s
.58763 .47073 m .59829 .46454 L .61312 .47803 L p .66 .741 .91 r
F P
0 g
s
.85986 .43317 m .84517 .43141 L .82254 .38116 L p .517 .67 .932 r
F P
0 g
s
.80859 .38174 m .82254 .38116 L .84517 .43141 L p .524 .673 .932 r
F P
0 g
s
.31349 .41107 m .32652 .41464 L .30567 .45062 L p .702 .786 .916 r
F P
0 g
s
.30567 .45062 m .29152 .44973 L .31349 .41107 L p .702 .786 .916 r
F P
0 g
s
.52747 .44246 m .52706 .45051 L .50847 .44573 L p .495 .665 .938 r
F P
0 g
s
.50847 .44573 m .50504 .43762 L .52747 .44246 L p .495 .665 .938 r
F P
0 g
s
.50159 .42903 m .50504 .43762 L .48419 .43581 L p .501 .69 .952 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50159 .42903 L p .501 .69 .952 r
F P
0 g
s
.63862 .46494 m .62587 .47217 L .60898 .45685 L p .733 .76 .875 r
F P
0 g
s
.59829 .46454 m .60898 .45685 L .62587 .47217 L p .701 .753 .892 r
F P
0 g
s
.40501 .40392 m .41546 .40902 L .39082 .42597 L p .671 .839 .964 r
F P
0 g
s
.39082 .42597 m .37811 .42407 L .40501 .40392 L p .671 .839 .964 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44629 .42507 L p .558 .76 .972 r
F P
0 g
s
.44629 .42507 m .4361 .41951 L .46294 .41262 L p .558 .76 .972 r
F P
0 g
s
.30042 .40684 m .31349 .41107 L .29152 .44973 L p .684 .762 .91 r
F P
0 g
s
.29152 .44973 m .27739 .44794 L .30042 .40684 L p .684 .762 .91 r
F P
0 g
s
.82254 .38116 m .8366 .38074 L .85986 .43317 L p .517 .67 .932 r
F P
0 g
s
.65135 .4566 m .63862 .46494 L .61969 .44781 L p .754 .764 .861 r
F P
0 g
s
.60898 .45685 m .61969 .44781 L .63862 .46494 L p .733 .76 .875 r
F P
0 g
s
.56265 .46589 m .57036 .45967 L .58763 .47073 L p .592 .7 .918 r
F P
0 g
s
.57036 .45967 m .56265 .46589 L .54558 .45739 L p .565 .68 .917 r
F P
0 g
s
.59829 .46454 m .58763 .47073 L .57036 .45967 L p .64 .712 .899 r
F P
0 g
s
.5498 .45 m .54558 .45739 L .52706 .45051 L p .531 .668 .924 r
F P
0 g
s
.52706 .45051 m .52747 .44246 L .5498 .45 L p .531 .668 .924 r
F P
0 g
s
.66408 .44748 m .65135 .4566 L .63042 .43767 L p .768 .767 .852 r
F P
0 g
s
.61969 .44781 m .63042 .43767 L .65135 .4566 L p .754 .764 .861 r
F P
0 g
s
.28734 .40194 m .30042 .40684 L .27739 .44794 L p .665 .738 .905 r
F P
0 g
s
.27739 .44794 m .26328 .44525 L .28734 .40194 L p .665 .738 .905 r
F P
0 g
s
.54558 .45739 m .5498 .45 L .57036 .45967 L p .565 .68 .917 r
F P
0 g
s
.67681 .43795 m .66408 .44748 L .64116 .42675 L p .776 .77 .847 r
F P
0 g
s
.63042 .43767 m .64116 .42675 L .66408 .44748 L p .768 .767 .852 r
F P
0 g
s
.39448 .39878 m .40501 .40392 L .37811 .42407 L p .687 .836 .955 r
F P
0 g
s
.37811 .42407 m .36532 .42217 L .39448 .39878 L p .687 .836 .955 r
F P
0 g
s
.27423 .39642 m .28734 .40194 L .26328 .44525 L p .645 .716 .9 r
F P
0 g
s
.26328 .44525 m .24921 .4417 L .27423 .39642 L p .645 .716 .9 r
F P
0 g
s
.68956 .42839 m .67681 .43795 L .65194 .4154 L p .777 .771 .848 r
F P
0 g
s
.64116 .42675 m .65194 .4154 L .67681 .43795 L p .776 .77 .847 r
F P
0 g
s
.4981 .41996 m .50159 .42903 L .47717 .42815 L p .535 .705 .949 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .4981 .41996 L p .535 .705 .949 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .4361 .41951 L p .59 .775 .968 r
F P
0 g
s
.4361 .41951 m .42582 .41419 L .45573 .40475 L p .59 .775 .968 r
F P
0 g
s
.70234 .41918 m .68956 .42839 L .66274 .40399 L p .772 .772 .853 r
F P
0 g
s
.65194 .4154 m .66274 .40399 L .68956 .42839 L p .777 .771 .848 r
F P
0 g
s
.52787 .43355 m .52747 .44246 L .50504 .43762 L p .534 .676 .929 r
F P
0 g
s
.50504 .43762 m .50159 .42903 L .52787 .43355 L p .534 .676 .929 r
F P
0 g
s
.2611 .39035 m .27423 .39642 L .24921 .4417 L p .627 .698 .896 r
F P
0 g
s
.24921 .4417 m .23517 .43742 L .2611 .39035 L p .627 .698 .896 r
F P
0 g
s
.71518 .41064 m .70234 .41918 L .67361 .39289 L p .76 .772 .863 r
F P
0 g
s
.66274 .40399 m .67361 .39289 L .70234 .41918 L p .772 .772 .853 r
F P
0 g
s
.60898 .45685 m .59829 .46454 L .57811 .45202 L p .678 .719 .88 r
F P
0 g
s
.57036 .45967 m .57811 .45202 L .59829 .46454 L p .64 .712 .899 r
F P
0 g
s
.24795 .38387 m .2611 .39035 L .23517 .43742 L p .613 .685 .894 r
F P
0 g
s
.23517 .43742 m .22116 .4326 L .24795 .38387 L p .613 .685 .894 r
F P
0 g
s
.57811 .45202 m .57036 .45967 L .5498 .45 L p .61 .689 .899 r
F P
0 g
s
.72811 .40305 m .71518 .41064 L .68454 .38242 L p .742 .771 .876 r
F P
0 g
s
.67361 .39289 m .68454 .38242 L .71518 .41064 L p .76 .772 .863 r
F P
0 g
s
.23477 .37712 m .24795 .38387 L .22116 .4326 L p .602 .677 .894 r
F P
0 g
s
.22116 .4326 m .20717 .42743 L .23477 .37712 L p .602 .677 .894 r
F P
0 g
s
.22154 .37026 m .23477 .37712 L .20717 .42743 L p .596 .675 .895 r
F P
0 g
s
.20717 .42743 m .19318 .42214 L .22154 .37026 L p .596 .675 .895 r
F P
0 g
s
.38386 .39351 m .39448 .39878 L .36532 .42217 L p .696 .827 .946 r
F P
0 g
s
.36532 .42217 m .35245 .42007 L .38386 .39351 L p .696 .827 .946 r
F P
0 g
s
.55404 .44142 m .5498 .45 L .52747 .44246 L p .573 .676 .91 r
F P
0 g
s
.52747 .44246 m .52787 .43355 L .55404 .44142 L p .573 .676 .91 r
F P
0 g
s
.74115 .39659 m .72811 .40305 L .69557 .37284 L p .717 .767 .892 r
F P
0 g
s
.68454 .38242 m .69557 .37284 L .72811 .40305 L p .742 .771 .876 r
F P
0 g
s
.5498 .45 m .55404 .44142 L .57811 .45202 L p .61 .689 .899 r
F P
0 g
s
.61969 .44781 m .60898 .45685 L .58591 .443 L p .706 .724 .864 r
F P
0 g
s
.57811 .45202 m .58591 .443 L .60898 .45685 L p .678 .719 .88 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42582 .41419 L p .618 .786 .962 r
F P
0 g
s
.42582 .41419 m .41546 .40902 L .44846 .39682 L p .618 .786 .962 r
F P
0 g
s
.49459 .41046 m .4981 .41996 L .47008 .42042 L p .567 .719 .944 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49459 .41046 L p .567 .719 .944 r
F P
0 g
s
.75433 .39138 m .74115 .39659 L .70673 .36434 L p .685 .76 .909 r
F P
0 g
s
.69557 .37284 m .70673 .36434 L .74115 .39659 L p .717 .767 .892 r
F P
0 g
s
.52828 .4238 m .52787 .43355 L .50159 .42903 L p .568 .686 .92 r
F P
0 g
s
.50159 .42903 m .4981 .41996 L .52828 .4238 L p .568 .686 .92 r
F P
0 g
s
.58591 .443 m .57811 .45202 L .55404 .44142 L p .645 .695 .882 r
F P
0 g
s
.63042 .43767 m .61969 .44781 L .59374 .43274 L p .727 .728 .851 r
F P
0 g
s
.58591 .443 m .59374 .43274 L .61969 .44781 L p .706 .724 .864 r
F P
0 g
s
.37317 .38801 m .38386 .39351 L .35245 .42007 L p .699 .814 .936 r
F P
0 g
s
.35245 .42007 m .33951 .41761 L .37317 .38801 L p .699 .814 .936 r
F P
0 g
s
.76765 .3874 m .75433 .39138 L .71801 .35702 L p .648 .75 .924 r
F P
0 g
s
.70673 .36434 m .71801 .35702 L .75433 .39138 L p .685 .76 .909 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41546 .40902 L p .641 .792 .955 r
F P
0 g
s
.41546 .40902 m .40501 .40392 L .44112 .38881 L p .641 .792 .955 r
F P
0 g
s
.55832 .43168 m .55404 .44142 L .52787 .43355 L p .607 .683 .896 r
F P
0 g
s
.52787 .43355 m .52828 .4238 L .55832 .43168 L p .607 .683 .896 r
F P
0 g
s
.55404 .44142 m .55832 .43168 L .58591 .443 L p .645 .695 .882 r
F P
0 g
s
.64116 .42675 m .63042 .43767 L .6016 .42146 L p .74 .731 .843 r
F P
0 g
s
.59374 .43274 m .6016 .42146 L .63042 .43767 L p .727 .728 .851 r
F P
0 g
s
.49104 .40059 m .49459 .41046 L .46294 .41262 L p .595 .73 .938 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49104 .40059 L p .595 .73 .938 r
F P
0 g
s
.78114 .3846 m .76765 .3874 L .72945 .35089 L p .607 .737 .937 r
F P
0 g
s
.71801 .35702 m .72945 .35089 L .76765 .3874 L p .648 .75 .924 r
F P
0 g
s
.3624 .38222 m .37317 .38801 L .33951 .41761 L p .697 .798 .927 r
F P
0 g
s
.33951 .41761 m .32652 .41464 L .3624 .38222 L p .697 .798 .927 r
F P
0 g
s
.59374 .43274 m .58591 .443 L .55832 .43168 L p .672 .699 .867 r
F P
0 g
s
.52869 .41328 m .52828 .4238 L .4981 .41996 L p .597 .694 .91 r
F P
0 g
s
.4981 .41996 m .49459 .41046 L .52869 .41328 L p .597 .694 .91 r
F P
0 g
s
.65194 .4154 m .64116 .42675 L .60948 .40944 L p .749 .735 .839 r
F P
0 g
s
.6016 .42146 m .60948 .40944 L .64116 .42675 L p .74 .731 .843 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40501 .40392 L p .658 .794 .947 r
F P
0 g
s
.40501 .40392 m .39448 .39878 L .43372 .38074 L p .658 .794 .947 r
F P
0 g
s
.66274 .40399 m .65194 .4154 L .61741 .397 L p .752 .739 .84 r
F P
0 g
s
.60948 .40944 m .61741 .397 L .65194 .4154 L p .749 .735 .839 r
F P
0 g
s
.79479 .38279 m .78114 .3846 L .74105 .34587 L p .568 .723 .946 r
F P
0 g
s
.72945 .35089 m .74105 .34587 L .78114 .3846 L p .607 .737 .937 r
F P
0 g
s
.55832 .43168 m .56262 .42091 L .59374 .43274 L p .672 .699 .867 r
F P
0 g
s
.56262 .42091 m .55832 .43168 L .52828 .4238 L p .635 .688 .883 r
F P
0 g
s
.52828 .4238 m .52869 .41328 L .56262 .42091 L p .635 .688 .883 r
F P
0 g
s
.35157 .37607 m .3624 .38222 L .32652 .41464 L p .692 .78 .918 r
F P
0 g
s
.32652 .41464 m .31349 .41107 L .35157 .37607 L p .692 .78 .918 r
F P
0 g
s
.48747 .39043 m .49104 .40059 L .45573 .40475 L p .619 .739 .932 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48747 .39043 L p .619 .739 .932 r
F P
0 g
s
.6016 .42146 m .59374 .43274 L .56262 .42091 L p .693 .703 .855 r
F P
0 g
s
.67361 .39289 m .66274 .40399 L .62538 .38449 L p .75 .743 .846 r
F P
0 g
s
.61741 .397 m .62538 .38449 L .66274 .40399 L p .752 .739 .84 r
F P
0 g
s
.52911 .40212 m .52869 .41328 L .49459 .41046 L p .622 .701 .902 r
F P
0 g
s
.49459 .41046 m .49104 .40059 L .52911 .40212 L p .622 .701 .902 r
F P
0 g
s
.80859 .38174 m .79479 .38279 L .75282 .3418 L p .535 .709 .952 r
F P
0 g
s
.74105 .34587 m .75282 .3418 L .79479 .38279 L p .568 .723 .946 r
F P
0 g
s
.68454 .38242 m .67361 .39289 L .6334 .37222 L p .742 .748 .857 r
F P
0 g
s
.62538 .38449 m .6334 .37222 L .67361 .39289 L p .75 .743 .846 r
F P
0 g
s
.34067 .36954 m .35157 .37607 L .31349 .41107 L p .683 .761 .91 r
F P
0 g
s
.31349 .41107 m .30042 .40684 L .34067 .36954 L p .683 .761 .91 r
F P
0 g
s
.60948 .40944 m .6016 .42146 L .56695 .40927 L p .707 .707 .847 r
F P
0 g
s
.56262 .42091 m .56695 .40927 L .6016 .42146 L p .693 .703 .855 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39448 .39878 L p .671 .791 .939 r
F P
0 g
s
.39448 .39878 m .38386 .39351 L .42626 .3726 L p .671 .791 .939 r
F P
0 g
s
.56695 .40927 m .56262 .42091 L .52869 .41328 L p .657 .693 .872 r
F P
0 g
s
.52869 .41328 m .52911 .40212 L .56695 .40927 L p .657 .693 .872 r
F P
0 g
s
.48387 .38008 m .48747 .39043 L .44846 .39682 L p .639 .746 .926 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48387 .38008 L p .639 .746 .926 r
F P
0 g
s
.69557 .37284 m .68454 .38242 L .64149 .36048 L p .73 .753 .871 r
F P
0 g
s
.6334 .37222 m .64149 .36048 L .68454 .38242 L p .742 .748 .857 r
F P
0 g
s
.32972 .36263 m .34067 .36954 L .30042 .40684 L p .673 .743 .903 r
F P
0 g
s
.30042 .40684 m .28734 .40194 L .32972 .36263 L p .673 .743 .903 r
F P
0 g
s
.82254 .38116 m .80859 .38174 L .76474 .33845 L p .514 .7 .954 r
F P
0 g
s
.75282 .3418 m .76474 .33845 L .80859 .38174 L p .535 .709 .952 r
F P
0 g
s
.52952 .39048 m .52911 .40212 L .49104 .40059 L p .641 .708 .895 r
F P
0 g
s
.49104 .40059 m .48747 .39043 L .52952 .39048 L p .641 .708 .895 r
F P
0 g
s
.61741 .397 m .60948 .40944 L .5713 .397 L p .717 .712 .844 r
F P
0 g
s
.56695 .40927 m .5713 .397 L .60948 .40944 L p .707 .707 .847 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38386 .39351 L p .68 .786 .93 r
F P
0 g
s
.38386 .39351 m .37317 .38801 L .41873 .36438 L p .68 .786 .93 r
F P
0 g
s
.70673 .36434 m .69557 .37284 L .64966 .34951 L p .71 .757 .889 r
F P
0 g
s
.64149 .36048 m .64966 .34951 L .69557 .37284 L p .73 .753 .871 r
F P
0 g
s
.5713 .397 m .56695 .40927 L .52911 .40212 L p .673 .698 .865 r
F P
0 g
s
.3187 .35535 m .32972 .36263 L .28734 .40194 L p .662 .727 .898 r
F P
0 g
s
.28734 .40194 m .27423 .39642 L .3187 .35535 L p .662 .727 .898 r
F P
0 g
s
.52911 .40212 m .52952 .39048 L .5713 .397 L p .673 .698 .865 r
F P
0 g
s
.48023 .36963 m .48387 .38008 L .44112 .38881 L p .654 .751 .921 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48023 .36963 L p .654 .751 .921 r
F P
0 g
s
.62538 .38449 m .61741 .397 L .57568 .38435 L p .723 .717 .845 r
F P
0 g
s
.5713 .397 m .57568 .38435 L .61741 .397 L p .717 .712 .844 r
F P
0 g
s
.8366 .38074 m .82254 .38116 L .77681 .33553 L p .506 .696 .954 r
F P
0 g
s
.76474 .33845 m .77681 .33553 L .82254 .38116 L p .514 .7 .954 r
F P
0 g
s
.71801 .35702 m .70673 .36434 L .65793 .33949 L p .685 .76 .908 r
F P
0 g
s
.64966 .34951 m .65793 .33949 L .70673 .36434 L p .71 .757 .889 r
F P
0 g
s
.52995 .37854 m .52952 .39048 L .48747 .39043 L p .657 .715 .891 r
F P
0 g
s
.48747 .39043 m .48387 .38008 L .52995 .37854 L p .657 .715 .891 r
F P
0 g
s
.30762 .34776 m .3187 .35535 L .27423 .39642 L p .651 .714 .894 r
F P
0 g
s
.27423 .39642 m .2611 .39035 L .30762 .34776 L p .651 .714 .894 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37317 .38801 L p .684 .779 .923 r
F P
0 g
s
.37317 .38801 m .3624 .38222 L .41113 .35609 L p .684 .779 .923 r
F P
0 g
s
.57568 .38435 m .5713 .397 L .52952 .39048 L p .685 .704 .862 r
F P
0 g
s
.6334 .37222 m .62538 .38449 L .58009 .3716 L p .724 .725 .85 r
F P
0 g
s
.57568 .38435 m .58009 .3716 L .62538 .38449 L p .723 .717 .845 r
F P
0 g
s
.29648 .33991 m .30762 .34776 L .2611 .39035 L p .642 .704 .892 r
F P
0 g
s
.2611 .39035 m .24795 .38387 L .29648 .33991 L p .642 .704 .892 r
F P
0 g
s
.52952 .39048 m .52995 .37854 L .57568 .38435 L p .685 .704 .862 r
F P
0 g
s
.72945 .35089 m .71801 .35702 L .66632 .3305 L p .653 .759 .928 r
F P
0 g
s
.65793 .33949 m .66632 .3305 L .71801 .35702 L p .685 .76 .908 r
F P
0 g
s
.47656 .35919 m .48023 .36963 L .43372 .38074 L p .666 .755 .916 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47656 .35919 L p .666 .755 .916 r
F P
0 g
s
.77681 .33553 m .78901 .33274 L .8366 .38074 L p .506 .696 .954 r
F P
0 g
s
.64149 .36048 m .6334 .37222 L .58453 .35901 L p .721 .733 .86 r
F P
0 g
s
.58009 .3716 m .58453 .35901 L .6334 .37222 L p .724 .725 .85 r
F P
0 g
s
.28528 .33187 m .29648 .33991 L .24795 .38387 L p .634 .698 .892 r
F P
0 g
s
.24795 .38387 m .23477 .37712 L .28528 .33187 L p .634 .698 .892 r
F P
0 g
s
.53037 .36649 m .52995 .37854 L .48387 .38008 L p .669 .722 .889 r
F P
0 g
s
.48387 .38008 m .48023 .36963 L .53037 .36649 L p .669 .722 .889 r
F P
0 g
s
.58009 .3716 m .57568 .38435 L .52995 .37854 L p .694 .711 .862 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .3624 .38222 L p .685 .77 .916 r
F P
0 g
s
.3624 .38222 m .35157 .37607 L .40346 .34772 L p .685 .77 .916 r
F P
0 g
s
.74105 .34587 m .72945 .35089 L .67482 .32255 L p .617 .756 .944 r
F P
0 g
s
.66632 .3305 m .67482 .32255 L .72945 .35089 L p .653 .759 .928 r
F P
0 g
s
.27399 .32374 m .28528 .33187 L .23477 .37712 L p .629 .696 .894 r
F P
0 g
s
.23477 .37712 m .22154 .37026 L .27399 .32374 L p .629 .696 .894 r
F P
0 g
s
.52995 .37854 m .53037 .36649 L .58009 .3716 L p .694 .711 .862 r
F P
0 g
s
.64966 .34951 m .64149 .36048 L .58902 .34683 L p .714 .742 .873 r
F P
0 g
s
.58453 .35901 m .58902 .34683 L .64149 .36048 L p .721 .733 .86 r
F P
0 g
s
.47286 .34883 m .47656 .35919 L .42626 .3726 L p .675 .757 .913 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47286 .34883 L p .675 .757 .913 r
F P
0 g
s
.58453 .35901 m .58009 .3716 L .53037 .36649 L p .699 .719 .865 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35157 .37607 L p .683 .761 .91 r
F P
0 g
s
.35157 .37607 m .34067 .36954 L .39573 .33928 L p .683 .761 .91 r
F P
0 g
s
.5308 .35452 m .53037 .36649 L .48023 .36963 L p .677 .729 .889 r
F P
0 g
s
.48023 .36963 m .47656 .35919 L .5308 .35452 L p .677 .729 .889 r
F P
0 g
s
.75282 .3418 m .74105 .34587 L .68346 .31557 L p .581 .749 .957 r
F P
0 g
s
.67482 .32255 m .68346 .31557 L .74105 .34587 L p .617 .756 .944 r
F P
0 g
s
.65793 .33949 m .64966 .34951 L .59356 .33524 L p .702 .751 .89 r
F P
0 g
s
.58902 .34683 m .59356 .33524 L .64966 .34951 L p .714 .742 .873 r
F P
0 g
s
.53037 .36649 m .5308 .35452 L .58453 .35901 L p .699 .719 .865 r
F P
0 g
s
.46911 .33863 m .47286 .34883 L .41873 .36438 L p .68 .759 .911 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46911 .33863 L p .68 .759 .911 r
F P
0 g
s
.58902 .34683 m .58453 .35901 L .5308 .35452 L p .7 .728 .872 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34067 .36954 L p .679 .751 .906 r
F P
0 g
s
.34067 .36954 m .32972 .36263 L .38792 .33076 L p .679 .751 .906 r
F P
0 g
s
.53123 .3428 m .5308 .35452 L .47656 .35919 L p .683 .737 .891 r
F P
0 g
s
.47656 .35919 m .47286 .34883 L .53123 .3428 L p .683 .737 .891 r
F P
0 g
s
.66632 .3305 m .65793 .33949 L .59816 .3244 L p .684 .759 .908 r
F P
0 g
s
.59356 .33524 m .59816 .3244 L .65793 .33949 L p .702 .751 .89 r
F P
0 g
s
.76474 .33845 m .75282 .3418 L .69223 .30942 L p .55 .741 .965 r
F P
0 g
s
.68346 .31557 m .69223 .30942 L .75282 .3418 L p .581 .749 .957 r
F P
0 g
s
.5308 .35452 m .53123 .3428 L .58902 .34683 L p .7 .728 .872 r
F P
0 g
s
.59356 .33524 m .58902 .34683 L .53123 .3428 L p .698 .738 .882 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32972 .36263 L p .674 .742 .902 r
F P
0 g
s
.32972 .36263 m .3187 .35535 L .38005 .32217 L p .674 .742 .902 r
F P
0 g
s
.46533 .32864 m .46911 .33863 L .41113 .35609 L p .682 .76 .91 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46533 .32864 L p .682 .76 .91 r
F P
0 g
s
.53167 .33147 m .53123 .3428 L .47286 .34883 L p .686 .744 .896 r
F P
0 g
s
.47286 .34883 m .46911 .33863 L .53167 .33147 L p .686 .744 .896 r
F P
0 g
s
.67482 .32255 m .66632 .3305 L .60282 .31436 L p .662 .766 .927 r
F P
0 g
s
.59816 .3244 m .60282 .31436 L .66632 .3305 L p .684 .759 .908 r
F P
0 g
s
.77681 .33553 m .76474 .33845 L .70112 .30388 L p .528 .734 .969 r
F P
0 g
s
.69223 .30942 m .70112 .30388 L .76474 .33845 L p .55 .741 .965 r
F P
0 g
s
.53123 .3428 m .53167 .33147 L .59356 .33524 L p .698 .738 .882 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .3187 .35535 L p .668 .735 .9 r
F P
0 g
s
.3187 .35535 m .30762 .34776 L .3721 .3135 L p .668 .735 .9 r
F P
0 g
s
.59816 .3244 m .59356 .33524 L .53167 .33147 L p .692 .749 .895 r
F P
0 g
s
.4615 .31889 m .46533 .32864 L .40346 .34772 L p .683 .76 .91 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .4615 .31889 L p .683 .76 .91 r
F P
0 g
s
.68346 .31557 m .67482 .32255 L .60755 .30515 L p .636 .77 .944 r
F P
0 g
s
.60282 .31436 m .60755 .30515 L .67482 .32255 L p .662 .766 .927 r
F P
0 g
s
.53211 .32062 m .53167 .33147 L .46911 .33863 L p .685 .752 .902 r
F P
0 g
s
.46911 .33863 m .46533 .32864 L .53211 .32062 L p .685 .752 .902 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30762 .34776 L p .661 .729 .9 r
F P
0 g
s
.30762 .34776 m .29648 .33991 L .36408 .30475 L p .661 .729 .9 r
F P
0 g
s
.78901 .33274 m .77681 .33553 L .71014 .29871 L p .521 .73 .969 r
F P
0 g
s
.70112 .30388 m .71014 .29871 L .77681 .33553 L p .528 .734 .969 r
F P
0 g
s
.53167 .33147 m .53211 .32062 L .59816 .3244 L p .692 .749 .895 r
F P
0 g
s
.60282 .31436 m .59816 .3244 L .53211 .32062 L p .683 .759 .909 r
F P
0 g
s
.45762 .30938 m .4615 .31889 L .39573 .33928 L p .681 .759 .911 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45762 .30938 L p .681 .759 .911 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29648 .33991 L p .655 .725 .9 r
F P
0 g
s
.29648 .33991 m .28528 .33187 L .35599 .29592 L p .655 .725 .9 r
F P
0 g
s
.69223 .30942 m .68346 .31557 L .61235 .2967 L p .608 .771 .958 r
F P
0 g
s
.60755 .30515 m .61235 .2967 L .68346 .31557 L p .636 .77 .944 r
F P
0 g
s
.53256 .31032 m .53211 .32062 L .46533 .32864 L p .683 .759 .909 r
F P
0 g
s
.46533 .32864 m .4615 .31889 L .53256 .31032 L p .683 .759 .909 r
F P
0 g
s
.71014 .29871 m .71927 .29362 L .78901 .33274 L p .521 .73 .969 r
F P
0 g
s
.53211 .32062 m .53256 .31032 L .60282 .31436 L p .683 .759 .909 r
F P
0 g
s
.60755 .30515 m .60282 .31436 L .53256 .31032 L p .671 .768 .923 r
F P
0 g
s
.4537 .30008 m .45762 .30938 L .38792 .33076 L p .677 .758 .912 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .4537 .30008 L p .677 .758 .912 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28528 .33187 L p .65 .723 .902 r
F P
0 g
s
.28528 .33187 m .27399 .32374 L .34782 .287 L p .65 .723 .902 r
F P
0 g
s
.53301 .30056 m .53256 .31032 L .4615 .31889 L p .678 .766 .917 r
F P
0 g
s
.4615 .31889 m .45762 .30938 L .53301 .30056 L p .678 .766 .917 r
F P
0 g
s
.70112 .30388 m .69223 .30942 L .61722 .28889 L p .584 .769 .967 r
F P
0 g
s
.61235 .2967 m .61722 .28889 L .69223 .30942 L p .608 .771 .958 r
F P
0 g
s
.53256 .31032 m .53301 .30056 L .60755 .30515 L p .671 .768 .923 r
F P
0 g
s
.61235 .2967 m .60755 .30515 L .53301 .30056 L p .656 .775 .937 r
F P
0 g
s
.44973 .29096 m .4537 .30008 L .38005 .32217 L p .673 .757 .914 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44973 .29096 L p .673 .757 .914 r
F P
0 g
s
.53348 .29131 m .53301 .30056 L .45762 .30938 L p .671 .771 .925 r
F P
0 g
s
.45762 .30938 m .4537 .30008 L .53348 .29131 L p .671 .771 .925 r
F P
0 g
s
.71014 .29871 m .70112 .30388 L .62217 .28156 L p .567 .765 .972 r
F P
0 g
s
.61722 .28889 m .62217 .28156 L .70112 .30388 L p .584 .769 .967 r
F P
0 g
s
.44572 .28195 m .44973 .29096 L .3721 .3135 L p .667 .755 .916 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44572 .28195 L p .667 .755 .916 r
F P
0 g
s
.53301 .30056 m .53348 .29131 L .61235 .2967 L p .656 .775 .937 r
F P
0 g
s
.61722 .28889 m .61235 .2967 L .53348 .29131 L p .64 .78 .948 r
F P
0 g
s
.53394 .28248 m .53348 .29131 L .4537 .30008 L p .663 .774 .932 r
F P
0 g
s
.4537 .30008 m .44973 .29096 L .53394 .28248 L p .663 .774 .932 r
F P
0 g
s
.44165 .27296 m .44572 .28195 L .36408 .30475 L p .661 .753 .918 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44165 .27296 L p .661 .753 .918 r
F P
0 g
s
.71927 .29362 m .71014 .29871 L .62718 .27448 L p .559 .762 .973 r
F P
0 g
s
.62217 .28156 m .62718 .27448 L .71014 .29871 L p .567 .765 .972 r
F P
0 g
s
.53348 .29131 m .53394 .28248 L .61722 .28889 L p .64 .78 .948 r
F P
0 g
s
.62217 .28156 m .61722 .28889 L .53394 .28248 L p .625 .781 .956 r
F P
0 g
s
.43754 .26392 m .44165 .27296 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53442 .27394 m .53394 .28248 L .44973 .29096 L p .655 .775 .937 r
F P
0 g
s
.44973 .29096 m .44572 .28195 L .53442 .27394 L p .655 .775 .937 r
F P
0 g
s
.62718 .27448 m .63227 .26744 L .71927 .29362 L p .559 .762 .973 r
F P
0 g
s
.53394 .28248 m .53442 .27394 L .62217 .28156 L p .625 .781 .956 r
F P
0 g
s
.62718 .27448 m .62217 .28156 L .53442 .27394 L p .613 .781 .961 r
F P
0 g
s
.5349 .26555 m .53442 .27394 L .44572 .28195 L p .648 .775 .941 r
F P
0 g
s
.44572 .28195 m .44165 .27296 L .5349 .26555 L p .648 .775 .941 r
F P
0 g
s
.53442 .27394 m .5349 .26555 L .62718 .27448 L p .613 .781 .961 r
F P
0 g
s
.63227 .26744 m .62718 .27448 L .5349 .26555 L p .606 .778 .963 r
F P
0 g
s
.53539 .25714 m .5349 .26555 L .44165 .27296 L p .641 .773 .943 r
F P
0 g
s
.44165 .27296 m .43754 .26392 L .53539 .25714 L p .641 .773 .943 r
F P
0 g
s
.5349 .26555 m .53539 .25714 L .63227 .26744 L p .606 .778 .963 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?nTaO400ol0003oVlOfoi_7mP04oi_7mP_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00005?nTaO46o`00017o
VlOf2ol0000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Cooooo
1?l00002ojO0j`03o`000?nTaO7oY<Ga00koY<Ga2ol00005ojG6l003o`000?nLaoKoW<Of00?oW<Of
2ol0000<oi_7mPOo00005?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo
000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`?o00001onW`>/00ol0003oY<GaojC5l@07ojC5l@Ko00004?nUa_000ol0003oW<Ofoic7
mP0>oic7mP[o00001OnKaoH01?l0003oSl?ioho3nOn?`oT3o`00017ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Joooool4o`0000WoYl3[0ol00002ojC5l@;o00005OnU
a_06o`0001[oW<Of1Ol00007oho3n@?o00003_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Vooooo`Co00002_nW`>/3o`0000;oZL3[00?o0000ojG6l?nUa_003OnUa_0:
o`0000GoYlK_00?o0000oio7m?nOao@00onOao@:o`0000ooW<Of00?o0000oi73n?nA`oP02?n?`oT3
o`0000_ooooo00?o0000ooooooooool0<oooool2o`0002kooooo000Kooooo`03oeEEEOmVIVKo0000
00Kooooo0_l0000:ooooo`03o`000?oooooooooo067ooooo1?l0000:ojO0j`Co00001_nY`>/00ol0
003oYLK`ojG6l005ojG6l0Oo00003onWa^l00ol0003oWlOdoio7m00=oio7m0Wo00001OnLaoH00ol0
003oTL?hoi73n004oi73n0;o00001_n?`oT4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05go
oooo0ol0000:ojO0j`Co00002?nY`>/3o`0000;oYLK`0_l0000DojO6k`Ko00006?nOao@5o`0000[o
TL?h0ol00006oho3n@?o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_o
oooo000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool4o`0000[oYl3[
0ol00009ojW0j`?o00000_nZ`NX00ol0003oYlK_ojO6k`0<ojO6k`[o00001OnYa^h00ol0003oXlOb
oj?7lP05oj?7lPko00001onOao@01?l0003oULCgoiG4mol0000:oi73n0?o00001_n?`oT3o`0000;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000:ojO0j`Co00002OnY`>/3o`0000KoZ/7Z
00?o0000ojO6konWa^l01?nWa^l7o`0000ooZLK^00?o0000oj?7l_nSao804onSao87o`0000OoULCg
0_l00008oi73n0?o00001_n?`oT3o`0003Oooooo00?o0000ooooooooool0:_ooool002Cooooo0_l0
000>ooooo`03o`000?oooooooooo057ooooo0_l00002ojJiiP03o`000?nW`>_oYl3[00GoYl3[0ol0
0009ojW0j`Co00001onZ`NX3o`000004ojO6kol0003o0000o`0001CoZLK^1Ol0000Koj?7lP04o`00
0?nKaOGoVlGeo`0000SoULCg0ol00006oi73n0?o00001On?`oT4o`0003Gooooo00?o0000oooooooo
ool0:Oooool002?ooooo0_l0000@ooooo`03o`000?oooooooooo04kooooo0_l00005ojJiiP03o`00
0?nW`>_oYl3[00;oYl3[00?o0000ojW0jonY`>/02?nY`>/3o`0000SoZ/7Z0ol00002ojc1j@03o`00
0?nYa^koZLK^00goZLK^2Ol00004oj_5k003o`000?nWa^ooYlK_00GoYlK_3Ol00006oj?7lP03o`00
0?nKaOGoVlGe00CoVlGe0ol00007oiG4m`?o00001OnA`oP3o`0000;oSl?i00Co0000oho3nOn?`oWo
Sl?i0ol0000cooooo`03o`000?oooooooooo02Sooooo000Tooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Boooool2o`0000OoY[WV0ol00009ojW0j`Co00002?nZ`NX3o`0000Ko[<7Y
00?o0000ojW6k_nYa^h01OnYa^h7o`0000coZlG/00?o0000ojO6konWa^l04onWa^l6o`0000_oVlGe
1?l00005oiG4m`Co00001?nA`oP3o`0000;oSl?i00Co0000ohFjn?n5^_SoQK[h0_l0000`ooooo`;o
0000:_ooool002?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`18ooooo`;o0000
1onV^NH2o`0000;oYkWV00?o0000ojW0jonY`>/01OnY`>/2o`0000WoZ/7Z0ol00008ojc1j@?o0000
00CoZLK^o`000?l0003o00004On[aN`5o`0001[oYlK_00Co0000oj;5lOnRaO7o00003?nKaOD3o`00
00KoULCg1?l00002oi73n0?o00001_n5^_P2o`00033ooooo00?o0000ooooooooool09oooool002?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001onV^NH2o`0000Go
YkWV00?o0000ojW0jonY`>/00_nY`>/00ol0003oZ/7Zoj[1jP06oj[1jPCo00002?n/`NT3o`0000;o
[L;Y00?o0000oj_5k?n[aN`02_n[aN`9o`0000Co[LCZ00?o0000oj_4k?n[a>`01?n[a>`=o`0000Ko
YlK_00?o0000oj;5lOnRaO401OnRaO44o`0000SoVlGe1?l00006oiG4m`?o00000on7^oP7ohFjn003
o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool002?ooooo0_l0000Dooooo`03o`00
0?oooooooooo047ooooo0ol00007ojJiiP;o00001onW^NH3o`0000SoZ/7Z0ol00008ojc1j@Co0000
1_n]`^T00ol0003oZlG/oj_5k003oj_5k0Ko00003On]a>X00ol0003oZlC/oj_4k00Aoj_4k0Ko0000
3?nRaO44o`0000SoVlGe0ol000001_nEa?Oo0000o`000?l0003oS;ggo`0000GoQk_h00?o0000ohFj
n?n5^_P00on5^_P2o`0002kooooo00?o0000ooooooooool09_ooool002?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0nooooo`;o00002?nV^NH2o`0000OoYkWV0_l000000onY^^Ko
0000oj[1jP06oj[1jP;o00001on/`NT4o`0000So[L;Y0ol000000on[aNco0000o`00000Aojg4jPGo
00006?n[a>`00ol0003oZLC]ojW4k@02o`0000coX/Ga1?l00005oi_5m@Co00001?n<_OL00ol0003o
S;ggohNkn004ohNkn003o`000?n5^_SoQK[h00?oQK[h0_l0000]ooooo`03o`000?oooooooooo02Go
oooo000Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>oooool2o`0000SoY[WV
0_l00007ojNiiP;o00001?nY^^H01?l0003oZ/7Zoj[1j_nZ`NX2o`0000Oo[<7Y0ol00009ojg2j@?o
00000_n^`^T00ol0003o[LCZojg4jP0:ojg4jPSo00001?n^`^P00ol0003o[/;Xojk2j004ojk2j0co
00001On[a>`00ol0003oZLC]ojW4k@05ojW4k@Co00002_nRaO45o`000003oi_5mOl0003oU;od00;o
U;od1?n<_OL01?l0003oS;ggo`000?l00003ohNkn0;o00001On5^_P2o`0002_ooooo00?o0000oooo
ooooool09Oooool002?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`;o
00002?nV^NH2o`0000OoYkWV0_l00006ojVjiP?o00001on/`NT3o`0000Wo[L;Y0ol00006ojk2j@03
o`000?n]a>[o[LCZ00?o[LCZ1_l0000<ojk2j003o`000?n^`^So[/;X013o[/;X1_l0000;ojW4k@?o
00001_nRaO43o`0000;oX/Ga0_l00006oiBom004o`000?n<_OOoS;ggo`0000;oS;gg0_l00003ohNk
n0;o00001On5^_P2o`0002Wooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`008_ooool3o`0001Sooooo00?o0000
ooooooooool0=Oooool2o`0000SoY[WV0_l00007ojNiiP;o00001_nY^^H2o`0000?oZkcV00Co0000
ojc1jOn/`NWo[<7Y0_l00009ojg2j@Co00001on^`^T3o`000003ojg4j_l0003o000001Co[/;X00?o
0000ojk2j?n^`^P05On^`^P00ol0003o[l;Xojo2j002o`0000[oZLC]1_l00005oj;5l@03o`000?nM
`O7oWL7a00OoU;od0_l00004ohbmm`;o00000on7^oP2o`0000GoQK[h0_l0000Yooooo`03o`000?oo
oooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`07ooooo`008_ooool00ol0003oooooooooo`0Iooooo`;o0000<oooool2o`0000SoY[WV0_l0
0006ojNiiP?o00001_nY^^H2o`0000GoZkcV0ol00009ojg2j@?o00002?n^`^T3o`0000;o[/;X00?o
0000ojk2j?n^`^P04On^`^P5o`0000Go[/;X1_l0000;ojk2j003o`000?n_`^So[l;X00Go[l;X1Ol0
0003ojW4k@?o000000?oZLC]o`000?l000000_l00002oj;5l@03o`000?nM`O7oWL7a00?oWL7a00?o
0000oiBom?nD_o@00onD_o@2o`0000GoS;gg00?o0000ohNkn?n7^oP00_n7^oP2o`0000GoQK[h0_l0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_oo
ool3o`0000OoY[WV0_l00006ojNiiP;o00001onY^^H2o`0000GoZkcV0_l00002ojbmiP03o`000?n]
`^Wo[L;Y00Co[L;Y0ol00008ojk2j@?o00001_n^`^P00ol0003o[/;Xojk2j009ojk2j0Oo00001?n_
`>H00ol0003o/KoUok6oi@09ok6oi@_o00003On_`^P4o`0000OoZLC]0_l00008oig1l@03o`000?nD
_oCoU;od00?oU;od0_l00004ohbmm`;o00001?n7^oP2o`0000GoQK[h00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`07ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02co
oooo00Go0000oj6bi?nQ/^CoXK;To`000004ojJiiP;o00001_nW^NH2o`0000OoZK[V0_l00006oj^l
iP03o`000?n/_NKo[;gV00?o[;gV00Co0000ojg2jOn]`^Wo[L;Y0_l00008ojk2j@?o00002On^`^P0
0ol0003o[/;Xojk2j003ojk2j0Ko00002on_`>H00ol0003o/KoUok6oi@0Cok6oi@03o`000?nc`>?o
/l3S00Co00001?n_`^P3o`0000Co[l;X1?l00002ojW4k@05o`000?nW`^goYl;]ojO2kOl000002?nM
`O42o`0000?oU;od0ol00004ohbmm`;o00001?n7^oP00ol0003oQK[hohFjn003ohFjn0;o00009_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02[o
oooo00?o0000oj6bi?nQ/^@00onQ/^@01?l0003oY[WVojJii_l00006ojNiiP;o00001onY^^H2o`00
00KoZkcV0_l00006ojbmiP?o00002?n^`^T3o`0000_o[/;X0ol000000on^`^So0000o`00000Bojo0
iP03o`000?na_nGo/KoU01?o/KoU00?o0000ok?0honc`><01?nc`><4o`0000_o[l;X0_l00006ojO2
k@;o00001onM`O401?l0003oU;odoiBom?l00002oiBom0;o00001?n<_OL2o`0000?oQk_h0_l00005
ohFjn0;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0:ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:?oo
ool00ol0003oXK;Toj6bi004oj6bi0?o00001_nW^NH00ol0003oZK[VojVjiP06ojVjiP03o`000?n[
_>KoZkcV00CoZkcV0_l00006ojbmiP;o000000?o[L3Wo`000?n^`^T01On^`^T3o`0000_o[/;X0ol0
0002ojk2j003o`000?n_`>Ko[l3V00ko[l3V1_l00003ok6oi@So00002Ona_nD00ol0003o/l3Sok?0
h`03ok?0h`?o00000onc`><4o`0000Oo[l;X00Co0000ojo2j?n_`^So00001_nW`^d2o`0000KoWL7a
0_l000000onD_oCo0000oiBom002oiBom003o`000?n<_OOoS;gg00?oS;gg00?o0000ohNkn?n7^oP0
0_n7^oP2o`0000?oQK[h0ol0000Rooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool02_ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo0_l0000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oj6bi?nQ
/^@01?nQ/^@01?l0003oX[;Toj:bi?nR/^@2o`0000;oYkWV00?o0000ojVji_nY^^H01_nY^^H2o`00
00GoZkcV0_l00006ojbmiP;o00001?n]`>L01?l0003o[/;Yojk2jOn^`^T2o`0000[o[/;X1?l00006
ojk2j003o`000?n_`>Ko[l3V00;o[l3V2ol00005ojnni@03o`000?nb_>7o/[cQ00Wo/[cQ2_l00002
ok?0h`?o00002_nc`><4o`0000;o[l;X00?o0000ojo2j?n_`^P00on_`^P2o`0000GoYl;]0_l00006
oig1l@?o00000onD_o@2o`0000CoS;gg0_l00002ohNkn0Go00000on1/_@00ol0003oooooooooo`0R
ooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00009ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool09?ooool00ol0003oXK;Toj6bi004oj6b
i003o`000?nR/^CoX[;T00?oX[;T0ol00007ojVjiP;o00001_n[_>H00ol0003o[;gVojbmiP05ojbm
iP03o`000?n]`>Oo[L3W00Co[L3W0ol0000:ojk2j0?o00002?n^`^P3o`000004ojo0i_l0003o0000
o`00013o[kkU00?o0000ok:lhOnb_>404_nb_>47o`0000go/l3S0_l00008ojo2j0;o00001OnW`^d2
o`0000KoWL7a0_l00004oiBom0;o00000_n<_OL4o`0000CoPk?d1On1/_@00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool0
0ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00Go0000ojBdi?nT]>CoY;CTo`00
0004ojVjiP;o00001_n[_>H2o`0000Ko[;gV0_l00005ojg0i`;o00000_n^`^P00ol0003o[/;Xojk2
j004ojk2j0Co00002?n^`^P3o`0000;o[/;Y00?o0000ojnniOn__^D03On__^D6o`0000Co/[cQ00?o
0000ok:lhOnb_>402_nb_>43o`0000Oo][gO1?l0000:ok?0h`03o`000?ne`N?o000000So[l;X0_l0
0005ojO2k@;o00001OnM`O43o`0000;oU;od1?l00004ohRel`GoPk?d1On1/_@00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?oo
ool00ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBdi?nT]>@00onT
]>@01?l0003oZK[VojVji_l00006oj^liP;o00001_n/_NH2o`0000Go[L3W0_l00005ojk2j004o`00
0?n^`^So[/;Xojk2j0;o00002On^`^P3o`0000Ko[/;Y00?o0000ojnniOn__^D00on__^D9o`0000Go
[[cT00?o0000ok>jgonc^]l00onc^]l9o`000003ok:lhOl0003o000000;o/[cQ00?o0000okJmgonf
_Ml02Onf_Ml3o`0000Ko/l3S00?o0000okG1hone`N<00_ne`N<2o`0000Oo[l;X0_l00005ojO2k@;o
00001?nM`O401?l0003oWL7ao`000?l00003oi6ilP03o`000?n8]O?oR;Gc00?oR;Gc1On3/o@00ol0
003oPK;doh6bm002oh6bm003o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`0002Gooooo00?o0000oooo
ooooool07_ooool00ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBd
i?nT]>@01?nT]>@2o`0000KoZkcV0_l00006ojbmiP;o00001_n]`>L00ol0003o[/;Xojk2j005ojk2
j0?o00002?n^`^P4o`0000So[/;Y0_l000001?n__^Go0000o`000?l0000?ojjli003o`000?nc^]oo
/k[O00[o/k[O1ol0000?okJmg`Co00000_nc`><00ol0003o]L7SokG1h`04okG1h`;o00001on_`^P2
o`0000GoYl;]0_l000001?nM`O7o0000o`000?l00002oi^lk`CoTKWb00?o0000ohRelon8]O<00on8
]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Mooooo`008?ooool2o`0002Oooooo00?o0000ooooooooool07?ooool0
0ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBdi?nT]>@01?nT]>@0
1?l0003oY[KTojJfi?l00004oj^liP03o`000?n/_NKo[;gV00Co[;gV0_l00006ojg0i`;o00001_n^
`^P2o`000003ojo5j_l0003o[/;X00Go[/;X0ol00009ojk2j@?o000000?o[<7Yo`000?n^_>@04_n^
_>@00ol0003o/k[Ook>jg`07ok>jg`?o00001_nc^]l00ol0003o^;_LokRkg005o`0000co][gO0_l0
0009okG1h`;o00001on_`^P2o`0000CoYl;]0_l00002oi^lk`04o`000?nK_>ooVkc_oi^lk`CoTKWb
00?o0000ohRelon8]O<00on8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d
00?o0000ooooooooool07oooool2o`0001kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool06_ooool00ol0003oXK;Toj6bi003oj6bi0;o00001OnR/^@00ol0003oY;CTojBd
i004ojBdi003o`000?nV]^CoY[KT00;oY[KT00Co0000oj^li_n[_>Ko00001_n/_NH00ol0003o[L3W
ojg0i`04ojg0i`;o00001_n^`^P2o`0000Co[lGZ00Co0000ojk2j?n^`^So[/;X0_l00009ojk2j@?o
00001?n/`NT00ol0003o[[cTojjli00<ojjli0Ko00001?nc^]l00ol0003o/k[Oo`000002o`0000Wo
/k[O00?o0000okRkg?nh^m`01Onh^m`4o`0000So][gO00Co0000ok[0g_nj`=ko00002One`N<00ol0
003o[l;Xojo2j006ojo2j0;o000000?oYl;]o`000?nU_n`00_nU_n`2oi^lk`04o`000?nK_>ooVkc_
oi^lk`CoTKWb00?o0000ohRelon8]O<00on8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_Co
PK;d00;oPK;d00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`008?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01Sooooo00?o0000oj6bi?nQ/^@00onQ/^@00ol0
003oX[;Toj:bi004oj:bi003o`000?nT]>CoY;CT00CoY;CT00?o0000ojJfi?nV]^@00onV]^@3o`00
00Go[;gV0_l00005ojg0i`;o00001on^`^P00ol0003o[lGZojo5jP04ojo5jP?o00002On^`^T3o`00
00So[<7Y00?o0000ojjli?n^_>@00_n^_>@9o`0000Go[K[S00Co0000ok:hgOnb^=go/[SM2ol00003
ok>jg`03o`000?nh^mco^;_L00[o^;_L1Ol00002okJmg`03o`000?nj`=ko^/3N00?o^/3N0_l00007
okG1h`;o00002?n_`^P00ol0003oYKo/ojFok003ojFok0;oVkc_00Go0000oi^lkonK_>ooVkc_o`00
0003oi6ilP03o`000?n8]O?oR;Gc00?oR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6b
m002oh6bm003o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool0023ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?nQ/^CoXK;T00?oXK;T00?o0000
oj:bi?nR/^@00onR/^@2o`0000KoY;CT00?o0000ojJfi?nV]^@00onV]^@01?l0003oZK[UojVjiOnY
^^D2o`0000;o[;gV00?o0000ojg0ion]`>L00on]`>L2o`0000Oo[/;X0_l00005ojo5jP;o00000_n_
an`00ol0003o[/;Yojk2j@04ojk2j@?o00002On/`NT3o`000004ojjli?l0003o0000o`0000ko[K[S
1?l0000;ok:hg@Co00004Onh^m`2o`0000So^/3N0ol00006okG1h`;o00001?n_`^P01?l0003o[l;X
ojo2j?l00005ojFok003o`000?nK_>oo000000?oVkc_00Go0000oi6il_nA^O;oTKWbo`000005ohRe
l`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01[ooooo000Pooooo`;o0000:oooool00ol0003oooooooooo`0Dooooo`03
o`000?nQ/^CoXK;T00?oXK;T00?o0000oj:bi?nR/^@00onR/^@00ol0003oY;CTojBdi005ojBdi003
o`000?nV]^CoY[KT00?oY[KT00?o0000ojVjiOnY^^D00onY^^D3o`0000Go[L3W00?o0000ojk2j?n^
`^P01On^`^P2o`0000Ko[lGZ00?o0000ojo7k?n_an`00on_an`01?l0003o[/;Yojk2jOn^`^T2o`00
00So[<7Y1?l00002oj[1jP03o`000?n]^^?o[K[S00ko[K[S0ol0000Aok:hg@03o`000?ni^MWo^KWI
00Co00003?nh^m`00ol0003o_KoKo`000009ok[0gP;o00001_ne`N<2o`000003ojo2j?l0003o[l;X
00?o[l;X00?o0000ojFok?nU_n`00onU_n`2o`0000CoVkc_00Go0000oi6il_nA^O;oTKWbo`000005
ohRel`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool04_ooool00ol0003oXK;Toj6bi003oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBd
i?nT]>@01OnT]>@00ol0003oY[KTojJfi003ojJfi003o`000?nY^^GoZK[U00?oZK[U00Co0000ojbn
ion/_^Oo[;kW0_l00002ojg0i`03o`000?n^`^So[/;X00Co[/;X0_l00006ojo5jP;o00001_n_an`3
o`0000Ko[<7Y1Ol00007oj[1jP03o`000?n]^^?o[K[S00Ko[K[S2Ol0000Aok:hg@03o`000?ni^MWo
^KWI00Go^KWI1?l00007okRkg003o`000?nm_m_o_KoK00;o_KoK00?o0000ok[0g_nj`=h01onj`=h2
o`0000Ko]L7S00?o0000ojo2j?n_`^P01?n_`^P00ol0003oYKo/ojFok003ojFok0;o00001?nK_>l0
1Ol0003oTKWboi6il_nA^O;o000000GoR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6b
m002oh6bm003o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?nQ/^CoXK;T00?oXK;T00?o0000
oj:bi?nR/^@00onR/^@00ol0003oY;CTojBdi004ojBdi0;o00001OnV]^@00ol0003oZK[UojVji@03
ojVji@03o`000?n/_^Oo[;kW00?o[;kW0_l00006ojk2j0;o00001_n_aNX2o`0000Ko[lO/0_l00002
ojk9kP04o`000?n/`NWo[<7Yojc1j@?o00002onZ`NX3o`000003ojfjhol0003o000000Co000000Co
ZkSSo`000?l0003o00001?n[^><00ol0003o/KKLok6fg002ok6fg0Wo00001?nb^=d00ol0003o^KWI
okVif@09okVif@Co00000_nh^m`00ol0003o_KoKokfof`04okfof`;o00002Onj`=h2o`000003okG1
hol0003o000000?o]lCT1_n_`^P00ol0003oYKo/ojFok003ojFok0;o00001?nK_>l01Ol0003oTKWb
oi6il_nA^O;o000000GoR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6bm002oh6bm003
o`000?oooooooooo01gooooo0_l0000Jooooo`008?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00kooooo0_l00005oj6bi0GoX[;T00?o0000ojBdi?nT]>@01?nT]>@00ol0003oY[KT
ojJfi004ojJfi003o`000?nY^^GoZK[U00?oZK[U00?o0000ojbnion/_^L00on/_^L01?l0003o[/;X
ojk2j?l00004ojk2j003o`000?n_aN[o[lGZ00Co[lGZ0_l00006ojo7k0;o00001?n^bNh3o`0000_o
Z/7Z1?l00002ojO0j`03o`000?n[^>?oZkSS00?oZkSS0ol00007oj^hh`03o`000?na]]co/KKL00_o
/KKL1?l0000@okVif@;o00002Onm_m/2o`0000Wo^/3N00?o0000okO4i?nga>@01?nga>@00ol0003o
[l;Xojo2j003ojo2j003o`000?nU_ncoYKo/00?oYKo/0_l00004oi^lk`05o`000?nA^O;oTKWboi6i
l_l000001On8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00gooooo00Co0000oiR/iOl0003o00000_nQ/^@5oj:bi003o`000?nT]>CoY;CT
00CoY;CT00?o0000ojJfi?nV]^@00onV]^@2o`0000GoZK[U00?o0000ojbnion/_^L00on/_^L00ol0
003o[/;Xojk2j002ojk2j004o`000?n^`^So[/;Xo`0000Go[lGZ0_l00006ojo7k0;o00001?n^bNh2
o`0000;oZl[`00?o0000oj[1j_nZ`NX01OnZ`NX4o`0000KoYl3[00?o0000oj^hhon[^><00ol0000:
oj^hh`03o`000?na]]co/KKL00ko/KKL00?o0000okVgf?ni]mP01?l0000;okVif@03o`000?no_]So
000000Wo_KoK0_l00006ok[0gP03o`000?nmaN3o000000Ko]lCT00?o0000ojo2j?n_`^P00on_`^P0
0ol0003oYKo/ojFok003ojFok003o`000?nK_>ooVkc_00?oVkc_00Go0000oi6il_nA^O;oTKWbo`00
0005ohRel`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Oooooo000Oooooo`;o0000<Oooool00ol0003oooooooooo`0;
ooooo`03o`000?nH[>GoV:cU00;oV:cU0_l00005oj:bi0KoY;CT00?o0000ojJfi?nV]^@00onV]^@0
0ol0003oZK[UojVji@04ojVji@03o`000?n/_^Oo[;kW00?o[;kW00?o0000ojk2j?n^`^P00on^`^P3
o`0000Go[lGZ00?o0000ojo7k?n_an`01On_an`00ol0003o[/W^ojk9kP02ojk9kP;o00001On[b_00
1?l0003oZ/7Zoj[1j_nZ`NX3o`0000[oYl3[0ol00006oj^hh`So00000ona]]`00ol0003o/KKLok6f
g00:ok6fg003o`000?ni]mSo^KOH00Co^KOH0ol00007okVif@03o`000?no_]So_kkH00;o_kkH0_l0
0008okfof`03o`000?nj`=ko^/3N00;o^/3N00Go0000okg5h?nmaN3o_LGPo`000006okO4i003o`00
0?n_`^So[l;X00?o[l;X00?o0000ojFok?nU_n`00onU_n`00ol0003oVkc_oi^lk`03oi^lk`05o`00
0?nA^O;oTKWboi6il_l000001On8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;o
PK;d00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`007oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000oiR/iOnH[>D00_nH[>D01?l0003oVZgT
o`000?l00002oj:bi0KoY;CT00?o0000ojJfi?nV]^@00onV]^@00ol0003oZK[UojVji@04ojVji@03
o`000?n/_^Oo[;kW00?o[;kW00?o0000ojk2j?n^`^P00on^`^P01?l0003o/LO[ok77jonaan/2o`00
00;o[lGZ00?o0000ojo7k?n_an`01?n_an`2o`0000?o[/W^0_l00007oj_:l0?o00002onW`>/5o`00
0003oj^hhol0003o000000Co00001onX]n@00ol0003o[kCLojndg002ojndg0So00000ona]]`00ol0
003o^KOHokVgf008okVgf0Co00000_ni^MT00ol0003o_kkHoknnf005oknnf0;o00001onm_m/2o`00
0003ok[0g_l0003o_LGP00Co_LGP00?o0000okO4i?nga>@01?nga>@00ol0003o[l;Xojo2j003ojo2
j003o`000?nU_ncoYKo/00?oYKo/00?o0000oi^lkonK_>l00onK_>l01Ol0003oTKWboi6il_nA^O;o
000000?oR;Gc3Ol0000Nooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool02?ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT
00;oVZgT0_l00005ojBdi003o`000?nV]^CoY[KT00?oY[KT00?o0000ojVjiOnY^^D01?nY^^D00ol0
003o[;kWojbni`03ojbni`03o`000?n^`^So[/;X00?o[/;X00?o0000ok77jonaan/00onaan/3o`00
00Go[lO/0_l00003ojk9kP;o00001on[b_02o`000003ojS;l_l0003oYl3[00SoYl3[1Ol00002oj>n
k@03o`000?nX]nCoZ;OT00coZ;OT00?o0000ojndg?n_]=`02_n_]=`4o`0000ko^KOH0_l0000:oknn
f0;o00001onm_m/00ol0003o_LGPokg5h005okg5h003o`000?nga>Co]lCT00Co]lCT00?o0000ojo2
j?n_`^P00on_`^P00ol0003oYKo/ojFok003ojFok004o`000?nK_>ooVkc_oi^lk`Wo00000_n:[nh5
ohJ/kPGoQ:_^00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`007oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?o0000oiR/iOnH[>D00onH[>D00ol0
003oVZgToiZ]i002oiZ]i003o`000?nL[nCo000000;o00000_nT]>@5ojJfi003o`000?nY^^GoZK[U
00CoZK[U00?o0000ojbnion/_^L00on/_^L00ol0003o[/;Xojk2j003ojk2j003o`000?naan_o/LO[
00?o/LO[00Co0000ok;<kOnbc>go//c]0_l00002ojo7k004o`000?n^bNko[/W^ojk9kP;o00001on[
b_02o`0000CoZ<_b00Co0000ojO0jonW`>_oYl3[1_l00007oj>nk@03o`000?nX]nCoZ;OT00_oZ;OT
00?o0000ojndg?n_]=`03On_]=`00ol0003o]kKHo`000002o`0000_o^KOH00Co0000ol2meol0003o
00002Ono_]P2o`0000Co_KoK00?o0000ol;5g?o2aM`01onmaN000ol0003o]lCTokO4i004okO4i003
o`000?n_`^So[l;X00?o[l;X00?o0000ojFok?nU_n`00_nU_n`4o`0000;oVkS/1?nB/nd6ohZ_kPGo
QZc^1On4Znh00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eooooo`;o0000
1_ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT00;oVZgT00?o0000oib_i?nL[n@0
0onL[n@2o`0000GoY[KT1_nY^^D00ol0003o[;kWojbni`03ojbni`03o`000?n^`^So[/;X00?o[/;X
00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<k@Co00000_n^bNh00ol0003oZl[`
oj_:l004oj_:l0?o00001_nXbo87o`0000SoXkk]0ol000000onX]nCo0000o`00000;o`0000ko[kCL
00?o0000okNff?ng]]P00ong]]P3o`0000Oo^KOH00?o0000ol2meoo0_ML00_o0_ML2o`0000Wo_kkH
0_l000000onm_m_o0000ol;5g003ol;5g003o`000?nmaN3o_LGP00Co_LGP00?o0000okO4i?nga>@0
1?nga>@00ol0003o[l;Xojo2j003ojo2j006o`000?nU_nco0000o`000?nU_N_o00001OnK^>`4oi:c
k@GoRZo^00?o0000ohJ/k_n6[>h00_n6[>h00ol0003oQ:_^ohB[kP02ohB[kP03o`000?oooooooooo
01gooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`02ooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000oiZ]i?nJ[N@00_nJ[N@00ol0003o
W:oToib_i003oib_i004o`000?nP/^Go0000o`0000;oY[KT1_nY^^D00ol0003o[;kWojbni`03ojbn
i`03o`000?n^`^So[/;X00?o[/;X00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<
k@04o`000?nbd>oo/]3_ok;@k`?o00001On[b_02o`0000KoZ<_b0ol000001?nTb_Co0000o`000?l0
0006oj>nk@Go00000_nN_Nh00ol0003oY;GUojBei@0;ojBei@03o`000?n//]go[;;M00Go00001on_
]=`00ol0003o]kKHokNff006okNff0?o00001?ni]mP00ol0003o`;gGol2me`04ol2me`;o00002Ono
_]P00ol0003o`/GLol;5g004ol;5g003o`000?nmaN3o_LGP00Co_LGP00?o0000okO4i?nga>@01?ng
a>@01?l0003o[l;Xojo2j?n_`^P3o`0000CoYKg[00?o0000oi^hk?nK^>`00_nK^>`01Ol0003oT[?]
oi:ckOnB/ngo000000CoRZo^00?o0000ohJ/k_n6[>h00_n6[>h00ol0003oQ:_^ohB[kP02ohB[kP03
o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool001kooooo00?o0000ooooooooool0
>?ooool01Ol0003ooooooooooooooooo000000CoV:cU00?o0000oiZ]i?nJ[N@00_nJ[N@00ol0003o
W:oToib_i003oib_i003o`000?nP/^GoX;;U00;oX;;U0_l00005ojVji@03o`000?n/_^Oo[;kW00?o
[;kW00?o0000ojk2j?n^`^P00on^`^P00ol0003o/LO[ok77j`03ok77j`03o`000?nbc>go//c]00?o
//c]00Go0000ok;@konbd>oo/]3_o`000003ok;ClP;o00000_n[b_000ol0003oZ<_bojS;lP04ojS;
lP;o000000CoY<[do`000?l0003o00000_nTb_@01?l0003oXkk]oj>nkOnS_^d3o`0000OoW[g^00?o
0000ojBeiOnT]ND02onT]ND00ol0003o[;;Mojbbg@05ojbbg@Go00000_n_]=`00ol0003o]kKHokNf
f009okNff0?o000000?o^KOHo`000?o0_ML01oo0_ML00ol0003o_kkHoknnf005oknnf003o`000?o5
aM[o000000Ko`/GL0_l00005okg5h003o`000?nga>Co]lCT00?o]lCT1?l00002ojo2j0GoYKg[0_l0
0004oi^hk005o`000?nB/ngoT[?]oi:ckOl000001?n:[nh00ol0003oQZc^ohJ/kP02ohJ/kP03o`00
0?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
o`000005oiR/i@03o`000?nJ[NCoVZgT00;oVZgT00?o0000oib_i?nL[n@00onL[n@00ol0003oX;;U
oj2bi@02oj2bi@03o`000?nU]nKo000000;o00000_nY^^D5ojbni`03o`000?n^`^So[/;X00?o[/;X
00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<k@05o`000?nbd>oo/]3_ok;@kol0
00001Onbdo83o`0000GoZ<_b1Ol00005ojC:m0?o00003?nN_Nh00ol0003oY;GUojBei@0:ojBei@03
o`000?n//]go[;;M00[o[;;M0_l0000?okNff003o`000?o0_MOo`;gG00So`;gG0_l00004oknnf005
o`000?o5aM[oaLGJolG5f_l000001oo2aM`00ol0003o_LGPokg5h003okg5h006o`000?nga>Co]lCT
okO4i?l0003o^<OU1_n_`^P5ojFmj`03o`000?nK^>coVkS/00;oVkS/00Go0000oi:ckOnB/ngoT[?]
o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01;ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`0jooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000oiZ]i?nJ[N@0
0_nJ[N@00ol0003oW:oToib_i003oib_i003o`000?nP/^GoX;;U00;oX;;U00?o0000ojFgi_nU]nH0
0onU]nH2o`0000Co[;kW00?o0000ojk2j?n^`^P00on^`^P00ol0003o/LO[ok77j`03ok77j`03o`00
0?nbc>go//c]00?o//c]00Go0000ok;@konbd>oo/]3_o`000005ok;ClP05o`000?n_e_Co[mKdojoF
m?l000000_nXbo84o`0000GoY<[d0ol00002oik9mP03o`000?nN_NkoW[g^00CoW[g^1ol000000onT
]NGo0000o`00000:o`0000go[;;M00?o0000okBdf?nd]=P00ol0000:okNff004o`000?no_=Ko0000
o`0000Wo`;gG0_l000000ono_]So0000olG5fP04olG5fP03o`000?o2aMco`/GL00Go`/GL00?o0000
okg5h?nmaN000onmaN000ol0003o]lCTo`000003okS7i@Go[l;X00?o0000ojFmjonU_N/00_nU_N/2
o`0000CoVkS/00Go0000oi:ckOnB/ngoT[?]o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00?o
0000ohB[k_n4Znh00_n4Znh00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l0
00000ol@413oooooooooo`03ooooo`004oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0>_ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT00?oVZgT00?o
0000oib_i?nL[n@00_nL[n@00ol0003oX;;Uoj2bi@03oj2bi@03o`000?nU]nKoYKOV00?oYKOV00Co
0000ojZliol0003o00000_n/_^L5ojk2j003o`000?naan_o/LO[00?o/LO[00?o0000ok;<kOnbc>d0
0_nbc>d2o`0000?o/]3_00?o0000ok;Cl_nbdo800onbdo800ol0003o[mKdojoFm002ojoFm0Co0000
1OnTb_@3o`0000CoW/Wf2?l00006oiRjl003o`000?nO/nKoWk?V00[oWk?V00?o0000ojRagonX/Ml0
1Ol00006ojbbg@03o`000?nd]=So];CH00?o];CH0ol00006okNff003o`000?no_=Ko_kcF00;o_kcF
0_l00009ol2me`03o`000?o5aM[oaLGJ00GoaLGJ00?o0000ol;5g?o2aM`01Oo2aM`00ol0003o_LGP
okg5h002okg5h0;o00001?nhanD00ol0003o[l;Xojo2j003ojo2j003o`000?nU_N_oYKg[00;oYKg[
0_l00003oi^hk005o`000?nB/ngoT[?]oi:ckOl000001?n:[nh00ol0003oQZc^ohJ/kP02ohJ/kP03
o`000?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07Oooool00ol0003oooooo`00000:ooooo`03
o`000?oooooooooo00Gooooo000Cooooo`05o`000?ooooooooooooooool000001Oooool3o`0003[o
oooo00?o0000oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?o
W:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;o
Z[cW1?l00003ojk2j0Go/LO[00?o0000ok;<kOnbc>d00_nbc>d00ol0003o/]3_ok;@k`02ok;@k`03
o`000?nbdo;o/]?b00?o/]?b00Co0000ojoFm?n_e_Co[mKd0ol00002oj_FmP;o00000_nTb_@2o`00
00CoW/Wf0ol00003oiO6m`03o`000?nH^_3oV;[`00WoV;[`00?o0000oinci_nO/nH02OnO/nH00ol0
003oZ;7OojRag`05ojRag`Co000000?o[;;Mo`000?nd]=P02?nd]=P3o`0000;o]kKH00?o0000oknl
e_no_=H01Ono_=H00ol0003o`;gGol2me`05ol2me`03o`000?o6aMWoa/GI00OoaLGJ00?o0000ol;5
g?o2aM`01Oo2aM`01_l0003o_LGPo`000?l0003o_l[So`0000Go^<OU00?o0000ojo2j?n_`^P00_n_
`^P00ol0003oYKg[ojFmj`02ojFmj`03o`000?nK^>co000000?oVkS/00Go0000oi:ckOnB/ngoT[?]
o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00Go0000ohB[k_n4ZnkoQ:_^o`00000Qooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03[ooooo00?o0000oiR/iOnH[>D00_nH[>D00ol0003o
VZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000oj2biOnP/^D00onP/^D00ol0003o
YKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;oZ[cW00Co0000ojo3j?n_`nSo[l?X0ol00004ok77
j`03o`000?nbc>go//c]00;o//c]00?o0000ok;@konbd>l00_nbd>l00ol0003o/]?bok;ClP02ok;C
lP;o000000?o[mKdo`000?l000000_l00005oj_FmPCo00000_nNbOH3o`0000OoUlKg00?o0000oiRj
l?nH^_000onH^_06o`000003oinci_l0003o000000?o00001OnO/nH00ol0003oZ;7OojRag`09ojRa
g`;o00003?nd]=P2o`0000Wo_kcF0_l00004ol2me`03o`000?o6aMWoa/GI00;oa/GI00?o0000olG5
f_o5aMX01?o5aMX00ol0003o`/GLol;5g004ol;5g0;o00001?nob^<00ol0003o^<OUokS7i@02okS7
i@03o`000?n_`^So[l;X00?o[l;X00?o0000ojFmjonU_N/00_nU_N/2o`0000?oVkS/00?o0000oi:c
kOnB/nd00_nB/nd01Ol0003oRZo^ohZ_k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
01?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Wooooo00?o0000
oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000
oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;oZ[cW00?o0000
ojo3j?n_`nP00on_`nP01?l0003o/lWZo`000?l00002ok77j`Co//c]00?o0000ok;@konbd>l00_nb
d>l00ol0003o/]?bok;ClP02ok;ClPCo000000?o[mKdo`000?l000001On[e_H01?l0003oYMKhojGF
n?nUe_P3o`0000WoUlKg1ol00005oi6hl@03o`000?nH/NSoV;7X00CoV;7X1_l0000<ojRag`03o`00
0?na/m[o000000;o00002Ond]=P01?l0003o_K_Go`000?l00008oknleP;o000000?o`;gGo`000?o6
aMT01Oo6aMT00ol0003oaLGJolG5fP04olG5fP04o`000?o2aMco`/GLol;5g0;o000000?oaLgPo`00
0?nob^<00onob^<00ol0003o^<OUokS7i@03okS7i@03o`000?n_`^So[l;X00;o[l;X00?o0000ojFm
jonU_N/00_nU_N/00ol0003oVkS/o`000002oi^hk003o`000?nB/ngoT[?]00;oT[?]00Go0000ohZ_
k_n:[nkoRZo^o`000004ohJ/kP03o`000?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000
oiZ]i?nJ[N@00_nJ[N@00ol0003oW:oToib_i003oib_i003o`000?nP/^GoX;;U00?oX;;U00?o0000
ojFgi_nU]nH00onU]nH00ol0003oZ[cWojZli`02ojZli`03o`000?n_`nSo[l?X00;o[l?X00?o0000
ok?9j_ncbNX00_ncbNX3o`0000?o//c]1Onbd>l3ok;ClP?o00000on_e_@00ol0003oZmKfoj_FmP03
oj_FmP;o00000onUe_P01?l0003oW]?joikCn_nNdoX2o`0000;oUlKg1Ol00003ohk2n003o`000?nA
^?7oTKSa00OoTKSa00?o0000oiRaj?nH/NP02?nH/NP00ol0003oX[3Roj:`hP04o`0000GoZ;7O00?o
0000ok6cf_na/mX00ona/mX3o`0000Go];CH00?o0000okfkeonm^mL00_nm^mL2o`0000So_kcF00?o
0000olK5fOo6aMT01_o6aMT00ol0003oaLGJolG5fP04olG5fP03o`000?o2aMco000000CoaLgP00?o
0000oko:honob^<00_nob^<00ol0003o^<OUokS7i@03okS7i@05o`000?n_`^So[l;Xojo2j?l00000
1OnU_N/00ol0003oVkS/o`000002oi^hk003o`000?nB/ngoT[?]00;oT[?]00Go0000ohZ_k_n:[nko
RZo^o`000004ohJ/kP05o`000?n4ZnkoQ:_^ohB[k_l000008_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo000Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
03Wooooo00?o0000oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT
00?oW:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW
00;oZ[cW00?o0000ojo3j?n_`nP00_n_`nP00ol0003o/lWZok?9jP03ok?9jP03o`000?ngcnco]lo/
00co00001?n_e_@00ol0003oZmKfoj_FmP02oj_FmP;o00000onUe_P2o`0000GoW]?j0ol00007ohk2
n0go00000_nH/NP00ol0003oV;7XoiRaj004oiRaj003o`000?nR/>;oX[3R00CoX[3R0ol00002ojRa
g`03o`000?na/m[o/K?J00Ko/K?J0ol000000ond]=So0000okfke`06okfke`03o`000?no_=Ko_kcF
00Go_kcF00?o0000olK5f?l000001oo6aMT00ol0003oaLGJolG5fP03olG5fP;o00001Oo5cN000ol0
003o_l[Soko:h`02oko:h`03o`000?nhanGo^<OU00?o^<OU00?o0000ojo2j?n_`^P00_n_`^P00ol0
003oYKg[ojFmj`02ojFmj`06o`000?nK^>coVkS/o`000?nK^>co00001?nB/nd01Ol0003oRZo^ohZ_
k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0003oooooooooo`0Oooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`007Oooool00ol0003oooooooooo`0gooooo`;o00001?nH
[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000oj2biOnP/^D00onP
/^D00ol0003oYKOVojFgiP03ojFgiP05o`000?nZ_>OoZ[cWojZliol000001On_`nP00ol0003o/lWZ
ok?9jP02ok?9jP03o`000?ngcnco]lo/00;o]lo/00Co0000ok[DkOnje>go^]C]0ol000000onkfNoo
0000o`000002o`0000?o[mKd1?n[e_H00ol0003oYMKhojGFn002ojGFn003o`000?nNdo[oW]?j00?o
W]?j0_l00003oiG>n`03o`000?n>`_SoS/;h00Co00000on6_OT00ol0003oR;CbohRdlP06ohRdlP04
o`000?nA[n_oTJo[oi6_j`Go000000?oV;7Xo`000?nR/>802?nR/>82o`0000co/K?J00?o0000okfk
eonm^mL01onm^mL2o`0000Co_kcF00Go0000olK5f?o6aMSoa/GHo`000007olK5f@07o`000?o5aM[o
aLGJolG5f_l0003ob<kNo`000006olG=h003o`000?nob^?o_l[S00;o_l[S00?o0000okS7iOnhanD0
0onhanD01Ol0003o[l;Xojo2j?n_`^So000000GoYKg[00?o0000oi^hk?l000000_nK^>`00ol0003o
T[?]oi:ck@02oi:ck@05o`000?n:[nkoRZo^ohZ_k_l000001?n6[>h01Ol0003oQ:_^ohB[k_n4Znko
0000023ooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`000007ooooo`007Oooool00ol0
003oooooooooo`0gooooo`;oSZWX0ol000000onH[>Go0000oiZ]i003oiZ]i003o`000?nL[nCoW:oT
00?oW:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW
00;oZ[cW00?o0000ojo3j?n_`nP00_n_`nP00ol0003o/lWZok?9jP03ok?9jP05o`000?ngcnco]lo/
okO?k?l000000_nje>d3o`0000Co^mW_00?o0000ok[LlOnjg?402Ol00003ojGFn0GoW]?j00?o0000
oiG>nonEc_/00onEc_/3o`0000SoQ[gi00?o0000ohRdl_n8]?801_n8]?800ol0003oTJo[oi6_j`05
oi6_j`;o00002_nR/>800ol0003o[;;Mo`000002o`0000So/K?J00Co0000okZjfOl0003o00002?nm
^mL2o`000003oknle_l0003oa/GH00Coa/GH0_l00006olK5f@03o`000?o5aM[o000000?ob<kN00?o
0000olG=h?o5cN000oo5cN000ol0003o_l[Soko:h`03oko:h`03o`000?nhanGo^<OU00;o^<OU00?o
0000ojo2j?n_`^P00_n_`^P00ol0003oYKg[ojFmj`02ojFmj`06o`000?nK^>coVkS/o`000?nK^>co
00001?nB/nd01Ol0003oRZo^ohZ_k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo03So
oooo1On>ZNP2o`0000?oVZgT00?o0000oib_i?nL[n@00onL[n@00ol0003oX;;Uoj2bi@03oj2bi@03
o`000?nU]nKoYKOV00;oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3j003ojo3j003
o`000?ncbN[o/lWZ00;o/lWZ00?o0000okO?k?ngcn`00_ngcn`3o`000003ok[DkOl0003o^mW_00?o
^mW_00?o0000ok[LlOnjg?400_njg?400ol0003o^=gcokSMl`02okSMl`03o`000?ncgOGo/mge00Co
00000_nNdoX2o`0000CoULkk0_l00003oh_8o0;o00001?n6_OT<o`0000SoTJo[00Co0000oi^^iOnK
[^GoVjkU1Ol000000onR/>;o0000ojbbg@04ojbbg@?o00001?na/mX00ol0003o^[[IokZjf@02okZj
f@;o00002?nm^mL00ol0003oa/GHolK5f006olK5f003o`000?o6aMWoa/GI00Coa/GI00?o0000olS>
g_o8c]h00oo8c]h00ol0003oaLgPolG=h003olG=h003o`000?nob^?o_l[S00;o_l[S00?o0000okS7
iOnhanD00onhanD01Ol0003o[l;Xojo2j?n_`^So000000?oYKg[4?l00004ohJ/kP03o`000?n4Znko
Q:_^00;oQ:_^00?o0000ooooooooool07oooool3o`0000gooooo000Looooo`03o`000?oooooooooo
03Sooooo1On>ZNP2ohnYi`;o000000?oVZgTo`000?nL[n@00onL[n@00ol0003oX;;Uoj2bi@03oj2b
i@03o`000?nU]nKoYKOV00?oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3j002ojo3
j003o`000?ncbN[o/lWZ00;o/lWZ00?o0000okO?k?ngcn`00ol00004ok[Dk@05o`000?nkfNoo^mW_
ok_Ikol000001?njg?400ol0003o^=gcokSMl`02okSMl`03o`000?ncgOGo/mge00;o/mge00?o0000
ojgKn?n]foP01?l00002oiG>n`;o00001_n;b?`5o`0000?oO;Oh00?o0000oh2`lon0/?<01On0/?<0
0ol0003oR:g]ohR]k@05o`000003oi6_jol0003oVjkU00OoVjkU0_l00008ojbbg@?o000000?o/K?J
o`000?nj^]T01Onj^]T2o`0000Co_K_G00Co0000olC4f_o4a=[o00002?o6aMP01ol0003oa/GIolK5
fOo6aMWo0000ol_?gOl000001Oo8c]h00ol0003oaLgPolG=h003olG=h003o`000?nob^?o_l[S00?o
_l[S00?o0000okS7iOnhanD00_nhanD00ol0003o[l;Xojo2j005o`0000;oY[cY0onM]NT00ol0003o
WKGYoiJ_j004oiJ_j0?oT:_X2ol0000Nooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`00
7?ooool2o`0003Wooooo00?o0000ohjYj?n>ZNP00_n>ZNP4ohnYi`Co00000_nL[n@00ol0003oX;;U
oj2bi@03oj2bi@03o`000?nU]nKoYKOV00;oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?X
ojo3j002ojo3j003o`000?ncbN[o/lWZ00?o/lWZ0ol00002okO?k005o`000?nje>go^]C]ok[DkOl0
00001?nkfNl01Ol0003o^]caok[LlOnjg?7o000000Co^=gc00?o0000ok?MmOncgOD00_ncgOD00ol0
003o[M_hojgKn002ojgKn003o`000?nTeo[oY=Oj00Co00000on;b?`3o`0000?oPL3l00?o0000ogbg
n?ml]oP00oml]oP00ol0003oP;3coh2`l`05oh2`l`03o`000?n8[NgoR:g]00CoR:g]0_l00009oi^^
i@04o`000?nU/N7o0000o`0000So[;;M00?o0000okZjfOnj^]T01onj^]T2o`000003okfkeol0003o
a<CJ00?oa<CJ00?o0000olK5f?o6aMP01_o6aMP00ol0003oa/GIo`000003ol_?g@03o`000?o8c]ko
b<kN00?ob<kN00?o0000olG=h?o5cN000_o5cN000ol0003o_l[Soko:h`03oko:h`04o`000?nhanGo
^<OUokS7i@Co00000_n_`nP00ol0003oY[cYojJlj@02ojJlj@05o`000?nM]NWoWKGYoifejOl00000
1OnF[nP4oi2[j0GoS:SX1?n;Z>P2o`0001[ooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo
000Looooo`03o`000?oooooooooo03Sooooo00?o0000ohjYj?n>ZNP00_n>ZNP4ohnYi`CoTjcW0ol0
0004oj2bi@03o`000?nU]nKoYKOV00?oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3
j002ojo3j003o`000?ncbN[o/lWZ00?o00001?ngcn`01Ol0003o^]C]ok[DkOnje>go000000Co^mW_
00?o0000ok[LlOnjg?400_njg?401Ol0003o^=gcokSMlonhgO?o000000Co/mge00?o0000ojgKn?n]
foP00_n]foP01Ol0003oY=OjojCGn_nTeo[o000000?oVM7k0ol00006oh70o0oo00001on8[Nd00ol0
003oTZgXo`000002o`0000CoVjkU00?o0000ojFahOnU/N400_nU/N43o`0000Co[;;M00?o0000okBi
gOnd^Md00_l00008okZjf@03o`000?o4a=[oa<CJ00Coa<CJ00?o0000olK5f?o6aMP01_o6aMP00ol0
003obloMol_?g@02ol_?g@03o`000?o8c]kob<kN00?ob<kN00?o0000olG=h?o5cN000oo5cN000ol0
003o_l[Soko:h`02oko:h`Co00000_ngbNL01Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000
oifejOnM]NT00_nM]NT00ol0003oUZoXoiJ_j002oiJ_j004o`000?n@ZnSoT:_Xoi2[j0GoS:SX1On;
Z>P00ol0003oooooooooo`0Eooooo`?o00002?ooool00ol0003oooooooooo`0;ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`03o`000?n>ZNSoSZWX00;oSZWX00Co0000ohnYion?ZNOoSjWW1OnC
[>L2oiV`j0?o000000?oX;;Uo`000?nU]nH00onU]nH00ol0003oZ[cWojZli`02ojZli`03o`000?n_
`nSo[l?X00;o[l?X1?l00002ok?9jP05o`000?ngcnco]lo/okO?k?l000000onje>d00ol0003o^mW_
ok_Ik`02ok_Ik`03o`000?njg?7o^]ca00;o^]ca00?o0000okSMlonhgO<00_nhgO<01Ol0003o/mge
ok?MmOncgOGo000000Co[M_h00Go0000ojCGn_nTeo[oY=Ojo`000004oiWAn`03o`000?n=b?coSLSl
00;o000000CoPL3lo`000?l0003o00000omf^?X00ol0003oLk7hog>an002og>an003o`000?mf[?Co
MZcd00?oMZcd00?o0000ogjZl?mnZ_001?l000000on8[Ngo0000oi:]j003oi:]j0?o000000?oVjkU
o`000?nU/N401_nU/N42o`000003ojbbgOl0003o];WM00Co];WM0_l00006okZjf@;o00001_o4a=X0
0ol0003oa/GHolK5f003olK5f003o`000?o;d=ko000000GobloM00?o0000olS>g_o8c]h00oo8c]h0
0ol0003oaLgPolG=h002olG=h003o`000?nob^?o000000;o000000?o_/oVo`000?ngbNL00ongbNL0
1Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT00_nM]NT2o`0000?oUZoX00Go
0000oi2[j?n@ZnSoT:_Xo`000004ohbXj003o`000?n;Z>SoRjSX00;oRjSX00?o0000ooooooooool0
4Oooool4o`0000_ooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?oo
ool01Ol0003oSZWXohjYj?n>ZNSo000000CoSjWW00?o0000oi>/ionC[>L00_nC[>L5oiV`j0Co0000
0_nU]nH01Ol0003oZ[cWojZlionZ_>Oo000000?o[l?X0ol00004ok?9jP03o`000?ngcnco]lo/00;o
]lo/00Go0000ok[DkOnje>go^]C]o`000004ok_Ik`03o`000?njg?7o^]ca00;o^]ca00Go0000okSM
lonhgO?o^=gco`000003ok?Mm@03o`000?n]foSo[M_h00;o[M_h00Go0000ojCGn_nTeo[oY=Ojo`00
0004oiWAn`03o`000?n=b?coSLSl00?oSLSl1?l00003ogJhnP[o00000_mf[?@00ol0003oOZ[`ogjZ
l003ogjZl0;o00001onB[NP00ol0003oYK7QojFah@08ojFah@03o`000?nd^Mgo];WM00Ko];WM00?o
0000okZjfOnj^]T00_nj^]T01?l0003o`L?Lol73g?l00006olC4fP05o`000?o6aMSoa/GHolK5f?l0
00000oo;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00?ob<kN00Co0000olG=h?o5
cN3oaLgP0_l00004okk?iP03o`000?ngbNOo]lWW00;o]lWW00Go0000ojo3j?n_`nSo[l?Xo`000004
ojJlj@03o`000?nM]NWoWKGY00;oWKGY0_l00003oiJ_j005o`000?n@ZnSoT:_Xoi2[j?l000001?n<
Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oo
oooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000ohjYj?n>ZNSoSZWXo`00
0004ohnYi`03o`000?nC[>OoTjcW00;oTjcW1OnI/>P4oj2fj0Co00000_nZ_>L4o`000003ojo3j?l0
003o/lWZ00?o/lWZ00?o0000okO?k?ngcn`00_ngcn`01Ol0003o^]C]ok[DkOnje>go000000Co^mW_
00?o0000ok[LlOnjg?400_njg?400ol0003o^=gco`00000Go`0000;oSLSl00?o0000oh2onon0_o/0
0_n0_o/3o`0000?oK:oi00Go0000ofZZm_mZZ_KoJZ[fo`000002offWm0?o00001_mnZ_000ol0003o
Qj_/ohN[k003o`0000;oTZgX00?o0000oib`i_nL/>H00ol00005ojFah@03o`000?n]^>7o000000Oo
];WM0_l000000onj^]Wo0000ol73g003ol73g003o`000?o4a=[oa<CJ00Coa<CJ00?o0000olK5f?l0
00001?o;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00?ob<kN00Ko0000olG=h?l0
003o0000olCCiOl00004okk?iP03o`000?ngbNOo]lWW00;o]lWW00Go0000ojo3j?n_`nSo[l?Xo`00
0004ojJlj@03o`000?nM]NWoWKGY00;oWKGY00?o0000oiJ_j?l000000_nF[nP01Ol0003oT:_Xoi2[
j?n@ZnSo000000CoS:SX00?o0000oh^Xj?n;Z>P00_n;Z>P00ol0003oooooooooo`0;ooooo`?o0000
4oooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0iooooo`05o`000?n>
ZNSoSZWXohjYj?l000001?n?ZNL00ol0003oTjcWoi>/i`02oi>/i`03o`000?nI/>SoVK3X00;oVK3X
1OnP]^P00ol0003oYkcXojNlj00:o`0000;o/lWZ00?o0000okO?k?ngcn`00_ngcn`@o`0000;oa=g[
00Go0000ol7Mk_o1gNko`Mg^o`000004ok_Ll005o`000?ncfO?o/mWcok?Ilol000001?nXe?L01?l0
003oVlcioi_<nOnKc?T4o`0000;oP;ok00Co0000og>dn_mc]?[oLkCj0_l00002ofb_n@05o`000?mZ
Z_KoJZ[fofZZm_l000000om]Yo@00ol0003oM:KaogBVl@04o`0000KoQj_/0_l00006oib`iP?o0000
00?oYK7Qo`000?n]^>400_n]^>42o`0000Oo];WM00?o0000ol73g?o1`m`01?o1`m`00ol0003oa<CJ
olC4fP03olC4fP;o00001_o;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00;ob<kN
0_l00003olCCi@03o`000?nncnKo_/oV00;o_/oV00?o0000okO9iongbNL00_ngbNL01Ol0003o[l?X
ojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT00_nM]NT01_l0003oUZoXoiJ_j?l0003oUZoX
o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooo
oooo00Oooooo1?l0000Fooooo`03o`000?oooooooooo00[ooooo000Kooooo`;o0000>Oooool00ol0
003oSZWXohjYj002ohjYj003o`000?n?ZNOoSjWW00;oSjWW00?o0000oi>/ionC[>L00_nC[>L00ol0
003oVK3XoiV`j002oiV`j0GoX;KX0ol000000onW_>So0000ojo3j003ojo3j004o`000?nfbNSo]/WX
okK9j0So00000_o1e>P00ol0003o`mSYol?Hj@02ol?Hj@03o`000?o5fn[oaM_Z00;oaM_Z00?o0000
olCMjoo4gN/00_o4gN/01Ol0003o`Mg^ol7Mk_o1gNko000000Co^mc`00Go0000ok?IloncfO?o/mWc
o`000004ojSDm`03o`000?nKc?WoVlci00;oVlci00?o0000ohg3n_n=`oX01Ol00002og>dnP_o0000
00?oKJOdo`000?mdY_400omdY_400ol0003oQj_/ohN[k005ohN[k004o`000?n@[^[o0000o`0000Ko
W;3V00?o0000ojfhhOn]^>401?n]^>42o`0000?o];WM00Go0000ok_2gonk`]oo^l;Oo`000005ol73
g007o`000?o4a=[oa<CJolC4f_l0003obLoOo`000006ol_@gP03o`000?o;cmgobloM00?obloM00?o
0000olS>g_l000000_l000000oo8enGo0000olCCi@02olCCi@03o`000?nncnKo_/oV00;o_/oV00?o
0000okO9iongbNL00_ngbNL01Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT0
0_nM]NT01?l0003oUZoXoiJ_j?nF[nP2o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003o
RjSXoh^Xj002oh^Xj003o`000?oooooooooo00Cooooo0ol0000Jooooo`03o`000?oooooooooo00[o
oooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ohjYj?n>ZNP00_n>ZNP00ol0003oSjWW
ohnYi`02ohnYi`03o`000?nC[>OoTjcW00;oTjcW00?o0000oiV`j?nI/>P00_nI/>P00ol0003oX;KX
o`000003o`0000?oYkcX00?o0000ojo3j?n_`nP00_n_`nP00ol0003o]/WXokK9j002okK9j003o`00
0?nlcnSo_<oX00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?Hj@03o`000?o5fn[oaM_Z00;o
aM_Z00Go0000olCMjoo4gN_oa=g[o`000004ol7MkP05o`000?nkg?3o^mc`ok_Ll?l000000oncfO<0
0ol0003oZ=CgojSDm`02ojSDm`03o`000?nKc?WoVlci00;oVlci00?o0000ohg3n_n=`oX00_n=`oX0
1?l0003oOKSiogfhnOmm^?T3o`0000;oJ:_g0_l000001_mSYoKo0000of:TmOmRY?Go0000ofBSl`;o
00000_mdY_400ol0003oM:Kao`000002og^Wk`?o000000?oQj_/o`000?n@[^X00on@[^X00ol0003o
W;3Voib`iP02oib`iP04o`000?nS]^KoXkKVo`0000Ko[KSQ00?o0000okBigOl000001Onk`]l00ol0
003o`L?Lol73g003ol73g003o`000?o4a=[o000000?obLoO00?o0000ol_@g_o;d=h00oo;d=h00ol0
003obloMol_?g@03ol_?g@;o00001?o8enD01Ol0003oa=?UolCCiOo4dnGo000000Co_/oV00?o0000
okO9iongbNL00_ngbNL00ol0003o[l?Xojo3j002ojo3j005o`000?nV_>WoY[cYojJljOl000001?nM
]NT01?l0003oUZoXoiJ_j?nF[nP2o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003oRjSX
oh^Xj002oh^Xj004o`000?ooooooooooooooo`?o00007Oooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0hooooo`03o`000?n>ZNSoSZWX00;oSZWX00?o0000ohnYion?ZNL0
0_n?ZNL00ol0003oTjcWoi>/i`02oi>/i`04o`000?nI/>SoVK3XoiV`j0?o00000onP]^P01Ol0003o
YkcXojNlj?nW_>So000000Co[l?X00?o0000okK9j?nfbNP00_nfbNP00ol0003o_<oXokc?j002okc?
j005o`000?o1e>So`MCXol7Dj?l000001?o3f>T01Ol0003oaM_ZolGKj_o5fn[o000000Coa=g[00Go
0000ol7Mk_o1gNko`Mg^o`000004ok_Ll003o`000?ncfO?o000001?o00000_mm^?T01Ol0003oKZkg
o`000?l0003oJ:_g00Wo00000omYX_82o`0000GoNjO_0_l00005oi2^jP;o000000?oW;3Vo`000?nS
]^H00onS]^H2o`0000Go[KSQ00?o0000ok_2gonk`]l01Onk`]l00ol0003o`L?Lol73g003ol73g003
o`000?o9cmoobLoO00?obLoO00?o0000ol_@g_o;d=h00oo;d=h00ol0003obloMol_?g@02o`000003
ol[IiOl0003ob=OU00?ob=OU00Go0000olCCiOo4dnGoa=?Uo`000004okk?iP03o`000?ngbNOo]lWW
00;o]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000
oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xoi2[j002oi2[j005o`000?n<Z>SoS:SXohbXj?l000001?n;
Z>P4o`00023ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0>?ooool0
0ol0003oSZWXohjYj002ohjYj005o`000?n?ZNOoSjWWohnYiol000001OnC[>L5o`0000CoX;KX00?o
0000ojNlj?nW_>P00_nW_>P01Ol0003o[l?Xojo3j?n_`nSo000000Go]/WX00?o0000okc?j?nlcnP0
0_nlcnP01Ol0003o`MCXol7Dj?o1e>So000000Co`mSY00Go0000olGKj_o5fn[oaM_Zo`000004olCM
j`05o`000?o1gNko`Mg^ol7Mk_l000000_nkg?04o`0000;o_=?[00?o0000ok?@koncd>l00_ncd>l0
0ol0003oY/[cojK:l`02ojK:l`05o`000?nG`oKoUl?foiO3m_l000000on5^OL5o`000003ofj^mol0
003o000000;oGZ?e0_l000002_mLWo?o0000oefOlomMWo?o0000ofVRl_l0003oJJ;bo`000?m_Y?43
o`000004og^Wkol0003oPj[^oh>ZkP;o00001?n@[^X00ol0003oXkKVoj>fiP05oj>fiP04o`000?n]
^>7o0000o`0000?o/l3T00?o0000ok_2gonk`]l01?nk`]l01_l0003o`L?Lo`000?l0003oaLoRo`00
00KobLoO00?o0000ol_@g_o;d=h00_o;d=h00ol0003obloMo`000003ol[Ii@03o`000?o8enGob=OU
00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo000000Co]lWW00?o0000
ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000oiJ_j?nF[nP00_nF
[nP2o`0000?oT:_X00Go0000ohbXj?n<Z>SoS:SXo`000004oh^Xj003o`000?oooooooooo027ooooo
00?o0000ooooooooool02_ooool001[ooooo0ol0000iooooo`03o`000?n>ZNSoSZWX00;oSZWX00Go
0000ohnYion?ZNOoSjWWo`000004oi>/i`;o00000onI/>P00ol0003oX;KXoj2fj002oj2fj003o`00
0?nW_>SoYkcX00;oYkcX00Go0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX00;o
_<oX00?o0000ol7Dj?o1e>P00_o1e>P00ol0003o`mSYol?Hj@02ol?Hj@05o`000?o5fn[oaM_ZolGK
j_l000001?o4gN/00ol0003o`Mg^ol7MkP04o`0000;o`mGW00?o0000okcCjonldn/00_nldn/01Ol0
003o/m3_ok?@koncd>oo000000GoY/[c00Go0000oiO3m_nG`oKoUl?fo`000003ohFim`04o`000?md
[oKoM:ofogB_mPSo000000KoG9oco`000?mMWo?oGIoco`000?mOWo82o`0000CoKjCa00?o0000oh>Z
k_n3Z^h00on3Z^h00ol0003oT:kZo`000003oiNcj`;o00001OnS]^H00ol0003o/l3Tok?0i004ok?0
i003o`000?nk`]oo^l;O00Co^l;O00?o0000olG?h_o5cn800_o5cn800ol0003obLoOolW?g`03olW?
g`03o`000?o;d=kobm3N00;obm3N0_l00004ol[Ii@03o`000?o8enGob=OU00;ob=OU00?o0000olCC
iOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP0
1Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xo`00
0002oi2[j005o`000?n<Z>SoS:SXohbXj?l000001?n;Z>P00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo03Wooooo00?o0000ohjYj?n>ZNP00_n>
ZNP01_l0003oSjWWohnYion?ZNOo0000oi>/i`Co00001?nI/>P00ol0003oX;KXoj2fj002oj2fj003
o`000?nW_>SoYkcX00;oYkcX00Go0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX
00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?Hj@03o`000?o5fn[oaM_Z00;oaM_Z00Co0000
olCMjoo4gN_oa=g[1?l000000oo8e^Co0000ol?Ei`03ol?Ei`03o`000?nldn_o_=?[00;o_=?[00?o
0000ok?@koncd>l00_ncd>l00ol0003oY/[cojK:l`0>o`000004ogB_m_l0003oIJGeo`0000;oHZCe
2_l000001_mSWo;o0000o`000?m_Y?7o0000ogBVl@?o00000_n3Z^h00ol0003oUk?[oiNcj`04oiNc
j`;o000000GoXkKVo`000?nX_NSoZ;gXo`000006ok?0i007o`000?nk`]oo^l;Ook_2gol0003o_/gU
o`000005olG?hP03o`000?o9cmoobLoO00?obLoO00Ko0000ol_@g_l0003o0000ol[KiOl00004ol[I
i@03o`000?o8enGob=OU00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo
000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o
0000oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xo`000002oi2[j005o`000?n<Z>SoS:SXohbXj?l00000
1?n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00001?lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0>Oooool01Ol0003oSZWXohjYj?n>ZNSo000000?oSjWW0ol00003oi>/i`03o`000?nI/>SoVK3X
00;oVK3X00?o0000oj2fj?nP]^P00_nP]^P00ol0003oYkcXojNlj002ojNlj005o`000?n_`nSo[l?X
ojo3j?l000001?nfbNP00ol0003o_<oXokc?j002okc?j005o`000?o1e>So`MCXol7Dj?l000001?o3
f>T01Ol0003oaM_ZolGKj_o5fn[o000000;oa=g[0ol00004olSFi003o`000?o3eNOo`mGW00;o`mGW
00?o0000okcCjonldn/00_nldn/00ol0003o/m3_ok?@k`05o`0000;oZlC/00Go0000oibnl?nL__3o
W;k`o`000004oh^gl`03o`000?mh[_CoN:kd00Oo000000?oFIgco`000?l000000_l000001?mGVo;o
0000oeRLl_l00002of>OlP;o00001OmdY_401?l0003oR:k_ohR^kon8[^l2o`0000GoUk?[00?o0000
ojRmj?nX_NP00_nX_NP00ol0003o/l3Tok?0i004ok?0i003o`000?nk`]oo000000?o_/gU00?o0000
olG?h_o5cn800_o5cn800ol0003obLoOolW?g`03olW?g`;o00000oo:fnD00ol0003ob]WUol[Ii@02
ol[Ii@03o`000?o8enGob=OU00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nn
cnKo000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY
00?o0000oiJ_j?nF[nP00_nF[nP01_l0003oT:_Xoi2[j?l0003oT:_Xo`0000?oS:SX00?o0000oh^X
j?n;Z>P00_n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Wooooo00Co0000ohjYj?n>ZNSoSZWX1?l000000on?ZNOo0000oi>/i`03oi>/i`03o`000?nI/>So
VK3X00;oVK3X00?o0000oj2fj?nP]^P00_nP]^P01Ol0003oYkcXojNlj?nW_>So000000Co[l?X00?o
0000okK9j?nfbNP00_nfbNP00ol0003o_<oXokc?j002okc?j005o`000?o1e>So`MCXol7Dj?l00000
1?o3f>T00ol0003oaM_ZolGKjP04o`0000;ob]KS00?o0000olSFi?o8e^@00oo8e^@00ol0003o`mGW
ol?Ei`02ol?Ei`04o`000?nldn_o_=?[okcCj`?o00000_nfanL00ol0003oZlC/oj_4k003oj_4k005
o`000?nL__3oW;k`oibnl?l000001?n;]o<01?l0003oN:kdogR^m?l00003ofNUm0Co000000?oFIgc
o`000?l000001?l000000omIW?;o0000ofJQlP02ofJQlP03o`000?mdY_7o000000?oN:Wa00Ko0000
ohR^kon8[^ooR:k_o`000?nG/n/2o`0000;oVkW]00?o0000ojRmj?nX_NP00_nX_NP00ol0003o/l3T
ok?0i004ok?0i003o`000?nncNGo_/gU00;o_/gU00?o0000olG?h_o5cn800oo5cn800ol0003obLoO
o`000002o`000003olSKiol0003ob]_U00;ob]_U00?o0000ol[IiOo:fND00oo:fND01Ol0003ob=OU
olSGiOo8enGo000000Coa=?U00?o0000okk?i_l000006?l000000onF[nSo0000oi2[j002oi2[j0;o
00000on<Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02Oooool000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Wooooo1Ol00004ohnYi`03o`000?nC[>OoTjcW00;oTjcW00?o0000oiV`j?nI/>P0
0_nI/>P00ol0003oX;KXoj2fj002oj2fj005o`000?nW_>SoYkcXojNlj?l000001?n_`nP00ol0003o
]/WXokK9j002okK9j003o`000?nlcnSo_<oX00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?H
j@?o000000?ob]CRo`000?o:e^<00oo:e^<00ol0003ob=KTolSFi003olSFi003o`000?o3eNOo`mGW
00;o`mGW1?l000000onnb^?o0000okK7i`03okK7i`03o`000?n[a>coZlC/00;oZlC/00?o0000oibn
l?nL__004?l000000omJWO?o0000o`000005o`000004oeVLl_l0003oFYcbo`0000;oIZ7b00?o0000
ogRYlOmhZO400omhZO401Ol0003oR:k_ohR^kon8[^oo000000GoVkW]00?o0000ojRmj?nX_NP00_nX
_NP00ol0003o/l3To`000002o`000003okG:jOl0003o_/gU00Co_/gU00?o0000olG?h_o5cn800_o5
cn82o`0000Cob=_W00Go0000ol[KiOo:fnGob]_Uo`000005ol[Ii@05o`000?o8enGob=OUolSGiOl0
00000_o4dnD4o`0000;o^m7[00?o0000okK:jOnfb^T00_nfb^T00ol0003o[l?Xojo3j002ojo3j005
o`000?nX^nOoZ;_WojRkiol000001?nR]>H01?l0003oW:oUoib_iOnL[nD5o`000003oi2[j?l0003o
S:SX00;oS:SX00?o0000oh^Xj?n;Z>P00_n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Wooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0hooooo`?o000000?oPZS]o`000?l000000ol000000on?ZNOo0000oi>/i`03oi>/
i`05o`000?nI/>SoVK3XoiV`j?l000001OnP]^P01Ol0003oYkcXojNlj?nW_>So000000Co[l?X00?o
0000okK9j?nfbNP00_nfbNP01Ol0003o_<oXokc?j?nlcnSo000000Co`MCX00?o0000ol?HjOo3f>T0
0ol00004ol[DhP03o`000?o:e^?ob]KS00;ob]KS00?o0000olSFi?o8e^@00_o8e^@01?l0003o`mGW
ol?Eioo3eNL2o`0000Go_/[S00?o0000okK7ionfanL00_nfanL00ol0003oZlC/oj_4k004o`0000Co
W;S/00Go0000ohbcl?n</o3oS;?`o`000003ogZ/l`04o`000?mXY??oJ:Cco`0000;oFigb1ol00003
oeZLlP05o`000?mXXo;oJ:?bofRSl_l000001?mhZO42o`0000?oRk?a00?o0000oi^ikOnK^Nd00_nK
^Nd00ol0003oZ;gXojRmj003o`0000Go]L[Y00?o0000okk=iOnncND00_nncND00ol0003oaLoRo`00
0002o`000003ol?Jj_l0003ob=_W00?ob=_W00?o0000ol[KiOo:fnD00_o:fnD00ol0003ob]WUol[I
i@02ol[Ii@03o`000?o8enGob=OU00Co00000_o0f>/01?l0003o^m7[ok_Ajol00004okK:j@03o`00
0?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00?o
W:oU00Co0000oiR[i?nHZnCoV:_T1?l000000on<Z>So0000oh^Xj003oh^Xj003o`000?oooooooooo
02;ooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool3oh:Xk@CoQ:W]1Ol000000onC
[>Oo0000oiV`j002oiV`j003o`000?nP]^SoX;KX00;oX;KX00?o0000ojNlj?nW_>P00_nW_>P01Ol0
003o[l?Xojo3j?n_`nSo000000Co]/WX00?o0000okc?j?nlcnP00_nlcnP00ol0003o`MCXol7Dj005
o`0000;ob=;R00?o0000ol[Dh_o:e>800_o:e>800ol0003ob]KSol[Fh`02ol[Fh`03o`000?o8e^Co
b=KT00?ob=KT0ol000000oo4bmoo0000okk:h`05okk:h`04o`000?nfanOo]/OWokK7i`?o00001?nY
_>L00ol0003oW;S/oibhk002oibhk004o`000?n</o3oS;?`ohbcl0?o000000?oNZcco`000?l00000
3_l000001?mKWO;o0000o`000?mXXo82o`0000;oNJcc00?o0000oh^clOn;/o400on;/o401Ol0003o
VkW]oi^ikOl0003oVkW]00;o00000_nYaNh00ol0003o]L[YokG:j@04okG:j@04o`000?nncNGo_/gU
okk=i@;o00001?o3f^X00ol0003ob=_WolSKi`02olSKi`03o`000?o:fnGob]_U00;ob]_U00?o0000
ol[IiOo:fND00_o:fND3o`000003ol?Lk?l0003o`=S[00;o`=S[00Go0000ok_AjonkdN_o^m7[o`00
0004okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`00
0?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@2o`000003oiBXhol0003o000000?o0000
00?oRjSXo`000?ooool08oooool00ol0003oooooooooo`09ooooo`000oooool00ol@413ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool3o`0000Gooooo1?n2
Z>d4ohBYk@CoRJc]1?l000000onI/>So0000oj2fj003oj2fj003o`000?nW_>SoYkcX00;oYkcX00Go
0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX00Go00000_o4cn<00ol0003ob=;R
olSBhP02olSBhP03o`000?o:e>;ob]CR00;ob]CR00?o0000ol[Fhoo:e^<00_o:e^<00ol0003ob=KT
olSFi002olSFi0;o00001?o4bml00ol0003o_/[Sokk:h`03okk:h`04o`000?nfanOo0000o`0000?o
/kkR00?o0000ojVlionY_>L00_nY_>L00ol0003oW;S/oibhk002oibhk0;o00000on9[^h01?l0003o
N:WaogRYlOl00003ofRSlP03o`000?mJW?;oFYcb00Wo000000GoFigbo`000?mXY??oJ:Cco`000003
ogV/l`06o`000?n;/o7oRk?aoh^clOl0003oRk?a0_l00002oiZolP03o`000?nYaNkoZLG^00;oZLG^
00?o0000okG:jOneb^T00oneb^T01_l0003o_/gUo`000?l0003o_=O^o`0000Co`m[Z00?o0000olSK
ioo8fnL00_o8fnL00ol0003ob]_Uol[Ki@02ol[Ki@03o`000?o:fNGob]WU00?o00000oo3g>`01Ol0
003o`=S[ol3Hjoo0f>_o000000?o^m7[00?o0000okK:jOnfb^T00_nfb^T00ol0003o[l?Xojo3j002
ojo3j005o`000?nX^nOoZ;_WojRkiol000001?nR]>H00ol0003oW:oUoib_i@02oib_i@03o`000?nH
ZnCoV:_T00;oV:_T00Ko0000oiBXhonDZ>?o0000oiBXhol00003oi>Xi0;o00009Oooool00ol0003o
ooooooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo033ooooo0ol00008ooooo`04o`000?n2Z>goPZS]oh:Xk@CoQ:W]00?o0000ohV/
kOn9[>d00_n9[>d3oi:ak0Go000000?oX;KXo`000?nW_>P00onW_>P01Ol0003o[l?Xojo3j?n_`nSo
000000;o]/WX1Ol00002oko<i003o`000?o4cn?oa<oS00;oa<oS00?o0000olSBh_o8d^800oo8d^80
0ol0003ob]CRol[DhP02ol[DhP03o`000?o:e^?ob]KS00;ob]KS1?l000000oo8bmco0000olC;g`04
olC;g`03o`000?nnb^?o_/[S00;o_/[S0_l00006ok>nhP03o`000?nY_>OoZKcW00;oZKcW00?o0000
oibhk?l000000onH/^X01_l0003oRJk^ohV^k_n9[^ko0000ogRYl@?o00000omVXO82o`000003oeVL
l_l0003o000000Co00000omJWO<:o`0000;oRKOd00?o0000oiZol_nJ_o800_nJ_o800ol0003oZLG^
ojW5kP02ojW5kP04o`000?neb^Wo]L[YokG:j@?o00000onlenh00ol0003o`m[Zol?JjP03ol?JjP05
o`000?o8fnOob=_WolSKiol000000oo:fnD4o`0000;oa>3]00Co0000ol?Lk?o3g>co00001?o0f>/0
1?l0003o^m7[ok_Ajol00004okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_W
o`000004oj:diP03o`000?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@01Ol0003oU:SS
oiBXhonDZ>?o000000GoTjST00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`00
00Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0;Oooool3o`0000co
oooo00Co0000oh:XkOn2Z>go00001?n4ZNd00ol0003oRJc]ohV/k@02ohV/k@?oT[7/1?nK]n/=o`00
00;o^<OV1Onoc>@00ol0003oa<oSolC?h`03olC?h`03o`000?o8d^;ob=;R00;ob=;R00?o0000ol[D
h_o:e>800_o:e>801?l0003ob]KSol[Fhoo:e^<2o`0000Gob<_L00?o0000olC;goo4bml00_o4bml0
1Ol0003o_/[Sokk:honnb^?o000000?o^koM00?o0000ok>nh_nc_^800onc_^801?l0003oZKcWojVl
ionY_>L2o`0000KoV;;Z00Co0000ohV^k_n9[^ko00001?mdY_43o`000003of>Ol_l0003o000000;o
000000?oEicboeNLlomGW?<00_mHWO<3o`0000;oIJGe0_l00002ogR^m@03o`000?n9]oCoRKOd00;o
RKOd00?o0000oiZol_nJ_o800_nJ_o800ol0003oZLG^ojW5kP05o`0000;o/M;a00Go0000okcGk_nl
enko_=O^o`000005ol?JjP04o`000?o8fnOob=_WolSKi`Co000000?o`n;^o`000?o4h>d00_o4h>d0
1Ol0003o`mc/ol?Lk?o3g>co000000?o`=S[00Go0000ok_AjonkdN_o^m7[o`000004okK:j@03o`00
0?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00;o
W:oU00?o0000oiR[i?nHZn@00_nHZn@00ol0003oU:SSoiBXh`02oiBXh`03o`000?nCZ>CoTjST00;o
TjST00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003ooooo
ooooo`0Zooooo`?o00003oooool01Ol0003oPZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/kOn9
[>d00_n9[>d4oi:ak0CoVkO[1OnU_NX4ojo2j0Ko^<OV1Onoc>@00ol0003oa<oSolC?h`02olC?h`03
o`000?o8d^;ob=;R00;ob=;R00?o0000ol[Dh_o:e>800_o:e>801_l0003ob]KSo`000?l0003obL_K
o`0000Kob<_L00?o0000olC;goo4bml00_o4bml00ol0003o_/[So`000005ok^og@03o`000?nc_^;o
/kkR00?o/kkR00?o0000ojVliol000000onT]N@2o`0000CoV;;Z00Co0000ohBZk_n4Z^koQ:[^0_l0
00001?mdY_7o0000ofnTlOm_Y?42o`0000;oGiob0_l000000omGW?;oEiccoeNLl`02oeNMl`Co0000
00CoIJGeo`000?mc[oOoLjog1Ol000000on9]oCo0000o`000005o`0000;oY<cd00?o0000ok7BlOna
d_400_nad_400ol0003o_=O^okcGkP02okcGkP03o`000?o3f^[o`m[Z00;o`m[Z00?o0000olSKiol0
00000_l00003ol?RkP03o`000?o4h>goa>3]00;oa>3]00Go0000ol?Lk?o3g>co`mc/o`000003ol3H
j`05o`000?nkdN_o^m7[ok_Ajol000000onfb^T00ol0003o[l?Xojo3j002ojo3j003o`000?nX^nOo
Z;_W00;oZ;_W00Go0000oj:di_nR]>KoX[CVo`000004oib_i@03o`000?nHZnCoV:_T00?oV:_T00Oo
0000oiBXhonDZ>?oU:SSo`000?nCZ>Co000000?oTjST00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`08ooooo`006Oooool2o`0002Sooooo0ol0000Booooo`05o`000?n2Z>goPZS]oh:XkOl0
00000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`000?nB/NcoT[7/oi:ak?l000000onK]n/00ol0
003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o[l;X1OnhanH00ol0003o_lcToko<i002oko<
i003o`000?o4cn?oa<oS00;oa<oS00?o0000olSBh_o8d^800_o8d^800ol0003ob]CRol[DhP02ol[D
hP;o00001?o9bm/00ol0003ob<_LolS;g004olS;g004o`000?o4bmooa<_OolC;g`;o00001onk_md0
0ol0003o/kkRok>nhP03ok>nhP03o`000?nT]NCoY;GT00CoY;GT00?o0000oiRbj_l000000onA[NT2
o`0000;oQ:[^0_l00003ofnTl@Co000000?oGIoco`000?l000001?l000001?mNXoGo0000of6TmOmQ
Y?D5o`0000CoQ;Wg00?o0000oiG3monE`oL00_nE`oL01Ol0003oY<cdojC<m?nTc?Co000000Co/M;a
00?o0000okcGk_nlenh00_nlenh00ol0003o`m[Zol?JjP04o`0000;o_n;`00Go0000ol?Rk_o3h^ko
`n;^o`000003olCPk@05o`000?o3g>co`mc/ol?Lk?l000001?o0f>/01?l0003o^m7[ok_Ajol00004
okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL
[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@01Ol0003oU:SSoiBXhonDZ>?o000000;oTjST
00?o0000oi>Xi?l000009oooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003ooooooooo
o`0Tooooo`?o00005_ooool01?l0003oPZS]oh:XkOl00004ohBYk@03o`000?n9[>goRJc]00;oRJc]
00Co0000oi:ak?nB/Nco00001?nK]n/00ol0003oYKgZojFmjP02ojFmjP05o`000?n_`^So[l;Xojo2
j?l000001?nhanH00ol0003o_lcToko<i002oko<i003o`000?o4cn?oa<oS00?oa<oS00Go0000olSB
h_o8d^;ob=;Ro`000002ol[DhP;o000000?obL_Ko`000?o9bm/01?o9bm/00ol0003ob<_LolS;g004
olS;g003o`000?o4bmoo000000?o`<3J00?o0000ok^ogOnk_md01?nk_md01?l0003o/kkRo`000?l0
0003ojjfg`03o`000?nT]NCoY;GT00?oY;GT00?o0000oi6]jOnA[NT01?nA[NT01?l0003oQ:[^o`00
0?mlYnl4o`0000;oJJ?b1?l00002oe^Ol`;oG:7d00?o0000oejSmOmNXoD00_l00003off^m`Co0000
00?oQ;Wgo`000?nE`oL00onE`oL00ol0003oY<cdojC<m002ojC<m005o`000?nad_7o/M;aok7BlOl0
00000_nlenh5o`0000;o^^3c00Go0000okoRl?noh_3o_n;`o`000003ol?RkP05o`000?o4h>goa>3]
olCPkOl000000oo3g>`01Ol0003o`=S[ol3Hjoo0f>_o000000?o^m7[00?o0000okK:jOnfb^T00_nf
b^T00ol0003o[l?Xojo3j002ojo3j005o`000?nX^nOoZ;_WojRkiol000001?nR]>H01Ol0003oW:oU
oib_iOnL[nGo000000GoV:_T00?o0000oiBXhonDZ><00_nDZ><01?l0003oTjSToi>Xi?nCZ>@2o`00
02Oooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000ooooooooool08_ooool3o`0001Wo
oooo00Go0000oh:XkOn2Z>goPZS]o`000003ohBYk@03o`000?n9[>goRJc]00;oRJc]00Go0000oi:a
k?nB/NcoT[7/o`000003oi^gj`03o`000?nU_N[oYKgZ00;oYKgZ00Go0000ojo2j?n_`^So[l;Xo`00
0005okS7iP03o`000?noc>Co_lcT00;o_lcT00?o0000olC?hoo4cn<00_o4cn<00ol0003ob=;RolSB
hP02olSBhP;o00001?o9bm/00ol0003obL_KolW;f`03olW;f`03o`000?o8bmcob<_L00?ob<_L0_l0
0005ol30fP;o00001Onk_md00ol0003o[[KOojjfg`04ojjfg`;o00000onT]N@00ol0003oWJoUo`00
0002o`0000?oTJgY0ol00003ogbWk`Go00000_mTXo<8o`000003ofN[mol0003o000000;oKJkg00?o
0000og^hnOmk^?T01Ol000000onE`oOo0000ojC<m003ojC<m003o`000?nad_7o000000Co00000_na
g?H01Ol0003o^^3cok[Plonjh??o000000?o_n;`00Go0000ol?Rk_o3h^ko`n;^o`000004olCPk@05
o`000?o3g>co`mc/ol?Lk?l000000oo0f>/01Ol0003o^m7[ok_AjonkdN_o000000?o]/[Y00?o0000
ojo3j?n_`nP00_n_`nP00ol0003oZ;_WojRki`02ojRki`05o`000?nR]>KoX[CVoj:di_l000001?nL
[nD00ol0003oV:_ToiR[i003oiR[i005o`000?nDZ>?oU:SSoiBXhol000001?nCZ>@00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo023ooooo0_l0
000Looooo`05o`000?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`00
0?nB/NcoT[7/oi:ak?l000000onK]n/00ol0003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o
[l;X00?o0000okS7i_nhanH00_nhanH00ol0003o_lcToko<i002oko<i003o`000?o4cn?oa<oS00;o
a<oS00Co0000olSBh_o8d^;ob=;R0_l00006olW;f`03o`000?o9bm_obL_K00?obL_K00Go0000olS;
g?o8bmcob<_Lo`000003olC1e`03o`000?o0`=[o`<3J00?o`<3J00Go0000ok^ogOnk_mgo^koMo`00
0002okBgf`;o00001On^]]l00ol0003oY;GTo`000005oif_i@;o000000CoTJgYo`000?n8Z^coR:[/
1?l00003ogBVl@Ko000000?oHZCeo`000?mSYoH00_mSYoH00ol0003oIj_gofN[m`04o`0000;oNkSi
00Co0000oh[4n_n:a?[oR/Cj2?l00002ojKFn005o`000?nag?Ko/Mcfok7Lm_l000001?njh?<01Ol0
003o_n;`okoRl?noh_3o000000?o`n;^00Go0000olCPkOo4h>goa>3]o`000004ol?Lk005o`000?o0
f>_o`=S[ol3Hjol000000_nkdN/00ol0003o]/[YokK:j@02okK:j@03o`000?n_`nSo[l?X00;o[l?X
00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nH
Zn@00_nHZn@00ol0003oU:SSoiBXh`02oiBXh`03o`000?nCZ>CoTjST00;oTjST0_l0000Xooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Oooooo`05o`00
0?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@04o`000?nB/NcoT[7/o`00
00CoVkO[00?o0000ojFmj_nU_NX00_nU_NX01Ol0003o[l;Xojo2j?n_`^So000000Co^<OV00?o0000
oko<i?noc>@00_noc>@00ol0003oa<oSolC?h`03olC?h`?o000000?ob<[Lo`000?o9bm/01_o9bm/0
0ol0003obL_KolW;f`03olW;f`03o`000?o8bmco000000Goa<7G00?o0000ol30f_o0`=X00oo0`=X0
0ol0003o^koMo`000005okBgf`;o00001?n^]]l00ol0003oWJoUoif_i@06oif_i@;o00001On8Z^`3
o`0000;oM:Ka00Co0000offWm?m]YoCoKJOd1?l00002of>WmPCo00000omb]?X5o`0000;oR/Cj00?o
0000oiW>n_nIc_X00_nIc_X01Ol0003oY]KhojKFn?nVe_So000000?o/Mcf00Go0000ok[Plonjh??o
^^3co`000004okoRl005o`000?o3h^ko`n;^ol?Rk_l000000oo4h>d01_l0003o`mc/ol?Lk?o3g>co
0000ol3Hj`Wo00000_nfb^T00ol0003o[l?Xojo3j002ojo3j005o`000?nX^nOoZ;_WojRkiol00000
0onR]>H00ol0003oW:oUoib_i@02oib_i@03o`000?nHZnCoV:_T00?oV:_T00Go0000oiBXhonDZ>?o
U:SSo`000004oi>Xi004o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01oooool001So
oooo0_l0000Kooooo`?o00008_ooool01Ol0003oPZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/
kOn9[>d00_n9[>d01Ol0003oT[7/oi:ak?nB/Nco000000?oVkO[00?o0000ojFmj_nU_NX00_nU_NX0
1Ol0003o[l;Xojo2j?n_`^So000000Go^<OV00Go0000oko<i?noc>Co_lcTo`000004olC?h`;o0000
1?o8b]`00ol0003obL_KolW;f`04olW;f`03o`000?o9bm_obL_K00?obL_K0_l00007olC1e`03o`00
0?o0`=[o`<3J00?o`<3J00?o0000okBgfond]m/01_nd]m/2o`000004ojjfgol0003oYK7PojFah0?o
00001?nM[nD00ol0003oTjcXo`000002o`0000;oR:[/00?o0000ognZkomoZ^l01?l00003offWm003
o`000?mYZ_OoJJ[g00;o00001?m[[oT01?l0003oL[Cjog:dn_l00004ogjoo0Co00000_nIc_X01Ol0
003oY]KhojKFn?nVe_So000000Co/Mcf00Go0000ok[Plonjh??o^^3co`000003okoRl003o`000?o3
h^ko000000co00000_nienl01Ol0003o]]7]okKAkOnfdNgo000000;o/l[[2Ol00002ojRki`05o`00
0?nR]>KoX[CVoj:di_l000001?nL[nD00ol0003oV:_ToiR[i002oiR[i003o`000?nDZ>?oU:SS00;o
U:SS00?o0000oi>Xi?nCZ>@00_nCZ>@01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
00Oooooo000Hooooo`03o`000?oooooooooo01Oooooo0ol0000Uooooo`05o`000?n2Z>goPZS]oh:X
kOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`000?nB/NcoT[7/oi:ak?l000000onK]n/0
0ol0003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o[l;X00?o0000okS7i_nhanH00_nhanH0
0ol0003o_lcToko<i002oko<i0Co000000?oa<WNo`000?o8b]`01?o8b]`00ol0003obL_KolW;f`04
olW;f`05o`000?o9bm_obL_KolW;fol000000oo5`MH00ol0003oa<7GolC1e`04olC1e`05o`000?o0
`=[o`<3Jol30f_l000000_nj^=P2o`0000Oo];OK00?o0000ojFah?nU/N001?nU/N04o`0000GoTjcX
0ol00005ognZk`Co000000?oKJOdo`000?mYZ_L00_mYZ_L2o`0000;oJjoi1?l00003ogjoo003o`00
0?n:bOgoR/Wm00;oR/Wm1Ol000000onVe_So0000ok7LmP02ok7LmP03o`000?njh??o000000So0000
0_nfh_D01Ol0003o^N3cokWPlonih??o000000Co^]ca00Co0000okWGkonienoo00000onfdNd00ol0
003o/l[[ok?:j`02ok?:j`03o`000?n_`nWo[l?Y00;o[l?Y00?o0000ojZli_nZ_>H01?l00002oj:d
iP05o`000?nL[nGoW:oUoib_iOl000001OnHZn@01Ol0003oU:SSoiBXhonDZ>?o000000GoTjST00Go
0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oo
oooooooo01Cooooo0ol0000Yooooo`05o`000?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]
ohV/k@02ohV/k@04o`000?nB/NcoT[7/o`0000CoVkO[00?o0000ojFmj_nU_NX00_nU_NX01Ol0003o
[l;Xojo2j?n_`^So000000Co^<OV00Co0000oko<i?noc>Co_lcT0_l00005olC9gP03o`000?o8b]co
b<[L00?ob<[L00?o0000olW;foo9bm/01?o9bm/00ol0003obL_Ko`000005olG1eP03o`000?o4`MOo
a<7G00Coa<7G00?o0000ol30f_l000001Onj^=P2o`0000Co];OK00?o0000ojbag?n//M`00_l00006
ojFah0?o00001OnC[>P5o`000003ognZkol0003oMZcd00;oMZcd2Ol00004ogBhn`03o`000?mn_oco
000000CoR/Wm00?o0000oiKBoOnFd_d00onFd_d7o`0000;oZMkj00Go0000ok7Qn?nahOSo/N7ho`00
0003okKRm@05o`000?nih??o^N3cokWPlol000001?njg?401?l0003o^MO_okWGkol00003okKAk@03
o`000?ncb^_o/l[[00;o/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP03
o`000?nV]^CoY[KT00Co00000_nL[nD00ol0003oV:_ToiR[i003oiR[i005o`000?nDZ>?oU:SSoiBX
hol000001?nCZ>@00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool001Oooooo00?o0000ooooooooool04_ooool3o`0002cooooo00Go0000oh:XkOn2
Z>goPZS]o`000003ohBYk@03o`000?n9[>goRJc]00;oRJc]00Go0000oi:ak?nB/NcoT[7/o`000003
oi^gj`03o`000?nU_N[oYKgZ00;oYKgZ00Go0000ojo2j?n_`^So[l;Xo`000005okS7iP?o000000?o
_lOQo`000?o4bMh01Oo4bMh00ol0003ob<[LolS:g003olS:g003o`000?o9bm_obL_K00?obL_K0_l0
0007olG1eP;o00001Oo4`ML00ol0003o^[SHokZhf006okZhf0;o000000?o];OKo`000?n//M`01?n/
/M`2o`0000CoYK7P00?o0000oib^i?nL[^@01?l000000onC[>So0000ohV]k@03ohV]k@Oo000000?o
MZcdo`000?mb/OP01?mb/OP00ol0003oM;SkogBhn`05o`0000;oR/Wm00?o0000oiKBoOnFd_d00_nF
d_d2o`0000?oXMWk00?o0000ojWNn_nYg_X00_nYg_X01Ol0003o/N7hok7Qn?nahOSo000000?o]^;e
00Go0000okWPlonih??o^N3co`000004ok[Ll@04o`000?nienoo^MO_o`0000?o]]7]00?o0000ok?:
joncb^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000ojJf
i?nV]^@00_nV]^@00ol0003oX[7Soj:ah`03o`0000CoV:_T00?o0000oiBXhonDZ><00_nDZ><00ol0
003oTjSToi>Xi002oi>Xi003o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`07ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000;oooool01Ol0003o
PZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/kOn9[>d00_n9[>d01Ol0003oT[7/oi:ak?nB/Nco
000000?oVkO[00?o0000ojFmj_nU_NX00_nU_NX00ol0003o[l;Xojo2j002ojo2j003o`000?nhanKo
^<OV00?o00001?noan400ol0003oa<WNolC9gP04olC9gP03o`000?o8b]cob<[L00?ob<[L00Go0000
olW;foo9bm_obL_Ko`000003olG2eP03o`000?o5`MKoaL7F00GoaL7F00Go0000olC1eoo4`MOoa<7G
o`000002okfhe@;o00001onj^=P00ol0003o[;7Lojbag006ojbag0;o000000?oYK7Po`000?nL[^@0
1_nL[^@4o`0000CoRJg]00?o0000oh2`lon0/?<00_n0/?<:o`0000GoO/3l1?l00002oiKBo@03o`00
0?nQfO_oXMWk00;oXMWk00?o0000ojWNn_nYg_X00_nYg_X01Ol0003o/N7hok7Qn?nahOSo000000?o
]^;e00Go0000okWPlonih??o^N3co`000004ok[Ll@04o`000?nienoo^MO_o`0000?o]]7]00?o0000
ok?:joncb^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000
ojJfi?nV]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;o000000;o000000?oV:_T
o`000?nDZ><00_nDZ><00ol0003oTjSToi>Xi002oi>Xi003o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2o`0000gooooo0ol0000coooo
o`Oo000000?oQ:W]o`000?n9[>d00on9[>d01?l0003oT[7/oi:ak?l00004oi^gj`03o`000?nU_N[o
YKgZ00;oYKgZ00?o0000ojo2j?l000001?l00002okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000
olC9g_o4bMh01?o4bMh00ol0003ob<[LolS:g003olS:g003o`000?o9bm_o000000GoaL;F00?o0000
olG1e_o5`MH01Oo5`MH00ol0003oa<7Go`000005okfhe@;o00001Onj^=P00ol0003o/K;Io`000002
o`0000Ko[;7L00?o0000oib^i?nL[^@01onL[^@00ol0003oTZo[oi:_j`04o`000003ohV]kOl0003o
P;3c00GoP;3c00?o0000og^gnOmk]oT01?mk]oT00ol0003oO/3lo`000002o`0000CoR<Sm1?l00002
oj7In`03o`000?nYg_[oZMkj00;oZMkj00Go0000ok7Qn?nahOSo/N7ho`000003okKRm@05o`000?ni
h??o^N3cokWPlol000001?njg?401Ol0003o^MO_okWGkonienoo000000;o]]7]00?o0000ok?:jonc
b^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000ojJfi?nV
]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;oWjgR00?oWjgR0ol00002oiBXh`03
o`000?nCZ>CoTjST00;oTjST00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000fooooo`05o`00
0?mhZo?oN:_cogR[lol000000_mj[?<9o`000003oi:ak?l0003oVkO[00Wo00000_n_`^P00ol0003o
^<GTokS5i003okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000olC9g_o4bMh00oo4bMh00ol0003o
b<[LolS:g003olS:g0;o00001oo5`]H00ol0003oaL7FolG1eP05olG1eP03o`000?nm^=Go_KSE00Ko
_KSE00Go0000okZhf?nj^=So^[SHo`000005ok6bf@;o00001?n//M`01?l0003oXjoPoj>_h?nS[n05
o`000003oib^i?l0003oTZo[00GoTZo[4ol00002ohS8o@?o00001?nBcod4o`0000;oZMkj00Go0000
ok7Qn?nahOSo/N7ho`000003okKRm@05o`000?nih??o^N3cokWPlol000001?njg?401Ol0003o^MO_
okWGkonienoo000000?o]]7]00Go0000ok?:joncb^_o/l[[o`000004ojo3j@03o`000?nZ_>KoZ[cV
00;oZ[cV00?o0000ojJfi?nV]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;oWjgR
00CoWjgR00?o0000oif[hOnMZn400ol00003oi>Xi003o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`06ooooo`?o
0000>_ooool01Ol0003oN:_cogR[lomhZo?o000000;oNZcc00?o0000oh:`l_n2/?800_n2/?800ol0
003oS;Caohbdl@03o`0000;oV;[_00?o0000ojBnk?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2
j003o`000?nhaNCo^<GT00?o^<GT00?o0000oko7hOnoan400onoan400ol0003oa<WNolC9gP03olC9
gP05o`000?o8b]cob<[LolS:g?l000000oo4`]P00ol0003oaL;FolG2eP04olG2eP03o`000?o5`MKo
aL7F00?oaL7F00?o0000oknie?no^M@00_l00006okfhe@;o000000?o^[SHo`000?na/]T01_na/]T4
o`0000WoXjoP1?l00005oi:_j`03o`000?n8]?;oR;Cb00GoR;Cb00?o0000ohBmnOn4_OT01On4_OT4
o`0000CoT/om0ol00004oi_Do0So000000?o]^;eo`000?nih?<00_nih?<00ol0003o^]caok[Ll@02
ok[Ll@05o`000?nienoo^MO_okWGkol000000onfdNd00ol0003o/l[[ok?:j`02ok?:j`03o`000?n_
`nWo[l?Y00;o[l?Y00Go0000ojZli_nZ_>KoZ[cVo`000004ojJfi003o`000?nR/N?oX[7S00;oX[7S
00?o0000oin]h_nO[N801?nO[N800ol0003oWJ_Qoif[h@02oif[h@06o`000?nKZn7o0000o`000?nC
Z>Co00002oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03
o`000?oooooooooo00?ooooo0ol0000nooooo`05o`000?mhZo?oN:_cogR[lol000000_mj[?<00ol0
003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o0000ojBnk?nT_^`00_nT_^`0
0ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00?o0000oko7hOnoan400_noan40
0ol0003oa<WNolC9gP04olC9gP03o`000?o8b]co000000Goa<;H00?o0000olG2e_o5`]H01?o5`]H0
1Ol0003oaL7FolG1e_o5`MKo000000Go_kWD0_l00006okfhe@03o`000?na/]Wo/K;I00Wo/K;I00?o
0000oj>_h?nS[n002?nS[n000ol0003oVK7XoiVaj005o`000003oi:_jol0003oR;Cb00KoR;Cb00?o
0000ohBmnOn4_OT01?l00004ohg2n@04o`000?nBcogo0000o`0000GoVmCl0_l00002oj?HnP;o0000
0onYfOP8o`0000;o^]ca00Go0000okWGkonienoo^MO_o`000003okKAk@03o`000?ncb^_o/l[[00;o
/l[[00?o0000ojo3jOn_`nT00_n_`nT01Ol0003oZ[cVojZli_nZ_>Ko000000CoY[KT00?o0000oj:a
honR/N<00_nR/N<00ol0003oWjgRoin]hP04oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[
hOnKZn400_nKZn400ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01_ooool001Kooooo00Co0000oooooooooooooooo0ol00012ooooo`05o`000?mhZo?oN:_c
ogR[lol000000_mj[?<00ol0003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o
0000ojBnk?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00?o
0000oko7hOnoan400_noan400ol0003oa<WNolC9gP03olC9gP;o00001oo4`]P2o`0000GoaL;F00?o
0000olG1e_l000002?no^M@2o`0000Co_KSE00?o0000okFceone/mL01?l00005ok6bf@04o`000?nX
/=goZ;3MojR`g@Go00000_nS[n000ol0003oVK7XoiVaj005oiVaj0co00001on=`_T4o`0000CoVmCl
0_l00002oj?HnP;o00000onYfOP2o`0000?o[MSf00?o0000ok3Flon`e_<00_n`e_<8o`000003okKA
kOl0003o/l[[00?o/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP05o`00
0?nV]^CoY[KTojJfi?l000001?nR/N<00ol0003oWjgRoin]hP04oin]hP03o`000?nMZn7oWJ_Q00;o
WJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`05o`000?mhZo?oN:_cogR[lol0
00000_mj[?<00ol0003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o0000ojBn
k?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00;o^<GT00?o0000oko7
hOnoan400onoan401Ol0003oa<WNolC9g_o4bMko000000?o`/;J00?o0000olC2f?o4`]P01Oo4`]P0
0ol0003oaL;FolG2eP03olG2eP03o`000?no^MCo_kWD00Wo_kWD0_l000000onm^=Go0000okFce`06
okFce`?o000000?o/K;Io`000?nX/=d02?nX/=d8o`0000?oVK7X00?o0000oi6hlOnA^?401onA^?40
0ol0003oSL;iohg2n@05o`0000CoULOh00Co0000oi_Do?l0003o00000onSf?X01?l0003oZMWhojWI
n?nYfOP2o`0000?o[MSf0_l00004ok3Fl`05o`000?nad_7o/M;aok7BlOl000000onacNh4o`0000;o
/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP03o`000?nV]^CoY[KT00;o
Y[KT00Go0000oj:ahonR/N?oX[7So`000006oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[
hOnKZn400onKZn400ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01_ooool001Kooooo0_l00019ooooo`04o`000?mhZo?oN:_co`0000?oNZcc00?o0000oh:`
l_n2/?800_n2/?801?l0003oS;CaohbdlOl00003oiRjk`03o`000?nT_^coY;k/00;oY;k/00?o0000
ojo2j?n_`^P00on_`^P00ol0003o^<GTokS5i002okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000
olC9g_l000001Oo2`]X00ol0003oa<;HolC2f005olC2f005o`000?o5`]KoaL;FolG2e_l000000_no
^]D3o`0000Wo_kWD00?o0000okFceone/mL02One/mL2o`0000_oZ;3M00?o0000oinbi_nO/^H00onO
/^H@o`0000SoULOh1Ol000000onSf?[o0000o`000003ojWIn003o`000?n]f?Ko[MSf00;o[MSf00?o
0000ok3Flon`e_<00_n`e_<2o`0000?o/M;a00Go0000ok7=k_nacNko/Lg^o`000004ok38j`Co0000
0_n_`nT00ol0003oZ[cVojZliP02ojZliP03o`000?nV]^CoY[KT00;oY[KT00?o0000oj:ahonR/N<0
0_nR/N<00ol0003oWjgRoin]hP03oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[hOnKZn40
0onKZn400ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool000cooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00Co
0000ogR[lomhZo?o00000omj[?<01Ol0003oP[3boh:`l_n2/?;o000000?oS;Ca00Go0000oiRjkonH
^^ooV;[_o`000004ojBnk003o`000?n_`^So[l;X00;o[l;X00?o0000okS5i?nhaN@00onhaN@00ol0
003o_lOQoko7h@02oko7h@;o00001oo2`]X00ol0003oa<;HolC2f005olC2f003o`000?o5`]Ko0000
00Ko_k[E0_l00007oknie003o`000?ng]=Ko]kCF00?o00001one/mL00ol0003o[;7Lojbag004o`00
00GoZ;3M00?o0000oinbi_nO/^H01onO/^H00ol0003oV;[`oiRjl008oiRjl004o`000?nEaoSoULOh
oiG7n0Go00000onLbOL5o`000003ojWIn?l0003o000000Co[MSf00Co0000ok3Flon`e_?o/=Kc0_l0
0003ok7Bl@;o00000onacNh00ol0003o/<S[ok38j`02ok38j`03o`000?n^`^Wo[/;Y00;o[/;Y0ol0
0003ojZliP03o`000?nV]^CoY[KT00;oY[KT00?o0000oj:ahonR/N<00_nR/N<00ol0003oWjgRoin]
hP03oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool000kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`17ooooo`04o`000?mhZo?oN:_co`0000?oNZcc00Go
0000oh:`l_n2/?;oP[3bo`000003ohbdl@05o`000?nH^^ooV;[_oiRjkol000001?nT_^`00ol0003o
[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00Co0000oko7hOl0003o00000onm`mh7ol;2
fP;o00001_o4`]P00ol0003o_k[Eoknje@07oknje@;o00001?no^M@00ol0003o]kCFokNdeP04okNd
eP?o00001?ne/mL00ol0003o[;7Lojbag004ojbag0?o000000?oZ;3Mo`000?nO/^H02_nO/^H00ol0
003oV;[`oiRjl003oiRjl0So00001?nLbOL4o`0000CoX/_e0ol00003ojgHmP;o00000on`e_<00ol0
003o/M;aok7Bl@02ok7Bl@04o`000?nacNko/Lg^ok7=kP;o00001?n`b>/00ol0003o[/;Yojk2j@02
ojk2j@07o`000?n/_NKo[;gVojbmi_l0003oZ[cVo`000004ojJfi003o`000?nR/N?oX[7S00;oX[7S
00?o0000oin]h_nO[N800onO[N800ol0003oWJ_Qoif[h@02oif[h@03o`000?nKZn7oVj_Q00?oVj_Q
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
000>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool01Ol0003oN:_cogR[
lomhZo?o000000;oNZcc00?o0000oh:`l_n2/?800_n2/?801?l0003oS;CaohbdlOl00004oiRjk`03
o`000?nT_^coY;k/00;oY;k/00?o0000ojo2j?n_`^P00_n_`^P00ol0003o^<GTokS5i002okS5i0;o
00001_nm`mh00ol0003o`/;Jol;2fP05ol;2fP03o`000?o4`]Soa<;H00?oa<;H00Co0000oknke_l0
003o00002?no^]D3o`000003oknie?l0003o]kCF00So]kCF1?l0000:ojbag1?o00001_nN_Nh00ol0
003oW<Wgoic9m`03o`0000GoX/_e0ol00003ojO<l`03o`000?n]f?Ko000000?o/=Kc0_l00004ok7B
l@05o`000?nacNko/Lg^ok7=k_l000001?n`b>/2o`0000Co[/;Y00?o0000ojbmi_n/_NH00_n/_NH4
o`0000;oY[KT00?o0000oj:ahonR/N<00_nR/N<00ol0003oWjgRoin]hP03oin]hP03o`000?nMZn7o
WJ_Q00;oWJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`00
04Oooooo00Go0000ogR[lomhZo?oN:_co`000002ogZ/l`03o`000?n2/?;oP[3b00;oP[3b00Co0000
ohbdlOn<]?7o00001?nH^^l01Ol0003oY;k/ojBnk?nT_^co000000Go[l;X00Co0000okS5i?l0003o
00000ong`n<6okg3gP;o00001_o2`]X01Ol0003oa<;HolC2f?o4`]So000000Co_k_F0_l00009oknj
e@03o`000?ng]=Ko]kCF00_o]kCF00?o0000ojbag?n//M`02On//M`00ol0003oY;CTojBdi009ojBd
i003o`000?nN_NkoW[g^00OoW[g^1Ol00006oj;;m@;o00001_nWc?<4o`000003ok3Flol0003o/M;a
00?o/M;a0_l00003ok7=kP03o`000?n`b>_o/<S[00;o/<S[00?o0000ojk2jOn^`^T00_n^`^T2o`00
00Co[;gV00?o0000ojZii?nZ^N@00_nZ^N@3o`0000?oX[7S00?o0000oin]h_nO[N800onO[N800ol0
003oWJ_Qoif[h@03oif[h@03o`000?nKZn7oVj_Q00;oVj_Q00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool01?l0003oN:_cogR[lol00003ogZ/l`05o`000?n2/?;oP[3b
oh:`l_l000000on<]?401Ol0003oV;[_oiRjkonH^^oo000000CoY;k/00?o0000ojo2j?n_`^P00_n_
`^P2o`0000Ko]l?S00?o0000okg3g_nm`mh01?nm`mh00ol0003o`/;Jol;2fP04ol;2fP03o`000?o4
`]So000000Oo_k_F0_l00007oknje@03o`000?ni]MKo^KGF00?o00002?ng]=H01?l0003o[k;Kojnb
fon_/]/6o`0000;o[;7L00?o0000ojBdi?nT]>@02_nT]>@00ol0003oW[g^oijmkP06o`0000?oXkk]
00?o0000oj;;mOnRboD00onRboD2o`0000GoYlcc0ol00003oj_;l@?o00000onad_401?l0003o/Lg^
ok7=k_nacNh2o`0000Co/<S[00?o0000ojk2jOn^`^T00_n^`^T00ol0003o[;gVojbmiP02ojbmiP;o
00001?nZ^N@01ol0003oYkGSojNehonW]N?o0000oj:ahol000001OnO[N800ol0003oWJ_Qoif[h@03
oif[h@03o`000?nKZn7oVj_Q00;oVj_Q00?o0000ooooooooool05oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0AOooool01?l0003oN:_cogR[lol00003ogZ/l`05o`000?n2/?;oP[3boh:`l_l000000on<
]?401Ol0003oV;[_oiRjkonH^^oo000000CoY;k/00Co0000ojo2j?l0003o00000on_`^P6okO3h`;o
00001Onm`mh2o`0000Go`/;J00?o0000oknke_no^mH02?no^mH2o`0000Co_k[E00?o0000okVee_ni
]MH01?ni]MH3o`0000Co]kCF00?o0000ojnbfon_/]/02?n_/]/Bo`0000[oXkk]00?o0000oj;;mOl0
00000_l00004ojO<l`?o00000on[bo43o`0000?o[L[_00?o0000ok7BlOl000000onacNh00ol0003o
/<S[ok38j`03ok38j`04o`000?n^`^Wo[/;Yojk2j@;o00001?n/_NH00ol0003oZ[WTojZii002ojZi
i0;o00001?nW]N<3o`0000CoWjgR00?o0000oif[hOnMZn400onMZn400ol0003oVj_Qoi^[h@02oi^[
h@03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05oooo
o`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00Co0000ogR[lomh
Zo?o00000omj[?<01Ol0003oP[3boh:`l_n2/?;o000000?oS;Ca00Go0000oiRjkonH^^ooV;[_o`00
0002ojBnk0?o00001_n_`^P00ol0003o]l?SokO3h`04okO3h`03o`000?nm`mko_L?N00Co_L?N00Go
0000ol;2f_o2`][o`/;Jo`000002okfmf@?o00002?no^mH2o`000003oknjeOl0003o^KGF00Wo^KGF
0ol000000ong]=Ko0000ojnbf`0;ojnbf`03o`000?nX]^?oZ;KS00[oZ;KS00?o0000oj>nkOnS_^d0
2?nS_^d4o`0000GoYlcc0_l00004oj_;l@;o00001_n]b^l4o`000003ok7=k_l0003o/<S[00?o/<S[
0_l00003ojk2j@03o`000?n/_NKo[;gV00;o[;gV0_l00004ojZii003o`000?nW]N?oYkGS00?oYkGS
00Co0000ojFbh_nU/^;oYK;R0_l000000onO[N;o0000oif[h@04oif[h@03o`000?nKZn7oVj_Q00;o
Vj_Q00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Go
oooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00016ooooo`04o`000?mhZo?oN:_co`0000?o
NZcc00Go0000oh:`l_n2/?;oP[3bo`000002ohbdl@Oo00001?nT`Nd7ojo2j003o`000?ng`n?o]l?S
00?o]l?S00?o0000okg3g_nm`mh01?nm`mh00ol0003o`/;Jo`000006okfmf@?o00001ono^mH00ol0
003o^KGFokVeeP0<okVeeP04o`000?n_/]_o[k;Kojnbf`Co00001_n_/]/00ol0003oZ;KSojRfh`0;
ojRfh`03o`000?nS_^goXkk]00Oo00001?nW`>/00ol0003oYlcco`000002o`0000CoZl_a0_l00005
ojg:k`?o00000on^an`3o`0000?o/<S[00?o0000ojk2jOn^`^T00_n^`^T00ol0003o[;gVojbmiP02
ojbmiP03o`000?nZ^NCoZ[WT00;oZ[WT0_l00004ojNeh`;o00001OnU/^83o`0000CoWJ_Q00?o0000
oi^[hOnKZn400_nKZn400ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01?ooool002;ooooo00?o0000ooooooooool0A?ooool=o`0000?oR[[f1?nH__85ojC1
k@;o00001On_`^P2o`0000Co]l?S0_l00005okg3gP03o`000?nm_MWo_KgI00So_KgI0_l00005oknk
eP03o`000?ni]mSo^KOH00Go00001oni]MH00ol0003o/KCKok6df`05ok6dfaOo00002_nW`>/3o`00
00CoZl_a0ol00005ojg:k`;o00001?n^an`2o`0000?o[lGZ00?o0000ok38jol000000on^`^T2o`00
00?o[;gV0_l00004ojZii003o`000?nW]N?oYkGS00?oYkGS00?o0000ojFbh_nU/^801?nU/^801?l0
003oY;7RojBah_nT/N82o`000003oif[hOl0003oVj_Q00?oVj_Q00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Sooooo`03o`000?oooooooooo
04Gooooo0omc/_P4ogJcn0CoO[Kh1?n:^_H01Ol0003oV;kboiRnl_nH__;o000000GoY<7]00?o0000
ojo2j?n_`^P01?n_`^P00ol0003o]l?SokO3h`03okO3h`05o`000?nm`mko_L?Nokg3g_l000000_nj
_]d3o`0000So_KgI0ol000000ono^mKo0000okVgf007okVgf0Go000000?o^KGFo`000?na]=/03Ona
]=/00ol0003oZkSRoj^hhP0;oj^hhP03o`000?nW`>_oYl3[00GoYl3[1Ol00003oj[1jP04o`000?n[
bo7o0000o`0000Go[L[_0ol00003ojk7k0?o00001On_aNX2o`0000?o[/;Y00?o0000ojbmi_n/_NH0
0_n/_NH00ol0003oZ[WTojZii003ojZii003o`000?nW]N?oYkGS00;oYkGS0_l00005ojFbhP;o0000
1OnT/N83o`0000?oVj_Q00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo000Tooooo`;o0000A_ooool01?l0003oLk;hog>bn?l00003ogJcn005o`00
0?mn]_SoO[Khogjfn?l000000on:^_H2o`0000?oV;kb00?o0000ojC1kOnT`Nd00_nT`Nd2o`0000Go
[l;X00?o0000okO3hong`n<00ong`n<00ol0003o_L?No`000006okZng@;o00002Onm_MT00ol0003o
^KOHokVgf00<okVgf0;o00000ona]=/00ol0003o/KCKok6df`08ok6df`03o`000?n[^>;oZkSR00co
ZkSR00?o0000ojO0jol000001?l00007oj[1jP?o00001On]b^l2o`0000Co[/O/0_l00005ojo5jP?o
00000_n^`^P00ol0003o[/;Yo`000003ojbmiP;o00001?nZ^N@2o`0000CoYkGS00?o0000ojFbh_nU
/^801?nU/^800ol0003oY;7RojBahP04ojBahP07o`000?nR/>;oX[3Roj:`h_l0003oVj_Qo`00000T
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002Kooooo00?o0000oooo
ooooool0AOooool3og>bn004o`000?mf/oSoM[?hogJcn0?oO[Kh0_l00003ohZjmP05o`000?nH__;o
V;kboiRnl_l000001OnT`Nd00ol0003o[l;Xojo2j003ojo2j0;o00000ong`n<2o`0000Wo^[kM0_l0
0007okfmf@03o`000?nh^M[o^;WJ00Co00002Oni]mP00ol0003o/kKLok>fg002ok>fg0Oo00000ona
]=/00ol0003oZkSRoj^hhP05oj^hhPWo00002?nZ`NX4o`0000?o[<7Y00?o0000ojg:kol000000_l0
0004ojk7k0;o00001On_aNX2o`0000Go[/;X1?l000000on/_NKo0000ojZii004ojZii003o`000?nW
]N?oYkGS00?oYkGS00?o0000ojFbh_nU/^800onU/^82o`0000GoY;7R0_l00004oj:`hP;o00009_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo000Wooooo`03o`000?oooooo
oooo04Gooooo00?o0000og>bn?mc/_P00_l00002ogJcn005o`000?mn]_SoO[Khogjfn?l000000on:
^_H2o`0000;oV;kb0_l00004ojC1k@03o`000?n_`^So[l;X00Co[l;X00?o0000okO3hol000000onf
`>82o`0000So^[kM0ol00003okfmf@03o`000?nh^M[o^;WJ00Go^;WJ0ol00006okVgf003o`000?nc
]]co/kKL00Wo/kKL2ol00007ojfihP03o`000?nZ`N[oZ/7Z00CoZ/7Z0ol00006ojc1j@?o00001?n^
an`3o`0000Co[lGZ0ol00005ojk2j0;o00000on]_nL3o`0000?oZ[WT0_l00004ojNeh`;o00001?nU
/^82o`0000GoY;7R0_l00004oj:`hP;o0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo000Xooooo`03o`000?oooooooooo04Kooooo00Co0000og>bn?mc/_So00000omf
/oP00ol0003oO[Khogjfn002o`0000?oR[[f00Go0000oiRnl_nH__;oV;kbo`000004ojC1k@;o0000
1?n_`^P2o`0000Oo]/3R0_l00008okZng@;o000000?o_KgIo`000?nh^MX02Onh^MX4o`000003okVg
f?l0003o/kKL00ko/kKL00?o0000ojfih_n]^N803On]^N800ol0003oZ/7Zo`000003o`0000Go[<7Y
1?l00003ojk2j@04o`000?n^anco0000o`0000Go[lGZ0_l00006ojk2j0;o00000on]_nL2o`0000?o
[;gV00?o0000ojZii?l000001OnW]N<00ol0003oYK;RojFbhP03ojFbhP03o`000?nT/N;oY;7R00Co
Y;7R00?o0000oj:`h_nR/>800onR/>800ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool002Wooooo0_l00017ooooo`;o000000?oLk;ho`000?l00000
0omf/oP01?l0003oO[Khogjfn?l00003ohZjmP04o`000?nH__;oV;kboiRnlP;o00001?nT`Nd01?l0
003o[l;Xo`000?l00003ojo2j003o`000?nf`>;o]/3R00Go]/3R0ol00007okZng@03o`000?nh^M[o
^;WJ00go^;WJ0_l00003ok>fg0Go00001onc]]`00ol0003o[KWRojfihP05ojfihP[o00001On/`NT4
o`0000Ko[/;Y0ol00005ojo5jP;o00001_n^`^P2o`0000?o[KoW0_l00005ojbmiP?o00000onW]N<2
o`0000CoYK;R0_l00005ojBahP;o00001?nR/>82o`0002gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`00:oooool00ol0003oooooooooo`16ooooo`04o`000?mc/_SoLk;h
o`0000?oM[?h00Co0000ogjfn?mn]_So00000on:^_H2o`0000?oV;kb00Co0000ojC1kOnT`NgoY<7]
0_l00008ojo2j0;o00001_nf`>82o`0000Go^[kM00Co0000okNlg_ng_=ko]kcN1Ol00008okRifP03
o`000?nc^Mgo/kWM00Ko/kWM3ol00008ojnkh`03o`000?n/`NWo[<7Y00Co00001on^`^T3o`0000?o
[/;X00?o0000ojo5j_l000000_l00005ojk2j0?o00000on]_nL2o`0000Go[;gV0_l00003oj^ki@03
o`000?nW]N?o000000GoYK;R00?o0000ojBah_nT/N800onT/N82o`0000CoX[3R0_l0000_ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0
A_ooool2o`000003og>bn?l0003o000000?oM[?h00Co0000ogjfn?l0003o00000on:^_H01ol0003o
V;kboiRnl_nH__;o0000ojC1kOl000000onV`nh00ol0003o[l;Xojo2j006ojo2j0?o00001Onf`>83
o`000003okZngOl0003o]kcN00So]kcN1Ol00002okRifP03o`000?nc^Mgo/kWM00ko/kWM00?o0000
ojnkhon_^n<02_n_^n<6o`0000Oo[/;Y1?l00005ojk2j0?o00001_n^`^P2o`0000Co[KoW0_l00005
ojbmiP;o00001On[^nD3o`0000?oYK;R0_l00005ojBahP03o`000?nR/>;oX[3R00;oX[3R0_l0000b
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002gooooo00?o0000oooo
ooooool0Aoooool01?l0003oLk;hog>bn?l00003ogJcn0;o000000?oO[Kho`000?n:^_H00_n:^_H0
0ol0003oV;kboiRnlP02o`0000OoY/?^0_l00007ojo2j0;o00001_nf`>800ol0003o]kcNokNlgP0=
okNlgP?o00000onc^Md6o`0000Oo/kWM00Co0000ojnkhon_^n?o[k_S2Ol00004ojnmi003o`000?n^
`^Wo[/;Y00?o[/;Y0ol00006ojk2j0?o00000_n^`^P00ol0003o[/;Xojk2j002ojk2j0;o00001?n]
_nL2o`0000Go[;gV0_l00005oj^ki@;o00000onY^ND00ol0003oYK;Ro`000005ojBahP;o00001?nR
/>800ol0003oooooooooo`0cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool002kooooo0_l00018ooooo`;o000000?oLk;ho`000?l000000omf/oP00ol0003oO[Kho`000002
ohZjmP?o00000onK`o@00ol0003oY/?^ojK3kP05ojK3kP?o00001_n_`^P3o`000003okK0h_l0003o
/koS00Co/koS1_l00008okNlgP03o`000?nb_>3o/[cP00Oo/[cP2ol0000>ojnmi003o`000?n^`^Wo
000000;o00001On^`^P4o`0000Ko[/;X00Co0000ojk2j?l0003o00001?n]_nL2o`0000Co[;gV0ol0
0004oj^ki@?o00001OnY^ND3o`0000?oY;7R0_l00004oj:`hP;o0000=oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo00Co0000
og>bn?mc/_So00000_mf/oP5o`0000?oS/7h00?o0000oi_3m?nK`o@00onK`o@2o`0000KoY/?^0_l0
0007ojo2j003o`000?nc_n?o/koS00[o/koS1Ol00002okNlgP03o`000?nb_>3o/[cP00oo/[cP00?o
0000ojnmi?n__N@02on__N@6o`0000Co[/;X1?l00009ojk2j0?o00001?n]_nL2o`0000Co[;gV0_l0
0005oj^ki@;o00001OnY^ND3o`0000?oZ;SU00?o0000ojBah_l000001?nR/>82o`0003Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`17
ooooo`Go00000omk_O/2oh>onP03o`000?n>`OSoS/7h00?oS/7h00?o0000oi_3m?nK`o@00_nK`o@3
o`0000GoY/?^0_l00005ojo2j003o`000?n_`^So[l;X00Go00002_nc_n<3o`0000Co/[cP1Ol00008
ok:lh003o`000?n__NCo[kgT00;o[kgT2Ol00004ojo0iP03o`000?n^`^So[/;X00?o00002On^`^P4
o`0000?o[/;Y00Co0000ojfoiol0003o00001?n/_NH2o`0000GoZk_U0_l00005ojVii@;o00001_nX
^>D2o`0000CoX[3R00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00?ooooo000booooo`03o`000?oooooooooo04Sooooo0omh^o`5og^mn`03o`000?n3_o[o
Pkoj00;o00001?n>`OP2o`0000?oVl?d0ol00004ojK3kP?o000000?o[l;Xo`000?n_`^P01on_`^P5
o`0000Oo/koS00?o0000ok6oi?na_n@01ona_n@=o`0000_o[l3V1Ol00008ojk2j0Co00001_n^`^T3
o`0000Co[;gV0_l00005oj^ki@;o00001OnY^ND2o`0000GoZ;SU0ol00002ojNhi@04o`000?nR/>;o
0000o`0003kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<oooool2
o`0004_ooooo0omh^o`5og^mn`03o`000?n3_o[o000000;o00001?n>`OP2o`0000?oVl?d0_l00005
ojK3kP03o`000?n_`^So[l;X00co[l;X1Ol000000onc_n?o0000ok6oi00Aok6oi003o`000?n_`>Ko
[l3V00Ko[l3V1ol00003ojk2j003o`000?n^`^So[/;X00Co[/;X0ol00006ojk2j@Co00000on]`^T0
1?l0003o[;gVo`000?l00005oj^ki@;o00001?nY^ND3o`0000GoZ;SU0_l00005ojNhi@;o0000@Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooo
oooo04[ooooo00Co0000ogRko?mh^oco00001?mk_O/2o`000003oh>on_l0003o000000CoS/7h0ol0
0002oi_3m0?o000000?oY/?^o`000?nXa>h00onXa>h7o`0000Wo[l;X0_l00004ok6oi0Ko00002?na
_n@00ol0003o[l3Vojo0iP06o`0000_o[/;X00?o0000ojk2j?l000000ol00005ojk2j@Co00001_n]
`^T3o`0000CoZk_U0ol00004ojVii@;o00001OnX^>D3o`0000CoYkSU0ol00013ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0C?ooool2
ogRko0;o00000omk_O/2o`000004oh>on_l0003o0000o`0000CoS/7h0ol00002oi_3m003o`000?nX
a>koZ<C^00[oZ<C^1_l00003ojo2j003o`000?n^`^So[/;X00Wo[/;X2ol0000<ojk2j0Oo00001On^
`^T4o`0000Ko[L;Y1?l00003ojc1j@04o`000?n[^nGo0000o`0000GoZKWU0_l00005ojRhi@;o0000
1OnW^>D2o`0004Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=ooo
ool2o`0004kooooo00?o0000ogRko?mh^o`00_l00002og^mn`;o00000_n3_oX2o`0000GoS/7h00?o
0000oj36lonPa_<00onPa_<5o`0000[oZ<C^0ol0000:ojk2j003o`000?n^`^So[/;X00Oo[/;X00?o
0000ojk2j?n^`^P00_n^`^P:o`0000Go[LC[00?o0000ojk2jOn^`^T01?l00005ojg2j@Go00001_n/
`NT3o`0000CoZKWU0ol00005ojRhi@;o00001?nW^>D3o`0004[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`;o000000?oN;_l
o`000?l000000_mk_O/3o`000006oh>on_l0003o0000o`000?n>`OSo00000onGaoP2o`0000KoX<Kc
1Ol00007ojS4kP03o`000?n[aNgoZlG]00WoZlG]3_l0000;ojg4j`Oo00001On]`^T4o`0000Ko[<7Y
1Ol00003oj[1jP04o`000?nY^NGo0000o`0000GoZ;SU0ol00004ojNhi@;o0000C_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oooooooooo04oooooo
00?o0000ogRko?l000000_l00002og^mn`;o000000?oPkojo`000?l000002?nGaoP5o`0000CoX<Kc
1Ol000000onXa>ko0000oj_5k@0Doj_5k@03o`000?n]a>_o[LC[00;o[LC[2ol00005oj_5k@03o`00
0?n]`^Wo[L;Y00Co00001_n/`NT4o`0000OoZ/7Z0ol00005ojRhi@;o00001OnW^>D2o`00053ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003ooooooooo
o`1@ooooo`;o000000CoN;_lo`000?l0003oNkgk0_l00005oho6nP03o`000?nGaoSoUlOh00OoUlOh
1?l00005oj36l`;o00001On[aNdEo`0000goZlG]1_l00006ojc1j@Co00001_nZ`NX5o`0000?oZL3[
00?o0000ojRhiOl000000_l00004ojNhi@?o0000Doooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo000looooo`;o0000Doooool3o`0000CoR<Gl0_l00006oho6nPCo00001OnG
aoP4o`0000;oX<Kc00?o0000ojK7lOnVao404_nVao400ol0003oZlG]oj_5k@08oj_5k@So00001?nX
anl00ol0003o[<7Yojc1j@05o`0000GoZ/7Z1Ol00007ojW0j`?o00001OnW^>D2o`0005Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00?_ooool00ol0003oooooooooo`1C
ooooo`03o`000?n5a?co000000KoR<Gl1Ol00004oho6nPGo00000_nGaoP2o`0000GoY/Oa1_l0000:
ojK7l@04o`000?n[aNgoZlG]oj_5k@Oo00001onXanl8o`0000KoZ/7Z1?l00007ojW0j`Go00000onW
`>/00ol0003oYkSUo`000002o`0005[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`01ooooo`00?oooool00ol0003oooooooooo`1Fooooo`;o000000?oQLClo`000?l000001On8aO`4
o`0000GoSlKj0ol0000<oj79m0ko00000_nXanl<o`0000KoY/Oa00?o0000oj[1j_nZ`NX01Ol00006
ojW0j`Go00001_nW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01
ooooo`00@?ooool00ol0003oooooooooo`1Iooooo`?o000000?oQLClo`000?l000000_l00002ohS5
o0Go00000_n?a_X00ol0003oW<[goic:m`0:oic:ma3o00003OnVao48o`0000KoZL3[1Ol00006ojO0
j`Go0000H_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o
0000Foooool00ol0003oooooooooo`03o`000003ohG4o?l0003o000000?o000000?oR<Glo`000?l0
00002onLb_L00ol0003oW<[goic:m`09oic:m`03o`000?nVao7oY/Oa00?oY/Oa3Ol00006ojC7lP03
o`000?nY`>_oZL3[00Go00001_nW`>/5o`0006Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Cooooo
1?l000000on5a?co0000o`00000=oiS9nA7o00003OnTao89o`0000KoYl3[1Ol0001^ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`08ooooo`;o00001onFbOT=o`0000GoV<Wi00?o0000ojC7l_nTao800onT
ao8=o`0000KoX/Ob00Co0000ojO0jonW`>_oYl3[1Ol0001cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00Oooool004Gooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0>ooooo`Wo00001onFbOT;o`0000koX/Ob2Ol0001iooooo`03o`000?oooooooooo00Sooooo0Ol0
0001ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Gooooo`Wo00000onFbOT0
0ol0003oX/Oboj;7lP04oj;7lPgo0000Poooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00B?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo2_l0002Aoooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00
B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0
1Oooool1o`00007ooooo0Oooool004_ooooo0_l0001Aooooo`03o`000?oooooooooo0;gooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001>oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`04oooo
o`7o00000Oooool004oooooo0_l0001=ooooo`03o`000?oooooooooo0;oooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
`?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005;ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Doooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo0<7ooooo00Go0000ooooooooooooooooo`00
0001ooooo`00E?ooool2o`0004Sooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool0
0001ooooo`00E_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0<?ooooo00?o0000
ooooool000000Oooool005Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`33oooo
o`03o`000?oooooooooo007o0000001Hooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0a?ooool1o`00007ooooo0Ol0000005Wooooo0_l00013ooooo`03o`000?oooooooooo0<Gooooo
0_l0000005_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o0000001L
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0`?ooool4o`0000?ooooo001Moooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool4o`0000Oooooo001Nooooo`;o
0000?_ooool00ol0003oooooooooo`2hooooo`Co00002oooool0063ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2dooooo`Co00003oooool0067ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`2aooooo`?o00004oooool006;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2]ooooo`Co00005_ooool006?ooooo0_l0000iooooo`03o`000?oooooooooo
0:Wooooo1?l0000Jooooo`00IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Go
oooo1?l0000Nooooo`00I_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;ooooo
1?l0000Rooooo`00Ioooool2o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0002Kooooo001Y
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0V_ooool4o`0002[ooooo001Zoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0U_ooool4o`0002kooooo001[ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0T_ooool4o`0003;ooooo001/ooooo`;o0000
;oooool00ol0003oooooooooo`2>ooooo`Co0000=_ooool006kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`2:ooooo`Co0000>_ooool006oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`27ooooo`?o0000?_ooool0073ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`23ooooo`Co0000@Oooool0077ooooo0_l0000Zooooo`03o`000?oooooooooo07oo
oooo1?l00015ooooo`00Loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07_ooooo
1?l00019ooooo`00M?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0
001=ooooo`00MOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07?ooooo1?l0001A
ooooo`00M_ooool2o`0002Gooooo00?o0000ooooooooool0Koooool4o`0005Gooooo001hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Wooooo001iooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005gooooo001jooooo`;o00008Ooo
ool00ol0003oooooooooo`1Sooooo`Co0000HOooool007cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Pooooo`?o0000IOooool007gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Looooo`Co0000J?ooool007kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Hooooo`Co0000K?ooool007oooooo0_l0000Looooo`03o`000?oooooooooo05Cooooo
1?l0001`ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo053ooooo1?l0
001dooooo`00P_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l0001h
ooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001loooo
o`00Q?ooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`00083ooooo0026ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008Cooooo0027ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008Sooooo0028ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0>Oooool3o`0008cooooo0029ooooo`;o00004_ooool00ol0
003oooooooooo`0eooooo`Co0000Soooool008_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0booooo`Co0000Toooool008cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0^ooooo`Co0000Uoooool008gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Zooooo`Co0000Voooool008kooooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo1?l0002O
ooooo`00T?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Soooo
o`00TOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Wooooo`00
T_ooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:_ooooo002Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:oooooo002Eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;?ooooo002Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool3o`000;Oooooo002Gooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`Co0000^_ooool009Wooooo00Co0000oooooooooooo00002Oooool4o`000;ko
oooo002Jooooo`03o`000?oooooo000000Gooooo1?l00032ooooo`00Voooool2o`000003ooooool0
003o000000;o0000a_ooool009cooooo0_l0003:ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .64975 m .51694 .65827 L .43899 .65168 L p .689 .716 .87 r
F P
0 g
s
.51694 .65827 m .51725 .64975 L .59261 .64645 L p .669 .727 .893 r
F P
0 g
s
.59261 .64645 m .59527 .65394 L .51694 .65827 L p .669 .727 .893 r
F P
0 g
s
.59527 .65394 m .59261 .64645 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44231 .64262 L .51725 .64975 L p .689 .716 .87 r
F P
0 g
s
.51756 .64124 m .51725 .64975 L .44231 .64262 L p .685 .715 .872 r
F P
0 g
s
.51725 .64975 m .51756 .64124 L .58993 .63894 L p .664 .725 .895 r
F P
0 g
s
.58993 .63894 m .59261 .64645 L .51725 .64975 L p .664 .725 .895 r
F P
0 g
s
.44231 .64262 m .43899 .65168 L .36521 .63435 L p .711 .719 .856 r
F P
0 g
s
.59261 .64645 m .58993 .63894 L .65915 .62672 L p .65 .749 .922 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59261 .64645 L p .65 .749 .922 r
F P
0 g
s
.44231 .64262 m .44564 .6336 L .51756 .64124 L p .685 .715 .872 r
F P
0 g
s
.51788 .63289 m .51756 .64124 L .44564 .6336 L p .678 .716 .877 r
F P
0 g
s
.51756 .64124 m .51788 .63289 L .58722 .63149 L p .658 .725 .899 r
F P
0 g
s
.58722 .63149 m .58993 .63894 L .51756 .64124 L p .658 .725 .899 r
F P
0 g
s
.36521 .63435 m .37145 .62527 L .44231 .64262 L p .711 .719 .856 r
F P
0 g
s
.44564 .6336 m .44231 .64262 L .37145 .62527 L p .708 .718 .857 r
F P
0 g
s
.58993 .63894 m .58722 .63149 L .65355 .62061 L p .644 .747 .924 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58993 .63894 L p .644 .747 .924 r
F P
0 g
s
.37145 .62527 m .37772 .61628 L .44564 .6336 L p .708 .718 .857 r
F P
0 g
s
.44899 .62483 m .44564 .6336 L .37772 .61628 L p .701 .719 .864 r
F P
0 g
s
.44564 .6336 m .44899 .62483 L .51788 .63289 L p .678 .716 .877 r
F P
0 g
s
.51819 .62484 m .51788 .63289 L .44899 .62483 L p .669 .719 .886 r
F P
0 g
s
.51788 .63289 m .51819 .62484 L .58451 .62417 L p .65 .727 .905 r
F P
0 g
s
.58451 .62417 m .58722 .63149 L .51788 .63289 L p .65 .727 .905 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72983 .60915 L p .656 .786 .944 r
F P
0 g
s
.72983 .60915 m .73799 .61332 L .67023 .63881 L p .656 .786 .944 r
F P
0 g
s
.37772 .61628 m .38401 .60762 L .44899 .62483 L p .701 .719 .864 r
F P
0 g
s
.45235 .61651 m .44899 .62483 L .38401 .60762 L p .69 .723 .875 r
F P
0 g
s
.44899 .62483 m .45235 .61651 L .51819 .62484 L p .669 .719 .886 r
F P
0 g
s
.58722 .63149 m .58451 .62417 L .6479 .61445 L p .638 .745 .926 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58722 .63149 L p .638 .745 .926 r
F P
0 g
s
.37145 .62527 m .36521 .63435 L .29943 .6068 L p .733 .733 .851 r
F P
0 g
s
.51851 .6172 m .51819 .62484 L .45235 .61651 L p .657 .725 .899 r
F P
0 g
s
.51819 .62484 m .51851 .6172 L .58177 .61703 L p .642 .73 .913 r
F P
0 g
s
.58177 .61703 m .58451 .62417 L .51819 .62484 L p .642 .73 .913 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72161 .60492 L p .649 .784 .946 r
F P
0 g
s
.72161 .60492 m .72983 .60915 L .66471 .63279 L p .649 .784 .946 r
F P
0 g
s
.29943 .6068 m .30841 .59829 L .37145 .62527 L p .733 .733 .851 r
F P
0 g
s
.37772 .61628 m .37145 .62527 L .30841 .59829 L p .73 .732 .853 r
F P
0 g
s
.38401 .60762 m .39032 .59954 L .45235 .61651 L p .69 .723 .875 r
F P
0 g
s
.45572 .60881 m .45235 .61651 L .39032 .59954 L p .674 .728 .89 r
F P
0 g
s
.45235 .61651 m .45572 .60881 L .51851 .6172 L p .657 .725 .899 r
F P
0 g
s
.58451 .62417 m .58177 .61703 L .64221 .60824 L p .632 .743 .928 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58451 .62417 L p .632 .743 .928 r
F P
0 g
s
.51883 .61005 m .51851 .6172 L .45572 .60881 L p .642 .733 .914 r
F P
0 g
s
.51851 .6172 m .51883 .61005 L .57901 .61013 L p .634 .735 .921 r
F P
0 g
s
.57901 .61013 m .58177 .61703 L .51851 .6172 L p .634 .735 .921 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71332 .60054 L p .643 .779 .946 r
F P
0 g
s
.71332 .60054 m .72161 .60492 L .65915 .62672 L p .643 .779 .946 r
F P
0 g
s
.30841 .59829 m .31742 .5899 L .37772 .61628 L p .73 .732 .853 r
F P
0 g
s
.38401 .60762 m .37772 .61628 L .31742 .5899 L p .722 .733 .86 r
F P
0 g
s
.39032 .59954 m .39663 .59224 L .45572 .60881 L p .674 .728 .89 r
F P
0 g
s
.4591 .60184 m .45572 .60881 L .39663 .59224 L p .652 .735 .91 r
F P
0 g
s
.45572 .60881 m .4591 .60184 L .51883 .61005 L p .642 .733 .914 r
F P
0 g
s
.58177 .61703 m .57901 .61013 L .63648 .60198 L p .628 .742 .929 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58177 .61703 L p .628 .742 .929 r
F P
0 g
s
.31742 .5899 m .32644 .5819 L .38401 .60762 L p .722 .733 .86 r
F P
0 g
s
.39032 .59954 m .38401 .60762 L .32644 .5819 L p .709 .735 .872 r
F P
0 g
s
.51916 .60345 m .51883 .61005 L .4591 .60184 L p .624 .742 .931 r
F P
0 g
s
.51883 .61005 m .51916 .60345 L .57624 .60348 L p .625 .742 .931 r
F P
0 g
s
.57624 .60348 m .57901 .61013 L .51883 .61005 L p .625 .742 .931 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70497 .59594 L p .636 .772 .945 r
F P
0 g
s
.70497 .59594 m .71332 .60054 L .65355 .62061 L p .636 .772 .945 r
F P
0 g
s
.39663 .59224 m .40294 .58586 L .4591 .60184 L p .652 .735 .91 r
F P
0 g
s
.46249 .59566 m .4591 .60184 L .40294 .58586 L p .623 .742 .932 r
F P
0 g
s
.4591 .60184 m .46249 .59566 L .51916 .60345 L p .624 .742 .931 r
F P
0 g
s
.32644 .5819 m .33545 .57459 L .39032 .59954 L p .709 .735 .872 r
F P
0 g
s
.39663 .59224 m .39032 .59954 L .33545 .57459 L p .689 .738 .888 r
F P
0 g
s
.57901 .61013 m .57624 .60348 L .6307 .59568 L p .626 .741 .93 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57901 .61013 L p .626 .741 .93 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69655 .59106 L p .631 .762 .941 r
F P
0 g
s
.69655 .59106 m .70497 .59594 L .6479 .61445 L p .631 .762 .941 r
F P
0 g
s
.51948 .59738 m .51916 .60345 L .46249 .59566 L p .604 .752 .948 r
F P
0 g
s
.51916 .60345 m .51948 .59738 L .57345 .59708 L p .618 .749 .94 r
F P
0 g
s
.57345 .59708 m .57624 .60348 L .51916 .60345 L p .618 .749 .94 r
F P
0 g
s
.73799 .61332 m .72983 .60915 L .78416 .57634 L p .673 .822 .955 r
F P
0 g
s
.78416 .57634 m .79464 .57831 L .73799 .61332 L p .673 .822 .955 r
F P
0 g
s
.33545 .57459 m .34446 .56816 L .39663 .59224 L p .689 .738 .888 r
F P
0 g
s
.40294 .58586 m .39663 .59224 L .34446 .56816 L p .661 .74 .909 r
F P
0 g
s
.40294 .58586 m .40927 .58048 L .46249 .59566 L p .623 .742 .932 r
F P
0 g
s
.4659 .59027 m .46249 .59566 L .40927 .58048 L p .587 .748 .954 r
F P
0 g
s
.46249 .59566 m .4659 .59027 L .51948 .59738 L p .604 .752 .948 r
F P
0 g
s
.57624 .60348 m .57345 .59708 L .62488 .58932 L p .626 .741 .93 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57624 .60348 L p .626 .741 .93 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68806 .58585 L p .628 .751 .936 r
F P
0 g
s
.68806 .58585 m .69655 .59106 L .64221 .60824 L p .628 .751 .936 r
F P
0 g
s
.72983 .60915 m .72161 .60492 L .77362 .57428 L p .666 .82 .957 r
F P
0 g
s
.77362 .57428 m .78416 .57634 L .72983 .60915 L p .666 .82 .957 r
F P
0 g
s
.30841 .59829 m .29943 .6068 L .24558 .56996 L p .75 .755 .856 r
F P
0 g
s
.51981 .59181 m .51948 .59738 L .4659 .59027 L p .584 .762 .964 r
F P
0 g
s
.51948 .59738 m .51981 .59181 L .57063 .59091 L p .614 .758 .948 r
F P
0 g
s
.57063 .59091 m .57345 .59708 L .51948 .59738 L p .614 .758 .948 r
F P
0 g
s
.34446 .56816 m .35346 .56279 L .40294 .58586 L p .661 .74 .909 r
F P
0 g
s
.40927 .58048 m .40294 .58586 L .35346 .56279 L p .623 .741 .932 r
F P
0 g
s
.24558 .56996 m .25696 .56264 L .30841 .59829 L p .75 .755 .856 r
F P
0 g
s
.31742 .5899 m .30841 .59829 L .25696 .56264 L p .747 .755 .858 r
F P
0 g
s
.40927 .58048 m .41561 .57609 L .4659 .59027 L p .587 .748 .954 r
F P
0 g
s
.46933 .58562 m .4659 .59027 L .41561 .57609 L p .546 .752 .972 r
F P
0 g
s
.4659 .59027 m .46933 .58562 L .51981 .59181 L p .584 .762 .964 r
F P
0 g
s
.72161 .60492 m .71332 .60054 L .76299 .57198 L p .658 .812 .957 r
F P
0 g
s
.76299 .57198 m .77362 .57428 L .72161 .60492 L p .658 .812 .957 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67949 .58029 L p .626 .74 .929 r
F P
0 g
s
.67949 .58029 m .68806 .58585 L .63648 .60198 L p .626 .74 .929 r
F P
0 g
s
.57345 .59708 m .57063 .59091 L .61901 .58292 L p .629 .742 .929 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57345 .59708 L p .629 .742 .929 r
F P
0 g
s
.25696 .56264 m .26835 .55545 L .31742 .5899 L p .747 .755 .858 r
F P
0 g
s
.32644 .5819 m .31742 .5899 L .26835 .55545 L p .739 .755 .865 r
F P
0 g
s
.35346 .56279 m .36246 .55856 L .40927 .58048 L p .623 .741 .932 r
F P
0 g
s
.41561 .57609 m .40927 .58048 L .36246 .55856 L p .573 .738 .954 r
F P
0 g
s
.52014 .58665 m .51981 .59181 L .46933 .58562 L p .566 .773 .976 r
F P
0 g
s
.51981 .59181 m .52014 .58665 L .56779 .58493 L p .614 .767 .954 r
F P
0 g
s
.56779 .58493 m .57063 .59091 L .51981 .59181 L p .614 .767 .954 r
F P
0 g
s
.26835 .55545 m .27973 .54871 L .32644 .5819 L p .739 .755 .865 r
F P
0 g
s
.33545 .57459 m .32644 .5819 L .27973 .54871 L p .723 .754 .877 r
F P
0 g
s
.71332 .60054 m .70497 .59594 L .75228 .56929 L p .65 .799 .954 r
F P
0 g
s
.75228 .56929 m .76299 .57198 L .71332 .60054 L p .65 .799 .954 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67086 .57437 L p .626 .73 .922 r
F P
0 g
s
.67086 .57437 m .67949 .58029 L .6307 .59568 L p .626 .73 .922 r
F P
0 g
s
.41561 .57609 m .42198 .57263 L .46933 .58562 L p .546 .752 .972 r
F P
0 g
s
.47278 .58158 m .46933 .58562 L .42198 .57263 L p .504 .754 .985 r
F P
0 g
s
.46933 .58562 m .47278 .58158 L .52014 .58665 L p .566 .773 .976 r
F P
0 g
s
.57063 .59091 m .56779 .58493 L .61309 .57646 L p .635 .745 .927 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57063 .59091 L p .635 .745 .927 r
F P
0 g
s
.27973 .54871 m .29108 .54269 L .33545 .57459 L p .723 .754 .877 r
F P
0 g
s
.34446 .56816 m .33545 .57459 L .29108 .54269 L p .7 .752 .893 r
F P
0 g
s
.36246 .55856 m .37146 .55547 L .41561 .57609 L p .573 .738 .954 r
F P
0 g
s
.42198 .57263 m .41561 .57609 L .37146 .55547 L p .515 .731 .971 r
F P
0 g
s
.70497 .59594 m .69655 .59106 L .74149 .5661 L p .641 .781 .949 r
F P
0 g
s
.74149 .5661 m .75228 .56929 L .70497 .59594 L p .641 .781 .949 r
F P
0 g
s
.52047 .58177 m .52014 .58665 L .47278 .58158 L p .555 .783 .984 r
F P
0 g
s
.52014 .58665 m .52047 .58177 L .56493 .57906 L p .618 .777 .957 r
F P
0 g
s
.56493 .57906 m .56779 .58493 L .52014 .58665 L p .618 .777 .957 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66216 .56814 L p .629 .721 .913 r
F P
0 g
s
.66216 .56814 m .67086 .57437 L .62488 .58932 L p .629 .721 .913 r
F P
0 g
s
.29108 .54269 m .3024 .53762 L .34446 .56816 L p .7 .752 .893 r
F P
0 g
s
.35346 .56279 m .34446 .56816 L .3024 .53762 L p .667 .748 .911 r
F P
0 g
s
.56779 .58493 m .56493 .57906 L .60713 .56996 L p .645 .748 .924 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56779 .58493 L p .645 .748 .924 r
F P
0 g
s
.42198 .57263 m .42839 .56994 L .47278 .58158 L p .504 .754 .985 r
F P
0 g
s
.47626 .57796 m .47278 .58158 L .42839 .56994 L p .469 .755 .992 r
F P
0 g
s
.47278 .58158 m .47626 .57796 L .52047 .58177 L p .555 .783 .984 r
F P
0 g
s
.69655 .59106 m .68806 .58585 L .73059 .56232 L p .633 .761 .94 r
F P
0 g
s
.73059 .56232 m .74149 .5661 L .69655 .59106 L p .633 .761 .94 r
F P
0 g
s
.3024 .53762 m .31369 .53367 L .35346 .56279 L p .667 .748 .911 r
F P
0 g
s
.36246 .55856 m .35346 .56279 L .31369 .53367 L p .622 .74 .931 r
F P
0 g
s
.37146 .55547 m .38048 .55344 L .42198 .57263 L p .515 .731 .971 r
F P
0 g
s
.42839 .56994 m .42198 .57263 L .38048 .55344 L p .453 .719 .981 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .6534 .56162 L p .634 .715 .905 r
F P
0 g
s
.6534 .56162 m .66216 .56814 L .61901 .58292 L p .634 .715 .905 r
F P
0 g
s
.5208 .57701 m .52047 .58177 L .47626 .57796 L p .556 .794 .988 r
F P
0 g
s
.52047 .58177 m .5208 .57701 L .56204 .57323 L p .629 .787 .958 r
F P
0 g
s
.56204 .57323 m .56493 .57906 L .52047 .58177 L p .629 .787 .958 r
F P
0 g
s
.68806 .58585 m .67949 .58029 L .71961 .5579 L p .625 .739 .929 r
F P
0 g
s
.71961 .5579 m .73059 .56232 L .68806 .58585 L p .625 .739 .929 r
F P
0 g
s
.56493 .57906 m .56204 .57323 L .60112 .5634 L p .657 .752 .92 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57906 L p .657 .752 .92 r
F P
0 g
s
.31369 .53367 m .32495 .53092 L .36246 .55856 L p .622 .74 .931 r
F P
0 g
s
.37146 .55547 m .36246 .55856 L .32495 .53092 L p .566 .727 .95 r
F P
0 g
s
.79464 .57831 m .78416 .57634 L .82392 .53563 L p .704 .846 .95 r
F P
0 g
s
.82392 .53563 m .83625 .53514 L .79464 .57831 L p .704 .846 .95 r
F P
0 g
s
.42839 .56994 m .43484 .5678 L .47626 .57796 L p .469 .755 .992 r
F P
0 g
s
.47978 .57455 m .47626 .57796 L .43484 .5678 L p .452 .759 .995 r
F P
0 g
s
.47626 .57796 m .47978 .57455 L .5208 .57701 L p .556 .794 .988 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64459 .55489 L p .642 .711 .897 r
F P
0 g
s
.64459 .55489 m .6534 .56162 L .61309 .57646 L p .642 .711 .897 r
F P
0 g
s
.38048 .55344 m .38954 .55229 L .42839 .56994 L p .453 .719 .981 r
F P
0 g
s
.43484 .5678 m .42839 .56994 L .38954 .55229 L p .401 .706 .984 r
F P
0 g
s
.67949 .58029 m .67086 .57437 L .70855 .55285 L p .62 .719 .917 r
F P
0 g
s
.70855 .55285 m .71961 .5579 L .67949 .58029 L p .62 .719 .917 r
F P
0 g
s
.78416 .57634 m .77362 .57428 L .81153 .53602 L p .698 .845 .953 r
F P
0 g
s
.81153 .53602 m .82392 .53563 L .78416 .57634 L p .698 .845 .953 r
F P
0 g
s
.52114 .57219 m .5208 .57701 L .47978 .57455 L p .57 .806 .988 r
F P
0 g
s
.5208 .57701 m .52114 .57219 L .55913 .56733 L p .645 .796 .955 r
F P
0 g
s
.55913 .56733 m .56204 .57323 L .5208 .57701 L p .645 .796 .955 r
F P
0 g
s
.32495 .53092 m .33619 .52939 L .37146 .55547 L p .566 .727 .95 r
F P
0 g
s
.38048 .55344 m .37146 .55547 L .33619 .52939 L p .502 .707 .962 r
F P
0 g
s
.56204 .57323 m .55913 .56733 L .59506 .55679 L p .672 .757 .914 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56204 .57323 L p .672 .757 .914 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63572 .54803 L p .652 .71 .89 r
F P
0 g
s
.63572 .54803 m .64459 .55489 L .60713 .56996 L p .652 .71 .89 r
F P
0 g
s
.25696 .56264 m .24558 .56996 L .20758 .52532 L p .761 .782 .871 r
F P
0 g
s
.67086 .57437 m .66216 .56814 L .69741 .54721 L p .617 .701 .904 r
F P
0 g
s
.69741 .54721 m .70855 .55285 L .67086 .57437 L p .617 .701 .904 r
F P
0 g
s
.77362 .57428 m .76299 .57198 L .79906 .53607 L p .689 .836 .954 r
F P
0 g
s
.79906 .53607 m .81153 .53602 L .77362 .57428 L p .689 .836 .954 r
F P
0 g
s
.43484 .5678 m .44135 .56594 L .47978 .57455 L p .452 .759 .995 r
F P
0 g
s
.48333 .57109 m .47978 .57455 L .44135 .56594 L p .459 .769 .997 r
F P
0 g
s
.47978 .57455 m .48333 .57109 L .52114 .57219 L p .57 .806 .988 r
F P
0 g
s
.20758 .52532 m .22083 .51981 L .25696 .56264 L p .761 .782 .871 r
F P
0 g
s
.26835 .55545 m .25696 .56264 L .22083 .51981 L p .758 .782 .873 r
F P
0 g
s
.38954 .55229 m .39865 .55177 L .43484 .5678 L p .401 .706 .984 r
F P
0 g
s
.44135 .56594 m .43484 .5678 L .39865 .55177 L p .37 .7 .984 r
F P
0 g
s
.22083 .51981 m .23406 .51444 L .26835 .55545 L p .758 .782 .873 r
F P
0 g
s
.27973 .54871 m .26835 .55545 L .23406 .51444 L p .748 .78 .879 r
F P
0 g
s
.33619 .52939 m .34744 .52896 L .38048 .55344 L p .502 .707 .962 r
F P
0 g
s
.38954 .55229 m .38048 .55344 L .34744 .52896 L p .438 .684 .968 r
F P
0 g
s
.66216 .56814 m .6534 .56162 L .68621 .54107 L p .617 .687 .893 r
F P
0 g
s
.68621 .54107 m .69741 .54721 L .66216 .56814 L p .617 .687 .893 r
F P
0 g
s
.23406 .51444 m .24725 .50952 L .27973 .54871 L p .748 .78 .879 r
F P
0 g
s
.29108 .54269 m .27973 .54871 L .24725 .50952 L p .73 .776 .89 r
F P
0 g
s
.76299 .57198 m .75228 .56929 L .78649 .5356 L p .675 .819 .952 r
F P
0 g
s
.78649 .5356 m .79906 .53607 L .76299 .57198 L p .675 .819 .952 r
F P
0 g
s
.52148 .56713 m .52114 .57219 L .48333 .57109 L p .596 .817 .984 r
F P
0 g
s
.52114 .57219 m .52148 .56713 L .55618 .56128 L p .665 .802 .948 r
F P
0 g
s
.55618 .56128 m .55913 .56733 L .52114 .57219 L p .665 .802 .948 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62679 .54113 L p .665 .712 .883 r
F P
0 g
s
.62679 .54113 m .63572 .54803 L .60112 .5634 L p .665 .712 .883 r
F P
0 g
s
.55913 .56733 m .55618 .56128 L .58896 .55013 L p .688 .761 .908 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55913 .56733 L p .688 .761 .908 r
F P
0 g
s
.24725 .50952 m .26039 .50531 L .29108 .54269 L p .73 .776 .89 r
F P
0 g
s
.3024 .53762 m .29108 .54269 L .26039 .50531 L p .704 .769 .903 r
F P
0 g
s
.6534 .56162 m .64459 .55489 L .67495 .53458 L p .621 .677 .882 r
F P
0 g
s
.67495 .53458 m .68621 .54107 L .6534 .56162 L p .621 .677 .882 r
F P
0 g
s
.75228 .56929 m .74149 .5661 L .77383 .53442 L p .659 .796 .948 r
F P
0 g
s
.77383 .53442 m .78649 .5356 L .75228 .56929 L p .659 .796 .948 r
F P
0 g
s
.44135 .56594 m .44793 .56405 L .48333 .57109 L p .459 .769 .997 r
F P
0 g
s
.48692 .56732 m .48333 .57109 L .44793 .56405 L p .491 .785 .997 r
F P
0 g
s
.48333 .57109 m .48692 .56732 L .52148 .56713 L p .596 .817 .984 r
F P
0 g
s
.26039 .50531 m .27346 .50205 L .3024 .53762 L p .704 .769 .903 r
F P
0 g
s
.31369 .53367 m .3024 .53762 L .27346 .50205 L p .668 .757 .917 r
F P
0 g
s
.34744 .52896 m .35871 .52947 L .38954 .55229 L p .438 .684 .968 r
F P
0 g
s
.39865 .55177 m .38954 .55229 L .35871 .52947 L p .384 .663 .968 r
F P
0 g
s
.39865 .55177 m .40784 .55159 L .44135 .56594 L p .37 .7 .984 r
F P
0 g
s
.44793 .56405 m .44135 .56594 L .40784 .55159 L p .371 .706 .985 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61782 .5343 L p .678 .716 .877 r
F P
0 g
s
.61782 .5343 m .62679 .54113 L .59506 .55679 L p .678 .716 .877 r
F P
0 g
s
.27346 .50205 m .28648 .4999 L .31369 .53367 L p .668 .757 .917 r
F P
0 g
s
.32495 .53092 m .31369 .53367 L .28648 .4999 L p .622 .74 .931 r
F P
0 g
s
.52183 .56164 m .52148 .56713 L .48692 .56732 L p .631 .825 .975 r
F P
0 g
s
.52148 .56713 m .52183 .56164 L .55321 .55498 L p .688 .807 .939 r
F P
0 g
s
.55321 .55498 m .55618 .56128 L .52148 .56713 L p .688 .807 .939 r
F P
0 g
s
.74149 .5661 m .73059 .56232 L .76107 .53241 L p .642 .768 .94 r
F P
0 g
s
.76107 .53241 m .77383 .53442 L .74149 .5661 L p .642 .768 .94 r
F P
0 g
s
.55618 .56128 m .55321 .55498 L .5828 .54342 L p .705 .766 .9 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55618 .56128 L p .705 .766 .9 r
F P
0 g
s
.64459 .55489 m .63572 .54803 L .66364 .5279 L p .628 .672 .873 r
F P
0 g
s
.66364 .5279 m .67495 .53458 L .64459 .55489 L p .628 .672 .873 r
F P
0 g
s
.28648 .4999 m .29943 .49893 L .32495 .53092 L p .622 .74 .931 r
F P
0 g
s
.33619 .52939 m .32495 .53092 L .29943 .49893 L p .568 .716 .942 r
F P
0 g
s
.73059 .56232 m .71961 .5579 L .74821 .52952 L p .625 .739 .929 r
F P
0 g
s
.74821 .52952 m .76107 .53241 L .73059 .56232 L p .625 .739 .929 r
F P
0 g
s
.35871 .52947 m .37003 .53066 L .39865 .55177 L p .384 .663 .968 r
F P
0 g
s
.40784 .55159 m .39865 .55177 L .37003 .53066 L p .353 .65 .967 r
F P
0 g
s
.44793 .56405 m .45458 .5618 L .48692 .56732 L p .491 .785 .997 r
F P
0 g
s
.49056 .56298 m .48692 .56732 L .45458 .5618 L p .541 .803 .994 r
F P
0 g
s
.48692 .56732 m .49056 .56298 L .52183 .56164 L p .631 .825 .975 r
F P
0 g
s
.63572 .54803 m .62679 .54113 L .65231 .5212 L p .638 .672 .866 r
F P
0 g
s
.65231 .5212 m .66364 .5279 L .63572 .54803 L p .638 .672 .866 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .6088 .52761 L p .694 .722 .871 r
F P
0 g
s
.6088 .52761 m .61782 .5343 L .58896 .55013 L p .694 .722 .871 r
F P
0 g
s
.40784 .55159 m .41711 .55139 L .44793 .56405 L p .371 .706 .985 r
F P
0 g
s
.45458 .5618 m .44793 .56405 L .41711 .55139 L p .405 .724 .989 r
F P
0 g
s
.71961 .5579 m .70855 .55285 L .73527 .52574 L p .609 .711 .917 r
F P
0 g
s
.73527 .52574 m .74821 .52952 L .71961 .5579 L p .609 .711 .917 r
F P
0 g
s
.5502 .54835 m .55321 .55498 L .52183 .56164 L p .71 .808 .926 r
F P
0 g
s
.55321 .55498 m .5502 .54835 L .5766 .53665 L p .721 .77 .891 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55321 .55498 L p .721 .77 .891 r
F P
0 g
s
.29943 .49893 m .31234 .49915 L .33619 .52939 L p .568 .716 .942 r
F P
0 g
s
.34744 .52896 m .33619 .52939 L .31234 .49915 L p .511 .689 .948 r
F P
0 g
s
.52218 .55557 m .52183 .56164 L .49056 .56298 L p .667 .829 .961 r
F P
0 g
s
.52183 .56164 m .52218 .55557 L .5502 .54835 L p .71 .808 .926 r
F P
0 g
s
.62679 .54113 m .61782 .5343 L .64094 .51467 L p .651 .676 .861 r
F P
0 g
s
.64094 .51467 m .65231 .5212 L .62679 .54113 L p .651 .676 .861 r
F P
0 g
s
.70855 .55285 m .69741 .54721 L .72225 .52114 L p .597 .685 .903 r
F P
0 g
s
.72225 .52114 m .73527 .52574 L .70855 .55285 L p .597 .685 .903 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59973 .52116 L p .71 .73 .867 r
F P
0 g
s
.59973 .52116 m .6088 .52761 L .5828 .54342 L p .71 .73 .867 r
F P
0 g
s
.37003 .53066 m .38142 .53221 L .40784 .55159 L p .353 .65 .967 r
F P
0 g
s
.41711 .55139 m .40784 .55159 L .38142 .53221 L p .353 .652 .968 r
F P
0 g
s
.31234 .49915 m .32523 .50046 L .34744 .52896 L p .511 .689 .948 r
F P
0 g
s
.35871 .52947 m .34744 .52896 L .32523 .50046 L p .457 .66 .949 r
F P
0 g
s
.45458 .5618 m .46132 .55888 L .49056 .56298 L p .541 .803 .994 r
F P
0 g
s
.49425 .55785 m .49056 .56298 L .46132 .55888 L p .599 .816 .983 r
F P
0 g
s
.49056 .56298 m .49425 .55785 L .52218 .55557 L p .667 .829 .961 r
F P
0 g
s
.41711 .55139 m .42648 .55081 L .45458 .5618 L p .405 .724 .989 r
F P
0 g
s
.46132 .55888 m .45458 .5618 L .42648 .55081 L p .464 .75 .991 r
F P
0 g
s
.69741 .54721 m .68621 .54107 L .70918 .51587 L p .59 .665 .891 r
F P
0 g
s
.70918 .51587 m .72225 .52114 L .69741 .54721 L p .59 .665 .891 r
F P
0 g
s
.61782 .5343 m .6088 .52761 L .62954 .50849 L p .667 .684 .857 r
F P
0 g
s
.62954 .50849 m .64094 .51467 L .61782 .5343 L p .667 .684 .857 r
F P
0 g
s
.54717 .54132 m .5502 .54835 L .52218 .55557 L p .731 .807 .912 r
F P
0 g
s
.5502 .54835 m .54717 .54132 L .57035 .52982 L p .737 .774 .883 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .5502 .54835 L p .737 .774 .883 r
F P
0 g
s
.52253 .54878 m .52218 .55557 L .49425 .55785 L p .702 .827 .942 r
F P
0 g
s
.52218 .55557 m .52253 .54878 L .54717 .54132 L p .731 .807 .912 r
F P
0 g
s
.68621 .54107 m .67495 .53458 L .69608 .51012 L p .587 .651 .88 r
F P
0 g
s
.69608 .51012 m .70918 .51587 L .68621 .54107 L p .587 .651 .88 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59061 .515 L p .726 .739 .862 r
F P
0 g
s
.59061 .515 m .59973 .52116 L .5766 .53665 L p .726 .739 .862 r
F P
0 g
s
.32523 .50046 m .33812 .50269 L .35871 .52947 L p .457 .66 .949 r
F P
0 g
s
.37003 .53066 m .35871 .52947 L .33812 .50269 L p .415 .637 .947 r
F P
0 g
s
.6088 .52761 m .59973 .52116 L .61812 .50281 L p .684 .695 .854 r
F P
0 g
s
.61812 .50281 m .62954 .50849 L .6088 .52761 L p .684 .695 .854 r
F P
0 g
s
.38142 .53221 m .39289 .53375 L .41711 .55139 L p .353 .652 .968 r
F P
0 g
s
.42648 .55081 m .41711 .55139 L .39289 .53375 L p .384 .669 .971 r
F P
0 g
s
.83625 .53514 m .82392 .53563 L .84551 .48896 L p .737 .85 .933 r
F P
0 g
s
.84551 .48896 m .85906 .48583 L .83625 .53514 L p .737 .85 .933 r
F P
0 g
s
.67495 .53458 m .66364 .5279 L .68296 .50411 L p .59 .643 .871 r
F P
0 g
s
.68296 .50411 m .69608 .51012 L .67495 .53458 L p .59 .643 .871 r
F P
0 g
s
.46132 .55888 m .46814 .55501 L .49425 .55785 L p .599 .816 .983 r
F P
0 g
s
.49798 .55174 m .49425 .55785 L .46814 .55501 L p .653 .822 .964 r
F P
0 g
s
.49425 .55785 m .49798 .55174 L .52253 .54878 L p .702 .827 .942 r
F P
0 g
s
.42648 .55081 m .43595 .54951 L .46132 .55888 L p .464 .75 .991 r
F P
0 g
s
.46814 .55501 m .46132 .55888 L .43595 .54951 L p .536 .774 .986 r
F P
0 g
s
.66364 .5279 m .65231 .5212 L .66983 .49812 L p .598 .642 .865 r
F P
0 g
s
.66983 .49812 m .68296 .50411 L .66364 .5279 L p .598 .642 .865 r
F P
0 g
s
.5441 .53384 m .54717 .54132 L .52253 .54878 L p .749 .804 .897 r
F P
0 g
s
.54717 .54132 m .5441 .53384 L .56404 .52294 L p .752 .777 .874 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54717 .54132 L p .752 .777 .874 r
F P
0 g
s
.82392 .53563 m .81153 .53602 L .83193 .49196 L p .732 .849 .936 r
F P
0 g
s
.83193 .49196 m .84551 .48896 L .82392 .53563 L p .732 .849 .936 r
F P
0 g
s
.59973 .52116 m .59061 .515 L .60667 .49776 L p .704 .709 .852 r
F P
0 g
s
.60667 .49776 m .61812 .50281 L .59973 .52116 L p .704 .709 .852 r
F P
0 g
s
.52289 .5412 m .52253 .54878 L .49798 .55174 L p .731 .821 .921 r
F P
0 g
s
.52253 .54878 m .52289 .5412 L .5441 .53384 L p .749 .804 .897 r
F P
0 g
s
.33812 .50269 m .35104 .50559 L .37003 .53066 L p .415 .637 .947 r
F P
0 g
s
.38142 .53221 m .37003 .53066 L .35104 .50559 L p .394 .623 .944 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58144 .50918 L p .742 .748 .858 r
F P
0 g
s
.58144 .50918 m .59061 .515 L .57035 .52982 L p .742 .748 .858 r
F P
0 g
s
.65231 .5212 m .64094 .51467 L .65671 .49239 L p .612 .646 .86 r
F P
0 g
s
.65671 .49239 m .66983 .49812 L .65231 .5212 L p .612 .646 .86 r
F P
0 g
s
.81153 .53602 m .79906 .53607 L .81827 .49457 L p .721 .84 .938 r
F P
0 g
s
.81827 .49457 m .83193 .49196 L .81153 .53602 L p .721 .84 .938 r
F P
0 g
s
.39289 .53375 m .40446 .53491 L .42648 .55081 L p .384 .669 .971 r
F P
0 g
s
.43595 .54951 m .42648 .55081 L .40446 .53491 L p .441 .695 .973 r
F P
0 g
s
.64094 .51467 m .62954 .50849 L .6436 .48719 L p .63 .656 .857 r
F P
0 g
s
.6436 .48719 m .65671 .49239 L .64094 .51467 L p .63 .656 .857 r
F P
0 g
s
.20348 .47193 m .21781 .46895 L .23406 .51444 L p .756 .808 .895 r
F P
0 g
s
.23406 .51444 m .22083 .51981 L .20348 .47193 L p .756 .808 .895 r
F P
0 g
s
.24725 .50952 m .23406 .51444 L .21781 .46895 L p .745 .804 .9 r
F P
0 g
s
.18911 .47507 m .20348 .47193 L .22083 .51981 L p .759 .808 .892 r
F P
0 g
s
.22083 .51981 m .20758 .52532 L .18911 .47507 L p .759 .808 .892 r
F P
0 g
s
.21781 .46895 m .23207 .46637 L .24725 .50952 L p .745 .804 .9 r
F P
0 g
s
.26039 .50531 m .24725 .50952 L .23207 .46637 L p .726 .796 .908 r
F P
0 g
s
.46814 .55501 m .47504 .54997 L .49798 .55174 L p .653 .822 .964 r
F P
0 g
s
.50175 .54453 m .49798 .55174 L .47504 .54997 L p .699 .82 .94 r
F P
0 g
s
.49798 .55174 m .50175 .54453 L .52289 .5412 L p .731 .821 .921 r
F P
0 g
s
.59061 .515 m .58144 .50918 L .59518 .49341 L p .723 .724 .85 r
F P
0 g
s
.59518 .49341 m .60667 .49776 L .59061 .515 L p .723 .724 .85 r
F P
0 g
s
.43595 .54951 m .44553 .54715 L .46814 .55501 L p .536 .774 .986 r
F P
0 g
s
.47504 .54997 m .46814 .55501 L .44553 .54715 L p .606 .791 .97 r
F P
0 g
s
.23207 .46637 m .24624 .46445 L .26039 .50531 L p .726 .796 .908 r
F P
0 g
s
.27346 .50205 m .26039 .50531 L .24624 .46445 L p .699 .783 .916 r
F P
0 g
s
.79906 .53607 m .78649 .5356 L .80453 .49651 L p .703 .824 .94 r
F P
0 g
s
.80453 .49651 m .81827 .49457 L .79906 .53607 L p .703 .824 .94 r
F P
0 g
s
.54101 .52591 m .5441 .53384 L .52289 .5412 L p .765 .8 .882 r
F P
0 g
s
.5441 .53384 m .54101 .52591 L .55769 .51601 L p .765 .78 .865 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .5441 .53384 L p .765 .78 .865 r
F P
0 g
s
.62954 .50849 m .61812 .50281 L .63051 .48272 L p .652 .671 .856 r
F P
0 g
s
.63051 .48272 m .6436 .48719 L .62954 .50849 L p .652 .671 .856 r
F P
0 g
s
.24624 .46445 m .26033 .46339 L .27346 .50205 L p .699 .783 .916 r
F P
0 g
s
.28648 .4999 m .27346 .50205 L .26033 .46339 L p .664 .764 .924 r
F P
0 g
s
.35104 .50559 m .364 .50884 L .38142 .53221 L p .394 .623 .944 r
F P
0 g
s
.39289 .53375 m .38142 .53221 L .364 .50884 L p .397 .623 .943 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57222 .50371 L p .757 .758 .853 r
F P
0 g
s
.57222 .50371 m .58144 .50918 L .56404 .52294 L p .757 .758 .853 r
F P
0 g
s
.52325 .53278 m .52289 .5412 L .50175 .54453 L p .754 .813 .9 r
F P
0 g
s
.52289 .5412 m .52325 .53278 L .54101 .52591 L p .765 .8 .882 r
F P
0 g
s
.26033 .46339 m .27432 .46334 L .28648 .4999 L p .664 .764 .924 r
F P
0 g
s
.29943 .49893 m .28648 .4999 L .27432 .46334 L p .623 .739 .93 r
F P
0 g
s
.78649 .5356 m .77383 .53442 L .7907 .49759 L p .679 .8 .939 r
F P
0 g
s
.7907 .49759 m .80453 .49651 L .78649 .5356 L p .679 .8 .939 r
F P
0 g
s
.61812 .50281 m .60667 .49776 L .61742 .47917 L p .676 .689 .854 r
F P
0 g
s
.61742 .47917 m .63051 .48272 L .61812 .50281 L p .676 .689 .854 r
F P
0 g
s
.40446 .53491 m .41615 .53533 L .43595 .54951 L p .441 .695 .973 r
F P
0 g
s
.44553 .54715 m .43595 .54951 L .41615 .53533 L p .511 .724 .969 r
F P
0 g
s
.27432 .46334 m .28822 .46437 L .29943 .49893 L p .623 .739 .93 r
F P
0 g
s
.31234 .49915 m .29943 .49893 L .28822 .46437 L p .577 .71 .933 r
F P
0 g
s
.58144 .50918 m .57222 .50371 L .58366 .4898 L p .742 .739 .849 r
F P
0 g
s
.58366 .4898 m .59518 .49341 L .58144 .50918 L p .742 .739 .849 r
F P
0 g
s
.77383 .53442 m .76107 .53241 L .77678 .49764 L p .652 .771 .936 r
F P
0 g
s
.77678 .49764 m .7907 .49759 L .77383 .53442 L p .652 .771 .936 r
F P
0 g
s
.47504 .54997 m .48202 .5436 L .50175 .54453 L p .699 .82 .94 r
F P
0 g
s
.50556 .53617 m .50175 .54453 L .48202 .5436 L p .734 .814 .914 r
F P
0 g
s
.50175 .54453 m .50556 .53617 L .52325 .53278 L p .754 .813 .9 r
F P
0 g
s
.44553 .54715 m .45522 .54351 L .47504 .54997 L p .606 .791 .97 r
F P
0 g
s
.48202 .5436 m .47504 .54997 L .45522 .54351 L p .666 .799 .946 r
F P
0 g
s
.364 .50884 m .37704 .5121 L .39289 .53375 L p .397 .623 .943 r
F P
0 g
s
.40446 .53491 m .39289 .53375 L .37704 .5121 L p .424 .635 .944 r
F P
0 g
s
.60667 .49776 m .59518 .49341 L .60434 .47663 L p .701 .708 .853 r
F P
0 g
s
.60434 .47663 m .61742 .47917 L .60667 .49776 L p .701 .708 .853 r
F P
0 g
s
.28822 .46437 m .30206 .46648 L .31234 .49915 L p .577 .71 .933 r
F P
0 g
s
.32523 .50046 m .31234 .49915 L .30206 .46648 L p .533 .679 .932 r
F P
0 g
s
.53788 .51752 m .54101 .52591 L .52325 .53278 L p .777 .796 .868 r
F P
0 g
s
.54101 .52591 m .53788 .51752 L .55128 .50901 L p .776 .782 .857 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54101 .52591 L p .776 .782 .857 r
F P
0 g
s
.76107 .53241 m .74821 .52952 L .76277 .49661 L p .624 .739 .929 r
F P
0 g
s
.76277 .49661 m .77678 .49764 L .76107 .53241 L p .624 .739 .929 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56293 .49859 L p .77 .766 .85 r
F P
0 g
s
.56293 .49859 m .57222 .50371 L .55769 .51601 L p .77 .766 .85 r
F P
0 g
s
.52362 .52354 m .52325 .53278 L .50556 .53617 L p .771 .805 .88 r
F P
0 g
s
.52325 .53278 m .52362 .52354 L .53788 .51752 L p .777 .796 .868 r
F P
0 g
s
.74821 .52952 m .73527 .52574 L .74869 .49448 L p .596 .706 .92 r
F P
0 g
s
.74869 .49448 m .76277 .49661 L .74821 .52952 L p .596 .706 .92 r
F P
0 g
s
.57222 .50371 m .56293 .49859 L .57208 .48691 L p .76 .753 .847 r
F P
0 g
s
.57208 .48691 m .58366 .4898 L .57222 .50371 L p .76 .753 .847 r
F P
0 g
s
.30206 .46648 m .31584 .46958 L .32523 .50046 L p .533 .679 .932 r
F P
0 g
s
.33812 .50269 m .32523 .50046 L .31584 .46958 L p .496 .651 .928 r
F P
0 g
s
.41615 .53533 m .42795 .53468 L .44553 .54715 L p .511 .724 .969 r
F P
0 g
s
.45522 .54351 m .44553 .54715 L .42795 .53468 L p .583 .749 .957 r
F P
0 g
s
.73527 .52574 m .72225 .52114 L .73455 .49136 L p .573 .677 .91 r
F P
0 g
s
.73455 .49136 m .74869 .49448 L .73527 .52574 L p .573 .677 .91 r
F P
0 g
s
.59518 .49341 m .58366 .4898 L .59124 .47516 L p .726 .727 .851 r
F P
0 g
s
.59124 .47516 m .60434 .47663 L .59518 .49341 L p .726 .727 .851 r
F P
0 g
s
.72225 .52114 m .70918 .51587 L .72039 .48742 L p .555 .652 .9 r
F P
0 g
s
.72039 .48742 m .73455 .49136 L .72225 .52114 L p .555 .652 .9 r
F P
0 g
s
.70918 .51587 m .69608 .51012 L .70623 .48289 L p .545 .635 .89 r
F P
0 g
s
.70623 .48289 m .72039 .48742 L .70918 .51587 L p .545 .635 .89 r
F P
0 g
s
.69608 .51012 m .68296 .50411 L .69208 .47807 L p .544 .625 .883 r
F P
0 g
s
.69208 .47807 m .70623 .48289 L .69608 .51012 L p .544 .625 .883 r
F P
0 g
s
.37704 .5121 m .39015 .51499 L .40446 .53491 L p .424 .635 .944 r
F P
0 g
s
.41615 .53533 m .40446 .53491 L .39015 .51499 L p .47 .658 .943 r
F P
0 g
s
.68296 .50411 m .66983 .49812 L .67797 .47327 L p .55 .623 .877 r
F P
0 g
s
.67797 .47327 m .69208 .47807 L .68296 .50411 L p .55 .623 .877 r
F P
0 g
s
.45522 .54351 m .46501 .5384 L .48202 .5436 L p .666 .799 .946 r
F P
0 g
s
.48907 .53584 m .48202 .5436 L .46501 .5384 L p .713 .8 .919 r
F P
0 g
s
.48202 .5436 m .48907 .53584 L .50556 .53617 L p .734 .814 .914 r
F P
0 g
s
.50941 .52669 m .50556 .53617 L .48907 .53584 L p .759 .806 .89 r
F P
0 g
s
.50556 .53617 m .50941 .52669 L .52362 .52354 L p .771 .805 .88 r
F P
0 g
s
.66983 .49812 m .65671 .49239 L .66391 .46883 L p .565 .628 .873 r
F P
0 g
s
.66391 .46883 m .67797 .47327 L .66983 .49812 L p .565 .628 .873 r
F P
0 g
s
.65671 .49239 m .6436 .48719 L .64991 .46503 L p .587 .641 .871 r
F P
0 g
s
.64991 .46503 m .66391 .46883 L .65671 .49239 L p .587 .641 .871 r
F P
0 g
s
.31584 .46958 m .32959 .4735 L .33812 .50269 L p .496 .651 .928 r
F P
0 g
s
.35104 .50559 m .33812 .50269 L .32959 .4735 L p .47 .629 .922 r
F P
0 g
s
.53473 .50871 m .53788 .51752 L .52362 .52354 L p .786 .791 .857 r
F P
0 g
s
.53788 .51752 m .53473 .50871 L .54482 .50197 L p .785 .783 .85 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53788 .51752 L p .785 .783 .85 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55358 .49377 L p .781 .774 .846 r
F P
0 g
s
.55358 .49377 m .56293 .49859 L .55128 .50901 L p .781 .774 .846 r
F P
0 g
s
.6436 .48719 m .63051 .48272 L .63597 .46216 L p .615 .659 .87 r
F P
0 g
s
.63597 .46216 m .64991 .46503 L .6436 .48719 L p .615 .659 .87 r
F P
0 g
s
.58366 .4898 m .57208 .48691 L .57811 .47473 L p .749 .746 .849 r
F P
0 g
s
.57811 .47473 m .59124 .47516 L .58366 .4898 L p .749 .746 .849 r
F P
0 g
s
.63051 .48272 m .61742 .47917 L .62208 .46041 L p .646 .68 .868 r
F P
0 g
s
.62208 .46041 m .63597 .46216 L .63051 .48272 L p .646 .68 .868 r
F P
0 g
s
.52399 .51355 m .52362 .52354 L .50941 .52669 L p .783 .797 .864 r
F P
0 g
s
.52362 .52354 m .52399 .51355 L .53473 .50871 L p .786 .791 .857 r
F P
0 g
s
.56293 .49859 m .55358 .49377 L .56045 .48466 L p .775 .766 .844 r
F P
0 g
s
.56045 .48466 m .57208 .48691 L .56293 .49859 L p .775 .766 .844 r
F P
0 g
s
.42795 .53468 m .43986 .5327 L .45522 .54351 L p .583 .749 .957 r
F P
0 g
s
.46501 .5384 m .45522 .54351 L .43986 .5327 L p .646 .767 .937 r
F P
0 g
s
.61742 .47917 m .60434 .47663 L .60823 .45993 L p .678 .703 .865 r
F P
0 g
s
.60823 .45993 m .62208 .46041 L .61742 .47917 L p .678 .703 .865 r
F P
0 g
s
.32959 .4735 m .34334 .47803 L .35104 .50559 L p .47 .629 .922 r
F P
0 g
s
.364 .50884 m .35104 .50559 L .34334 .47803 L p .459 .616 .917 r
F P
0 g
s
.39015 .51499 m .40337 .51716 L .41615 .53533 L p .47 .658 .943 r
F P
0 g
s
.42795 .53468 m .41615 .53533 L .40337 .51716 L p .527 .685 .939 r
F P
0 g
s
.46501 .5384 m .47488 .53177 L .48907 .53584 L p .713 .8 .919 r
F P
0 g
s
.49619 .52673 m .48907 .53584 L .47488 .53177 L p .746 .797 .894 r
F P
0 g
s
.48907 .53584 m .49619 .52673 L .50941 .52669 L p .759 .806 .89 r
F P
0 g
s
.60434 .47663 m .59124 .47516 L .59441 .46075 L p .71 .725 .861 r
F P
0 g
s
.59441 .46075 m .60823 .45993 L .60434 .47663 L p .71 .725 .861 r
F P
0 g
s
.51329 .51618 m .50941 .52669 L .49619 .52673 L p .777 .798 .869 r
F P
0 g
s
.50941 .52669 m .51329 .51618 L .52399 .51355 L p .783 .797 .864 r
F P
0 g
s
.57208 .48691 m .56045 .48466 L .56495 .47523 L p .769 .761 .846 r
F P
0 g
s
.56495 .47523 m .57811 .47473 L .57208 .48691 L p .769 .761 .846 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53473 .50871 L p .792 .784 .845 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54417 .4892 L p .79 .779 .843 r
F P
0 g
s
.54417 .4892 m .55358 .49377 L .54482 .50197 L p .79 .779 .843 r
F P
0 g
s
.53155 .49954 m .53473 .50871 L .52399 .51355 L p .793 .788 .848 r
F P
0 g
s
.53473 .50871 m .53155 .49954 L .5383 .49486 L p .792 .784 .845 r
F P
0 g
s
.59124 .47516 m .57811 .47473 L .5806 .46285 L p .739 .745 .856 r
F P
0 g
s
.5806 .46285 m .59441 .46075 L .59124 .47516 L p .739 .745 .856 r
F P
0 g
s
.43986 .5327 m .45187 .52922 L .46501 .5384 L p .646 .767 .937 r
F P
0 g
s
.47488 .53177 m .46501 .5384 L .45187 .52922 L p .697 .777 .913 r
F P
0 g
s
.55358 .49377 m .54417 .4892 L .54875 .48295 L p .787 .775 .842 r
F P
0 g
s
.54875 .48295 m .56045 .48466 L .55358 .49377 L p .787 .775 .842 r
F P
0 g
s
.52436 .50293 m .52399 .51355 L .51329 .51618 L p .792 .791 .851 r
F P
0 g
s
.52399 .51355 m .52436 .50293 L .53155 .49954 L p .793 .788 .848 r
F P
0 g
s
.34334 .47803 m .35711 .48287 L .364 .50884 L p .459 .616 .917 r
F P
0 g
s
.37704 .5121 m .364 .50884 L .35711 .48287 L p .465 .615 .913 r
F P
0 g
s
.40337 .51716 m .41668 .51831 L .42795 .53468 L p .527 .685 .939 r
F P
0 g
s
.43986 .5327 m .42795 .53468 L .41668 .51831 L p .587 .712 .93 r
F P
0 g
s
.47488 .53177 m .48483 .52364 L .49619 .52673 L p .746 .797 .894 r
F P
0 g
s
.50335 .51639 m .49619 .52673 L .48483 .52364 L p .77 .793 .872 r
F P
0 g
s
.49619 .52673 m .50335 .51639 L .51329 .51618 L p .777 .798 .869 r
F P
0 g
s
.56045 .48466 m .54875 .48295 L .55174 .47651 L p .784 .773 .843 r
F P
0 g
s
.55174 .47651 m .56495 .47523 L .56045 .48466 L p .784 .773 .843 r
F P
0 g
s
.57811 .47473 m .56495 .47523 L .56678 .46611 L p .763 .761 .851 r
F P
0 g
s
.56678 .46611 m .5806 .46285 L .57811 .47473 L p .763 .761 .851 r
F P
0 g
s
.51721 .50481 m .51329 .51618 L .50335 .51639 L p .789 .791 .854 r
F P
0 g
s
.51329 .51618 m .51721 .50481 L .52436 .50293 L p .792 .791 .851 r
F P
0 g
s
.45187 .52922 m .46396 .52417 L .47488 .53177 L p .697 .777 .913 r
F P
0 g
s
.48483 .52364 m .47488 .53177 L .46396 .52417 L p .736 .783 .89 r
F P
0 g
s
.35711 .48287 m .37091 .48772 L .37704 .5121 L p .465 .615 .913 r
F P
0 g
s
.39015 .51499 m .37704 .5121 L .37091 .48772 L p .487 .624 .911 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53155 .49954 L p .797 .784 .841 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53468 .4848 L p .797 .783 .84 r
F P
0 g
s
.53468 .4848 m .54417 .4892 L .5383 .49486 L p .797 .783 .84 r
F P
0 g
s
.52835 .49009 m .53155 .49954 L .52436 .50293 L p .798 .786 .842 r
F P
0 g
s
.53155 .49954 m .52835 .49009 L .53174 .48769 L p .797 .784 .841 r
F P
0 g
s
.41668 .51831 m .43008 .51817 L .43986 .5327 L p .587 .712 .93 r
F P
0 g
s
.45187 .52922 m .43986 .5327 L .43008 .51817 L p .644 .735 .916 r
F P
0 g
s
.54417 .4892 m .53468 .4848 L .53697 .48161 L p .796 .782 .84 r
F P
0 g
s
.53697 .48161 m .54875 .48295 L .54417 .4892 L p .796 .782 .84 r
F P
0 g
s
.56495 .47523 m .55174 .47651 L .55293 .47032 L p .782 .773 .845 r
F P
0 g
s
.55293 .47032 m .56678 .46611 L .56495 .47523 L p .782 .773 .845 r
F P
0 g
s
.63597 .46216 m .62208 .46041 L .62019 .44274 L p .618 .686 .891 r
F P
0 g
s
.62208 .46041 m .60823 .45993 L .60651 .44441 L p .659 .71 .885 r
F P
0 g
s
.60651 .44441 m .62019 .44274 L .62208 .46041 L p .659 .71 .885 r
F P
0 g
s
.52474 .49184 m .52436 .50293 L .51721 .50481 L p .797 .786 .843 r
F P
0 g
s
.52436 .50293 m .52474 .49184 L .52835 .49009 L p .798 .786 .842 r
F P
0 g
s
.60823 .45993 m .59441 .46075 L .5929 .44754 L p .698 .732 .877 r
F P
0 g
s
.5929 .44754 m .60651 .44441 L .60823 .45993 L p .698 .732 .877 r
F P
0 g
s
.48483 .52364 m .49484 .51418 L .50335 .51639 L p .77 .793 .872 r
F P
0 g
s
.51057 .50504 m .50335 .51639 L .49484 .51418 L p .786 .789 .855 r
F P
0 g
s
.50335 .51639 m .51057 .50504 L .51721 .50481 L p .789 .791 .854 r
F P
0 g
s
.64991 .46503 m .63597 .46216 L .63395 .44248 L p .577 .661 .895 r
F P
0 g
s
.62019 .44274 m .63395 .44248 L .63597 .46216 L p .618 .686 .891 r
F P
0 g
s
.59441 .46075 m .5806 .46285 L .57933 .45208 L p .732 .751 .867 r
F P
0 g
s
.57933 .45208 m .5929 .44754 L .59441 .46075 L p .732 .751 .867 r
F P
0 g
s
.54875 .48295 m .53697 .48161 L .53846 .47834 L p .795 .781 .84 r
F P
0 g
s
.53846 .47834 m .55174 .47651 L .54875 .48295 L p .795 .781 .84 r
F P
0 g
s
.46396 .52417 m .47612 .5176 L .48483 .52364 L p .736 .783 .89 r
F P
0 g
s
.49484 .51418 m .48483 .52364 L .47612 .5176 L p .764 .785 .87 r
F P
0 g
s
.66391 .46883 m .64991 .46503 L .64781 .44348 L p .541 .64 .897 r
F P
0 g
s
.63395 .44248 m .64781 .44348 L .64991 .46503 L p .577 .661 .895 r
F P
0 g
s
.52115 .49282 m .51721 .50481 L .51057 .50504 L p .796 .787 .843 r
F P
0 g
s
.51721 .50481 m .52115 .49282 L .52474 .49184 L p .797 .786 .843 r
F P
0 g
s
.5806 .46285 m .56678 .46611 L .56578 .45791 L p .76 .766 .857 r
F P
0 g
s
.56578 .45791 m .57933 .45208 L .5806 .46285 L p .76 .766 .857 r
F P
0 g
s
.37091 .48772 m .38476 .49223 L .39015 .51499 L p .487 .624 .911 r
F P
0 g
s
.40337 .51716 m .39015 .51499 L .38476 .49223 L p .522 .641 .908 r
F P
0 g
s
.43008 .51817 m .44356 .51659 L .45187 .52922 L p .644 .735 .916 r
F P
0 g
s
.46396 .52417 m .45187 .52922 L .44356 .51659 L p .692 .753 .899 r
F P
0 g
s
.67797 .47327 m .66391 .46883 L .66176 .44551 L p .513 .625 .899 r
F P
0 g
s
.64781 .44348 m .66176 .44551 L .66391 .46883 L p .541 .64 .897 r
F P
0 g
s
.55174 .47651 m .53846 .47834 L .53905 .47521 L p .794 .781 .841 r
F P
0 g
s
.53905 .47521 m .55293 .47032 L .55174 .47651 L p .794 .781 .841 r
F P
0 g
s
.56678 .46611 m .55293 .47032 L .55223 .46479 L p .78 .776 .849 r
F P
0 g
s
.55223 .46479 m .56578 .45791 L .56678 .46611 L p .78 .776 .849 r
F P
0 g
s
.49484 .51418 m .5049 .50361 L .51057 .50504 L p .786 .789 .855 r
F P
0 g
s
.51782 .49296 m .51057 .50504 L .5049 .50361 L p .796 .786 .844 r
F P
0 g
s
.51057 .50504 m .51782 .49296 L .52115 .49282 L p .796 .787 .843 r
F P
0 g
s
.47612 .5176 m .48833 .50965 L .49484 .51418 L p .764 .785 .87 r
F P
0 g
s
.5049 .50361 m .49484 .51418 L .48833 .50965 L p .783 .785 .854 r
F P
0 g
s
.69208 .47807 m .67797 .47327 L .67581 .44827 L p .496 .617 .901 r
F P
0 g
s
.66176 .44551 m .67581 .44827 L .67797 .47327 L p .513 .625 .899 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49009 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53468 .4848 L .53174 .48769 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52835 .49009 L .52474 .49184 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53697 .48161 L .53468 .4848 L closepath p .8 .785 .838 r
F P
0 g
s
.38476 .49223 m .39867 .4961 L .40337 .51716 L p .522 .641 .908 r
F P
0 g
s
.41668 .51831 m .40337 .51716 L .39867 .4961 L p .564 .664 .905 r
F P
0 g
s
.44356 .51659 m .4571 .51351 L .46396 .52417 L p .692 .753 .899 r
F P
0 g
s
.47612 .5176 m .46396 .52417 L .4571 .51351 L p .731 .766 .881 r
F P
0 g
s
.52511 .48046 m .52474 .49184 L .52115 .49282 L closepath p .8 .785 .838 r
F P
0 g
s
.55293 .47032 m .53905 .47521 L .53868 .47243 L p .794 .782 .842 r
F P
0 g
s
.53868 .47243 m .55223 .46479 L .55293 .47032 L p .794 .782 .842 r
F P
0 g
s
.52511 .48046 m .53846 .47834 L .53697 .48161 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52115 .49282 L .51782 .49296 L closepath p .8 .785 .838 r
F P
0 g
s
.70623 .48289 m .69208 .47807 L .68996 .45143 L p .491 .619 .905 r
F P
0 g
s
.67581 .44827 m .68996 .45143 L .69208 .47807 L p .496 .617 .901 r
F P
0 g
s
.85906 .48583 m .84551 .48896 L .84593 .43898 L p .758 .834 .91 r
F P
0 g
s
.84593 .43898 m .85986 .43317 L .85906 .48583 L p .758 .834 .91 r
F P
0 g
s
.48833 .50965 m .50058 .50059 L .5049 .50361 L p .783 .785 .854 r
F P
0 g
s
.51499 .49225 m .5049 .50361 L .50058 .50059 L p .795 .785 .844 r
F P
0 g
s
.5049 .50361 m .51499 .49225 L .51782 .49296 L p .796 .786 .844 r
F P
0 g
s
.52511 .48046 m .53905 .47521 L .53846 .47834 L closepath p .8 .785 .838 r
F P
0 g
s
.4571 .51351 m .47069 .50896 L .47612 .5176 L p .731 .766 .881 r
F P
0 g
s
.48833 .50965 m .47612 .5176 L .47069 .50896 L p .76 .775 .865 r
F P
0 g
s
.52511 .48046 m .51782 .49296 L .51499 .49225 L closepath p .8 .785 .838 r
F P
0 g
s
.5929 .44754 m .57933 .45208 L .57434 .44315 L p .731 .764 .879 r
F P
0 g
s
.57933 .45208 m .56578 .45791 L .562 .45119 L p .76 .774 .864 r
F P
0 g
s
.562 .45119 m .57434 .44315 L .57933 .45208 L p .76 .774 .864 r
F P
0 g
s
.84551 .48896 m .83193 .49196 L .83199 .44464 L p .754 .833 .912 r
F P
0 g
s
.83199 .44464 m .84593 .43898 L .84551 .48896 L p .754 .833 .912 r
F P
0 g
s
.56578 .45791 m .55223 .46479 L .54969 .46031 L p .781 .78 .852 r
F P
0 g
s
.54969 .46031 m .562 .45119 L .56578 .45791 L p .781 .78 .852 r
F P
0 g
s
.39867 .4961 m .41264 .49904 L .41668 .51831 L p .564 .664 .905 r
F P
0 g
s
.43008 .51817 m .41668 .51831 L .41264 .49904 L p .611 .69 .899 r
F P
0 g
s
.72039 .48742 m .70623 .48289 L .70418 .45462 L p .499 .631 .91 r
F P
0 g
s
.68996 .45143 m .70418 .45462 L .70623 .48289 L p .491 .619 .905 r
F P
0 g
s
.52511 .48046 m .53868 .47243 L .53905 .47521 L closepath p .8 .785 .838 r
F P
0 g
s
.26501 .42404 m .27905 .42629 L .27432 .46334 L p .656 .767 .931 r
F P
0 g
s
.27432 .46334 m .26033 .46339 L .26501 .42404 L p .656 .767 .931 r
F P
0 g
s
.28822 .46437 m .27432 .46334 L .27905 .42629 L p .623 .739 .93 r
F P
0 g
s
.60651 .44441 m .5929 .44754 L .58673 .43643 L p .694 .75 .895 r
F P
0 g
s
.57434 .44315 m .58673 .43643 L .5929 .44754 L p .731 .764 .879 r
F P
0 g
s
.27905 .42629 m .293 .42943 L .28822 .46437 L p .623 .739 .93 r
F P
0 g
s
.30206 .46648 m .28822 .46437 L .293 .42943 L p .591 .709 .925 r
F P
0 g
s
.25085 .42261 m .26501 .42404 L .26033 .46339 L p .685 .79 .93 r
F P
0 g
s
.26033 .46339 m .24624 .46445 L .25085 .42261 L p .685 .79 .93 r
F P
0 g
s
.55223 .46479 m .53868 .47243 L .53739 .47019 L p .794 .783 .843 r
F P
0 g
s
.53739 .47019 m .54969 .46031 L .55223 .46479 L p .794 .783 .843 r
F P
0 g
s
.47069 .50896 m .4843 .50311 L .48833 .50965 L p .76 .775 .865 r
F P
0 g
s
.50058 .50059 m .48833 .50965 L .4843 .50311 L p .781 .78 .852 r
F P
0 g
s
.50058 .50059 m .51284 .49073 L .51499 .49225 L p .795 .785 .844 r
F P
0 g
s
.52511 .48046 m .51499 .49225 L .51284 .49073 L closepath p .8 .785 .838 r
F P
0 g
s
.293 .42943 m .30684 .43344 L .30206 .46648 L p .591 .709 .925 r
F P
0 g
s
.31584 .46958 m .30206 .46648 L .30684 .43344 L p .562 .679 .918 r
F P
0 g
s
.23658 .42189 m .25085 .42261 L .24624 .46445 L p .709 .808 .927 r
F P
0 g
s
.24624 .46445 m .23207 .46637 L .23658 .42189 L p .709 .808 .927 r
F P
0 g
s
.62019 .44274 m .60651 .44441 L .5992 .43115 L p .648 .731 .909 r
F P
0 g
s
.58673 .43643 m .5992 .43115 L .60651 .44441 L p .694 .75 .895 r
F P
0 g
s
.83193 .49196 m .81827 .49457 L .818 .44984 L p .742 .826 .916 r
F P
0 g
s
.818 .44984 m .83199 .44464 L .83193 .49196 L p .742 .826 .916 r
F P
0 g
s
.52511 .48046 m .53739 .47019 L .53868 .47243 L closepath p .8 .785 .838 r
F P
0 g
s
.4843 .50311 m .49792 .49618 L .50058 .50059 L p .781 .78 .852 r
F P
0 g
s
.51284 .49073 m .50058 .50059 L .49792 .49618 L p .794 .783 .843 r
F P
0 g
s
.73455 .49136 m .72039 .48742 L .71846 .45748 L p .519 .65 .917 r
F P
0 g
s
.70418 .45462 m .71846 .45748 L .72039 .48742 L p .499 .631 .91 r
F P
0 g
s
.30684 .43344 m .32062 .43827 L .31584 .46958 L p .562 .679 .918 r
F P
0 g
s
.32959 .4735 m .31584 .46958 L .32062 .43827 L p .54 .654 .909 r
F P
0 g
s
.49792 .49618 m .51152 .48851 L .51284 .49073 L p .794 .783 .843 r
F P
0 g
s
.52511 .48046 m .51284 .49073 L .51152 .48851 L closepath p .8 .785 .838 r
F P
0 g
s
.41264 .49904 m .42667 .50082 L .43008 .51817 L p .611 .69 .899 r
F P
0 g
s
.44356 .51659 m .43008 .51817 L .42667 .50082 L p .656 .714 .891 r
F P
0 g
s
.2222 .42171 m .23658 .42189 L .23207 .46637 L p .727 .82 .922 r
F P
0 g
s
.23207 .46637 m .21781 .46895 L .2222 .42171 L p .727 .82 .922 r
F P
0 g
s
.52511 .48046 m .53527 .46865 L .53739 .47019 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53244 .46791 L .53527 .46865 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52911 .46803 L .53244 .46791 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52549 .469 L .52911 .46803 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52185 .47076 L .52549 .469 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47076 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51548 .4761 L .51844 .47318 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51318 .47931 L .51548 .4761 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51169 .4826 L .51318 .47931 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51113 .48574 L .51169 .4826 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51152 .48851 L .51113 .48574 L closepath p .8 .785 .838 r
F P
0 g
s
.81827 .49457 m .80453 .49651 L .80395 .45429 L p .722 .813 .921 r
F P
0 g
s
.80395 .45429 m .818 .44984 L .81827 .49457 L p .722 .813 .921 r
F P
0 g
s
.63395 .44248 m .62019 .44274 L .61175 .42738 L p .598 .708 .921 r
F P
0 g
s
.5992 .43115 m .61175 .42738 L .62019 .44274 L p .648 .731 .909 r
F P
0 g
s
.54969 .46031 m .53739 .47019 L .53527 .46865 L p .795 .785 .844 r
F P
0 g
s
.74869 .49448 m .73455 .49136 L .73277 .45969 L p .548 .677 .923 r
F P
0 g
s
.71846 .45748 m .73277 .45969 L .73455 .49136 L p .519 .65 .917 r
F P
0 g
s
.32062 .43827 m .33433 .44377 L .32959 .4735 L p .54 .654 .909 r
F P
0 g
s
.34334 .47803 m .32959 .4735 L .33433 .44377 L p .527 .635 .901 r
F P
0 g
s
.562 .45119 m .54969 .46031 L .54545 .45719 L p .783 .785 .854 r
F P
0 g
s
.53527 .46865 m .54545 .45719 L .54969 .46031 L p .795 .785 .844 r
F P
0 g
s
.4971 .49069 m .51113 .48574 L .51152 .48851 L p .794 .782 .842 r
F P
0 g
s
.51152 .48851 m .49792 .49618 L .4971 .49069 L p .794 .782 .842 r
F P
0 g
s
.20772 .42187 m .2222 .42171 L .21781 .46895 L p .738 .825 .918 r
F P
0 g
s
.21781 .46895 m .20348 .47193 L .20772 .42187 L p .738 .825 .918 r
F P
0 g
s
.42667 .50082 m .44073 .50131 L .44356 .51659 L p .656 .714 .891 r
F P
0 g
s
.4571 .51351 m .44356 .51659 L .44073 .50131 L p .697 .735 .88 r
F P
0 g
s
.80453 .49651 m .7907 .49759 L .78983 .45775 L p .695 .793 .926 r
F P
0 g
s
.78983 .45775 m .80395 .45429 L .80453 .49651 L p .695 .793 .926 r
F P
0 g
s
.76277 .49661 m .74869 .49448 L .74709 .46097 L p .584 .707 .928 r
F P
0 g
s
.73277 .45969 m .74709 .46097 L .74869 .49448 L p .548 .677 .923 r
F P
0 g
s
.54545 .45719 m .53527 .46865 L .53244 .46791 L p .795 .786 .844 r
F P
0 g
s
.57434 .44315 m .562 .45119 L .55567 .44644 L p .764 .783 .869 r
F P
0 g
s
.54545 .45719 m .55567 .44644 L .562 .45119 L p .783 .785 .854 r
F P
0 g
s
.48303 .49497 m .4971 .49069 L .49792 .49618 L p .781 .776 .849 r
F P
0 g
s
.49792 .49618 m .4843 .50311 L .48303 .49497 L p .781 .776 .849 r
F P
0 g
s
.7907 .49759 m .77678 .49764 L .77564 .46006 L p .661 .768 .929 r
F P
0 g
s
.77564 .46006 m .78983 .45775 L .7907 .49759 L p .661 .768 .929 r
F P
0 g
s
.77678 .49764 m .76277 .49661 L .76138 .46113 L p .623 .739 .93 r
F P
0 g
s
.74709 .46097 m .76138 .46113 L .76277 .49661 L p .584 .707 .928 r
F P
0 g
s
.44073 .50131 m .45483 .50046 L .4571 .51351 L p .697 .735 .88 r
F P
0 g
s
.47069 .50896 m .4571 .51351 L .45483 .50046 L p .732 .753 .869 r
F P
0 g
s
.76138 .46113 m .77564 .46006 L .77678 .49764 L p .623 .739 .93 r
F P
0 g
s
.4982 .48446 m .51169 .4826 L .51113 .48574 L p .794 .781 .841 r
F P
0 g
s
.51113 .48574 m .4971 .49069 L .4982 .48446 L p .794 .781 .841 r
F P
0 g
s
.33433 .44377 m .34801 .44975 L .34334 .47803 L p .527 .635 .901 r
F P
0 g
s
.35711 .48287 m .34334 .47803 L .34801 .44975 L p .524 .625 .893 r
F P
0 g
s
.64781 .44348 m .63395 .44248 L .62441 .42506 L p .546 .682 .928 r
F P
0 g
s
.61175 .42738 m .62441 .42506 L .63395 .44248 L p .598 .708 .921 r
F P
0 g
s
.46893 .4983 m .48303 .49497 L .4843 .50311 L p .76 .767 .858 r
F P
0 g
s
.4843 .50311 m .47069 .50896 L .46893 .4983 L p .76 .767 .858 r
F P
0 g
s
.19318 .42214 m .20772 .42187 L .20348 .47193 L p .743 .825 .916 r
F P
0 g
s
.20348 .47193 m .18911 .47507 L .19318 .42214 L p .743 .825 .916 r
F P
0 g
s
.45483 .50046 m .46893 .4983 L .47069 .50896 L p .732 .753 .869 r
F P
0 g
s
.53244 .46791 m .5398 .45565 L .54545 .45719 L p .795 .786 .844 r
F P
0 g
s
.5398 .45565 m .53244 .46791 L .52911 .46803 L p .796 .786 .843 r
F P
0 g
s
.58673 .43643 m .57434 .44315 L .56593 .43671 L p .736 .78 .888 r
F P
0 g
s
.55567 .44644 m .56593 .43671 L .57434 .44315 L p .764 .783 .869 r
F P
0 g
s
.50116 .47795 m .51318 .47931 L .51169 .4826 L p .795 .781 .84 r
F P
0 g
s
.51169 .4826 m .4982 .48446 L .50116 .47795 L p .795 .781 .84 r
F P
0 g
s
.55567 .44644 m .54545 .45719 L .5398 .45565 L p .786 .788 .855 r
F P
0 g
s
.34801 .44975 m .36166 .45597 L .35711 .48287 L p .524 .625 .893 r
F P
0 g
s
.37091 .48772 m .35711 .48287 L .36166 .45597 L p .532 .623 .887 r
F P
0 g
s
.52911 .46803 m .53312 .4558 L .5398 .45565 L p .796 .786 .843 r
F P
0 g
s
.53312 .4558 m .52911 .46803 L .52549 .469 L p .797 .786 .843 r
F P
0 g
s
.50576 .47159 m .51548 .4761 L .51318 .47931 L p .796 .782 .84 r
F P
0 g
s
.51318 .47931 m .50116 .47795 L .50576 .47159 L p .796 .782 .84 r
F P
0 g
s
.48465 .48578 m .4982 .48446 L .4971 .49069 L p .782 .774 .846 r
F P
0 g
s
.4971 .49069 m .48303 .49497 L .48465 .48578 L p .782 .774 .846 r
F P
0 g
s
.52549 .469 m .52588 .45765 L .53312 .4558 L p .797 .786 .843 r
F P
0 g
s
.52588 .45765 m .52549 .469 L .52185 .47076 L p .798 .786 .842 r
F P
0 g
s
.5992 .43115 m .58673 .43643 L .57627 .42823 L p .699 .773 .909 r
F P
0 g
s
.56593 .43671 m .57627 .42823 L .58673 .43643 L p .736 .78 .888 r
F P
0 g
s
.66176 .44551 m .64781 .44348 L .63718 .42403 L p .5 .658 .931 r
F P
0 g
s
.62441 .42506 m .63718 .42403 L .64781 .44348 L p .546 .682 .928 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51548 .4761 L p .797 .783 .84 r
F P
0 g
s
.51548 .4761 m .50576 .47159 L .5117 .46583 L p .797 .783 .84 r
F P
0 g
s
.52185 .47076 m .51857 .46107 L .52588 .45765 L p .798 .786 .842 r
F P
0 g
s
.51857 .46107 m .52185 .47076 L .51844 .47318 L p .797 .784 .841 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51857 .46107 L p .797 .784 .841 r
F P
0 g
s
.36166 .45597 m .37531 .46219 L .37091 .48772 L p .532 .623 .887 r
F P
0 g
s
.38476 .49223 m .37091 .48772 L .37531 .46219 L p .55 .63 .883 r
F P
0 g
s
.56593 .43671 m .55567 .44644 L .5472 .444 L p .77 .792 .871 r
F P
0 g
s
.5398 .45565 m .5472 .444 L .55567 .44644 L p .786 .788 .855 r
F P
0 g
s
.5472 .444 m .5398 .45565 L .53312 .4558 L p .789 .791 .854 r
F P
0 g
s
.47104 .48632 m .48465 .48578 L .48303 .49497 L p .763 .762 .852 r
F P
0 g
s
.48303 .49497 m .46893 .4983 L .47104 .48632 L p .763 .762 .852 r
F P
0 g
s
.48906 .47618 m .50116 .47795 L .4982 .48446 L p .784 .774 .843 r
F P
0 g
s
.4982 .48446 m .48465 .48578 L .48906 .47618 L p .784 .774 .843 r
F P
0 g
s
.37531 .46219 m .38897 .46812 L .38476 .49223 L p .55 .63 .883 r
F P
0 g
s
.39867 .4961 m .38476 .49223 L .38897 .46812 L p .576 .643 .88 r
F P
0 g
s
.61175 .42738 m .5992 .43115 L .58667 .42113 L p .651 .762 .93 r
F P
0 g
s
.57627 .42823 m .58667 .42113 L .5992 .43115 L p .699 .773 .909 r
F P
0 g
s
.67581 .44827 m .66176 .44551 L .65008 .42407 L p .464 .64 .932 r
F P
0 g
s
.63718 .42403 m .65008 .42407 L .66176 .44551 L p .5 .658 .931 r
F P
0 g
s
.45738 .4859 m .47104 .48632 L .46893 .4983 L p .739 .746 .858 r
F P
0 g
s
.46893 .4983 m .45483 .50046 L .45738 .4859 L p .739 .746 .858 r
F P
0 g
s
.53312 .4558 m .53717 .44405 L .5472 .444 L p .789 .791 .854 r
F P
0 g
s
.53717 .44405 m .53312 .4558 L .52588 .45765 L p .792 .79 .851 r
F P
0 g
s
.38897 .46812 m .40264 .47351 L .39867 .4961 L p .576 .643 .88 r
F P
0 g
s
.41264 .49904 m .39867 .4961 L .40264 .47351 L p .607 .662 .877 r
F P
0 g
s
.57627 .42823 m .56593 .43671 L .55465 .43323 L p .746 .795 .892 r
F P
0 g
s
.5472 .444 m .55465 .43323 L .56593 .43671 L p .77 .792 .871 r
F P
0 g
s
.49597 .46684 m .50576 .47159 L .50116 .47795 L p .787 .776 .842 r
F P
0 g
s
.50116 .47795 m .48906 .47618 L .49597 .46684 L p .787 .776 .842 r
F P
0 g
s
.4437 .4844 m .45738 .4859 L .45483 .50046 L p .71 .727 .864 r
F P
0 g
s
.45483 .50046 m .44073 .50131 L .4437 .4844 L p .71 .727 .864 r
F P
0 g
s
.40264 .47351 m .41632 .47813 L .41264 .49904 L p .607 .662 .877 r
F P
0 g
s
.42667 .50082 m .41264 .49904 L .41632 .47813 L p .642 .683 .874 r
F P
0 g
s
.55465 .43323 m .5472 .444 L .53717 .44405 L p .777 .797 .869 r
F P
0 g
s
.43001 .4818 m .4437 .4844 L .44073 .50131 L p .677 .706 .869 r
F P
0 g
s
.44073 .50131 m .42667 .50082 L .43001 .4818 L p .677 .706 .869 r
F P
0 g
s
.52588 .45765 m .52627 .44661 L .53717 .44405 L p .792 .79 .851 r
F P
0 g
s
.52627 .44661 m .52588 .45765 L .51857 .46107 L p .793 .788 .848 r
F P
0 g
s
.41632 .47813 m .43001 .4818 L .42667 .50082 L p .642 .683 .874 r
F P
0 g
s
.47689 .47385 m .48906 .47618 L .48465 .48578 L p .769 .762 .847 r
F P
0 g
s
.48465 .48578 m .47104 .48632 L .47689 .47385 L p .769 .762 .847 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50576 .47159 L p .79 .779 .843 r
F P
0 g
s
.50576 .47159 m .49597 .46684 L .50491 .45842 L p .79 .779 .843 r
F P
0 g
s
.62441 .42506 m .61175 .42738 L .59718 .41546 L p .595 .744 .947 r
F P
0 g
s
.58667 .42113 m .59718 .41546 L .61175 .42738 L p .651 .762 .93 r
F P
0 g
s
.51857 .46107 m .51525 .45151 L .52627 .44661 L p .793 .788 .848 r
F P
0 g
s
.51525 .45151 m .51857 .46107 L .5117 .46583 L p .792 .784 .845 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51525 .45151 L p .792 .784 .845 r
F P
0 g
s
.68996 .45143 m .67581 .44827 L .6631 .42486 L p .444 .63 .933 r
F P
0 g
s
.65008 .42407 m .6631 .42486 L .67581 .44827 L p .464 .64 .932 r
F P
0 g
s
.58667 .42113 m .57627 .42823 L .56216 .42355 L p .714 .796 .916 r
F P
0 g
s
.55465 .43323 m .56216 .42355 L .57627 .42823 L p .746 .795 .892 r
F P
0 g
s
.53717 .44405 m .54125 .43298 L .55465 .43323 L p .777 .797 .869 r
F P
0 g
s
.54125 .43298 m .53717 .44405 L .52627 .44661 L p .783 .796 .864 r
F P
0 g
s
.46465 .47082 m .47689 .47385 L .47104 .48632 L p .749 .747 .85 r
F P
0 g
s
.47104 .48632 m .45738 .4859 L .46465 .47082 L p .749 .747 .85 r
F P
0 g
s
.48611 .46177 m .49597 .46684 L .48906 .47618 L p .775 .766 .845 r
F P
0 g
s
.48906 .47618 m .47689 .47385 L .48611 .46177 L p .775 .766 .845 r
F P
0 g
s
.56216 .42355 m .55465 .43323 L .54125 .43298 L p .759 .804 .888 r
F P
0 g
s
.63718 .42403 m .62441 .42506 L .60779 .41118 L p .535 .721 .959 r
F P
0 g
s
.59718 .41546 m .60779 .41118 L .62441 .42506 L p .595 .744 .947 r
F P
0 g
s
.70418 .45462 m .68996 .45143 L .67625 .42604 L p .442 .63 .934 r
F P
0 g
s
.6631 .42486 m .67625 .42604 L .68996 .45143 L p .444 .63 .933 r
F P
0 g
s
.52627 .44661 m .52666 .43602 L .54125 .43298 L p .783 .796 .864 r
F P
0 g
s
.52666 .43602 m .52627 .44661 L .51525 .45151 L p .786 .791 .857 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49597 .46684 L p .781 .774 .846 r
F P
0 g
s
.49597 .46684 m .48611 .46177 L .49806 .45095 L p .781 .774 .846 r
F P
0 g
s
.59718 .41546 m .58667 .42113 L .56973 .4151 L p .671 .793 .94 r
F P
0 g
s
.56216 .42355 m .56973 .4151 L .58667 .42113 L p .714 .796 .916 r
F P
0 g
s
.45236 .46702 m .46465 .47082 L .45738 .4859 L p .726 .73 .853 r
F P
0 g
s
.45738 .4859 m .4437 .4844 L .45236 .46702 L p .726 .73 .853 r
F P
0 g
s
.51525 .45151 m .51191 .44216 L .52666 .43602 L p .786 .791 .857 r
F P
0 g
s
.51191 .44216 m .51525 .45151 L .50491 .45842 L p .785 .783 .85 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51191 .44216 L p .785 .783 .85 r
F P
0 g
s
.47617 .45631 m .48611 .46177 L .47689 .47385 L p .76 .754 .847 r
F P
0 g
s
.47689 .47385 m .46465 .47082 L .47617 .45631 L p .76 .754 .847 r
F P
0 g
s
.54125 .43298 m .54536 .42278 L .56216 .42355 L p .759 .804 .888 r
F P
0 g
s
.54536 .42278 m .54125 .43298 L .52666 .43602 L p .771 .803 .879 r
F P
0 g
s
.44003 .46242 m .45236 .46702 L .4437 .4844 L p .7 .711 .856 r
F P
0 g
s
.4437 .4844 m .43001 .4818 L .44003 .46242 L p .7 .711 .856 r
F P
0 g
s
.56973 .4151 m .56216 .42355 L .54536 .42278 L p .735 .81 .911 r
F P
0 g
s
.65008 .42407 m .63718 .42403 L .61852 .40814 L p .479 .696 .964 r
F P
0 g
s
.60779 .41118 m .61852 .40814 L .63718 .42403 L p .535 .721 .959 r
F P
0 g
s
.71846 .45748 m .70418 .45462 L .6895 .42726 L p .458 .642 .936 r
F P
0 g
s
.67625 .42604 m .6895 .42726 L .70418 .45462 L p .442 .63 .934 r
F P
0 g
s
.42765 .45705 m .44003 .46242 L .43001 .4818 L p .674 .692 .859 r
F P
0 g
s
.43001 .4818 m .41632 .47813 L .42765 .45705 L p .674 .692 .859 r
F P
0 g
s
.60779 .41118 m .59718 .41546 L .57739 .40791 L p .617 .785 .962 r
F P
0 g
s
.56973 .4151 m .57739 .40791 L .59718 .41546 L p .671 .793 .94 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48611 .46177 L p .77 .767 .85 r
F P
0 g
s
.48611 .46177 m .47617 .45631 L .49116 .44341 L p .77 .767 .85 r
F P
0 g
s
.52666 .43602 m .52705 .42602 L .54536 .42278 L p .771 .803 .879 r
F P
0 g
s
.52705 .42602 m .52666 .43602 L .51191 .44216 L p .777 .795 .868 r
F P
0 g
s
.41525 .45098 m .42765 .45705 L .41632 .47813 L p .648 .674 .861 r
F P
0 g
s
.41632 .47813 m .40264 .47351 L .41525 .45098 L p .648 .674 .861 r
F P
0 g
s
.46617 .45042 m .47617 .45631 L .46465 .47082 L p .743 .741 .85 r
F P
0 g
s
.46465 .47082 m .45236 .46702 L .46617 .45042 L p .743 .741 .85 r
F P
0 g
s
.40281 .44434 m .41525 .45098 L .40264 .47351 L p .624 .659 .864 r
F P
0 g
s
.40264 .47351 m .38897 .46812 L .40281 .44434 L p .624 .659 .864 r
F P
0 g
s
.50854 .43307 m .51191 .44216 L .49806 .45095 L p .776 .782 .857 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50854 .43307 L p .776 .782 .857 r
F P
0 g
s
.51191 .44216 m .50854 .43307 L .52705 .42602 L p .777 .795 .868 r
F P
0 g
s
.73277 .45969 m .71846 .45748 L .70284 .42812 L p .488 .661 .938 r
F P
0 g
s
.6895 .42726 m .70284 .42812 L .71846 .45748 L p .458 .642 .936 r
F P
0 g
s
.39034 .4373 m .40281 .44434 L .38897 .46812 L p .604 .649 .868 r
F P
0 g
s
.38897 .46812 m .37531 .46219 L .39034 .4373 L p .604 .649 .868 r
F P
0 g
s
.37784 .43003 m .39034 .4373 L .37531 .46219 L p .589 .644 .873 r
F P
0 g
s
.37531 .46219 m .36166 .45597 L .37784 .43003 L p .589 .644 .873 r
F P
0 g
s
.54536 .42278 m .54952 .41356 L .56973 .4151 L p .735 .81 .911 r
F P
0 g
s
.54952 .41356 m .54536 .42278 L .52705 .42602 L p .754 .811 .898 r
F P
0 g
s
.57739 .40791 m .56973 .4151 L .54952 .41356 L p .702 .815 .935 r
F P
0 g
s
.36529 .42274 m .37784 .43003 L .36166 .45597 L p .58 .645 .88 r
F P
0 g
s
.36166 .45597 m .34801 .44975 L .36529 .42274 L p .58 .645 .88 r
F P
0 g
s
.6631 .42486 m .65008 .42407 L .62938 .4061 L p .436 .675 .964 r
F P
0 g
s
.61852 .40814 m .62938 .4061 L .65008 .42407 L p .479 .696 .964 r
F P
0 g
s
.35269 .41559 m .36529 .42274 L .34801 .44975 L p .577 .653 .889 r
F P
0 g
s
.34801 .44975 m .33433 .44377 L .35269 .41559 L p .577 .653 .889 r
F P
0 g
s
.34003 .40877 m .35269 .41559 L .33433 .44377 L p .58 .668 .899 r
F P
0 g
s
.33433 .44377 m .32062 .43827 L .34003 .40877 L p .58 .668 .899 r
F P
0 g
s
.32728 .4024 m .34003 .40877 L .32062 .43827 L p .59 .688 .91 r
F P
0 g
s
.32062 .43827 m .30684 .43344 L .32728 .4024 L p .59 .688 .91 r
F P
0 g
s
.45611 .44408 m .46617 .45042 L .45236 .46702 L p .723 .726 .853 r
F P
0 g
s
.45236 .46702 m .44003 .46242 L .45611 .44408 L p .723 .726 .853 r
F P
0 g
s
.31445 .39659 m .32728 .4024 L .30684 .43344 L p .605 .713 .92 r
F P
0 g
s
.30684 .43344 m .293 .42943 L .31445 .39659 L p .605 .713 .92 r
F P
0 g
s
.61852 .40814 m .60779 .41118 L .58513 .40193 L p .558 .769 .977 r
F P
0 g
s
.57739 .40791 m .58513 .40193 L .60779 .41118 L p .617 .785 .962 r
F P
0 g
s
.74709 .46097 m .73277 .45969 L .71624 .4283 L p .529 .687 .939 r
F P
0 g
s
.70284 .42812 m .71624 .4283 L .73277 .45969 L p .488 .661 .938 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47617 .45631 L p .757 .759 .854 r
F P
0 g
s
.47617 .45631 m .46617 .45042 L .48419 .43581 L p .757 .759 .854 r
F P
0 g
s
.30152 .39139 m .31445 .39659 L .293 .42943 L p .624 .739 .929 r
F P
0 g
s
.293 .42943 m .27905 .42629 L .30152 .39139 L p .624 .739 .929 r
F P
0 g
s
.52705 .42602 m .52745 .41668 L .54952 .41356 L p .754 .811 .898 r
F P
0 g
s
.52745 .41668 m .52705 .42602 L .50854 .43307 L p .764 .799 .881 r
F P
0 g
s
.50513 .42428 m .50854 .43307 L .49116 .44341 L p .765 .78 .865 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50513 .42428 L p .765 .78 .865 r
F P
0 g
s
.28847 .3868 m .30152 .39139 L .27905 .42629 L p .645 .765 .936 r
F P
0 g
s
.27905 .42629 m .26501 .42404 L .28847 .3868 L p .645 .765 .936 r
F P
0 g
s
.50854 .43307 m .50513 .42428 L .52745 .41668 L p .764 .799 .881 r
F P
0 g
s
.76138 .46113 m .74709 .46097 L .72968 .42749 L p .576 .714 .936 r
F P
0 g
s
.71624 .4283 m .72968 .42749 L .74709 .46097 L p .529 .687 .939 r
F P
0 g
s
.44599 .43731 m .45611 .44408 L .44003 .46242 L p .703 .712 .855 r
F P
0 g
s
.44003 .46242 m .42765 .45705 L .44599 .43731 L p .703 .712 .855 r
F P
0 g
s
.67625 .42604 m .6631 .42486 L .64037 .40478 L p .413 .663 .963 r
F P
0 g
s
.62938 .4061 m .64037 .40478 L .6631 .42486 L p .436 .675 .964 r
F P
0 g
s
.58513 .40193 m .57739 .40791 L .55372 .40534 L p .66 .815 .958 r
F P
0 g
s
.54952 .41356 m .55372 .40534 L .57739 .40791 L p .702 .815 .935 r
F P
0 g
s
.55372 .40534 m .54952 .41356 L .52745 .41668 L p .732 .818 .918 r
F P
0 g
s
.27531 .38279 m .28847 .3868 L .26501 .42404 L p .665 .788 .94 r
F P
0 g
s
.26501 .42404 m .25085 .42261 L .27531 .38279 L p .665 .788 .94 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46617 .45042 L p .742 .75 .859 r
F P
0 g
s
.46617 .45042 m .45611 .44408 L .47717 .42815 L p .742 .75 .859 r
F P
0 g
s
.77564 .46006 m .76138 .46113 L .74312 .42551 L p .622 .739 .931 r
F P
0 g
s
.72968 .42749 m .74312 .42551 L .76138 .46113 L p .576 .714 .936 r
F P
0 g
s
.62938 .4061 m .61852 .40814 L .59297 .39705 L p .501 .749 .984 r
F P
0 g
s
.58513 .40193 m .59297 .39705 L .61852 .40814 L p .558 .769 .977 r
F P
0 g
s
.4358 .43015 m .44599 .43731 L .42765 .45705 L p .683 .699 .858 r
F P
0 g
s
.42765 .45705 m .41525 .45098 L .4358 .43015 L p .683 .699 .858 r
F P
0 g
s
.26203 .37925 m .27531 .38279 L .25085 .42261 L p .683 .807 .941 r
F P
0 g
s
.25085 .42261 m .23658 .42189 L .26203 .37925 L p .683 .807 .941 r
F P
0 g
s
.78983 .45775 m .77564 .46006 L .75656 .42222 L p .665 .761 .922 r
F P
0 g
s
.74312 .42551 m .75656 .42222 L .77564 .46006 L p .622 .739 .931 r
F P
0 g
s
.52745 .41668 m .52785 .40803 L .55372 .40534 L p .732 .818 .918 r
F P
0 g
s
.52785 .40803 m .52745 .41668 L .50513 .42428 L p .75 .803 .895 r
F P
0 g
s
.50169 .41582 m .50513 .42428 L .48419 .43581 L p .752 .777 .874 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50169 .41582 L p .752 .777 .874 r
F P
0 g
s
.6895 .42726 m .67625 .42604 L .65147 .40383 L p .413 .661 .962 r
F P
0 g
s
.64037 .40478 m .65147 .40383 L .67625 .42604 L p .413 .663 .963 r
F P
0 g
s
.80395 .45429 m .78983 .45775 L .76997 .41763 L p .7 .779 .912 r
F P
0 g
s
.75656 .42222 m .76997 .41763 L .78983 .45775 L p .665 .761 .922 r
F P
0 g
s
.42556 .42265 m .4358 .43015 L .41525 .45098 L p .664 .687 .862 r
F P
0 g
s
.41525 .45098 m .40281 .44434 L .42556 .42265 L p .664 .687 .862 r
F P
0 g
s
.50513 .42428 m .50169 .41582 L .52785 .40803 L p .75 .803 .895 r
F P
0 g
s
.24863 .37609 m .26203 .37925 L .23658 .42189 L p .698 .82 .94 r
F P
0 g
s
.23658 .42189 m .2222 .42171 L .24863 .37609 L p .698 .82 .94 r
F P
0 g
s
.818 .44984 m .80395 .45429 L .78335 .41181 L p .728 .791 .902 r
F P
0 g
s
.76997 .41763 m .78335 .41181 L .80395 .45429 L p .7 .779 .912 r
F P
0 g
s
.59297 .39705 m .58513 .40193 L .55797 .3981 L p .613 .809 .975 r
F P
0 g
s
.55372 .40534 m .55797 .3981 L .58513 .40193 L p .66 .815 .958 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45611 .44408 L p .726 .741 .864 r
F P
0 g
s
.45611 .44408 m .44599 .43731 L .47008 .42042 L p .726 .741 .864 r
F P
0 g
s
.55797 .3981 m .55372 .40534 L .52785 .40803 L p .704 .822 .938 r
F P
0 g
s
.83199 .44464 m .818 .44984 L .79668 .40494 L p .747 .8 .894 r
F P
0 g
s
.78335 .41181 m .79668 .40494 L .818 .44984 L p .728 .791 .902 r
F P
0 g
s
.85986 .43317 m .84593 .43898 L .82329 .38909 L p .762 .805 .887 r
F P
0 g
s
.82329 .38909 m .8366 .38074 L .85986 .43317 L p .762 .805 .887 r
F P
0 g
s
.84593 .43898 m .83199 .44464 L .80999 .39727 L p .759 .804 .889 r
F P
0 g
s
.80999 .39727 m .82329 .38909 L .84593 .43898 L p .759 .804 .889 r
F P
0 g
s
.79668 .40494 m .80999 .39727 L .83199 .44464 L p .747 .8 .894 r
F P
0 g
s
.41526 .41492 m .42556 .42265 L .40281 .44434 L p .647 .679 .866 r
F P
0 g
s
.40281 .44434 m .39034 .4373 L .41526 .41492 L p .647 .679 .866 r
F P
0 g
s
.64037 .40478 m .62938 .4061 L .60092 .39305 L p .455 .729 .985 r
F P
0 g
s
.59297 .39705 m .60092 .39305 L .62938 .4061 L p .501 .749 .984 r
F P
0 g
s
.23513 .37315 m .24863 .37609 L .2222 .42171 L p .708 .826 .938 r
F P
0 g
s
.2222 .42171 m .20772 .42187 L .23513 .37315 L p .708 .826 .938 r
F P
0 g
s
.40489 .40702 m .41526 .41492 L .39034 .4373 L p .633 .675 .872 r
F P
0 g
s
.39034 .4373 m .37784 .43003 L .40489 .40702 L p .633 .675 .872 r
F P
0 g
s
.49821 .40766 m .50169 .41582 L .47717 .42815 L p .737 .774 .883 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49821 .40766 L p .737 .774 .883 r
F P
0 g
s
.70284 .42812 m .6895 .42726 L .6627 .40289 L p .435 .669 .961 r
F P
0 g
s
.65147 .40383 m .6627 .40289 L .6895 .42726 L p .413 .661 .962 r
F P
0 g
s
.52785 .40803 m .52826 .40004 L .55797 .3981 L p .704 .822 .938 r
F P
0 g
s
.52826 .40004 m .52785 .40803 L .50169 .41582 L p .732 .805 .91 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44599 .43731 L p .709 .732 .869 r
F P
0 g
s
.44599 .43731 m .4358 .43015 L .46294 .41262 L p .709 .732 .869 r
F P
0 g
s
.22154 .37026 m .23513 .37315 L .20772 .42187 L p .714 .827 .935 r
F P
0 g
s
.20772 .42187 m .19318 .42214 L .22154 .37026 L p .714 .827 .935 r
F P
0 g
s
.50169 .41582 m .49821 .40766 L .52826 .40004 L p .732 .805 .91 r
F P
0 g
s
.39446 .39908 m .40489 .40702 L .37784 .43003 L p .622 .675 .88 r
F P
0 g
s
.37784 .43003 m .36529 .42274 L .39446 .39908 L p .622 .675 .88 r
F P
0 g
s
.60092 .39305 m .59297 .39705 L .56228 .39171 L p .565 .797 .986 r
F P
0 g
s
.55797 .3981 m .56228 .39171 L .59297 .39705 L p .613 .809 .975 r
F P
0 g
s
.56228 .39171 m .55797 .3981 L .52826 .40004 L p .673 .822 .955 r
F P
0 g
s
.38396 .39118 m .39446 .39908 L .36529 .42274 L p .615 .68 .888 r
F P
0 g
s
.36529 .42274 m .35269 .41559 L .38396 .39118 L p .615 .68 .888 r
F P
0 g
s
.65147 .40383 m .64037 .40478 L .60896 .38967 L p .429 .714 .984 r
F P
0 g
s
.60092 .39305 m .60896 .38967 L .64037 .40478 L p .455 .729 .985 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .4358 .43015 L p .693 .724 .874 r
F P
0 g
s
.4358 .43015 m .42556 .42265 L .45573 .40475 L p .693 .724 .874 r
F P
0 g
s
.71624 .4283 m .70284 .42812 L .67401 .40158 L p .474 .685 .959 r
F P
0 g
s
.6627 .40289 m .67401 .40158 L .70284 .42812 L p .435 .669 .961 r
F P
0 g
s
.49469 .39977 m .49821 .40766 L .47008 .42042 L p .721 .77 .891 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49469 .39977 L p .721 .77 .891 r
F P
0 g
s
.37339 .38341 m .38396 .39118 L .35269 .41559 L p .612 .69 .898 r
F P
0 g
s
.35269 .41559 m .34003 .40877 L .37339 .38341 L p .612 .69 .898 r
F P
0 g
s
.52826 .40004 m .52867 .39262 L .56228 .39171 L p .673 .822 .955 r
F P
0 g
s
.52867 .39262 m .52826 .40004 L .49821 .40766 L p .712 .805 .923 r
F P
0 g
s
.49821 .40766 m .49469 .39977 L .52867 .39262 L p .712 .805 .923 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42556 .42265 L p .677 .718 .88 r
F P
0 g
s
.42556 .42265 m .41526 .41492 L .44846 .39682 L p .677 .718 .88 r
F P
0 g
s
.36273 .37584 m .37339 .38341 L .34003 .40877 L p .613 .704 .909 r
F P
0 g
s
.34003 .40877 m .32728 .4024 L .36273 .37584 L p .613 .704 .909 r
F P
0 g
s
.60896 .38967 m .60092 .39305 L .56664 .38603 L p .525 .783 .991 r
F P
0 g
s
.56228 .39171 m .56664 .38603 L .60092 .39305 L p .565 .797 .986 r
F P
0 g
s
.56664 .38603 m .56228 .39171 L .52867 .39262 L p .64 .818 .968 r
F P
0 g
s
.72968 .42749 m .71624 .4283 L .68541 .39959 L p .523 .705 .954 r
F P
0 g
s
.67401 .40158 m .68541 .39959 L .71624 .4283 L p .474 .685 .959 r
F P
0 g
s
.6627 .40289 m .65147 .40383 L .6171 .38659 L p .428 .708 .982 r
F P
0 g
s
.60896 .38967 m .6171 .38659 L .65147 .40383 L p .429 .714 .984 r
F P
0 g
s
.49114 .39208 m .49469 .39977 L .46294 .41262 L p .705 .766 .9 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49114 .39208 L p .705 .766 .9 r
F P
0 g
s
.35199 .36852 m .36273 .37584 L .32728 .4024 L p .618 .721 .92 r
F P
0 g
s
.32728 .4024 m .31445 .39659 L .35199 .36852 L p .618 .721 .92 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41526 .41492 L p .663 .714 .887 r
F P
0 g
s
.41526 .41492 m .40489 .40702 L .44112 .38881 L p .663 .714 .887 r
F P
0 g
s
.52867 .39262 m .52909 .38567 L .56664 .38603 L p .64 .818 .968 r
F P
0 g
s
.52909 .38567 m .52867 .39262 L .49469 .39977 L p .69 .803 .935 r
F P
0 g
s
.74312 .42551 m .72968 .42749 L .69687 .39662 L p .574 .724 .944 r
F P
0 g
s
.68541 .39959 m .69687 .39662 L .72968 .42749 L p .523 .705 .954 r
F P
0 g
s
.49469 .39977 m .49114 .39208 L .52909 .38567 L p .69 .803 .935 r
F P
0 g
s
.34115 .36148 m .35199 .36852 L .31445 .39659 L p .625 .74 .929 r
F P
0 g
s
.31445 .39659 m .30152 .39139 L .34115 .36148 L p .625 .74 .929 r
F P
0 g
s
.6171 .38659 m .60896 .38967 L .57106 .38081 L p .499 .769 .992 r
F P
0 g
s
.56664 .38603 m .57106 .38081 L .60896 .38967 L p .525 .783 .991 r
F P
0 g
s
.48754 .38451 m .49114 .39208 L .45573 .40475 L p .688 .761 .908 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48754 .38451 L p .688 .761 .908 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40489 .40702 L p .65 .713 .893 r
F P
0 g
s
.40489 .40702 m .39446 .39908 L .43372 .38074 L p .65 .713 .893 r
F P
0 g
s
.57106 .38081 m .56664 .38603 L .52909 .38567 L p .61 .81 .977 r
F P
0 g
s
.67401 .40158 m .6627 .40289 L .62534 .3835 L p .449 .711 .979 r
F P
0 g
s
.6171 .38659 m .62534 .3835 L .6627 .40289 L p .428 .708 .982 r
F P
0 g
s
.33021 .35473 m .34115 .36148 L .30152 .39139 L p .635 .759 .937 r
F P
0 g
s
.30152 .39139 m .28847 .3868 L .33021 .35473 L p .635 .759 .937 r
F P
0 g
s
.75656 .42222 m .74312 .42551 L .70836 .39248 L p .622 .74 .931 r
F P
0 g
s
.69687 .39662 m .70836 .39248 L .74312 .42551 L p .574 .724 .944 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39446 .39908 L p .64 .713 .901 r
F P
0 g
s
.39446 .39908 m .38396 .39118 L .42626 .3726 L p .64 .713 .901 r
F P
0 g
s
.52951 .37903 m .52909 .38567 L .49114 .39208 L p .669 .798 .944 r
F P
0 g
s
.49114 .39208 m .48754 .38451 L .52951 .37903 L p .669 .798 .944 r
F P
0 g
s
.31917 .34824 m .33021 .35473 L .28847 .3868 L p .646 .777 .943 r
F P
0 g
s
.28847 .3868 m .27531 .38279 L .31917 .34824 L p .646 .777 .943 r
F P
0 g
s
.52909 .38567 m .52951 .37903 L .57106 .38081 L p .61 .81 .977 r
F P
0 g
s
.76997 .41763 m .75656 .42222 L .71987 .38706 L p .664 .752 .916 r
F P
0 g
s
.70836 .39248 m .71987 .38706 L .75656 .42222 L p .622 .74 .931 r
F P
0 g
s
.48391 .37696 m .48754 .38451 L .44846 .39682 L p .672 .757 .914 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48391 .37696 L p .672 .757 .914 r
F P
0 g
s
.62534 .3835 m .6171 .38659 L .57554 .37582 L p .492 .759 .99 r
F P
0 g
s
.57106 .38081 m .57554 .37582 L .6171 .38659 L p .499 .769 .992 r
F P
0 g
s
.68541 .39959 m .67401 .40158 L .63367 .38005 L p .487 .719 .973 r
F P
0 g
s
.62534 .3835 m .63367 .38005 L .67401 .40158 L p .449 .711 .979 r
F P
0 g
s
.78335 .41181 m .76997 .41763 L .73138 .38033 L p .697 .761 .901 r
F P
0 g
s
.71987 .38706 m .73138 .38033 L .76997 .41763 L p .664 .752 .916 r
F P
0 g
s
.57554 .37582 m .57106 .38081 L .52951 .37903 L p .587 .8 .981 r
F P
0 g
s
.30803 .34196 m .31917 .34824 L .27531 .38279 L p .657 .792 .946 r
F P
0 g
s
.27531 .38279 m .26203 .37925 L .30803 .34196 L p .657 .792 .946 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38396 .39118 L p .632 .717 .908 r
F P
0 g
s
.38396 .39118 m .37339 .38341 L .41873 .36438 L p .632 .717 .908 r
F P
0 g
s
.79668 .40494 m .78335 .41181 L .74289 .37239 L p .722 .767 .888 r
F P
0 g
s
.73138 .38033 m .74289 .37239 L .78335 .41181 L p .697 .761 .901 r
F P
0 g
s
.52994 .3725 m .52951 .37903 L .48754 .38451 L p .65 .791 .95 r
F P
0 g
s
.48754 .38451 m .48391 .37696 L .52994 .3725 L p .65 .791 .95 r
F P
0 g
s
.48024 .36934 m .48391 .37696 L .44112 .38881 L p .657 .752 .92 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48024 .36934 L p .657 .752 .92 r
F P
0 g
s
.52951 .37903 m .52994 .3725 L .57554 .37582 L p .587 .8 .981 r
F P
0 g
s
.29678 .33584 m .30803 .34196 L .26203 .37925 L p .667 .802 .947 r
F P
0 g
s
.26203 .37925 m .24863 .37609 L .29678 .33584 L p .667 .802 .947 r
F P
0 g
s
.80999 .39727 m .79668 .40494 L .7544 .3634 L p .739 .771 .879 r
F P
0 g
s
.74289 .37239 m .7544 .3634 L .79668 .40494 L p .722 .767 .888 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37339 .38341 L p .627 .723 .916 r
F P
0 g
s
.37339 .38341 m .36273 .37584 L .41113 .35609 L p .627 .723 .916 r
F P
0 g
s
.69687 .39662 m .68541 .39959 L .64206 .37595 L p .534 .728 .963 r
F P
0 g
s
.63367 .38005 m .64206 .37595 L .68541 .39959 L p .487 .719 .973 r
F P
0 g
s
.82329 .38909 m .80999 .39727 L .76591 .35359 L p .749 .773 .873 r
F P
0 g
s
.7544 .3634 m .76591 .35359 L .80999 .39727 L p .739 .771 .879 r
F P
0 g
s
.63367 .38005 m .62534 .3835 L .58007 .37078 L p .503 .754 .985 r
F P
0 g
s
.57554 .37582 m .58007 .37078 L .62534 .3835 L p .492 .759 .99 r
F P
0 g
s
.8366 .38074 m .82329 .38909 L .77744 .34327 L p .752 .774 .871 r
F P
0 g
s
.76591 .35359 m .77744 .34327 L .82329 .38909 L p .749 .773 .873 r
F P
0 g
s
.58007 .37078 m .57554 .37582 L .52994 .3725 L p .574 .789 .98 r
F P
0 g
s
.28544 .3298 m .29678 .33584 L .24863 .37609 L p .676 .808 .946 r
F P
0 g
s
.24863 .37609 m .23513 .37315 L .28544 .3298 L p .676 .808 .946 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36273 .37584 L p .625 .731 .923 r
F P
0 g
s
.36273 .37584 m .35199 .36852 L .40346 .34772 L p .625 .731 .923 r
F P
0 g
s
.47653 .36153 m .48024 .36934 L .43372 .38074 L p .645 .748 .924 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47653 .36153 L p .645 .748 .924 r
F P
0 g
s
.77744 .34327 m .78901 .33274 L .8366 .38074 L p .752 .774 .871 r
F P
0 g
s
.53037 .36591 m .52994 .3725 L .48391 .37696 L p .634 .783 .953 r
F P
0 g
s
.48391 .37696 m .48024 .36934 L .53037 .36591 L p .634 .783 .953 r
F P
0 g
s
.70836 .39248 m .69687 .39662 L .65052 .37095 L p .58 .736 .949 r
F P
0 g
s
.64206 .37595 m .65052 .37095 L .69687 .39662 L p .534 .728 .963 r
F P
0 g
s
.52994 .3725 m .53037 .36591 L .58007 .37078 L p .574 .789 .98 r
F P
0 g
s
.27399 .32374 m .28544 .3298 L .23513 .37315 L p .682 .81 .944 r
F P
0 g
s
.23513 .37315 m .22154 .37026 L .27399 .32374 L p .682 .81 .944 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35199 .36852 L p .626 .74 .93 r
F P
0 g
s
.35199 .36852 m .34115 .36148 L .39573 .33928 L p .626 .74 .93 r
F P
0 g
s
.64206 .37595 m .63367 .38005 L .58465 .36542 L p .528 .751 .978 r
F P
0 g
s
.58007 .37078 m .58465 .36542 L .63367 .38005 L p .503 .754 .985 r
F P
0 g
s
.47278 .35347 m .47653 .36153 L .42626 .3726 L p .635 .745 .927 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47278 .35347 L p .635 .745 .927 r
F P
0 g
s
.58465 .36542 m .58007 .37078 L .53037 .36591 L p .571 .778 .976 r
F P
0 g
s
.71987 .38706 m .70836 .39248 L .65902 .36486 L p .623 .741 .931 r
F P
0 g
s
.65052 .37095 m .65902 .36486 L .70836 .39248 L p .58 .736 .949 r
F P
0 g
s
.53081 .35906 m .53037 .36591 L .48024 .36934 L p .623 .774 .953 r
F P
0 g
s
.48024 .36934 m .47653 .36153 L .53081 .35906 L p .623 .774 .953 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34115 .36148 L p .629 .75 .935 r
F P
0 g
s
.34115 .36148 m .33021 .35473 L .38792 .33076 L p .629 .75 .935 r
F P
0 g
s
.53037 .36591 m .53081 .35906 L .58465 .36542 L p .571 .778 .976 r
F P
0 g
s
.469 .34506 m .47278 .35347 L .41873 .36438 L p .629 .742 .929 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .469 .34506 L p .629 .742 .929 r
F P
0 g
s
.65052 .37095 m .64206 .37595 L .58928 .3595 L p .56 .748 .965 r
F P
0 g
s
.58465 .36542 m .58928 .3595 L .64206 .37595 L p .528 .751 .978 r
F P
0 g
s
.73138 .38033 m .71987 .38706 L .66755 .35759 L p .658 .744 .913 r
F P
0 g
s
.65902 .36486 m .66755 .35759 L .71987 .38706 L p .623 .741 .931 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33021 .35473 L p .634 .76 .939 r
F P
0 g
s
.33021 .35473 m .31917 .34824 L .38005 .32217 L p .634 .76 .939 r
F P
0 g
s
.58928 .3595 m .58465 .36542 L .53081 .35906 L p .578 .768 .969 r
F P
0 g
s
.53125 .35177 m .53081 .35906 L .47653 .36153 L p .618 .765 .95 r
F P
0 g
s
.47653 .36153 m .47278 .35347 L .53125 .35177 L p .618 .765 .95 r
F P
0 g
s
.74289 .37239 m .73138 .38033 L .67611 .34911 L p .686 .745 .896 r
F P
0 g
s
.66755 .35759 m .67611 .34911 L .73138 .38033 L p .658 .744 .913 r
F P
0 g
s
.46518 .33625 m .469 .34506 L .41113 .35609 L p .626 .741 .93 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46518 .33625 L p .626 .741 .93 r
F P
0 g
s
.53081 .35906 m .53125 .35177 L .58928 .3595 L p .578 .768 .969 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31917 .34824 L p .64 .768 .941 r
F P
0 g
s
.31917 .34824 m .30803 .34196 L .3721 .3135 L p .64 .768 .941 r
F P
0 g
s
.65902 .36486 m .65052 .37095 L .59395 .35281 L p .593 .745 .949 r
F P
0 g
s
.58928 .3595 m .59395 .35281 L .65052 .37095 L p .56 .748 .965 r
F P
0 g
s
.7544 .3634 m .74289 .37239 L .68469 .3395 L p .707 .745 .882 r
F P
0 g
s
.67611 .34911 m .68469 .3395 L .74289 .37239 L p .686 .745 .896 r
F P
0 g
s
.53169 .3439 m .53125 .35177 L .47278 .35347 L p .617 .756 .945 r
F P
0 g
s
.47278 .35347 m .469 .34506 L .53169 .3439 L p .617 .756 .945 r
F P
0 g
s
.59395 .35281 m .58928 .3595 L .53125 .35177 L p .591 .759 .958 r
F P
0 g
s
.46133 .32702 m .46518 .33625 L .40346 .34772 L p .626 .741 .93 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46133 .32702 L p .626 .741 .93 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30803 .34196 L p .647 .775 .941 r
F P
0 g
s
.30803 .34196 m .29678 .33584 L .36408 .30475 L p .647 .775 .941 r
F P
0 g
s
.76591 .35359 m .7544 .3634 L .69328 .32891 L p .721 .745 .871 r
F P
0 g
s
.68469 .3395 m .69328 .32891 L .7544 .3634 L p .707 .745 .882 r
F P
0 g
s
.53125 .35177 m .53169 .3439 L .59395 .35281 L p .591 .759 .958 r
F P
0 g
s
.66755 .35759 m .65902 .36486 L .59865 .34519 L p .624 .741 .931 r
F P
0 g
s
.59395 .35281 m .59865 .34519 L .65902 .36486 L p .593 .745 .949 r
F P
0 g
s
.77744 .34327 m .76591 .35359 L .7019 .31756 L p .729 .746 .865 r
F P
0 g
s
.69328 .32891 m .7019 .31756 L .76591 .35359 L p .721 .745 .871 r
F P
0 g
s
.53214 .33535 m .53169 .3439 L .469 .34506 L p .62 .748 .938 r
F P
0 g
s
.469 .34506 m .46518 .33625 L .53214 .33535 L p .62 .748 .938 r
F P
0 g
s
.45745 .31735 m .46133 .32702 L .39573 .33928 L p .628 .742 .929 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45745 .31735 L p .628 .742 .929 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29678 .33584 L p .654 .779 .94 r
F P
0 g
s
.29678 .33584 m .28544 .3298 L .35599 .29592 L p .654 .779 .94 r
F P
0 g
s
.59865 .34519 m .59395 .35281 L .53169 .3439 L p .608 .75 .945 r
F P
0 g
s
.78901 .33274 m .77744 .34327 L .71056 .3057 L p .733 .747 .864 r
F P
0 g
s
.7019 .31756 m .71056 .3057 L .77744 .34327 L p .729 .746 .865 r
F P
0 g
s
.67611 .34911 m .66755 .35759 L .60338 .33657 L p .65 .737 .913 r
F P
0 g
s
.59865 .34519 m .60338 .33657 L .66755 .35759 L p .624 .741 .931 r
F P
0 g
s
.53169 .3439 m .53214 .33535 L .59865 .34519 L p .608 .75 .945 r
F P
0 g
s
.71056 .3057 m .71927 .29362 L .78901 .33274 L p .733 .747 .864 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28544 .3298 L p .66 .781 .938 r
F P
0 g
s
.28544 .3298 m .27399 .32374 L .34782 .287 L p .66 .781 .938 r
F P
0 g
s
.45353 .30727 m .45745 .31735 L .38792 .33076 L p .632 .743 .928 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45353 .30727 L p .632 .743 .928 r
F P
0 g
s
.5326 .32604 m .53214 .33535 L .46518 .33625 L p .625 .742 .931 r
F P
0 g
s
.46518 .33625 m .46133 .32702 L .5326 .32604 L p .625 .742 .931 r
F P
0 g
s
.60338 .33657 m .59865 .34519 L .53214 .33535 L p .625 .742 .931 r
F P
0 g
s
.68469 .3395 m .67611 .34911 L .60813 .32693 L p .671 .733 .897 r
F P
0 g
s
.60338 .33657 m .60813 .32693 L .67611 .34911 L p .65 .737 .913 r
F P
0 g
s
.53214 .33535 m .5326 .32604 L .60338 .33657 L p .625 .742 .931 r
F P
0 g
s
.44959 .29682 m .45353 .30727 L .38005 .32217 L p .638 .745 .926 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44959 .29682 L p .638 .745 .926 r
F P
0 g
s
.53305 .31599 m .5326 .32604 L .46133 .32702 L p .632 .736 .923 r
F P
0 g
s
.46133 .32702 m .45745 .31735 L .53305 .31599 L p .632 .736 .923 r
F P
0 g
s
.69328 .32891 m .68469 .3395 L .61291 .31633 L p .687 .73 .883 r
F P
0 g
s
.60813 .32693 m .61291 .31633 L .68469 .3395 L p .671 .733 .897 r
F P
0 g
s
.60813 .32693 m .60338 .33657 L .5326 .32604 L p .64 .734 .917 r
F P
0 g
s
.44561 .28606 m .44959 .29682 L .3721 .3135 L p .644 .747 .924 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44561 .28606 L p .644 .747 .924 r
F P
0 g
s
.5326 .32604 m .53305 .31599 L .60813 .32693 L p .64 .734 .917 r
F P
0 g
s
.7019 .31756 m .69328 .32891 L .6177 .30488 L p .698 .728 .874 r
F P
0 g
s
.61291 .31633 m .6177 .30488 L .69328 .32891 L p .687 .73 .883 r
F P
0 g
s
.53351 .30521 m .53305 .31599 L .45745 .31735 L p .64 .732 .915 r
F P
0 g
s
.45745 .31735 m .45353 .30727 L .53351 .30521 L p .64 .732 .915 r
F P
0 g
s
.61291 .31633 m .60813 .32693 L .53305 .31599 L p .654 .729 .904 r
F P
0 g
s
.71056 .3057 m .7019 .31756 L .62253 .29278 L p .706 .728 .868 r
F P
0 g
s
.6177 .30488 m .62253 .29278 L .7019 .31756 L p .698 .728 .874 r
F P
0 g
s
.4416 .27506 m .44561 .28606 L .36408 .30475 L p .65 .749 .922 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .4416 .27506 L p .65 .749 .922 r
F P
0 g
s
.53305 .31599 m .53351 .30521 L .61291 .31633 L p .654 .729 .904 r
F P
0 g
s
.53398 .2938 m .53351 .30521 L .45353 .30727 L p .648 .73 .909 r
F P
0 g
s
.45353 .30727 m .44959 .29682 L .53398 .2938 L p .648 .73 .909 r
F P
0 g
s
.6177 .30488 m .61291 .31633 L .53351 .30521 L p .666 .724 .893 r
F P
0 g
s
.71927 .29362 m .71056 .3057 L .62738 .28022 L p .709 .73 .866 r
F P
0 g
s
.62253 .29278 m .62738 .28022 L .71056 .3057 L p .706 .728 .868 r
F P
0 g
s
.43754 .26392 m .4416 .27506 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53351 .30521 m .53398 .2938 L .6177 .30488 L p .666 .724 .893 r
F P
0 g
s
.62738 .28022 m .63227 .26744 L .71927 .29362 L p .709 .73 .866 r
F P
0 g
s
.53444 .28189 m .53398 .2938 L .44959 .29682 L p .655 .729 .903 r
F P
0 g
s
.44959 .29682 m .44561 .28606 L .53444 .28189 L p .655 .729 .903 r
F P
0 g
s
.62253 .29278 m .6177 .30488 L .53398 .2938 L p .675 .722 .885 r
F P
0 g
s
.53398 .2938 m .53444 .28189 L .62253 .29278 L p .675 .722 .885 r
F P
0 g
s
.62738 .28022 m .62253 .29278 L .53444 .28189 L p .682 .722 .88 r
F P
0 g
s
.53491 .26961 m .53444 .28189 L .44561 .28606 L p .661 .729 .9 r
F P
0 g
s
.44561 .28606 m .4416 .27506 L .53491 .26961 L p .661 .729 .9 r
F P
0 g
s
.63227 .26744 m .62738 .28022 L .53491 .26961 L p .686 .724 .879 r
F P
0 g
s
.53444 .28189 m .53491 .26961 L .62738 .28022 L p .682 .722 .88 r
F P
0 g
s
.53539 .25714 m .53491 .26961 L .4416 .27506 L p .666 .731 .898 r
F P
0 g
s
.4416 .27506 m .43754 .26392 L .53539 .25714 L p .666 .731 .898 r
F P
0 g
s
.53491 .26961 m .53539 .25714 L .63227 .26744 L p .686 .724 .879 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?nZ^nD00ol0003o[kWQojnih@04ojnih@_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00006OnZ^nD00ol0003o
[kWQojnih@0?ojnih@_o00006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oo
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`Co00000_nW`>/00ol0003oZ[_UojZki@0NojZki@03o`000?n_^N7o[kWQ01[o[kWQ
1ol0000Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0ol0
0007ojO0j`03o`000?nZ^nGoZ[_U01GoZ[_U2Ol0000Pojnih@03o`000?ne^]go]K[M00?o00004Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`Co00002_nW`>/0
0ol0003oZ[_UojZki@06ojZki@oo00002?nY^^H00ol0003o[[SQojjhh@03ojjhh@_o00003on_^N40
0ol0003o]K[MokFjg@04okFjg@?o00003_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Vooooo`Co00003OnW`>/3o`0000;oZ[_U1Ol0000GojVjiP03o`000?n^^>7o[[SQ
00ko[[SQ2_l00005ojnih@03o`000?ne^]go]K[M00Oo]K[M0ol0000;ooooo`03o`000?oooooooooo
03?ooooo0_l0000^ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o00002_ooool00ol0003o
ooooooooo`1Qooooo`Co00003OnW`>/4o`0000;oY[o/00?o0000ojVji_nY^^H07?nY^^H00ol0003o
[[SQojjhh@0Hojjhh@Go00003One^]d4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
0ol0000=ojO0j`Co00001onV_n`00ol0003oZK[VojVjiP0<ojVjiQ3o00007_n^^>401?l0003o];[N
okBjg_l0000>okFjg@?o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_o
oooo000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool4o`0000_oYl3[
1Ol00009ojJok0?o00000_nY^^H<o`0000ooYk[W00?o0000ojbhh_n/^>800_n/^>87o`0001;o[[SQ
00?o0000okBjg_nd^]h01?nd^]h3o`0000co]K[M0ol00002ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0:_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1Dooooo`?o00002onW`>/4o`0000[oY[o/1?l00002ojBok003o`000?nW^^OoYk[W01_oYk[W00?o
0000ojbhh_n/^>802On/^>87o`0000_o[[SQ00?o0000okBjg_nd^]h01ond^]h3o`0000co]K[M0ol0
000gooooo`03o`000?oooooooooo02[ooooo000Tooooo`;o00003_ooool00ol0003oooooooooo`1A
ooooo`;o00000_nXao000ol0003oYl3[ojO0j`05ojO0j`Co00002_nV_n`4o`0000KoY;o/00?o0000
ojNjionW^^L06onW^^L00ol0003o[;SRojbhhP0@ojbhhPOo00001?n^^>400ol0003o];[NokBjgP0:
okBjgP?o00002one^]d4o`0003Gooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@oooo
o`03o`000?oooooooooo04kooooo0_l00005ojS7l003o`000?nW`>_oYl3[00;oYl3[0_l0000:ojJo
k0Co00002onT_n`00ol0003oYk[WojNji`0<ojNji`oo00006On/^>84o`00013o];[N0ol00008okFj
g@04o`000?ne^]go]K[MokFjg@?o0000<oooool00ol0003oooooooooo`0Xooooo`009?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04_ooooo0_l00007ojS7l0?o00002onV_n`3o`00
00goY;o/0ol00002ojNji`co00003_nU^^P00ol0003oZ[WTojZii002ojZii0Oo00004On/^>800ol0
003o/[[Ook:jg`02o`0000oo];[N0ol00005okFjg@03o`000?ne^]go]K[M00;o]K[M00Co0000ok^o
gOl0003o0000<?ooool2o`0002[ooooo000Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool2o`0000OoZ<O`0_l00002ojO7l003o`000?nV_ncoY[o/00GoY[o/1?l0000;ojBo
k0Go00000_nS_^d00ol0003oYK[XojFjj00JojFjj003o`000?nZ^NCoZ[WT00WoZ[WT1ol0000:ojbh
hP03o`000?nb^]oo/[[O00?o/[[O0ol0000>okBjgP?o00000_ne^]d01Ol0003o]K[MokFjgOne^]go
000000Co^koM0_l0000`ooooo`03o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0AOooool2o`0000OoZ<O`0_l00005ojO7l003o`000?nV_ncoY[o/
00;oY[o/0_l0000;ojBok0Co00002?nS_^d00ol0003oYK[XojFjj00IojFjj003o`000?nZ^NCoZ[WT
013oZ[WT1ol00002ojbhhP03o`000?nb^]oo/[[O00Oo/[[O1?l0000=okBjgP?o00000_ne^]d00ol0
003o^koMok^og@05ok^og@03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool002?o
oooo0_l0000Dooooo`03o`000?oooooooooo047ooooo0ol00006ojS7l0?o00001onWao03o`0000_o
Y;o/1?l0000;oj>nk@?o00000_nU^^PIo`0001WoZ[WT0ol0000=ok:jg`?o00002?nd^]h3o`000004
okBjg_l0003o0000o`0000Wo^koM0_l0000^ooooo`03o`000?oooooooooo02Kooooo000Sooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool2o`0000OoZ<O`0_l00008ojO7l0;o
000000?oYLK`o`000?nT_n`01_nT_n`5o`0000[oXkk]1Ol00002oj6nk@03o`000?nS^n[oXk_Z01So
Xk_Z00?o0000ojNjionW^^L00_nW^^L9o`0000koZ[WT00?o0000ojnjh_n_^^800_l0000<ok:jg`Co
000000Co];[No`000?l0003o00001Ond^]h2o`000003okZngOl0003o^koM00So^koM0_l0000]oooo
o`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0>oooool2o`0000OoZ<O`0_l00007ojO7l0?o00001?nUa_000ol0003oY;o/ojBok002ojBok0;o
00002_nS_^d5o`0000OoXKk]00?o0000oj>kj_nS^nX05onS^nX00ol0003oYk[WojNji`0<ojNji`Wo
00001?nZ^N@00ol0003o[k[RojnjhP04ojnjhP?o00002_nb^]l5o`0000Ko];[N0_l00003okZng@03
o`000?nk_mgo^koM00Oo^koM0_l0000[ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool2o`0000OoZ<O`0_l00007ojO7l0;o0000
1onUa_03o`0000WoXkk]1Ol0000=oj6nk@03o`000?nS^n[oXk_Z00[oXk_Z3Ol0000GojNji`Co0000
2_n_^^83o`0000Co/[[O0ol00005ok:jg`?o00000_nd^]h01?l0003o^[kMokZngOl00003okZng@;o
00002Onk_md2o`0002Wooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`008_ooool3o`0001Sooooo00?o0000oooo
ooooool0=Oooool2o`0000OoZ<O`0_l00007ojO7l0;o00001_nUa_03o`0000?oXlC`00?o0000oj>n
kOnS_^d00_nS_^d4o`0000ooXKk]1?l00002oj>kjP[o00003?nQ_>`01?l0003oXk_Zoj>kj_nS^nX7
o`00013oYk[W00Co0000oj^kiOn[^nGo00002_n_^^84o`0000_o/[[O0_l00003okZng@03o`000?nj
_]go^[kM00?o^[kM0_l00009ok^og@;o0000:Oooool00ol0003oooooooooo`05ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01oooool002;ooooo00?o
0000ooooooooool06Oooool2o`0003?ooooo0_l00006ojS7l0?o00001_nWao03o`0000KoYLK`0_l0
0006oj?4l0Co00003_nQ_^d6o`0000?oX;g]00?o0000oj6lk?nQ_>`05_nQ_>`00ol0003oXk_Zoj>k
jP08oj>kjPKo00002_nW^^L00ol0003oZk_Uoj^ki@03oj^ki@?o00000on_^^83o`0000;o[k[R0ol0
000:ok:jg`03o`000?nh_]ko^[kM00;o^[kM00?o0000okZngOnj_]d01?nj_]d2o`0000Wo^koM0_l0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_oo
ool3o`0000KoZ<O`00?o0000ojO7l?nWao001OnWao02o`0000OoYLK`0_l00005oj?4l0?o00000_nR
`_000ol0003oXKk]oj6nk@08oj6nk@Go00002_nP_Nd00ol0003oXKc/oj6lk00Eoj6lk003o`000?nS
^n[oXk_Z00koXk_Z1ol00002ojNji`03o`000?n[^nGoZk_U00OoZk_U0ol00008ojnjhP?o00001_nb
^]l00ol0003o^;kNokRngP02okRngP03o`000?nj_]go000000Oo^[kM0_l00009ok^og@03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0/ooooo`04o`000?n^co7o[/oaojk?l@;o00000_nXao000ol0003oYlO`ojO7l005ojO7
l0;o00001_nUa_03o`0000GoXlC`0_l00006oj;2l003o`000?nQ_^goXKk]00;oXKk]1Ol0000<oj2m
k@Co00000_nQ_>`Fo`0001OoXk_Z0ol00006oj^ki@?o00000on[^nD3o`0000So[k[R0ol00002ok:j
g`03o`000?nh_]ko^;kN00Go^;kN0_l00008okZng@03o`000?nk_mgo^koM00Oo^koM0_l0000Voooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_oo
ool00ol0003o[/oaojk?l@03ojk?l@?o00001_nWao02o`0000KoYLK`0_l00006oj?4l0;o00002?nR
`_04o`0000goX;g]1Ol00003oj2mkP03o`000?nO_NkoWkg^01GoWkg^00?o0000oinmk_nO_Nh00_nO
_Nh8o`0000goXk_Z00?o0000ojJljOnV_>T01?l00009oj^ki@?o00002?n_^^82o`0000Wo^;kN0_l0
0008okZng@;o00002Onk_md2o`0002Cooooo00?o0000ooooooooool00oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool02_ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Sooooo00?o0000ojk?lOn^co400on^co401?l0003o[Lkbojg>l_n]c_82o`0000;o
YlO`00?o0000ojG6l?nUa_001OnUa_02o`0000GoXlC`0ol00007oj;2l0?o000000?oXKo_o`000?nP
_Nd02?nP_Nd6o`0000WoX;g^00?o0000oinmk_nO_Nh05?nO_Nh00ol0003oWkg^oinmkP0:oinmkPSo
00001?nS^nX00ol0003oY[cYo`000002o`0000;oY[cY0ol0000:oj^ki@?o00001On_^^801?l0003o
];kQokBnhOl00008okRngP?o00002?nj_]d2o`0000Wo^koM00?o0000ooooooooool08?ooool3o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o00008Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_800on]c_83
o`0000KoYLK`0_l00005oj?4l0;o00002?nR`_02o`0000GoXKo_00?o0000oj2mkOnP_Nd00onP_Nd3
o`0000goX;g^1?l00003oinmkQ?o00005?nO_Nh6o`0000SoY[cY1?l00009oj^ki@?o000000?o[k[R
o`000?nd_^401?nd_^42o`0000Ko^;kN00Co0000okRng_l0003o00002?nj_]d2o`0000Ko^koM00?o
0000ol36g_l000009?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00002Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000
ojk?lOn^co400on^co400ol0003o[Lkbojg>lP03ojg>lP04o`000?nZcO;oZ/gboj[=lP;o00000_nU
a_000ol0003oXlC`oj?4l004oj?4l0;o00001onR`_03o`0000OoXKo_0_l000000onP_Ngo0000oj2m
kP0<oj2mkPGo00000onP_Nh00ol0003oW[o`oijol00Coijol003o`000?nK_o7oVkoa00;oVkoa1ol0
0009oinmkPCo00000_nO_Nh00ol0003oY[cYojJlj@09ojJlj@?o00002On[^nD00ol0003o];kQokBn
h@06okBnh@;o00001Onh_]h00ol0003o^;kNokRngP02o`0000So^[kM00?o0000ok^ogOnk_md00_nk
_md01Ol0003o`<KNol36g_o0a]ko000002?ooooo00?o0000ooooooooool07oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Rooooo`03o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_80
0on]c_800ol0003oZ/gboj[=lP03oj[=lP?o00001OnSa?02o`0000OoX/;`0_l00008oj6ok`;o0000
0_nP_Nh00ol0003oX;g^oj2mkP07oj2mkPGo00002OnP_Nh00ol0003oW[o`oijol00Boijol003o`00
0?nK_o7oVkoa00WoVkoa2Ol00002oinmkP03o`000?nO_NkoWkg^00CoWkg^0ol00009ojJlj@?o0000
1_n[^nD00ol0003o[kkUo`000008okBnh@;o00000onh_]h00ol0003o^;kNokRngP02okRngP;o0000
1onj_]d2o`000003ok^ogOl0003o`<KN00Co`<KN00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ojk?lOn^co40
0on^co400ol0003o[Lkbojg>lP03ojg>lP03o`000?nZcO;oZ/gb00?oZ/gb00Go0000ojS:l_nXb_;o
Z<[bo`000002oj?4l003o`000?nR`_3oX/;`00GoX/;`0ol00007oj6ok`?o00001OnP_Nh00ol0003o
X;g^oj2mkP02oj2mkPCo00003?nP_Nh3o`0000?oW[o`4_l0000?oi^ol@;o000000?oVkoao`000?l0
00000_l0000:oinmkP?o00002OnV_>T3o`0000;oZk_U00?o0000ojnniOn__^D00_n__^D2o`0000Oo
];kQ0_l00002okRngP03o`000?nh_]ko^;kN00?o^;kN00?o0000okZngOnj_]d01Onj_]d2o`0000Oo
`<KN00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o00009Oooool00ol0003oooooooooo`0Nooooo`03
o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_800on]c_800ol0003oZ/gboj[=lP03oj[=lP03
o`000?nXb_;oZ<[b00;oZ<[b0ol00006oj;2l0;o00002?nQ_nl2o`0000SoX;g^1?l0000<oj2mkPGo
00000_nQ_Nd00ol0003oWL7aoig1l@0Boig1l@03o`000?nG`_GoUl;e00;oUl;e1ol000001?nK_o7o
0000o`000?l00006oi^ol@04o`000?nG__;oUkkbo`0000[oWkg^0ol00009ojJlj@;o00001on__^D0
0ol0003o];kQokBnh@06okBnh@04o`000?nh_]ko^;kNo`0000Go^;kN0_l00004okZng@04o`000?no
aMoo_lGOo`0000Oo`<KN00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`008?oo
ool2o`0002Oooooo00?o0000ooooooooool07?ooool00ol0003o[/oaojk?l@02ojk?l@;o00001On]
c_800ol0003oZ/gboj[=lP03oj[=lP03o`000?nXb_;oZ<[b00;oZ<[b00Co0000ojG6lOnUa_7oYLKa
0_l00002oj;2l0;o00002?nQ_nl2o`0000OoX;g^0ol000000onO^nco0000oj2mkP08oj2mkPGo0000
2?nQ_Nd00ol0003oWL7aoig1l@07oig1l@_o00002OnG`_D9o`0000;oVkoa00?o0000oiNnl_nG__80
1?nG__83o`0000SoWkg^0ol00006ojJlj@03o`000?nX_^WoZ;kY00Oo[kkU0_l00007okBnh@?o0000
1onh_]h2o`000003okZngOl0003o_lGO00?o_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003ooooo
ooooo`0Oooooo`;o00007_ooool0027ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?n^co7o[/oa00;o[/oa00?o0000ojg>l_n]c_801?n]c_800ol0003oZ/gboj[=
lP02oj[=lP;o00001?nXb_800ol0003oYLKaojG6l@03ojG6l@?o00002?nQ_nl2o`0000OoX;g^0_l0
0005oinkk003o`000?nP_NkoX;g^00;oX;g^1?l0000;oj6mk@?o00000_nM`O47o`0000[oW/?c00Co
0000oi?4n?nCa?SoTlCh1ol00008oiO2m@?o00002OnG__83o`0000SoWkg^0ol00002ojJlj@03o`00
0?nX_^WoZ;kY00;oZ;kY0_l00006ojnni@;o00001ond_^42o`0000So^;kN00?o0000oko5gonoaMl0
1?noaMl00ol0003o`<KNol36gP05ol36gP03o`000?oooooooooo023ooooo00?o0000ooooooooool0
6oooool0023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?n^
co7o[/oa00;o[/oa00?o0000ojg>l_n]c_800on]c_82o`0000CoZ/gb00?o0000ojS:l_nXb_800onX
b_800ol0003oYLKaojG6l@03ojG6l@05o`000?nR`^ooX/;_oj;2kol000001OnQ_nl2o`0000KoX;g^
0ol00007oinkk0Co00002onQ_Nd5o`0000;oX[k]00?o0000oik3lonN`o<04OnN`o<01?l0003oTlCh
oi?4n?nCa?P3o`0000CoTlCh1_l00003oiO2m@05o`000?n?_oOoSkogohnomol000002OnG__83o`00
00SoWkg^0_l00007ojRnj@;o00001_n__^D2o`0000Oo];kQ0_l00004okRngP04o`000?nmaN7o_LGQ
o`0000Ko_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01_ooooo000Pooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0
003o[/oaojk?l@02ojk?l@03o`000?n]c_;o[Lkb00?o[Lkb00?o0000oj[=l_nZcO800onZcO800ol0
003oZ<[bojS:lP03ojS:lP03o`000?nUa_7oYLKa00?oYLKa00?o0000oj;2konR`^l00onR`^l01?l0
003oXKo_oj6okol00006oj2mkP?o00001onO^n`3o`0000;oX;WZ00?o0000oj6mkOnQ_Nd01_nQ_Nd4
o`0000SoX[k]00?o0000oik3lonN`o<01onN`o<=o`0000goTlCh0ol00007ohnom`?o00001onG__83
o`0000GoWkg^00?o0000oinmk_nO_Nh02?nX_^T00ol0003o[kkUojnni@05ojnni@;o00001_nd_^43
o`000003okRng_l0003o_LGQ00?o_LGQ00?o0000oko5gonoaMl01?noaMl00ol0003o`<KNol36gP05
ol36gP03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool0023ooooo0_l0000[oooo
o`03o`000?oooooooooo01Cooooo00?o0000ojk?lOn^co400_n^co400ol0003o[Lkbojg>lP03ojg>
lP03o`000?nZcO;oZ/gb00?oZ/gb00?o0000ojS:l_nXb_800onXb_800ol0003oYLKaojG6l@03ojG6
l@03o`000?nR`^ooX/;_00CoX/;_0ol00005oj2mkP;o00001onO^n`3o`0000KoX;WZ00?o0000oj6m
kOnQ_Nd00_nQ_Nd3o`0000WoX[k]1?l000000onN`o?o0000o`000006o`0000OoWlKc0ol00005oi;7
n@Wo00001?nCa?P01?l0003oQl3johO0n_l00007ohnom`?o00001onG__83o`000003oinmk_l0003o
Wkg^00CoWkg^00?o0000ojRnjOnX_^T01?nX_^T2o`0000Oo[kkU00?o0000okBnhOnd_^400ond_^40
1?l0003o];kQo`000?l00006okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000ol36g_o0a]h01Oo0
a]h00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool04_ooool00ol0003o[/oaojk?l@02ojk?l@03o`000?n]c_;o
[Lkb00?o[Lkb00?o0000oj[=l_nZcO800onZcO800ol0003oZ<[bojS:lP02ojS:lP;o00001?nUa_42
o`0000KoX/;_00Go0000oinmkOnO_NgoWkg]o`000002oj2mkP;o00001onO^n`2o`0000WoX;WZ0ol0
0008oj:nk@Ko00001?nU_n`00ol0003oWlKcoio6l`06oio6l`Wo00003onBaoT4o`0000KoQl3j0ol0
0005ohnom`?o00001onG__800ol0003oWkg^oinmkP05oinmkP;o00001_nX_^T2o`0000Ko[kkU0_l0
0004okBnh@04o`000?nha>?o^<CSo`0000Ko_LGQ00?o0000oko5gonoaMl01?noaMl00ol0003o`<KN
ol36gP05ol36gP03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool0023ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?n^co7o[/oa00?o[/oa1On]
c_800ol0003oZ/gboj[=lP02oj[=lP;o00001?nXb_800ol0003oYLKaojG6l@03ojG6l@03o`000?nR
`^ooX/;_00CoX/;_0_l00004oinmk@?o00001_nO^n`3o`0000SoX;WZ0ol00002oj6gj003o`000?nR
_^goX[k]00;oX[k]1?l00009ojFok0?o00000_nOa_<5o`000004oj;8lol0003o0000o`0000CoX/Sc
00?o0000oi;9n_nBbOX00_nBbOX9o`0000CoT/Oi00Co0000oh31o?n0`OcoP<7l1on7`?X3o`0000Go
Skog0ol00002oiNnlP04o`000?nD_?;oU;cboiBllPSoWkg^0_l00006ojRnj@03o`000?n__^Go[kkU
00Go[kkU0_l000001?nd_^7o0000okS4hol00002okS4h`03o`000?nmaN7o_LGQ00Co_LGQ00?o0000
oko5gonoaMl01?noaMl00ol0003o`<KNol36gP05ol36gP03o`000?oooooooooo01gooooo0_l0000J
ooooo`008?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo0ol00003ojk?
l@Ko[Lkb1OnZcO85ojS:lP03o`000?nUa_7oYLKa00?oYLKa00?o0000oj;2konR`^l01?nR`^l00ol0
003oWkg]oinmk@03oinmk@04o`000?nN^>_oW[S[oijhj`;o00000_nO^n`2o`0000WoX;WZ0_l00005
oj6gj0Co00002_nU_n`4o`0000;oZ<3[00?o0000oj;8lonRb?<00onRb?<3o`0000?oX/Sc1Ol0000=
oi;9nPCo00001on0`O`2o`0000GoQl3j0ol00005ohnom`;o00001_nD_?800ol0003oWkg^oinmkP05
oinmkP03o`000?nX_^WoZ;kY00CoZ;kY0_l00006ojnni@;o00000onha><01?l0003o^<CSokS4hol0
0006okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo000Oooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03Oooool00ol0003o]]?_okKCk`05o`0000?o[Lkb1OnZcO86ojS:lPCoYLKa0_l00006
oj;2k`03o`000?nO_NgoWkg]00?oWkg]00?o0000oijhjonN^>/00onN^>/3o`0000SoX;WZ0ol00005
oj6gj0;o00000_nS]^H00ol0003oYKo/ojFok005ojFok0Co00001onX`>/00ol0003oX/Sco`000002
o`000003oj;8lol0003o000000?o00001?nVb_<00ol0003oU/ckoiK<n`06oiK<n`So00000omm`_d0
0ol0003oP<7loh31o005oh31o0?o00001?n7`?X3o`000003ohnomol0003oR;[f00;oR;[f1_nD_?82
o`0000KoWkg^0_l00006ojRnj@;o00000on__^D01?l0003o//;Vok;2i_l00002okS4h`05o`000?nh
a>?o^<CSokS4hol000001_nmaN400ol0003o_lGOoko5g`04oko5g`03o`000?o0a]ko`<KN00Go`<KN
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`007oooool2o`00037ooooo00?o
0000ooooooooool02oooool00ol0003o]]?_okKCk`02okKCk`04o`000?nedo3o]M?`okGCl0Co0000
0onZcO86ojS:lPCoYLKa00?o0000oj;2konR`^l01?nR`^l2o`0000CoWkg]0_l00005oijhj`05o`00
0?nL]>SoW;CXoibdj?l000001OnP^NX2o`0000KoXKOX0_l00005oj>fiP04o`000?nU_ncoYKo/ojFo
k0?o00002OnX`>/6o`0000_oY/[c00?o0000oiK<nonFc?/03?nFc?/01Ol0003oOlCmogo4oOmoa?go
000000CoOL;m0ol00004oh31o0?o00001?n7`?X00ol0003oR;[fohRjmP04ohRjmP03o`000?nD_?;o
U;cb00?oU;cb0_l00006oinmkP;o00001_nX_^T00ol0003o[kkUo`000004ok;2iP04o`000?nha>?o
^<CSo`0000?o^<CS00?o0000okg5hOnmaN401?nmaN400ol0003o_lGOoko5g`04oko5g`03o`000?o0
a]ko`<KN00Go`<KN00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`007oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo00Go0000okKCkonfdnoo]]?_o`00
0005okGCl003o`000?nbdO3o/]7`00Go00000onXb_85ojG6l@KoX/;_00?o0000oinmkOnO_Nd00onO
_Nd00ol0003oW[S[oijhj`04oijhj`03o`000?nL]>SoW;CX00?oW;CX00?o0000oj2ij_nP^NX00_l0
0006oj6gj0;o00001onS]^H3o`0000WoZ<3[1Ol000000on/`NWo0000ojK:l`06ojK:l`So00000onF
c?/;o`0000OoOlCm0ol00002ogg2o@Co00000on0`O`3o`0000?oO;Si00?o0000ohRjm_n8^_H01?n8
^_H2o`0000CoU;cb0_l00006oinmkP03o`000?nX_^WoZ;kY00?oZ;kY0_l00006ok;2iP04o`000?nh
a>?o^<CSo`0000?o^<CS00?o0000okg5hOnmaN401?nmaN400ol0003o_lGOoko5g`04oko5g`03o`00
0?o0a]ko`<KN00Co`<KN0_l0000Nooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003o]]?_okKCk`02okKCk`03o`000?ne
do3o]M?`00;o]M?`00?o0000ok;Al?nbdO000_nbdO001?l0003o[/k`ojk>l?n^c_04o`0000?oYLKa
1OnR`^l2o`0000GoWkg]00?o0000oijhjonN^>/00onN^>/2o`0000KoW;CX0_l00007oj6gj0;o0000
1onS]^H2o`000003ojJfi?l0003oZ<3[00KoZ<3[1Ol00004ojc1j@;o000000?oY/[co`000?l00000
0ol00007oj_<l@03o`000?nLco[oW<oj00_oW<oj00?o0000ohK8oOn6b?d00_l00007ogo4o@?o0000
0_mm`_d3o`0000?oL[Kj00?o0000ogbhnOml^?T00_ml^?T2o`0000GoR;[f0_l00004oiBllP;o0000
1OnO_Nh2o`000003ojRnjOl0003o000000;oZL3Z00?o0000ok;2i_nb`^H01?nb`^H01?l0003o^<CS
okS4hol00003okS4h`03o`000?nmaN7o_LGQ00Co_LGQ00?o0000oko5gonoaMl01?noaMl01?l0003o
`<KNol36g_o0a]h2o`000003ol?>hol0003ooooo01kooooo00?o0000ooooooooool05Oooool001oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?nfdnoo]]?_00;o
]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`000?n^c_3o[/k`00?o
[/k`00?o0000oj[9l?nZbO000ol00005oj;2k`KoWkg]00?o0000oijhjonN^>/00onN^>/00ol0003o
W;CXoibdj005oibdj004o`000?nL/>GoW;3Uo`0000CoXKOX0_l00007oj>fiP;o00001?nV]^@01?l0
003oZ<3[ojS0jonX`>/6o`0000?o[<7Y0ol000000on``^So0000oj_<l@09oj_<l@Co00000onLcoX:
o`0000SoQ/Sm1?l00003ogo4o@;o00000om]]O/5og:fnP;o00000oml^?T3o`0000CoR;[f0_l00004
oiBllP03o`000?nO_NkoWkg^00?oWkg^0_l00005ojW0jP03o`000?nb`^Ko//;V00Co//;V00?o0000
okS4hol000001?nha><00ol0003o_LGQokg5h@04okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000
ol36g_l000001?o3c^<00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eoooo
o`;o00001_ooool01Ol0003o]]?_okKCkonfdnoo000000Go]M?`00?o0000ok;Al?nbdO000_nbdO00
0ol0003o[/k`ojk>l002ojk>l003o`000?nZbO3oZ/W`00;oZ/W`00Co0000ojG3kol0003o00000_nR
`^l6oinmk@KoW[S[00?o0000oibdj?nL]>P01OnL]>P00ol0003oW;3Uoib`i@02oib`i@04o`000?nQ
]nSoXKOXo`0000KoXkKV0ol00006ojJfi0?o000000Co[<7Yo`000?l0003o00000on/`NT3o`0000Go
/<;X00?o0000oj_<lOn[c?400_n[c?45o`0000?o/<g_00?o0000oj?AmonSdOL02OnSdOL00ol0003o
T<cloi3<o002oi3<o0Co00001On6b?d3o`0000?oKKKk1?m]]O/00ol0003oL[Kjog:fnP02og:fnP;o
00001?ml^?T2o`0000CoR;[f0_l00003oiBllP;o000000?oWkg^o`000?l000000onO_Nh5ojW0jP03
o`000?nb`^Ko//;V00Co//;V00?o0000okS4hol000001?nha><00ol0003o_LGQokg5h@04okg5h@03
o`000?noaMoo_lGO00?o_lGO0_l00005ol?>h`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`00
0?nfdnoo]]?_00;o]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`00
0?n^c_3o[/k`00;o[/k`00?o0000oj[9l?nZbO000_nZbO000ol0003oYL?_ojG3k`02ojG3k`Co0000
0onO_Nd5oijhj`;o00001_nL]>P2o`0000GoW;3U0ol00005oj>fiP;o00001onV]^@2o`000004ojVf
hol0003o0000o`0000Co[<7Y0_l00007ok32j0;o000000?oZlcao`000?n`cNl01on`cNl3o`0000;o
Xm7g2Ol0000:oi3<o0Co00000omd^_`5offfn`04o`000?m]]O_oKKGkoffen`;o00000omb]_X2o`00
00CoO;Si0_l00004ohRjmP;o00000_nD_?82o`0000KoWkg^1OnY`>X00ol0003o//;Vok;2iP04ok;2
iP03o`000?nha>?o000000Co^<CS00?o0000okg5hOnmaN401?nmaN401ol0003o_lGOoko5gonoaMoo
0000ol;=hol000001Oo3c^<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo000N
ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`000003okKCk`03o`000?ne
do3o]M?`00?o]M?`00Go0000ok;Al?nbdO3o/]7`o`000005ojk>l005o`000?nZbO3oZ/W`oj[9l?l0
00001OnU`nl01?l0003oWkg]oinmkOnO_Nd3o`0000GoW[S[1onL]>P00ol0003oW;3Uoib`i@04oib`
i@04o`000?nM[^?oWJkSoif^h`;o00000_nS]^H00ol0003oY[KTojJfi005ojJfi0Go00000_nY]^<0
1Ol0003o[<7Yojc1jOn/`NWo000000Ko/<;X0ol000000onda>Ko0000ok3=k`05ok3=k`Co00000_nf
c^`00ol0003o[=;dojcBm008ojcBm004o`000?nLcoWoW<oioic?n@Go00000on@c?`01?l0003oP;ok
oh2onol00004ogBjo003o`000?m]]__oKKKk00;oKKKk00Go0000offenom]]O_oKKGko`000004og:f
nP;o00001?ml^?T2o`0000;oR;[f00Co0000ohRjm_l0003o00000onB^O46oinmkP03o`000?nY`>[o
ZL3Z00;oZL3Z00?o0000ok;2i_nb`^H01?nb`^H00ol0003o^<CSo`000004okS4h`03o`000?nmaN7o
_LGQ00Co_LGQ00?o0000oko5gol000000oo2cN<00ol0003o`lkSol?>h`03ol?>h`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool04_ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000001?nfdnl00ol0003o]M?`okGCl002
okGCl003o`000?nbdO3o/]7`00;o/]7`00?o0000ojk>l?n^c_000_n^c_000ol0003oZ/W`oj[9l002
oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd01?l0003oV[K[o`000?l0
0002oijhj`OoW;CX00?o0000oib`iOnL/>D01?nL/>D00ol0003oWJkSoif^h`03oif^h`;o00001onV
]^@4o`0000GoZKKS0_l00006ok32j0?o00001Onda>H01?l0003o/<g_ok3=kon`cNl2o`0000Ko]/k/
00?o0000ojcBm?n/d_@00_n/d_@6o`0000WoW<oi0ol00005oh2on`;o00000omd^_`2o`0000;oKKKk
0_l00002offen`;o00001?mb]_X2o`0000;oO;Si1?l00003ohFdm003o`000?nB^O7oT[Wa00;oT[Wa
00?o0000oinmk_nO_Nh00onO_Nh00ol0003oZL3ZojW0jP02ojW0jP03o`000?nb`^Ko//;V00Co//;V
0_l00005okS4h`03o`000?nmaN7o_LGQ00?o_LGQ0_l00004ol;=h`03o`000?o3c^?o`lkS00?o`lkS
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0>_ooool00ol0003o]]?_okKCk`02okKCk`03o`00
0?nedo3o]M?`00;o]M?`00?o0000ok;Al?nbdO000_nbdO000ol0003o[/k`ojk>l002ojk>l003o`00
0?nZbO3oZ/W`00;oZ/W`00?o0000ojG3konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`00
0?nJ]^_oV[K[00;oV[K[0_l00005oibdj0;o00001_nL/>D00ol0003oWJkSoif^h`03oif^h`04o`00
0?nO[>7oWjcQo`0000CoY[KT0ol00006ojVfh`;o00000_n]]n400ol0003o/<;Xok32j003o`0000Oo
]<CV0ol00008okK>k0?o000000Co[=;do`000?l0003o00001?ndd_000ol0003oZ=3eojS@m@04ojS@
m@Go00000on>a?X00ol0003oP;okoh2on`03oh2on`;o00000omd^_`2o`0000;oKKKk0_l00002offe
n`;o00000_mb]_X4o`0000?oNJoe00?o0000ohFdm?n5]?@00_n5]?@00ol0003oT[Waoi:il@02oi:i
l@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0j_nY`>X00_nY`>X00ol0003o//;Vok;2iP04ok;2
iP;o00001Onha><00ol0003o_LGQo`000002o`000003oko<i?l0003o`/gS00Co`/gS00?o0000ol?>
hoo3c^<00oo3c^<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@
413oooooooooo`03ooooo`004oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0>_ooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o]M?`00?o0000ok;A
l?nbdO000_nbdO001Ol0003o[/k`ojk>l?n^c_3o000000GoZ/W`00?o0000ojG3konU`nl00_nU`nl0
0ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`j?l000000onL]>P0
0ol0003oW;3Uoib`i@04oib`i@;o00001OnM[^<00ol0003oWjcQoin/h@02oin/h@Co00001onY]^<2
o`0000Co[KOQ0ol00007okC4iP?o00000_nhaN@01?l0003o]/k/okK>k?nfc^`5o`0000;o^lkX00?o
0000okCBl?ndd_000_ndd_04o`0000SoZ=3e00Co0000oig8m_nMb?KoWLSf0_l00004ohk4nP;o0000
0on0_o/2o`0000?oM;[l2_l00004ofn[mPCoNJoe00?o0000ohFdm?n5]?@00_n5]?@00ol0003oT[Wa
oi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0j_nY`>X00_nY`>X00ol0003o//;V
ok;2iP04ok;2iP;o00001?nha><2o`0000Go_lcT00?o0000ol;=hoo2cN<00_o2cN<00ol0003o`lkS
ol?>h`03ol?>h`03o`000?oooooooooo01gooooo00?o0000ooooool000002_ooool00ol0003ooooo
ooooo`05ooooo`004oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0000jooooo`03o`00
0?nfdnoo]]?_00;o]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`00
0?n^c_3o[/k`00;o[/k`00?o0000oj[9l?nZbO000_nZbO000ol0003oYL?_ojG3k`02ojG3k`03o`00
0?nO_NgoWkg]00?oWkg]00?o0000oiZfjonJ]^/00_nJ]^/01Ol0003oUk3XoiN`j?nG/>So000000;o
W;CX1_nL/>D00ol0003oWJkSoif^h`04oif^h`04o`000?nO[>7oWjcQoin/h@Go00001onY]^<00ol0
003o[KOQojfgh@02ojfgh@;o00000_na^Ml00ol0003o]<CVokC4iP03okC4iP;o00001OnhaN@4o`00
00Ko^lkX0_l000000ondd_3o0000o`000004ok_Aj`03o`000?ncd>oo/m3_00;o/m3_1?l00007oig8
mP?o00000on>a?X3o`000003oh2onol0003o000000?oKjcf2?mYZOH5ofn[mPCoNJoe00?o0000ohFd
m?n5]?@00_n5]?@00ol0003oT[Waoi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0
j_nY`>X00_nY`>X00ol0003o//;Vok;2iP04ok;2iP;o00000_nha><00ol0003o^/[Voko<i005oko<
i003o`000?o2cN?o`/gS00?o`/gS00?o0000ol?>hoo3c^<00_o3c^<00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo03[ooooo00?o0000okKCkonfdnl00_nfdnl00ol0
003o]M?`okGCl002okGCl003o`000?nbdO3o/]7`00;o/]7`00Go0000ojk>l?n^c_3o[/k`o`000004
oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd00ol0003oV[K[oiZfj`02
oiZfj`03o`000?nG/>SoUk3X00?oUk3X0_l00005oib`i@03o`000?nM[^?oWJkS00?oWJkS0_l00000
1_nO[>7o0000o`000?l0003oWjcQo`0000?oXZcO00?o0000ojVfhonY]^<00_nY]^<2o`0000Co[KOQ
00?o0000ok6igona^Ml00ona^Ml00ol0003o]<CVokC4iP02o`0000Co^<GT0ol000000onla^;o0000
ok_>j004ok_>j0?o000000?o_lgUo`000?nkdN/01OnkdN/00ol0003o/m3_ok?@k`06ok?@k`03o`00
0?n[bo3o000000;o00001_nMb?H2o`0000;oR;Se00?o0000ogZbm_mj/_H00_mj/_H4ofn/mP03o`00
0?mYZOKoJJWf00GoJJWf00?o0000ofn[m_m_ZoH00_m_ZoH01Ol0003oNJoeogV_mOmi[oGo000000Co
QKCd00?o0000oi:ilOnB^O400_nB^O400ol0003oWkg^oinmkP03oinmkP03o`000?nY`>[oZL3Z00;o
ZL3Z00?o0000ok;2i_nb`^H01?nb`^H00ol0003o^<CSo`000003ok[:iPKo_lcT00?o0000ol;=hoo2
cN<00_o2cN<00ol0003o`lkSol?>h`03ol?>h`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`004oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0>Oooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o
]M?`00?o0000ok;Al?nbdO000_nbdO001Ol0003o[/k`ojk>l?n^c_3o000000GoZ/W`00?o0000ojG3
konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`
j?nG/>P00onG/>P00ol0003oU:_Vo`000002o`0000;oW;3U1OnM[^<4o`0000?oWjcQ00?o0000oj:/
gonR[=l00onR[=l01?l0003oZKKSojVfhol00004ojfgh@;o00001_na^Ml2o`0000Go^<GT0_l00005
okc6hP03o`000?nkc^So^lkX00;o00000onocND01?l0003o^m7[ok_AjonkdN/5o`000004ok?@kol0
003o0000o`0000?o/m3_00?o0000oj_;l?n[bo000on[bo02o`000003oig8m_l0003o000000;oV;kb
00Go0000ohRhmOn8^?GoR;Seo`000004ogZbmP05o`000?m_[?KoKjcfofn/m_l000000omYZOH01Ol0
003oJJWfofVYm_mYZOKo000000CoKj_f00Go0000ogV_mOmi[oGoNJoeo`000004ohFdm003o`000?nB
^O7oT[Wa00;oT[Wa00?o0000oinmk_nO_Nh00onO_Nh00ol0003oZL3ZojW0jP02ojW0jP03o`000?nb
`^Ko//;V00?o//;V0_l00004ok[:iP03o`000?noc>Co_lcT00?o_lcT00?o0000ol;=hoo2cN<00oo2
cN<00ol0003o`lkSol?>h`02ol?>h`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0>?ooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o]M?`00?o
0000ok;Al?nbdO000_nbdO000ol0003o[/k`ojk>l002ojk>l003o`000?nZbO3oZ/W`00;oZ/W`00?o
0000ojG3konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o
0000oiN`j?nG/>P00onG/>P00ol0003oU:_VoiB[iP03oiB[iP;o00000onM[^<3o`0000GoWjcQ00?o
0000oj:/gonR[=l01?nR[=l3o`0000Co[KOQ00?o0000ok6igona^Ml01Ona^Ml01?l0003o]K_NokFk
g_l00002okS5i0;o00001_nla^83o`0000Go_lgU1Ol00004ol7?i@03o`000?nlcnWo_<oY00;o_<oY
0ol00008oj_;l003o`000?nH__;oV;kb00?oV;kb00Go0000ohRhmOn8^?GoR;Seo`000004ogZbmP05
o`000?m_[?KoKjcfofn/m_l000001?mYZOH01?l0003oJJWfofVYm_l00004ofn[mP05o`000?mi[oGo
NJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o
0000ojW0j_nY`>X00_nY`>X00ol0003o//;Vo`000002o`000003ok?7jOnjb^Ko000000Co^/[V00?o
0000oko<i?noc>@00_noc>@00ol0003o`/gSol;=h`03ol;=h`03o`000?o3c^?o`lkS00;o`lkS00?o
0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000C
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Wooooo00?o0000okKCkonfdnl00_nf
dnl00ol0003o]M?`okGCl002okGCl003o`000?nbdO3o/]7`00;o/]7`00Go0000ojk>l?n^c_3o[/k`
o`000005oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd01Ol0003oV[K[
oiZfjonJ]^_o000000GoUk3X00?o0000oiB[i_nDZnH01?nDZnH00ol0003oTjOSo`000003o`0000Ko
WjcQ00?o0000oj:/gonR[=l01?nR[=l01Ol0003oYJgMojF]gOnU[Mgo000000;o[KOQ1ona^Ml2o`00
00?o]K_N0_l00007okc6hP;o000000?o`<KOo`000?nocND00_nocND3o`000003ol?<hOl0003o`LoU
00Go`LoU00?o0000okc?jOnlcnT01?nlcnT00ol0003o]/_ZokK;jP03o`000003oj_;l?l0003o0000
00?oY/?^00?o0000oiRnl_nH__800_nH__801Ol0003oR;SeohRhmOn8^?Go000000CoN[;f00Go0000
ofn/m_m_[?KoKjcfo`000004ofVYmP04o`000?mYZOKoJJWfo`0000CoKj_f00Go0000ogV_mOmi[oGo
NJoeo`000004ohFdm003o`000?nB^O7oT[Wa00;oT[Wa00?o0000oinmk_nO_Nh00onO_Nh00ol0003o
ZL3ZojW0jP03o`0000Go/lOY00?o^/[Vo`000?njb^H00_njb^H00ol0003o_lcToko<i003oko<i003
o`000?o2cN?o`/gS00;o`/gS00?o0000ol?>hoo3c^<00oo3c^<00ol0003oooooooooo`0Oooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`007Oooool00ol0003oooooooooo`0goooooaOo0000
0_nZbO000ol0003oYL?_ojG3k`02ojG3k`03o`000?nO_NgoWkg]00?oWkg]00?o0000oiZfjonJ]^/0
0_nJ]^/00ol0003oUk3XoiN`j003oiN`j003o`000?nDZnKoU:_V00?oU:_V0ol00002oi>Wh`;o0000
1OnO[>400ol0003oXZcOoj:/g`04oj:/g`03o`000?nU[MgoYJgM00?oYJgM0_l00006ok6ig`03o`00
0?ne^mko]K_N00;o]K_N00Co0000okVmgOni_Mgo00001?nla^82o`0000Co`<KO00?o0000oko=iOl0
00001?o3c>401?l0003o`LoUol7?iOo1cnD4o`000003okc?jOl0003o000000;o_<oY00?o0000okK;
j_nfbnX01?nfbnX00ol0003oY/?^ojK3kP04ojK3kP03o`000?nH__;oV;kb00;oV;kb00Go0000ohRh
mOn8^?GoR;Seo`000004ogZbmP05o`000?m_[?KoKjcfofn/m_l000001?mYZOH01?l0003oJJWfofVY
m_l00004ofn[mP05o`000?mi[oGoNJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@02oi:il@04
o`000?nO_NkoWkg^oinmkPCo00000_nZ`^`00ol0003o/lOYok?7j@03ok?7j@;o00001?njb^H00ol0
003o_lcToko<i002oko<i003o`000?o2cN?o`/gS00?o`/gS00?o0000ol?>hoo3c^<00_o3c^<00ol0
003oooooooooo`0Nooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool001go
oooo00?o0000ooooooooool0=oooool00ol0003o_]?ZokkCjP02okkCjP03o`000?nldn_o_=?[00;o
_=?[00?o0000ok[Ak?njdN`00_njdN`01Ol0003o]Lk]okG>kOnec^go000000?o[l[^2?l00004oinm
k@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`j?nG/>P00onG/>P00ol0003oU:_VoiB[iP02oiB[
iP;o00001OnCYn<00ol0003oU:GQo`000003oin/h@03o`000?nR[=ooXZcO00?oXZcO0_l00006ojF]
g@03o`000?nY[mco000000?o/KWO0_l00004okFkgP03o`000?ni_Mgo^KgM00;o^KgM00Co0000okc6
h_nla^;o00001Oo0a]l2o`0000Go`lcQ1Ol00003olG=h@04o`000?o2cN?o`/gSol;=h`;o00001Onf
bnX01Ol0003o//GXok;5j?nbaNSo000000GoY/?^00?o0000oiRnl_nH__806?l00004ofn[mP05o`00
0?mi[oGoNJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@05o`0000;oWkg^1OnZ`^`00ol0003o
/lOYok?7j@03ok?7j@;o00000onjb^H00ol0003o_lcToko<i003oko<i003o`000?o2cN?o`/gS00;o
`/gS00?o0000ol?>hoo3c^<00oo3c^<00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00co
oooo000Looooo`03o`000?oooooooooo03Sooooo00?o0000okkCj_nndnX00_nndnX00ol0003o_=?[
okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/00Go0000okG>kOnec^go]Lk]o`000004ojo:kP03
o`000?nWa>koYlC^00;oYlC^0_nO_Nh3o`000003oinmkOl0003oV[K[00?oV[K[00?o0000oiN`j?nG
/>P00_nG/>P00ol0003oU:_VoiB[iP03o`000003oiB[i_l0003oTjOS00?oTjOS00Oo0000oiBUhOnD
YN7oU:GQo`000?nO[>7o000000GoXZcO00?o0000ojF]gOnU[Md01OnU[Md01Ol0003oZJoLojV_g?nY
[mco000000;o/KWO1?ne^mh2o`0000Go^KgM0_l00005ol36g`;o000000?o`lOMo`000?o3c>400_o3
c>42o`000003olK;g_l0003oaLgQ00CoaLgQ00?o0000ol;=hoo2cN<00oo2cN<01?l0003o_/_Tokk;
i?nnbn@2o`0000Ko//GX00Go0000ojK3k_nV`nko0000ojK3kP02o`0000;oVKG[00Go0000oh^^kOn;
[^goRjk]o`000004ognXkP05o`000?mfXnkoMZ?^ogJSk_l000001?maXNh3og6Qka7o00000_nC]^l6
oinmkPCoZ/;/00?o0000ok?7jOncanT00oncanT00ol0003o^/[Vo`000003ok[:iP03o`000?noc>Co
_lcT00;o_lcT00?o0000ol;=hoo2cN<00oo2cN<00ol0003o`lkSol?>h`02ol?>h`03o`000?oooooo
oooo01oooooo0ol0000=ooooo`007?ooool00ol0003oooooooooo`0hooooo`03o`000?nndn[o_]?Z
00;o_]?Z00?o0000okcCjonldn/00_nldn/00ol0003o^]7/ok[Ak002ok[Ak005o`000?nec^go]Lk]
okG>kOl000001?n_b^h00ol0003oYlC^ojO4kP02ojO4kPGoWkg^0ol00002oiZfj`03o`000?nG/>So
Uk3X00?oUk3X0ol00003oiB[iP03o`000?nCYn?oTjOS00;oTjOS00?o0000oiBUhOnDYN400onDYN42
o`0000CoXZcO00?o0000ojF]gOnU[Md01OnU[Md00ol0003oZJoLojV_g003ojV_g0;o00001?ne^mh6
okVmg@03o`000?nm_m_o000000Co`<KO00?o0000ol?7gOo3amd00_o3amd00ol0003o`lcQo`000003
olK;gP03o`000?o5cN7oaLgQ00?oaLgQ00?o0000ol;=hoo2cN<00_o2cN<01Ol0003o_/_Tokk;i?nn
bnCo000000;o_<OS00?o0000ok;5j?nbaNP01?nbaNP2o`0000;oYK_X00?o0000oiVejonI]N/00_nI
]N/01Ol0003oRjk]oh^^kOn;[^go000000CoOjS^00Go0000ogJSk_mfXnkoMZ?^o`000004og6QkP?o
LJ7_00?o0000ogFTkomeY>l00_meY>l4ogbYl0GoQjo`1OnC]^l5oinmkP03o`000?nZ`^coZ/;/00;o
Z/;/00?o0000ok?7jOncanT00oncanT2o`0000?o^/[V00?o0000oko<i?noc>@00onoc>@00ol0003o
`/gSol;=h`02ol;=h`03o`000?o3c^?o`lkS00;o`lkS00?o0000ooooooooool07?ooool3o`0000;o
oooo00?o0000ooooooooool02oooool001cooooo0_l0000iooooo`03o`000?nndn[o_]?Z00;o_]?Z
00?o0000okcCjonldn/00_nldn/00ol0003o^]7/ok[Ak002ok[Ak005o`000?nec^go]Lk]okG>kOl0
00001?n_b^h00ol0003oYlC^ojO4kP02ojO4kP03o`000?nO_NkoWkg^00;oWkg^0onG]N`8o`0000Go
U:_V00?o0000oi>WhonCYn<00onCYn<00ol0003oU:GQoiBUh@03oiBUh@06o`000?nFY=oo0000o`00
0?nR[=oo00001onU[Md00ol0003oZJoLojV_g003ojV_g004o`000?n^/]_o[[;Ko`0000;o]K_N1Oni
_Md2o`0000?o_KoK00Co0000ol36goo0a]oo00001?o3amd2o`0000Goa/_N00?o0000olG=hOo5cN40
2?l000001?nnbnCo0000okk;i?l00004okc7h`03o`000?nbaNSo000000;o000000?o/KoUo`000?nU
^nP00onU^nP01Ol0003oVKG[oiVejonI]N_o000000CoRjk]00Go0000ognXk_moZ>koOjS^o`000003
ogJSkP03o`000?maXNkoLJ7^00;oLJ7^00Go0000og6QkomaXNooLJ7_o`000004ogFTk`CoO:W`1On7
[o04oi>fk`03o`000?nO_NkoWkg^00?oWkg^00Go0000oj[2k?nZ`^coZ/;/o`000005ok?7j@03o`00
0?njb^Ko000000;o^/[V00?o0000oko<i?noc>@00onoc>@00ol0003o`/gSol;=h`03ol;=h`04o`00
0?o3c^?o`lkSol?>h`;o00006_ooool3o`0000Gooooo00?o0000ooooooooool02oooool001cooooo
00?o0000ooooooooool0>?ooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000ok[Ak?nj
dN`00_njdN`00ol0003o]Lk]okG>k@02okG>k@03o`000?n_b^ko[l[^00;o[l[^00Go0000ojO4k_nW
a>koYlC^o`000005oinmkPCoUkG/00?oSjg[o`000?l000001?l00005oiB[iP03o`000?nCYn?oTjOS
00;oTjOS00?o0000oiBUhOnDYN400onDYN400ol0003oUZCOoiJTg`02oiJTg`;o00001_nU[Md00ol0
003oZJoLojV_g003ojV_g003o`000?n^/]_o[[;K00;o[[;K0_l00003okVmg@;o00001Onm_m/2o`00
00Co`lOM0_l000000oo6b=_o0000olK;gP03olK;gPCo00000_o8bmd01Ol0003oa/cNolK<g_o6c=ko
000000?oaL[N00?o0000okc7honlan<01?nlan<00ol0003o/KoUok6oi@03ok6oi@03o`000?nU^nSo
YK_X00;oYK_X00Go0000oiVejonI]N_oVKG[o`000003oh^^k@03o`000?moZ>koOjS^00;oOjS^00Go
0000ogJSk_mfXnkoMZ?^o`000004og6QkP04o`000?maXNooLJ7_o`0000CoMJC_00Go0000ogbYl?ml
ZO3oO:W`o`000004ohN_l003o`000?nC]^ooTkK_00;oTkK_00?o0000oinmk_nO_Nh00_nO_Nh00ol0
003oZ/;/oj[2k002oj[2k003o`000?ncanWo/lOY00?o/lOY00?o0000ok[:i_l000000_njb^H00ol0
003o_lcToko<i002oko<i003o`000?o2cN?o`/gS00?o`/gS00Ko0000ol?>hol0003o0000ol;Ej?l0
000Gooooo`?o00002?ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[Ak002ok[Ak003o`000?ne
c^go]Lk]00;o]Lk]00?o0000ojo:k_n_b^h00_n_b^h01Ol0003oYlC^ojO4k_nWa>ko000000GoWkg^
00?o0000oiNek?l000000_l00004ohn]j`;oRZOX0ol000000onDZnKo0000oi>Wh`03oi>Wh`03o`00
0?nDYN7oU:GQ00?oU:GQ00?o0000oiJTgonFY=l00onFY=l01?l0003oVZKNo`000?l00003ojF]g@03
o`000?nY[mcoZJoL00?oZJoL00?o0000ojjbfon^/]/00on^/]/00ol0003o/kKJo`000002okVmg@Ko
_KoK00Co0000ol72f_o1`][o00000_o3amd00ol0003oa/SKolK8f`02olK8f`06o`000?o6bmko0000
o`000?o9b]_o00000oo8bmd01Ol0003oa/cNolK<g_o6c=ko000000?oaL[N00Go0000ol?8g_o3b=ko
0000okc7h`02o`000003ok_3hOl0003o/KoU00Co/KoU00?o0000ojFkj?nU^nP00_nU^nP01Ol0003o
VKG[oiVejonI]N_o000000CoRjk]00?o0000ognXk_moZ>h00_moZ>h01?l0003oMZ?^ogJSk_l00004
og6QkP05o`000?maXNooLJ7_og6Qkol000001?meY>l01Ol0003oO:W`ogbYl?mlZO3o000000CoQjo`
00Go0000oi>fkonC]^ooTkK_o`000005oinmkP03o`000?nZ`^coZ/;/00;oZ/;/00?o0000ok?7jOnc
anT00_ncanT01_l0003o^/[Vok[:i_l0003o^/[Vo`0000Go_lcT00?o0000ol;=hoo2cN<00_o2cN<2
o`0000?o`]GX00?o0000ooooooooool04Oooool4o`0000_ooooo00?o0000ooooooooool02oooool0
01cooooo00?o0000ooooooooool0>?ooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000
ok[Ak?njdN`00_njdN`00ol0003o]Lk]okG>k@02okG>k@03o`000?n_b^ko[l[^00;o[l[^00Go0000
ojO4k_nWa>koYlC^o`000004oinmkP?o00000_nG]N`00ol0003oSjg[ohn]j`02ohn]j`GoRZOX0_l0
0004oi>Wh`03o`000?nDYN7oU:GQ00?oU:GQ00?o0000oiJTgonFY=l00_nFY=l00ol0003oVZKNoiZV
gP02oiZVgP03o`000?nU[Mgo000000GoZJoL00?o0000ojjbfon^/]/00on^/]/01?l0003o/kKJok>f
f_nc]]X2o`0000Go_KoK00?o0000ol72f_o1`]X00_o1`]X00ol0003oa/SKolK8f`03olK8f`;o0000
1?o9b]/00ol0003ob<_Mo`000005o`000004olG:g_l0003oaL[No`0000Co`lSN00?o0000ok_3hOnk
`n400_nk`n400ol0003o/KoUok6oi@02ok6oi@04o`000?nU^nSoYK_XojFkj13o00000omfXnh01Ol0
003oLJ7^og6Qk_maXNko000000CoLJ7_00Go0000ogFTkomeY>ooMJC_o`000003ogbYl003o`000?n7
[o3oQjo`00;oQjo`00?o0000oi>fkonC]^l00_nC]^l00ol0003oWkg^oinmkP02oinmkP03o`000?nZ
`^coZ/;/00;oZ/;/00?o0000ok?7jOncanT00oncanT00ol0003o^/[Vo`000002ok[:iP03o`000?no
c>Co_lcT00;o_lcT00?o0000ol;=hol000000_l000000oo1eNWo0000ol;Ej002ol;Ej003o`000?oo
oooooooo00kooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooo
oooo03Wooooo00Go0000okkCj_nndn[o_]?Zo`000004okcCj`03o`000?njdNco^]7/00;o^]7/00Go
0000okG>kOnec^go]Lk]o`000004ojo:kP03o`000?nWa>koYlC^00;oYlC^00?o0000oinmk_l00000
0ol00004oiNek003o`000?n?[N_oSjg[00;oSjg[00?o0000ohZWj?n:YnP00_n:YnP2ohJRiP;o0000
00?oTjOSo`000?nDYN401?nDYN400ol0003oUZCOoiJTg`03oiJTg`03o`000?nJY]koVZKN00?oVZKN
0_l00004ojV_g003o`000?n^/]_o[[;K00?o[[;K00?o0000ok>ff_nc]]X00_nc]]X00ol0003o^KWJ
o`000003okfof`03o`000?o1`][o`L;J00;o`L;J00?o0000olG4fOl000000oo6b=/00ol0003ob<SI
o`000003olW:f`?o00000_o:b]T01?l0003obL[JolW:f_l00002olW9fP07o`000?o3b=ko`lSNol?8
g_l0003o`/KMo`000005ok_3h@03o`000?na_nGo/KoU00Go00000_nX]N84oij_i0GoTjWU1?n:XnD5
o`0000CoLJ7^00Go0000og6QkomaXNooLJ7_o`000004ogFTk`05o`000?mlZO3oO:W`ogbYl?l00000
1?n7[o001Ol0003oTkK_oi>fkonC]^oo000000CoWkg^00?o0000oj[2k?nZ`^`00onZ`^`00ol0003o
/lOYok?7j@02ok?7j@06o`000?njb^Ko^/[Vo`000?njb^Ko00000onoc>@3o`0000Co`MGY00Go0000
ol;Ej?o2eNSo`]GXo`00000=ooooo`?o00004oooool00ol0003oooooooooo`0:ooooo`006oooool0
0ol0003oooooooooo`0iooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[A
k002ok[Ak005o`000?nec^go]Lk]okG>kOl000001?n_b^h01?l0003oYlC^ojO4k_nWa>h3o`0000?o
Wkg^00?o0000oiNek?nG]N`00_nG]N`01Ol0003oSjg[ohn]jon?[N_o000000GoRZOX1?n6X^H2o`00
00GoU:GQ00?o0000oiJTgonFY=l00_nFY=l00ol0003oVZKNoiZVgP04oiZVgP06o`000?nOZ=go0000
o`000?nY[mco00001On^/]/00ol0003o/kKJok>ffP02ok>ffP07o`000?ni^M[o^KWJokVif_l0003o
_KoKo`000004ol72fP07o`000?o5a=WoaLCIolG4fOl0003oa/SKo`000003olS8f@05o`000?o9b]_o
0000ol_9fOl000000oo:b]T2olW:fP04o`000?o9bM[obLWJolW9fP;o000000?o`lSNo`000?o2a]d0
0_o2a]d01_l0003o^l?Qok_3hOnk`n7o0000ok_3h@;o00000_nb^n000ol0003oZ;GRojRehP02ojRe
hP05o`000?nN[nCoWZoToij_i?l000001?nCZND00ol0003oRZ?UohZSi@02ohZSi@?oPioV1_l00004
og6Qk`05o`000?meY>ooMJC_ogFTkol000001?mlZO001Ol0003oQjo`ohN_l?n7[o3o000000CoTkK_
00?o0000oinmk_nO_Nh00_nO_Nh00ol0003oZ/;/oj[2k002oj[2k003o`000?ncanWo/lOY00?o/lOY
00?o0000ok[:i_njb^H01Ol00002okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go0000ol;Ej?o2eNSo
`]GXo`000009ooooo`Co00005_ooool00ol0003oooooooooo`0:ooooo`006oooool2o`0003Wooooo
00?o0000okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/
00Go0000okG>kOnec^go]Lk]o`000004ojo:kPCo000000?oYlC^o`000?nO_Nh00onO_Nh01Ol0003o
UkG/oiNek?nG]Nco000000CoSjg[00?o0000ohZWj?n:YnP00_n:YnP00ol0003oQZ;VohJRiP02ohJR
iP;oQYoT0ol000000onDYN7o0000oiJTg`03oiJTg`03o`000?nJY]koVZKN00CoVZKN00?o0000oinX
gOnOZ=d00_nOZ=d2o`0000Co[[;K00?o0000ok>ff_nc]]X00_nc]]X00ol0003o^KWJokVifP03okVi
fP;o00000oo1`]X00ol0003oaLCIolG4f@02olG4f@;o00000oo8b=T2o`0000?oblWI00Co0000ol[:
fOo:b]Wo00000_o9b]X01?l0003obLWJolW9f_l00002olS8fP03o`000?o2a]go`/KM00?o`/KM0ol0
0002ok_0g@05o`000?nb^n3o/[_Pok:kh?l000001?nX]N801Ol0003oWZoToij_i?nN[nCo000000Co
TjWU00?o0000ohZSiOn:XnD00_n:XnD01?l0003oPioVoh>Oi_n3WnH4ogjMiPKo00001?meY>l01Ol0
003oO:W`ogbYl?mlZO3o000000?oQjo`00?o0000oi>fkonC]^l00_nC]^l00ol0003oWkg^oinmkP02
oinmkP03o`000?nZ`^coZ/;/00?oZ/;/00?o0000ok?7jOncanT00_ncanT00ol0003o^/[Vo`000003
o`0000Co_M?Z00?o0000ol7EjOo1eNT00_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000000Kooooo0ol0
000Jooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000
okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/00Go0000
okG>kOnec^go]Lk]o`000002ojo:kP?o00001?nWa>h00ol0003oWkg^oinmkP02oinmkP05o`000?nG
]NcoUkG/oiNek?l000001?n?[N/00ol0003oRZOXohZWj002ohZWj003o`000?n6X^KoQZ;V00;oQZ;V
1On6Wn@2o`0000CoUZCO00?o0000oiZVg_nJY]h00onJY]h00ol0003oWjSMoinXg@03oinXg@06o`00
0?nU[=co0000o`000?n^/]_o00001?nc]]X00ol0003o^KWJokVifP03okVifP06o`000?nn_MWo_[gI
o`000?o1`][o00001?o5a=T02?l0003oalKHolO6f?l0003ob<SIo`000?o:b=So00000oo;bMT00ol0
003ob/[Io`000004o`000007olW9f_l0003ob<SJolS8f_o7am[o0000ol;6g@03o`000003ol;4fol0
003o^l3M00?o^l3M00?o0000ok:kh?nb^n000_nb^n001Ol0003oZ;GRojReh_nX]N;o000000CoWZoT
00?o0000oi>YiOnCZND00_nCZND01Ol0003oRZ?UohZSiOn:XnGo000000?oPioV00?o0000ogjMi_mn
WNH00_mnWNH4ogfNi`Ko00001?mlZO001Ol0003oQjo`ohN_l?n7[o3o000000CoTkK_00?o0000oinm
k_nO_Nh00_nO_Nh00ol0003oZ/;/oj[2k002oj[2k004o`000?ncanWo/lOYok?7j@?o00000_nhd>/2
o`0000Co_M?Z00?o0000ol7EjOo1eNT00_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000000?ooooo0ol0
000Mooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000
okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`05o`000?njdNco^]7/ok[Ak?l000001?ne
c^d3o`0000;o[l[^00Go0000ojO4k_nWa>koYlC^o`000004oinmkP03o`000?nG]NcoUkG/00;oUkG/
00?o0000ohn]jon?[N/00_n?[N/00ol0003oRZOXohZWj002ohZWj003o`000?n6X^KoQZ;V00;oQZ;V
00?o0000ohJOi?n6Wn@00_n6Wn@2ohROh`04o`000?nFY=ooUZCOo`0000KoVZKN00?o0000oinXgOnO
Z=d00_nOZ=d00ol0003oYJcLojF/g002ojF/g0;o00001?nc]]X00ol0003o^KWJokVifP02okVifP03
o`000?nn_MWo_[gI00;o_[gI0ol00002olG4f@03o`000?o7a]SoalKH00;oalKH00Ko0000ol[8f?o:
b=Sob/SHo`000?o;bMT2o`000009olc9eol0003oblWGol_9eol0003oblWHo`000?o8b=[o000000?o
alOJ00?o0000ol;4foo2a=/00_o2a=/00ol0003o^l3Mok_0g@02ok_0g@03o`000?nb^n3o/[_P00;o
/[_P00Go0000ojReh_nX]N;oZ;GRo`000004oij_i003o`000?nCZNGoTjWU00;oTjWU00Go0000ohZS
iOn:XnGoRZ?Uo`000003oh>OiP03o`000?mnWNKoOYgV00;oOYgV00?o0000ogfNiommW^L00_mmW^L4
ognQj0Ko00000on7[o000ol0003oTkK_oi>fk`02oi>fk`03o`000?nO_NkoWkg^00;oWkg^00Co0000
oj[2k?nZ`^coZ/;/1Ol00002ok7;k@05o`000?nhd>_o^=3[okS@jol000001?nmdnX00ol0003o`MGY
ol7Ej@02ol7Ej@04o`000?o2eNSo`]GXol;Ej0Co00008?ooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0hooooo`03o`000?nndn[o_]?Z00;o_]?Z00Go0000okcCjonldn_o
_=?[o`000004ok[Ak003o`000?nec^go000000?o00001?n_b^h01Ol0003oYlC^ojO4k_nWa>ko0000
00CoWkg^00?o0000oiNek?nG]N`00_nG]N`00ol0003oSjg[ohn]j`02ohn]j`03o`000?n:YnSoRZOX
00;oRZOX00?o0000ohJRi_n6X^H00_n6X^H00ol0003oQYoTohJOi002ohJOi0?oR9oS00?o0000oiJT
gol000001OnJY]h00ol0003oWjSMoinXg@02oinXg@03o`000?nU[=coYJcL00?oYJcL00Ko0000ojba
fol0003o0000ok>ff_l00004okVifP03o`000?nn_MWo_[gI00;o_[gI00Co0000ol;1f?o2`MSo`/7H
0ol00003olO6f0;o00000oo:b=P2o`000004olc9eol0003oc<WGo`0000;oblWG00CoblWHo`000?o;
b=So00000_o7amX00ol0003oalKIo`000004ol;4f`03o`000?nk`=go^l3M00oo000000?oWZoTo`00
0?nCZND00onCZND01Ol0003oRZ?UohZSiOn:XnGo000000?oPioV00?o0000ogjMi_mnWNH00_mnWNH0
0ol0003oOIkWogfNi`02ogfNi`03o`000?moXNSoOj7X00;oOj7X1?n4Y^XBo`0000;oZLC]00?o0000
ok7;kOnabnd00_nabnd01?l0003o^=3[okS@jonhd>/2o`0000?o_M?Z00?o0000ol7EjOo1eNT00_o1
eNT01Ol0003o`]GXol;Ej?o2eNSo000002?ooooo00?o0000ooooooooool02_ooool001[ooooo0ol0
000iooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[Ak002ok[Ak0;o0000
00?o]Lk]o`000?l000004_l000000onG]Nco0000ohn]j`02ohn]j`03o`000?n:YnSoRZOX00?oRZOX
00?o0000ohJRi_n6X^H00_n6X^H01Ol0003oQYoTohJOi?n6WnCo000000CoR9oS0_l00005oiZVgP05
o`000?nOZ=goWjSMoinXgOl000001OnU[=`00ol0003o[;7Kojbaf`02ojbaf`?o00000_ni^MX00ol0
003o_[gIokjmf@02okjmf@03o`000?o2`MSo`/7H00;o`/7H00Ko0000olK4f?o6a=So0000olO6f?l0
0002ol[7e`06o`000?o:b=So0000olc8eol0003oc<WG0_l00002ol_9e`03ol_9f?l0003oblSH00;o
blSG00?o0000olO6fOo7a]T00_o7a]T00ol0003o`/CKo`000004o`0000;o_KkK00?o0000okFig?ne
^M`00_ne^M`01Ol0003o[K?MojfcgOn]/mgo000000?oYJkN2?l00002ohZSi@03o`000?n3WnKoPioV
00;oPioV00Go0000ogjMi_mnWNKoOYgVo`000004ogfNi`03o`000?moXNSoOj7X00;oOj7X00?o0000
ohBVj_n4Y^X00_n4Y^X4ohb]k0GoUKC]1OnO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo
/L_]00;o/L_]00Oo0000okS@jonhd>_o^=3[o`000?nmdn[o000000;o_M?Z00?o0000ol7EjOo1eNT0
0_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000002Cooooo00?o0000ooooooooool02Oooool001[ooooo
00?o0000ooooooooool0>Oooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000ok[Ak?l0
00001Ol00002okW;j0Go//SZ1?nY`n`5oinmkPCoTkG^1?l000000on?[N_o0000ohZWj003ohZWj003
o`000?n6X^KoQZ;V00;oQZ;V00?o0000ohJOi?n6Wn@00_n6Wn@00ol0003oR9oSohROh`02ohROh`;o
S:7R0ol000000onJY]ko0000oinXg@03oinXg@03o`000?nU[=coYJcL00?oYJcL00?o0000ojbafon/
/M/00_n//M/00ol0003o/kKKok>ff`04o`0000;o_[gI00?o0000ol;1f?o2`MP00_o2`MP00ol0003o
a/CHolK4f002olK4f0;o00000oo:amL01?l0003oc<SGolc8eoo<b=L3o`000004ol_9eoo;bMSo0000
o`0000?oblSG00Go0000olO6fOo7a]Wo0000olO6f@02o`0000;o`l;I00?o0000okfnfonm_]/00_nm
_]/01Ol0003o]KWLokFig?ne^Mco000000Co[K?M00?o0000ojF^g_nU[]h00_nU[]h00ol0003oWJSN
oifXgP02oifXgP05o`000?nFY=ko0000ohZSiOl000001?n3WnH00ol0003oOYgVogjMiP02ogjMiP05
o`000?mmW^OoOIkWogfNiol000001?moXNP00ol0003oQ:KZohBVjP02ohBVjP05o`000?n<[NcoS:g/
ohb]k?l000001?nE]>d00ol0003oWkg^oinmkP02oinmkP03o`000?nYa>goZLC]00;oZLC]00?o0000
ok7;kOnabnd00_nabnd01ol0003o^=3[okS@jonhd>_o0000okgCj_l000000_nmdnX00ol0003o`MGY
ol7Ej@02ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?ooool00ol0003oooooooooo`09ooooo`00
00Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo03Wooooo00Go0000okkCj_nndn[o_]?Zo`000002okcCj`Go00000_nncNH6
okW;j0Co//SZ00?o0000ojW3k?nY`n`00_nY`n`5oinmkPCoTkG^0on8[Nh5o`000003ohZWj?l0003o
QZ;V00?oQZ;V00?o0000ohJOi?n6Wn@00_n6Wn@00ol0003oR9oSohROh`02ohROh`GoS:7R0ol00002
oinXg@03o`000?nU[=coYJcL00?oYJcL00?o0000ojbafon//M/00_n//M/00ol0003o/kKKok>ff`02
ok>ff`03o`000?ni^][o^K[J00Co00000_o2`MP00ol0003oa/CHolK4f003olK4f008o`000?o9a]Oo
0000ol[7eol0003oc<SGo`000?o<b=L8o`0000?oblSG0ol00002olS5f005o`000?o3`]Wo`l;Iol?2
fOl000000onm_]/00ol0003o]KWLokFig002okFig003o`000?n]/mgo[K?M00;o[K?M00Go0000ojF^
g_nU[]koYJkNo`000005oifXgP04o`000?nFY=koUZCNoiJTgPCo000000?oPioVo`000?mnWNH00omn
WNH01Ol0003oOIkWogfNiommW^Oo000000CoOj7X00?o0000ohBVj_n4Y^X00_n4Y^X01Ol0003oS:g/
ohb]k?n<[Nco000000CoUKC]00?o0000oinmk_nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03
o`000?nabngo/L_]00;o/L_]00Go0000okS@jonhd>_o^=3[o`000002okgCjP03o`000?nmdn[o0000
00Co`MGY00Go0000ol;Ej?o2eNSo`]GXo`00000Tooooo`03o`000?oooooooooo00Wooooo00001?nH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03Wooooo00?o0000okkCj_l000001Ol000000oo1c^Go_/gVokk=iP04okk=iPGo^L_X00?o0000
ok;8j_nbb>X00_nbb>X01Ol0003oZL?/ojW3k?nY`nco000000CoWkg^00Go0000oi>ek_nC]NkoTkG^
o`000003ohR]kPCoOZK]0ol00003ohJRiP03o`000?n6WnCoQYoT00;oQYoT00?o0000ohROhon8Wn<0
0_n8Wn<00ol0003oS:7RohbQhP02ohbQhP?oTjCQ0ol00004ojF/g003o`000?n//M_o[;7K00?o[;7K
00Go0000ok>ffonc]]_o/kKKo`000004okVjfP03o`000?no_mWo_koI00Go00000_o6a=P01?l0003o
bLKGolW6eoo9a]L3o`000003olc8eol0003oc<SF00?o000000?oc<SFo`000?l000000_o;b=L00ol0
003oblOGo`000003olS5f003o`000?o3`]Wo`l;I00;o`l;I00Go0000okfnfonm_]_o_KkKo`000004
okFig005o`000?n]/mgo[K?MojfcgOl000001?nU[]h00ol0003oWJSNoifXgP02oifXgP03o`000?nF
Y=koUZCN00;oUZCN00Co0000oi2Pgon@X=ooT:3O0ol00003ogjMiP03o`000?mmW^OoOIkW00;oOIkW
00Go0000ognQj?moXNSoOj7Xo`000004ohBVjP05o`000?n<[NcoS:g/ohb]k?l000001?nE]>d00ol0
003oWkg^oinmkP02oinmkP03o`000?nYa>goZLC]00;oZLC]00?o0000ok7;kOnabnd00_nabnd01Ol0
003o^=3[okS@jonhd>_o000000?o_M?Z0_l00004ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?oo
ool00ol0003oooooooooo`09ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>Oooool5o`0000Go`LkU1OnncNH00ol0003o^L_XokW;j002
okW;j003o`000?nbb>[o//SZ00;o//SZ00Go0000ojW3k?nY`ncoZL?/o`000004oinmkP03o`000?nC
]NkoTkG^00;oTkG^00Co0000ohR]k_n8[Nko00001?mnY^d2ogRQk0Co00001?n6Wn@00ol0003oR9oS
ohROh`02ohROh`03o`000?n<XN;oS:7R00;oS:7R00Co0000oi>ThOnCY>7oTjCQ0_nKZN03o`000003
ojF/g?l0003o[;7K00?o[;7K00?o0000ok>ffonc]]/00_nc]]/01Ol0003o^K[JokVjf_ni^][o0000
00Co_koI00Co0000olC3f?o4`mSoa<?H1?l00002olW6e`03o`000?o;b=OoblSG00Wo00001?o;amLE
o`000003ojfcgOl0003oYJkN00?oYJkN00?o0000oifXg_nMZ=h00_nMZ=h00ol0003oUZCNoiJTgP02
oiJTgP03o`000?n@X=ooT:3O00;oT:3O00Ko0000ohbOh?l0003o0000ogjMi_l00004ogfNi`05o`00
0?moXNSoOj7XognQj?l000001?n4Y^X01Ol0003oS:g/ohb]k?n<[Nco000000CoUKC]00?o0000oinm
k_nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo/L_]00;o/L_]00Go0000okS@
jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go0000ol;Ej?o2eNSo`]GXo`00
000Tooooo`03o`000?oooooooooo00Wooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0hooooo`?o00000oo2c^@00ol0003o`LkUol7>i@02
ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?nibnP00onibnP01Ol0003o//SZok;8j_nb
b>[o000000CoZL?/00?o0000oinmk_nO_Nh00_nO_Nh01Ol0003oTkG^oi>ek_nC]Nko000000?oR:g^
00Go0000ogjVkOmnY^goOZK]o`000004ogRQk0?o000000?oQYoTo`000?n8Wn<00on8Wn<00ol0003o
S:7RohbQhP02ohbQhP03o`000?nCY>7oTjCQ00;oTjCQ00?o0000oi^Yh?nKZN000_nKZN04o`0000;o
[;7K00Go0000ok>ffonc]]_o/kKKo`000004okVjfP03o`000?no_mWo_koI00;o_koI00?o0000olC3
f?o4`mP00_o4`mP00ol0003ob<KGolS6e`0@o`0000;oblOG00Go0000olS5eoo8aMOob<GGo`000004
olC2f005o`000?no_]Wo_kkIoknnfOl000000oni^]T01?l0003o/kGJok>ef_nc]MX4o`000003ojF^
g_l0003oWJSN00CoWJSN00Go0000oiJTg_nFY=koUZCNo`000004oi2Pg`03o`000?n<Wn3oS9oP00?o
S9oP0_l00003ogfNi`05o`000?moXNSoOj7XognQj?l000001?n4Y^X00ol0003oS:g/ohb]k002ohb]
k005o`000?nE]>goUKC]oiFdkOl000001?nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo
/L_]00;o/L_]00Go0000okS@jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go
0000ol;Ej?o2eNSo`]GXo`00000Tooooo`03o`000?oooooooooo00Wooooo0003ooooo`03o`000?oo
oooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`?o0000=_ooool3o`0000;ooooo
00Go0000ol;>i?o2c^Co`/kTo`000004ol7>i@03o`000?nncNKo_/gV00?o_/gV00?o0000okW;j?ni
bnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l000001?nO_Nh01Ol0
003oTkG^oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01?l0003oN:7/ogRQk?mh
XN`3ogFMjP?o00000on8Wn<00ol0003oS:7RohbQhP02ohbQhP03o`000?nCY>7oTjCQ00;oTjCQ00?o
0000oi^Yh?nKZN000_nKZN04ojB^g`Co00000_nc]]/00ol0003o^K[JokVjfP02okVjfP05o`000?no
_mWo_koIoknofOl000001?o4`mP00ol0003ob<KGolS6e`02olS6e`ko00000_o;amL01Ol0003ob<GG
olS5eoo8aMOo000000Coa<;H00Go0000oknnfOno_]Wo_kkIo`000003okVjf@03o`000?nc]M[o/kGJ
00?o/kGJ00?o0000ojf`f_n]/=X00ol00004oifXgP05o`000?nFY=koUZCNoiJTg_l000001?n@X=l0
0ol0003oS9oPohbOh003ohbOh006o`000?n;Wn;o0000o`000?mmW^Oo00000omoXNP00ol0003oQ:KZ
ohBVjP02ohBVjP03o`000?n<[NcoS:g/00;oS:g/00?o0000oiFdkOnE]>d00_nE]>d01Ol0003oWkg^
oinmk_nO_Nko000000CoZLC]00?o0000ok7;kOnabnd00_nabnd01Ol0003o^=3[okS@jonhd>_o0000
00Co_M?Z0_l00003ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?ooool00ol0003oooooooooo`09
ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0<oooool3o`0000Gooooo00Go0000ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo
_/gV00;o_/gV00?o0000okW;j?nibnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`nco
ZL?/ojW3k?l000001?nO_Nh00ol0003oTkG^oi>ekP02oi>ekP04o`000?n8[NkoR:g^o`0000CoOZK]
00Go0000ogRQk?mhXNcoN:7/o`000003ogFMjP;oMigY1?l00004ohbQhP03o`000?nCY>7oTjCQ00;o
TjCQ00?o0000oi^Yh?nKZN000_nKZN000ol0003oY:kOojB^g`02ojB^g`03o`000?n]]=ko[KCN00Go
000000?o^K[Jo`000?no_mT00ono_mT00ol0003oa<?Ho`000008o`000003ol_7eol0003o000000Ko
000000?oc<SFo`000?o;b=L00_o;b=L8o`0000;oa<;H00Co0000oknnfOno_]Wo00001?ni^]T00ol0
003o/kGJok>efP02ok>efP03o`000?n]/=[o[K3J00;o[K3J00Ko0000ojJ[fol0003o0000oifXg_l0
0004oiJTgP03o`000?n@X=ooT:3O00;oT:3O00?o0000ohbOh?n<Wn000_n<Wn000ol0003oRioRoh^O
hP03oh^OhP?o000000?oOj7Xo`000?n4Y^X00on4Y^X00ol0003oS:g/ohb]k002ohb]k003o`000?nE
]>goUKC]00;oUKC]00Go0000oinmk_nO_NkoWkg^o`000004ojW4k@03o`000?nabngo/L_]00;o/L_]
00Go0000okS@jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo000000;o`MGY00?o0000ol;Ej?o2
eNP00_l0000Uooooo`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool3o`0000Sooooo00?o0000ol;>i?o2
c^@00_o2c^@00ol0003o`LkUol7>i@02ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?ni
bnP00onibnP01Ol0003o//SZok;8j_nbb>[o000000CoZL?/00?o0000oinmk_nO_Nh00_nO_Nh01Ol0
003oTkG^oi>ek_nC]Nko000000?oR:g^00Go0000ogjVkOmnY^goOZK]o`000004ogRQk004o`000?me
WN[oMIgZo`0000CoMigY0_l00003ohbQhP05o`000?nCY>7oTjCQoi>ThOl000001OnKZN000ol0003o
Y:kOojB^g`02ojB^g`05o`000?n]]=ko[KCNojfdg_l000000one^]d8o`0000;o`l?J00?o0000olS6
f?o8a]P00_o8a]P5o`000003olc8e_l0003o000000Co00000_o<b=L2ol_8e`05o`000?o9a]OobLKG
olW6eol000000oo6a=P4o`000003oknnfOl0003o^K[I00;o^K[I00?o0000ok>ef_nc]MX00onc]MX0
1Ol0003o[K3Jojf`f_n]/=[o000000GoYZ_K0_l00003oiJTgP05o`000?n@X=ooT:3Ooi2Pgol00000
1On<Wn000ol0003oRioRoh^OhP03oh^OhP03o`000?n;X^?oRj;S00Go000000?oQ:KZo`000?n<[N`0
0on<[N`00ol0003oUKC]oiFdk@02oiFdk@05o`000?nO_NkoWkg^oinmk_l000001?nYa>d00ol0003o
/L_]ok7;k@02ok7;k@05o`000?nhd>_o^=3[okS@jol000001?nmdnX01Ol0003o`MGYol7EjOl0003o
`MGY00?o000000?o_=W^o`000?ooool09?ooool00ol0003oooooooooo`08ooooo`0000Co<S8bo`00
0?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0;Oooool3o`0000cooooo00Go0000
ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?nibnP00_ni
bnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l000001?nO_Nh01Ol0003oTkG^
oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01Ol0003oN:7/ogRQk?mhXNco0000
00?oMIgZ00Co0000ogNMjOmgWNWoMigY0_mlWnT3o`0000CoTjCQ00?o0000oi^Yh?nKZN000_nKZN00
0ol0003oY:kOojB^g`03ojB^g`05o`000?n]]=ko[KCNojfdg_l000001?ne^]d00ol0003o_KkKokfn
f`02okfnf`05o`000?o3`m[o`l?Jol?3f_l000000_o8a]P2o`0000;oblSG00?o0000ol_8eoo;b=L0
1ol00003olc8e`?o000000?obLKGo`000?o6a=P00oo6a=P01?l0003o`/3Hol;0f?o2`=P3o`0000;o
^K[I00?o0000ok>ef_nc]MX00_nc]MX00ol0003o[K3Jojf`fP02ojf`fP03o`000?nVZm_oYZ_K00?o
YZ_K00?o0000oj6Wfol000000_l00004oi2Pg`03o`000?n<Wn3oS9oP00?oS9oP00?o0000oh^Oh_n;
Wn800_n;Wn800ol0003oRj;Soh^Rh`02oh^Rh`04o`000?n>Y^KoSZKVohjViPGo000000?oS:g/o`00
0?nE]>d00onE]>d01Ol0003oWkg^oinmk_nO_Nko000000CoZLC]00?o0000ok7;kOnabnd00_nabnd0
1Ol0003o^=3[okS@jonhd>_o000000Co_M?Z00?o0000ol7EjOo1eNT00ol00002okcIkP03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool0:_ooool3
o`0000oooooo00Go0000ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o
0000okW;j?nibnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l00000
1?nO_Nh01Ol0003oTkG^oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01Ol0003o
N:7/ogRQk?mhXNco000000?oMIgZ00Go0000ogNMjOmgWNWoMigYo`000003ogbOj@Co000000?oTjCQ
o`000?nKZN000onKZN000ol0003oY:kOojB^g`02ojB^g`03o`000?n]]=ko[KCN00;o[KCN00?o0000
okFjgOne^]d00_ne^]d00ol0003o_KkKokfnf`02okfnf`04o`000?o3`m[o`l?Jol?3fP?o000000Co
alKIo`000?o;b=Oo00000_o;b=L00oo;b=So0000o`000004o`000004olc8eol0003oc<SGo`0000?o
b/OG0_l00003olK4f003o`000?o2`=So`/3H00;o`/3H00?o0000okfmfOnm_MT00ol00003ok>efP03
o`000?n]/=[o[K3J00;o[K3J00?o0000ojJ[fonVZm/00onVZm/00ol0003oXJOKoj6Wf`02oj6Wf`;o
00000on@X=l00ol0003oS9oPohbOh002ohbOh003o`000?n;Wn;oRioR00?oRioR00?o0000oh^Rhon;
X^<00_n;X^<00ol0003oSZKVohjViP02ohjViP04o`000?nB[NSoTZgXoi:]j0Go000000?oUKC]o`00
0?nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo/L_]00;o/L_]00?o0000okS@
jol000002Ol000000onkfNoo0000o`000002okcIkP03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool001Wooooo0_l0000Xooooo`?o00004_ooool00ol0003o`/kTol;>i002ol;>i003
o`000?o1c^Go`LkU00;o`LkU00?o0000okk=i_nncNH00_nncNH00ol0003o^L_XokW;j003okW;j005
o`000?nbb>[o//SZok;8j_l000001?nY`n`00ol0003oWkg^oinmkP02oinmkP05o`000?nC]NkoTkG^
oi>ek_l000000on8[Nh01Ol0003oOZK]ogjVkOmnY^go000000?oN:7/00Go0000ogFMj_meWN[oMIgZ
o`000004ogNMj@03o`000?mlWnWoO9oY00CoQJCX1Ol000000onKZN3o0000ojB^g`03ojB^g`05o`00
0?n]]=ko[KCNojfdg_l000001?ne^]d00ol0003o_KkKokfnf`02okfnf`03o`000?o3`m[o`l?J00?o
00000oo7a]T3o`0000;oblSH00Oo0000ol_9f?l0003o0000olc9eol0003oc<WG00?o00000oo:amL0
1_l0003oalKHolO6f?l0003oa/CHo`0000Co`/3H00?o0000okfmfOnm_MT00_nm_MT01_l0003o^KWI
o`000?l0003o/kGJo`0000?o[K3J00?o0000ojJ[fonVZm/00onVZm/00ol0003oXJOKoj6Wf`03oj6W
f`03o`000?nLYMco000000;o00001On<Wn000ol0003oRioRoh^OhP02oh^OhP03o`000?n;X^?oRj;S
00;oRj;S00?o0000ohjVi_n>Y^H00_n>Y^H00ol0003oTZgXoi:]j003oi:]j004o`000?nH]>_oV;C[
oiRdja7o00000_ncd_000ol0003o^=O`okSGl002okSGl004o`000?nkfNoo^mW_ok_Ik`;o000000?o
_=W^o`000?ooool09_ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0T
ooooo`?o00005_ooool01Ol0003o`/kTol;>i?o2c^Co000000Go`LkU00?o0000okk=i_nncNH00_nn
cNH00ol0003o^L_XokW;j002okW;j003o`000?nbb>[o//SZ00;o//SZ00?o0000ojW3k?l000004_l0
00001OmnY^go0000ogRQk?mhXNco000000?oMIgZ00?o0000ogNMjOmgWNT00_mgWNT01?l0003oO9oY
ogbOjOl00004ohFTj0CoT:WW1Ol000000onT[]oo0000ojfdgP02ojfdgP03o`000?ne^]go]K[M00[o
00000_o2a=/4o`000009olO7f_l0003o0000ol_8f?l0003oblWHo`000?o;bMOo000000;oc<WG0_l0
0002ol[8f003o`000?o:amOo000000CoalKH0_l00003ol;0f003o`000?nm_MWo_KgI00;o_KgI00?o
0000okVifOni^MT00_ni^MT3o`0000;o[K3J00?o0000ojJ[fonVZm/00_nVZm/00ol0003oXJOKoj6W
f`03oj6Wf`03o`000?nLYMcoW:GL00;oW:GL0_l00004ohbOh003o`000?n;Wn;oRioR00;oRioR00?o
0000oh^Rhon;X^<00_n;X^<00ol0003oSZKVohjViP02ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o
0000oiRdjonH]>/00onH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?00
0_n]c?001?l0003o/m;`ok?Bl?l00004okSGl003o`000?nkfNoo^mW_00;o^mW_00Co0000okcIk_l0
003o00009oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`0Rooooo`?o
00006Oooool00ol0003o`/kTol;>i002ol;>i003o`000?o1c^Go`LkU00;o`LkU00?o0000okk=i_nn
cNH00_nncNH00ol0003o^L_XokW;j002okW;j003o`000?nbb>[o//SZ00Co00000_n[`NX00ol0003o
Wkg^oinmkP02oinmkP05o`000?nA]o7oTKOaoi6glOl000000on2/?801?l0003oM:SbogBXl_mdZ?84
o`000005ogRQk?l0003oMIgZogFMj_l000001?mgWNT01Ol0003oO9oYogbOjOmlWnWo000000?oQJCX
00?o0000oi2Yion@ZNL00_n@ZNL01?l0003oW;3Voib`i_nL/>H8o`0000;o/[cQ00?o0000ok_0g_nk
`=h00_nk`=h01?l0003o`/CKol;4foo2a=/2o`0000?oalOJ00?o0000olS8f_o8b=X00_l000001?o;
bMSo0000o`000?o<bML2o`000004ol_9fOl0003ob/SHol[8f0?o00000oo7a]P00ol0003oaLCIolG4
f@02o`000003ol;0f?l0003o_KgI00;o_KgI00?o0000okVifOni^MT00_ni^MT01?l0003o];GJokBe
f_nd]MX3o`0000CoYZ_K00?o0000oj6WfonQYm/00_nQYm/00ol0003oW:GLoibUg003oibUg003o`00
0?nIY=go000000?o00001On;Wn800ol0003oRj;Soh^Rh`02oh^Rh`03o`000?n>Y^KoSZKV00;oSZKV
00?o0000oi:]j?nB[NP00_nB[NP00ol0003oV;C[oiRdj`02oiRdj`05o`000?nO_NgoWkg]oinmkOl0
00001?nVaNl00ol0003o[Lc`ojg<l002ojg<l005o`000?ncd_3o/m;`ok?Bl?l000001?nheo001Ol0
003o^mW_ok_IkonkfNoo000000;o_=W^00?o0000ooooooooool09_ooool00ol0003oooooooooo`08
ooooo`006?ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool00ol0003o`/kTol;>i002ol;>
i003o`000?o1c^Go`LkU00?o`LkU00Go0000okk=i_nncNKo_/gVo`000003okW;j0Co00000_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6glOnA]o7oTKOao`00
0003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo84o`000003ogFMj_l0003oMigY00;oMigY
00Go0000ogbOjOmlWnWoO9oYo`000004ohFTj005o`000?n@ZNOoT:WWoi2Yiol000001?nL/>H01Ol0
003oYkKTojNfi?nW]^Co000000Co/[cQ00?o0000ok_0g_nk`=h00_nk`=h4o`000005ol;6gOl0003o
alOJolO7f_l000000oo8b=X00ol0003obLWJo`000002o`000003ol[:fOl0003oblWI00;oblWI0_l0
0003olS8f@03o`000?o7a]So000000CoaLCI1?l000000onm_MWo0000okVif@03okVif@03o`000?nd
]M[o];GJ00;o];GJ00?o0000ojnaf_n_/MX00_l000000onVZm_o0000oj6Wf`03oj6Wf`03o`000?nL
YMcoW:GL00?oW:GL00?o0000oiVTgOnIY=d00onIY=d2o`0000?oRioR00?o0000oh^Rhon;X^<00_n;
X^<00ol0003oSZKVohjViP02ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o0000oiRdjonH]>/00onH
]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001?l0003o/m;`
ok?Bl?l00004okSGl003o`000?nkfNoo^mW_00;o^mW_00?o0000okcIk_nlfNh00_l0000Xooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Oooooo`05o`00
0?o2c^Co`/kTol;>i?l000001Oo1c^D01?l0003o_/gVokk=i_nncNH4o`0000;o^/KS00?o0000okC4
ionda>L00_nda>L00ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6g
lOnA]o7oTKOao`000003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo800ol0003oI9oaofBO
l@05o`000005ogNMjOl0003oO9oYogbOjOl000001?n5Y>P01Ol0003oT:WWoi2Yion@ZNOo000000Co
W;3V00Go0000ojNfi?nW]^CoYkKTo`000005ok:lh@03o`000?nk`=ko^l3N00;o00001Oo2a]d2o`00
00?ob<SJ00So0000olW9f_o9bM[o0000olW:f_l0003ob/[Io`0000;oblWI0_l00004olS8f@;o0000
1?o5a=T01?l0003o`L;Jol72f_o1`]X3o`0000?o^KWI00?o0000okBef_nd]MX00_nd]MX00ol0003o
[k7JojnafP03ojnafP;o00001?nQYm/00ol0003oW:GLoibUg002oibUg003o`000?nIY=goVJCM00Co
VJCM00Ko0000oiNTg_l0003o0000oh^Oh_l00004oh^Rh`03o`000?n>Y^KoSZKV00;oSZKV00?o0000
oi:]j?nB[NP00_nB[NP00ol0003oV;C[oiRdj`02oiRdj`03o`000?nO_NgoWkg]00;oWkg]00Go0000
ojK5konVaNooY/G_o`000004ojg<l005o`000?ncd_3o/m;`ok?Bl?l000001?nheo001Ol0003o^mW_
ok_IkonkfNoo000000;o_=W^00Co0000oooooooooooo00009oooool00ol0003oooooooooo`07oooo
o`006?ooool2o`0001_ooooo0ol0000Rooooo`03o`000?o2c^Co`/kT00;o`/kT00?o0000ol7>iOo1
c^D00_o1c^D01_l0003o_/gVo`000?l0003o_lOQo`0000Go^/KS00?o0000okC4ionda>L00_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6glOnA]o7oTKOao`00
0003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo801?l0003oI9oaofBOlOl00003ofFOl@Co
000000?oO9oYo`000?n5Y>P00_n5Y>P00ol0003oT:WWoi2Yi`02oi2Yi`03o`000?nL/>KoW;3V00;o
W;3V00Go0000ojNfi?nW]^CoYkKTo`000004ok:lh@?o000000?o^lCQo`000?o2a]d01?o2a]d3o`00
0005olS8f_l0003obLWJolW9f_l000000_o9b]X00ol0003ob/[Io`000002o`000004olW:fol0003o
b<SIolS8f@;o000000?oa/SKo`000?o5a=T00_o5a=T01Ol0003o`L;Jol72f_o1`][o000000?o_KoK
00?o0000okVifOl000001?nd]MX00ol0003o[k7JojnafP03ojnafP03o`000?nZ[m_oZZoK00;o0000
00?oXJOKo`000?nLYM`00onLYM`00ol0003oVJCMoiVTg@04oiVTg@03o`000?nGY=koUjCN00;oUjCN
0_l00004oh^Rh`05o`000?n>Y^KoSZKVohjVi_l000001?nB[NP00ol0003oV;C[oiRdj`03oiRdj`05
o`000?nO_NgoWkg]oinmkOl000001?nVaNl00ol0003o[Lc`ojg<l002ojg<l005o`000?ncd_3o/m;`
ok?Bl?l000000onheo000ol0003o^mW_ok_Ik`02ok_Ik`04o`000?nlfNko_=W^o`0000;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0G
ooooo`?o00009Oooool00ol0003o`/kTol;>i002ol;>i003o`000?o1c^Go`LkU00;o`LkU0_l00004
oko7h@03o`000?nja^?o^/KS00?o^/KS00?o0000okC4ionda>L00_nda>L00ol0003oZl7Zoj_1jP02
oj_1jP05o`000?nO_NkoWkg^oinmk_l000001?nA]o401Ol0003oP[3boh:`l_n2/?;o000000?oM:Sb
00Co0000ofZSl_mZXo;o00000_mTWo401Ol0003oIIoaofFOlOmUWo7o000000;oK:;a1Ol000000on5
Y>So0000oi2Yi`02oi2Yi`03o`000?nL/>KoW;3V00;oW;3V00Go0000ojNfi?nW]^CoYkKTo`000002
ok:lh@?o00001?nka>401?l0003o`/KMo`000?l00004ol?8gP;o000000KobLWJo`000?o9b][obL[J
o`000?o:b]T2o`0000CobL[K0_l00004olK8f`03o`000?o5a=Wo000000?o`L;J00?o0000okfofonm
_m/00_nm_m/3o`0000?o];GJ00?o0000ojnaf_n_/MX00on_/MX00ol0003oZZoKojZ_f`02ojZ_f`?o
00001?nLYM`00ol0003oVJCMoiVTg@03oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o0000oiJVhOl0
00000ol00004ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o0000oiRdjonH]>/00_nH]>/00ol0003o
Wkg]oinmk@02oinmk@05o`000?nVaNooY/G_ojK5kol000001?n]c?001Ol0003o/m;`ok?Bl?ncd_3o
000000Co^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP05o`000?ooooooooooooooool00000
9_ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o0000:Ooo
ool01_l0003o`/kTol;>i?o2c^Co0000ol7>i@?o000000?o`/SOo`000?noan401?noan400ol0003o
^/KSok[6h`03ok[6h`03o`000?nda>Oo]<CW00;o]<CW00?o0000oj_1j_n[`NX00_n[`NX01Ol0003o
Wkg^oinmk_nO_Nko000000?oTKOa00Go0000oh:`l_n2/?;oP[3bo`000004ogBXlP04o`000?mZXo;o
JZ?bo`0000;oI9oa00Go0000ofFOlOmUWo7oIIoao`000002ofbRl@04o`000?mhZ?7oN:SaogRXlA7o
00000_na`>H00ol0003o^lCQok_4h@03ok_4h@03o`000?o3b=ko`lSN00;o`lSN00Co0000olG;goo5
bmooaL_O1_l000000oo8c=go0000olW:f`02olW:f`;o00001Oo6b=/2o`0000?o`L;J00?o0000okfo
fonm_m/00_nm_m/01ol0003o^KgLokVmg?ni_Mco0000okBef_l000001On_/MX00ol0003oZZoKojZ_
f`02ojZ_f`04o`000?nV[McoYZgLojJ]g0;o000000?oW:GLo`000?nIY=d01?nIY=d00ol0003oUjCN
oiNTgP03oiNTgP03o`000?nFY^7oUZKQ00?oUZKQ0ol00002ohjViP03o`000?nB[NSoTZgX00;oTZgX
00?o0000oiRdjonH]>/00_nH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]
c?000_n]c?001Ol0003o/m;`ok?Bl?ncd_3o000000?o^=O`00Go0000ok_IkonkfNoo^mW_o`000003
okcIkP03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`005oooool00ol0003oooooooooo`0Booooo`?o0000;?ooool01?l0003o`/kTol;>i?o2c^@2
o`0000Go`/SO00?o0000oko7hOnoan400onoan400ol0003o^/KSok[6h`02ok[6h`03o`000?nda>Oo
]<CW00?o]<CW00Go0000oj_1j_n[`N[oZl7Zo`000004oinmkP05o`000?nA]o7oTKOaoi6glOl00000
0on2/?801Ol0003oM:SbogBXl_mdZ?;o000000?oJZ?b00Co0000ofBOlOmTWo7o00000omUWo401?l0
003oK:;aofbRlOl00003ogRXl@05o`000?n6[o3oQZo`ohJ_l?l000001?nF]^h01Ol0003oY;cZojBl
j_nT_>[o000000Go/L3V00Co0000ok_4hOl0003o00000onlb><00ol0003o`lSNo`000004olG;g`05
o`000?o6c=koa/cNolK<g_l000000_o8c=d01_l0003obL[Ko`000?l0003oa/_No`0000?oa/SK0_l0
0002ol?7g@03o`000?o1`][o000000?o_KoK0_l00004okVmg0;o00001On_/MX00ol0003oZZoKojZ_
f`02ojZ_f`03o`000?nV[McoYZgL00?oYZgL0_l00005oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o
0000oiJVhOnFY^400onFY^401?l0003oUj[ToiNZi?nGZ^@3o`0000?oTZgX00?o0000oiRdjonH]>/0
0onH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001?l0003o
/m;`ok?Bl?l00004okSGl005o`000?nkfNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo00?o0000oooo
ooooool03oooool3o`0002oooooo00Ko0000ol;>i?l0003o0000ol;8g_l00006ol;8g`03o`000?no
an7o_lOQ00?o_lOQ00?o0000ok[6honja^<00_nja^<00ol0003o]<CWokC4i`02okC4i`03o`000?n[
`N[oZl7Z00;oZl7Z00Go0000oinmk_nO_NkoWkg^o`000004oi6gl@05o`000?n2/?;oP[3boh:`l_l0
00000omdZ?801?l0003oJZ?bofZSl_l00002ofBOl@05o`000?mUWo7oIIoaofFOlOl000000om/X_40
1Ol0003oN:SaogRXlOmhZ?7o000000?oQZo`00?o0000oiJfk_nF]^h00_nF]^h01Ol0003oY;cZojBl
j_nT_>[o000000Go/L3V00?o0000okc8honlb><01?nlb><00ol0003oaL_Oo`000002olG;g`06o`00
0?o6c=koa/cNolK<g_l0003ob<cM0ol00005olK;gP?o00001?o3amd2o`0000?o_KoK00?o0000okVm
g?ni_M`00oni_M`01?l0003o]K[MokFjgOl00003ojnafP03o`000?nZ[m_oZZoK00;oZZoK00?o0000
ojJ]g?nV[M`00onV[M`01?l0003oXjcMoj>/gOl00003oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o
0000oiJVhOnFY^400onFY^400ol0003oUj[ToiNZi003oiNZi006o`000?nH[nOo0000o`000?nB[NSo
00001?nH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001Ol0
003o/m;`ok?Bl?ncd_3o000000?o^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2
o`0000gooooo0ol0000cooooo`03o`000?o2b=ko`/SN00;o`/SN00?o0000ol;8goo2b=l01?o2b=l0
0ol0003o_lOQoko7h@02oko7h@03o`000?nja^?o^/KS00?o^/KS00?o0000okC4ionda>L00_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP05o`000?nO_NkoWkg^oinmk_l000001?nA]o401Ol0003oP[3boh:`
l_n2/?;o000000?oM:Sb00Co0000ofZSl_mZXo;o00000_mTWo401Ol0003oIIoaofFOlOmUWo7o0000
00?oK:;a00Go0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00;oU[K^00Ko0000
ojBlj_nT_>[oY;cZo`000?na`>H2o`0000?o//KY00Go0000okc8honlb>?o_<SSo`000003okk<i0So
00000_o5c^400ol0003oa/_NolK;gP02olK;gP;o00001?o3amd2o`0000;o`<KO00?o0000okfofol0
00001Oni_M`00ol0003o]K[MokFjg@02okFjg@03o`000?n_/M[o000000CoZZoK00?o0000ojJ]g?nV
[M`00onV[M`00ol0003oXjcMoj>/g@02oj>/g@03o`000?nIY=go000000GoUjCN00?o0000oiJVhOnF
Y^400onFY^400ol0003oUj[ToiNZi003oiNZi003o`000?nH[nOoV:oW00;oV:oW1?l00002oiRdj`05
o`000?nO_NgoWkg]oinmkOl000001?nVaNl00ol0003o[Lc`ojg<l002ojg<l004o`000?ncd_3o/m;`
o`0000Co^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`09
ooooo`?o0000=_ooool00ol0003o`/SNol;8gP03ol;8gP03o`000?o2b=oo`/SO00Co`/SO00?o0000
oko7hOnoan400_noan400ol0003o^/KSok[6h`03ok[6h`03o`000?nda>Oo]<CW00;o]<CW00?o0000
oj_1j_n[`NX00_n[`NX01Ol0003oWkg^oinmk_nO_Nko000000;oTKOa3_l00002ofBOl@04o`000?mU
Wo7oIIoao`0000?oK:;a00Go0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00;o
U[K^00?o0000ojBlj_nT_>X00ol00006ok;6j@03o`000?nlb>?o000000Go_/cT00Go0000ol;>hoo2
c^?o`/kSo`000004olG>h@03o`000?o6bmko000000;o000000?o`lcQo`000?o3amd00_o3amd00ol0
003o`<KOol36g`02ol36g`;o00001?ni_M`2o`0000Go]K[M0ol00003ojZ_f`03o`000?nV[McoYZgL
00;oYZgL0_l00005oj>/g@?o00001?nGY=h00ol0003oUZKQoiJVh@03oiJVh@03o`000?nGZ^CoUj[T
00?oUj[T00?o0000oiR_ionH[nL00_nH[nL00ol0003oVkKZoi^fjP02oi^fjPCo00000_nO_Nd01Ol0
003oY/G_ojK5konVaNoo000000Co[Lc`00Go0000ok?Bl?ncd_3o/m;`o`000003okSGl005o`000?nk
fNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003[ooooo00?o
0000ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ00?o
0000ok[6honja^<00onja^<00ol0003o]<CWokC4i`02okC4i`03o`000?n[`N[oZl7Z00;oZl7Z00?o
0000oinmk_nO_Nh00ol00004oi2jl`CoP;Cf1?m`[oL00omRZOOo0000o`000006o`0000?oK:;a00Go
0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00Co00001?nUa>l00ol0003o//KY
ok;6j@03ok;6j@04o`000?nnc>Co0000o`0000;o_/cT00Go0000ol;>hoo2c^?o`/kSo`000002olG>
h@Go00001Oo3c>43o`0000?o`<KO0_l000000onla^;o0000okVmg002okVmg003o`000?ne^]go]K[M
00?o]K[M0_l00003ok6hgP03o`000?nZ[m_o000000CoYZgL00?o0000oj>/gOnS[=d01?nS[=d01?l0
003oX:cOoj2/gonP[=l2o`000003oiNTg_l0003oUZKQ00CoUZKQ00?o0000oiNZi?nGZ^@00onGZ^@0
0ol0003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00Co0000oinmkOnO_NgoWkg]1?l0
0002ojK5k`03o`000?n]c?3o[Lc`00;o[Lc`00Go0000ok?Bl?ncd_3o/m;`o`000003okSGl005o`00
0?nkfNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool00oooool3o`0003kooooo
00?o0000ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ
00?o0000ok[6honja^<00_nja^<00ol0003o]<CWokC4i`03okC4i`03o`000?n[`N[oZl7Z00Co0000
0onO_Nh5oi2jl`05o`000?n0]?KoP;Cfoh2dm_l000000om`[oL3of:Ym`CoFZKg3ol00004oiFom003
o`000?nUa>ooYLC_00;oYLC_00Co0000ok;6jOl0003o00001Onfc>/9o`0000?o`M3V00?o0000ol?<
hOo3c>400_o3c>43o`0000?o`<KO0_l00004okc6hP03o`000?ni_Mco000000Co]K[M0_l00005ok6h
gP?o00000onV[M`00ol0003oXjcMoj>/g@03oj>/g@;o00001OnP[=l3o`0000CoUZKQ00?o0000oiNZ
i?nGZ^@00onGZ^@00ol0003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000oinm
kOnO_Nd00_nO_Nd01?l0003oY<C`ojC4l?nTa?0Go`0000cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo00?o0000
ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00;o_lOQ00?o0000
ok[6honja^<00onja^<00ol0003o]<CWokC4i`02okC4i`?o00001?nZ_nT4oinmkP03o`000?n@^_?o
T;[c00;oT;[c0_l00002oh2dmP05o`000?m`[oOoL:ogog2_mol000000_mRZOL01?l0003oFZKgoeZV
mol00002oeZVm`CoHZ_h1?m`/OT4oh:in003o`000?nE_oCoUKod00;oUKod00?o0000ojG4konUa>l0
0_nUa>l00ol0003o]/c[okK<j`05okK<j`03o`000?nkd>Wo^m3Y00?o^m3Y00?o0000ol7@i_o1d>H0
0oo1d>H00ol0003o`lcQo`000002o`0000;o_lgU00Co0000ol36gol0003o00001_nla^82o`0000Co
]K[M00?o0000ok6hg_na^=h00ona^=h2o`0000?o[KOP00?o0000ojJ]g?l000001OnS[=d00ol0003o
X:cOoj2/g`04oj2/g`04o`000?nN[N7oWZgQoij]h@;o000000?oUZKQo`000?nGZ^@01?nGZ^@00ol0
003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000oinmkOnO_Nd00_nO_Nd00ol0
003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l000000on/dO<01Ol0003o/=Kdok3Fm?n`
e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000=ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`03o`000?o2b=ko`/SN00?o`/SN00?o
0000ol;8goo2b=l00oo2b=l00ol0003o_lOQoko7h@02oko7h@03o`000?nja^?o^/KS00?o^/KS00Co
0000okC4iol0003o00000onc`>@5ojZoj@03o`000?nO_NkoWkg^00;oWkg^00?o0000oi2jlon@^_<0
0_n@^_<01Ol0003oP;Cfoh2dm_n0]?Ko000000;oL:og0_l000001OmRZOOo0000oeZVmomJY_Oo0000
00;oFZKg00Go0000of:[n?mRZoSoHZ_ho`000003og2an@;o00000_n2^OP2o`0000?oUKod00?o0000
ojG4kol000001?nZc?83o`000003okK<jol0003o^m3Y00Co^m3Y00Co0000ol7@i_o1d>Ko`M3V1Ol0
0005oko=i@;o00001_nla^82o`0000;o^<GT00Co0000okFjgOl0003o00001?na^=h2o`0000Go[KOP
0ol00003oj>/g@;o00001OnP[=l2o`0000GoWZgQ0ol00004oiNZi003o`000?nH[nOoV:oW00;oV:oW
00?o0000oi^fj_nK]^X00onK]^X00ol0003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`
00Go0000ojS;l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0
003o]=ScokCHlondf??o000000oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06
ooooo`005_ooool2o`0004Wooooo00?o0000ol;8g_o2b=h00_o2b=h00ol0003o`/SOol;8g`03ol;8
g`03o`000?noan7o_lOQ00?o_lOQ00?o0000ok[6honja^<00_nja^<2o`0000Ko/l3T00?o0000ojZo
jOnZ_nT00onZ_nT01?l0003oWkg^oinmk_nO_Nh2o`0000?oT;[c00Co0000oh2dm_n0]?KoP;Cf0_l0
0002og2_m`04o`000?mRZOOoHZWgo`0000;oFZKg00Co0000oeZVmol0003o00000omRZoP2o`0000;o
L;7i00Go0000oh:in?n2^OSoP[Who`000002oiFom0;o00002?nZc?8;o`0000?o^m;[00Co0000oko=
iOnocNGo_lgU0ol000000onkc^Wo0000okc6hP02okc6hP?o00001?nhaN@2o`0000Co/KSN0_l00005
ojfgh0;o00000onZ]^800ol0003oXjcMo`000006oj2/g`03o`000?nN[N7oWZgQ00CoWZgQ00Co0000
oif_i?nM[nCoWJoT0_l000000onGZ^Co0000oiR_i`03oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o
0000oinmkOnO_Nd00_nO_Nd00ol0003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l00000
0on/dO<01Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Aoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool000cooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00?o0000ol;8g_o2b=h00_o2b=h00ol0003o
`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ00Co0000ok[6hol0003o00000oni`N07ok?0
i003o`000?nZ_nWoZ[oY00;oZ[oY0_l00003oinmkP04o`000?n@^_?oT;[coi2jl`;o00000on0]?H0
1?l0003oL:ogog2_mol00002of:Ym`04o`000?mJY_OoFZKgo`0000;oFZKg00?o0000of:[n?mRZoP0
0_mRZoP01?l0003oL;7iog2anOl00002oh:in0?o00001?nKb_P3o`0000;oZ/cb00?o0000ok;Al?nb
dO001OnbdO000ol0003o^m;[ok_Bj`04ok_Bj`04o`000?nocNGo0000o`0000Go^lkY0ol00004okS5
i0?o00000_nda>H01?l0003o/KSNo`000?l00004ojfgh0?o00001OnZ]^82o`0000KoX:cO00?o0000
oij]hOnN[N400onN[N42o`0000GoWJoT0ol00003oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000
oinmkOnO_Nd00_nO_Nd00ol0003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l000000on/
dO<01Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`17ooooo`03o`000?o2b=ko`/SN00;o`/SN00?o0000ol;8goo2b=l0
0oo2b=l00ol0003o_lOQoko7h@02oko7h@;o00001_ni`N000ol0003o/l3Tok?0i004ok?0i003o`00
0?nZ_nWoZ[oY00?oZ[oY00Go0000oinmk_nO_NkoWkg^o`000004oi2jl`05o`000?n0]?KoP;Cfoh2d
m_l000000_m`[oL01?l0003oHZWgof:Ymol00002oeZVm`04o`000?mJY_OoFZKgo`0000;oHZ_h1ol0
0003ohW6o0?o00001?nKb_P2o`000004ok;Al?l0003o0000o`0000?o/]7`00Co0000ok_Bjonkd^_o
^m;[1Ol00006ok_>j@?o00001?nhaN@2o`0000Go]<CV0_l00004ojfgh0;o00001_nZ]^82o`0000;o
Y[GS00Co0000oj2/gonP[=ooX:cO0_l00004oij]h@;o00001OnM[n@2o`0000?oWK?W00?o0000oiR_
iol000001OnK]^X00ol0003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;
l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCH
londf??o000001Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`003_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ol;8g_o2b=h00oo2
b=h00ol0003o`/SOol;8g`03ol;8g`04o`000?noan7o0000o`0000?o_L7M1oni`N000ol0003o/l3T
ok?0i003ok?0i0;o00001?nZ_nT01?l0003oWkg^oinmk_nO_Nh2o`0000?oT;[c00?o0000oh2dm_n0
]?H03ol00004ofNio@03o`000?mf_ogoM[om00;o00001?n9a_`3o`000003oi_:n?l0003oYm;f00Co
Ym;f1ol00004ok?Cl@03o`000?nkc^Wo000000Co00000_nec^d00ol0003o^<GTo`000002o`0000Co
]<CV0ol00002ok32j004o`000?n]]n3o0000o`0000KoZ[KR0_l00005ojJeh`03o`000?nP[=oo0000
00GoWZgQ00?o0000oif_i?nM[n@01?nM[n@00ol0003oWK?Woifci`03oifci`?o00001?nK]^X00ol0
003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;l_nXbo;oZ<_bo`000003
ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCHlondf??o000001Kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooooooo
o`0:ooooo`;o0000Aoooool00ol0003o`/SNol;8gP03ol;8gP03o`000?o2b=oo`/SO00;o`/SO0_l0
0006okg1g@;o00001Oni`N02o`0000Go/l3T00?o0000ojZojOnZ_nT00_nZ_nT2o`0000?oWkg^00?o
0000oi2jlon@^_<00ol00003oh>kn0?oLkSk00Co0000ofJdnomV]?_o00000omN/o/2oejdo003o`00
0?mW^OgoIkWm00?oIkWm0ol000001?mf_ogo0000o`000?l00003ohW6o003o`000?nWd_KoYm;f00Ko
Ym;f00Co0000ok?ClOncdo7o/m?a1ol00006okG>k@?o00001?nda>H3o`0000Go/<;X0_l00006ojZf
hP;o00001onV]N<3o`0000?oWZgQ0_l00005oif_i0;o00001?nM/nL2o`0000?oW[SZ0_l000000onK
]^[o0000oinmk@03oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;l_nXbo;oZ<_bo`000003
ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCHlondf??o000001Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000ol;8g_o2b=h00oo2b=h01?l0003o`/SOo`00
0?l00003oko1f`Oo_L7M00?o0000okW1h?ni`N001?ni`N000ol0003o/l3Tok?0i003ok?0i0;o0000
1?nZ_nT00ol0003oWkg^oinmkP03o`0000?oT[cd1On3^oP00ol0003oLkSkog>hn`02o`0000;oI[Ck
0_l00002oejcn`;oG[Cl0ol00003ofNio@;o00000_mf_od2o`0000KoVM3k1?l000001?ncdo7o0000
o`000?l00005oj[DmP03o`000?nec^go]Lk]00Go00000_n`c_000ol0003o]<CVo`000002o`0000Go
/<;X0ol000000on/`NWo0000ojZfhP03ojZfhP;o00001_nV]N<3o`0000?oY;KU00?o0000oij]hOl0
00001OnM[n@2o`0000GoWK?W00?o0000oijhj_nN^>X01?nN^>X4o`0000;oWkg]00?o0000ojC4l?nT
a?000onTa?001Ol0003oZ<_bojS;l_nXbo;o000000?o[=7c00Go0000ok3Fm?n`e_Co/=Kdo`000004
ok;Hl`05o`000?ndf??o]=ScokCHlol000006Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool0
0ol0003o`/SNol;8gP03ol;8gP03o`000?no`M_o_l7K00Co_l7K00?o0000okg1gOnm`Md01?nm`Md2
o`0000Go^L7P0_l00005ok?0i004o`000?nZ_nWoZ[oYojZoj@?o00000onO_Nh00ol0003oT[cdoi:l
m002oi:lm003o`000?n3^oSoPk_h00;oPk_h0_l000001Omc^?_o0000o`000?l0003oI[Ck00;o0000
0omN/o/00ol0003oG[Clo`000002o`0000;oIkWm00?o0000oh[=o_n:cOh01On:cOh5o`0000;oZ]Cf
2ol00005ok3>l0Co00001On``^P3o`0000Go[<7Y00Co0000ojZfh_l0003o00001OnV]N<3o`0000Ko
Y;KU0ol00004oif_i003o`000?nM/nOoWK?W00?oWK?W0_l00005oijhjP;o00001?nO_Nd3o`0000Co
Y<C`00Go0000ojS;l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<0
1Ol0003o]=ScokCHlondf??o000001_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00Go0000
ol;8g_o2b=ko`/SNo`000009oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000okW1h?ni`N001?ni
`N000ol0003o/l3Tok?0i003ok?0i003o`000?nZ_nWo000000?oZKgX00?o0000oinmk_nO_Nh00_nO
_Nh2o`0000?oT[cd0_l00003oh>kn0;o00000_mc^?/2o`000004ofJdnol0003o0000o`0000?oG[?k
00?o0000oejdo?l000001Ommb?l5o`0000?oR/gn00?o0000oj7CnOnQdoT02?nQdoT00ol0003o/<k`
o`000005o`0000?oZ/gb00?o0000ok32j?n``^P00ol00007ojc1j@?o00001OnV]N<2o`0000KoY;KU
0ol00003oj:gi`04o`000?nM[nCo0000o`0000CoWK?W0_l00005oijhjP;o00001?nO_Nd2o`0000?o
X/;`0_l000000onTa?3o0000ojS;lP02ojS;lP05o`000?n/dO?o[=7cojcAlol000000on`e_@00ol0
003o/]Scok;Hl`02ok;Hl`05o`000?ndf??o]=ScokCHlol000007Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Gooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00016oooo
o`03o`000?o2b=ko000000Co_l7K00?o0000oko1fono`M/01?no`M/00ol0003o_L7Mokg1g@04okg1
g@03o`000?ni`N3o^L7P00Co^L7P0_l00003ok?0i0;o00001_nY_NP2o`0000CoWkg^0_l00003oi:l
m0;o00000_n3^oP2o`0000;oLkSk0_l000001?mV]?_o0000o`000?l00004og?2oP;o000000?oMLCo
o`000?l000000_l00003ogg8o`?o00000_nQdoT;o`0000OoZ/gb1Ol00005ojc1j@Go00000onX`>/0
0ol0003oY[GSo`000002o`0000GoY;KU0ol00006oj:gi`?o00001?nM/nL00ol0003oW[SZoijhjP03
oijhjP;o00001OnO_Nd00ol0003oX/;`oj;2l004oj;2l0Co000000?oZ<_bo`000?n/dO<00_n/dO<0
1Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Oooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002;ooooo00?o0000ooooooooool0A?oo
ool00ol0003o_l7Koko1f`05oko1f`03o`000?no`M_o_l7K00?o_l7K0_l00005okg1g@;o00001_ni
`N000ol0003o/l3To`000003ok2lh`03o`000?nY_NSoZKgX00CoZKgX0_l00004oinmkP;o00000onB
_?@2o`0000;oPk_h0_l000000omc^?_o0000o`000004ogS1o@;o00001Omc`_h4o`000004ogG4ool0
003o0000o`0000GoV=7k00?o0000oiSAnonHdO/00onHdO/00ol0003oZ/gboj[=lP07o`0000?oYL_d
00?o0000ojc1jOn/`NT01?l00007ojS0j`?o00001OnT]^D3o`0000KoX[OW0ol00003oj6hj@04o`00
0?nM/nOo0000o`0000GoW[SZ00?o0000oinmkOnO_Nd00onO_Nd2o`0000GoX/;`0_l00003ojC7lPSo
000000?o/=Kdo`000?nbf?<00onbf?<01Ol0003o]=ScokCHlondf??o0000023ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`15ooooo`Oo
_l7K0_l00005oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000okW1h?ni`N001?ni`N000ol0003o
/;cSok2lh`04ok2lh`;o00001OnY_NP3o`0000?oWkg^0ol00002oi:lm0;o000000?oPk_ho`000?l0
00001?n1`O`2o`0000GoN<7m1?l00002og?2oP;o00002?nAc_`8o`0000CoYL_d2Ol00006ojS0j`Go
00000onU_n`00ol0003oY;KUo`000002o`0000KoX[OW0ol00005oj6hj@Co00001?nN^>X2o`0000Co
Wkg]0_l00005oj;2l0;o00000onTao82o`0000;oY/cd0_l00003ojS?m0Co00000_nbf?<01Ol0003o
]=ScokCHlondf??o000002;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04oooo
o`009?ooool2o`0004Kooooo0_l00006oko1f`03o`000?no`M_o_l7K00?o_l7K0_l00005okg1g@;o
00000oni`N001?l0003o]KcOokFlgol00006ok2lh`;o00001_nY_NP2o`0000CoWkg^0_l000000onB
_?Co0000o`000004oh_0n003o`000?n1`OcoPL7l00?oPL7l0ol00005ogS1o@;o00002?n>bo`=o`00
00OoXLWe00?o0000ojS0jonX`>/01Ol00007ojFok0?o00001_nR]nL3o`0000GoXKSY0ol00004oj2j
k004o`000?nN^>[o0000o`0000CoWkg]0_l00005oj;2l0;o00001?nTao801Ol0003oY/cdojK<m?nV
c?Co000000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@4o`000003okCHlol0003ooooo02?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15
ooooo`03o`000?no`M_o_l7K00Co_l7K0_l00005oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000
okW1h?l000001One_=l2o`0000Go/;cS0ol00005ojVmj0;o00001?nO_Nh00ol0003oU[odoiJom002
oiJom003o`000?n;`?SoRl3h00?oRl3h0ol00002oh71o0Co00000_mh`Od00ol0003oS/Skohk8n`02
ohk8n`Oo00000on>bo`00ol0003oXLWeoj79m@05oj79m@Wo00001onU_n`5o`0000?oX[k]00?o0000
oj:gionR]nL00ol00005oj6hj@?o00001_nP^^`4o`0000CoWkg]00?o0000oj;2l?nR`_000onR`_02
o`0000CoY<Ob0_l00002ojK<m0;o00000onXco@2o`0000CoZ]7d00Co0000ojcBm?n/d_Co[=;d0_l0
000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002Oooooo00?o0000
ooooooooool0AOooool2o`0000Ko_l7K00?o0000oko1fono`M/00ono`M/00ol0003o_L7Mokg1g@04
okg1g@03o`000?ne_=oo]KcO00Ko]KcO0_l00006ok2lh`;o00001OnY_NP2o`000003oinmk_l0003o
Wkg^00;oWkg^1OnF_o@4o`0000?oRl3h1?l000000on1`Oco0000o`00000<ohk8n`_o00001onNa_@0
1?l0003oYKo/ojFok?nU_n`5o`0000KoX[k]1Ol00005oj6hj@?o00001_nP^^`3o`0000CoX;g]00Co
0000oinmkOl0003o00001?nR`_02o`0000CoY<Ob0_l00002ojK<m0;o00001?nXco@00ol0003oZ]7d
oj[Am002oj[Am0;o00000_n/d_@2o`0002Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`04ooooo`00:?ooool00ol0003oooooooooo`16ooooo`03o`000?no`M_o_l7K00Co_l7K0_l0
0004oko1f`;o00000onm`Md01?l0003o^;_LokRkg?l00008okFlg`;o00001_n`_><2o`0000GoZKgX
00?o0000oinmk_nO_Nh01OnO_Nh2o`0000CoU[od0ol00004oh_0n0;o00002On@aOTJo`0000KoX[k]
1Ol00004oj6mk@03o`000?nQ^>WoXKSY00?o00001OnP^^`4o`0000OoX;g]0_l00004oj;2l0;o0000
1?nTao82o`0000?oY/cd00?o0000ojS?m?nXco@00_nXco@2o`0000?oZ]7d0_l00003ojcBm003o`00
0?oooooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00:Ooo
ool2o`0004Oooooo0_l00006oko1f`03o`000?no`M_o_l7K00?o_l7K00?o0000okg1gOl000001_nh
^m`00ol0003o]KcOokFlg`05okFlg`;o00001_n`_><2o`000003ojVmj?l0003oY[cX00?oY[cX00?o
0000oinmk_nO_Nh01_nO_Nh3o`0000;oU[od0ol00002oh_0n003o`000?nE`oKoUL?f00;oUL?f2Ol0
0003oi35n@03o`000?nMa?CoWLCd00goWLCd00Co0000oj:nkOnR_^goX[k]1Ol00007oj6mk@Go0000
1OnP^^`3o`0000SoX;g]0ol00002oj30k`04o`000?nR`_3o0000o`0000CoY<Ob0_l00003ojK<m0;o
00000onXco@2o`0000CoZ]7d00Co0000ojcBm?n/d_Co[=;d0_l0000]ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0A_ooool00ol0003o
_l7Koko1f`04oko1f`;o00000ono`M/2o`0000Wo^;_L0_l00006okFlg`;o00001_n`_><00ol0003o
Y[cXojJlj006ojJlj0?o00001onO_Nh3o`000003oiJom?l0003o000000koUL?f5ol00006oj6mk@Ko
00001?nP_Nh00ol0003oX;[/oj2jk003o`0000SoX;g]0ol00005oj30k`?o00001?nTao801?l0003o
Y/cdojK<m?nVc?@2o`0000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@2o`0000;o[=;d0_l0000_oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool002cooooo00?o0000oooooooo
ool0A_ooool2o`0000Ko_l7K00?o0000oko1fol000000onj^mX00ol0003o^;_LokRkg007okRkg0?o
00001One_=l2o`0000Co/;cS00Co0000ojbjhon/^^?o00002?nV_>P3o`0000OoWkg^0_l00006oi[0
lPWo00000onE`oH00ol0003oWL;boig2lP0>oig2lP04o`000?nQ_NgoXKg]oj6mk@Go00002?nP_Nh5
o`0000SoX;g]0ol00005oj30k`?o00000onQ`o001?l0003oY<Obo`000?l00003ojK<m003o`000?nX
coCoZ<od00;oZ<od0_l00003oj[Am0;o00000_n/d_@2o`0003;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003oooooooooo`17ooooo`03o`000?no`M_o
_l7K00Co_l7K00?o0000okZkf_nj^mX01Onj^mX2o`0000So^;_L0_l00005okFlg`;o000000?o/;cS
o`000?n/^^<01On/^^<3o`0000KoY[cX0ol00005oinmkP04o`000?nO_NkoWkg^oinmkPOo00001OnJ
`?8Ho`0000OoX;g^1_l00003oj2mkP03o`000?nP_NgoX;g]00CoX;g]0ol00005oj30k`?o00001OnQ
`o05o`000003ojK<m?l0003o000000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@01Ol0003o[=;dojcB
m?n/d_Co000003Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00;_oo
ool2o`0004Sooooo0_l00003oko1f`04o`000?nk^mWo^k_Io`0000Oo^[_J0ol00007okRkg0;o0000
1One_=l00ol0003o[;[Sojbjh`08ojbjh`Co00001OnV_>P3o`000003oinmk_l0003oWkg^00[oWkg^
1_l00002oi[0lP03o`000?nN_o3oW[o`00ooW[o`00Co0000oj2mk_nP_NkoX;g^1_l0000:oj2mkP03
o`000?nP_NgoX;g]00?o00001OnP`>l3o`0000GoXL?`0ol00004oj;5l@?o00000onXco@2o`0000?o
Z]7d0_l00002ojcBm0;o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000oko1fol000001_nk^mT2o`0000Ko^[_J
0_l00007okRkg0?o000000?o]KcOo`000?n`^Ml00_n`^Ml2o`0000[o[;[S0ol00005ojJlj003o`00
0?nO_NkoWkg^013oWkg^6?l0000<oj2mkPOo00001OnP`>l3o`0000GoXL?`0ol00004oj;5l@?o0000
0onTao800ol0003oZ<odo`000003oj[Am0;o00000_n/d_@2o`0003Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`17ooooo`03o`000?nk
^mWo^k_I00Oo^k_I0_l00006okZkfP?o00001onh^m`00ol0003o/;WOok2ig`06ok2ig`Go00001_n/
^^<3o`0000;oY[cX00?o0000ojBkjOnT^nT00onT^nT;o`0000CoWkg^00?o0000oinmk_nO_Nh04?nO
_Nh00ol0003oX;g^oj2mkP03oj2mkPWo00001_nP_Nd00ol0003oX<3_oj30k`03o`0000GoXL?`0ol0
0004oj;5l@?o00001_nTao84o`000003oj[Am?l0003o[=;d00;o[=;d00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000booooo`03o`000?oooooo
oooo04Sooooo00?o0000ok^kfOnk^mT01onk^mT3o`0000Ko^[_J0_l00005okRkg003o`000?nc^=go
/kSM00;o00002On`^Ml4o`0000Go[;[S0_l0000AojBkjAgo00003OnP_Nd5o`0000GoXL?`0ol00004
oj;5l@?o00001_nTao83o`0000?oY/Sb0ol000000on/d_Co0000o`00000nooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00oooool003?ooooo0_l0001;ooooo`;o00002?nk^mT2o`00
00Ko^[_J0ol000000onh^mco0000ok>hg@06ok>hg@?o00002?n`^Ml4o`0000;o[;[S00?o0000ojRi
i_nX^NH00_nX^NH7o`0000[oY;_Y00?o0000oj:ljonR_>/04OnR_>/00ol0003oX;g]oj2mk@08oj2m
k@Oo00001?nQ_^d00ol0003oXL?`oj73l003o`0000CoX/Ga0ol00006ojC7lP?o00000onVb?83o`00
00;oYlWa0_l00011ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003Go
oooo00?o0000ooooooooool0B_ooool3o`0000Oo^k_I0_l00007okZkfP03o`000?nc^=go/kSM00Wo
/kSM1?l00008ok2ig`;o00003?nX^NH7o`0000;oY;_Y00?o0000oj:ljonR_>/04onR_>/00ol0003o
X;g]oj2mk@07o`0000WoXKk]1Ol00004oj;5l@?o00001_nTao83o`0000?oY/Sb0ol00002ojO9l@?o
0000@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`00
0?oooooooooo04cooooo0_l00007ok^kf@?o00001?nj^mX00ol0003o]KOKokFgf`02o`0000_o/kSM
1?l00005ok2ig`03o`000?n[^>;oZkSR00;oZkSR1ol00008ojRiiQ_o00002OnQ_^d7o`0000CoXkk]
00?o0000oj;5lOl000000_l00006ojC7lP?o00000onVb?83o`0000?oYlWa0_l00017ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Oooooo0_l0001>ooooo`;o00002?nk
^mT2o`000003okZkf_l0003o]KOK00Ko]KOK1?l00009ok>hg@?o000000?o/;WOo`000?n[^>802on[
^>87o`0000?oZ;WV00?o0000ojBjjOnT^^T04onT^^T00ol0003oXKk]oj6nk@02oj6nk@Oo00002OnS
_^d4o`0000KoY<Ob0ol00004ojK8lP;o00000onWbO43o`0004[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`?o00001onk^mT0
0ol0003o]KOKokFgf`0:okFgf`?o00002Onc^=d2o`0001?oZkSR7_l0000;oj>nk@Go00001?nT_n`0
0ol0003oY<ObojC7lP03o`0000CoY/Sb0ol00003ojO9l@;o0000C_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oooooooooo04oooooo0_l00005ok^k
f@03o`000?nf^=_o][SK00;o00002one]m/4o`0000Ko/kSM00?o0000ojfgh?n]]n000_n]]n08o`00
00[oZkSR00?o0000ojJjionV^^L05?nV^^L00ol0003oXkk]oj>nk@06oj>nk@Ko00001onT_n`5o`00
00CoY/Sb0ol00004ojO9l@;o0000D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo000kooooo`03o`000?oooooooooo053ooooo0ol000000onk^mWo0000okJhf`06okJhf`Co
00002One]m/4o`000003ok>hgOl0003o[KOP00co[KOP1ol00003oj^hhP03o`000?nV^^OoY[[W01Go
Y[[W00?o0000oj>nkOnS_^d01Ol00007ojBok0Ko00001?nV_n`00ol0003oY/Sbo`000002o`0000Co
YlWa0ol0001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003cooooo
0_l0001Cooooo`03o`000?nf^=_o][SK00[o][SK1?l00009okFgf`;o00005?n]]n0No`0000OoY;o/
1Ol00009ojJok0?o00001OnWbO42o`0005Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`00?_ooool00ol0003oooooooooo`1Cooooo`;o00003?nf^=/4o`0000Ko]KOK00?o
0000ojnggon_]ml00_n_]ml8o`0000_o[KOP00?o0000ojRii_nX^NH05OnX^NH01?l0003oY;o/ojBo
k?nT_n`6o`0000WoY[o/1Ol00003ojO0j`03o`000?nWbO7o000000;o0000F_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo05Kooooo1?l0
000:okJhf`Co000000?o]KOKo`000?n_]ml03?n_]ml8o`0000?o[KOP00?o0000ojRii_nX^NH02_nX
^NH?o`0000[oY[o/1Ol00006ojO0j`Co0000GOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo007ooooo0010ooooo`03o`000?oooooooooo05Wooooo1Ol00009okJhf`;o00005On_]ml@
o`0000coZKWU00?o0000ojJok?nV_n`01OnV_n`5o`0000KoYl3[1Ol0001Rooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Kooooo`03o`000?oooooooooo
00Co00001_nf^=/00ol0003o/;ONok2ggP02ok2ggPWo00002on_]ml00ol0003oZKWUojVii@0FojVi
i@03o`000?nV_ncoY[o/00Go00001_nW`>/5o`0006Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Co
oooo1?l000000onf^=_o0000ok2ggP0=ok2ggPSo00000on_]ml00ol0003oZKWUojVii@0:ojVii@oo
00001_nW`>/5o`0006kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
A?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Sooooo0_l0000Fok2ggQ3o0000
3?n[^^@01?l0003oYl3[ojO0jonW`>/5o`0007?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`00AOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo
2Ol0000<ok2ggP03o`000?n[^^CoZk[T017oZk[T2Ol0001iooooo`03o`000?oooooooooo00Sooooo
0Ol00001ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Gooooo`Wo00000on`
]mh00ol0003oZk[Toj^ji004oj^ji0go0000Poooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool1ooooo`00B?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo2_l0002A
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool004_ooooo0_l0001Aooooo`03o`000?oooooooooo0;gooooo
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001>
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`04
ooooo`7o00000Oooool004oooooo0_l0001=ooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ooooool00oooool1o`00007ooooo001Aooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0`?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005;ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Dooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0<7ooooo00Go0000oooooooooooooooo
o`000001ooooo`00E?ooool2o`0004Sooooo00?o0000ooooooooool0`_ooool01?l0003ooooooooo
ool00001ooooo`00E_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0<?ooooo00?o
0000ooooool000000Oooool005Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`33
ooooo`03o`000?oooooooooo007o0000001Hooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0a?ooool1o`00007ooooo0Ol0000005Wooooo0_l00013ooooo`03o`000?oooooooooo0<Go
oooo0_l0000005_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o0000
001Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0`?ooool4o`0000?ooooo001M
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool4o`0000Oooooo001Noooo
o`;o0000?_ooool00ol0003oooooooooo`2hooooo`Co00002oooool0063ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2dooooo`Co00003oooool0067ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`2aooooo`?o00004oooool006;ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`2]ooooo`Co00005_ooool006?ooooo0_l0000iooooo`03o`000?oooooo
oooo0:Wooooo1?l0000Jooooo`00IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
0:Gooooo1?l0000Nooooo`00I_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;o
oooo1?l0000Rooooo`00Ioooool2o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0002Kooooo
001Yooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0V_ooool4o`0002[ooooo001Z
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0U_ooool4o`0002kooooo001[oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0T_ooool4o`0003;ooooo001/ooooo`;o
0000;oooool00ol0003oooooooooo`2>ooooo`Co0000=_ooool006kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2:ooooo`Co0000>_ooool006oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`27ooooo`?o0000?_ooool0073ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`23ooooo`Co0000@Oooool0077ooooo0_l0000Zooooo`03o`000?oooooooooo
07oooooo1?l00015ooooo`00Loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07_o
oooo1?l00019ooooo`00M?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo
1?l0001=ooooo`00MOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07?ooooo1?l0
001Aooooo`00M_ooool2o`0002Gooooo00?o0000ooooooooool0Koooool4o`0005Gooooo001hoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Wooooo001iooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005gooooo001jooooo`;o0000
8Oooool00ol0003oooooooooo`1Sooooo`Co0000HOooool007cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Pooooo`?o0000IOooool007gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Looooo`Co0000J?ooool007kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Hooooo`Co0000K?ooool007oooooo0_l0000Looooo`03o`000?oooooooooo05Co
oooo1?l0001`ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo053ooooo
1?l0001dooooo`00P_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l0
001hooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001l
ooooo`00Q?ooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`00083ooooo0026ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008Cooooo0027ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008Sooooo0028ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0>Oooool3o`0008cooooo0029ooooo`;o00004_ooool0
0ol0003oooooooooo`0eooooo`Co0000Soooool008_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0booooo`Co0000Toooool008cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0^ooooo`Co0000Uoooool008gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Zooooo`Co0000Voooool008kooooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo1?l0
002Oooooo`00T?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002S
ooooo`00TOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Woooo
o`00T_ooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:_ooooo002Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:oooooo002Eooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;?ooooo002Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool3o`000;Oooooo002Gooooo`;o00000oooool00ol0
003oooooooooo`0;ooooo`Co0000^_ooool009Wooooo00Co0000oooooooooooo00002Oooool4o`00
0;kooooo002Jooooo`03o`000?oooooo000000Gooooo1?l00032ooooo`00Voooool2o`000003oooo
ool0003o000000;o0000a_ooool009cooooo0_l0003:ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51726 .64678 m .51694 .65827 L .43899 .65168 L p .713 .672 .808 r
F P
0 g
s
.51694 .65827 m .51726 .64678 L .59258 .64491 L p .681 .692 .854 r
F P
0 g
s
.59258 .64491 m .59527 .65394 L .51694 .65827 L p .681 .692 .854 r
F P
0 g
s
.59527 .65394 m .59258 .64491 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44241 .63841 L .51726 .64678 L p .713 .672 .808 r
F P
0 g
s
.51757 .63542 m .51726 .64678 L .44241 .63841 L p .706 .669 .812 r
F P
0 g
s
.51726 .64678 m .51757 .63542 L .58987 .63592 L p .671 .688 .858 r
F P
0 g
s
.58987 .63592 m .59258 .64491 L .51726 .64678 L p .671 .688 .858 r
F P
0 g
s
.44241 .63841 m .43899 .65168 L .36521 .63435 L p .748 .678 .783 r
F P
0 g
s
.44241 .63841 m .44583 .62536 L .51757 .63542 L p .706 .669 .812 r
F P
0 g
s
.5179 .62457 m .51757 .63542 L .44583 .62536 L p .695 .67 .822 r
F P
0 g
s
.51757 .63542 m .5179 .62457 L .58715 .62717 L p .657 .688 .867 r
F P
0 g
s
.58715 .62717 m .58987 .63592 L .51757 .63542 L p .657 .688 .867 r
F P
0 g
s
.59258 .64491 m .58987 .63592 L .65915 .62672 L p .64 .746 .925 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59258 .64491 L p .64 .746 .925 r
F P
0 g
s
.36521 .63435 m .37169 .6201 L .44241 .63841 L p .748 .678 .783 r
F P
0 g
s
.44583 .62536 m .44241 .63841 L .37169 .6201 L p .742 .676 .786 r
F P
0 g
s
.37169 .6201 m .37817 .60614 L .44583 .62536 L p .742 .676 .786 r
F P
0 g
s
.44925 .61307 m .44583 .62536 L .37817 .60614 L p .733 .678 .797 r
F P
0 g
s
.44583 .62536 m .44925 .61307 L .5179 .62457 L p .695 .67 .822 r
F P
0 g
s
.51822 .6146 m .5179 .62457 L .44925 .61307 L p .679 .677 .84 r
F P
0 g
s
.5179 .62457 m .51822 .6146 L .58441 .61884 L p .641 .691 .881 r
F P
0 g
s
.58441 .61884 m .58715 .62717 L .5179 .62457 L p .641 .691 .881 r
F P
0 g
s
.58987 .63592 m .58715 .62717 L .65355 .62061 L p .623 .74 .931 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58987 .63592 L p .623 .74 .931 r
F P
0 g
s
.37817 .60614 m .38462 .59317 L .44925 .61307 L p .733 .678 .797 r
F P
0 g
s
.45266 .60204 m .44925 .61307 L .38462 .59317 L p .717 .684 .817 r
F P
0 g
s
.44925 .61307 m .45266 .60204 L .51822 .6146 L p .679 .677 .84 r
F P
0 g
s
.51854 .6058 m .51822 .6146 L .45266 .60204 L p .656 .688 .868 r
F P
0 g
s
.51822 .6146 m .51854 .6058 L .58167 .6111 L p .621 .697 .899 r
F P
0 g
s
.58167 .6111 m .58441 .61884 L .51822 .6146 L p .621 .697 .899 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72992 .61072 L p .644 .847 .978 r
F P
0 g
s
.72992 .61072 m .73799 .61332 L .67023 .63881 L p .644 .847 .978 r
F P
0 g
s
.58715 .62717 m .58441 .61884 L .6479 .61445 L p .606 .734 .935 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58715 .62717 L p .606 .734 .935 r
F P
0 g
s
.38462 .59317 m .39103 .58177 L .45266 .60204 L p .717 .684 .817 r
F P
0 g
s
.45605 .59271 m .45266 .60204 L .39103 .58177 L p .691 .695 .849 r
F P
0 g
s
.45266 .60204 m .45605 .59271 L .51854 .6058 L p .656 .688 .868 r
F P
0 g
s
.37169 .6201 m .36521 .63435 L .29943 .6068 L p .783 .702 .775 r
F P
0 g
s
.51886 .59838 m .51854 .6058 L .45605 .59271 L p .621 .703 .904 r
F P
0 g
s
.51854 .6058 m .51886 .59838 L .57892 .60405 L p .596 .707 .921 r
F P
0 g
s
.57892 .60405 m .58167 .6111 L .51854 .6058 L p .596 .707 .921 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72179 .608 L p .622 .84 .983 r
F P
0 g
s
.72179 .608 m .72992 .61072 L .66471 .63279 L p .622 .84 .983 r
F P
0 g
s
.29943 .6068 m .30879 .59247 L .37169 .6201 L p .783 .702 .775 r
F P
0 g
s
.37817 .60614 m .37169 .6201 L .30879 .59247 L p .779 .701 .778 r
F P
0 g
s
.58441 .61884 m .58167 .6111 L .64221 .60824 L p .589 .727 .939 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58441 .61884 L p .589 .727 .939 r
F P
0 g
s
.39103 .58177 m .39738 .57247 L .45605 .59271 L p .691 .695 .849 r
F P
0 g
s
.45942 .58535 m .45605 .59271 L .39738 .57247 L p .646 .709 .893 r
F P
0 g
s
.45605 .59271 m .45942 .58535 L .51886 .59838 L p .621 .703 .904 r
F P
0 g
s
.30879 .59247 m .31812 .57851 L .37817 .60614 L p .779 .701 .778 r
F P
0 g
s
.38462 .59317 m .37817 .60614 L .31812 .57851 L p .77 .703 .789 r
F P
0 g
s
.31812 .57851 m .3274 .56568 L .38462 .59317 L p .77 .703 .789 r
F P
0 g
s
.39103 .58177 m .38462 .59317 L .3274 .56568 L p .753 .708 .81 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71357 .60494 L p .602 .825 .985 r
F P
0 g
s
.71357 .60494 m .72179 .608 L .65915 .62672 L p .602 .825 .985 r
F P
0 g
s
.51918 .59246 m .51886 .59838 L .45942 .58535 L p .564 .721 .947 r
F P
0 g
s
.51886 .59838 m .51918 .59246 L .57615 .59777 L p .567 .721 .945 r
F P
0 g
s
.57615 .59777 m .57892 .60405 L .51886 .59838 L p .567 .721 .945 r
F P
0 g
s
.58167 .6111 m .57892 .60405 L .63648 .60198 L p .577 .722 .942 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58167 .6111 L p .577 .722 .942 r
F P
0 g
s
.39738 .57247 m .40368 .56563 L .45942 .58535 L p .646 .709 .893 r
F P
0 g
s
.46278 .58015 m .45942 .58535 L .40368 .56563 L p .561 .72 .947 r
F P
0 g
s
.45942 .58535 m .46278 .58015 L .51918 .59246 L p .564 .721 .947 r
F P
0 g
s
.3274 .56568 m .33658 .55465 L .39103 .58177 L p .753 .708 .81 r
F P
0 g
s
.39738 .57247 m .39103 .58177 L .33658 .55465 L p .722 .716 .844 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70526 .60137 L p .586 .803 .982 r
F P
0 g
s
.70526 .60137 m .71357 .60494 L .65355 .62061 L p .586 .803 .982 r
F P
0 g
s
.33658 .55465 m .34566 .546 L .39738 .57247 L p .722 .716 .844 r
F P
0 g
s
.40368 .56563 m .39738 .57247 L .34566 .546 L p .667 .723 .891 r
F P
0 g
s
.5195 .58806 m .51918 .59246 L .46278 .58015 L p .474 .732 .983 r
F P
0 g
s
.51918 .59246 m .5195 .58806 L .57338 .59223 L p .537 .736 .967 r
F P
0 g
s
.57338 .59223 m .57615 .59777 L .51918 .59246 L p .537 .736 .967 r
F P
0 g
s
.57892 .60405 m .57615 .59777 L .6307 .59568 L p .569 .719 .943 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57892 .60405 L p .569 .719 .943 r
F P
0 g
s
.40368 .56563 m .40993 .56145 L .46278 .58015 L p .561 .72 .947 r
F P
0 g
s
.46613 .5771 m .46278 .58015 L .40993 .56145 L p .4 .702 .983 r
F P
0 g
s
.46278 .58015 m .46613 .5771 L .5195 .58806 L p .474 .732 .983 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69686 .5971 L p .575 .775 .974 r
F P
0 g
s
.69686 .5971 m .70526 .60137 L .6479 .61445 L p .575 .775 .974 r
F P
0 g
s
.34566 .546 m .35463 .54012 L .40368 .56563 L p .667 .723 .891 r
F P
0 g
s
.40993 .56145 m .40368 .56563 L .35463 .54012 L p .559 .718 .947 r
F P
0 g
s
.73799 .61332 m .72992 .61072 L .7844 .57939 L p .665 .933 .97 r
F P
0 g
s
.7844 .57939 m .79464 .57831 L .73799 .61332 L p .665 .933 .97 r
F P
0 g
s
.57615 .59777 m .57338 .59223 L .62488 .58932 L p .57 .72 .943 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57615 .59777 L p .57 .72 .943 r
F P
0 g
s
.51982 .58504 m .5195 .58806 L .46613 .5771 L p .344 .719 .985 r
F P
0 g
s
.5195 .58806 m .51982 .58504 L .57058 .5874 L p .509 .755 .984 r
F P
0 g
s
.57058 .5874 m .57338 .59223 L .5195 .58806 L p .509 .755 .984 r
F P
0 g
s
.40993 .56145 m .41614 .55993 L .46613 .5771 L p .4 .702 .983 r
F P
0 g
s
.46949 .57605 m .46613 .5771 L .41614 .55993 L p .136 .605 .923 r
F P
0 g
s
.46949 .57605 m .42234 .56089 L p .46006 .57269 L 0 .429 .736 r
F P
0 g
s
.46949 .57605 m .51982 .58504 L p .4769 .57869 L .344 .719 .985 r
F P
0 g
s
.52014 .5832 m .51982 .58504 L .46949 .57605 L p .195 .674 .932 r
F P
0 g
s
.47286 .5767 m .52014 .5832 L p .47622 .577 L .195 .674 .932 r
F P
0 g
s
.46949 .57605 m .47286 .5767 L p .47622 .577 L .195 .674 .932 r
F P
0 g
s
.47286 .5767 m .46949 .57605 L p .46006 .57269 L 0 .429 .736 r
F P
0 g
s
.46613 .5771 m .46949 .57605 L p .4769 .57869 L .344 .719 .985 r
F P
0 g
s
.42234 .56089 m .46949 .57605 L p .42688 .56317 L .136 .605 .923 r
F P
0 g
s
.41614 .55993 m .42234 .56089 L p .42688 .56317 L .136 .605 .923 r
F P
0 g
s
.42234 .56089 m .38105 .54028 L p .41656 .55797 L 0 .263 .637 r
F P
0 g
s
.42234 .56089 m .42856 .56395 L .47286 .5767 L p 0 .429 .736 r
F P
0 g
s
.42856 .56395 m .42234 .56089 L p .41656 .55797 L 0 .263 .637 r
F P
0 g
s
.47286 .5767 m .42856 .56395 L p .46896 .57635 L .326 0 0 r
F P
0 g
s
.47625 .57858 m .47286 .5767 L p .46896 .57635 L .326 0 0 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68836 .59203 L p .569 .746 .96 r
F P
0 g
s
.68836 .59203 m .69686 .5971 L .64221 .60824 L p .569 .746 .96 r
F P
0 g
s
.35463 .54012 m .3635 .53724 L .40993 .56145 L p .559 .718 .947 r
F P
0 g
s
.41614 .55993 m .40993 .56145 L .3635 .53724 L p .345 .662 .973 r
F P
0 g
s
.72992 .61072 m .72179 .608 L .77406 .58029 L p .64 .926 .974 r
F P
0 g
s
.77406 .58029 m .7844 .57939 L .72992 .61072 L p .64 .926 .974 r
F P
0 g
s
.30879 .59247 m .29943 .6068 L .24558 .56996 L p .818 .742 .78 r
F P
0 g
s
.24558 .56996 m .25745 .55654 L .30879 .59247 L p .818 .742 .78 r
F P
0 g
s
.31812 .57851 m .30879 .59247 L .25745 .55654 L p .814 .742 .784 r
F P
0 g
s
.25745 .55654 m .26927 .54354 L .31812 .57851 L p .814 .742 .784 r
F P
0 g
s
.3274 .56568 m .31812 .57851 L .26927 .54354 L p .804 .743 .796 r
F P
0 g
s
.26927 .54354 m .28098 .53175 L .3274 .56568 L p .804 .743 .796 r
F P
0 g
s
.33658 .55465 m .3274 .56568 L .28098 .53175 L p .784 .746 .818 r
F P
0 g
s
.57338 .59223 m .57058 .5874 L .61901 .58292 L p .58 .724 .941 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57338 .59223 L p .58 .724 .941 r
F P
0 g
s
.28098 .53175 m .29255 .52186 L .33658 .55465 L p .784 .746 .818 r
F P
0 g
s
.34566 .546 m .33658 .55465 L .29255 .52186 L p .748 .748 .852 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67976 .5861 L p .57 .718 .942 r
F P
0 g
s
.67976 .5861 m .68836 .59203 L .63648 .60198 L p .57 .718 .942 r
F P
0 g
s
.51982 .58504 m .52014 .5832 L .56777 .58314 L p .493 .776 .995 r
F P
0 g
s
.56777 .58314 m .57058 .5874 L .51982 .58504 L p .493 .776 .995 r
F P
0 g
s
.72179 .608 m .71357 .60494 L .76361 .58059 L p .62 .907 .984 r
F P
0 g
s
.76361 .58059 m .77406 .58029 L .72179 .608 L p .62 .907 .984 r
F P
0 g
s
.29255 .52186 m .30396 .51448 L .34566 .546 L p .748 .748 .852 r
F P
0 g
s
.35463 .54012 m .34566 .546 L .30396 .51448 L p .682 .743 .898 r
F P
0 g
s
.3635 .53724 m .3723 .53736 L .41614 .55993 L p .345 .662 .973 r
F P
0 g
s
.42234 .56089 m .41614 .55993 L .3723 .53736 L p .008 .494 .869 r
F P
0 g
s
.57058 .5874 m .56777 .58314 L .61309 .57646 L p .599 .731 .937 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57058 .5874 L p .599 .731 .937 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67108 .5793 L p .576 .693 .921 r
F P
0 g
s
.67108 .5793 m .67976 .5861 L .6307 .59568 L p .576 .693 .921 r
F P
0 g
s
.30396 .51448 m .3152 .51001 L .35463 .54012 L p .682 .743 .898 r
F P
0 g
s
.3635 .53724 m .35463 .54012 L .3152 .51001 L p .557 .716 .947 r
F P
0 g
s
.71357 .60494 m .70526 .60137 L .75301 .5799 L p .606 .876 .992 r
F P
0 g
s
.75301 .5799 m .76361 .58059 L .71357 .60494 L p .606 .876 .992 r
F P
0 g
s
.52047 .58221 m .52014 .5832 L .47286 .5767 L p .08 .621 .85 r
F P
0 g
s
.52014 .5832 m .52047 .58221 L .56493 .57929 L p .499 .802 .999 r
F P
0 g
s
.56493 .57929 m .56777 .58314 L .52014 .5832 L p .499 .802 .999 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66231 .5717 L p .587 .674 .9 r
F P
0 g
s
.66231 .5717 m .67108 .5793 L .62488 .58932 L p .587 .674 .9 r
F P
0 g
s
.38105 .54028 m .34818 .51525 L p .37933 .53794 L 0 .234 .688 r
F P
0 g
s
.38105 .54028 m .42234 .56089 L p .3824 .54211 L .008 .494 .869 r
F P
0 g
s
.38981 .54558 m .42856 .56395 L p .38741 .54345 L 0 .263 .637 r
F P
0 g
s
.38105 .54028 m .38981 .54558 L p .38741 .54345 L 0 .263 .637 r
F P
0 g
s
.38981 .54558 m .38105 .54028 L p .37933 .53794 L 0 .234 .688 r
F P
0 g
s
.35906 .52248 m .38981 .54558 L p .35377 .51932 L 0 .234 .688 r
F P
0 g
s
.34818 .51525 m .35906 .52248 L p .35377 .51932 L 0 .234 .688 r
F P
0 g
s
.35906 .52248 m .33851 .49589 L p .36522 .52615 L 0 .185 .703 r
F P
0 g
s
.38981 .54558 m .35906 .52248 L p .39261 .54805 L .465 0 0 r
F P
0 g
s
.36999 .53155 m .39862 .55263 L p .36181 .52457 L .465 0 0 r
F P
0 g
s
.35906 .52248 m .36999 .53155 L p .36181 .52457 L .465 0 0 r
F P
0 g
s
.38105 .54028 m .3723 .53736 L .33727 .5105 L p .014 .45 .869 r
F P
0 g
s
.33727 .5105 m .34818 .51525 L .38105 .54028 L p .014 .45 .869 r
F P
0 g
s
.40752 .56067 m .39862 .55263 L .36999 .53155 L p .544 0 0 r
F P
0 g
s
.3723 .53736 m .38105 .54028 L p .3824 .54211 L .008 .494 .869 r
F P
0 g
s
.36999 .53155 m .381 .54166 L .40752 .56067 L p .544 0 0 r
F P
0 g
s
.36999 .53155 m .35099 .50646 L p .37881 .53909 L 0 .129 .658 r
F P
0 g
s
.381 .54166 m .36999 .53155 L p .37881 .53909 L 0 .129 .658 r
F P
0 g
s
.36999 .53155 m .35906 .52248 L p .36522 .52615 L 0 .185 .703 r
F P
0 g
s
.39862 .55263 m .38981 .54558 L p .39261 .54805 L .465 0 0 r
F P
0 g
s
.3152 .51001 m .3263 .50868 L .3635 .53724 L p .557 .716 .947 r
F P
0 g
s
.3723 .53736 m .3635 .53724 L .3263 .50868 L p .334 .629 .96 r
F P
0 g
s
.47286 .5767 m .47625 .57858 L .52047 .58221 L p .08 .621 .85 r
F P
0 g
s
.70526 .60137 m .69686 .5971 L .74225 .57792 L p .593 .829 .989 r
F P
0 g
s
.74225 .57792 m .75301 .5799 L .70526 .60137 L p .593 .829 .989 r
F P
0 g
s
.56777 .58314 m .56493 .57929 L .60713 .56996 L p .626 .741 .93 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56777 .58314 L p .626 .741 .93 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65347 .56342 L p .602 .661 .88 r
F P
0 g
s
.65347 .56342 m .66231 .5717 L .61901 .58292 L p .602 .661 .88 r
F P
0 g
s
.69686 .5971 m .68836 .59203 L .73134 .57441 L p .58 .773 .971 r
F P
0 g
s
.73134 .57441 m .74225 .57792 L .69686 .5971 L p .58 .773 .971 r
F P
0 g
s
.3263 .50868 m .33727 .5105 L .3723 .53736 L p .334 .629 .96 r
F P
0 g
s
.5208 .58165 m .52047 .58221 L .47625 .57858 L p .04 .603 .793 r
F P
0 g
s
.52047 .58221 m .5208 .58165 L .56207 .57563 L p .533 .833 .999 r
F P
0 g
s
.56207 .57563 m .56493 .57929 L .52047 .58221 L p .533 .833 .999 r
F P
0 g
s
.56493 .57929 m .56207 .57563 L .60112 .5634 L p .66 .753 .919 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57929 L p .66 .753 .919 r
F P
0 g
s
.43482 .56857 m .42856 .56395 L .38981 .54558 L p .49 0 0 r
F P
0 g
s
.42856 .56395 m .43482 .56857 L .47625 .57858 L p .326 0 0 r
F P
0 g
s
.79464 .57831 m .7844 .57939 L .82432 .54001 L p .742 .978 .92 r
F P
0 g
s
.82432 .54001 m .83625 .53514 L .79464 .57831 L p .742 .978 .92 r
F P
0 g
s
.68836 .59203 m .67976 .5861 L .72028 .56926 L p .569 .715 .941 r
F P
0 g
s
.72028 .56926 m .73134 .57441 L .68836 .59203 L p .569 .715 .941 r
F P
0 g
s
.47969 .58114 m .47625 .57858 L .43482 .56857 L p .396 0 0 r
F P
0 g
s
.47625 .57858 m .47969 .58114 L .5208 .58165 L p .04 .603 .793 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64458 .55466 L p .621 .655 .862 r
F P
0 g
s
.64458 .55466 m .65347 .56342 L .61309 .57646 L p .621 .655 .862 r
F P
0 g
s
.23509 .5028 m .24865 .49294 L .28098 .53175 L p .831 .795 .817 r
F P
0 g
s
.28098 .53175 m .26927 .54354 L .23509 .5028 L p .831 .795 .817 r
F P
0 g
s
.29255 .52186 m .28098 .53175 L .24865 .49294 L p .807 .794 .84 r
F P
0 g
s
.24865 .49294 m .26203 .48498 L .29255 .52186 L p .807 .794 .84 r
F P
0 g
s
.30396 .51448 m .29255 .52186 L .26203 .48498 L p .763 .786 .873 r
F P
0 g
s
.22138 .51385 m .23509 .5028 L .26927 .54354 L p .844 .795 .804 r
F P
0 g
s
.26927 .54354 m .25745 .55654 L .22138 .51385 L p .844 .795 .804 r
F P
0 g
s
.67976 .5861 m .67108 .5793 L .70908 .56246 L p .561 .665 .907 r
F P
0 g
s
.70908 .56246 m .72028 .56926 L .67976 .5861 L p .561 .665 .907 r
F P
0 g
s
.7844 .57939 m .77406 .58029 L .81228 .54463 L p .723 .974 .925 r
F P
0 g
s
.81228 .54463 m .82432 .54001 L .7844 .57939 L p .723 .974 .925 r
F P
0 g
s
.20758 .52532 m .22138 .51385 L .25745 .55654 L p .847 .793 .799 r
F P
0 g
s
.25745 .55654 m .24558 .56996 L .20758 .52532 L p .847 .793 .799 r
F P
0 g
s
.26203 .48498 m .2752 .47947 L .30396 .51448 L p .763 .786 .873 r
F P
0 g
s
.3152 .51001 m .30396 .51448 L .2752 .47947 L p .686 .765 .912 r
F P
0 g
s
.52113 .58107 m .5208 .58165 L .47969 .58114 L p .089 .645 .794 r
F P
0 g
s
.5208 .58165 m .52113 .58107 L .55918 .57192 L p .592 .865 .994 r
F P
0 g
s
.55918 .57192 m .56207 .57563 L .5208 .58165 L p .592 .865 .994 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63564 .54562 L p .643 .654 .846 r
F P
0 g
s
.63564 .54562 m .64458 .55466 L .60713 .56996 L p .643 .654 .846 r
F P
0 g
s
.56207 .57563 m .55918 .57192 L .59506 .55679 L p .696 .764 .904 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56207 .57563 L p .696 .764 .904 r
F P
0 g
s
.2752 .47947 m .28816 .47682 L .3152 .51001 L p .686 .765 .912 r
F P
0 g
s
.3263 .50868 m .3152 .51001 L .28816 .47682 L p .558 .714 .945 r
F P
0 g
s
.67108 .5793 m .66231 .5717 L .69777 .55415 L p .559 .626 .875 r
F P
0 g
s
.69777 .55415 m .70908 .56246 L .67108 .5793 L p .559 .626 .875 r
F P
0 g
s
.38981 .54558 m .39862 .55263 L .43482 .56857 L p .49 0 0 r
F P
0 g
s
.44114 .57404 m .43482 .56857 L .39862 .55263 L p .561 0 0 r
F P
0 g
s
.43482 .56857 m .44114 .57404 L .47969 .58114 L p .396 0 0 r
F P
0 g
s
.77406 .58029 m .76361 .58059 L .80008 .54842 L p .703 .96 .946 r
F P
0 g
s
.80008 .54842 m .81228 .54463 L .77406 .58029 L p .703 .96 .946 r
F P
0 g
s
.48317 .5837 m .47969 .58114 L .44114 .57404 L p .384 0 0 r
F P
0 g
s
.47969 .58114 m .48317 .5837 L .52113 .58107 L p .089 .645 .794 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62665 .53654 L p .668 .66 .832 r
F P
0 g
s
.62665 .53654 m .63564 .54562 L .60112 .5634 L p .668 .66 .832 r
F P
0 g
s
.28816 .47682 m .30093 .47725 L .3263 .50868 L p .558 .714 .945 r
F P
0 g
s
.33727 .5105 m .3263 .50868 L .30093 .47725 L p .363 .613 .946 r
F P
0 g
s
.66231 .5717 m .65347 .56342 L .68638 .54459 L p .562 .599 .848 r
F P
0 g
s
.68638 .54459 m .69777 .55415 L .66231 .5717 L p .562 .599 .848 r
F P
0 g
s
.55625 .56791 m .55918 .57192 L .52113 .58107 L p .665 .888 .979 r
F P
0 g
s
.55918 .57192 m .55625 .56791 L .58896 .55013 L p .731 .773 .886 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55918 .57192 L p .731 .773 .886 r
F P
0 g
s
.76361 .58059 m .75301 .5799 L .7877 .55082 L p .68 .928 .97 r
F P
0 g
s
.7877 .55082 m .80008 .54842 L .76361 .58059 L p .68 .928 .97 r
F P
0 g
s
.52147 .57998 m .52113 .58107 L .48317 .5837 L p .227 .744 .853 r
F P
0 g
s
.52113 .58107 m .52147 .57998 L .55625 .56791 L p .665 .888 .979 r
F P
0 g
s
.65347 .56342 m .64458 .55466 L .67493 .53414 L p .572 .584 .826 r
F P
0 g
s
.67493 .53414 m .68638 .54459 L .65347 .56342 L p .572 .584 .826 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61764 .52769 L p .695 .669 .82 r
F P
0 g
s
.61764 .52769 m .62665 .53654 L .59506 .55679 L p .695 .669 .82 r
F P
0 g
s
.30093 .47725 m .31354 .48075 L .33727 .5105 L p .363 .613 .946 r
F P
0 g
s
.34818 .51525 m .33727 .5105 L .31354 .48075 L p .123 .462 .889 r
F P
0 g
s
.64458 .55466 m .63564 .54562 L .66345 .52322 L p .588 .578 .81 r
F P
0 g
s
.66345 .52322 m .67493 .53414 L .64458 .55466 L p .588 .578 .81 r
F P
0 g
s
.39862 .55263 m .40752 .56067 L .44114 .57404 L p .561 0 0 r
F P
0 g
s
.44757 .57956 m .44114 .57404 L .40752 .56067 L p .563 0 0 r
F P
0 g
s
.44114 .57404 m .44757 .57956 L .48317 .5837 L p .384 0 0 r
F P
0 g
s
.75301 .5799 m .74225 .57792 L .77511 .55137 L p .649 .871 .982 r
F P
0 g
s
.77511 .55137 m .7877 .55082 L .75301 .5799 L p .649 .871 .982 r
F P
0 g
s
.48671 .58557 m .48317 .5837 L .44757 .57956 L p .291 0 0 r
F P
0 g
s
.48317 .5837 m .48671 .58557 L .52147 .57998 L p .227 .744 .853 r
F P
0 g
s
.55328 .56335 m .55625 .56791 L .52147 .57998 L p .735 .897 .952 r
F P
0 g
s
.55625 .56791 m .55328 .56335 L .5828 .54342 L p .764 .78 .865 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55625 .56791 L p .764 .78 .865 r
F P
0 g
s
.63564 .54562 m .62665 .53654 L .65196 .51232 L p .609 .582 .798 r
F P
0 g
s
.65196 .51232 m .66345 .52322 L .63564 .54562 L p .609 .582 .798 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60859 .5193 L p .724 .682 .81 r
F P
0 g
s
.60859 .5193 m .61764 .52769 L .58896 .55013 L p .724 .682 .81 r
F P
0 g
s
.74225 .57792 m .73134 .57441 L .76231 .54974 L p .608 .795 .971 r
F P
0 g
s
.76231 .54974 m .77511 .55137 L .74225 .57792 L p .608 .795 .971 r
F P
0 g
s
.52181 .57789 m .52147 .57998 L .48671 .58557 L p .43 .862 .929 r
F P
0 g
s
.52147 .57998 m .52181 .57789 L .55328 .56335 L p .735 .897 .952 r
F P
0 g
s
.31354 .48075 m .32605 .48711 L .34818 .51525 L p .123 .462 .889 r
F P
0 g
s
.35906 .52248 m .34818 .51525 L .32605 .48711 L p 0 .303 .792 r
F P
0 g
s
.62665 .53654 m .61764 .52769 L .64049 .50191 L p .635 .593 .79 r
F P
0 g
s
.64049 .50191 m .65196 .51232 L .62665 .53654 L p .635 .593 .79 r
F P
0 g
s
.73134 .57441 m .72028 .56926 L .74931 .54578 L p .567 .714 .941 r
F P
0 g
s
.74931 .54578 m .76231 .54974 L .73134 .57441 L p .567 .714 .941 r
F P
0 g
s
.61764 .52769 m .60859 .5193 L .62903 .49244 L p .665 .611 .785 r
F P
0 g
s
.62903 .49244 m .64049 .50191 L .61764 .52769 L p .665 .611 .785 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55328 .56335 L p .794 .784 .844 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59952 .51156 L p .752 .697 .799 r
F P
0 g
s
.59952 .51156 m .60859 .5193 L .5828 .54342 L p .752 .697 .799 r
F P
0 g
s
.55028 .55803 m .55328 .56335 L .52181 .57789 L p .79 .891 .916 r
F P
0 g
s
.55328 .56335 m .55028 .55803 L .5766 .53665 L p .794 .784 .844 r
F P
0 g
s
.40752 .56067 m .41654 .56878 L .44757 .57956 L p .563 0 0 r
F P
0 g
s
.45411 .58427 m .44757 .57956 L .41654 .56878 L p .5 0 0 r
F P
0 g
s
.44757 .57956 m .45411 .58427 L .48671 .58557 L p .291 0 0 r
F P
0 g
s
.72028 .56926 m .70908 .56246 L .73614 .53948 L p .532 .641 .903 r
F P
0 g
s
.73614 .53948 m .74931 .54578 L .72028 .56926 L p .532 .641 .903 r
F P
0 g
s
.49032 .58608 m .48671 .58557 L .45411 .58427 L p .086 0 0 r
F P
0 g
s
.48671 .58557 m .49032 .58608 L .52181 .57789 L p .43 .862 .929 r
F P
0 g
s
.60859 .5193 m .59952 .51156 L .61759 .48432 L p .698 .633 .78 r
F P
0 g
s
.61759 .48432 m .62903 .49244 L .60859 .5193 L p .698 .633 .78 r
F P
0 g
s
.32605 .48711 m .33851 .49589 L .35906 .52248 L p 0 .303 .792 r
F P
0 g
s
.70908 .56246 m .69777 .55415 L .72285 .53106 L p .508 .585 .867 r
F P
0 g
s
.72285 .53106 m .73614 .53948 L .70908 .56246 L p .508 .585 .867 r
F P
0 g
s
.41654 .56878 m .40752 .56067 L .381 .54166 L p .548 0 0 r
F P
0 g
s
.52216 .57437 m .52181 .57789 L .49032 .58608 L p .628 .936 .963 r
F P
0 g
s
.52181 .57789 m .52216 .57437 L .55028 .55803 L p .79 .891 .916 r
F P
0 g
s
.69777 .55415 m .68638 .54459 L .70947 .52089 L p .497 .546 .837 r
F P
0 g
s
.70947 .52089 m .72285 .53106 L .69777 .55415 L p .497 .546 .837 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55028 .55803 L p .818 .786 .822 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59041 .50466 L p .78 .713 .79 r
F P
0 g
s
.59041 .50466 m .59952 .51156 L .5766 .53665 L p .78 .713 .79 r
F P
0 g
s
.68638 .54459 m .67493 .53414 L .69605 .50948 L p .497 .524 .815 r
F P
0 g
s
.69605 .50948 m .70947 .52089 L .68638 .54459 L p .497 .524 .815 r
F P
0 g
s
.24784 .44599 m .26201 .4429 L .2752 .47947 L p .759 .825 .904 r
F P
0 g
s
.2752 .47947 m .26203 .48498 L .24784 .44599 L p .759 .825 .904 r
F P
0 g
s
.28816 .47682 m .2752 .47947 L .26201 .4429 L p .677 .784 .93 r
F P
0 g
s
.67493 .53414 m .66345 .52322 L .68264 .49747 L p .508 .515 .799 r
F P
0 g
s
.68264 .49747 m .69605 .50948 L .67493 .53414 L p .508 .515 .799 r
F P
0 g
s
.23343 .45132 m .24784 .44599 L .26203 .48498 L p .812 .846 .875 r
F P
0 g
s
.26203 .48498 m .24865 .49294 L .23343 .45132 L p .812 .846 .875 r
F P
0 g
s
.83625 .53514 m .82432 .54001 L .84605 .4944 L p .838 .975 .88 r
F P
0 g
s
.84605 .4944 m .85906 .48583 L .83625 .53514 L p .838 .975 .88 r
F P
0 g
s
.59952 .51156 m .59041 .50466 L .60617 .47786 L p .733 .659 .776 r
F P
0 g
s
.60617 .47786 m .61759 .48432 L .59952 .51156 L p .733 .659 .776 r
F P
0 g
s
.66345 .52322 m .65196 .51232 L .66928 .48552 L p .528 .519 .789 r
F P
0 g
s
.66928 .48552 m .68264 .49747 L .66345 .52322 L p .528 .519 .789 r
F P
0 g
s
.54724 .55176 m .55028 .55803 L .52216 .57437 L p .829 .874 .877 r
F P
0 g
s
.55028 .55803 m .54724 .55176 L .57035 .52982 L p .818 .786 .822 r
F P
0 g
s
.65196 .51232 m .64049 .50191 L .65598 .47431 L p .557 .533 .784 r
F P
0 g
s
.65598 .47431 m .66928 .48552 L .65196 .51232 L p .557 .533 .784 r
F P
0 g
s
.26201 .4429 m .27594 .44241 L .28816 .47682 L p .677 .784 .93 r
F P
0 g
s
.30093 .47725 m .28816 .47682 L .27594 .44241 L p .56 .713 .944 r
F P
0 g
s
.21881 .45837 m .23343 .45132 L .24865 .49294 L p .842 .854 .853 r
F P
0 g
s
.24865 .49294 m .23509 .5028 L .21881 .45837 L p .842 .854 .853 r
F P
0 g
s
.64049 .50191 m .62903 .49244 L .64278 .46449 L p .593 .556 .782 r
F P
0 g
s
.64278 .46449 m .65598 .47431 L .64049 .50191 L p .593 .556 .782 r
F P
0 g
s
.62903 .49244 m .61759 .48432 L .62966 .45661 L p .636 .586 .781 r
F P
0 g
s
.62966 .45661 m .64278 .46449 L .62903 .49244 L p .636 .586 .781 r
F P
0 g
s
.20402 .46652 m .21881 .45837 L .23509 .5028 L p .858 .856 .838 r
F P
0 g
s
.23509 .5028 m .22138 .51385 L .20402 .46652 L p .858 .856 .838 r
F P
0 g
s
.27594 .44241 m .28966 .44472 L .30093 .47725 L p .56 .713 .944 r
F P
0 g
s
.31354 .48075 m .30093 .47725 L .28966 .44472 L p .414 .612 .931 r
F P
0 g
s
.58126 .4987 m .59041 .50466 L .57035 .52982 L p .806 .729 .78 r
F P
0 g
s
.59041 .50466 m .58126 .4987 L .59475 .47325 L p .768 .685 .772 r
F P
0 g
s
.59475 .47325 m .60617 .47786 L .59041 .50466 L p .768 .685 .772 r
F P
0 g
s
.45411 .58427 m .46077 .58733 L .49032 .58608 L p .086 0 0 r
F P
0 g
s
.494 .5846 m .49032 .58608 L .46077 .58733 L p .246 .756 .867 r
F P
0 g
s
.49032 .58608 m .494 .5846 L .52216 .57437 L p .628 .936 .963 r
F P
0 g
s
.61759 .48432 m .60617 .47786 L .61662 .45108 L p .682 .62 .78 r
F P
0 g
s
.61662 .45108 m .62966 .45661 L .61759 .48432 L p .682 .62 .78 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54724 .55176 L p .838 .787 .802 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58126 .4987 L p .806 .729 .78 r
F P
0 g
s
.41654 .56878 m .42573 .57602 L .45411 .58427 L p .5 0 0 r
F P
0 g
s
.46077 .58733 m .45411 .58427 L .42573 .57602 L p .34 0 0 r
F P
0 g
s
.33851 .49589 m .35099 .50646 L .36999 .53155 L p 0 .185 .703 r
F P
0 g
s
.82432 .54001 m .81228 .54463 L .83293 .50267 L p .827 .976 .887 r
F P
0 g
s
.83293 .50267 m .84605 .4944 L .82432 .54001 L p .827 .976 .887 r
F P
0 g
s
.52252 .56908 m .52216 .57437 L .494 .5846 L p .762 .942 .94 r
F P
0 g
s
.52216 .57437 m .52252 .56908 L .54724 .55176 L p .829 .874 .877 r
F P
0 g
s
.18911 .47507 m .20402 .46652 L .22138 .51385 L p .862 .853 .832 r
F P
0 g
s
.22138 .51385 m .20758 .52532 L .18911 .47507 L p .862 .853 .832 r
F P
0 g
s
.60617 .47786 m .59475 .47325 L .60364 .4482 L p .729 .656 .778 r
F P
0 g
s
.60364 .4482 m .61662 .45108 L .60617 .47786 L p .729 .656 .778 r
F P
0 g
s
.381 .54166 m .39216 .55186 L .41654 .56878 L p .548 0 0 r
F P
0 g
s
.42573 .57602 m .41654 .56878 L .39216 .55186 L p .479 0 0 r
F P
0 g
s
.54416 .54444 m .54724 .55176 L .52252 .56908 L p .854 .853 .841 r
F P
0 g
s
.54724 .55176 m .54416 .54444 L .56404 .52294 L p .838 .787 .802 r
F P
0 g
s
.28966 .44472 m .3032 .44981 L .31354 .48075 L p .414 .612 .931 r
F P
0 g
s
.32605 .48711 m .31354 .48075 L .3032 .44981 L p .266 .498 .893 r
F P
0 g
s
.57208 .49372 m .58126 .4987 L .56404 .52294 L p .829 .744 .77 r
F P
0 g
s
.58126 .4987 m .57208 .49372 L .58331 .47058 L p .801 .711 .766 r
F P
0 g
s
.58331 .47058 m .59475 .47325 L .58126 .4987 L p .801 .711 .766 r
F P
0 g
s
.81228 .54463 m .80008 .54842 L .81965 .5099 L p .805 .965 .909 r
F P
0 g
s
.81965 .5099 m .83293 .50267 L .81228 .54463 L p .805 .965 .909 r
F P
0 g
s
.59475 .47325 m .58331 .47058 L .59068 .44806 L p .773 .691 .773 r
F P
0 g
s
.59068 .44806 m .60364 .4482 L .59475 .47325 L p .773 .691 .773 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54416 .54444 L p .854 .786 .784 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57208 .49372 L p .829 .744 .77 r
F P
0 g
s
.64278 .46449 m .62966 .45661 L .63487 .43017 L p .561 .551 .801 r
F P
0 g
s
.62966 .45661 m .61662 .45108 L .62105 .42604 L p .626 .598 .802 r
F P
0 g
s
.62105 .42604 m .63487 .43017 L .62966 .45661 L p .626 .598 .802 r
F P
0 g
s
.61662 .45108 m .60364 .4482 L .60733 .42514 L p .691 .645 .799 r
F P
0 g
s
.60733 .42514 m .62105 .42604 L .61662 .45108 L p .691 .645 .799 r
F P
0 g
s
.65598 .47431 m .64278 .46449 L .64884 .4372 L p .501 .51 .798 r
F P
0 g
s
.63487 .43017 m .64884 .4372 L .64278 .46449 L p .561 .551 .801 r
F P
0 g
s
.3032 .44981 m .31662 .45749 L .32605 .48711 L p .266 .498 .893 r
F P
0 g
s
.33851 .49589 m .32605 .48711 L .31662 .45749 L p .146 .396 .844 r
F P
0 g
s
.494 .5846 m .49774 .58063 L .52252 .56908 L p .762 .942 .94 r
F P
0 g
s
.52288 .5618 m .52252 .56908 L .49774 .58063 L p .832 .911 .892 r
F P
0 g
s
.52252 .56908 m .52288 .5618 L .54416 .54444 L p .854 .853 .841 r
F P
0 g
s
.46077 .58733 m .46757 .58797 L .494 .5846 L p .246 .756 .867 r
F P
0 g
s
.49774 .58063 m .494 .5846 L .46757 .58797 L p .575 .913 .972 r
F P
0 g
s
.66928 .48552 m .65598 .47431 L .66296 .44662 L p .451 .478 .796 r
F P
0 g
s
.64884 .4372 m .66296 .44662 L .65598 .47431 L p .501 .51 .798 r
F P
0 g
s
.60364 .4482 m .59068 .44806 L .5937 .4276 L p .75 .687 .791 r
F P
0 g
s
.5937 .4276 m .60733 .42514 L .60364 .4482 L p .75 .687 .791 r
F P
0 g
s
.54106 .53601 m .54416 .54444 L .52288 .5618 L p .869 .833 .809 r
F P
0 g
s
.54416 .54444 m .54106 .53601 L .55769 .51601 L p .854 .786 .784 r
F P
0 g
s
.35099 .50646 m .36355 .51803 L .381 .54166 L p 0 .129 .658 r
F P
0 g
s
.39216 .55186 m .381 .54166 L .36355 .51803 L p 0 .137 .667 r
F P
0 g
s
.56283 .4897 m .57208 .49372 L .55769 .51601 L p .849 .757 .761 r
F P
0 g
s
.57208 .49372 m .56283 .4897 L .57184 .4698 L p .83 .735 .759 r
F P
0 g
s
.57184 .4698 m .58331 .47058 L .57208 .49372 L p .83 .735 .759 r
F P
0 g
s
.42573 .57602 m .43509 .58142 L .46077 .58733 L p .34 0 0 r
F P
0 g
s
.46757 .58797 m .46077 .58733 L .43509 .58142 L p 0 .542 .796 r
F P
0 g
s
.58331 .47058 m .57184 .4698 L .57772 .4506 L p .812 .722 .765 r
F P
0 g
s
.57772 .4506 m .59068 .44806 L .58331 .47058 L p .812 .722 .765 r
F P
0 g
s
.80008 .54842 m .7877 .55082 L .80615 .51541 L p .769 .937 .938 r
F P
0 g
s
.80615 .51541 m .81965 .5099 L .80008 .54842 L p .769 .937 .938 r
F P
0 g
s
.68264 .49747 m .66928 .48552 L .67724 .45778 L p .415 .459 .798 r
F P
0 g
s
.66296 .44662 m .67724 .45778 L .66928 .48552 L p .451 .478 .796 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54106 .53601 L p .866 .785 .769 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56283 .4897 L p .849 .757 .761 r
F P
0 g
s
.59068 .44806 m .57772 .4506 L .58009 .43335 L p .8 .722 .778 r
F P
0 g
s
.58009 .43335 m .5937 .4276 L .59068 .44806 L p .8 .722 .778 r
F P
0 g
s
.39216 .55186 m .40351 .56115 L .42573 .57602 L p .479 0 0 r
F P
0 g
s
.43509 .58142 m .42573 .57602 L .40351 .56115 L p 0 .236 .664 r
F P
0 g
s
.69605 .50948 m .68264 .49747 L .69166 .46988 L p .394 .455 .805 r
F P
0 g
s
.67724 .45778 m .69166 .46988 L .68264 .49747 L p .415 .459 .798 r
F P
0 g
s
.7877 .55082 m .77511 .55137 L .79241 .51863 L p .714 .883 .959 r
F P
0 g
s
.79241 .51863 m .80615 .51541 L .7877 .55082 L p .714 .883 .959 r
F P
0 g
s
.31662 .45749 m .32996 .46735 L .33851 .49589 L p .146 .396 .844 r
F P
0 g
s
.35099 .50646 m .33851 .49589 L .32996 .46735 L p .074 .326 .805 r
F P
0 g
s
.5603 .47074 m .57184 .4698 L .56283 .4897 L p .854 .754 .752 r
F P
0 g
s
.57184 .4698 m .5603 .47074 L .56471 .45559 L p .844 .747 .756 r
F P
0 g
s
.56471 .45559 m .57772 .4506 L .57184 .4698 L p .844 .747 .756 r
F P
0 g
s
.62105 .42604 m .60733 .42514 L .60553 .40559 L p .657 .656 .837 r
F P
0 g
s
.60733 .42514 m .5937 .4276 L .59212 .41056 L p .736 .703 .82 r
F P
0 g
s
.59212 .41056 m .60553 .40559 L .60733 .42514 L p .736 .703 .82 r
F P
0 g
s
.63487 .43017 m .62105 .42604 L .61906 .40436 L p .564 .597 .845 r
F P
0 g
s
.60553 .40559 m .61906 .40436 L .62105 .42604 L p .657 .656 .837 r
F P
0 g
s
.55352 .48654 m .56283 .4897 L .55128 .50901 L p .865 .767 .752 r
F P
0 g
s
.56283 .4897 m .55352 .48654 L .5603 .47074 L p .854 .754 .752 r
F P
0 g
s
.49774 .58063 m .50154 .57385 L .52288 .5618 L p .832 .911 .892 r
F P
0 g
s
.52324 .55241 m .52288 .5618 L .50154 .57385 L p .864 .873 .843 r
F P
0 g
s
.52288 .5618 m .52324 .55241 L .54106 .53601 L p .869 .833 .809 r
F P
0 g
s
.53792 .5265 m .54106 .53601 L .52324 .55241 L p .877 .815 .784 r
F P
0 g
s
.54106 .53601 m .53792 .5265 L .55128 .50901 L p .866 .785 .769 r
F P
0 g
s
.70947 .52089 m .69605 .50948 L .70618 .48211 L p .39 .468 .82 r
F P
0 g
s
.69166 .46988 m .70618 .48211 L .69605 .50948 L p .394 .455 .805 r
F P
0 g
s
.57772 .4506 m .56471 .45559 L .56647 .44208 L p .838 .749 .764 r
F P
0 g
s
.56647 .44208 m .58009 .43335 L .57772 .4506 L p .838 .749 .764 r
F P
0 g
s
.5937 .4276 m .58009 .43335 L .57877 .41918 L p .796 .737 .797 r
F P
0 g
s
.57877 .41918 m .59212 .41056 L .5937 .4276 L p .796 .737 .797 r
F P
0 g
s
.46757 .58797 m .4745 .58557 L .49774 .58063 L p .575 .913 .972 r
F P
0 g
s
.50154 .57385 m .49774 .58063 L .4745 .58557 L p .759 .927 .943 r
F P
0 g
s
.64884 .4372 m .63487 .43017 L .63274 .40673 L p .464 .532 .842 r
F P
0 g
s
.61906 .40436 m .63274 .40673 L .63487 .43017 L p .564 .597 .845 r
F P
0 g
s
.77511 .55137 m .76231 .54974 L .77843 .51915 L p .642 .804 .961 r
F P
0 g
s
.77843 .51915 m .79241 .51863 L .77511 .55137 L p .642 .804 .961 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53792 .5265 L p .876 .784 .756 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55352 .48654 L p .865 .767 .752 r
F P
0 g
s
.72285 .53106 m .70947 .52089 L .72076 .49361 L p .404 .5 .843 r
F P
0 g
s
.70618 .48211 m .72076 .49361 L .70947 .52089 L p .39 .468 .82 r
F P
0 g
s
.43509 .58142 m .44465 .58412 L .46757 .58797 L p 0 .542 .796 r
F P
0 g
s
.4745 .58557 m .46757 .58797 L .44465 .58412 L p .392 .799 .981 r
F P
0 g
s
.36355 .51803 m .37624 .52969 L .39216 .55186 L p 0 .137 .667 r
F P
0 g
s
.40351 .56115 m .39216 .55186 L .37624 .52969 L p 0 .209 .727 r
F P
0 g
s
.76231 .54974 m .74931 .54578 L .76423 .51677 L p .564 .713 .941 r
F P
0 g
s
.76423 .51677 m .77843 .51915 L .76231 .54974 L p .564 .713 .941 r
F P
0 g
s
.58009 .43335 m .56647 .44208 L .56544 .43112 L p .838 .759 .775 r
F P
0 g
s
.56544 .43112 m .57877 .41918 L .58009 .43335 L p .838 .759 .775 r
F P
0 g
s
.66296 .44662 m .64884 .4372 L .64662 .41235 L p .37 .47 .832 r
F P
0 g
s
.63274 .40673 m .64662 .41235 L .64884 .4372 L p .464 .532 .842 r
F P
0 g
s
.73614 .53948 m .72285 .53106 L .73534 .50363 L p .439 .552 .874 r
F P
0 g
s
.72076 .49361 m .73534 .50363 L .72285 .53106 L p .404 .5 .843 r
F P
0 g
s
.74931 .54578 m .73614 .53948 L .74985 .51151 L p .493 .625 .909 r
F P
0 g
s
.74985 .51151 m .76423 .51677 L .74931 .54578 L p .493 .625 .909 r
F P
0 g
s
.73534 .50363 m .74985 .51151 L .73614 .53948 L p .439 .552 .874 r
F P
0 g
s
.54868 .4731 m .5603 .47074 L .55352 .48654 L p .872 .768 .745 r
F P
0 g
s
.5603 .47074 m .54868 .4731 L .55162 .46261 L p .868 .765 .747 r
F P
0 g
s
.55162 .46261 m .56471 .45559 L .5603 .47074 L p .868 .765 .747 r
F P
0 g
s
.56471 .45559 m .55162 .46261 L .55278 .45331 L p .865 .766 .751 r
F P
0 g
s
.55278 .45331 m .56647 .44208 L .56471 .45559 L p .865 .766 .751 r
F P
0 g
s
.54414 .48409 m .55352 .48654 L .54482 .50197 L p .877 .774 .745 r
F P
0 g
s
.55352 .48654 m .54414 .48409 L .54868 .4731 L p .872 .768 .745 r
F P
0 g
s
.52324 .55241 m .52361 .54098 L .53792 .5265 L p .877 .815 .784 r
F P
0 g
s
.53475 .516 m .53792 .5265 L .52361 .54098 L p .883 .801 .764 r
F P
0 g
s
.53792 .5265 m .53475 .516 L .54482 .50197 L p .876 .784 .756 r
F P
0 g
s
.50154 .57385 m .50539 .56411 L .52324 .55241 L p .864 .873 .843 r
F P
0 g
s
.52361 .54098 m .52324 .55241 L .50539 .56411 L p .878 .839 .803 r
F P
0 g
s
.32996 .46735 m .3433 .47882 L .35099 .50646 L p .074 .326 .805 r
F P
0 g
s
.36355 .51803 m .35099 .50646 L .3433 .47882 L p .056 .297 .785 r
F P
0 g
s
.40351 .56115 m .41506 .56854 L .43509 .58142 L p 0 .236 .664 r
F P
0 g
s
.44465 .58412 m .43509 .58142 L .41506 .56854 L p .003 .479 .867 r
F P
0 g
s
.60553 .40559 m .59212 .41056 L .586 .39809 L p .736 .743 .857 r
F P
0 g
s
.59212 .41056 m .57877 .41918 L .57382 .40905 L p .803 .765 .818 r
F P
0 g
s
.57382 .40905 m .586 .39809 L .59212 .41056 L p .803 .765 .818 r
F P
0 g
s
.61906 .40436 m .60553 .40559 L .59826 .39089 L p .636 .7 .892 r
F P
0 g
s
.586 .39809 m .59826 .39089 L .60553 .40559 L p .736 .743 .857 r
F P
0 g
s
.4745 .58557 m .48155 .57971 L .50154 .57385 L p .759 .927 .943 r
F P
0 g
s
.50539 .56411 m .50154 .57385 L .48155 .57971 L p .836 .889 .879 r
F P
0 g
s
.56647 .44208 m .55278 .45331 L .55208 .44583 L p .866 .772 .756 r
F P
0 g
s
.55208 .44583 m .56544 .43112 L .56647 .44208 L p .866 .772 .756 r
F P
0 g
s
.67724 .45778 m .66296 .44662 L .6607 .42065 L p .294 .421 .82 r
F P
0 g
s
.64662 .41235 m .6607 .42065 L .66296 .44662 L p .37 .47 .832 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53475 .516 L p .882 .782 .746 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54414 .48409 L p .877 .774 .745 r
F P
0 g
s
.57877 .41918 m .56544 .43112 L .56168 .42344 L p .844 .775 .785 r
F P
0 g
s
.56168 .42344 m .57382 .40905 L .57877 .41918 L p .844 .775 .785 r
F P
0 g
s
.63274 .40673 m .61906 .40436 L .61067 .38755 L p .498 .63 .91 r
F P
0 g
s
.59826 .39089 m .61067 .38755 L .61906 .40436 L p .636 .7 .892 r
F P
0 g
s
.44465 .58412 m .45438 .58343 L .4745 .58557 L p .392 .799 .981 r
F P
0 g
s
.48155 .57971 m .4745 .58557 L .45438 .58343 L p .671 .881 .976 r
F P
0 g
s
.56544 .43112 m .55208 .44583 L .54954 .44067 L p .869 .78 .76 r
F P
0 g
s
.54954 .44067 m .56168 .42344 L .56544 .43112 L p .869 .78 .76 r
F P
0 g
s
.50539 .56411 m .50929 .55149 L .52361 .54098 L p .878 .839 .803 r
F P
0 g
s
.52398 .5277 m .52361 .54098 L .50929 .55149 L p .884 .814 .774 r
F P
0 g
s
.52361 .54098 m .52398 .5277 L .53475 .516 L p .883 .801 .764 r
F P
0 g
s
.53156 .50468 m .53475 .516 L .52398 .5277 L p .886 .79 .75 r
F P
0 g
s
.53475 .516 m .53156 .50468 L .5383 .49486 L p .882 .782 .746 r
F P
0 g
s
.53695 .4765 m .54868 .4731 L .54414 .48409 L p .884 .777 .739 r
F P
0 g
s
.54868 .4731 m .53695 .4765 L .53843 .47112 L p .882 .776 .74 r
F P
0 g
s
.53843 .47112 m .55162 .46261 L .54868 .4731 L p .882 .776 .74 r
F P
0 g
s
.55162 .46261 m .53843 .47112 L .53901 .46638 L p .882 .777 .741 r
F P
0 g
s
.53901 .46638 m .55278 .45331 L .55162 .46261 L p .882 .777 .741 r
F P
0 g
s
.37624 .52969 m .38911 .54046 L .40351 .56115 L p 0 .209 .727 r
F P
0 g
s
.41506 .56854 m .40351 .56115 L .38911 .54046 L p 0 .337 .818 r
F P
0 g
s
.53467 .48215 m .54414 .48409 L .5383 .49486 L p .885 .779 .739 r
F P
0 g
s
.54414 .48409 m .53467 .48215 L .53695 .4765 L p .884 .777 .739 r
F P
0 g
s
.64662 .41235 m .63274 .40673 L .62325 .38794 L p .335 .535 .901 r
F P
0 g
s
.61067 .38755 m .62325 .38794 L .63274 .40673 L p .498 .63 .91 r
F P
0 g
s
.69166 .46988 m .67724 .45778 L .675 .4309 L p .244 .392 .813 r
F P
0 g
s
.6607 .42065 m .675 .4309 L .67724 .45778 L p .294 .421 .82 r
F P
0 g
s
.48155 .57971 m .4887 .57024 L .50539 .56411 L p .836 .889 .879 r
F P
0 g
s
.50929 .55149 m .50539 .56411 L .4887 .57024 L p .867 .849 .824 r
F P
0 g
s
.55278 .45331 m .53901 .46638 L .53864 .46258 L p .882 .778 .742 r
F P
0 g
s
.53864 .46258 m .55208 .44583 L .55278 .45331 L p .882 .778 .742 r
F P
0 g
s
.3433 .47882 m .35668 .49117 L .36355 .51803 L p .056 .297 .785 r
F P
0 g
s
.37624 .52969 m .36355 .51803 L .35668 .49117 L p .089 .31 .788 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53156 .50468 L p .887 .781 .739 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53467 .48215 L p .885 .779 .739 r
F P
0 g
s
.586 .39809 m .57382 .40905 L .56551 .40369 L p .82 .801 .834 r
F P
0 g
s
.57382 .40905 m .56168 .42344 L .55541 .41958 L p .855 .795 .791 r
F P
0 g
s
.55541 .41958 m .56551 .40369 L .57382 .40905 L p .855 .795 .791 r
F P
0 g
s
.26639 .40708 m .28039 .40898 L .27594 .44241 L p .654 .793 .949 r
F P
0 g
s
.27594 .44241 m .26201 .4429 L .26639 .40708 L p .654 .793 .949 r
F P
0 g
s
.28966 .44472 m .27594 .44241 L .28039 .40898 L p .562 .713 .942 r
F P
0 g
s
.59826 .39089 m .586 .39809 L .57567 .39108 L p .756 .801 .888 r
F P
0 g
s
.56551 .40369 m .57567 .39108 L .586 .39809 L p .82 .801 .834 r
F P
0 g
s
.25216 .40734 m .26639 .40708 L .26201 .4429 L p .73 .851 .938 r
F P
0 g
s
.26201 .4429 m .24784 .44599 L .25216 .40734 L p .73 .851 .938 r
F P
0 g
s
.41506 .56854 m .42682 .57314 L .44465 .58412 L p .003 .479 .867 r
F P
0 g
s
.45438 .58343 m .44465 .58412 L .42682 .57314 L p .367 .696 .983 r
F P
0 g
s
.28039 .40898 m .29417 .41319 L .28966 .44472 L p .562 .713 .942 r
F P
0 g
s
.3032 .44981 m .28966 .44472 L .29417 .41319 L p .469 .623 .918 r
F P
0 g
s
.55208 .44583 m .53864 .46258 L .53736 .45999 L p .883 .781 .743 r
F P
0 g
s
.53736 .45999 m .54954 .44067 L .55208 .44583 L p .883 .781 .743 r
F P
0 g
s
.56168 .42344 m .54954 .44067 L .54533 .43819 L p .874 .788 .762 r
F P
0 g
s
.54533 .43819 m .55541 .41958 L .56168 .42344 L p .874 .788 .762 r
F P
0 g
s
.50929 .55149 m .51322 .53627 L .52398 .5277 L p .884 .814 .774 r
F P
0 g
s
.52436 .51289 m .52398 .5277 L .51322 .53627 L p .887 .796 .754 r
F P
0 g
s
.52398 .5277 m .52436 .51289 L .53156 .50468 L p .886 .79 .75 r
F P
0 g
s
.61067 .38755 m .59826 .39089 L .58592 .38209 L p .642 .778 .946 r
F P
0 g
s
.57567 .39108 m .58592 .38209 L .59826 .39089 L p .756 .801 .888 r
F P
0 g
s
.2377 .40944 m .25216 .40734 L .24784 .44599 L p .784 .887 .919 r
F P
0 g
s
.24784 .44599 m .23343 .45132 L .2377 .40944 L p .784 .887 .919 r
F P
0 g
s
.52835 .49275 m .53156 .50468 L .52436 .51289 L p .888 .784 .74 r
F P
0 g
s
.53156 .50468 m .52835 .49275 L .53174 .48769 L p .887 .781 .739 r
F P
0 g
s
.45438 .58343 m .46427 .57889 L .48155 .57971 L p .671 .881 .976 r
F P
0 g
s
.4887 .57024 m .48155 .57971 L .46427 .57889 L p .794 .868 .903 r
F P
0 g
s
.29417 .41319 m .30778 .41968 L .3032 .44981 L p .469 .623 .918 r
F P
0 g
s
.31662 .45749 m .3032 .44981 L .30778 .41968 L p .389 .538 .884 r
F P
0 g
s
.4887 .57024 m .49592 .55725 L .50929 .55149 L p .867 .849 .824 r
F P
0 g
s
.51322 .53627 m .50929 .55149 L .49592 .55725 L p .879 .819 .785 r
F P
0 g
s
.6607 .42065 m .64662 .41235 L .63604 .39169 L p .178 .434 .866 r
F P
0 g
s
.62325 .38794 m .63604 .39169 L .64662 .41235 L p .335 .535 .901 r
F P
0 g
s
.70618 .48211 m .69166 .46988 L .68949 .44224 L p .223 .387 .816 r
F P
0 g
s
.675 .4309 m .68949 .44224 L .69166 .46988 L p .244 .392 .813 r
F P
0 g
s
.54954 .44067 m .53736 .45999 L .53523 .45879 L p .885 .783 .744 r
F P
0 g
s
.53523 .45879 m .54533 .43819 L .54954 .44067 L p .885 .783 .744 r
F P
0 g
s
.52511 .48046 m .53695 .4765 L .53467 .48215 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53843 .47112 L .53695 .4765 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53901 .46638 L .53843 .47112 L closepath p .889 .781 .735 r
F P
0 g
s
.22303 .41296 m .2377 .40944 L .23343 .45132 L p .82 .905 .899 r
F P
0 g
s
.23343 .45132 m .21881 .45837 L .22303 .41296 L p .82 .905 .899 r
F P
0 g
s
.52511 .48046 m .53467 .48215 L .53174 .48769 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53864 .46258 L .53901 .46638 L closepath p .889 .781 .735 r
F P
0 g
s
.51322 .53627 m .51717 .51894 L .52436 .51289 L p .887 .796 .754 r
F P
0 g
s
.52474 .49698 m .52436 .51289 L .51717 .51894 L p .888 .785 .742 r
F P
0 g
s
.52436 .51289 m .52474 .49698 L .52835 .49275 L p .888 .784 .74 r
F P
0 g
s
.62325 .38794 m .61067 .38755 L .5963 .37683 L p .452 .706 .976 r
F P
0 g
s
.58592 .38209 m .5963 .37683 L .61067 .38755 L p .642 .778 .946 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49275 L closepath p .889 .781 .735 r
F P
0 g
s
.30778 .41968 m .32125 .4283 L .31662 .45749 L p .389 .538 .884 r
F P
0 g
s
.32996 .46735 m .31662 .45749 L .32125 .4283 L p .335 .472 .85 r
F P
0 g
s
.38911 .54046 m .40217 .54938 L .41506 .56854 L p 0 .337 .818 r
F P
0 g
s
.42682 .57314 m .41506 .56854 L .40217 .54938 L p .218 .492 .899 r
F P
0 g
s
.52511 .48046 m .53736 .45999 L .53864 .46258 L closepath p .889 .781 .735 r
F P
0 g
s
.56551 .40369 m .55541 .41958 L .54703 .41984 L p .868 .81 .791 r
F P
0 g
s
.55541 .41958 m .54533 .43819 L .53972 .43858 L p .88 .795 .762 r
F P
0 g
s
.53972 .43858 m .54703 .41984 L .55541 .41958 L p .88 .795 .762 r
F P
0 g
s
.57567 .39108 m .56551 .40369 L .55438 .40351 L p .843 .831 .835 r
F P
0 g
s
.54703 .41984 m .55438 .40351 L .56551 .40369 L p .868 .81 .791 r
F P
0 g
s
.49592 .55725 m .50319 .5411 L .51322 .53627 L p .879 .819 .785 r
F P
0 g
s
.51717 .51894 m .51322 .53627 L .50319 .5411 L p .885 .798 .759 r
F P
0 g
s
.35668 .49117 m .37016 .50357 L .37624 .52969 L p .089 .31 .788 r
F P
0 g
s
.38911 .54046 m .37624 .52969 L .37016 .50357 L p .167 .357 .808 r
F P
0 g
s
.52511 .48046 m .52835 .49275 L .52474 .49698 L closepath p .889 .781 .735 r
F P
0 g
s
.46427 .57889 m .4743 .57031 L .4887 .57024 L p .794 .868 .903 r
F P
0 g
s
.49592 .55725 m .4887 .57024 L .4743 .57031 L p .846 .838 .838 r
F P
0 g
s
.42682 .57314 m .43879 .57422 L .45438 .58343 L p .367 .696 .983 r
F P
0 g
s
.46427 .57889 m .45438 .58343 L .43879 .57422 L p .623 .793 .964 r
F P
0 g
s
.85906 .48583 m .84605 .4944 L .84655 .44514 L p .884 .922 .844 r
F P
0 g
s
.84655 .44514 m .85986 .43317 L .85906 .48583 L p .884 .922 .844 r
F P
0 g
s
.54533 .43819 m .53523 .45879 L .53242 .45906 L p .886 .785 .744 r
F P
0 g
s
.53242 .45906 m .53972 .43858 L .54533 .43819 L p .886 .785 .744 r
F P
0 g
s
.52511 .48046 m .53523 .45879 L .53736 .45999 L closepath p .889 .781 .735 r
F P
0 g
s
.58592 .38209 m .57567 .39108 L .56177 .3901 L p .793 .854 .896 r
F P
0 g
s
.55438 .40351 m .56177 .3901 L .57567 .39108 L p .843 .831 .835 r
F P
0 g
s
.20817 .41739 m .22303 .41296 L .21881 .45837 L p .839 .911 .885 r
F P
0 g
s
.21881 .45837 m .20402 .46652 L .20817 .41739 L p .839 .911 .885 r
F P
0 g
s
.51717 .51894 m .52114 .5001 L .52474 .49698 L p .888 .785 .742 r
F P
0 g
s
.52511 .48046 m .52474 .49698 L .52114 .5001 L closepath p .889 .781 .735 r
F P
0 g
s
.50319 .5411 m .51049 .52239 L .51717 .51894 L p .885 .798 .759 r
F P
0 g
s
.52114 .5001 m .51717 .51894 L .51049 .52239 L p .888 .786 .743 r
F P
0 g
s
.72076 .49361 m .70618 .48211 L .70413 .45374 L p .234 .408 .831 r
F P
0 g
s
.68949 .44224 m .70413 .45374 L .70618 .48211 L p .223 .387 .816 r
F P
0 g
s
.52511 .48046 m .53242 .45906 L .53523 .45879 L closepath p .889 .781 .735 r
F P
0 g
s
.675 .4309 m .6607 .42065 L .64907 .39822 L p .058 .353 .826 r
F P
0 g
s
.63604 .39169 m .64907 .39822 L .6607 .42065 L p .178 .434 .866 r
F P
0 g
s
.32125 .4283 m .33463 .4387 L .32996 .46735 L p .335 .472 .85 r
F P
0 g
s
.3433 .47882 m .32996 .46735 L .33463 .4387 L p .311 .432 .823 r
F P
0 g
s
.4743 .57031 m .48441 .55782 L .49592 .55725 L p .846 .838 .838 r
F P
0 g
s
.50319 .5411 m .49592 .55725 L .48441 .55782 L p .869 .813 .792 r
F P
0 g
s
.51049 .52239 m .5178 .50188 L .52114 .5001 L p .888 .786 .743 r
F P
0 g
s
.52511 .48046 m .52114 .5001 L .5178 .50188 L closepath p .889 .781 .735 r
F P
0 g
s
.63604 .39169 m .62325 .38794 L .60685 .37517 L p .2 .57 .939 r
F P
0 g
s
.5963 .37683 m .60685 .37517 L .62325 .38794 L p .452 .706 .976 r
F P
0 g
s
.54703 .41984 m .53972 .43858 L .53309 .44183 L p .884 .798 .759 r
F P
0 g
s
.53972 .43858 m .53242 .45906 L .5291 .4608 L p .888 .786 .743 r
F P
0 g
s
.5291 .4608 m .53309 .44183 L .53972 .43858 L p .888 .786 .743 r
F P
0 g
s
.52511 .48046 m .5291 .4608 L .53242 .45906 L closepath p .889 .781 .735 r
F P
0 g
s
.5963 .37683 m .58592 .38209 L .56924 .37993 L p .689 .863 .965 r
F P
0 g
s
.56177 .3901 m .56924 .37993 L .58592 .38209 L p .793 .854 .896 r
F P
0 g
s
.84605 .4944 m .83293 .50267 L .83314 .45675 L p .877 .924 .852 r
F P
0 g
s
.83314 .45675 m .84655 .44514 L .84605 .4944 L p .877 .924 .852 r
F P
0 g
s
.55438 .40351 m .54703 .41984 L .53709 .42425 L p .878 .817 .785 r
F P
0 g
s
.53309 .44183 m .53709 .42425 L .54703 .41984 L p .884 .798 .759 r
F P
0 g
s
.52511 .48046 m .52549 .46388 L .5291 .4608 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .52186 .4681 L .52549 .46388 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52186 .4681 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51547 .47876 L .51844 .47318 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51316 .48447 L .51547 .47876 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51166 .4899 L .51316 .48447 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51109 .49468 L .51166 .4899 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51148 .49849 L .51109 .49468 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .5128 .50105 L .51148 .49849 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51496 .50221 L .5128 .50105 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .5178 .50188 L .51496 .50221 L closepath p .889 .781 .735 r
F P
0 g
s
.48441 .55782 m .49459 .54182 L .50319 .5411 L p .869 .813 .792 r
F P
0 g
s
.51049 .52239 m .50319 .5411 L .49459 .54182 L p .881 .796 .762 r
F P
0 g
s
.19318 .42214 m .20817 .41739 L .20402 .46652 L p .846 .907 .877 r
F P
0 g
s
.20402 .46652 m .18911 .47507 L .19318 .42214 L p .846 .907 .877 r
F P
0 g
s
.43879 .57422 m .45093 .5713 L .46427 .57889 L p .623 .793 .964 r
F P
0 g
s
.4743 .57031 m .46427 .57889 L .45093 .5713 L p .756 .813 .897 r
F P
0 g
s
.50478 .52299 m .51496 .50221 L .5178 .50188 L p .887 .785 .744 r
F P
0 g
s
.5178 .50188 m .51049 .52239 L .50478 .52299 L p .887 .785 .744 r
F P
0 g
s
.49459 .54182 m .50478 .52299 L .51049 .52239 L p .881 .796 .762 r
F P
0 g
s
.40217 .54938 m .41545 .55559 L .42682 .57314 L p .218 .492 .899 r
F P
0 g
s
.43879 .57422 m .42682 .57314 L .41545 .55559 L p .449 .626 .928 r
F P
0 g
s
.53309 .44183 m .5291 .4608 L .52549 .46388 L p .888 .785 .742 r
F P
0 g
s
.56177 .3901 m .55438 .40351 L .54112 .4086 L p .864 .844 .823 r
F P
0 g
s
.53709 .42425 m .54112 .4086 L .55438 .40351 L p .878 .817 .785 r
F P
0 g
s
.73534 .50363 m .72076 .49361 L .71888 .46445 L p .277 .456 .857 r
F P
0 g
s
.70413 .45374 m .71888 .46445 L .72076 .49361 L p .234 .408 .831 r
F P
0 g
s
.37016 .50357 m .38377 .51516 L .38911 .54046 L p .167 .357 .808 r
F P
0 g
s
.40217 .54938 m .38911 .54046 L .38377 .51516 L p .281 .431 .834 r
F P
0 g
s
.50043 .52069 m .5128 .50105 L .51496 .50221 L p .885 .783 .744 r
F P
0 g
s
.51496 .50221 m .50478 .52299 L .50043 .52069 L p .885 .783 .744 r
F P
0 g
s
.33463 .4387 m .34797 .45039 L .3433 .47882 L p .311 .432 .823 r
F P
0 g
s
.35668 .49117 m .3433 .47882 L .34797 .45039 L p .315 .417 .807 r
F P
0 g
s
.53709 .42425 m .53309 .44183 L .52588 .44775 L p .886 .796 .754 r
F P
0 g
s
.52549 .46388 m .52588 .44775 L .53309 .44183 L p .888 .785 .742 r
F P
0 g
s
.52588 .44775 m .52549 .46388 L .52186 .4681 L p .888 .784 .74 r
F P
0 g
s
.83293 .50267 m .81965 .5099 L .81957 .46717 L p .857 .917 .871 r
F P
0 g
s
.81957 .46717 m .83314 .45675 L .83293 .50267 L p .857 .917 .871 r
F P
0 g
s
.45093 .5713 m .46322 .56421 L .4743 .57031 L p .756 .813 .897 r
F P
0 g
s
.48441 .55782 m .4743 .57031 L .46322 .56421 L p .822 .807 .837 r
F P
0 g
s
.49775 .51561 m .51148 .49849 L .5128 .50105 L p .883 .781 .743 r
F P
0 g
s
.5128 .50105 m .50043 .52069 L .49775 .51561 L p .883 .781 .743 r
F P
0 g
s
.48801 .53833 m .50043 .52069 L .50478 .52299 L p .875 .789 .762 r
F P
0 g
s
.50478 .52299 m .49459 .54182 L .48801 .53833 L p .875 .789 .762 r
F P
0 g
s
.60685 .37517 m .5963 .37683 L .57682 .37309 L p .487 .814 1 r
F P
0 g
s
.56924 .37993 m .57682 .37309 L .5963 .37683 L p .689 .863 .965 r
F P
0 g
s
.56924 .37993 m .56177 .3901 L .54519 .39532 L p .834 .878 .875 r
F P
0 g
s
.54112 .4086 m .54519 .39532 L .56177 .3901 L p .864 .844 .823 r
F P
0 g
s
.52186 .4681 m .51858 .45593 L .52588 .44775 L p .888 .784 .74 r
F P
0 g
s
.51858 .45593 m .52186 .4681 L .51844 .47318 L p .887 .781 .739 r
F P
0 g
s
.68949 .44224 m .675 .4309 L .66232 .40678 L p 0 .307 .8 r
F P
0 g
s
.64907 .39822 m .66232 .40678 L .675 .4309 L p .058 .353 .826 r
F P
0 g
s
.54112 .4086 m .53709 .42425 L .52626 .43255 L p .883 .813 .774 r
F P
0 g
s
.52588 .44775 m .52626 .43255 L .53709 .42425 L p .886 .796 .754 r
F P
0 g
s
.46322 .56421 m .47559 .55307 L .48441 .55782 L p .822 .807 .837 r
F P
0 g
s
.49459 .54182 m .48441 .55782 L .47559 .55307 L p .856 .797 .792 r
F P
0 g
s
.47559 .55307 m .48801 .53833 L .49459 .54182 L p .856 .797 .792 r
F P
0 g
s
.49695 .5081 m .51109 .49468 L .51148 .49849 L p .882 .779 .742 r
F P
0 g
s
.51148 .49849 m .49775 .51561 L .49695 .5081 L p .882 .779 .742 r
F P
0 g
s
.64907 .39822 m .63604 .39169 L .6176 .37675 L p 0 .41 .843 r
F P
0 g
s
.60685 .37517 m .6176 .37675 L .63604 .39169 L p .2 .57 .939 r
F P
0 g
s
.74985 .51151 m .73534 .50363 L .73366 .47351 L p .351 .528 .89 r
F P
0 g
s
.71888 .46445 m .73366 .47351 L .73534 .50363 L p .277 .456 .857 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51858 .45593 L p .887 .781 .739 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51547 .47876 L p .885 .779 .739 r
F P
0 g
s
.41545 .55559 m .42891 .5584 L .43879 .57422 L p .449 .626 .928 r
F P
0 g
s
.45093 .5713 m .43879 .57422 L .42891 .5584 L p .624 .709 .907 r
F P
0 g
s
.52626 .43255 m .52588 .44775 L .51858 .45593 L p .886 .79 .75 r
F P
0 g
s
.49809 .49867 m .51166 .4899 L .51109 .49468 L p .882 .777 .741 r
F P
0 g
s
.51109 .49468 m .49695 .5081 L .49809 .49867 L p .882 .777 .741 r
F P
0 g
s
.51547 .47876 m .50573 .47677 L .5117 .46583 L p .885 .779 .739 r
F P
0 g
s
.50573 .47677 m .51547 .47876 L .51316 .48447 L p .884 .777 .739 r
F P
0 g
s
.81965 .5099 m .80615 .51541 L .80579 .47565 L p .818 .897 .898 r
F P
0 g
s
.80579 .47565 m .81957 .46717 L .81965 .5099 L p .818 .897 .898 r
F P
0 g
s
.50108 .48797 m .51316 .48447 L .51166 .4899 L p .883 .777 .74 r
F P
0 g
s
.51166 .4899 m .49809 .49867 L .50108 .48797 L p .883 .777 .74 r
F P
0 g
s
.51316 .48447 m .50108 .48797 L .50573 .47677 L p .884 .777 .739 r
F P
0 g
s
.48395 .53083 m .49775 .51561 L .50043 .52069 L p .87 .78 .76 r
F P
0 g
s
.50043 .52069 m .48801 .53833 L .48395 .53083 L p .87 .78 .76 r
F P
0 g
s
.34797 .45039 m .36132 .46279 L .35668 .49117 L p .315 .417 .807 r
F P
0 g
s
.37016 .50357 m .35668 .49117 L .36132 .46279 L p .346 .425 .801 r
F P
0 g
s
.38377 .51516 m .39755 .52507 L .40217 .54938 L p .281 .431 .834 r
F P
0 g
s
.41545 .55559 m .40217 .54938 L .39755 .52507 L p .412 .515 .854 r
F P
0 g
s
.54519 .39532 m .54112 .4086 L .52665 .41869 L p .876 .836 .803 r
F P
0 g
s
.52626 .43255 m .52665 .41869 L .54112 .4086 L p .883 .813 .774 r
F P
0 g
s
.76423 .51677 m .74985 .51151 L .74841 .48017 L p .45 .618 .922 r
F P
0 g
s
.73366 .47351 m .74841 .48017 L .74985 .51151 L p .351 .528 .89 r
F P
0 g
s
.57682 .37309 m .56924 .37993 L .54929 .38468 L p .767 .91 .937 r
F P
0 g
s
.54519 .39532 m .54929 .38468 L .56924 .37993 L p .834 .878 .875 r
F P
0 g
s
.51858 .45593 m .51528 .4442 L .52626 .43255 L p .886 .79 .75 r
F P
0 g
s
.51528 .4442 m .51858 .45593 L .5117 .46583 L p .882 .782 .746 r
F P
0 g
s
.80615 .51541 m .79241 .51863 L .79178 .48153 L p .756 .859 .926 r
F P
0 g
s
.79178 .48153 m .80579 .47565 L .80615 .51541 L p .756 .859 .926 r
F P
0 g
s
.42891 .5584 m .44255 .55734 L .45093 .5713 L p .624 .709 .907 r
F P
0 g
s
.46322 .56421 m .45093 .5713 L .44255 .55734 L p .737 .752 .864 r
F P
0 g
s
.52665 .41869 m .52626 .43255 L .51528 .4442 L p .882 .8 .764 r
F P
0 g
s
.47012 .54328 m .48395 .53083 L .48801 .53833 L p .846 .778 .786 r
F P
0 g
s
.48801 .53833 m .47559 .55307 L .47012 .54328 L p .846 .778 .786 r
F P
0 g
s
.48271 .51982 m .49695 .5081 L .49775 .51561 L p .866 .772 .756 r
F P
0 g
s
.49775 .51561 m .48395 .53083 L .48271 .51982 L p .866 .772 .756 r
F P
0 g
s
.77843 .51915 m .76423 .51677 L .76305 .48388 L p .561 .713 .943 r
F P
0 g
s
.74841 .48017 m .76305 .48388 L .76423 .51677 L p .45 .618 .922 r
F P
0 g
s
.6176 .37675 m .60685 .37517 L .58452 .36947 L p .188 .663 .933 r
F P
0 g
s
.57682 .37309 m .58452 .36947 L .60685 .37517 L p .487 .814 1 r
F P
0 g
s
.79241 .51863 m .77843 .51915 L .77752 .48435 L p .668 .797 .943 r
F P
0 g
s
.77752 .48435 m .79178 .48153 L .79241 .51863 L p .668 .797 .943 r
F P
0 g
s
.44255 .55734 m .4563 .55226 L .46322 .56421 L p .737 .752 .864 r
F P
0 g
s
.47559 .55307 m .46322 .56421 L .4563 .55226 L p .805 .77 .821 r
F P
0 g
s
.76305 .48388 m .77752 .48435 L .77843 .51915 L p .561 .713 .943 r
F P
0 g
s
.4563 .55226 m .47012 .54328 L .47559 .55307 L p .805 .77 .821 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51528 .4442 L p .882 .782 .746 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50573 .47677 L p .877 .775 .745 r
F P
0 g
s
.70413 .45374 m .68949 .44224 L .6758 .41648 L p 0 .302 .797 r
F P
0 g
s
.66232 .40678 m .6758 .41648 L .68949 .44224 L p 0 .307 .8 r
F P
0 g
s
.48439 .50605 m .49809 .49867 L .49695 .5081 L p .866 .767 .751 r
F P
0 g
s
.49695 .5081 m .48271 .51982 L .48439 .50605 L p .866 .767 .751 r
F P
0 g
s
.54929 .38468 m .54519 .39532 L .52704 .40649 L p .862 .866 .841 r
F P
0 g
s
.52665 .41869 m .52704 .40649 L .54519 .39532 L p .876 .836 .803 r
F P
0 g
s
.36132 .46279 m .37471 .47519 L .37016 .50357 L p .346 .425 .801 r
F P
0 g
s
.38377 .51516 m .37016 .50357 L .37471 .47519 L p .397 .453 .801 r
F P
0 g
s
.39755 .52507 m .41149 .53254 L .41545 .55559 L p .412 .515 .854 r
F P
0 g
s
.42891 .5584 m .41545 .55559 L .41149 .53254 L p .541 .596 .858 r
F P
0 g
s
.50573 .47677 m .4959 .47422 L .50491 .45842 L p .877 .775 .745 r
F P
0 g
s
.4959 .47422 m .50573 .47677 L .50108 .48797 L p .872 .769 .745 r
F P
0 g
s
.66232 .40678 m .64907 .39822 L .62856 .38101 L p 0 .286 .75 r
F P
0 g
s
.6176 .37675 m .62856 .38101 L .64907 .39822 L p 0 .41 .843 r
F P
0 g
s
.4889 .49048 m .50108 .48797 L .49809 .49867 L p .868 .766 .747 r
F P
0 g
s
.49809 .49867 m .48439 .50605 L .4889 .49048 L p .868 .766 .747 r
F P
0 g
s
.50108 .48797 m .4889 .49048 L .4959 .47422 L p .872 .769 .745 r
F P
0 g
s
.51528 .4442 m .51195 .43313 L .52665 .41869 L p .882 .8 .764 r
F P
0 g
s
.51195 .43313 m .51528 .4442 L .50491 .45842 L p .876 .784 .756 r
F P
0 g
s
.52704 .40649 m .52665 .41869 L .51195 .43313 L p .876 .814 .784 r
F P
0 g
s
.46841 .52906 m .48271 .51982 L .48395 .53083 L p .84 .761 .775 r
F P
0 g
s
.48395 .53083 m .47012 .54328 L .46841 .52906 L p .84 .761 .775 r
F P
0 g
s
.58452 .36947 m .57682 .37309 L .55346 .37674 L p .628 .909 .983 r
F P
0 g
s
.54929 .38468 m .55346 .37674 L .57682 .37309 L p .767 .91 .937 r
F P
0 g
s
.41149 .53254 m .42558 .53694 L .42891 .5584 L p .541 .596 .858 r
F P
0 g
s
.44255 .55734 m .42891 .5584 L .42558 .53694 L p .652 .662 .847 r
F P
0 g
s
.45408 .53521 m .46841 .52906 L .47012 .54328 L p .798 .741 .8 r
F P
0 g
s
.47012 .54328 m .4563 .55226 L .45408 .53521 L p .798 .741 .8 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51195 .43313 L p .876 .784 .756 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .4959 .47422 L p .865 .767 .752 r
F P
0 g
s
.37471 .47519 m .38818 .4869 L .38377 .51516 L p .397 .453 .801 r
F P
0 g
s
.39755 .52507 m .38377 .51516 L .38818 .4869 L p .464 .495 .806 r
F P
0 g
s
.47062 .5114 m .48439 .50605 L .48271 .51982 L p .84 .75 .765 r
F P
0 g
s
.48271 .51982 m .46841 .52906 L .47062 .5114 L p .84 .75 .765 r
F P
0 g
s
.55346 .37674 m .54929 .38468 L .52743 .39613 L p .831 .899 .888 r
F P
0 g
s
.52704 .40649 m .52743 .39613 L .54929 .38468 L p .862 .866 .841 r
F P
0 g
s
.42558 .53694 m .43979 .53788 L .44255 .55734 L p .652 .662 .847 r
F P
0 g
s
.4563 .55226 m .44255 .55734 L .43979 .53788 L p .737 .709 .825 r
F P
0 g
s
.43979 .53788 m .45408 .53521 L .4563 .55226 L p .737 .709 .825 r
F P
0 g
s
.58452 .36947 m .59237 .36876 L .6176 .37675 L p .188 .663 .933 r
F P
0 g
s
.62856 .38101 m .6176 .37675 L .59237 .36876 L p 0 .463 .785 r
F P
0 g
s
.71888 .46445 m .70413 .45374 L .68945 .42634 L p .022 .34 .82 r
F P
0 g
s
.6758 .41648 m .68945 .42634 L .70413 .45374 L p 0 .302 .797 r
F P
0 g
s
.52743 .39613 m .52704 .40649 L .50859 .42289 L p .867 .83 .809 r
F P
0 g
s
.51195 .43313 m .50859 .42289 L .52704 .40649 L p .876 .814 .784 r
F P
0 g
s
.50859 .42289 m .51195 .43313 L .49806 .45095 L p .866 .785 .769 r
F P
0 g
s
.4959 .47422 m .486 .47089 L .49806 .45095 L p .865 .767 .752 r
F P
0 g
s
.486 .47089 m .4959 .47422 L .4889 .49048 L p .854 .755 .752 r
F P
0 g
s
.47662 .49154 m .4889 .49048 L .48439 .50605 L p .845 .748 .757 r
F P
0 g
s
.48439 .50605 m .47062 .5114 L .47662 .49154 L p .845 .748 .757 r
F P
0 g
s
.4889 .49048 m .47662 .49154 L .486 .47089 L p .854 .755 .752 r
F P
0 g
s
.31522 .38497 m .3279 .39257 L .30778 .41968 L p .516 .642 .911 r
F P
0 g
s
.30778 .41968 m .29417 .41319 L .31522 .38497 L p .516 .642 .911 r
F P
0 g
s
.32125 .4283 m .30778 .41968 L .3279 .39257 L p .481 .581 .878 r
F P
0 g
s
.30239 .379 m .31522 .38497 L .29417 .41319 L p .566 .714 .941 r
F P
0 g
s
.29417 .41319 m .28039 .40898 L .30239 .379 L p .566 .714 .941 r
F P
0 g
s
.3279 .39257 m .34044 .40165 L .32125 .4283 L p .481 .581 .878 r
F P
0 g
s
.33463 .4387 m .32125 .4283 L .34044 .40165 L p .462 .537 .848 r
F P
0 g
s
.38818 .4869 m .40174 .49721 L .39755 .52507 L p .464 .495 .806 r
F P
0 g
s
.41149 .53254 m .39755 .52507 L .40174 .49721 L p .54 .546 .809 r
F P
0 g
s
.45679 .51423 m .47062 .5114 L .46841 .52906 L p .802 .725 .78 r
F P
0 g
s
.46841 .52906 m .45408 .53521 L .45679 .51423 L p .802 .725 .78 r
F P
0 g
s
.28938 .37466 m .30239 .379 L .28039 .40898 L p .621 .787 .961 r
F P
0 g
s
.28039 .40898 m .26639 .40708 L .28938 .37466 L p .621 .787 .961 r
F P
0 g
s
.6758 .41648 m .66232 .40678 L .63973 .38723 L p 0 .224 .7 r
F P
0 g
s
.62856 .38101 m .63973 .38723 L .66232 .40678 L p 0 .286 .75 r
F P
0 g
s
.59237 .36876 m .58452 .36947 L .55769 .37143 L p .394 .826 .958 r
F P
0 g
s
.55346 .37674 m .55769 .37143 L .58452 .36947 L p .628 .909 .983 r
F P
0 g
s
.34044 .40165 m .35289 .41198 L .33463 .4387 L p .462 .537 .848 r
F P
0 g
s
.34797 .45039 m .33463 .4387 L .35289 .41198 L p .46 .511 .824 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50859 .42289 L p .866 .785 .769 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .486 .47089 L p .85 .758 .761 r
F P
0 g
s
.27618 .37184 m .28938 .37466 L .26639 .40708 L p .675 .849 .966 r
F P
0 g
s
.26639 .40708 m .25216 .40734 L .27618 .37184 L p .675 .849 .966 r
F P
0 g
s
.40174 .49721 m .4154 .5055 L .41149 .53254 L p .54 .546 .809 r
F P
0 g
s
.42558 .53694 m .41149 .53254 L .4154 .5055 L p .617 .599 .81 r
F P
0 g
s
.55769 .37143 m .55346 .37674 L .52783 .38768 L p .771 .926 .937 r
F P
0 g
s
.52743 .39613 m .52783 .38768 L .55346 .37674 L p .831 .899 .888 r
F P
0 g
s
.44296 .51422 m .45679 .51423 L .45408 .53521 L p .752 .691 .794 r
F P
0 g
s
.45408 .53521 m .43979 .53788 L .44296 .51422 L p .752 .691 .794 r
F P
0 g
s
.46428 .4908 m .47662 .49154 L .47062 .5114 L p .814 .725 .766 r
F P
0 g
s
.47062 .5114 m .45679 .51423 L .46428 .4908 L p .814 .725 .766 r
F P
0 g
s
.35289 .41198 m .36527 .4232 L .34797 .45039 L p .46 .511 .824 r
F P
0 g
s
.36132 .46279 m .34797 .45039 L .36527 .4232 L p .473 .502 .807 r
F P
0 g
s
.50859 .42289 m .50519 .41357 L .52743 .39613 L p .867 .83 .809 r
F P
0 g
s
.50519 .41357 m .50859 .42289 L .49116 .44341 L p .854 .786 .784 r
F P
0 g
s
.52783 .38768 m .52743 .39613 L .50519 .41357 L p .852 .848 .839 r
F P
0 g
s
.486 .47089 m .47602 .46661 L .49116 .44341 L p .85 .758 .761 r
F P
0 g
s
.47602 .46661 m .486 .47089 L .47662 .49154 L p .831 .736 .76 r
F P
0 g
s
.4154 .5055 m .42915 .51128 L .42558 .53694 L p .617 .599 .81 r
F P
0 g
s
.43979 .53788 m .42558 .53694 L .42915 .51128 L p .689 .648 .804 r
F P
0 g
s
.42915 .51128 m .44296 .51422 L .43979 .53788 L p .689 .648 .804 r
F P
0 g
s
.47662 .49154 m .46428 .4908 L .47602 .46661 L p .831 .736 .76 r
F P
0 g
s
.73366 .47351 m .71888 .46445 L .70324 .4354 L p .116 .414 .862 r
F P
0 g
s
.68945 .42634 m .70324 .4354 L .71888 .46445 L p .022 .34 .82 r
F P
0 g
s
.26277 .37033 m .27618 .37184 L .25216 .40734 L p .72 .894 .959 r
F P
0 g
s
.25216 .40734 m .2377 .40944 L .26277 .37033 L p .72 .894 .959 r
F P
0 g
s
.36527 .4232 m .37761 .43487 L .36132 .46279 L p .473 .502 .807 r
F P
0 g
s
.37471 .47519 m .36132 .46279 L .37761 .43487 L p .499 .507 .796 r
F P
0 g
s
.59237 .36876 m .60037 .37044 L .62856 .38101 L p 0 .463 .785 r
F P
0 g
s
.63973 .38723 m .62856 .38101 L .60037 .37044 L p 0 .311 .658 r
F P
0 g
s
.45189 .48805 m .46428 .4908 L .45679 .51423 L p .775 .694 .775 r
F P
0 g
s
.45679 .51423 m .44296 .51422 L .45189 .48805 L p .775 .694 .775 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50519 .41357 L p .854 .786 .784 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47602 .46661 L p .83 .745 .77 r
F P
0 g
s
.37761 .43487 m .38995 .44652 L .37471 .47519 L p .499 .507 .796 r
F P
0 g
s
.38818 .4869 m .37471 .47519 L .38995 .44652 L p .535 .525 .791 r
F P
0 g
s
.24919 .36982 m .26277 .37033 L .2377 .40944 L p .754 .921 .946 r
F P
0 g
s
.2377 .40944 m .22303 .41296 L .24919 .36982 L p .754 .921 .946 r
F P
0 g
s
.46598 .46126 m .47602 .46661 L .46428 .4908 L p .802 .714 .767 r
F P
0 g
s
.46428 .4908 m .45189 .48805 L .46598 .46126 L p .802 .714 .767 r
F P
0 g
s
.55769 .37143 m .562 .36848 L .59237 .36876 L p .394 .826 .958 r
F P
0 g
s
.60037 .37044 m .59237 .36876 L .562 .36848 L p .129 .666 .85 r
F P
0 g
s
.47602 .46661 m .46598 .46126 L .48419 .43581 L p .83 .745 .77 r
F P
0 g
s
.68945 .42634 m .6758 .41648 L .6511 .39454 L p 0 .225 .704 r
F P
0 g
s
.63973 .38723 m .6511 .39454 L .6758 .41648 L p 0 .224 .7 r
F P
0 g
s
.50519 .41357 m .50176 .40522 L .52783 .38768 L p .852 .848 .839 r
F P
0 g
s
.50176 .40522 m .50519 .41357 L .48419 .43581 L p .838 .787 .802 r
F P
0 g
s
.43948 .48322 m .45189 .48805 L .44296 .51422 L p .729 .66 .781 r
F P
0 g
s
.44296 .51422 m .42915 .51128 L .43948 .48322 L p .729 .66 .781 r
F P
0 g
s
.38995 .44652 m .4023 .45764 L .38818 .4869 L p .535 .525 .791 r
F P
0 g
s
.40174 .49721 m .38818 .4869 L .4023 .45764 L p .579 .552 .788 r
F P
0 g
s
.562 .36848 m .55769 .37143 L .52824 .38107 L p .669 .928 .972 r
F P
0 g
s
.52783 .38768 m .52824 .38107 L .55769 .37143 L p .771 .926 .937 r
F P
0 g
s
.52824 .38107 m .52783 .38768 L .50176 .40522 L p .827 .866 .874 r
F P
0 g
s
.74841 .48017 m .73366 .47351 L .7171 .44272 L p .252 .515 .908 r
F P
0 g
s
.70324 .4354 m .7171 .44272 L .73366 .47351 L p .116 .414 .862 r
F P
0 g
s
.4023 .45764 m .41467 .46773 L .40174 .49721 L p .579 .552 .788 r
F P
0 g
s
.4154 .5055 m .40174 .49721 L .41467 .46773 L p .629 .586 .787 r
F P
0 g
s
.42707 .47637 m .43948 .48322 L .42915 .51128 L p .68 .623 .785 r
F P
0 g
s
.42915 .51128 m .4154 .5055 L .42707 .47637 L p .68 .623 .785 r
F P
0 g
s
.41467 .46773 m .42707 .47637 L .4154 .5055 L p .629 .586 .787 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50176 .40522 L p .838 .787 .802 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46598 .46126 L p .807 .732 .781 r
F P
0 g
s
.45588 .45481 m .46598 .46126 L .45189 .48805 L p .769 .689 .774 r
F P
0 g
s
.45189 .48805 m .43948 .48322 L .45588 .45481 L p .769 .689 .774 r
F P
0 g
s
.23543 .36994 m .24919 .36982 L .22303 .41296 L p .777 .932 .934 r
F P
0 g
s
.22303 .41296 m .20817 .41739 L .23543 .36994 L p .777 .932 .934 r
F P
0 g
s
.46598 .46126 m .45588 .45481 L .47717 .42815 L p .807 .732 .781 r
F P
0 g
s
.85986 .43317 m .84655 .44514 L .8239 .39554 L p .875 .847 .813 r
F P
0 g
s
.8239 .39554 m .8366 .38074 L .85986 .43317 L p .875 .847 .813 r
F P
0 g
s
.76305 .48388 m .74841 .48017 L .73096 .44755 L p .41 .622 .939 r
F P
0 g
s
.7171 .44272 m .73096 .44755 L .74841 .48017 L p .252 .515 .908 r
F P
0 g
s
.50176 .40522 m .49829 .39778 L .52824 .38107 L p .827 .866 .874 r
F P
0 g
s
.49829 .39778 m .50176 .40522 L .47717 .42815 L p .818 .786 .822 r
F P
0 g
s
.60037 .37044 m .60854 .37385 L .63973 .38723 L p 0 .311 .658 r
F P
0 g
s
.6511 .39454 m .63973 .38723 L .60854 .37385 L p .343 0 0 r
F P
0 g
s
.44574 .44729 m .45588 .45481 L .43948 .48322 L p .734 .662 .779 r
F P
0 g
s
.43948 .48322 m .42707 .47637 L .44574 .44729 L p .734 .662 .779 r
F P
0 g
s
.84655 .44514 m .83314 .45675 L .81113 .40995 L p .87 .847 .819 r
F P
0 g
s
.81113 .40995 m .8239 .39554 L .84655 .44514 L p .87 .847 .819 r
F P
0 g
s
.52824 .38107 m .52865 .3761 L .562 .36848 L p .669 .928 .972 r
F P
0 g
s
.52865 .3761 m .52824 .38107 L .49829 .39778 L p .791 .88 .911 r
F P
0 g
s
.22154 .37026 m .23543 .36994 L .20817 .41739 L p .79 .93 .926 r
F P
0 g
s
.20817 .41739 m .19318 .42214 L .22154 .37026 L p .79 .93 .926 r
F P
0 g
s
.70324 .4354 m .68945 .42634 L .66266 .40199 L p 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .68945 .42634 L p .65394 .39689 L 0 .225 .704 r
F P
0 g
s
.67435 .40865 m .70324 .4354 L p .6689 .40713 L 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .67435 .40865 L p .6689 .40713 L 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .62532 .38269 L p .67097 .40686 L 0 .308 .703 r
F P
0 g
s
.67435 .40865 m .66266 .40199 L p .67097 .40686 L 0 .308 .703 r
F P
0 g
s
.6511 .39454 m .66266 .40199 L p .65394 .39689 L 0 .225 .704 r
F P
0 g
s
.66266 .40199 m .6511 .39454 L .61686 .37822 L p .334 0 0 r
F P
0 g
s
.62532 .38269 m .66266 .40199 L p .62024 .37997 L .334 0 0 r
F P
0 g
s
.61686 .37822 m .62532 .38269 L p .62024 .37997 L .334 0 0 r
F P
0 g
s
.562 .36848 m .5664 .36747 L .60037 .37044 L p .129 .666 .85 r
F P
0 g
s
.62532 .38269 m .61686 .37822 L .57543 .36896 L p 0 .414 .694 r
F P
0 g
s
.58006 .37013 m .62532 .38269 L p .5791 .36997 L 0 .414 .694 r
F P
0 g
s
.57543 .36896 m .58006 .37013 L p .5791 .36997 L 0 .414 .694 r
F P
0 g
s
.62532 .38269 m .58006 .37013 L p .63016 .38529 L 0 .465 .774 r
F P
0 g
s
.5664 .36747 m .562 .36848 L .52865 .3761 L p .524 .889 .975 r
F P
0 g
s
.52865 .3761 m .52907 .37249 L .5664 .36747 L p .524 .889 .975 r
F P
0 g
s
.60854 .37385 m .60037 .37044 L .5664 .36747 L p 0 .514 .736 r
F P
0 g
s
.5664 .36747 m .57087 .36784 L .60854 .37385 L p 0 .514 .736 r
F P
0 g
s
.57087 .36784 m .5664 .36747 L .52907 .37249 L p .374 .818 .948 r
F P
0 g
s
.52907 .37249 m .5295 .36982 L .57087 .36784 L p .374 .818 .948 r
F P
0 g
s
.57543 .36896 m .57087 .36784 L .5295 .36982 L p .263 .749 .922 r
F P
0 g
s
.5295 .36982 m .52993 .36764 L .57543 .36896 L p .263 .749 .922 r
F P
0 g
s
.58006 .37013 m .57543 .36896 L .52993 .36764 L p .217 .71 .92 r
F P
0 g
s
.52993 .36764 m .53037 .36544 L .58006 .37013 L p .217 .71 .92 r
F P
0 g
s
.63389 .38641 m .67435 .40865 L p .63283 .38667 L 0 .308 .703 r
F P
0 g
s
.62532 .38269 m .63389 .38641 L p .63283 .38667 L 0 .308 .703 r
F P
0 g
s
.63389 .38641 m .62532 .38269 L p .63008 .38524 L 0 .465 .774 r
F P
0 g
s
.63016 .38529 m .63389 .38641 L .63008 .38524 L 0 .465 .774 r
F
.60854 .37385 m .61686 .37822 L .6511 .39454 L p .343 0 0 r
F P
0 g
s
.61686 .37822 m .60854 .37385 L .57087 .36784 L p .166 0 0 r
F P
0 g
s
.57087 .36784 m .57543 .36896 L .61686 .37822 L p .166 0 0 r
F P
0 g
s
.63389 .38641 m .58475 .37063 L p .63482 .38618 L .057 .56 .884 r
F P
0 g
s
.64253 .38858 m .63389 .38641 L p .63482 .38618 L .057 .56 .884 r
F P
0 g
s
.58006 .37013 m .58475 .37063 L .63389 .38641 L p 0 .465 .774 r
F P
0 g
s
.58006 .37013 m .53037 .36544 L p .58098 .37027 L .237 .704 .945 r
F P
0 g
s
.58475 .37063 m .58006 .37013 L p .58098 .37027 L .237 .704 .945 r
F P
0 g
s
.67435 .40865 m .63389 .38641 L p .67918 .41 L 0 .432 .827 r
F P
0 g
s
.68612 .41361 m .67435 .40865 L p .67918 .41 L 0 .432 .827 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49829 .39778 L p .818 .786 .822 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45588 .45481 L p .781 .716 .791 r
F P
0 g
s
.43556 .43881 m .44574 .44729 L .42707 .47637 L p .697 .636 .784 r
F P
0 g
s
.42707 .47637 m .41467 .46773 L .43556 .43881 L p .697 .636 .784 r
F P
0 g
s
.45588 .45481 m .44574 .44729 L .47008 .42042 L p .781 .716 .791 r
F P
0 g
s
.77752 .48435 m .76305 .48388 L .74475 .44929 L p .559 .714 .944 r
F P
0 g
s
.73096 .44755 m .74475 .44929 L .76305 .48388 L p .41 .622 .939 r
F P
0 g
s
.83314 .45675 m .81957 .46717 L .79824 .42309 L p .853 .844 .835 r
F P
0 g
s
.79824 .42309 m .81113 .40995 L .83314 .45675 L p .853 .844 .835 r
F P
0 g
s
.42534 .42954 m .43556 .43881 L .41467 .46773 L p .661 .613 .79 r
F P
0 g
s
.41467 .46773 m .4023 .45764 L .42534 .42954 L p .661 .613 .79 r
F P
0 g
s
.41509 .4197 m .42534 .42954 L .4023 .45764 L p .628 .594 .797 r
F P
0 g
s
.4023 .45764 m .38995 .44652 L .41509 .4197 L p .628 .594 .797 r
F P
0 g
s
.81957 .46717 m .80579 .47565 L .78516 .43417 L p .82 .835 .861 r
F P
0 g
s
.78516 .43417 m .79824 .42309 L .81957 .46717 L p .82 .835 .861 r
F P
0 g
s
.79178 .48153 m .77752 .48435 L .7584 .44763 L p .68 .778 .925 r
F P
0 g
s
.74475 .44929 m .7584 .44763 L .77752 .48435 L p .559 .714 .944 r
F P
0 g
s
.4048 .40954 m .41509 .4197 L .38995 .44652 L p .598 .581 .806 r
F P
0 g
s
.38995 .44652 m .37761 .43487 L .4048 .40954 L p .598 .581 .806 r
F P
0 g
s
.49829 .39778 m .49477 .39118 L .52865 .3761 L p .791 .88 .911 r
F P
0 g
s
.49477 .39118 m .49829 .39778 L .47008 .42042 L p .794 .784 .844 r
F P
0 g
s
.39445 .39932 m .4048 .40954 L .37761 .43487 L p .573 .577 .818 r
F P
0 g
s
.37761 .43487 m .36527 .4232 L .39445 .39932 L p .573 .577 .818 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44574 .44729 L p .753 .701 .802 r
F P
0 g
s
.44574 .44729 m .43556 .43881 L .46294 .41262 L p .753 .701 .802 r
F P
0 g
s
.80579 .47565 m .79178 .48153 L .77189 .44251 L p .765 .815 .893 r
F P
0 g
s
.77189 .44251 m .78516 .43417 L .80579 .47565 L p .765 .815 .893 r
F P
0 g
s
.38405 .38929 m .39445 .39932 L .36527 .4232 L p .555 .582 .836 r
F P
0 g
s
.36527 .4232 m .35289 .41198 L .38405 .38929 L p .555 .582 .836 r
F P
0 g
s
.7584 .44763 m .77189 .44251 L .79178 .48153 L p .68 .778 .925 r
F P
0 g
s
.37357 .37969 m .38405 .38929 L .35289 .41198 L p .545 .598 .858 r
F P
0 g
s
.35289 .41198 m .34044 .40165 L .37357 .37969 L p .545 .598 .858 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49477 .39118 L p .794 .784 .844 r
F P
0 g
s
.363 .37069 m .37357 .37969 L .34044 .40165 L p .544 .626 .884 r
F P
0 g
s
.34044 .40165 m .3279 .39257 L .363 .37069 L p .544 .626 .884 r
F P
0 g
s
.52907 .37249 m .52865 .3761 L .49477 .39118 L p .741 .884 .945 r
F P
0 g
s
.35232 .36244 m .363 .37069 L .3279 .39257 L p .552 .667 .913 r
F P
0 g
s
.3279 .39257 m .31522 .38497 L .35232 .36244 L p .552 .667 .913 r
F P
0 g
s
.7171 .44272 m .70324 .4354 L .67435 .40865 L p 0 .393 .841 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43556 .43881 L p .724 .686 .813 r
F P
0 g
s
.43556 .43881 m .42534 .42954 L .45573 .40475 L p .724 .686 .813 r
F P
0 g
s
.34153 .35499 m .35232 .36244 L .31522 .38497 L p .568 .716 .941 r
F P
0 g
s
.31522 .38497 m .30239 .379 L .34153 .35499 L p .568 .716 .941 r
F P
0 g
s
.49477 .39118 m .49121 .38523 L .52907 .37249 L p .741 .884 .945 r
F P
0 g
s
.49121 .38523 m .49477 .39118 L .46294 .41262 L p .764 .78 .865 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49121 .38523 L p .764 .78 .865 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42534 .42954 L p .694 .673 .825 r
F P
0 g
s
.42534 .42954 m .41509 .4197 L .44846 .39682 L p .694 .673 .825 r
F P
0 g
s
.33061 .34837 m .34153 .35499 L .30239 .379 L p .591 .768 .964 r
F P
0 g
s
.30239 .379 m .28938 .37466 L .33061 .34837 L p .591 .768 .964 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41509 .4197 L p .665 .664 .838 r
F P
0 g
s
.41509 .4197 m .4048 .40954 L .44112 .38881 L p .665 .664 .838 r
F P
0 g
s
.73096 .44755 m .7171 .44272 L .68612 .41361 L p .174 .525 .92 r
F P
0 g
s
.67435 .40865 m .68612 .41361 L .7171 .44272 L p 0 .393 .841 r
F P
0 g
s
.5295 .36982 m .52907 .37249 L .49121 .38523 L p .681 .876 .972 r
F P
0 g
s
.31955 .3425 m .33061 .34837 L .28938 .37466 L p .618 .818 .977 r
F P
0 g
s
.28938 .37466 m .27618 .37184 L .31955 .3425 L p .618 .818 .977 r
F P
0 g
s
.4876 .37973 m .49121 .38523 L .45573 .40475 L p .731 .773 .886 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .4876 .37973 L p .731 .773 .886 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .4048 .40954 L p .638 .658 .853 r
F P
0 g
s
.4048 .40954 m .39445 .39932 L .43372 .38074 L p .638 .658 .853 r
F P
0 g
s
.49121 .38523 m .4876 .37973 L .5295 .36982 L p .681 .876 .972 r
F P
0 g
s
.30835 .33729 m .31955 .3425 L .27618 .37184 L p .646 .857 .98 r
F P
0 g
s
.27618 .37184 m .26277 .37033 L .30835 .33729 L p .646 .857 .98 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39445 .39932 L p .614 .658 .869 r
F P
0 g
s
.39445 .39932 m .38405 .38929 L .42626 .3726 L p .614 .658 .869 r
F P
0 g
s
.74475 .44929 m .73096 .44755 L .69792 .41612 L p .387 .641 .956 r
F P
0 g
s
.68612 .41361 m .69792 .41612 L .73096 .44755 L p .174 .525 .92 r
F P
0 g
s
.48394 .37444 m .4876 .37973 L .44846 .39682 L p .696 .764 .904 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48394 .37444 L p .696 .764 .904 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38405 .38929 L p .594 .663 .887 r
F P
0 g
s
.38405 .38929 m .37357 .37969 L .41873 .36438 L p .594 .663 .887 r
F P
0 g
s
.52993 .36764 m .5295 .36982 L .4876 .37973 L p .618 .856 .988 r
F P
0 g
s
.29702 .33256 m .30835 .33729 L .26277 .37033 L p .672 .885 .976 r
F P
0 g
s
.26277 .37033 m .24919 .36982 L .29702 .33256 L p .672 .885 .976 r
F P
0 g
s
.4876 .37973 m .48394 .37444 L .52993 .36764 L p .618 .856 .988 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37357 .37969 L p .58 .676 .906 r
F P
0 g
s
.37357 .37969 m .363 .37069 L .41113 .35609 L p .58 .676 .906 r
F P
0 g
s
.7584 .44763 m .74475 .44929 L .7097 .41562 L p .559 .716 .946 r
F P
0 g
s
.69792 .41612 m .7097 .41562 L .74475 .44929 L p .387 .641 .956 r
F P
0 g
s
.48024 .36909 m .48394 .37444 L .44112 .38881 L p .66 .753 .919 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48024 .36909 L p .66 .753 .919 r
F P
0 g
s
.28557 .32812 m .29702 .33256 L .24919 .36982 L p .695 .899 .97 r
F P
0 g
s
.24919 .36982 m .23543 .36994 L .28557 .32812 L p .695 .899 .97 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .363 .37069 L p .571 .694 .925 r
F P
0 g
s
.363 .37069 m .35232 .36244 L .40346 .34772 L p .571 .694 .925 r
F P
0 g
s
.77189 .44251 m .7584 .44763 L .72139 .41178 L p .676 .754 .909 r
F P
0 g
s
.7097 .41562 m .72139 .41178 L .7584 .44763 L p .559 .716 .946 r
F P
0 g
s
.53037 .36544 m .52993 .36764 L .48394 .37444 L p .566 .828 .995 r
F P
0 g
s
.48394 .37444 m .48024 .36909 L .53037 .36544 L p .566 .828 .995 r
F P
0 g
s
.4765 .36344 m .48024 .36909 L .43372 .38074 L p .626 .741 .93 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .4765 .36344 L p .626 .741 .93 r
F P
0 g
s
.8366 .38074 m .8239 .39554 L .77795 .34956 L p .84 .779 .793 r
F P
0 g
s
.77795 .34956 m .78901 .33274 L .8366 .38074 L p .84 .779 .793 r
F P
0 g
s
.78516 .43417 m .77189 .44251 L .73297 .40456 L p .75 .77 .869 r
F P
0 g
s
.72139 .41178 m .73297 .40456 L .77189 .44251 L p .676 .754 .909 r
F P
0 g
s
.8239 .39554 m .81113 .40995 L .76686 .36595 L p .835 .778 .797 r
F P
0 g
s
.76686 .36595 m .77795 .34956 L .8239 .39554 L p .835 .778 .797 r
F P
0 g
s
.27399 .32374 m .28557 .32812 L .23543 .36994 L p .714 .901 .963 r
F P
0 g
s
.23543 .36994 m .22154 .37026 L .27399 .32374 L p .714 .901 .963 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35232 .36244 L p .57 .718 .942 r
F P
0 g
s
.35232 .36244 m .34153 .35499 L .39573 .33928 L p .57 .718 .942 r
F P
0 g
s
.69792 .41612 m .68612 .41361 L .64253 .38858 L p .167 .571 .934 r
F P
0 g
s
.63389 .38641 m .64253 .38858 L .68612 .41361 L p 0 .432 .827 r
F P
0 g
s
.81113 .40995 m .79824 .42309 L .7557 .38109 L p .821 .777 .811 r
F P
0 g
s
.7557 .38109 m .76686 .36595 L .81113 .40995 L p .821 .777 .811 r
F P
0 g
s
.79824 .42309 m .78516 .43417 L .7444 .39417 L p .795 .775 .835 r
F P
0 g
s
.73297 .40456 m .7444 .39417 L .78516 .43417 L p .75 .77 .869 r
F P
0 g
s
.7444 .39417 m .7557 .38109 L .79824 .42309 L p .795 .775 .835 r
F P
0 g
s
.47271 .35723 m .4765 .36344 L .42626 .3726 L p .599 .731 .937 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47271 .35723 L p .599 .731 .937 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34153 .35499 L p .575 .744 .957 r
F P
0 g
s
.34153 .35499 m .33061 .34837 L .38792 .33076 L p .575 .744 .957 r
F P
0 g
s
.53081 .36274 m .53037 .36544 L .48024 .36909 L p .532 .799 .995 r
F P
0 g
s
.48024 .36909 m .4765 .36344 L .53081 .36274 L p .532 .799 .995 r
F P
0 g
s
.53037 .36544 m .53081 .36274 L .58475 .37063 L p .237 .704 .945 r
F P
0 g
s
.7097 .41562 m .69792 .41612 L .65122 .38851 L p .396 .671 .971 r
F P
0 g
s
.64253 .38858 m .65122 .38851 L .69792 .41612 L p .167 .571 .934 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33061 .34837 L p .587 .77 .967 r
F P
0 g
s
.33061 .34837 m .31955 .3425 L .38005 .32217 L p .587 .77 .967 r
F P
0 g
s
.4689 .35028 m .47271 .35723 L .41873 .36438 L p .58 .724 .941 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .4689 .35028 L p .58 .724 .941 r
F P
0 g
s
.53126 .35907 m .53081 .36274 L .4765 .36344 L p .52 .774 .989 r
F P
0 g
s
.4765 .36344 m .47271 .35723 L .53126 .35907 L p .52 .774 .989 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31955 .3425 L p .604 .794 .972 r
F P
0 g
s
.31955 .3425 m .30835 .33729 L .3721 .3135 L p .604 .794 .972 r
F P
0 g
s
.58475 .37063 m .58949 .36983 L .64253 .38858 L p .057 .56 .884 r
F P
0 g
s
.58949 .36983 m .58475 .37063 L .53081 .36274 L p .309 .718 .977 r
F P
0 g
s
.72139 .41178 m .7097 .41562 L .65991 .3857 L p .56 .718 .946 r
F P
0 g
s
.65122 .38851 m .65991 .3857 L .7097 .41562 L p .396 .671 .971 r
F P
0 g
s
.65122 .38851 m .64253 .38858 L .58949 .36983 L p .257 .654 .965 r
F P
0 g
s
.46506 .34244 m .4689 .35028 L .41113 .35609 L p .57 .72 .943 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46506 .34244 L p .57 .72 .943 r
F P
0 g
s
.53081 .36274 m .53126 .35907 L .58949 .36983 L p .309 .718 .977 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30835 .33729 L p .624 .813 .973 r
F P
0 g
s
.30835 .33729 m .29702 .33256 L .36408 .30475 L p .624 .813 .973 r
F P
0 g
s
.73297 .40456 m .72139 .41178 L .66857 .37986 L p .662 .731 .901 r
F P
0 g
s
.65991 .3857 m .66857 .37986 L .72139 .41178 L p .56 .718 .946 r
F P
0 g
s
.46119 .33363 m .46506 .34244 L .40346 .34772 L p .569 .719 .943 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46119 .33363 L p .569 .719 .943 r
F P
0 g
s
.53172 .35404 m .53126 .35907 L .47271 .35723 L p .526 .752 .979 r
F P
0 g
s
.47271 .35723 m .4689 .35028 L .53172 .35404 L p .526 .752 .979 r
F P
0 g
s
.65991 .3857 m .65122 .38851 L .59427 .36716 L p .437 .706 .979 r
F P
0 g
s
.58949 .36983 m .59427 .36716 L .65122 .38851 L p .257 .654 .965 r
F P
0 g
s
.59427 .36716 m .58949 .36983 L .53126 .35907 L p .405 .731 .991 r
F P
0 g
s
.7444 .39417 m .73297 .40456 L .67717 .37094 L p .722 .731 .858 r
F P
0 g
s
.66857 .37986 m .67717 .37094 L .73297 .40456 L p .662 .731 .901 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29702 .33256 L p .645 .825 .97 r
F P
0 g
s
.29702 .33256 m .28557 .32812 L .35599 .29592 L p .645 .825 .97 r
F P
0 g
s
.53126 .35907 m .53172 .35404 L .59427 .36716 L p .405 .731 .991 r
F P
0 g
s
.45731 .32383 m .46119 .33363 L .39573 .33928 L p .577 .722 .942 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45731 .32383 L p .577 .722 .942 r
F P
0 g
s
.7557 .38109 m .7444 .39417 L .68569 .35914 L p .758 .728 .825 r
F P
0 g
s
.67717 .37094 m .68569 .35914 L .7444 .39417 L p .722 .731 .858 r
F P
0 g
s
.53217 .34736 m .53172 .35404 L .4689 .35028 L p .544 .735 .964 r
F P
0 g
s
.4689 .35028 m .46506 .34244 L .53217 .34736 L p .544 .735 .964 r
F P
0 g
s
.76686 .36595 m .7557 .38109 L .69415 .34487 L p .78 .726 .803 r
F P
0 g
s
.68569 .35914 m .69415 .34487 L .7557 .38109 L p .758 .728 .825 r
F P
0 g
s
.77795 .34956 m .76686 .36595 L .70254 .32872 L p .792 .726 .79 r
F P
0 g
s
.69415 .34487 m .70254 .32872 L .76686 .36595 L p .78 .726 .803 r
F P
0 g
s
.78901 .33274 m .77795 .34956 L .7109 .31138 L p .797 .727 .787 r
F P
0 g
s
.70254 .32872 m .7109 .31138 L .77795 .34956 L p .792 .726 .79 r
F P
0 g
s
.7109 .31138 m .71927 .29362 L .78901 .33274 L p .797 .727 .787 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28557 .32812 L p .664 .83 .963 r
F P
0 g
s
.28557 .32812 m .27399 .32374 L .34782 .287 L p .664 .83 .963 r
F P
0 g
s
.66857 .37986 m .65991 .3857 L .59905 .36222 L p .562 .72 .947 r
F P
0 g
s
.59427 .36716 m .59905 .36222 L .65991 .3857 L p .437 .706 .979 r
F P
0 g
s
.4534 .31311 m .45731 .32383 L .38792 .33076 L p .589 .727 .939 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .4534 .31311 L p .589 .727 .939 r
F P
0 g
s
.59905 .36222 m .59427 .36716 L .53172 .35404 L p .495 .731 .977 r
F P
0 g
s
.53172 .35404 m .53217 .34736 L .59905 .36222 L p .495 .731 .977 r
F P
0 g
s
.53263 .33888 m .53217 .34736 L .46506 .34244 L p .568 .721 .945 r
F P
0 g
s
.46506 .34244 m .46119 .33363 L .53263 .33888 L p .568 .721 .945 r
F P
0 g
s
.67717 .37094 m .66857 .37986 L .60384 .35477 L p .64 .715 .902 r
F P
0 g
s
.59905 .36222 m .60384 .35477 L .66857 .37986 L p .562 .72 .947 r
F P
0 g
s
.44947 .30157 m .4534 .31311 L .38005 .32217 L p .606 .734 .935 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44947 .30157 L p .606 .734 .935 r
F P
0 g
s
.60384 .35477 m .59905 .36222 L .53217 .34736 L p .565 .721 .946 r
F P
0 g
s
.53309 .32858 m .53263 .33888 L .46119 .33363 L p .592 .709 .925 r
F P
0 g
s
.46119 .33363 m .45731 .32383 L .53309 .32858 L p .592 .709 .925 r
F P
0 g
s
.53217 .34736 m .53263 .33888 L .60384 .35477 L p .565 .721 .946 r
F P
0 g
s
.68569 .35914 m .67717 .37094 L .60861 .34477 L p .687 .705 .861 r
F P
0 g
s
.60384 .35477 m .60861 .34477 L .67717 .37094 L p .64 .715 .902 r
F P
0 g
s
.44552 .28939 m .44947 .30157 L .3721 .3135 L p .623 .74 .931 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44552 .28939 L p .623 .74 .931 r
F P
0 g
s
.69415 .34487 m .68569 .35914 L .61336 .33239 L p .717 .697 .831 r
F P
0 g
s
.60861 .34477 m .61336 .33239 L .68569 .35914 L p .687 .705 .861 r
F P
0 g
s
.60861 .34477 m .60384 .35477 L .53263 .33888 L p .615 .707 .91 r
F P
0 g
s
.53354 .31655 m .53309 .32858 L .45731 .32383 L p .615 .701 .906 r
F P
0 g
s
.45731 .32383 m .4534 .31311 L .53354 .31655 L p .615 .701 .906 r
F P
0 g
s
.53263 .33888 m .53309 .32858 L .60861 .34477 L p .615 .707 .91 r
F P
0 g
s
.44155 .27677 m .44552 .28939 L .36408 .30475 L p .64 .746 .925 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44155 .27677 L p .64 .746 .925 r
F P
0 g
s
.70254 .32872 m .69415 .34487 L .6181 .31794 L p .735 .693 .81 r
F P
0 g
s
.61336 .33239 m .6181 .31794 L .69415 .34487 L p .717 .697 .831 r
F P
0 g
s
.7109 .31138 m .70254 .32872 L .62282 .30191 L p .747 .692 .799 r
F P
0 g
s
.6181 .31794 m .62282 .30191 L .70254 .32872 L p .735 .693 .81 r
F P
0 g
s
.61336 .33239 m .60861 .34477 L .53309 .32858 L p .65 .694 .878 r
F P
0 g
s
.534 .30303 m .53354 .31655 L .4534 .31311 L p .635 .696 .889 r
F P
0 g
s
.4534 .31311 m .44947 .30157 L .534 .30303 L p .635 .696 .889 r
F P
0 g
s
.71927 .29362 m .7109 .31138 L .62753 .28487 L p .754 .695 .796 r
F P
0 g
s
.62282 .30191 m .62753 .28487 L .7109 .31138 L p .747 .692 .799 r
F P
0 g
s
.43754 .26392 m .44155 .27677 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53309 .32858 m .53354 .31655 L .61336 .33239 L p .65 .694 .878 r
F P
0 g
s
.62753 .28487 m .63227 .26744 L .71927 .29362 L p .754 .695 .796 r
F P
0 g
s
.6181 .31794 m .61336 .33239 L .53354 .31655 L p .675 .685 .852 r
F P
0 g
s
.53446 .28835 m .534 .30303 L .44947 .30157 L p .652 .694 .877 r
F P
0 g
s
.44947 .30157 m .44552 .28939 L .53446 .28835 L p .652 .694 .877 r
F P
0 g
s
.53354 .31655 m .534 .30303 L .6181 .31794 L p .675 .685 .852 r
F P
0 g
s
.62282 .30191 m .6181 .31794 L .534 .30303 L p .692 .681 .835 r
F P
0 g
s
.53492 .2729 m .53446 .28835 L .44552 .28939 L p .666 .696 .868 r
F P
0 g
s
.44552 .28939 m .44155 .27677 L .53492 .2729 L p .666 .696 .868 r
F P
0 g
s
.534 .30303 m .53446 .28835 L .62282 .30191 L p .692 .681 .835 r
F P
0 g
s
.62753 .28487 m .62282 .30191 L .53446 .28835 L p .704 .68 .824 r
F P
0 g
s
.63227 .26744 m .62753 .28487 L .53492 .2729 L p .712 .684 .821 r
F P
0 g
s
.53446 .28835 m .53492 .2729 L .62753 .28487 L p .704 .68 .824 r
F P
0 g
s
.53539 .25714 m .53492 .2729 L .44155 .27677 L p .677 .7 .864 r
F P
0 g
s
.44155 .27677 m .43754 .26392 L .53539 .25714 L p .677 .7 .864 r
F P
0 g
s
.53492 .2729 m .53539 .25714 L .63227 .26744 L p .712 .684 .821 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?n]/md00ol0003o]ZoBokJ_dP04okJ_dP_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00006On]/md00ol0003o
]ZoBokJ_dP0?okJ_dP_o00006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oo
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`Co00000_nW`>/00ol0003o[K?Mojfcg@0Nojfcg@03o`000?nf[m;o]ZoB01[o]ZoB
1ol0000Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0ol0
0007ojO0j`03o`000?n]/mgo[K?M01go[K?M00?o0000okJ_d_nf[m807_nf[m800ol0003o`K7;ol6a
b`03o`00017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4
o`0000[oYl3[00?o0000ojfcgOn]/md03_n]/md@o`0001oo]ZoB00?o0000ol6aboo1/L/01?o1/L/3
o`0000kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool4o`00
00goYl3[0ol00002ojfcg@go00003onZ/]h00ol0003o]:kBokB^dP02okB^dPSo00004onf[m800ol0
003o`K7;ol6ab`07ol6ab`?o00002oooool00ol0003oooooooooo`0cooooo`;o0000;_ooool001_o
oooo00?oEEEEofIVI_l000001_ooool2o`0000[ooooo00?o0000ooooooooool0HOooool4o`0000go
Yl3[1?l00002oj>nk003o`000?nZ/]koZ[;N01coZ[;N00?o0000okB^d_nd[]802_nd[]87o`0000co
]ZoB00?o0000ol6aboo1/L/02_o1/L/4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
0ol0000=ojO0j`Co00001_nS_^`00ol0003oZ[;NojZbgP0LojZbgP03o`000?nd[];o]:kB017o]:kB
2?l00003okJ_dP03o`000?o1/L_o`K7;00oo`K7;0ol00005ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:oooool002Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Hooooo`Co00002onW`>/5o`0000_oXkk/00?o0000ojZbg_nZ/]h06onZ/]h00ol0003o]:kBokB^
dP0IokB^dPCo00005?o1/L/3o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000;
ojO0j`Co00003_nS_^`3o`0000;oZ[;N7?l0000NokB^dP03o`000?no/Lco_k7<00?o00004_o1/L/3
o`0003Oooooo00?o0000ooooooooool0:_ooool002Cooooo0_l0000>ooooo`03o`000?oooooooooo
057ooooo0_l00002ojWDmP03o`000?nW`>_oYl3[00GoYl3[1?l0000=oj>nk0Go00000_nO_Nh00ol0
003oY[7PojJah00KojJah004o`000?na[]Go/JkEok6^e@Ko00005Ond[]800ol0003o_k7<oknac003
oknac0?o00004Oo1/L/4o`0003Gooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@oooo
o`03o`000?oooooooooo04kooooo0_l00005ojWDmP03o`000?nW`>_oYl3[00;oYl3[0_l0000=oj>n
k0Co00001onO_Nh00ol0003oY[7PojJah00KojJah003o`000?na[]Go/JkE00Oo/JkE1_l0000?okB^
dP03o`000?no/Lco_k7<00Ko_k7<0ol0000>ol6ab`04o`000?o1/L_o`K7;ol6ab`?o0000<oooool0
0ol0003oooooooooo`0Xooooo`009?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04_ooooo0_l00007ojWDmP?o00003?nS_^`5o`0000coWkg^00?o0000ojJah?nV/N006_nV/N000ol0
003o/JkEok6^e@0=ok6^e@Ko00002?nd[]800ol0003o_k7<oknac00:oknac0?o00002oo1/L/00ol0
003o`K7;ol6ab`02ol6ab`04o`000?o<^/Wo0000o`00033ooooo0_l0000Zooooo`008oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo0_l00006ojWDmP?o00000_nUdoP00ol0
003oXkk/oj>nk006oj>nk0Co00003_nO_Nh4o`0000?oY[7P3?l0000=ojJah003o`000?na[]Go/JkE
01?o/JkE1_l00002okB^dP03o`000?no/Lco_k7<00go_k7<0ol00008ol6ab`05o`000?o1/L_o`K7;
ol6abol000001?o<^/T2o`00033ooooo00?o0000ooooooooool09oooool002?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001_nYe?H2o`0000KoYM?h00?o0000oj>n
k?nS_^`00_nS_^`3o`0000goWkg^1Ol00003oi^kk`03o`000?nR/^?oX[;S00goX[;S3_l0000Kok6^
e@?o00004_no/L`3o`0000Co`K7;0_l00003ol6ab`03o`000?o<^/Woc;[900Coc;[900?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Vooooo`008oooool2o`0001Cooooo00?o0000oooooooo
ool0@Oooool3o`0000KoZMCf0_l00008ojGCn0?o00003OnO_Nh5o`0000WoVk__00?o0000oj:bhonR
/^<06OnR/^<01?l0003o[:oJojb_f_n/[mX5o`0001Go/JkE00?o0000okbacol000000_l0000Aokna
c0Co000000Go`K7;o`000?o1/L_o`K7;o`000008olbjb@;o0000;_ooool00ol0003oooooooooo`0V
ooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0_l00006ojWD
mP?o00001onUdoP3o`000003oio@nOl0003oWkg^00SoWkg^1Ol0000>oi^kk`03o`000?nR/^?oX[;S
01WoX[;S00?o0000ojb_f_n/[mX01_n/[mX6o`0000ko/JkE00?o0000okbaconl/Ll00onl/Ll3o`00
00co_k7<0ol00002oknac0Co000000?o`K7;o`000?o<^/T02Oo<^/T2o`0002gooooo00?o0000oooo
ooooool09Oooool002?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0kooooo`;o
00001_nYe?H2o`0000SoYM?h0_l00005oio@n@03o`000?nO_NkoWkg^00;oWkg^1?l0000@oi^kk`Go
00001?nR/^<3o`0001?oX[;S00?o0000ojb_f_n/[mX03?n/[mX6o`0000So/JkE00?o0000okbaconl
/Ll01_nl/Ll3o`0000Ko_k7<0ol00008oknac0;o00003Oo<^/T2o`0002_ooooo00?o0000oooooooo
ool09Oooool002?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`;o0000
1OnYe?H3o`0000OoYM?h0ol00007oio@n@Co00003?nK^nl9o`0000CoU[[`00?o0000oifcionM/nL0
1OnM/nL=o`0000KoX[;S00?o0000ojb_f_n/[mX04_n/[mX5o`0000?o/JkE00?o0000okbaconl/Ll0
2Onl/Ll6o`0000co_k7<0ol0000=olbjb@;o0000:Oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo000Rooooo`?o
00006?ooool00ol0003oooooooooo`0eooooo`;o00001OnYe?H2o`0000OoYM?h0ol00007oio@n@?o
00000onJboP00ol0003oVk__oi^kk`03oi^kk`Oo00003OnF^_000ol0003oWK?Woifci`0Boifci`Oo
00006On/[mX3o`0000co_;7?1_l0000;oknac003o`000?o:^L[o000000;ob[W:00?o0000olbjbOo<
^/T02oo<^/T2o`0002Wooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo000Rooooo`03o`000?oooooooooo01Wo
oooo0_l0000cooooo`;o00001OnYe?H2o`0000OoYM?h0_l00007oio@n@?o00001_nJboP2o`000003
oi^kkol0003o000001KoU[[`00?o0000oifcionM/nL05onM/nL01?l0003oY[7PojJah?nV/N05o`00
01?o[:oJ00?o0000okNbe?l000000_l00005okbac`?o00001_nl/Ll3o`0000So_k7<00Co0000olZi
b_o:^L[o00000_o:^LX2o`0000goc;[90_l0000Wooooo`03o`000?oooooooooo00Gooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Kooooo000Rooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0;_ooool4o`0000?oZMCf0_l00006ojGCn0?o00001onOd?T2
o`0000KoV/_h0ol00002oiK5m`03o`000?nF^_3oU[[`013oU[[`1ol0000Ioifci`03o`000?nV/N3o
Y[7P00KoY[7P1Ol0000=ojb_fP03o`000?ng/]Co]k;D00?o]k;D1Ol0000<okbac`?o00001?no/L`0
0ol0003ob[W:olZibP02olZibP04o`000?o:^L[ob[W:olZibP;o00003Oo<^/T00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;?ooool00ol0003o]^KfokKVmP02okKVmP?o00001_nUdoP2o`0000OoWm3i0ol00005oi[;n0?o
00001_nFaOL00ol0003oU[[`oiJjl004oiJjl0_o00001_nC^?400ol0003oUkG/oiNek004oiNek0go
00001OnM/nL00ol0003oY[7PojJah00<ojJah0Go00002?n/[mX00ol0003o]k;DokNbe002okNbe0?o
000000Co]k;Do`000?l0003o00003_nl/Ll3o`000003oknac?l0003ob[W:00Cob[W:00?o0000olZi
b_o:^LX00_o:^LX2o`0000coc;[90_l0000Vooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0:_ooool00ol0003o]^KfokKVmP02okKVmP04o`000?na
i_So/NKhok7Vn0;o00000_nUdoP2o`0000OoWm3i0_l00005oi[;n0?o00002?nFaOL3o`000003oiJj
l?l0003o000000;o00004_nC^?400ol0003oUkG/oiNek00@oiNek0Ko00004onV/N05o`0000?o[:oJ
00?o0000okNbe?l000000_l00007okNbe0?o00003_nl/Ll00ol0003ob[W:olZibP04olZibP03o`00
0?o:^L[ob[W:00Cob[W:0_l0000<olbjb@;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0:ooooo`001Ol00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0:?ooool00ol0003o]^KfokKVmP02okKVmP03o`000?nai_So/NKh00?o
/NKh0ol00006oio@n@?o00001?nJboP3o`0000SoU/Gg0ol00002oi>nm003o`000?nC^?7oTkSa013o
TkSa1_l0000GoiNek004o`000?nM]>SoWKCXoifdj0Go00004?nV/N05o`0000go]k;D0ol0000;okba
c`03o`000?o7^Lgo000000Gob[W:00?o0000olZib_o:^LX01Oo:^LX00ol0003oc;[9olbjb@0;olbj
b@03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0:ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool2o`00027ooooo00?o0000ooooooooool09_ooool00ol0003o]^KfokKVmP02
okKVmP03o`000?nai_So/NKh00?o/NKh00Co0000ojcRnOn/h_Wo[>;i0_l00003oio@n@03o`000?nJ
boSoV/_h00?oV/_h0_l00008oiK5m`?o00001_nC__@00ol0003oTkSaoi>hl@04oi>hl@_o00001OnA
^?400ol0003oTKSaoi6hl@04oi6hl@co00001OnG]N`00ol0003oWKCXoifdj006oifdj0Go00002_nV
/N04o`000004ojndg?l0003o0000o`0000ko]k;D0ol00007okbac`03o`000?o7^LgoakW=00;oakW=
0_l00003olZibP03o`000?o:^L[ob[W:00Gob[W:0_l0000;olbjb@;o00009?ooool02Ol0003ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002Oooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000okKVm_nfi_H00_nfi_H00ol0003o/NKhok7V
n003ok7Vn003o`000?n/h_Wo[>;i00?o[>;i1?l00004oi[;n003o`000?nFaOOoU/Gg00GoU/Gg1?l0
0008oi>nm0?o000000?oTkSao`000?l000000_l0000Aoi6hl@03o`000?nA^?7oTKSa00ooTKSa1_l0
000=oifdj0Go00000_nV/N03o`0000?oY[7P00?o0000ojndg?n_]=`00_n_]=`3o`0000ko]k;D0ol0
0004okbac`03o`000?o7^LgoakW=00CoakW=00Go0000olZib_o:^L[ob[W:o`000008olZibP;o0000
2?o<^/T01?l0003oelO;omO7bol0000Sooooo`03o`000?oooooooooo01oooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08_ooool00ol0003o]^KfokKVmP02okKVmP03o`000?nai_So/NKh00;o
/NKh0_l00005ojcRn@03o`000?nUfo[oYM_j00;oYM_j0ol00006oiK5m`?o00002OnC__@3o`0000?o
TKOa00?o0000oi6hlOnA^?403onA^?46o`0001GoTKSa00?o0000oi2hl_n@^?801Ol0000:oifdj0Ko
00000_nV/N000ol0003o[kCLojndg006ojndg0?o00003_ng/]@3o`000003okbacol0003oakW=00Ko
akW=0_l000000oo:^L[o0000olZibP09olZibP;o00001Oo<^/T00ol0003oelO;omO7b`02omO7b`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?nfi_Ko]^Kf00;o]^Kf00?o0000ok7Vn?nai_P00_nai_P00ol0003o
[>;iojcRn@03ojcRn@;o00001?nUfoX01Ol0003oW]7joikAn_nNdO[o000000?oU/Gg0_l00008oi>n
m0Co00001onA]o400ol0003oTKSaoi6hl@04oi6hl@[o00001OnA^?400ol0003oRkcfoh^lmP04oh^l
mP_o00001?nA^?400ol0003oT;Sboi2hlP05oi2hlPGo00000onM]>P2o`0000KoWKCX0ol0000;ojnd
g0?o00003_ng/]@00ol0003oakW=olNic@08olNic@?o00002oo:^LX00ol0003oc;[9olbjb@02olbj
b@03o`000?oGal_oelO;00?oelO;00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Moooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o00009Oooool00ol0
003oooooooooo`0Nooooo`04o`000?nfi_Ko]^KfokKVmP;o00001?nai_P00ol0003o[>;iojcRn@03
ojcRn@03o`000?nUfo[oYM_j00;oYM_j0_l00004oikAnP?o00001onC__@4o`0000[oTKOa0ol00000
1?nA^?7o0000o`000?l0000Aoi6hl@03o`000?n;_?KoRkcf00koRkcf1Ol0000<oi2hlPGo00002?nM
]>P01?l0003oXkOVo`000?l0000;ojndg0;o00003?ng/]@00ol0003o`[[Co`00000:olNic@;o0000
2oo:^LX2o`000003olbjbOl0003oelO;00KoelO;00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`008?ooool2o`0002Oooooo00?o0000ooooooooool07?ooool01Ol0003o]^KfokKV
m_nfi_Ko000000Co/NKh0_l00004ojcRn@;o00001?nUfoX00ol0003oW]7joikAnP03oikAnP04o`00
0?nGa?KoUlCfoiO4mP;o00000onC__@2o`0000_oTKOa0ol00002oi:ak003o`000?nA^?7oTKSa00ko
TKSa1_l0000:oh^lmP03o`000?n;_?KoRkcf00OoRkcf00?o0000ogjkn_mn^oX01?l00003oi2hlP?o
00001On@^?85o`0000;oWKCX00?o0000oj>gi_nS]nH00onS]nH2o`0000[o[kCL0ol00008okNbe003
o`000?o2^]?o`[[C00;o`[[C00?o0000olNicOo7^Ld01oo7^Ld3o`0000_ob[W:00?o0000omO7booG
al/01ooGal/00ol0003oooooooooo`0Oooooo`;o00007_ooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Jooooo`05o`000?nfi_Ko]^KfokKVm_l000001?nai_P00ol0003o
[>;iojcRn@03ojcRn@03o`000?nUfo[oYM_j00;oYM_j0_l00004oikAnP;o00001OnGa?H3o`0000[o
TKOa1?l00006oi:ak003o`000?nA^?7oTKSa00CoTKSa2Ol00005oiBil003o`000?n6`?[oQ/3j00Wo
Q/3j2_l00006ogjknPKo00002_n@^?82o`0000SoXkOV0ol0000:ojndg0?o00001?ng/]@00ol0003o
`[[Col:jd`04ol:jd`;o00002?o7^Ld01?l0003oakW=o`000?l00009olZibP;o00002OoGal/00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06?ooool01Ol0003o]^KfokKVm_nfi_Ko000000Co/NKh00?o0000ojcR
nOn/h_T00on/h_T00ol0003oYM_jojGKnP02ojGKnP03o`000?nNdO[oW]7j00?oW]7j00?o0000oiO4
m_nGa?H01?nGa?H01Ol0003oTKO`oi6gl?nA]o3o000000KoTKOa0ol00009oi:ak0?o000000CoTKSa
o`000?l0003o00003OnD^O04o`0000WoQ/3j00?o0000ohK0n_n6`?X01on6`?X00ol0003oIk_mofNk
o@04o`0000KoO[_j1?l00007oi2hlP03o`000?n?^?;o000000WoXkOV0ol0000:ojndg0?o000000?o
]k;Do`000?o2^]<01oo2^]<2o`0000OoakW=00Co0000olNicOo7^Lgo00001oo:^LX01?l0003oeLO<
omG7c?l00009omO7b`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool0023ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`05o`000?nfi_Ko]^KfokKVm_l0
00001?nai_P00ol0003o[>;iojcRn@02ojcRn@;o00000onUfoX2o`0000CoW]7j0_l00005oiO4mP;o
00001OnA]o001?l0003oTKOaoi6glOnA]o42o`0000WoT[7/0ol00003oiB]i`03o`000?nD^O3oU;W`
00SoU;W`1_l00003oiVkk`03o`000?n5a_goQLKm00SoQLKm3Ol00003ofNko@Go00001Omn^oX5o`00
0003oi2hl_l0003oSkSb00CoSkSb0_l00008oj>giP;o00002on_]=`00ol0003o`[[Col:jd`09ol:j
d`03o`000?o7^LgoakW=00GoakW=00?o0000olNicOo7^Ld00_l00004olZibP03o`000?oEalcoeLO<
00;oeLO<00?o0000omO7booGal/01ooGal/00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01[ooooo000Pooooo`;o0000:oooool00ol0003oooooooooo`0Dooooo`03o`000?nfi_Ko]^Kf00;o
]^Kf1?nai_P5ojcRn@03o`000?nUfo[oYM_j00;oYM_j00?o0000oikAn_nNdOX00_nNdOX2o`0000Ko
UlCf00?o0000oi6gl?nA]o001OnA]o03o`0000WoT[7/0ol00007oiB]i`03o`000?nD^O3oU;W`00?o
U;W`1?l00007oiVkk`Co00002On5a_d:o`0000?oCkOj00?o0000ofNkoOmW^od01OmW^od4o`0000Ko
O[_j0_l00007ohnhlP?o00001onS]nH3o`0000So[kCL00?o0000okRkfol000002_o2^]<2o`0000Go
akW=00?o0000olNicOo7^Ld00_o7^Ld2o`000003olZib_l0003oeLO<00GoeLO<00?o0000omO7booG
al/01ooGal/00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003o]^KfokKVmP02okKVmPCo/NKh
1On/h_T00ol0003oYM_jojGKnP02ojGKnP03o`000?nNdO[oW]7j00;oW]7j00?o0000oiO4m_nGa?H0
1?nGa?H2o`0000OoTKO`00Co0000ohfZjOn=Z^Wo00001_nB/N`3o`0000[oU:gW0_l000000onD^O3o
0000oiVkk`06oiVkk`Ko00001?nP_Nh00ol0003oR<cnohS<oP0:ohS<oPGo00001?ll]?42o`0000Go
CkOj00?o0000ofNkoOmW^od00_mW^od4o`0000;oO[_j00Co0000ofndn_m_]?[o00002?n?^?82o`00
00SoXkOV0_l00005ojndg004o`000?nh^m_o^;_KokRkf`;o00002_o2^]<2o`0000CoakW=00?o0000
olNicOo7^Ld00oo7^Ld00ol0003oeLO<omG7c006omG7c003o`000?oGal_oelO;00OoelO;00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`008?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo013ooooo00?o0000okKVm_nfi_H00_nfi_H00onai_So0000o`000003o`00
00?o[>;i1OnUfoX5oikAnP03o`000?nGa?KoUlCf00CoUlCf00?o0000oi6gl?nA]o001OnA]o02o`00
00CoSJ[Y00Co0000oi:ak?nB/NcoT[7/0_l0000:oiB]i`?o00000_nHZN<00ol0003oVK__oiVkk`03
oiVkk`?o00002OnP_Nh3o`0000?oR<cn1?l000001?n@doko0000o`000?l00002oi3CoP?o00001?lg
]N/00ol0003o?;Caocbdl@03ocbdl@Go00000_m?]oX2o`000003ofNkoOl0003o000000KoKkCj0_l0
0006ohnhlP;o00002?nS]nH3o`000003ojndg?l0003o^;_K00Go^;_K0_l0000:ol:jd`03o`000?o7
^LgoakW=00;oakW=00?o0000olNicOo7^Ld00_o7^Ld2o`0000SoeLO<00?o0000omO7booGal/01ooG
al/00ol0003oooooooooo`0Mooooo`;o00006_ooool0023ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`Oo00000_o6k^l00ol0003o`N_bol7[lP09o`0000?oW]7j1onGa?H0
0ol0003oTKO`oi6gl004oi6gl0;o00001_n=Z^T3o`0000[oU:gW0ol00005oiRYh`;o000000?oVK__
o`000?nP_Nh02OnP_Nh4o`0000;oZ<3[00?o0000oi3Co_n@doh00on@doh6o`0000;oW]_l00?o[^3h
o`000?l000001_mOdO83ohKSn@Co=kG[00?o0000ocbdlOll]?400ol00002o`j?hP03o`000?m1YoOo
000000KoKkCj0ol00005ohnhlP?o00002?nS]nH00ol0003o^;_KokRkf`07okRkf`03o`000?o2^]?o
`[[C00So`[[C0_l00003olNic@04o`000?o7^LgoakW=o`0000;od/K?00?o0000omG7c?oEal`01_oE
al`00ol0003oelO;omO7b`07omO7b`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?oo
ool001oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`05o`000?o:k^go
b^k]ol[^kOl000000oo6k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o^>Ce00?o
0000ojcImon/fOL00ol00006oiO4mP03o`000?nA]o3oTKO`00CoTKO`00?o0000ohfZjOn=Z^T01?n=
Z^T2o`0000?oRj3R00?o0000oiB]ionD[NL01?nD[NL3o`0000GoV:WS0ol00002oifXgP03o`000?nP
_NkoX;g^00GoX;g^1?l00006ojS0j`;o000000CoT=?no`000?l0003o00001OnNfo`2ojkPn0;o0000
00?o_N;ao`000?n6hoT01?n6hoT01?n[kOSo0000olG]kol00003oj3Xn`Co00000omld?l2o`1gaP?o
3XoR00Co0000od6Wmol0003o00001Om_]?X2o`0000KoSkSb0_l00005oj>giP03o`000?nY^nKoZK_V
00Wo^;_K0_l0000:ol:jd`;o000000CoakW=o`000?o7^Lgo00001?oBa/l00ol0003oeLO<omG7c006
omG7c003o`000?oGal_oelO;00OoelO;00?o0000ooooooooool07Oooool00ol0003oooooooooo`0G
ooooo`007oooool2o`00037ooooo00?o0000ooooooooool02oooool01Ol0003ob^k]ol[^kOo:k^go
000000?oa^k_00?o0000ol7[l_o1jo800_o1jo800ol0003o^>CeokSTm@02okSTm@03o`000?n/fOOo
[=Wg00;o[=Wg00?o0000oik9m_l000000_l00002oiO4mPKoTKO`0_l00006ohfZj@03o`000?n;X>;o
Rj3R00CoRj3R00?o0000oiB]ionD[NL00ol00006oiRYh`;o00001_nMZ=h01?l0003oX;g^oj2mk_nP
_Nh3o`0000OoZ<3[1_l00004oikKo0Co[^3h00Co0000okgRlOnmh_7o_N;a0_l000001?n6hoWoZngh
oj_]n?l00002olG]k`;o000000?oX>Sko`000?l000000oo4j>l00ol0003o/=cgok3Lm`03ok3Lm`;o
00000_l0MlH2o`j?hP;o000000?o@JOgo`000?l000001?m_]?X3o`0000GoSkSb0ol000000onS]nKo
0000ojVkiP04ojVkiP03o`000?nh^m_o^;_K00Ko^;_K00?o0000ol:jdoo2^]<02Oo2^]<00ol0003o
akW=o`000006om;6c`03o`000?oEalcoeLO<00KoeLO<00?o0000omO7booGal/01ooGal/00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool01?l0003ob^k]ol[^kOl00004olK^k`05o`000?o1jo;o`N_bol7[
l_l000001?nhi?D00ol0003o[=WgojcIm`02ojcIm`03o`000?nNbOKoW/Wf00?oW/Wf0_l00005oi6g
l003o`000?n=Z^WoSJ[Y00CoSJ[Y0_l00007oh^PhP?o00001onHZN<2o`0000SoWJSN0ol00008ojS0
j`Ko000000Co//?Wo`000?l0003oW]_l1?n^h?P01?l0003o_N;aokgRlOnmh_46o`0000?oaNg_0_l0
00000ooDi^?o0000olCXk`02olCXk`?o00001On`g?L2o`0000?oY<Ob0_mc]?T00ol0MlKo3XoRo`j?
hP02o`000003od6Wmol0003o000000CoKkCj0_l00006ohnhlP03o`000?nY^nKoZK_V00GoZK_V0_l0
0007okRkf`;o00002_o2^]<3o`0000Kod/K?00?o0000omG7c?oEal`01_oEal`00ol0003oelO;omO7
b`07omO7b`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`05o`000?o:k^gob^k]ol[^kOl000000oo6
k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o^>Ce00Go0000ojcImon/fOOo[=Wg
o`000006oik9mP04o`000?n@]_3o0000o`0000;oTKO`1_n=Z^T2o`0000SoRj3R00Co0000oh^Ifon;
VM_o00001OnHZN<2o`0000SoWJSN0_l000000onSZ=[o0000ojS0j`05ojS0j`?o000000?o//?Wo`00
0?l000000_nb`nL2o`000003ok_5h_l0003o[^3h00;o[^3h00Co0000okgRlOnmh_7o_N;a0_l00002
ol[Qj@03o`000?oCgMoo000000;oaNg_00?o0000omCVhooDi^<00_l000000oo4j>oo0000o`000002
omGPg`03o`000?o;f^Gobm[U00;obm[U0_l00006ojC7lP05o`000?mc]?WoLkCiog>dnOl0MlH00_l>
Sn85o`0000?oKkCj0ol000000on?^?;o0000ohnglP02ohnglPSoZK_V0_l00007okRkf`03o`000?o2
^]?o`[[C00Oo`[[C00Co0000ol_6eOl0003o00001_oBa/l00ol0003oeLO<omG7c006omG7c003o`00
0?oGal_oelO;00GoelO;0_l0000Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01_ooool01Ol0003ob^k]ol[^kOo:k^go000000Coa^k_
00Go0000ol7[l_o1jo;o`N_bo`000004okSTm@03o`000?n/fOOo[=Wg00;o[=Wg00?o0000oik9m_nN
bOH00onNbOH00ol0003oT;K`oi2fl002oi2fl0;o00001On=Z^T00ol0003oRj3Roh^PhP06oh^PhP;o
00001?n;VM/01?l0003oV:WSoiRYhol00009oifXgP;o00001?nSZ=X01?l0003oZ<3[ojS0jonX`>/2
o`000004ok;3iol0003o0000o`0000;o//?W0_l00003ok_5hP;o00001?nmh_42o`0000;ob^7Y00?o
0000om?MgooCgMl00_l00003omCVh`;o000000?og=gGo`000?oEh=l00ooEh=l00ol0003obm[Uol_J
i@03ol_Ji@04o`000?o1cN?o`LgSo`0000GoY<Ob0ol000001Omc]?Wo0000oc>Al?l0MlKo3XoR00Ko
00000om_]?X00ol0003oSkObohnglP03ohnglP;o00001onY^nH2o`0000Ko^;_K0_l00006ol:jd`05
o`000?o;a]GoblKEol_6eOl000001ooBa/l00ol0003oeLO<omG7c006omG7c003o`000?oGal_oelO;
00?oelO;00Co0000omoHd?oOf=3o00007Oooool3o`0001Kooooo000Oooooo`;o0000=Oooool2o`00
00Kooooo00Go0000ol[^kOo:k^gob^k]o`000003olK^k`03o`000?o1jo;o`N_b00;o`N_b00Go0000
okSTmOnhi?Go^>Ceo`000004ojcIm`03o`000?nNbOKoW/Wf00?oW/Wf00?o0000oi2fl?n@]_000on@
]_001?l0003oQ:CYo`000?l00002ohfZj@03o`000?n;X>;oRj3R00GoRj3R0_l00006oh^If`?o0000
1onMZ=h3o`0000KoXjSJ0ol000001?nb`nOo0000o`000?l00002ok;3i`?o00000onkaN82o`000003
ol?7gOl0003o_N;a00;o_N;a00Go0000ol[QjOo:hNWob^7Yo`000002om?Mg`03o`000?oJfMKo0000
00;oe>KS00Co0000omcMeooLgMOo00000ooEh=l2o`000003ol_JiOl0003o000000;obm[U00?o0000
ol7=hoo1cN<00_o1cN<01_l0003oY<Obo`000?l0003oX[?To`0000?oOj7X1_l000000ol>Sn;o0000
o`000003o`0000?oIJ_h1_n?]o82o`0000OoZK_V00?o0000okRkfonh^m/01Onh^m/2o`0000?o`[[C
00?o0000ol_6eOo;a]D00oo;a]D00ol0003od/K?om;6c`05om;6c`03o`000?oEalcoeLO<00KoeLO<
00Go0000omO7booGal_oelO;o`000003omoHd003o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`05o`00
0?o:k^gob^k]ol[^kOl000000oo6k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o
^>Ce00Go0000ojcImon/fOOo[=Wgo`000005oik9mP03o`000?n@]_3oT;K`00?oT;K`00?o0000ohBT
jOn4Y>T00_n4Y>T2o`0000OoRj3R00?o0000oh^Ifon;VM/01On;VM/01Ol0003oSYCFohjDe_n>U=Ko
000000CoWJSN0_l00007oj>XfP;o000000CoZZWFo`000?l0003o00001?nb`nL00ol0003o^lGRok_5
hP02ok_5hP;o00000oo3amd2o`0000Gob^7Y0_oCgMl2o`0000;of]WF00?oe>KSo`000?oLgML00ooL
gML01_l0003oeN3Oo`000?l0003ogMSBo`0000?oemCE0_l00006ol7=h`03o`000?nR/nCoX[?T00;o
X[?T00Go0000ognQj?moXNSoOj7Xo`000002oeF8iP;o000000?o06SGo`000?l0K]<00olZT^l5ofF[
n003o`000?n?]o;oSkOb00?oSkOb00?o0000ojVki_nY^nH01OnY^nH2o`0000Oo^;_K00?o0000ol:j
dol000001oo;a]D00ol0003od/K?om;6c`05om;6c`03o`000?oEalcoeLO<00KoeLO<00?o0000omO7
bol000001?oOf=000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo000Nooooo`03
o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`000002ol[^k@03o`000?o6k^ooa^k_
00;oa^k_00Go0000ol7[l_o1jo;o`N_bo`000004okSTm@03o`000?n/fOOo[=Wg00;o[=Wg00?o0000
oik9m_nNbOH00_nNbOH00ol0003oT;K`oi2fl003oi2fl003o`000?n4Y>WoQ:CY00?oQ:CY0_mkU>02
o`0000?oRj3R0_l00007oh^If`03o`000?n>U=KoSYCF00?oSYCF00Co0000oifXg_nMZ=ko00002?nS
Z=X4o`0000;oZZWF00Co0000ok;3ionb`nOo00001?nkaN82o`0000Co`lOM00Co0000ol_8f?o;b=So
00000_o:hNT3om?Mg`05o`000?oJfMKof]WFom[Ie_l000001?oLgML3o`0000?ogMSB00?o0000omOD
eOoGe=D00_oGe=D01Ol0003odLgEom7=eOl0003o`LgS00;o000000?o_;kKo`000?nR/n@00onR/n@0
0ol0003oOj7XognQj002ognQj003o`000?mER>KoEHSV00;o;FoM0ol000001?l0K]?o:Y;_obZBkolZ
T^l4ofF[n0;o00001?n?]o82o`0000OoZK_V0_l00006okRkf`03o`000?o;a]GoblKE00OoblKE00?o
0000om;6cooBa/l01OoBa/l00ol0003oeLO<omG7c006omG7c003o`000?oOf=3ogmS@00CogmS@00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000003ol[^k@05o`000?o6
k^ooa^k_olK^kol000001?o1jo801Ol0003o^>CeokSTmOnhi?Go000000Co[=Wg00?o0000oik9m_nN
bOH00onNbOH00ol0003oT;K`oi2fl002oi2fl003o`000?n4Y>WoQ:CY00?oQ:CY00?o0000og^Dh?mk
U>000_mkU>000ol0003oRj3Roh^PhP08oh^If`03o`000?n>U=KoSYCF00CoSYCF0_l00008oj>XfP?o
00001OnZZMH2o`0000Co^lGR0_l00004ol?7g@;o00000oo;b=P2o`0000?odmgO00Ko0000om[Ie_oJ
fMKof]WFomgDcol00003omcMe`03o`000?oPe/go000000CogMSB00Go0000omODeOoGe=GoemCEo`00
0004om7=e@03o`000?nl_]_o_;kK00;o_;kK00?o0000oj:ci?nR/n@00_nR/n@01Ol0003oOj7XognQ
j?moXNSo000000?oEHSV0ol]Kmd3o`000003o`1^dolZT^oo:Y;_00;o00000omUZoP2o`0000CoSkOb
0_l00007ojVkiP03o`000?nh^m_o^;_K00;o^;_K00?o0000oko5g_noaMh02?o;a]D2o`0000Ood/K?
00?o0000omG7c?oEal`01OoEal`00ol0003ogmS@omoHd004omoHd003o`000?oooooooooo01kooooo
00?o0000ooooooooool04_ooool001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo03[ooooo00Go0000ol[^kOo:k^gob^k]o`000004olK^k`05o`000?o1jo;o`N_bol7[
l_l000001?nhi?D00ol0003o[=WgojcIm`02ojcIm`03o`000?nNbOKoW/Wf00;oW/Wf00?o0000oi2f
l?n@]_000_n@]_000ol0003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP00?o0000oh^I
fon;VM/01On;VM/2o`0000KoSYCF00?o0000oi:CdOl000001OnSZ=X3o`0000OoZZWF00Co0000ok6/
dona[=?o00000_nkaN800ol0003o`lOMol?7g@03ol?7g@03o`000?o;b=SoblSH00;oblSH00?o0000
om79d_l000000_oCgMl4om[IeP;ogMC?00Co0000omcMeooLgMOo00000_oPe/d00ol0003ogMSBomgH
dP02omgHdP04o`000?oGe=GoemCEo`0000CodLgE0_l00005okbnf`05o`000?nR/nCoX[?Toj:ci?l0
00001?moXNP01?l0003oEHSVoeF8i_l00002obe_g@;o3U[C00Co0000o`0i/ol0003o06kC0_lZT^l2
o`0000?oIJ_h00?o0000ohngl_n?]o800on?]o800ol0003oZK_VojVkiP05ojVkiP;o000000?o^;_K
o`000?noaMh00onoaMh00ol0003oblKEol_6e@05ol_6e@;o00001ooBa/l00ol0003oeLO<omG7c003
omG7c003o`000?oNf=7o000000KogmS@00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`Co000000?o410@ooooooooool00oooool001?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo03[ooooo00Go0000ol[^kOo:k^gob^k]o`000003olK^k`03o`000?o1
jo;o`N_b00;o`N_b00Go0000okSTmOnhi?Go^>Ceo`000004ojcIm`03o`000?nNbOKoW/Wf00;oW/Wf
00?o0000oi2fl?n@]_000on@]_000ol0003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP
00?oMXWIo`000?n;VM/01?n;VM/00ol0003oSYCFohjDeP05ohjDeP06o`000?nBTm7oTY?Aoi:CdOl0
003oXjSJ1?l00007ojZYeP;o00000ona[=<2o`0000Ko`lOM00Co0000ol_8f?o;b=SoblSH0_l00003
om79dP03o`000?oJfMKof]WF00;of]WF0ooMe<l00ol0003og=gGon3Fc@02on3Fc@04o`000?oMf=;o
gMSBomgHdPGo00001?oAcMD01?l0003ocL?Aolg3dOl00005okbnf`Wo00000omER>H00ol0003o;FoM
obe_g@03o`iJd`03o`000?l0>KCo000000;o000000?o:Y;_o`000?l000000_mUZoP2o`0000CoSkOb
0_l00006ojVkiP;o00001_noaMh00ol0003oblKEol_6e@05ol_6e@;o00001ooBa/l01Ol0003oeLO<
omG7c?oEalco000000;og]SA00?o0000omoHd?oOf=001?oOf=000ol0003oooooooooo`0Mooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000>_ooool01Ol0003ob^k]ol[^kOo:k^go000000?oa^k_00?o0000ol7[
l_o1jo800_o1jo800ol0003o^>Ceo`000009o`0000;oW/Wf00?o0000oi2fl?n@]_000on@]_000ol0
003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP00Co0000ogJ9fOmfRMWo00000on;VM/0
0ol0003oSYCFohjDeP05ohjDeP04o`000?nBTm7oTY?Aoi:Cd@?o00000_nSZ=X00ol0003oZZWFojZY
eP04ojZYeP;o00001?na[=<01?l0003o^Jo@okV_d?l00004ol?7g@05o`000?o;b=SoblSHol_8f?l0
00001?oAbM82o`0000?of]WF0ooMe<l2o`0000Coh=K=00Ko0000omgHd_l0003o0000on3Ab?l00002
omk?bP05o`000?oJbl[o0000om7=eOl000000oo=`m400ol0003o_;kKo`000002o`000003okbcdOnX
YmKoZ:OF00;oZ:OF1?n@V=P3o`0000;oEHSV00?o0000obe_gOl000000ol>F]<00ol0003o03Vdo`00
0003o`000003obZBkol0003o000000;oIJ_h0_l00004ohnglP;o00000onY^nH01?l0003o[L7Xojg1
j?l00006oko5gP03o`000?o;a]GoblKE00GoblKE0_l00007om;6c`03o`000?oEalco000000Cog]SA
00?o0000omoHd?oOf=000ooOf=000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool001?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo03[ooooo00Co0000ol[^kOo:k^go00001?o6k^l00ol0003o`N_bo`000004o`0000;o
b>?[00?o0000ok[Il?njfO000_njfO000ol0003oYl_bojO;lP05o`0000;oT;K`00?o0000ohBTjOn4
Y>T00on4Y>T00ol0003oNiCPog^Dh004og^Dh003o`000?mfRMWoMXWI00;oMXWI00?o0000oh^Ifon;
VM/01_n>U=H2o`000004oi:CdOl0003o0000o`0000;oTY?A0ol00006ojZYeP03o`000?na[=?o/JcC
00?o/JcC00?o0000okV_d?ni[m000_ni[m000ol0003o`lOMol?7g@04ol_8f003o`000?oAbM;odLWB
00;odLWB00Go0000omK9cOoFbLgo0000om[IeP03omgDc`03o`000?oPd<So000000?oh=K=0_l00004
on3Ab0;og/o:00Go0000om[;b_oJbl[of/_:o`000005olg3d@03o`000?nl/m7o_;?A00;o_;?A00Go
0000ojRWe_nXYmKoZ:OFo`000004oi2Hf0;oMXSG0ol00002obe_g@03o`000?l>F]?o3U[C00;o04k<
00?o0000o`0i]?l000000ol000000olZT^oo0000ofF[n002ofF[n003o`000?n?]o;oSkOb00?oSkOb
00?o0000ojVki_l000001?n]`NP00ol0003o_lGNoko5gP04oko5gP03o`000?o;a]GoblKE00CoblKE
00?o0000ol_6eOl000001ooBa/l00ol0003og]SAomkHd@03omkHd@03o`000?oOf=3ogmS@00CogmS@
00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
000Cooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0iooooo`06o`00
0?o:k^gob^k]ol[^kOl0003oa^k_1Ol00002om7WiP03o`000?o8hn_ob>?[00;ob>?[00?o0000ok[I
l?njfO000_njfO001?l0003oYl_bojO;l_nWbo84ohnfl@?o00001On4Y>T00ol0003oNiCPog^Dh003
og^Dh003o`000?mfRMWoMXWI00CoMXWI0_l00005ohjDePCo00001?nBTm401Ol0003oVIC>oiVDc_nI
U<ko000000CoZZWF00?o0000ok6/dona[=<00ona[=<00ol0003o^Jo@okV_d004okV_d003o`000?o;
b=SoblSH00;oblSH00?o0000om79d_oAbM800_oAbM801Ol0003oe/W=omK9cOoFbLgo000000?ogMC?
00Co0000on3@b?oPd<So00000_oPe/d00ol0003oh]36o`000003on3Ab0;og/o:00?o0000om[;b_oJ
blX00_oJblX01ol0003ocL?Aolg3dOo=`m7o0000ol^lc?l000001?nl/m401Ol0003oZ:OFojRWe_nX
YmKo000000CoT9SH00?o0000ogJ8eomfR=L00_mfR=L00ol0003o;FoMo`000003o`iJd`;o04k<00Co
0000o`0i]?l0B<7o06CG1Ol00002ofF[n0;o00000_n?]o83o`0000Ko[L7X00?o0000oko5g_noaMh0
1?noaMh00ol0003oblKEol_6e@04ol_6e@03o`000?o;a]Go000000God/K?0_l00006omkHd@03o`00
0?oOf=3ogmS@00?ogmS@00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?o:k^gob^k]00Co00000_oFjN800ol0003odNOVom7WiP02om7WiP03o`00
0?o8hn_ob>?[00;ob>?[00?o0000ok[Il?njfO000_njfO001?l0003oYl_bojO;l_nWbo85ohnfl@;o
N9o[0ol000000on4Y>Wo0000og^Dh004og^Dh003o`000?mfRMWoMXWI00GoMXWI0_meP]800ol0003o
SYCFohjDeP03o`0000KoTY?A00?o0000oiVDc_nIU<h00onIU<h00ol0003oZZWFojZYeP06ok6/d`03
o`000?ni[m3o^Jo@00Co^Jo@00?o0000ol2ccOl000000_o;b=P5om79dP03o`000?oFbLgoe/W=00;o
e/W=00Co0000omgDcooMe<oo00000ooPd<P00ol0003oh=K=on;@aP02on;@aP04o`000?oPdLSoh=78
o`0000;og/o:00Wo0000om[;b_oJbl[of/_:o`000?oHa/So0000olg3dOl000000_o;_<`00ol0003o
_;?Aokbcd@02okbcd@03o`000?nXYmKoZ:OF00;oZ:OF00Go0000oi2Hf?n@V=SoT9SHo`000004ogJ8
e`;oGWSD00Go;FoMo`000?l>F]?o3U[Co`000002o`1>c003o`000?l0>KCo04S100;o06CG00?o0000
obb6jol000001_l00003ohnglP03o`000?n]`NSo[L7X00Co[L7X00?o0000oko5g_noaMh01?noaMh0
0ol0003oblKEol_6e@04ol_6e@03o`000?o;a]Go000000?od/K?00Co0000om[HeOoJf=Go00001OoN
f=400ol0003ogmS@omoHd003omoHd003o`000?oooooooooo023ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
000iooooo`?o000000?of>SPo`000?oFjN800ooFjN800ol0003odNOVom7WiP02om7WiP05o`000?o8
hn_ob>?[olSSjol000001?njfO000ol0003oYl_bojO;lP02ojO;lP03o`000?n?]_7oSkKa00;oSkKa
1OmhWn/2o`0000GoNiCP00?o0000ogJ9fOmfRMT01?mfRMT00ol0003oMH;BogF2dP04o`0000OoTY?A
00?o0000oiVDc_nIU<h01OnIU<h00ol0003o/JcCok6/d`04ok6/d`03o`000?ni[m3o^Jo@00Co^Jo@
00Go0000ol2ccOo0/lgo`;?=o`000005om79dP03o`000?oFbLgoe/W=00;oe/W=00Co0000om[9b?l0
003ogMC?1?oPd<P01Ol0003oh]36on;@a_oRd<Ko000000;oh=781?l00003om[;bP05o`000?oHa/So
f<K8omS6b?l000000oo;_<`00ol0003o_;?Aokbcd@02okbcd@03o`000?nXYmKoZ:OF00;oZ:OF00Go
0000oi2Hf?n@V=SoT9SHo`000004ogJ8e`04o`000?mNN=CoGWSDo`0000?o3U[C00Ko0000o`1>c?l0
CLco04g<o`000?l0B<42o`1Te`04o`000?l/Q^_o;8K[o`0000CoHjCd1?n?]o800ol0003o[L7Xojg1
j004ojg1j003o`000?noaMko_lGN00Co_lGN00?o0000ol_6eOo;a]D01?o;a]D01Ol0003oblKEo`00
0?oBa/oo000000?of]SE00?o0000omkHdOoNf=401?oNf=400ol0003ogmS@omoHd003omoHd003o`00
0?oooooooooo01oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Mooooo`03o`000?oo
oooooooo03Oooooo00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhP03o`000?oA
inKodNOV00;odNOV00Go0000olSSjoo8hn_ob>?[o`000004ok[Il003o`000?nWbo;oYl_b00;oYl_b
00?o0000ohnflOn?]_400_n?]_400ol0003oN9o[ogROj`02ogROj`;oHhWR00Go0000og^Dh?mkU>3o
NiCPo`000006ogJ9f@Co00000_meP]800ol0003oTY?Aoi:Cd@05oi:Cd@03o`000?nIU<koVIC>00Go
VIC>0_l00005ok6/d`03o`000?ni[m3o^Jo@00Co^Jo@00?o0000ol2ccOo0/ld00_o0/ld2o`0000?o
dLWB00?o0000omK9cOoFbLd00_oFbLd01?l0003of/W8om[9b?l00004on3@b0;o00000ooRd<H01?l0
003oh=78on;<`_l00002on7;``;o000000?of/_:o`000?oHa/P00_oHa/P00ooF`/Ko0000ol^lc003
ol^lc005o`000?nl/m7o_;?AokbcdOl000001?nXYmH00ol0003oT9SHoi2Hf002oi2Hf005o`000?mf
R=OoMXSGogJ8eol000000omNN=@2o`000004o`iJdol0003o04k<o`1>c0?o04g<00Co04S1o`1Teol0
I=Oo00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm0CoSkOb00?o0000ojg1j?n]`NP01?n]`NP00ol0
003o_lGNoko5gP04oko5gP03o`000?o;a]GoblKE00?oblKE00Co0000ol_6eOl0003o00001OoJf=D0
0ol0003og]SAomkHd@03omkHd@03o`000?oOf=3ogmS@00?ogmS@00?o0000ooooooooool07_ooool0
0ol0003oooooo`000005ooooo`03oeEEEOmVIVKo000000Oooooo000Mooooo`03o`000?oooooooooo
03Oooooo00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhP03o`000?oAinKodNOV
00;odNOV00Go0000olSSjoo8hn_ob>?[o`000004ok[Il003o`000?nWbo;oYl_b00;oYl_b00Go0000
ohnflOn?]_7oSkKao`000005ogROj`?oHhWR00?o0000og^Dh?l000001_mfRMT2o`0000GoMH;B00?o
NH3>o`000?nBTm401?nBTm400ol0003oVIC>oiVDcP05oiVDcP04o`000?nPV<coX9S<o`0000Co/JcC
1_ni[m000ol0003o`;?=ol2cc@02ol2cc@04o`000?o7]l[oakO:o`0000;odLWB1?oFbLd01Ol0003o
f/W8om[9b?oJbLSo000000?oh=3800?o0000on7<`ol000000_oRd<H2o`0000;oh/c200?o0000on7;
`ooQbl<00_oObL<01?l0003of<K8omS6b?l00002omK2aP03o`000?o;_<cobkc<00;obkc<00?o0000
okbcdOl000002?l00003oi2Hf005o`000?mfR=OoMXSGogJ8eol000000omNN=@2od][d@05o`000?l>
F]?o0000o`1>c?l000000ol0CL`2o`000005o`1Teol0003o;8K[obb6jol000001?mSY?@01Ol0003o
SkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh00ol0003oblKEol_6e@03ol_6
e@03o`000?oAeMco000000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003ogmS@omoHd004omoH
d003o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool001cooooo00?o0000oooooooo
ool0>?ooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR00?o0000om7Wi_oA
inH00_oAinH01Ol0003ob>?[olSSjoo8hn_o000000Co^]W`00Go0000ojO;l_nWbo;oYl_bo`000004
ohnfl@03o`000?mhWn_oN9o[00;oN9o[00?o0000of>9h_mSRN800_mSRN82o`0000?oMXWI1?l00005
ogF2dP04o`000?miP<koNH3>o`0000?oTY?A00?o0000oiVDc_nIU<h01OnIU<h00ol0003oX9S<oj2H
c002oj2Hc003o`000?na[=?o/JcC00Ko^Jo@00?o0000ol2ccOo0/ld00_o0/ld00ol0003oakO:olNg
bP02olNgbP03o`000?oFbLgoe/W=00;oe/W=00Co0000om[9b?oJbLSof/W80_l00002on3@b00:o`00
0?oQc<?ohLc3o`000?oRd<Ko0000on;;`Ol0003oh/c2o`0000;ohL_300Ko0000omo9`ooObL?o0000
omS6b?l00003omK2aP04o`000?o;_<cobkc<ol^lc0?o00000_no[lX00ol0003o/:G<ok2Uc002ok2U
c006o`000?nPVLgo0000o`000?n@V=So00000omfR=L01Ol0003oGWSDoeihe?mNN=Co000000?oBf_A
00Co0000o`1>c?l0C/co00000_l0CL`2o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mS
Y?@00_mSY?@01Ol0003oSkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh02Ol0
003oblKEol_6eOo;a]Go0000om7Eg?l0003odMGLo`000004om[He@03o`000?oNf=7og]SA00Cog]SA
00?o0000omoHd?oOf=000ooOf=000ol0003oooooooooo`0Oooooo`?o00003Oooool001cooooo00?o
0000ooooooooool0>?ooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR00?o
0000om7Wi_oAinH00_oAinH01Ol0003ob>?[olSSjoo8hn_o000000Co^]W`00Go0000ojO;l_nWbo;o
Yl_bo`000004ohnfl@03o`000?mhWn_oN9o[00;oN9o[00?o0000of>9h_mSRN800_mSRN82oeEhf@?o
00000_mfRMT00ol0003oMH;BogF2dP03ogF2dP03o`000?miP<koNH3>00;oNH3>00?o0000oi:CdOl0
00001onIU<h00ol0003oX9S<oj2Hc004oj2Hc0;o00001Oni[m000ol0003o`;?=ol2cc@02ol2cc@03
o`000?o7]l[oakO:00?oakO:00Go0000omK9cOoFbLgoe/W=o`000003om[9b003o`000?oMb<CogLS4
00;o00000ooQc<<01?l0003oh]36on;;`OoRbl42on;<`P03o`000?oQbl?o000000;oglW300?o0000
omk7`_l000001?oF`/H4o`000003olbhaol0003o_jo:00;o_jo:00?o0000ok2Uc?n`YL`00_n`YL`0
0ol0003oX9W=oj2Ic@02oj2Ic@;o00000_mfR=L01Ol0003oGWSDoeihe?mNN=Co000000CoBf_A0_l0
00001?l0C/co04g<o`1=c?l0CL`2o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mSY?@0
0_mSY?@01Ol0003oSkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh00ol0003o
blKEo`000002om7Eg003o`000?oAeMco000000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003o
gmS@omoHd003omoHd003o`000?oooooooooo01cooooo0ol00002ooooo`03o`000?oooooooooo00_o
oooo000Looooo`;o0000>Oooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR
00Go0000om7Wi_oAinKodNOVo`000004olSSj`03o`000?njfO3o^]W`00;o^]W`00Go0000ojO;l_nW
bo;oYl_bo`000004ohnfl@03o`000?mhWn_oN9o[00;oN9o[00Co0000of>9h_mSRN;oHhWR0ol00000
0omEN=Wo0000ogJ9f@02ogJ9f@03o`000?meP];oMH;B00?oMH;B00?o0000ogV0c_miP<h00omiP<h0
0ol0003oVIC>oiVDcP05oiVDcP03o`000?nPV<coX9S<00GoX9S<00?o0000ojVLb_l000000oni[m00
0ol0003o`;?=ol2cc@02ol2cc@03o`000?o7]l[oakO:00?oakO:00Go0000oljkaol0003oe/W=o`00
0003om[9b005o`000?oMb<CogLS4omg8a?l000000ooQc<<2o`0000;oh/_100So0000on;<`_oRc<;o
0000on7;`ol0003oglW3o`0000;og/O200?o0000omK2a_oF`/H00_oF`/H00ol0003oc;S7olbha`02
olbha`05o`000?no[l[o_jo:okn_b_l000000on`YL`00ol0003oX9W=oj2Ic@03oj2Ic@;oShg=00?o
0000ogJ8eol000000omNN=@00ol0003oBf_Aod][d@02od][d@;o?VC@00Go04k<o`000?l0CLco04g<
o`000002o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mSY?@00_mSY?@01Ol0003oSkOb
ohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh00onoaMh2o`0000CodMGL00?o0000om7Eg?l0
00001?oJf=D00ol0003og]SAomkHd@04omkHd@03o`000?oOf=3ogmS@00?ogmS@00?o0000oooooooo
ool06?ooool3o`0000Gooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0
>?ooool00ol0003of>SPomSXh002omSXh005o`000?oFjN;oe^WRomKYh_l000001?oAinH00ol0003o
b>?[olSSj`02olSSj`05o`000?njfO3o^]W`ok[Il?l000001?nWbo800ol0003oSkKaohnfl@02ohnf
l@03o`000?mhWn_oN9o[00;oN9o[1?l000000omSRN;o0000oeEhf@02oeEhf@03o`000?mfRMWo0000
00GoMH;B00?o0000ogV0c_miP<h01?miP<h00omoPL_o0000oiVDcP04oiVDcP03o`000?nPV<coX9S<
00GoX9S<00Oo0000ojVLb_nYW<[oZIc:o`000?ni[m3o000000Go`;?=00?o0000olNgb_o7]lX00_o7
]lX01Ol0003oc[_7oljkaoo>^lOo000000?of/W800?o0000omg8a?oMb<@00_oMb<@01_l0003ohLc3
on7<`ol0003oh/Zoo`0000;oh/_100?o0000on;<`_l000000_l000001?oObL?o0000omk7`_oNal82
o`0000;oe/;600?o0000omJo`ol000001?o<^<L01Ol0003o_jo:okn_b_no[l[o000000?o/:G<00?o
0000oj2IcOnPVLd00onPVLd4ohn=c@;o00000omNN=@01Ol0003oBf_Aod][dOm;Jm7o000000;o?VC@
00Go04k<o`000?l0CLco04g<o`000002o`EGd@?o00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm005
o`000?n?]o;oSkObohngl_l000001_n]`NP01ol0003o_lGNoko5g_noaMko0000ol?@i?l000001OoA
eM`2o`0000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003ogmS@omoHd002omoHd0;o00005ooo
ool3o`0000Sooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?ooool0
0ol0003of>SPomSXh002omSXh005o`000?oFjN;oe^WRomKYh_l000001?oAinH01Ol0003ob>?[olSS
joo8hn_o000000Co^]W`00?o0000ojO;l_nWbo800_nWbo801Ol0003oSkKaohnflOn?]_7o000000?o
N9o[0ol00004of>9hP03o`000?mEN=WoEGSI00;oEGSI00?o0000ogF2d_meP]801?meP]800ol0003o
NH3>ogV0cP03ogV0cP04o`000?moPL_oOh7;o`0000?oVIC>00?o0000oj2Hc?nPV<`01OnPV<`00ol0
003oZIc:ojVLbP03ojVLbP03o`000?o0/lgo`;?=00?o`;?=00?o0000olNgb_o7]lX00_o7]lX00ol0
003oc[_7oljka`02oljka`;o000000?of/W8o`000?oMb<@00ooMb<@01?l0003oh<S1o`000?l00002
on;:_`04o`000?oRbl7o0000on;<`P;o000000?oh/Rno`000?l000000_oNal800ol0003ogLG1omg5
`@02o`0000;oe[o300Go0000olbhaoo<^<Ooc;S7o`000003okn_bP03o`000?n`YLco/:G<00;o/:G<
00?o0000oj2IcOnPVLd00_nPVLd00ol0003oShg=ohn=c@02ohn=c@;oP8;<0_l000000omNN=Co0000
od][d@02od][d@05o`000?lnI=3o?VC@ociTd?l000000_l0CL`00ol0003o1EOAo`EGd@02oaeYg0;o
00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm005o`000?n?]o;oSkObohngl_l000001_n]`NP00ol0
003o_lGNo`000003ol?@i003o`000?oAeMcodMGL00?odMGL0_l00004om[He@03o`000?oNf=7og]SA
00Cog]SA00Ko0000omoHd?oOf=3o0000on;/f?l0000Cooooo`Co00002oooool00ol0003ooooooooo
o`0;ooooo`007?ooool00ol0003oooooooooo`0hooooo`05o`000?oHj>3of>SPomSXh?l000001?oF
jN800ol0003odNOVom7WiP02om7WiP05o`000?o8hn_ob>?[olSSjol000000_njfO0:o`000003ohnf
lOl0003o000000;o000000?oN9o[o`000?mSRN801?mSRN800ol0003oEGSIoeEhf@02oeEhf@03odm^
d_l0003oMH;B00?oMH;B00?o0000ogV0c_miP<h01?miP<h01ol0003oOh7;ogn1bomoPL_o0000oiVD
c_l000001onPV<`00ol0003oZIc:ojVLbP04ojVLbP;o00000oo0/ld00ol0003oakO:olNgbP02olNg
bP03o`000?o>^lOoc[_700;oc[_700Co0000omBnaOoD_/Go00001?oMb<@01?l0003oh<S1on38`Ol0
0003on;:_`06o`000?oRbl7o0000o`000?oSbKko00000_oRb;h00ol0003og/O2o`000003omg5`@05
o`000?oF_l?oe[o3omJo`ol000000oo<^<L01Ol0003o_jo:okn_b_no[l[o000000Co/:G<00?o0000
oj2IcOnPVLd00_nPVLd00ol0003oShg=ohn=c@02ohn=c@CoP8;<00?oGWSDo`000?m;Jm400_m;Jm40
0ol0003o?VC@ociTd002ociTd0;o000000Co04g<o`000?l5Em7o1EOA0olMJM`2o`000003obb6jol0
003oHjCd00?oHjCd00Go0000ohngl_n?]o;oSkObo`000005ojg1j0;o00001?o3d>@00ol0003odMGL
om7Eg003om7Eg0;o00001OoJf=D00ol0003og]SAomkHd@03omkHd@03o`000?oOf=3o000000;oh^cH
00?o0000ooooooooool03_ooool3o`00013ooooo00?o0000ooooooooool02_ooool001_ooooo00?o
0000ooooooooool0>Oooool01Ol0003of>SPomSXh?oHj>3o000000Coe^WR00?o0000om7Wi_oAinH0
0_oAinH00ol0003ob>?[olSSj`04o`0000;o`]?W1On]b>h2ohnfl@Ko000000?oN9o[o`000?mSRN80
0omSRN800ol0003oEGSIoeEhf@03oeEhf@;oCfkB00Co0000ogF2d_meP];o00001_miP<h00ol0003o
Oh7;ogn1b`03ogn1b`03o`000?nPV<coX9S<00GoX9S<00?o0000ojVLb_nYW<X01?nYW<X01_l0003o
/Z;8ok:Rb?l0003o`;?=o`0000CoakO:00?o0000oljkaoo>^lL00_o>^lL01?l0003oe;k5omBnaOoD
_/D2o`0000?ogLS400Co0000on38`OoPb<7o00000ooRb[l3o`0000;ohlVn00Goh/Rno`000?oRb;ko
h/Nno`000002omg5`@03o`000?oMa<3o000000;oe[o300?o0000olbhaoo<^<L00_o<^<L01Ol0003o
_jo:okn_b_no[l[o000000Co/:G<00?o0000oj2IcOnPVLd00_nPVLd01Ol0003oShg=ohn=cOn?SLgo
000000GoP8;<0_l00003od][d@04o`000?lnI=3o?VC@ociTd0;o>F?@00Go04g<o`000?l5Em7o1EOA
o`000002oaeYg0;o@8?X0ol00004of>Tm006o`000?n?]o;oSkObohngl_l0003o[L7X0ol000000on^
anco0000ol?@i004ol?@i003o`000?oAeMcodMGL00?odMGL0_l00004om[He@03o`000?oNf=7og]SA
00?og]SA0_l00003on;/f003o`000?oooooooooo00_ooooo0ol0000Cooooo`03o`000?oooooooooo
00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000omSXh?oHj>3of>SPo`000004omKY
hP03o`000?oAinKodNOV00;odNOV0ol000000oo?f=oo0000ol;Ci`04ol;Ci`?o[LS^0ol00002ohnf
l@CoJIc^0ol00003of>9hP03o`000?mEN=WoEGSI00;oEGSI00Oo0000odm^d_m?K];oCfkBo`000?me
P];o000000KoNH3>00?o0000ogn1bomoPL/00omoPL/00on8Q/[o0000oj2Hc004oj2Hc003o`000?nY
W<[oZIc:00CoZIc:00?o0000ok:Rb?nbX/P00_nbX/P2o`0000?oakO:00?o0000oljkaoo>^lL00_o>
^lL01Ol0003oe;k5omBnaOoD_/Go000000;ofL;200?o0000omg8a?l000000_oPb<400ol0003ohLRn
o`000002on;:_`04o`000?oSb;go0000on?9_P;o000000Koh/Rno`000?oRakko0000omg5`Ol00002
omg4`004o`000?oF_l?oe[o3o`0000;oc;S72Ol000000on`YLco0000oj2Ic@04oj2Ic@05o`000?n?
SLgoShg=ohn=cOl000001On0P/`2og=jb`04o`000?m;Jm7oBf_Ao`0000?o?VC@00Go0000ocUSd?li
Hm3o04g<o`000002o`EGd@03o`000?lMJMco7FWL00Co@8?X2_l00005ojk7k003o`000?o3d>Co`m3T
00;o`m3T00?o0000om7Eg?oAeM`01?oAeM`00ol0003of]SEom[He@02om[He@03o`000?oNf=7og]SA
00;og]SA00?o0000on3/f_l000000ooRk=P00ol0003oooooooooo`07ooooo`Co00005_ooool00ol0
003oooooooooo`0:ooooo`006oooool2o`0003Wooooo00?o0000omSXh?oHj>000_oHj>000ol0003o
e^WRomKYhP02omKYhP04o`000?oAinKodNOVom7WiP;o00001?o?f=l00ol0003o`]?Wol;Ci`02ol;C
i`?o00000_n]b>h01?l0003oSkKaohnflOn?]_44ofVLkP;oA7oT0_l000000omSRN;o0000oeEhf@03
oeEhf@03o`000?m?K];oCfkB00;oCfkB0_l00005ogV0cP03o`000?moPL_oOh7;00?oOh7;00Co0000
ohR6b_n8Q/[o00000onPV<`00ol0003oZIc:ojVLbP04ojVLbP03o`000?nbX/So/Z;800?o/Z;800Go
0000ok^Yaol0003oakO:o`000005oljka`04o`000?oD_/Goe;k5o`0000CofL;200Co0000on38`OoP
b<7o00000_oQb;h02ol0003oh/Zoo`000?l0003ohlRmo`000?oSbKko0000on;8__l0003oh/Nn00?o
00000_oMa<000ol0003oe[o3o`000004o`0000;ockS300Go0000olF`aOo5/<GoaK35o`000002okZW
a`?o00001?nPVLd01Ol0003oShg=ohn=cOn?SLgo000000GoP8;<0omcN//00ol0003oBf_Ao`000003
ociTd005o`000?liHm3o>F?@ocUSd?l000000ol5Em400ol0003o7FWLoaeYg003od23j0GoJ9o`1?n?
]_400ol0003o[/O/ojk7k003ojk7k003o`000?o3d>Co`m3T00?o`m3T00?o0000om7Eg?oAeM`00ooA
eM`2o`0000Cof]SE00Co0000omkHdOoNf=7o00000_oPk=X01Ol0003oh^cHon;/f?oRk=So000000Ko
oooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo
00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhPCo000000?oem[Jo`000?o?f=l0
0oo?f=l00ol0003o`]?Wo`000003o`0000Co[LS^00Go0000ohnflOn?]_7oSkKao`000004ofVLkP?o
A7oT0_l00004oeEhf@03o`000?m?K];oCfkB00;oCfkB0_m@J/h00ol0003oNH3>ogV0cP02ogV0cP03
o`000?moPL_oOh7;00?oOh7;00Oo0000ohR6b_n8Q/[oR8K:o`000?nPV<co000000KoZIc:00?o0000
ok:Rb?nbX/P00onbX/P01?l0003o^jW7ok^YaonkZLL2o`0000Coc[_700Go0000omBnaOoD_/Goe;k5
o`000004omW2`P;o000000?oh<S1o`000?oQb;h00_oQb;h01Ol0003ohlRmo`000?l0003ohlVn00?o
000000Coh/Nno`000?oQakgo00000ooMa<02o`0000;of;o100Go0000olnh`oo?^<?ockS3o`000003
olF`a@03o`000?njYlOo^ZO700;o^ZO700?o0000ojjNaol000000ol00004ohn=c@03o`000?n0P/co
P8;<00;oP8;<00?o0000og=jbomcN//00_mcN//00om;Jm7o0000ociTd002ociTd003o`000?liHm3o
>F?@00;o>F?@0_l000001Ol5Em7o0000oaeYg?lMJMco000000?o@8?X1OmXWo04ohnfl@03o`000?n^
anco[/O/00?o[/O/00?o0000ol?@i?o3d>@00_o3d>@00ol0003odMGLom7Eg004om7Eg003o`000?oJ
f=Gof]SE00;of]SE00?o0000omkHdOl000000ooPk=X01Ol0003oh^cHon;/f?oRk=So000000?ooooo
0ol0000Mooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o
0000omSXh?oHj>000_oHj>001?l0003oe^WRomKYh_oFjN82o`0000Goem[J00?o0000oloHgoo?f=l0
0ol00004ol;Ci`03o`000?n]b>ko[LS^00;o[LS^00Co0000ohnflOn?]_7o00001?mYW>h01?l0003o
A7oTodAoi?m4On@2o`0000?oEGSI00?o0000odm^d_m?K]800_m?K]83oe1ZcP04o`000?miP<koNH3>
o`0000GoOh7;00?o0000ohR6b_n8Q/X00on8Q/X2o`0000KoZIc:00?o0000ok:Rb?nbX/P00_nbX/P0
0ol0003o^jW7ok^Ya`02ok^Ya`06o`000?o4/<Ko0000o`000?o>^lOo00000ooD_/D00ol0003ofL;2
omW2`P02omW2`P04o`000?oMa<3ogLC0o`0000CohLRn00?o0000on?8_Ol000000ol000002_oRb;ko
0000o`000?oQakgohLJmo`000?oMa<3o0000omk3_ol00002omRo`@03o`000?o?^<?ockS300;ockS3
00Go0000olF`aOo5/<GoaK35o`000003okZWa`03o`000?n^W/Oo[Yk700?o[Yk70_l00003ohn=c@03
o`000?n0P/coP8;<00;oP8;<00?o0000og=jbomcN//00omcN//2o`0000?o?VC@00Co0000ocUSd?li
Hm3o>F?@0_lkJ=@00ol0003o1EOAo`000002oaeYg004o`000?m0PnSo@8?Xo`0000CoJ9o`00Go0000
ohnflOn?]_7oSkKao`000005ojk7k003o`000?o3d>Co`m3T00?o`m3T00?o0000om7Eg?oAeM`00ooA
eM`2o`0000?of]SE0_l00004on3/fP04o`000?oRk=Soh^cHon;/f0Co00008?ooool00ol0003ooooo
ooooo`0:ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`000?oHj>3of>SP00;of>SP00Ko
0000omKYh_l0003o0000om_Ke_l00005omOJfP?o00000_o?f=l00ol0003o`]?Wol;Ci`02ol;Ci`03
o`000?n]b>ko[LS^00;o[LS^00Go0000ohnflOn?]_7oSkKao`000003ofVLkP04o`000?m4OnCoA7oT
odAoi0;o9FGH00Co0000oeEhfOmEN=Wo00001?m?K]801ol0003oD6[>oe1Zc_m@J/ko0000ogV0c_l0
00001OmoPL/00ol0003oR8K:ohR6bP03ohR6bP;oU8g90_l00003ojVLbP03o`000?nbX/So/Z;800?o
/Z;800Go0000ok^YaonkZLOo^jW7o`000004olB`aP;o00000ooD_/D01Ol0003ofL;2omW2`_oI`/;o
000000?ogLC000Co0000on78__oQb;kohLRn0_l000000ooSb;go0000o`000005o`0000;ohLJm0_l0
0002omk3_`04o`000?oH_l7of;o1o`0000?ockS300?o0000olF`aOo5/<D00_o5/<D01Ol0003o^ZO7
okZWaonjYlOo000000Go[Yk700?o0000oj:Faol000000_l00005oh22c003o`000?mcN/_oLg[;00?o
Lg[;0_mZML`01?l0003o?VC@ociTd?l00003ocUSd005o`000?lkJ=Co>fSDoc]Xe?l000000_lMJM`0
1Ol0003o@8?Xod23j?m0PnSo000000CoJ9o`00Go0000ohnflOn?]_7oSkKao`000005ojk7k003o`00
0?o3d>Co`m3T00;o`m3T00?o0000om7Eg?oAeM`01?oAeM`2o`000004om[HeOl0003ofn[No`0000Co
h>cJ00Go0000on;/f?oRk=Soh^cHo`00000Sooooo`03o`000?oooooooooo00[ooooo000Jooooo`?o
0000>Oooool00ol0003of>SPomSXh002omSXh0;o00001?oKfmH00ol0003oem[JomOJfP03o`0000Co
cmSO00?o0000ol;Cioo2dnL00oo2dnL01Ol0003o[LS^ojg8k_n]b>ko000000?oSkKa00?o0000ofVL
k_mYW>h00_mYW>h01?l0003oA7oTodAoi?l00002obEUf0;o00001Om?K]800ol0003oD6[>oe1ZcP02
oe1ZcP03o`000?moPL_oOh7;00?oOh7;00?o0000ohR6b_n8Q/X00on8Q/X00ol0003oU8g9oiB=b@02
oiB=b@03o`000?nYW<[o000000Go/Z;800?o0000ok^YaonkZLL00_nkZLL00ol0003oa;36olB`aP02
olB`aP05o`000?o=]/Co0000omBnaOl000001?oI`/802?l0003ogLC0omg4`?l0003oh<Jno`000?oQ
b;ko00000_oSakd4o`000003on?7_?l0003o000000?ohLJm00Co0000omk3_ooN`koo00000ooH_l40
1Ol0003ockS3olnh`oo?^<?o000000?oaK3500?o0000okZWaonjYlL00_njYlL00ol0003o[Yk7ojjN
a`02ojjNa`03o`000?nRU/OoXYK700;oXYK70_l00004oh22c003o`000?mcN/_oLg[;00;oLg[;00Oo
0000ofYec?mZMLcoJWG<o`000?lnI=3o000000?o>F?@00?o0000oc]Xe?lkJ=@00_lkJ=@2o`000005
oaeYg?l0003o@8?Xod23j?l000001?mXWo000ol0003oSkKaohnfl@02ohnfl@03o`000?n^anco[/O/
00;o[/O/00?o0000ol?@i?o3d>@00oo3d>@00ol0003odMGLom7Eg003om7Eg003o`000?oJf=Go0000
00;ofn[N00?o0000on3/f_oPk=X00_oPk=X01Ol0003oh^cHon;/f?oRk=So000002Cooooo00?o0000
ooooooooool02Oooool001[ooooo00?o0000ooooooooool0>Oooool01?l0003of>SPomSXh?oHj>02
o`0000Gofm_F0ol00003omOJfP03o`000?o?f=oocmSO00;ocmSO00?o0000ol;Cioo2dnL00_o2dnL0
0ol0003o[LS^ojg8kP02ojg8kP04o`000?n?]_7oSkKao`0000CoJIc^00Co0000odAoi?m4OnCoA7oT
0olUIMP2o`0000?oCfkB00?o0000oe1Zc_m@J/h00om@J/h00omHK<go0000ogn1b`03ogn1b`03o`00
0?n8Q/[oR8K:00?oR8K:00?o0000oiB=bOnDSLT00onDSLT2o`0000Co/Z;800?o0000ok^YaonkZLL0
0_nkZLL00ol0003oa;36olB`aP02olB`aP04o`000?o=]/CocKK4olffa0?o00000_oI`/801Ol0003o
gLC0omg4`?oMa<3o000000;oh<Jn00Co0000on?7_OoSakgohlNm1_l00002on76_@03o`000?oQa[go
000000;og/>o00Co0000omRo`OoH_l7o00001?o?^<<01Ol0003oaK35olF`aOo5/<Go000000?o^ZO7
00?o0000ojjNaon^W/L00on^W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nGS/So000000?oP8;<
00?o0000og=jbomcN//00_mcN//00ol0003oJWG<ofYec002ofYec003ociTd?l0003o>F?@00;o>F?@
00?o0000oc]Xe?lkJ=@00_lkJ=@2odIdf`03o`000?lMJMco000000;o@8?X00?o0000ofROl?mXWo00
0_mXWo001Ol0003oSkKaohnflOn?]_7o000000Co[/O/00?o0000ol?@i?o3d>@00oo3d>@00ol0003o
dMGLom7Eg003om7Eg0?o00000_oKj]h00ol0003oh>cJon3/fP02on3/fP05o`000?oRk=Soh^cHon;/
f?l000009?ooool00ol0003oooooooooo`09ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Wooooo00Ko0000
omSXh?l0003o0000omcJe?l00002om_KePCo00001OoGf]X00ol0003ocmSOoloHg`02oloHg`03o`00
0?o2dnOo`]?W00?o`]?W00Go0000ojg8k_n]b>ko[LS^o`000003ohnfl@05o`000?mYW>koJIc^ofVL
k_l000000om4On@00ol0003o9FGHobEUf002oa9CcP04o`000?m?K];oCfkBo`0000GoD6[>0_mHK<d0
1?l0003oOh7;ogn1bol00006ohR6bP03o`000?nDSLWoU8g900?oU8g90_nQU/T01Ol0003o/Z;8ok:R
b?nbX/So000000Co^jW700?o0000olB`a_o4/<H00_o4/<H01Ol0003ocKK4olffa?o=]/Co000000;o
e;c20ol00002omg4`004o`000?oPa[koh<Jnon36_P;o000000?ohlNmo`000?l000001_l00002on76
_@03o`000?oN`koo000000_o00000_o5/<D01Ol0003o^ZO7okZWaonjYlOo000000Co[Yk700?o0000
oj:FaonRU/L00_nRU/L01ol0003oUhk8oiN>b?nGS/So0000oh22c?l000001OmcN//00ol0003oJWG<
ofYec003ofYec0;o00000oliHm001Ol0003o>fSDoc]Xe?lkJ=Co000000?oAWCK00Go0000od23j?m0
PnSo@8?Xo`000003ofROl003o`000?n?]_7oSkKa00;oSkKa00?o0000ojk7k?n^an`00_n^an`00ol0
003o`m3Tol?@i003ol?@i003o`000?oAeMcodMGL00;o000000KodNGUo`000?oKj]ko0000om_Zg_l0
0004on3/fP05o`000?oRk=Soh^cHon;/f?l000009?ooool00ol0003oooooooooo`09ooooo`0000Co
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0iooooo`;o00000ooLf]@3o`0000Cofm_F00?o0000omOJf_oGf]X00_oGf]X00ol0003ocmSO
oloHg`02oloHg`03o`000?o2dnOo`]?W00?o`]?W00Go0000ojg8k_n]b>ko[LS^o`000003ohnfl@03
o`000?mYW>koJIc^00;oJIc^00Co0000odAoi?m4OnCo00000_lUIMP01_l0003o4U?>oa9Cc_l0003o
CfkBo`0000CoD6[>00Oo0000oeQ/cOmHK<goF6c=o`000?moPL_o000000GoR8K:00?o0000oiB=bOnD
SLT00onDSLT01ol0003oXIK9oj6FbOnQU/Wo0000ok:Rb?l000001?nkZLL00ol0003oa;36olB`aP02
olB`aP05o`000?o=]/CocKK4olffa?l000001?oD_<801Ol0003of/70o`000?oMa<3o000000;oh<Jn
00Go0000on;7_OoRakgo0000on?7_006o`0000?ohLJm0_l00002omo4_P04o`000?oJ`L3of/70o`00
00?oe;c200?o0000olffa?o=]/@00ol00003okZWa`03o`000?n^W/Oo[Yk700;o[Yk700?o0000oj:F
aonRU/L00_nRU/L00ol0003oUhk8oiN>b002oiN>b0;o00001?mcN//00ol0003oJWG<ofYec004ofYe
c0;oI7C>00Co0000ocUSd?liHm3o00000olkJ=@00ol0003oAWCKodIdf`02odIdf`;o000000?o@8?X
o`000?mXWo000omXWo001Ol0003oSkKaohnflOn?]_7o000000Co[/O/00?o0000ol?@i?o3d>@00oo3
d>@00ol0003odMGLo`000003om7Ui@03o`000?oKj]kofn[N00;o00001?oPk=X01Ol0003oh^cHon;/
f?oRk=So000002Cooooo00?o0000ooooooooool02Oooool000?ooooo00?o410@ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000omcJe?l000000_l0
00000ooLf]Co0000om_KeP04om_KeP03o`000?oGf][oem[J00?oem[J00?o0000oloHgoo?f=l00_o?
f=l00ol0003o`]?Wol;Ci`02ol;Ci`03o`000?n]b>ko[LS^00Ko00001?mYW>h01Ol0003oA7oTodAo
i?m4OnCo000000;o9FGH0olBDlh2o`0000CoD6[>00?o0000oeQ/cOmHK<d00_mHK<d2o`0000GoR8K:
00?o0000oiB=bOnDSLT00onDSLT00ol0003oXIK9oj6Fb@02oj6Fb@;o00001?nkZLL01Ol0003oa;36
olB`a_o4/<Ko000000CocKK400Go0000omBl`_oD_<;oe;c2o`000003om[1`0Ko000000?oh/Nmo`00
0?l000001ol00002on;6_@04o`000?oOa;koglBno`0000;of/7000Go0000omBl`_oD_<;oe;c2o`00
0004olffa003o`000?o4[lGo000000;o00001On^W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nG
S/SoUhk800?oUhk80_l00003og=jb`03o`000?mZMLcoJWG<00?oJWG<00Oo0000ofAdc_mTM<koI7C>
o`000?liHm3o000000?o>fSD00?o0000odIdfom6M=/00_m6M=/2oeV7h`03o`000?m0PnSo000000?o
J9o`00?o0000ohnflOn?]_400_n?]_400ol0003o[/O/ojk7k002ojk7k003o`000?o3d>Co`m3T00;o
`m3T0_l00004om7Ui@05o`000?oKj]kofn[Nom_Zg_l000001?oPk=X01Ol0003oh^cHon;/f?oRk=So
000002Cooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool03Oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Sooooo0ol00004omcJe003o`000?oKfmKofm_F
00?ofm_F00?o0000omOJf_oGf]X00ooGf]X00ol0003ocmSOoloHg`02oloHg`03o`000?o2dnOo`]?W
00;o`]?W0ol00002ojo3j@03o`000?n>]_7oS[Ka00Ko00000om4On@01?l0003o9FGHobEUf?l00003
oa9CcP03o`000?m@J/koD6[>00;oD6[>00?o0000oeQ/cOmHK<d00_mHK<d2ofEcc@05o`000?n8Q/[o
R8K:ohR6b_l000001OnDSLT00ol0003oXIK9oj6Fb@03oj6Fb@03o`000?n^WlSo000000;o^jW700?o
0000olB`a_o4/<H00_o4/<H01Ol0003ocKK4olffa?o=]/Co000000Coe;c200Go0000om[1`?oJ`L3o
f/70o`000002omo4_P03o`000?oRa[goh/Jm00Oo000000GohlNlo`000?oRa[goh/Jmo`000003omo4
_P04o`000?oJ`L3of/70o`0000?oe;c200Go0000olffa?o=]/CocKK4o`000004olB_a@;o00000on^
W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nGS/SoUhk800CoUhk800?o0000ohj8b?l000000_mc
N//00ol0003oJWG<ofYec003ofYec003o`000?mTM<koI7C>00;oI7C>00?o>F?@o`000?lkJ=@00_lk
J=@00ol0003oAWCKodIdf`02odIdf`05o`000?mIQn?oFHOSoeV7hol000001?mXWo000ol0003oSkKa
ohnfl@02ohnfl@06o`000?n^anco[/O/ojk7k?l0003o`m3T0ol000000oo1fngo0000om7Ui@03om7U
i@05o`000?oKj]kofn[Nom_Zg_l000001?oPk=X01Ol0003oh^cHon;/f?oRk=So000002Cooooo00?o
0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool00ol0003og=[DomcJe003omcJe003o`000?oK
fmKofm_F00?ofm_F00?o0000omOJf_oGf]X00_oGf]X00ol0003ocmSOoloHg`02oloHg`03o`000?o2
dnOo000000;o000000?o`lWOo`000?n_`nT00on_`nT01?l0003oS[KaohjflOl00003oebLlP?o0000
00GoA7oTo`000?lUIMSo9FGHo`000003oa9CcP03o`i<b?l0003oD6[>00;oD6[>00?o0000oeQ/cOmH
K<d00_mHK<d3ofEcc@04o`000?n8Q/[oR8K:o`0000GoU8g900?o0000oj6FbOnQU/T00_nQU/T01ol0
003o[Yo8ojjOb?n^WlSo0000ok^Yaol000000oo4/<H00ol0003ocKK4olffa002olffa005o`000?oD
_<;oe;c2omBl`_l000000ooJ`L001Ol0003oglBnomo4__oOa;ko000000;oh/Jm00?o0000on?7_?l0
00001ol000001OoRa[go0000omo4__oOa;ko000000;of/7000?o0000omBl`_oD_<800_oD_<801Ol0
003ocKK4olffa?o=]/Co000000Coa:o500Ko0000ok^Xa_l0003o0000ojjNaol00004oj:Fa`03o`00
0?nGS/SoUhk800?oUhk800Co0000ohj8b?n>R<SoSXS80_l00006ofYec003o`000?mTM<koI7C>00?o
I7C>0_l00003oc]Xe005o`000?m6M=_oAWCKodIdfol000001?mIQn<5o`0000CoSkKa00?o0000ojk7
k?n^an`00ol00004ol7Kk@03o`000?oAiNGodNGU00;odNGU00Co0000om_Zg_oKj]kofn[N0_l00003
on3/fP05o`000?oRk=Soh^cHon;/f?l000009?ooool00ol0003oooooooooo`09ooooo`000oooool0
0ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool3
o`0000Gooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_Fom_KeP03om_KeP03o`000?oGf][o
em[J00?oem[J00Co0000oloHgoo?f=oocmSO0_l00005ol?9g`03o`000?n_`nWo[l?Y00;o[l?Y00Co
0000ohjflOn>]_7o00000omLW?801Ol0003o7gKSo`000?m4OnCo000000;o9FGH00Ko0000oa9Cc_lB
Dlko0000o`i<b?l00002oe1ZcP03o`000?mHK<goF6c=00;oF6c=00Oo0000ofEccOmULlgoIG?=o`00
0?n8Q/[o000000CoU8g900?o0000oj6FbOnQU/T00onQU/T00ol0003o[Yo8ojjOb002ojjOb0?o0000
0_o4/<H01Ol0003ocKK4olffa?o=]/Co000000?oe;c200?o0000om[1`?oJ`L000_oJ`L001Ol0003o
glBnomo4__l0003oh/Jm00Go000000GohlNlo`000?l0003ohlNlo`000002on;7_@?o000000GoglBn
o`000?oJ`L3of/70o`000003omBl`P05o`000?o=]/CocKK4olffa?l000001?o4[lD00ol0003o^jS6
ok^XaP02ok^XaP;o00000onRU/L00ol0003oUhk8oiN>b004oiN>b003o`000?n>R<SoSXS800;oSXS8
0_l00004ofYec003o`000?mTM<koI7C>00CoI7C>0_mSMm401?l0003o>fSDoc]Xe?l00003odIdf`03
o`000?mIQn?oFHOS00;oFHOS1?mcW^`8o`0000;oZlca00?o0000ol7KkOo1fnd00_o1fnd00ol0003o
dNGUom7Ui@02om7Ui@07o`000?oKj]kofn[Nom_Zg_l0003oh>cJo`000002on3/fP03o`000?oRk=So
h^cH00;o00009Oooool00ol0003oooooooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo0ol00008ooooo`03o`000?oLf]Co
g=[D00?og=[D00?o0000om_Ke_oKfmH00ooKfmH00ol0003oem[JomOJfP03omOJfP06o`000?o?f=oo
cmSOo`000?o>bmOo00001_o3bMl00ol0003o[l?Yojo3j@02ojo3j@04o`000?n>]_7oS[Kao`0000?o
G9cb00?o0000oamfholOM^<00_l000000olUIMSo0000oa9CcP02oa9CcP;o3Tc80_l00005oeQ/c@03
o`000?mULlgoIG?=00;oIG?=0_l00004oiB=b@03o`000?nQU/WoXIK900?oXIK900?o0000ojjOb?n^
WlP00_n^WlP00ol0003o^ZS7okZXa`04o`0000;ocKK400Go0000omBl`_oD_<;oe;c2o`000004om[1
`0Go00000_oRa[d2o`000005on?7_?l0003o0000on?7_?l000000ooRakd00ol0003oh<Jnon36_P03
o`000003om[1`?l0003oe;c200;oe;c200Go0000olffa?o=]/CocKK4o`000004olB_a@03o`000?nk
Z<Ko^jS600;o^jS600?o0000ok:Raol000000_nRU/L00ol0003oUhk8oiN>b003oiN>b003o`000?n>
R<SoSXS800?oSXS800?o0000ohN4bOl000000omZML`00ol0003oI7C>ofAdcP03ofAdcP07o`000?mS
Mm7oHgOAof=gdOl0003o>fSDo`000003odIdf`03o`000?mIQn?oFHOS00;oFHOS00?o0000og>Nk?mc
W^`00_mcW^`5ohnfl@05o`000?n[c?7oZlcaoj_<lOl000001?o1fnd00ol0003odNGUom7Ui@02om7U
i@05o`000?oKj]kofn[Nom_Zg_l000000_oPk=X01ol0003oh>cJo`000?oRk=So0000omKihOl00000
9Oooool00ol0003oooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo
00?o0000ooooooooool0;Oooool3o`0000cooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_F
om_KeP03om_KeP03o`000?oGf][oem[J00;oem[J00?o0000oloHgol000000oo>bmL00ol0003o`lWO
ol?9g`04ol?9g`05o`000?n_`nWo[l?Yojo3jOl000000on>]_401_l0003oG9cboebLl_mLW?;o0000
oamfh`;o04g:0_l00003oa9CcP03o`000?l>C<So3Tc800;o00000omHK<d00ol0003oIG?=ofEcc@03
ofEcc@;oMWk>00Co0000oiB=bOnDSLWo00001OnQU/T00ol0003o[Yo8ojjOb002ojjOb003o`000?nj
Z<Oo^ZS700;o^ZS700?o0000olJaa_o6/LH03?l00002omk4_`03o`000?oRa[go000000;o000000?o
hlNlo`000?l000000ol00002on;7_@05o`000?oPa[koh<Jnon36__l000000_oMa<03o`0000;oe;c2
00Go0000olffa?o=]/CocKK4o`000003olB_a@03o`000?nkZ<Ko^jS600;o^jS600Oo0000ok:Raonb
X/Oo/Z;7o`000?nRU/Oo000000CoUhk800?o0000ohj8b?n>R<P00on>R<P01Ol0003oQhC9ohN4bOn7
Q<Wo000000;oJWG<00?o0000ofAdc_mTM<h00omTM<h00ol0003oHgOAof=gd@02of=gd@03oc]Xe?l0
003oAWCK00;oAWCK00?o0000oeV7homIQn<00_mIQn<00ol0003oLik/og>Nk002og>Nk003o`000?n?
]_7oSkKa00;oSkKa00Go0000oj_<lOn[c?7oZlcao`000004ol7Kk@03o`000?oAiNGodNGU00;odNGU
00Go0000om_Zg_oKj]kofn[No`000002on3/fP06o`000?oPk=[o0000o`000?oFnN7o00009_ooool0
0ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0Zooooo`?o00003oooool00ol0
003og=[DomcJe003omcJe003o`000?oKfmKofm_F00?ofm_F00?o0000omOJf_oGf]X00_oGf]X2o`00
00Goc/_G00?o0000ol?9goo3bMl00oo3bMl00ol0003o[l?Yojo3j@02ojo3j@05o`000?n>]_7oS[Ka
ohjflOl000000omLW?801_l0003o7gKSo`1=b_l0CL[o9FGHo`0000;o4U?>00?o0000o`i<b?l>C<P0
0_lFClT01?l0003oF6c=oeQ/cOl00005ofEcc@?oMWk>00?o0000oiB=bOl000001OnQU/T00ol0003o
[Yo8ojjOb002ojjOb005o`000?njZ<Oo^ZS7okZXaol000001?o6/LH01Ol0003od;W4om2ia?o@^LCo
000000Cof;o100Co0000omk4_ooNa;oog/Bo0_l000000ooQa[go0000on?7_005o`000004on?7_Ol0
003oh/Nmo`0000;oh<Jn00Go0000omg4`?oMa<3ogLC0o`000002omW1`P?o00000_o=]/@01Ol0003o
a:o5olB_aOo4[lGo000000Co^jS600?o0000ok:RaonbX/L00onbX/L2o`0000CoUhk800?o0000ohj8
b?n>R<P00_n>R<P00ol0003oQhC9ohN4b@03ohN4b@;o00001OmTM<h00ol0003oHgOAof=gd@04of=g
d@;o00000_m6M=/00ol0003oFHOSoeV7h`02oeV7h`03o`000?mcW^coLik/00;oLik/00?o0000ohnf
lOn?]_400_n?]_401Ol0003oZlcaoj_<lOn[c?7o000000Co`M_]00?o0000om7UiOoAiND00_oAiND0
1Ol0003ofn[Nom_Zg_oKj]ko000000?oh>cJ0_l00002omKih@03o`000?oooooooooo02Cooooo00?o
0000ooooooooool02?ooool001Wooooo0_l0000Xooooo`?o00004_ooool00ol0003og=[DomcJe004
omcJe003o`000?oKfmKofm_F00;ofm_F00?o0000omOJf_oGf]X00_l000000ooDbm7o0000olk;e`05
olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o0000ojo3jOn_`nT00_n_`nT01Ol0003oS[KaohjflOn>
]_7o000000?oG9cb00Co0000oamfhol0CL[o04g:0_l000001OlBDlko0000o`i<b?l>C<So000000;o
5To900?o0000oeQ/cOl000001?mULld00ol0003oMWk>ogIncP02ogIncP;o00001?nQU/T00ol0003o
[Yo8ojjOb002ojjOb003o`000?njZ<Oo^ZS700;o^ZS700?o0000olJaa_o6/LH00_o6/LH01Ol0003o
d;W4om2ia?o@^LCo000000?of;o100Co0000omk4_ooNa;oog/Bo0_l000000ooQa[go0000o`000006
o`0000;ohlNm00Co0000on36__oPa[ko00000ooMa<000ol0003ofL72omW1`P02omW1`P05o`000?oD
_/Go0000olffa?l000000oo4[lD00ol0003o^jS6ok^XaP02ok^XaP03o`000?nbX/Oo/Z;700?o/Z;7
00?o0000ojZLb?l000000_nGS/P00ol0003oSXS8ohj8b003ohj8b003o`000?n7Q<WoQhC900CoQhC9
00?o0000ofAdc_mTM<h00omTM<h00ol0003oHgOAof=gd@04of=gd@;oIgoG00?o0000odIdfol00000
1?mIQn<00ol0003oLik/og>Nk002og>Nk003o`000?n?]_7oSkKa00;oSkKa00Go0000oj_<lOn[c?7o
Zlcao`000004ol7Kk@03o`000?oAiNGodNGU00;odNGU00Ko0000om_Zg_oKj]kofn[No`000?oPk=X2
o`000004om?ihol0003oe_WQo`0002Oooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000
ooooooooool09?ooool3o`0001Kooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_Fom_KeP03
om_KeP;o00001?oDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3bMoo`lWO00Co`lWO00?o0000
ojo3jOn_`nT00_n_`nT01Ol0003oS[KaohjflOn>]_7o000000;oG9cb00Co0000oamfholOM^?o04g:
0_l0;k<2o`0000?o3Tc80olFClT2o`0000CoIG?=00?o0000ogInc_mfO/h00_mfO/h2ohZ;c`;o0000
0_nQU/T00ol0003o[Yo8ojjOb002ojjOb003o`000?njZ<Oo^ZS700;o^ZS700Go0000olJaa_o6/LKo
a[76o`000003om2ia003o`000?oH_l7of;o100;of;o100?o0000omk4_ooNa;l00_l000001OoQa[go
0000on77_Ol0003ohlNl00;o000000?ohlRmo`000?l000000_oSakd2o`000003on36__l0003ogLC0
00;ogLC000Go0000omW1`_oI`L;ofL72o`000003omBna@;o00000_o4[lD00ol0003o^jS6ok^XaP02
ok^XaP03o`000?nbX/Oo/Z;700?o/Z;700Oo0000ojZLb?nZW<SoZYc8o`000?nGS/So000000CoSXS8
00?o0000ohN4bOn7Q<T01On7Q<T2o`0000CoI7C>00?o0000of=gdOmSMm400omSMm401_l0003oIgoG
ofMoeomWOmOoAWCKo`0000CoFHOS00?o0000og>Nk?mcW^`00_mcW^`00ol0003oSkKaohnfl@02ohnf
l@05o`000?n[c?7oZlcaoj_<lOl000001?o1fnd00ol0003odNGUom7Ui@02om7Ui@04o`000?oKj]ko
fn[Nom_ZgP;o00000_oCnN<01?l0003oe_WQo`000?l0000Wooooo`03o`000?oooooooooo00Sooooo
000Hooooo`03o`000?oooooooooo02;ooooo0ol0000Iooooo`03o`000?oLf]Cog=[D00?og=[D00?o
0000om_Ke_oKfmH00ooKfmH00ol0003oe<_AomC;d@04omC;d@03o`000?o>bmOoc/_G00?oc/_G00?o
0000ol?9goo3bMl01?o3bMl01Ol0003o[l?Yojo3jOn_`nWo000000CoS[Ka00Co0000oebLl_mLW?;o
00000_lOM^<01Ol0CL[o02nco`0_/olBDlko000000;o3Tc800Go0000oaI?bOlFClWo5To9o`000004
ofEcc@03o`000?mfO/koMWk>00;oMWk>1?n:Rll00ol0003oXIK9o`000004ojjOb005o`000?njZ<Oo
^ZS7okZXaol000001?o6/LH01Ol0003od;W4om2ia?o@^LCo000000Cof;o10ol000000ooMa<3o0000
o`000002on77_@Co000000?ohlRmo`000?oSb;d00_l00002on78_P;o00000_oMa<001Ol0003ofL72
omW1`_oI`L;o000000Coe;k500Go0000oljjaol0003oa:o5o`000003ok^XaP03o`000?nbX/Oo/Z;7
00?o/Z;700?o0000ojZLb?nZW<P00onZW<P00ol0003oSXS8ohj8b002ohj8b003o`000?n7Q<WoQhC9
00GoQhC900Co0000oh:3c?n2Plco00000_mTM<h00ol0003oHgOAof=gd@04of=gd@03o`000?mWOmOo
IgoG00;oIgoG0_l00003oeV7h`03o`000?mcW^coLik/00;oLik/00?o0000ohnflOn?]_400_n?]_40
0ol0003oZlcaoj_<l@02oj_<l@05o`000?o1fngo`M_]ol7KkOl000001?oAiND00ol0003ofn[Nom_Z
gP02o`0000?odoWS00?o0000omKihOl00000:?ooool00ol0003oooooooooo`08ooooo`006?ooool0
0ol0003oooooooooo`0Pooooo`;o00007?ooool00ol0003og=[DomcJe004omcJe004o`000?oKfmKo
fm_Fom_KeP;o00001ooDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o
0000ojo3jOn_`nT00_n_`nT00ol0003oS[Kaohjfl@02ohjfl@07o`000?mLW?;oG9cbo`000?lOM^?o
0000o`1=bP02o`0_/`04o`000?l>C<So3Tc8o`0000?o5To900?o:U_>o`000?mULld00_mULld00ol0
003oMWk>ogIncP02ogIncP03o`000?n:RlooRX_?00;oRX_?0_l00003ojjOb003o`000?njZ<Oo^ZS7
00;o^ZS700?o0000olJaa_o6/LH00_o6/LH01Ol0003od;W4om2ia?o@^LCo000000;of;o10_l00003
omg4`0;o00000_oQakd00ol0003oh/Nno`000002o`000004on?8_Ol0003ohlRmo`0000?ohLRn00Go
0000on38`Ol0003ogLC0o`000003omW1`P05o`000?oD_/Goe;k5omBnaOl000000oo>^/L2o`0000?o
^jS600?o0000ok:RaonbX/L00_nbX/L00ol0003oZYc8ojZLb004ojZLb0;o00000on>R<P00ol0003o
QhC9ohN4b@04ohN4b@03o`000?n2PlcoPX?<00;oPX?<00?o0000ofAdc_l000001OmSMm400ol0003o
IgoGofMoe`03ofMoe`;oL8gO0_l000000omIQn?o0000og>Nk003og>Nk003o`000?n?]_7oSkKa00;o
SkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1fngo000000CodNGU00Go0000om_Z
g_l0003oc_OXo`000002om?ih`03o`000?oFnN7oe_WQ00;o0000:?ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Mooooo`?o00007oooool00ol0003og=[DomcJe003omcJ
e004o`000?oKfmKofm_Fo`0000;of<_=00?o0000omC;dOoDbm401OoDbm400ol0003oc/_Golk;e`03
olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o0000ojo3jOn_`nT00_n_`nT00ol0003oS[Kaohjfl@06
o`000008oamfhol0003o04g:o`0_/ol08JSo0000o`i<b?l00003oaI?b@03o`000?lZFlko000000;o
IG?=00?o0000ogInc_mfO/h00_mfO/h00ol0003oRX_?ohZ;c`02ohZ;c`;oWIW?0_l000000on^WlSo
0000okZXa`03okZXa`03o`000?o6/LKoa[7600;oa[7600?o0000om2ia?o@^L@01?l000001?oG_l?o
0000omg4`?oMa<02o`0000;ohLNm00Co0000on;7__l0003ohlRn0ol000000ooSb;go0000o`000002
on78_P05o`000?oPb<7oh<S1on38`Ol000000ooI`L801Ol0003oe;k5omBnaOoD_/Go000000Coc[[7
00Go0000olNfb_l0003o^jS6o`000004ok:Ra`03o`000?nZW<SoZYc800CoZYc800Ko0000oj:Gb_nR
Ul[o0000ohj8b?l00006ohN4b@03o`000?n2PlcoPX?<00CoPX?<0_l00005of=gd@03o`000?mWOmOo
IgoG00;oIgoG00?o0000og2=gom`SMl00_m`SMl00omIQn?o0000og>Nk003og>Nk003o`000?n?]_7o
SkKa00;oSkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1fngo000000CodNGU0_l0
00000oo>mnSo0000om?ih`02om?ih`03o`000?oFnN7o000000;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`07ooooo`006?ooool2o`0001_ooooo0ol0000Rooooo`03o`000?oLf]Co
g=[D00?og=[D00?o0000om_Ke_l000001?oHbld00ol0003oe<_AomC;d@05omC;d@03o`000?o>bmOo
c/_G00?oc/_G00?o0000ol?9goo3bMl00oo3bMl00ol0003o[l?Yojo3j@04o`0000CoS[Ob00?oEJ7e
o`000?l000000_l000000ol0CL[o02nco`0QZ002o`0000Co5To90_lZFlh2o`0000GoMWk>00?o0000
ohZ;con:Rll00_n:Rll4oifIc`Co000000?o^ZS7o`000?o6/LH00oo6/LH00ol0003od;W4o`000002
o`0000Coeko300Go0000omg4`?l0003ogLG1o`000002on77_@Go000000OohlRmo`000?l0003oh/Zo
o`000?oQb;ko000000Coh<S100Go0000omW1`_oI`L;ofL72o`000002omBna@03o`000?o>^/Ooc[[7
00;oc[[700Go0000olNfb_o7]/[oakK:o`000005ok:Ra`03o`000?nZW<SoZYc800?oZYc800?o0000
oj:Gb_nRUlX00_nRUlX00ol0003oQhC9ohN4b@04ohN4b@03o`000?n2PlcoPX?<00GoPX?<00?o0000
ogn6d?l000001?mSMm400ol0003oIgoGofMoe`02ofMoe`03o`000?m`SMooL8gO00?oL8gO0_l00003
og>Nk003o`000?n?]_7oSkKa00;oSkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1
fngo000000;odNGU0ol00002olkgj004o`000?oCnN?odoWSo`0000;oe_WQ00Co0000oooooooooooo
00009oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Gooooo`?o0000
9Oooool00ol0003og=[DomcJe003omcJe0;o00001_oHbld00ol0003oe<_AomC;d@05omC;d@03o`00
0?o>bmOoc/_G00;oc/_G00?o0000ol?9goo3bMl00oo3bMl3o`0000Co[[kU1On>]o83oeFQm@?o0000
00Co02nco`0QZ?l>C<So00000olFClT00ol0003o:U_>obYKcP02o`0000?oMWk>00?o0000ohZ;con:
Rll00_n:Rll00ol0003oWIW?oifIc`02oifIc`Co/:G=2?l00002olfia`07o`000?oG_l?oeko3omNo
`ol0003ogLC0o`000003omg5`@Co000000GohlRno`000?l0003ohlRmo`000003on;:_`;o00000ooP
b<401Ol0003ogLS4o`000?oI`L;o000000?oe;k500Go0000oljjaoo>^/Ooc[[7o`000004olNfbP;o
00000onbX/L00ol0003oZYc8ojZLb003ojZLb003o`000?nRUl[oXYO:00?oXYO:0_l00005ohN4b@03
o`000?n2PlcoPX?<00CoPX?<00Go0000ogn6d?moQ]3oOhK@o`000002of=gd@03o`000?mWOmOoIgoG
00?oIgoG00?o0000og2=gom`SMl00om`SMl01_l0003oOYoXo`000?l0003oLik/o`0000CoSkKa00?o
0000oj_<lOn[c?400_n[c?400ol0003o`M_]ol7Kk@04o`0000;oa>o`00?o0000olkgj?l000000ooC
nN<01?l0003oe_WQomKihOl00003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
1oooool001Sooooo00?o0000ooooooooool05?ooool3o`0002Wooooo00Oo0000omcJe?oLf]Cog=[D
o`000?oHblco000000Oof<_=00?o0000omC;dOoDbm401?oDbm400ol0003oc/_Golk;e`03olk;e`05
o`000?o3bMoo`lWOol?9gol000000ono_mX5ojjni@03o`000?n>]o;oS[Ob00;oS[Ob00So0000oeFQ
mOmEXOGo0000o`=cg_l0003o02nco`0QZ0;o00000_lFClT00ol0003o:U_>obYKcP02odM^e@04o`00
0?mfO/koMWk>o`0000CoRX_?00?o0000oifIconMVLl00_nMVLl00ol0003o/:G=ok2Uc@02ok2Uc@03
o`000?o0/<_o`;3;00;o`;3;00Go0000olfiaoo=^LOocKW7o`000003omNo``;o00001?oMaL42o`00
0003on;8__l0003ohlRn00Co00000ooRb[l01Ol0003oh<S1on38`OoPb<7o000000?ogLS400Go0000
omBnaOoD_/Goe;k5o`000003oljja`03o`000?o7]/[oakK:00;oakK:00Ko0000ol2bc?o0//co0000
ok:Raol00005ojZLb003o`000?nRUl[oXYO:00?oXYO:00Co0000oi^Dc?nKU<co00000on7Q<T00ol0
003oPX?<oh:3c004oh:3c003o`000?moQ]3oOhK@00?oOhK@00?o0000of=gdOl000001?mWOmL00ol0
003oL8gOog2=g`03og2=g`03o`000?mnWnSoOYoX00?oOYoX1?l000000on?]_7o0000oj_<l@03oj_<
l@?o000000?o]^;eo`000?o4ko000_o4ko001?l0003oc_OXolkgj?l00002om?ih`04o`000?oFnN7o
e_WQo`0000Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`005oooool0
0ol0003oooooooooo`0Booooo`?o0000;?ooool01?l0003og=[DomcJe?l00003omS;c003o`000?oH
blgof<_=00Gof<_=00?o0000omC;dOoDbm401?oDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3
bMoo000000Go_koJ00?o0000ojjniOn^_^D00_n^_^D00ol0003oS[ObohjglP02ohjglP07o`000?mE
XOGoEJ7eo`000?l3Lmko0000o`0_/`02o`0SZP03o`000?lFClWo000000;o:U_>00Ko0000odM^eOm7
K]Go0000ogInc_l00004ohZ;c`03o`000?nMVLooWIW?00;oWIW?00?o0000ok2UcOn`YLd00_n`YLd0
0ol0003o`;3;ol2`b`02ol2`b`05o`000?o=^LOocKW7olfiaol000000_oG_l<2o`0000CogLG10ol0
00000ooRb;ko0000o`000002o`000004on?;`Ol0003oh/Zoon;:_`;o00000_oPb<402Ol0003ogLS4
omg8a?oMb<Co0000om[9b?l0003oe;k5o`000003oljja`03o`000?o7]/[oakK:00;oakK:00Co0000
ol2bc?o0//co`;;<0_l00005ojZLb003o`000?nRUl[oXYO:00?oXYO:00?o0000oi^Dc?nKU<`00_nK
U<`00ol0003oQhC9o`000006oh:3c003o`000?moQ]3oOhK@00GoOhK@00?o0000ofMoeomWOmL00omW
OmL00ol0003oL8gOog2=g`03og2=g`03o`000?mnWnSoOYoX00?oOYoX00Co0000oi2fl?n@]_3oT;K`
1ol00002okKRm@03o`000?o4ko3oa>o`00;oa>o`00?o0000olkgj?l000000ooCnN<01?l0003oe_WQ
omKihOl00006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo
00?o0000ooooooooool03oooool3o`0002oooooo00?o0000omcJe?l000001OoHbl`00ol0003of<_=
omS;c@05omS;c@03o`000?oDbm7oe<_A00Coe<_A00?o0000olk;eoo>bmL00oo>bmL00ol0003o_koJ
oknofP05oknofP03o`000?n^_^Go[[kU00?o[[kU00Co0000ohjgl_n>]o;oS[Ob0_l000000omEXOGo
0000o`000002o`0000;o02>Z0_l00003obYKcP?oAfkE0_l00004ohZ;c`03o`000?nMVLooWIW?00;o
WIW?00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`09o`000?o=^LOocKW7olfi
aol0003oeko3o`000?oG`/Ko000000?ogLG100Co0000omk7`_l0003oglW30ol000001_oRc<;o0000
on?;`Ol0003oh/Zoo`0000;oh/g30_l00003omg8a005o`000?oJbLSof/W8om[9b?l000000oo>^/L0
0ol0003oakK:olNfbP02olNfbP05o`000?o0//co`;;<ol2bc?l000000_ni[/l01Ol0003oZYc8ojZL
b?nZW<So000000GoXYO:00?o0000oi^Dc?nKU<`00onKU<`2o`0000KoPX?<00?o0000ogn6d?moQ]00
1OmoQ]000ol0003oOh_Fo`000003ofMoe`03o`000?m`SMooL8gO00CoL8gO00?o0000ogjOj?mnWnP0
0_mnWnP00ol0003oT;K`oi2fl003oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go
00000oo4ko001?l0003oc_OXolkgj?l00002om?ih`04o`000?oFnN7oe_WQo`0000Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2o`0000gooooo0ol0000coooo
o`03o`000?oHblcof<_<00Gof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;
d@05o`000?o>bmOoc/_Golk;eol000000_o8_]47oknofP;o00001?n^_^D00ol0003oS[ObohjglP02
ohjglP03o`000?mEXOGoEJ7e00;o000000Go026Xo`0SZ_l08j[o5To9o`000002obYKcP04o`000?m7
K]GoAfkEodM^e@;o00000on:Rll01Ol0003oWIW?oifIconMVLoo000000Go/:G=00Go0000ol2`boo0
/<_o`;3;o`000004olfia`;o00000_oG`/H01_l0003ogLG1omg5`Ol0003og/O2o`0000;oglW300Ko
0000on7;`ol0003oh/c2o`000?oSbl42o`0000?oh/g300Go0000omg8a?oMb<CogLS4o`000003om[9
b005o`000?oFbLgo0000oljjaol000001?o7]/X01Ol0003o`;;<ol2bc?o0//co000000Co^Jk?00?o
0000ojZLb?l000001OnRUlX00ol0003oViC<oi^Dc003oi^Dc004o`000?nFTlooUY??o`0000GoPX?<
00?o0000ogn6d?moQ]001?moQ]001Ol0003oOh_Fogn;e_moRmKo000000;oIgoG00?o0000og2=gom`
SMl00om`SMl00ol0003oOYoXogjOj003ogjOj003o`000?n@]_3oT;K`00;oT;K`00?o0000ojC=m_nT
cOH00_nTcOH01?l0003o]^;eokKRmOl00004olC_l003o`000?o>mnSo000000?odoWS00Co0000omKi
hOoFnN7o00002?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo000Goooo
o`03o`000?oooooooooo00Wooooo0ol0000fooooo`03o`000?oHblcof<_<00Kof<_<00?o0000omS;
cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;d@03o`000?o>bmOo000000Cob;kA00?o0000okno
f_no_mX01Ono_mX00ol0003o[[kUojjni@02ojjni@03o`000?n>]o;oS[Ob00;oS[Ob00Ko0000oeFQ
mOmEXOGo0000o`=cg_l08JP2o`0SZP04o`000?lZFlko:U_>o`0000?oAfkE0_mYPmX3o`0000CoWIW?
00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`04o`000?o=^LOocKW7olfia`;o
00001?oG`/H2o`00000:omk7`_l0003oglW3omo9`ol0003ohL_3o`000?oRc<;o0000on?;`@;o0000
0ooRcL<2o`0000;ogLS400Go0000om[9b?oJbLSof/W8o`000003omK9c@03o`000?o7]/[oakK:00;o
akK:00Go0000ol2bc?o0//co`;;<o`000005okV^c`;o00001OnRUlX00ol0003oViC<oi^Dc003oi^D
c003o`000?nFTlooUY??00;oUY??00Go0000oh:3c?n2PlcoPX?<o`000006ogn6d003o`000?moRmKo
Oh_F00?oOh_F00?o0000ofMoeol000001Om`SMl00ol0003oOYoXogjOj002ogjOj003o`000?n@]_3o
T;K`00?oT;K`00?o0000ojC=m_nTcOH00_nTcOH01?l0003o]^;eokKRmOl00003olC_l004o`000?o>
mnSoc_OXo`0000;odoWS00Co0000omKihOoFnN7o00002_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Kooooo0ol0000jooooo`03o`00
0?oHblcof<_<00Kof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;d@03o`00
0?o8_]7ob;kA00Cob;kA0_l00006oknofP03o`000?n^_^Go[[kU00;o[[kU0_l00003ohjglP0;o`00
0?mEXOGoEJ7eo`000?l3Lmko0000o`0SZ_l0=K[o0000obYKc_l000000om7K]D01?l0003oJH?JofV3
f_mYPmX2o`0000?oWIW?00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`Co0000
00?oc;g<o`000?oG`/H00_oG`/H2o`0000;og/O200?o0000omo9`ol000000_oQbl<01_l0003oh/c2
o`000?l0003oh]36o`0000;oh/g300?o0000on3@b?oPd<P00_l00003om[9b004o`000?oFbLgoe/W=
omK9c@;o00000oo7]/X01Ol0003o`;;<ol2bc?o0//co000000Go^Jk?00Co0000ok6[dOnaZm7o0000
0onRUlX00ol0003oViC<oi^Dc003oi^Dc003o`000?nFTlooUY??00CoUY??00?o0000oh:3c?l00000
1_moQ]000ol0003oOh_Fogn;eP04ogn;eP?o00001?m`SMl00ol0003oOYoXogjOj003ogjOj003o`00
0?n@]_3oT;K`00;oT;K`00?o0000ojC=m_nTcOH00_nTcOH01?l0003o]^;eokKRmOl00003olC_l004
o`000?o>mnSoc_OXo`0000?odoWS00Co0000omKihOoFnN7o00002oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0000noooo
o`03o`000?oHblcof<_<00Kof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@03omC;
d@03o`000?o=_/_ocKk;00Oob;kA00?o0000oknof_no_mX01?no_mX2o`0000Co[[kU00Go0000ohjg
l_n>]o;oS[Obo`000002oeFQm@05o`000?l3Lmko0000o`0SZ_l0=KX00_l00003odM^e@04o`000?mY
Pm[oJH?JofV3fP;oRYSK1?l00004ok2Uc@03o`000?o0/<_o`;3;00?o00001?o<_L`02?l0003oel;6
omO2a_l0003of<O9o`000?oNal;o00000_oObL<01?l0003ohL_3o`000?oRc<82o`0000;oh]3600?o
0000on;=`ol000000ooPd<P01Ol0003of/W8om[9b?oJbLSo000000?oe/W=00Ko0000om79d_oAbM;o
0000olNfb_l00003ol2bc003o`000?ni[/oo^Jk?00;o^Jk?0_l00004ok6[d@03o`000?nRUl[o0000
00GoViC<00?o0000oiJCconFTll01OnFTll3o`0000GoOhK@00?o0000ogn;e_moRmH01?moRmH01?l0
003oPYGMoh:EgOn2UMd2o`0000;oL8gO00?o0000ogjOj?mnWnP00_mnWnP00ol0003oT;K`oi2fl003
oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go00000oo4ko001?l0003oc_OXolkg
j?l00002om?ih`04o`000?oFnN7o0000o`0000cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo00?o0000omS;c?oH
bl`01OoHbl`00ol0003of<_=omS;c@05omS;c@05o`000?oDbm7oe<_AomC;dOl000001?o=_//00ol0
003ob;kAolRnd@04olRnd@;o00001_no_mX00ol0003o[[kUojjni@02ojjni@03o`000?n>]o;oS[Ob
00Ko00000_l08jX00ol0=K[o:U_>o`000002odM^e@05o`000?mYPm[oJH?JofV3f_l000001?n:V=/8
o`0000;o_;GC00?o0000olbmc?o<_L`00_o<_L`00ol0003oel;6o`000003omS7b@;o000000CoglW3
o`000?oQbl?ohL_30_l000001?oQdLSo0000on;@a_oRd<H2o`0000?oh=380_l00002om[9b005o`00
0?oFbLgoe/W=omK9cOl000000ooAbM82o`0000?o`;;<00?o0000okV^coni[/l00_ni[/l00ol0003o
/J_Aok6[d@04ok6[d@;o00001OnKU<`00ol0003oUY??oiJCc`05oiJCc`05o`000?nBUM?oTYGCoi:E
dol000000omoQ]000ol0003oOh_Fogn;eP04ogn;eP03o`000?n2UMgoPYGM00CoPYGM00?o0000og2=
gol000001?mnWnP00ol0003oT;K`oi2fl002oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKR
mOnfh_Go00000oo4ko001?l0003oc_OXolkgj?l00003om?ih`;o000000?o_O[[o`000?ooool03?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo000Fooooo`Co0000A_ooool0
0ol0003of<_<omS;c005omS;c003o`000?oHblgof<_=00Gof<_=00?o0000omC;dOl000001_o=_//2
o`0000Kob;kA00?o0000oknof_no_mX01?no_mX01?l0003o[[kUojjniOn^_^D3o`0000?oSkOb0omH
ZOT01?l0003o02>Zo`000?l0=KX2o`0000;oAfkE00Go0000ofV3f_mYPm[oJH?Jo`000003ohZHf`Go
YZWH00?o0000okbedonl]M<00_nl]M<00ol0003oc;g<olbmc002olbmc0;o00001?oHalT00ol0003o
flc:o`000003o`0000?ohM780_oRd<H2o`0000?oh=3800?o0000omkEcooNeLl00_l00003omK9c@05
o`000?oAbM;odLWBom79d_l000000_o;b=P00ol0003o`;;<o`000004okV^c`03o`000?naZm7o/J_A
00?o/J_A0_l00002oj^Xe005o`000?nKU<coViC<oi^Dc?l000001_nFTll2o`0000GoTYGC00?o0000
ogn6d?l000001_moRmH00ol0003oPYGMoh:Eg@05oh:Eg@?o00000omnWnP00ol0003oT;K`oi2fl003
oi2fl005o`000?nTcOKoY<gfojC=m_l000000onfh_D01Ol0003oa>o`olC_l?o4ko3o000000;oc_OX
1?l00002okgjj`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`005_ooool2o`0004Wooooo00?o0000omS;c?oHbl`01OoHbl`00ol0003of<_=omS;
c@05omS;c@03o`000?o=_/_ocKk;00OocKk;00?o0000olRndOo8_]401?o8_]400ol0003o_koJokno
fP04oknofP03o`000?n^_^Go000000?oZ[WT1On?]o801?l0003oF:WioeRYnOl08jX2o`000004o`1F
dOl0003oAfkEo`0000?oJH?J00Go0000ohZHfon:V=_oRYSKo`000004ojJYf003o`000?nl]M?o_;GC
00;o_;GC00Co0000olbmc?o<_Lcoc;g<0_l00004omS7b@04o`000?oKc<[oflc:o`0000;og]3:00So
0000on7Ab?oQdLSo0000on;@a_l0003oh=K=o`0000;oh=3800?o0000omkEcooNeLl00_l00003omK9
c@05o`000?oAbM;odLWBom79d_l000000oo;b=P2o`0000?o^Jk?0_l00004ok6[d@;o00001On[Z=@0
0ol0003oViC<o`000006oiJCc`03o`000?nBUM?oTYGC00GoTYGC0ol00005ogn;eP03o`000?n2UMgo
PYGM00GoPYGM00Co0000ohRTion8Y>OoR:CW0_l000000omnWnSo0000oi2fl003oi2fl003o`000?nT
cOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go00000oo4ko000ol0003oc_OXo`000002o`000005okWi
k?l0003o_O[[okgjjol000004Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`17ooooo`03o`00
0?oHblcof<_<00Gof<_<00?o0000omS;cOoHbld00ooHbld00ol0003od;g8om2mb009olfnb`;o0000
1Oo8_]42o`0000Go_koJ00?o0000ojZii?nZ^N@01?nZ^N@00ol0003oSkObohnglP02ohnglP08o`00
0?mHZOWo0000o`0e^_l0003o05KAodM^eOl00003ofV3fP05o`000?n:V=_oRYSKohZHfol000001?nV
ZMP00ol0003o_;GCokbed`03okbed`05o`000?o<_Lco0000olk5d_l000000ooHalT01?l0003oflc:
om_<b_l00002omk@bP04o`000?oQdLSohM78on7Ab0;o00000_oPe/d00ol0003oh=38o`000002omkE
c`03o`000?oJf]Oo000000;oe/W=00?o0000om79d_oAbM800_l00003ol_8f006o`000?o3amgo`lOM
o`000?ni[/oo00001OnaZm400ol0003oZjSDoj^Xe005oj^Xe0;o00001_nFTll00ol0003oTYGCoi:E
d`05oi:Ed`05o`000?n?VMWoSiWIohnIfOl000000omoRmH00ol0003oPYGMoh:Eg@05oh:Eg@03o`00
0?n8Y>OoR:CW00?oR:CW1Ol00002oi2fl005o`000?nTcOKoY<gfojC=m_l000000onfh_D01?l0003o
a>o`olC_l?o4ko02o`0000?o^OW/00Co0000okgjjonmn^_o00004_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Aoooool00ol0003of<_<omS;c005omS;c005o`000?oHblgof<_=omS;cOl000001?o@_LP0
0ol0003ocKk;olfnb`07olfnb`03o`000?o8_]7ob;kA00Cob;kA00Go0000oknof_no_m[o_koJo`00
0002okRgf003o`000?nZ^NCoZ[WT00CoZ[WT0_l00003ohnglP;o000000?o03Fjo`000?l0E]400_l0
0002ofV3fP03o`000?n:V=_oRYSK00;oRYSK00?o0000ojJYf?nVZMP00_nVZMP00ol0003o_;GCokbe
d`02okbed`;o00000oo>aM800ol0003of<O9o`000003om_<bP04o`000?oNd<[og]3:o`0000;ohM78
00?o0000on;@a_oPe/d00_oPe/d2o`0000;og]G?00Co0000om[JeooJf]Oof][G0_l00002om79dP04
o`000?o;b=SoblSHol_8f0;o00000oo3amd2o`0000Co/J_A0_l00006oj^Xe0;o00000_nTYmP01?l0
003oUY??oiJCconFTll2o`0000KoTYGC0_l00005ohnIf@03o`000?moRmKo000000KoPYGM0_l00005
ohRTi`03o`000?nA]_3oTKK`00?oTKK`1?l00002ojC=mPWo00000oninN`01?l0003o_O[[okgjjol0
000Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool000kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oHblcof<_<00Kof<_<00?o0000
omS;cOl000001_o@_LP2o`0000SocKk;00?o0000olRndOo8_]401?o8_]400ol0003o_koJo`000005
okRgf0;o00001OnZ^N@3o`0000;oSkOb00Go0000o`0e^_l0003o0000ocMmiP02o`000003ofV3f_l0
003oRYSK00;oRYSK00?o0000ojJYf?nVZMP00_nVZMP01?l0003o_;GCokbedonl]M<2o`0000Goc/GB
0_l00002om_<bP06o`000?oNd<[og]3:omk@b_l0003ohM780_l00003on3Fc@;o00000_oNeLl01?l0
003of][Gom[JeooJf]L2o`0000;odLWB00Go0000ol_8f?o;b=SoblSHo`000003ol?7g@;o00000_nk
aN801?l0003o/J_Ao`000?l00006oj^Xe0;o00001OnTYmP00ol0003oUY??o`000006oi:Ed`;o0000
1on?VMT3o`0000GoPYGM00?o0000ohRTion8Y>L01?n8Y>L00ol0003oTKK`oi6fl003oi6fl003o`00
0?nKboSoVl_h00;oVl_h1?l00003ojk]n003o`000?ncmO;o000000?o^OW/00Co0000okgjjonmn^_o
00005_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`00
0?oooooooooo00[ooooo0_l00017ooooo`03o`000?oHblcof<_<00Kof<_<00?o0000om2mb?o@_LP0
1oo@_LP00ol0003ocKk;olfnb`06olfnb`;o00001Oo8_]400ol0003o^;OHokRgf006okRgf0;o0000
1_nZ^N@2o`0000;oSkOb00?o0000o`1FdOl000000olgONH3o`000003ohZHfol0003oYZWH00?oYZWH
1?l000000onl`=go0000olk5dP03olk5dP06o`000?oBc]Kod/kFo`000?oKc<[o00000_oNd<X01Ol0
003ohM78o`000?oMfM;o000000;oh=K=00Go0000omgOeol0003og]G?o`000003om[Je`03o`000?oD
gn3o000000;odLWB0oo;b=P00ol0003o`lOMol?7g@02o`0000Co^lGR0_l00006oj^Xe0;o00001onT
YmP2o`0000KoTYGC00?o0000ohnIfOn?VMT01On?VMT2o`0000?oSj3O00Go0000oh:EgOn2UMgoPYGM
o`000006ohRTi`03o`000?nA]_3oTKK`00?oTKK`00?o0000oi_;n?nKboP00_nKboP01?l0003oY]kk
ojKNnol00003ojk]n003o`000?ncmO;o000000?o^OW/00Co0000okgjjonmn^_o00006?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool00ol0003of<_<omS;c005omS;c003o`000?oA_LOod;g800So
d;g800?o0000olfnboo=_//01oo=_//01Ol0003ob;kAolRndOo8_]7o000000;o`;G?00?o0000okRg
f?nh]mP01_nh]mP2o`0000KoZ[WT0_l000001?n?]o;o0000o`1FdOl00002ocMmiP03o`000?mbX>go
LZ3]00Oo00001Onl`=d01?l0003oc/GBolk5d_l00004om;>ePGo00000ooMfM800ol0003oh=K=o`00
0002omgOe`03o`000?oNeLoof][G00;of][G00?o0000omCOh?oDgn000_l00003ol_8f004o`000?o3
amgo`lOMo`0000?o^lGR0ol000000onb`nOo0000oj^Xe003oj^Xe0;o00001_nTYmP3o`0000;oWZOL
00Co0000oi:EdonBUM?oTYGC0_l00006ohnIf@;o00001_n?X=l00ol0003oPYGMo`000005ohRTi`;o
00001?nA]_02o`0000CoVl_h00Co0000ojKNnonVg__o00000on^kOP00ol0003o/oGbo`000003okWi
k004o`000?nmn^_o_O[[o`0001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05
ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo00?o0000omS;
c?oHbl`00ooHbl`01?l0003odKg7om6maooA_LL2o`0000Ood;g80_l00008olfnb`03o`000?o8_]7o
000000Go`;G?0_l00007okRgf0;o00001_nZ^N@5o`0000;o=ggV00Co0000og:PkOmbX>go00001?nO
]NP00ol0003o_<3Mokc0g@03okc0g@03o`000?o>aM;o000000God/kF00Go0000omSFe_oHe]Kof=KF
o`000002omgIdP03o`000?oPe/gogMoG00;ogMoG0_l00002om[Je`;o000000Goe=oPo`000?l0003o
b^CZo`000002ol_8f0;o`lOM0_l00002ok_5hP;o00001Onb`nL01?l0003oZjSDo`000?l00005ojBW
f0?o00001_nNYm`00ol0003oTYGCo`000006ohnIf@;o00002?n?X=l2o`0000GoR:CW00?o0000oi6f
l?nA]_000onA]_000ol0003oVl_hoi_;n002oi_;n0;o00000_nVg_/01ol0003o[^ghojk]n?n^kOSo
0000ok?el_l000000oninN`01?l0003o_O[[okgjjol0000Kooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`15ooooo`05o`000?oHblcof<_<omS;c?l000001_oA_LL00ol0003od;g8om2mb006om2mb003o`00
0?o=_/_ocKk;00KocKk;00?o0000ol2ecoo0]Ll01_o0]Ll2o`0000Oo^;OH0_l00006ojZii004o`00
0?n?^?;o0000o`0000;o=ggV00Co0000og:PkOmbX>go00001?nO]NP00ol0003o_<3Mokc0g@03okc0
g@03o`000?oBc]Kod/kF00?od/kF00Go0000omSFe_oHe]Kof=KFo`000002omgIdP;o00000_oMgmL2
o`000005omCYi?l0003of][Gom[JeooDgn000_l00003ol[TjP;o000000?o`lOMo`000?l000000_nk
aN82o`0000Ko//?W0ol00005ojBWf0;o00002?nNYm`4o`0000CoSiWI0_l00008ohnPg`;o00000_n?
Z^P01Ol0003oR:CWohRTion8Y>Oo000000CoTKK`0_l00004oi_;n003o`000?nVg__oY]kk00;o0000
0_n^kOP2o`000003ok?el_l0003o^OW/00;o^OW/00Co0000okgjjonmn^_o00007Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo
0_l00016ooooo`03o`000?oHblco000000SodKg700?o0000om2mb?o@_LP01_o@_LP00ol0003ocKk;
olfnb`05olfnb`03o`000?o5/lWo000000So`;G?0ol00006okRgf0;o00001?nZ^N@01?l0003oYKGT
o`000?l0?:T3o`0000?oLZ3]00?o0000oinej?nO]NP00_nO]NP01?l0003o_<3Mo`000?l00003ol7@
i@;o000000?od/kFo`000?oHe]H00_oHe]H4o`000004omKShOl0003ogMoGo`0000?oe>WT00Co0000
om[JeooDgn3o00000_o:i>X3o`000004okcUlol0003o0000ok_5hP?o00001Onb`nL3o`0000?oZ<3[
00?o0000ojBWf?l000000_l00007oijWg0?o00001?nJZN401?l0003oSiWIo`000?l00008ohnPg`;o
00001On?Z^P00ol0003oR:CWo`000004oi6fl003o`000?nKboSoVl_h00;oVl_h0_l00002ojKNn`05
o`000?n^kOSo[^ghojk]n?l000000_ncmO801Ol0003o^OW/okWik?ninNco000000;o_O[[00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Roooo
o`03o`000?oooooooooo04Cooooo00?o0000om6maooA_LL02?oA_LL2o`0000Ood;g80_l00004olfn
b`03o`000?o5/lWoaK?900;oaK?90_l00008ol2ec`;o00001_nh]mP2o`000003ojZii?l0003oYKGT
00CoYKGT00?o03bYo`000?l000000ombX>d00ol0003oWkGXoinej003o`0000Oo`M3U1_l00003omKS
h@03o`000?oMgmOo000000?oe>WT0_l000000ooDgn3o0000ol[TjP02o`000003okcUlol0003o0000
00Co00001Onb`nL3o`0000GoZ<3[0ol00006oijWg0Co00001_nJZN43o`0000OoSj3O0ol00007ohnZ
j0Co00000_nA]_000ol0003oVl_hoi_;n002oi_;n005o`000?nVg__oY]kkojKNnol000000on^kOP0
1?l0003o/oGbok?el_l00003okWik004o`000?nmn^_o_O[[o`00023ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`15ooooo`03o`000?oA
_LOodKg700SodKg700?o0000om2mb?o@_LP01_o@_LP01?l0003ocKk;olfnbol00007olFcb@;o0000
2?o0]Ll2o`0000Ko^;OH00?o0000ojFei?nU]N@01OnU]N@00ol0?:Wo0000o`000005o`0000CoWl_f
00Go0000ol7@iOo1d>Go`M3Uo`000005ol_Ni`03o`000?oFhn7oe^?Q00?o00000_oDjN@5o`000003
ol[Tj_l0003o000000Ko00000_nGgOh00ol0003o//?Wok;3i`03o`0000?oZ<3[1Ol00003oj2mkP03
o`000?nNYmcoWZOL00?o00001_nJZN44o`0000?oUZcV00?o0000ohnPgon?X=l00_n?X=l2o`0000Oo
Sj[X0ol00004oi6gl0Co00000_nKboP01Ol0003oY]kkojKNnonVg__o000000?o[^gh00Co0000ok?e
l_ncmO;o00000oninN`01?l0003o_O[[okgjjol0000Rooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01?ooool002Cooooo0_l00016ooooo`;o00002OoA_LL2o`0000Ood;g800?o0000
olfnbol000002Oo5/lT2o`0000So`;G?0_l00004okRgf004o`000?n`/MWo/;7Io`0000GoYKGT00Co
03bYo`000?l0N]go00000omM/_/00ol0003oWl_foio;mP02oio;mP03o`000?o1d>Go000000GobmkW
1?l000000oo2kO7o0000o`000002o`000003ol?al?l0003o000000;o000000Co_>Gco`000?l0003o
Z^?j0_l00003oiOMoPGo000000?oZ<3[o`000?l000000ol00005oj2mkPKo00001_nJZN43o`0000So
UZcV00Co0000ohnPgol0003o00001_n?Z^P3o`0000CoTKO`0ol00004oiC5n0Co000000?oY]kko`00
0?n^kOP00_n^kOP01?l0003o/oGbok?el_l00003okWik004o`000?nmn^_o_O[[o`0002Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15
ooooo`03o`000?oA_LOodKg700SodKg700?o0000om2mb?o@_LP01Oo@_LP00ol0003oaK?9olFcb@0:
olFcb@03o`000?o0]Loo`;G?00Oo`;G?0_l000000onh]mSo0000ok2af@05ok2af@?o00000_nU]N@0
1?l0003o07[Mo`000?l00003oefbn`04o`000?nOboKoWl_foio;mPSo00000_o2kO43o`0000;o`o7`
1_l00002oj[SnPgo00000onP_Nh7o`0000GoVK__00?o0000oiZYhOnJZN401?l00009oiJ/iPGo0000
1On?Z^P2o`0000GoTKO`0_l00005oiC5n0;o00000onGe?d@o`0002Kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`009oooool00ol0003oooooooooo`15ooooo`;o00002OoA
_LL00ol0003od;g8om2mb004om2mb003o`000?o7/lOo000000_oaK?90_l00009ol2ec`03o`000?n`
/MWo/;7I00So/;7I1ol00002oefbn`?o00001_n[hOT01?l0003o`^gao`000?l00002oi?Yn003o`00
0?o3lO3o000001Wo00002OnI^nl6o`0000SoUZcV1Ol00005oi>aj`03o`000?n?Z^So000000;o0000
1OnA]o02o`0000CoU<Gh0ol00003oiODo@;o00000_nKh?d2o`000003oikXnol0003o000000?oXngi
00Co0000oj[^n?l0003o0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo000Xooooo`03o`000?oooooooooo04Kooooo00?o0000om6maooA_LL01ooA_LL2o`0000?od;g8
00?o0000olNcaoo7/lL00_o7/lL3o`0000WoaK?90_l00007ol2ec`03o`000?ng[m7o000000;o0000
2On`/MT6o`0000KoI<ck2Ol00002ogVkn`?o000000?oF;Slo`000?l000002_l00006ogk6oP03o`00
0?nI^nooVK__00;oVK__2?l00005oiBil004o`000?nF[>KoUZcVoiJ/iPGo00002?nC/N/5o`0000Co
TKO`0ol00004oiC5n0;o00000onGe?d3o`0000;oVn3m0_l00002oikXn`04o`000?nSkOWoXngioj?]
n@;o000000?oZ^kho`000?ooool0:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo000Yooooo`;o0000Aoooool2o`0000WodKg700?o0000om2mb?l000002?o7/lL2o`0000Wo
aK?90_l00004ol2ec`03o`000?ng[m7o]joA00?o]joA0ol00009ok2af@?o00000_nU]N@8o`0000Oo
T;Sb1?l000000omi^o_o0000o`00000Do`0000KoU;W`2ol00007oi>aj`Ko00001OnA]o401?l0003o
TKO`o`000?l00005oiC5n0;o00000onGe?d2o`0000?oVn3m0_l00002oikXn`;o00000_nSkOT2o`00
0003oj[^n?l0003o000002gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04oooo
o`00:oooool00ol0003oooooooooo`16ooooo`03o`000?oA_LOodKg700OodKg700?o0000olNcaoo7
/lL02Oo7/lL2o`0000WoaK?90_l000000oo0]Loo0000okN_d@08okN_d@?o00002On`/MT2o`0000[o
W[?W1Ol00005oi2hlPOo00001?n9_?LAo`0000WoTKSa00Co0000oi>ajonC/N_oTk7[1Ol0000:oi6g
l@?o00001?nDaOP3o`0000?oUmCm0_l00003oi_Po@;o00000_nNj?/2o`0000?oXngi00Co0000oj[^
n?l0003o0000;oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000/oooo
o`03o`000?oooooooooo04Kooooo0_l00007om6ma`03o`000?o8/lKo000000_oak?70_l00009olFc
b@03o`000?ng[m7o]joA00_o]joA0ol00007ok2af@03o`000?nW/=koYk3N00Co00002OnN/nL5o`00
0003oi2hl_l0003oTKSa00CoTKSa2Ol00003ohVlm`03o`000?nA^?7oTKSa00OoTKSa3?l0000:oi6g
l@Go00000onA__D01?l0003oU<Gho`000?l00003oiODo@?o00001?nKh?d01Ol0003oW^SkoikXnonN
j?_o000000?oXngi1?l0000booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool002gooooo00?o0000ooooooooool0Aoooool00ol0003odKg7om6ma`03om6ma`03o`000?o8/lKo
b;?600;ob;?60_l0000:olNca`;o00001oo5/lT00ol0003o^jg<ok^]c002o`0000co]joA0ol00004
ok2af@03o`000?nW/=koYk3N00CoYk3N1Ol00009oijci`Oo00002OnA^?4=o`0000WoTKSa00?o0000
oi6glOnA]o401_nA]o44o`0000OoTKke1Ol000000onGe?go0000o`000005oi_Po@;o00000_nNj?/2
o`0000;oXngi0_l000000onZk_So0000ooooo`0dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool002kooooo0_l00018ooooo`;o00000_oA_LL00ol0003ob;?6olRcaP05olRc
aP;o00002_o7/lL3o`0000?oaK?900?o0000ok^]c?nk[L`01Onk[L`3o`0000[o]joA1?l0000<ojN`
gPCo00001_nN/nL00ol0003oV;C[oiRdj`03oiRdj`[o00000onA^?400ol0003oTKSaoi6hl@0@oi6h
l@03o`000?nA]o7oTKOa00Go00001_nA__D5o`0000?oTlKi1?l00004oi_Po@;o00000_nNj?/2o`00
00?oXngi00Co0000oj[^n?l0003o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000om6maol000002Oo8/lH2o`00
00_oak?70_l000000oo5/lWo0000ok^]c009ok^]c0Co00002Ong[m400ol0003oYk3NojN`gP0>ojN`
gPCo000000?oW[?Wo`000?nH]>/03onH]>/Io`0000OoTKke1?l00004oi?6n@Co00001?nFcO/01?l0
003oVn3mo`000?l00003oikXn`04o`000?nSkOWoXngioj?]n@Co0000>Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo04Oooooo00?o0000
olRca_o8/lH02_o8/lH3o`0000[oak?700?o0000ok^]c?nk[L`03Onk[L`4o`0000Go]joA00Co0000
ojf]eon][MOo[JgG1Ol0000<ojN`gPSo00003_nH]>/00ol0003oTkSaoi>hl@0Aoi>hl@03o`000?nA
__GoTKke00Go00001?nCa_T4o`0000OoU/gk1Ol000000onNj?_o0000o`000002oj?]n@;o000000?o
Z^kho`000?ooool0>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000b
ooooo`03o`000?oooooooooo04Sooooo00?o0000olRca_o8/lH02oo8/lH2o`0000Soak?700?o0000
okf]bOnm[LT01?l0000=ok^]c0?o000000?o]joAo`000?n][ML02?n][ML6o`0000OoYk3N00?o0000
oijbi_nN/^H01?nN/^H;o`0000CoV;C[00?o0000oi>hlOnC^?401onC^?4<o`0000KoTlKi0ol00007
oiK=n`Co00000onJdo`5o`000003oj?]nOl0003oZ^kh00;o0000?_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo000cooooo`;o0000Boooool2o`0000_ob;?60_l00005olNc
a`03o`000?nm[LWo_Jg900Go_Jg91?l0000<ok^]c0;o00003on][ML5o`0000;oYk3N00?o0000oijb
i_nN/^H03onN/^H>o`0000_oU[[`00?o0000oi?6nOnCa_T01?l00006oiK=n`Co00001?nJdo`3o`00
00?oWmOk1Ol00011ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003Go
oooo00?o0000ooooooooool0B_ooool3o`0000[ob;?60_l00003olNca`03o`000?nm[LWo_Jg900Wo
_Jg90ol0000:ok^]c004o`000?naZm;o/J_Bok6[dPKo00002on][ML?o`0000WoW[;V00?o0000oiJj
l?nF^_002OnF^_0<o`0000KoU/gk1?l00004oi[Co0Co00000onOeo/6o`0004?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`1<ooooo`;o
00002_o8/lH2o`000003olNcaol0003o_Jg900go_Jg91?l00006ok^]c003o`000?naZm;o/J_B00Oo
/J_B1Ol00008ojf]e`03o`000?nT/>7oY;3Q00[oY;3Q5Ol0000;oi^kk`03o`000?nFcO_oU/gk00Co
00001OnJdo`3o`0000CoWmOk0ol000000onTf?[o0000o`000017ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool003Oooooo0_l0001>ooooo`;o00002_o8/lH00ol0003o_Jg9
okf]b@0Aokf]b@Co000000?o^jg<o`000?naZm803_naZm86o`0000;o[JgG00?o0000ojB`hOnT/>40
5?nT/>400ol0003oVk__oi^kk`0?oi^kk`Oo00001OnJdo`4o`0000CoWmOk0ol000001?nTf?[o0000
o`000?l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Wooooo
00?o0000ooooooooool0COooool3o`0000Oob;?600?o0000okn]b?no[LP01?l0000Aokf]b@;o0000
5OnaZm8?o`0000_oY;3Q00?o0000oi^kkonK^nl00onK^nl;o`0000KoWkg^00?o0000oi[Co?nJdo`0
0ol00005oioGn`?o00000_nTf?X2o`0004kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`00>_ooool00ol0003oooooooooo`1?ooooo`;o00001?o8/lH00ol0003o_jg8okn]
b005okn]b0Co00003_nm[LT01?l0003o]:_?okB[condZll6o`0000ko/J_B00?o0000ojR`gOnX/=d0
2_nX/=dAo`0000koWkg^1_l00005oioGn`?o00000onTf?X2o`00053ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`1@ooooo`?o000000?o
b;?6o`000?no[LP02_no[LP4o`0000[o_Jg900?o0000okB[condZll01ondZll6o`0000So/J_B00?o
0000ojR`gOnX/=d05OnX/=d00ol0003oWkg^oinmkP09oinmkPSo00001OnS_^`00ol0003oWmOkoioG
n`03o`0000?oY=Sj0ol0001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool003cooooo0_l0001Cooooo`03o`000?no[LSo_jg800ko_jg81?l00005okf]b@03o`000?ndZloo
]:_?00ko]:_?1_l00002ok6[dP03o`000?nX/=goZ;3M01GoZ;3M00Co0000oinmk_nO_NkoWkg^2?l0
000;oj>nk0Go00001?nTf?X2o`0005Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`01ooooo`00?_ooool00ol0003oooooooooo`1Cooooo`Co00003_no[LP4o`000003okf]bOl0003o
]:_?01Go]:_?7_l0000=oj>nk0Ko00001?nW`>/00ol0003oY=Sjo`000002o`0005[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`1Foooo
o`Co00003_no[LP2o`0001So]:_?00?o0000oj^`fon[/=/05On[/=/00ol0003oXkk/oj>nk007oj>n
k0Oo00002?nW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01oooo
o`00@?ooool00ol0003oooooooooo`1Iooooo`Go00002_no[LP00ol0003o]Zc>okJ/cP02okJ/cPWo
00002ondZll00ol0003oZk3Koj^`f`0Foj^`f`03o`000?nS_^coXkk/00Ko00002_nW`>/5o`0006;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00@Oooool2o`0005_ooooo
00?o0000ooooooooool01?l00006okn]b003o`000?nf[<ko]Zc>00_o]Zc>2?l00003okB[c`03o`00
0?n[/=_oZk3K00[oZk3K3ol0000;ojO0j`Go0000J?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo007ooooo0013ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01?oo
ool4o`000003okn]b?l0003o]Zc>01Go]Zc>4?l0000<ojjafP03o`000?nW`>_oYl3[00KoYl3[1Ol0
001^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`08ooooo`;o00006Onf[<h00ol0003o[[7JojjafP0G
ojjafP03o`000?nW`>_oYl3[00Go0000Loooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo007ooooo0015ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool03_ooool9o`00
00co]Zc>00?o0000ojjaf_n^/MX04On^/MX9o`0007Wooooo00?o0000ooooooooool02?ooool1o`00
007ooooo0Oooool004Kooooo0_l0001Fooooo`03o`000?oooooooooo01Oooooo2Ol00003okJ/cP03
o`000?n^/M[o[[7J00Co[[7J3Ol00023ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo0018ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08?ooool:o`00097ooooo
00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001:
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05
ooooo`7o00000Oooool1ooooo`00Boooool2o`00057ooooo00?o0000ooooooooool0_Oooool00ol0
003oooooooooo`04ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00Coooool2o`0004gooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool0057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`30
ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Cooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo0000
007ooooo001Dooooo`;o0000B?ooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`00
007ooooo001Fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0`oooool00ol0003o
ooooo`000001ooooo`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0<?ooooo
00?o0000ooooooooool00Ol0000005Sooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`34ooooo`7o00000Oooool1o`000000FOooool2o`0004?ooooo00?o0000ooooooooool0aOooool2
o`000000Foooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo0ol0000005co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`30ooooo`Co00000oooool005gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2looooo`Co00001oooool005kooooo0_l0
000nooooo`03o`000?oooooooooo0;Sooooo1?l0000;ooooo`00H?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;Cooooo1?l0000?ooooo`00HOooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo0;7ooooo0ol0000Cooooo`00H_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0:gooooo1?l0000Fooooo`00Hoooool2o`0003Wooooo00?o0000ooooooooool0
ZOooool4o`0001[ooooo001Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOoo
ool4o`0001kooooo001Vooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4
o`0002;ooooo001Wooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00009_ooool006Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Jooooo`Co0000:_ooool006[ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Fooooo`Co0000;_ooool006_ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`Co0000<_ooool006cooooo0_l0000_
ooooo`03o`000?oooooooooo08kooooo1?l0000fooooo`00K_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo08[ooooo1?l0000jooooo`00Koooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo08Oooooo0ol0000nooooo`00L?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo08?ooooo1?l00011ooooo`00LOooool2o`0002[ooooo00?o0000ooooooooool0Oooo
ool4o`0004Gooooo001cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Noooool4
o`0004Wooooo001dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`00
04gooooo001eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00057o
oooo001fooooo`;o00009Oooool00ol0003oooooooooo`1_ooooo`Co0000EOooool007Sooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000FOooool007Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000GOooool007[ooooo0_l0000Qoooo
o`03o`000?oooooooooo06?ooooo1?l0001Qooooo`00O?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo063ooooo0ol0001Uooooo`00OOooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo05cooooo1?l0001Xooooo`00O_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo05Sooooo1?l0001/ooooo`00Ooooool2o`0001cooooo00?o0000ooooooooool0E?ooool4
o`00073ooooo0021ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`00
07Cooooo0022ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool4o`0007So
oooo0023ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007cooooo
0024ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000P?ooool008Kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Q?ooool008Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0looooo`Co0000R?ooool008Sooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0iooooo`?o0000S?ooool008Wooooo0_l0000Booooo`03o`00
0?oooooooooo03Gooooo1?l0002?ooooo`00Roooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03;ooooo1?l0002Cooooo`00S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02kooooo1?l0002Gooooo`00SOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02[ooooo1?l0002Kooooo`00S_ooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`0009oo
oooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`000:?ooooo
002Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:Oooooo002B
ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Zoooool009Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000[oooool009Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Co0000/oooool009Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`?o0000]oooool009Oooooo0_l00003ooooo`03o`000?oo
oooooooo00_ooooo1?l0002jooooo`00VOooool01?l0003oooooooooool00009ooooo`Co0000__oo
ool009[ooooo00?o0000ooooool000001Oooool4o`000<;ooooo002Kooooo`;o000000?oooooo`00
0?l000000_l00036ooooo`00W?ooool2o`000<[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51726 .64565 m .51694 .65827 L .43899 .65168 L p .718 .659 .79 r
F P
0 g
s
.51694 .65827 m .51726 .64565 L .59257 .64432 L p .684 .681 .841 r
F P
0 g
s
.59257 .64432 m .59527 .65394 L .51694 .65827 L p .684 .681 .841 r
F P
0 g
s
.43899 .65168 m .44245 .63681 L .51726 .64565 L p .718 .659 .79 r
F P
0 g
s
.51758 .6332 m .51726 .64565 L .44245 .63681 L p .71 .655 .794 r
F P
0 g
s
.51726 .64565 m .51758 .6332 L .58985 .63477 L p .672 .676 .846 r
F P
0 g
s
.58985 .63477 m .59257 .64432 L .51726 .64565 L p .672 .676 .846 r
F P
0 g
s
.59527 .65394 m .59257 .64432 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44245 .63681 m .43899 .65168 L .36521 .63435 L p .755 .666 .764 r
F P
0 g
s
.44245 .63681 m .4459 .62222 L .51758 .6332 L p .71 .655 .794 r
F P
0 g
s
.5179 .62141 m .51758 .6332 L .4459 .62222 L p .698 .657 .805 r
F P
0 g
s
.51758 .6332 m .5179 .62141 L .58712 .62552 L p .657 .675 .856 r
F P
0 g
s
.58712 .62552 m .58985 .63477 L .51758 .6332 L p .657 .675 .856 r
F P
0 g
s
.36521 .63435 m .37178 .61812 L .44245 .63681 L p .755 .666 .764 r
F P
0 g
s
.4459 .62222 m .44245 .63681 L .37178 .61812 L p .749 .664 .767 r
F P
0 g
s
.59257 .64432 m .58985 .63477 L .65915 .62672 L p .637 .745 .927 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59257 .64432 L p .637 .745 .927 r
F P
0 g
s
.37178 .61812 m .37833 .60229 L .4459 .62222 L p .749 .664 .767 r
F P
0 g
s
.44935 .6086 m .4459 .62222 L .37833 .60229 L p .739 .666 .778 r
F P
0 g
s
.4459 .62222 m .44935 .6086 L .5179 .62141 L p .698 .657 .805 r
F P
0 g
s
.51822 .6107 m .5179 .62141 L .44935 .6086 L p .681 .663 .825 r
F P
0 g
s
.5179 .62141 m .51822 .6107 L .58438 .61681 L p .637 .678 .872 r
F P
0 g
s
.58438 .61681 m .58712 .62552 L .5179 .62141 L p .637 .678 .872 r
F P
0 g
s
.58985 .63477 m .58712 .62552 L .65355 .62061 L p .615 .737 .933 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58985 .63477 L p .615 .737 .933 r
F P
0 g
s
.37833 .60229 m .38485 .58768 L .44935 .6086 L p .739 .666 .778 r
F P
0 g
s
.45278 .59655 m .44935 .6086 L .38485 .58768 L p .723 .672 .8 r
F P
0 g
s
.44935 .6086 m .45278 .59655 L .51822 .6107 L p .681 .663 .825 r
F P
0 g
s
.51854 .60146 m .51822 .6107 L .45278 .59655 L p .655 .675 .857 r
F P
0 g
s
.51822 .6107 m .51854 .60146 L .58163 .60884 L p .613 .685 .894 r
F P
0 g
s
.58163 .60884 m .58438 .61681 L .51822 .6107 L p .613 .685 .894 r
F P
0 g
s
.38485 .58768 m .3913 .57504 L .45278 .59655 L p .723 .672 .8 r
F P
0 g
s
.45617 .5866 m .45278 .59655 L .3913 .57504 L p .695 .684 .835 r
F P
0 g
s
.45278 .59655 m .45617 .5866 L .51854 .60146 L p .655 .675 .857 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72996 .61132 L p .633 .869 .986 r
F P
0 g
s
.72996 .61132 m .73799 .61332 L .67023 .63881 L p .633 .869 .986 r
F P
0 g
s
.58712 .62552 m .58438 .61681 L .6479 .61445 L p .593 .729 .939 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58712 .62552 L p .593 .729 .939 r
F P
0 g
s
.51886 .59394 m .51854 .60146 L .45617 .5866 L p .613 .692 .9 r
F P
0 g
s
.51854 .60146 m .51886 .59394 L .57888 .60174 L p .581 .696 .921 r
F P
0 g
s
.57888 .60174 m .58163 .60884 L .51854 .60146 L p .581 .696 .921 r
F P
0 g
s
.37178 .61812 m .36521 .63435 L .29943 .6068 L p .793 .693 .754 r
F P
0 g
s
.3913 .57504 m .39767 .56498 L .45617 .5866 L p .695 .684 .835 r
F P
0 g
s
.45954 .5791 m .45617 .5866 L .39767 .56498 L p .643 .7 .887 r
F P
0 g
s
.45617 .5866 m .45954 .5791 L .51886 .59394 L p .613 .692 .9 r
F P
0 g
s
.29943 .6068 m .30893 .59025 L .37178 .61812 L p .793 .693 .754 r
F P
0 g
s
.37833 .60229 m .37178 .61812 L .30893 .59025 L p .789 .692 .757 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72186 .60917 L p .603 .859 .992 r
F P
0 g
s
.72186 .60917 m .72996 .61132 L .66471 .63279 L p .603 .859 .992 r
F P
0 g
s
.58438 .61681 m .58163 .60884 L .64221 .60824 L p .571 .72 .943 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58438 .61681 L p .571 .72 .943 r
F P
0 g
s
.30893 .59025 m .31839 .57418 L .37833 .60229 L p .789 .692 .757 r
F P
0 g
s
.38485 .58768 m .37833 .60229 L .31839 .57418 L p .78 .694 .769 r
F P
0 g
s
.31839 .57418 m .32776 .55952 L .38485 .58768 L p .78 .694 .769 r
F P
0 g
s
.3913 .57504 m .38485 .58768 L .32776 .55952 L p .763 .7 .792 r
F P
0 g
s
.51918 .58829 m .51886 .59394 L .45954 .5791 L p .538 .711 .951 r
F P
0 g
s
.51886 .59394 m .51918 .58829 L .57612 .59559 L p .542 .711 .949 r
F P
0 g
s
.57612 .59559 m .57888 .60174 L .51886 .59394 L p .542 .711 .949 r
F P
0 g
s
.39767 .56498 m .40396 .55797 L .45954 .5791 L p .643 .7 .887 r
F P
0 g
s
.46289 .57426 m .45954 .5791 L .40396 .55797 L p .534 .709 .952 r
F P
0 g
s
.45954 .5791 m .46289 .57426 L .51918 .58829 L p .538 .711 .951 r
F P
0 g
s
.32776 .55952 m .33701 .5471 L .3913 .57504 L p .763 .7 .792 r
F P
0 g
s
.39767 .56498 m .3913 .57504 L .33701 .5471 L p .731 .708 .829 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71366 .60663 L p .576 .839 .995 r
F P
0 g
s
.71366 .60663 m .72186 .60917 L .65915 .62672 L p .576 .839 .995 r
F P
0 g
s
.58163 .60884 m .57888 .60174 L .63648 .60198 L p .555 .713 .946 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58163 .60884 L p .555 .713 .946 r
F P
0 g
s
.33701 .5471 m .34612 .53761 L .39767 .56498 L p .731 .708 .829 r
F P
0 g
s
.40396 .55797 m .39767 .56498 L .34612 .53761 L p .669 .717 .885 r
F P
0 g
s
.5195 .58451 m .51918 .58829 L .46289 .57426 L p .404 .711 .986 r
F P
0 g
s
.51918 .58829 m .5195 .58451 L .57335 .59039 L p .497 .727 .975 r
F P
0 g
s
.57335 .59039 m .57612 .59559 L .51918 .58829 L p .497 .727 .975 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70537 .60344 L p .557 .811 .993 r
F P
0 g
s
.70537 .60344 m .71366 .60663 L .65355 .62061 L p .557 .811 .993 r
F P
0 g
s
.40396 .55797 m .41018 .55424 L .46289 .57426 L p .534 .709 .952 r
F P
0 g
s
.46622 .57209 m .46289 .57426 L .41018 .55424 L p .293 .66 .971 r
F P
0 g
s
.46289 .57426 m .46622 .57209 L .5195 .58451 L p .404 .711 .986 r
F P
0 g
s
.57888 .60174 m .57612 .59559 L .6307 .59568 L p .545 .709 .947 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57888 .60174 L p .545 .709 .947 r
F P
0 g
s
.34612 .53761 m .35507 .53154 L .40396 .55797 L p .669 .717 .885 r
F P
0 g
s
.41018 .55424 m .40396 .55797 L .35507 .53154 L p .53 .707 .952 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69697 .59942 L p .545 .778 .984 r
F P
0 g
s
.69697 .59942 m .70537 .60344 L .6479 .61445 L p .545 .778 .984 r
F P
0 g
s
.73799 .61332 m .72996 .61132 L .78449 .58056 L p .633 .952 .937 r
F P
0 g
s
.78449 .58056 m .79464 .57831 L .73799 .61332 L p .633 .952 .937 r
F P
0 g
s
.57612 .59559 m .57335 .59039 L .62488 .58932 L p .546 .71 .947 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57612 .59559 L p .546 .71 .947 r
F P
0 g
s
.51982 .58247 m .5195 .58451 L .46622 .57209 L p .194 .655 .941 r
F P
0 g
s
.5195 .58451 m .51982 .58247 L .57056 .58606 L p .452 .744 .991 r
F P
0 g
s
.57056 .58606 m .57335 .59039 L .5195 .58451 L p .452 .744 .991 r
F P
0 g
s
.41634 .55379 m .37261 .53049 L p .40142 .54547 L 0 .311 .702 r
F P
0 g
s
.41634 .55379 m .46622 .57209 L p .42641 .55941 L .293 .66 .971 r
F P
0 g
s
.46955 .57241 m .46622 .57209 L .41634 .55379 L p 0 .456 .789 r
F P
0 g
s
.42248 .55642 m .46955 .57241 L p .42704 .55754 L 0 .456 .789 r
F P
0 g
s
.41634 .55379 m .42248 .55642 L p .42704 .55754 L 0 .456 .789 r
F P
0 g
s
.42248 .55642 m .41634 .55379 L p .40142 .54547 L 0 .311 .702 r
F P
0 g
s
.41018 .55424 m .41634 .55379 L p .42641 .55941 L .293 .66 .971 r
F P
0 g
s
.41634 .55379 m .41018 .55424 L .36389 .52917 L p .218 .601 .949 r
F P
0 g
s
.37261 .53049 m .41634 .55379 L p .37914 .53633 L .218 .601 .949 r
F P
0 g
s
.36389 .52917 m .37261 .53049 L p .37914 .53633 L .218 .601 .949 r
F P
0 g
s
.37261 .53049 m .33768 .50335 L p .36291 .52183 L 0 .28 .734 r
F P
0 g
s
.38127 .53528 m .42248 .55642 L p .38268 .53573 L 0 .311 .702 r
F P
0 g
s
.37261 .53049 m .38127 .53528 L p .38268 .53573 L 0 .311 .702 r
F P
0 g
s
.38127 .53528 m .37261 .53049 L p .36291 .52183 L 0 .28 .734 r
F P
0 g
s
.34846 .51004 m .38127 .53528 L p .34651 .50982 L 0 .28 .734 r
F P
0 g
s
.33768 .50335 m .34846 .51004 L p .34651 .50982 L 0 .28 .734 r
F P
0 g
s
.34846 .51004 m .32636 .48203 L p .35095 .51032 L 0 .124 .65 r
F P
0 g
s
.38127 .53528 m .34846 .51004 L p .37947 .53471 L .526 0 0 r
F P
0 g
s
.3592 .51981 m .38992 .54302 L p .35402 .51446 L .526 0 0 r
F P
0 g
s
.34846 .51004 m .3592 .51981 L p .35402 .51446 L .526 0 0 r
F P
0 g
s
.37261 .53049 m .36389 .52917 L .32681 .50027 L p .21 .563 .937 r
F P
0 g
s
.32681 .50027 m .33768 .50335 L .37261 .53049 L p .21 .563 .937 r
F P
0 g
s
.35507 .53154 m .36389 .52917 L .41018 .55424 L p .53 .707 .952 r
F P
0 g
s
.39861 .55296 m .38992 .54302 L .3592 .51981 L p .666 .132 0 r
F P
0 g
s
.36997 .5319 m .39861 .55296 L p .36193 .52212 L .666 .132 0 r
F P
0 g
s
.3592 .51981 m .36997 .5319 L p .36193 .52212 L .666 .132 0 r
F P
0 g
s
.40739 .56415 m .39861 .55296 L .36997 .5319 L p .717 .194 0 r
F P
0 g
s
.36997 .5319 m .38085 .54529 L .40739 .56415 L p .717 .194 0 r
F P
0 g
s
.36997 .5319 m .35097 .50679 L p .37866 .54248 L 0 0 .475 r
F P
0 g
s
.38085 .54529 m .36997 .5319 L p .37866 .54248 L 0 0 .475 r
F P
0 g
s
.3592 .51981 m .33866 .49329 L p .36522 .52604 L 0 0 .529 r
F P
0 g
s
.36997 .5319 m .3592 .51981 L p .36522 .52604 L 0 0 .529 r
F P
0 g
s
.3592 .51981 m .34846 .51004 L p .35095 .51032 L 0 .124 .65 r
F P
0 g
s
.38992 .54302 m .38127 .53528 L p .37947 .53471 L .526 0 0 r
F P
0 g
s
.42248 .55642 m .38127 .53528 L p .41666 .555 L .546 0 0 r
F P
0 g
s
.42863 .56167 m .42248 .55642 L p .41666 .555 L .546 0 0 r
F P
0 g
s
.46955 .57241 m .42248 .55642 L p .46011 .57017 L .403 0 0 r
F P
0 g
s
.46622 .57209 m .46955 .57241 L p .47696 .57417 L .194 .655 .941 r
F P
0 g
s
.47289 .57484 m .46955 .57241 L p .46011 .57017 L .403 0 0 r
F P
0 g
s
.46955 .57241 m .51982 .58247 L p .47696 .57417 L .194 .655 .941 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68847 .5944 L p .542 .742 .968 r
F P
0 g
s
.68847 .5944 m .69697 .59942 L .64221 .60824 L p .542 .742 .968 r
F P
0 g
s
.25764 .55422 m .26962 .53902 L .31839 .57418 L p .828 .736 .763 r
F P
0 g
s
.31839 .57418 m .30893 .59025 L .25764 .55422 L p .828 .736 .763 r
F P
0 g
s
.32776 .55952 m .31839 .57418 L .26962 .53902 L p .818 .738 .776 r
F P
0 g
s
.26962 .53902 m .28146 .52531 L .32776 .55952 L p .818 .738 .776 r
F P
0 g
s
.33701 .5471 m .32776 .55952 L .28146 .52531 L p .799 .742 .8 r
F P
0 g
s
.24558 .56996 m .25764 .55422 L .30893 .59025 L p .831 .736 .759 r
F P
0 g
s
.30893 .59025 m .29943 .6068 L .24558 .56996 L p .831 .736 .759 r
F P
0 g
s
.72996 .61132 m .72186 .60917 L .77424 .58259 L p .597 .94 .938 r
F P
0 g
s
.77424 .58259 m .78449 .58056 L .72996 .61132 L p .597 .94 .938 r
F P
0 g
s
.28146 .52531 m .29311 .51398 L .33701 .5471 L p .799 .742 .8 r
F P
0 g
s
.34612 .53761 m .33701 .5471 L .29311 .51398 L p .761 .745 .838 r
F P
0 g
s
.57335 .59039 m .57056 .58606 L .61901 .58292 L p .559 .715 .945 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57335 .59039 L p .559 .715 .945 r
F P
0 g
s
.29311 .51398 m .30455 .50573 L .34612 .53761 L p .761 .745 .838 r
F P
0 g
s
.35507 .53154 m .34612 .53761 L .30455 .50573 L p .687 .741 .893 r
F P
0 g
s
.52014 .58189 m .51982 .58247 L .46955 .57241 L p 0 .535 .791 r
F P
0 g
s
.52014 .58189 m .47289 .57484 L p .51316 .58122 L .174 0 0 r
F P
0 g
s
.51982 .58247 m .52014 .58189 L p .52617 .58246 L .421 .764 .996 r
F P
0 g
s
.52047 .58238 m .52014 .58189 L p .51316 .58122 L .174 0 0 r
F P
0 g
s
.52014 .58189 m .56776 .58246 L p .52617 .58246 L .421 .764 .996 r
F P
0 g
s
.56776 .58246 m .57056 .58606 L .51982 .58247 L p .421 .764 .996 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67986 .58832 L p .546 .707 .945 r
F P
0 g
s
.67986 .58832 m .68847 .5944 L .63648 .60198 L p .546 .707 .945 r
F P
0 g
s
.46955 .57241 m .47289 .57484 L .52014 .58189 L p 0 .535 .791 r
F P
0 g
s
.72186 .60917 m .71366 .60663 L .76384 .58389 L p .575 .922 .959 r
F P
0 g
s
.76384 .58389 m .77424 .58259 L .72186 .60917 L p .575 .922 .959 r
F P
0 g
s
.30455 .50573 m .31577 .50107 L .35507 .53154 L p .687 .741 .893 r
F P
0 g
s
.36389 .52917 m .35507 .53154 L .31577 .50107 L p .529 .704 .951 r
F P
0 g
s
.57056 .58606 m .56776 .58246 L .61309 .57646 L p .584 .725 .94 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57056 .58606 L p .584 .725 .94 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67116 .58118 L p .556 .678 .92 r
F P
0 g
s
.67116 .58118 m .67986 .58832 L .6307 .59568 L p .556 .678 .92 r
F P
0 g
s
.71366 .60663 m .70537 .60344 L .75328 .58398 L p .567 .893 .986 r
F P
0 g
s
.75328 .58398 m .76384 .58389 L .71366 .60663 L p .567 .893 .986 r
F P
0 g
s
.31577 .50107 m .32681 .50027 L .36389 .52917 L p .529 .704 .951 r
F P
0 g
s
.56494 .57938 m .56776 .58246 L .52014 .58189 L p .421 .793 .994 r
F P
0 g
s
.52014 .58189 m .52047 .58238 L .56494 .57938 L p .421 .793 .994 r
F P
0 g
s
.42248 .55642 m .42863 .56167 L .47289 .57484 L p .403 0 0 r
F P
0 g
s
.47625 .57882 m .47289 .57484 L .42863 .56167 L p .537 0 0 r
F P
0 g
s
.47289 .57484 m .47625 .57882 L .52047 .58238 L p .174 0 0 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66237 .57306 L p .571 .656 .894 r
F P
0 g
s
.66237 .57306 m .67116 .58118 L .62488 .58932 L p .571 .656 .894 r
F P
0 g
s
.56776 .58246 m .56494 .57938 L .60713 .56996 L p .619 .739 .932 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56776 .58246 L p .619 .739 .932 r
F P
0 g
s
.70537 .60344 m .69697 .59942 L .74255 .58246 L p .562 .843 .997 r
F P
0 g
s
.74255 .58246 m .75328 .58398 L .70537 .60344 L p .562 .843 .997 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .6535 .56411 L p .59 .642 .87 r
F P
0 g
s
.6535 .56411 m .66237 .57306 L .61901 .58292 L p .59 .642 .87 r
F P
0 g
s
.69697 .59942 m .68847 .5944 L .73163 .57906 L p .554 .775 .981 r
F P
0 g
s
.73163 .57906 m .74255 .58246 L .69697 .59942 L p .554 .775 .981 r
F P
0 g
s
.52079 .58343 m .52047 .58238 L .47625 .57882 L p .213 0 0 r
F P
0 g
s
.56208 .57655 m .56494 .57938 L .52057 .58237 L p .466 .833 .992 r
F P
0 g
s
.52057 .58237 m .52047 .58238 L p .52066 .58235 L .466 .833 .992 r
F P
0 g
s
.56208 .57655 m .52057 .58237 L .52066 .58235 L .466 .833 .992 r
F
.52047 .58238 m .52079 .58343 L .56208 .57655 L p F P
0 g
s
.55919 .57368 m .56208 .57655 L .52079 .58343 L p .551 .88 .99 r
F P
0 g
s
.52079 .58343 m .52113 .58448 L .55914 .57369 L p .551 .88 .99 r
F P
0 g
s
.55914 .57369 m .55919 .57368 L p .55908 .5737 L .551 .88 .99 r
F P
0 g
s
.55908 .5737 m .52079 .58343 L .55914 .57369 L .551 .88 .99 r
F
.38127 .53528 m .38992 .54302 L .42863 .56167 L p .546 0 0 r
F P
0 g
s
.43481 .56886 m .42863 .56167 L .38992 .54302 L p .666 .114 0 r
F P
0 g
s
.42863 .56167 m .43481 .56886 L .47625 .57882 L p .537 0 0 r
F P
0 g
s
.56494 .57938 m .56208 .57655 L .60112 .5634 L p .66 .753 .919 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56494 .57938 L p .66 .753 .919 r
F P
0 g
s
.79464 .57831 m .78449 .58056 L .82447 .54169 L p .721 .989 .855 r
F P
0 g
s
.82447 .54169 m .83625 .53514 L .79464 .57831 L p .721 .989 .855 r
F P
0 g
s
.47965 .58366 m .47625 .57882 L .43481 .56886 L p .574 .015 0 r
F P
0 g
s
.47625 .57882 m .47965 .58366 L .52079 .58343 L p .213 0 0 r
F P
0 g
s
.24919 .48666 m .26266 .47728 L .29311 .51398 L p .827 .796 .823 r
F P
0 g
s
.29311 .51398 m .28146 .52531 L .24919 .48666 L p .827 .796 .823 r
F P
0 g
s
.30455 .50573 m .29311 .51398 L .26266 .47728 L p .78 .791 .861 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64458 .55457 L p .613 .636 .849 r
F P
0 g
s
.64458 .55457 m .6535 .56411 L .61309 .57646 L p .613 .636 .849 r
F P
0 g
s
.23548 .49837 m .24919 .48666 L .28146 .52531 L p .851 .796 .797 r
F P
0 g
s
.28146 .52531 m .26962 .53902 L .23548 .49837 L p .851 .796 .797 r
F P
0 g
s
.68847 .5944 m .67986 .58832 L .72053 .57361 L p .545 .704 .944 r
F P
0 g
s
.72053 .57361 m .73163 .57906 L .68847 .5944 L p .545 .704 .944 r
F P
0 g
s
.26266 .47728 m .27586 .47092 L .30455 .50573 L p .78 .791 .861 r
F P
0 g
s
.31577 .50107 m .30455 .50573 L .27586 .47092 L p .693 .768 .909 r
F P
0 g
s
.22159 .51158 m .23548 .49837 L .26962 .53902 L p .863 .795 .782 r
F P
0 g
s
.26962 .53902 m .25764 .55422 L .22159 .51158 L p .863 .795 .782 r
F P
0 g
s
.20758 .52532 m .22159 .51158 L .25764 .55422 L p .866 .793 .777 r
F P
0 g
s
.25764 .55422 m .24558 .56996 L .20758 .52532 L p .866 .793 .777 r
F P
0 g
s
.27586 .47092 m .2888 .46809 L .31577 .50107 L p .693 .768 .909 r
F P
0 g
s
.32681 .50027 m .31577 .50107 L .2888 .46809 L p .53 .702 .949 r
F P
0 g
s
.78449 .58056 m .77424 .58259 L .81256 .54794 L p .693 .982 .858 r
F P
0 g
s
.81256 .54794 m .82447 .54169 L .78449 .58056 L p .693 .982 .858 r
F P
0 g
s
.67986 .58832 m .67116 .58118 L .70928 .56614 L p .538 .644 .902 r
F P
0 g
s
.70928 .56614 m .72053 .57361 L .67986 .58832 L p .538 .644 .902 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .6356 .5447 L p .639 .637 .831 r
F P
0 g
s
.6356 .5447 m .64458 .55457 L .60713 .56996 L p .639 .637 .831 r
F P
0 g
s
.52113 .58448 m .52079 .58343 L .47965 .58366 L p .158 0 0 r
F P
0 g
s
.56208 .57655 m .55919 .57368 L .59506 .55679 L p .704 .766 .9 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56208 .57655 L p .704 .766 .9 r
F P
0 g
s
.2888 .46809 m .30149 .46904 L .32681 .50027 L p .53 .702 .949 r
F P
0 g
s
.33768 .50335 m .32681 .50027 L .30149 .46904 L p .262 .554 .93 r
F P
0 g
s
.38992 .54302 m .39861 .55296 L .43481 .56886 L p .666 .114 0 r
F P
0 g
s
.44107 .57715 m .43481 .56886 L .39861 .55296 L p .704 .17 0 r
F P
0 g
s
.43481 .56886 m .44107 .57715 L .47965 .58366 L p .574 .015 0 r
F P
0 g
s
.67116 .58118 m .66237 .57306 L .69791 .55681 L p .538 .599 .863 r
F P
0 g
s
.69791 .55681 m .70928 .56614 L .67116 .58118 L p .538 .599 .863 r
F P
0 g
s
.77424 .58259 m .76384 .58389 L .80047 .55316 L p .676 .975 .894 r
F P
0 g
s
.80047 .55316 m .81256 .54794 L .77424 .58259 L p .676 .975 .894 r
F P
0 g
s
.48311 .58854 m .47965 .58366 L .44107 .57715 L p .558 .003 0 r
F P
0 g
s
.47965 .58366 m .48311 .58854 L .52113 .58448 L p .158 0 0 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .6266 .5348 L p .668 .643 .816 r
F P
0 g
s
.6266 .5348 m .6356 .5447 L .60112 .5634 L p .668 .643 .816 r
F P
0 g
s
.66237 .57306 m .6535 .56411 L .68644 .54594 L p .544 .57 .832 r
F P
0 g
s
.68644 .54594 m .69791 .55681 L .66237 .57306 L p .544 .57 .832 r
F P
0 g
s
.30149 .46904 m .31399 .47377 L .33768 .50335 L p .262 .554 .93 r
F P
0 g
s
.34846 .51004 m .33768 .50335 L .31399 .47377 L p 0 .332 .811 r
F P
0 g
s
.55627 .57045 m .55919 .57368 L .52113 .58448 L p .654 .916 .978 r
F P
0 g
s
.55919 .57368 m .55627 .57045 L .58896 .55013 L p .746 .776 .878 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55919 .57368 L p .746 .776 .878 r
F P
0 g
s
.6535 .56411 m .64458 .55457 L .67492 .53397 L p .557 .555 .808 r
F P
0 g
s
.67492 .53397 m .68644 .54594 L .6535 .56411 L p .557 .555 .808 r
F P
0 g
s
.76384 .58389 m .75328 .58398 L .78816 .55666 L p .661 .954 .948 r
F P
0 g
s
.78816 .55666 m .80047 .55316 L .76384 .58389 L p .661 .954 .948 r
F P
0 g
s
.52146 .58491 m .52113 .58448 L .48311 .58854 L p .001 0 0 r
F P
0 g
s
.52113 .58448 m .52146 .58491 L .55627 .57045 L p .654 .916 .978 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61756 .52518 L p .699 .655 .803 r
F P
0 g
s
.61756 .52518 m .6266 .5348 L .59506 .55679 L p .699 .655 .803 r
F P
0 g
s
.64458 .55457 m .6356 .5447 L .66337 .52144 L p .575 .551 .79 r
F P
0 g
s
.66337 .52144 m .67492 .53397 L .64458 .55457 L p .575 .551 .79 r
F P
0 g
s
.39861 .55296 m .40739 .56415 L .44107 .57715 L p .704 .17 0 r
F P
0 g
s
.44743 .58553 m .44107 .57715 L .40739 .56415 L p .7 .169 0 r
F P
0 g
s
.44107 .57715 m .44743 .58553 L .48311 .58854 L p .558 .003 0 r
F P
0 g
s
.75328 .58398 m .74255 .58246 L .7756 .55789 L p .634 .897 .986 r
F P
0 g
s
.7756 .55789 m .78816 .55666 L .75328 .58398 L p .634 .897 .986 r
F P
0 g
s
.6356 .5447 m .6266 .5348 L .65183 .50894 L p .6 .557 .778 r
F P
0 g
s
.65183 .50894 m .66337 .52144 L .6356 .5447 L p .6 .557 .778 r
F P
0 g
s
.31399 .47377 m .32636 .48203 L .34846 .51004 L p 0 .332 .811 r
F P
0 g
s
.48663 .5926 m .48311 .58854 L .44743 .58553 L p .487 0 0 r
F P
0 g
s
.48311 .58854 m .48663 .5926 L .52146 .58491 L p .001 0 0 r
F P
0 g
s
.55331 .56656 m .55627 .57045 L .52146 .58491 L p .748 .928 .948 r
F P
0 g
s
.55627 .57045 m .55331 .56656 L .5828 .54342 L p .782 .783 .853 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55627 .57045 L p .782 .783 .853 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60851 .51613 L p .73 .67 .791 r
F P
0 g
s
.60851 .51613 m .61756 .52518 L .58896 .55013 L p .73 .67 .791 r
F P
0 g
s
.6266 .5348 m .61756 .52518 L .64031 .49706 L p .629 .571 .77 r
F P
0 g
s
.64031 .49706 m .65183 .50894 L .6266 .5348 L p .629 .571 .77 r
F P
0 g
s
.74255 .58246 m .73163 .57906 L .76278 .55641 L p .59 .804 .981 r
F P
0 g
s
.76278 .55641 m .7756 .55789 L .74255 .58246 L p .59 .804 .981 r
F P
0 g
s
.52181 .58413 m .52146 .58491 L .48663 .5926 L p .267 .774 .787 r
F P
0 g
s
.52146 .58491 m .52181 .58413 L .55331 .56656 L p .748 .928 .948 r
F P
0 g
s
.61756 .52518 m .60851 .51613 L .62883 .48636 L p .663 .591 .764 r
F P
0 g
s
.62883 .48636 m .64031 .49706 L .61756 .52518 L p .663 .591 .764 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55331 .56656 L p .813 .786 .827 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59943 .50791 L p .761 .687 .78 r
F P
0 g
s
.59943 .50791 m .60851 .51613 L .5828 .54342 L p .761 .687 .78 r
F P
0 g
s
.73163 .57906 m .72053 .57361 L .74973 .55203 L p .542 .702 .944 r
F P
0 g
s
.74973 .55203 m .76278 .55641 L .73163 .57906 L p .542 .702 .944 r
F P
0 g
s
.55031 .56174 m .55331 .56656 L .52181 .58413 L p .816 .917 .905 r
F P
0 g
s
.55331 .56656 m .55031 .56174 L .5766 .53665 L p .813 .786 .827 r
F P
0 g
s
.60851 .51613 m .59943 .50791 L .61739 .47732 L p .7 .616 .76 r
F P
0 g
s
.61739 .47732 m .62883 .48636 L .60851 .51613 L p .7 .616 .76 r
F P
0 g
s
.32636 .48203 m .33866 .49329 L .3592 .51981 L p 0 .124 .65 r
F P
0 g
s
.24844 .43899 m .26264 .43514 L .27586 .47092 L p .779 .839 .897 r
F P
0 g
s
.27586 .47092 m .26266 .47728 L .24844 .43899 L p .779 .839 .897 r
F P
0 g
s
.2888 .46809 m .27586 .47092 L .26264 .43514 L p .682 .791 .932 r
F P
0 g
s
.72053 .57361 m .70928 .56614 L .73648 .54476 L p .502 .614 .896 r
F P
0 g
s
.73648 .54476 m .74973 .55203 L .72053 .57361 L p .502 .614 .896 r
F P
0 g
s
.23395 .4456 m .24844 .43899 L .26266 .47728 L p .837 .859 .861 r
F P
0 g
s
.26266 .47728 m .24919 .48666 L .23395 .4456 L p .837 .859 .861 r
F P
0 g
s
.40739 .56415 m .41632 .57548 L .44743 .58553 L p .7 .169 0 r
F P
0 g
s
.45392 .59294 m .44743 .58553 L .41632 .57548 L p .658 .112 0 r
F P
0 g
s
.44743 .58553 m .45392 .59294 L .48663 .5926 L p .487 0 0 r
F P
0 g
s
.26264 .43514 m .27656 .43449 L .2888 .46809 L p .682 .791 .932 r
F P
0 g
s
.30149 .46904 m .2888 .46809 L .27656 .43449 L p .532 .701 .947 r
F P
0 g
s
.49023 .59499 m .48663 .5926 L .45392 .59294 L p .322 0 0 r
F P
0 g
s
.48663 .5926 m .49023 .59499 L .52181 .58413 L p .267 .774 .787 r
F P
0 g
s
.70928 .56614 m .69791 .55681 L .72307 .53486 L p .477 .55 .852 r
F P
0 g
s
.72307 .53486 m .73648 .54476 L .70928 .56614 L p .477 .55 .852 r
F P
0 g
s
.2192 .45435 m .23395 .4456 L .24919 .48666 L p .868 .865 .833 r
F P
0 g
s
.24919 .48666 m .23548 .49837 L .2192 .45435 L p .868 .865 .833 r
F P
0 g
s
.59033 .50073 m .59943 .50791 L .5766 .53665 L p .791 .704 .768 r
F P
0 g
s
.59943 .50791 m .59033 .50073 L .60598 .47032 L p .738 .644 .756 r
F P
0 g
s
.60598 .47032 m .61739 .47732 L .59943 .50791 L p .738 .644 .756 r
F P
0 g
s
.41632 .57548 m .40739 .56415 L .38085 .54529 L p .719 .195 0 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55031 .56174 L p .839 .787 .802 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59033 .50073 L p .791 .704 .768 r
F P
0 g
s
.69791 .55681 m .68644 .54594 L .70957 .52281 L p .467 .508 .817 r
F P
0 g
s
.70957 .52281 m .72307 .53486 L .69791 .55681 L p .467 .508 .817 r
F P
0 g
s
.66337 .52144 m .65183 .50894 L .66906 .48073 L p .508 .485 .767 r
F P
0 g
s
.65183 .50894 m .64031 .49706 L .65571 .46746 L p .541 .502 .762 r
F P
0 g
s
.65571 .46746 m .66906 .48073 L .65183 .50894 L p .541 .502 .762 r
F P
0 g
s
.64031 .49706 m .62883 .48636 L .64247 .45591 L p .582 .529 .761 r
F P
0 g
s
.64247 .45591 m .65571 .46746 L .64031 .49706 L p .582 .529 .761 r
F P
0 g
s
.67492 .53397 m .66337 .52144 L .68252 .49493 L p .483 .479 .776 r
F P
0 g
s
.66906 .48073 m .68252 .49493 L .66337 .52144 L p .508 .485 .767 r
F P
0 g
s
.52216 .58161 m .52181 .58413 L .49023 .59499 L p .57 .937 .908 r
F P
0 g
s
.52181 .58413 m .52216 .58161 L .55031 .56174 L p .816 .917 .905 r
F P
0 g
s
.68644 .54594 m .67492 .53397 L .69604 .50924 L p .469 .486 .793 r
F P
0 g
s
.69604 .50924 m .70957 .52281 L .68644 .54594 L p .469 .486 .793 r
F P
0 g
s
.68252 .49493 m .69604 .50924 L .67492 .53397 L p .483 .479 .776 r
F P
0 g
s
.62883 .48636 m .61739 .47732 L .62934 .44674 L p .63 .563 .76 r
F P
0 g
s
.62934 .44674 m .64247 .45591 L .62883 .48636 L p .63 .563 .76 r
F P
0 g
s
.27656 .43449 m .29021 .43727 L .30149 .46904 L p .532 .701 .947 r
F P
0 g
s
.31399 .47377 m .30149 .46904 L .29021 .43727 L p .34 .564 .92 r
F P
0 g
s
.83625 .53514 m .82447 .54169 L .84625 .49649 L p .852 .995 .826 r
F P
0 g
s
.84625 .49649 m .85906 .48583 L .83625 .53514 L p .852 .995 .826 r
F P
0 g
s
.20422 .46445 m .2192 .45435 L .23548 .49837 L p .883 .865 .816 r
F P
0 g
s
.23548 .49837 m .22159 .51158 L .20422 .46445 L p .883 .865 .816 r
F P
0 g
s
.61739 .47732 m .60598 .47032 L .61632 .44048 L p .681 .601 .76 r
F P
0 g
s
.61632 .44048 m .62934 .44674 L .61739 .47732 L p .681 .601 .76 r
F P
0 g
s
.54727 .55577 m .55031 .56174 L .52216 .58161 L p .858 .892 .859 r
F P
0 g
s
.55031 .56174 m .54727 .55577 L .57035 .52982 L p .839 .787 .802 r
F P
0 g
s
.5812 .49471 m .59033 .50073 L .57035 .52982 L p .819 .722 .757 r
F P
0 g
s
.59033 .50073 m .5812 .49471 L .59459 .46561 L p .776 .674 .75 r
F P
0 g
s
.59459 .46561 m .60598 .47032 L .59033 .50073 L p .776 .674 .75 r
F P
0 g
s
.60598 .47032 m .59459 .46561 L .60338 .43746 L p .733 .642 .757 r
F P
0 g
s
.60338 .43746 m .61632 .44048 L .60598 .47032 L p .733 .642 .757 r
F P
0 g
s
.29021 .43727 m .30364 .44349 L .31399 .47377 L p .34 .564 .92 r
F P
0 g
s
.32636 .48203 m .31399 .47377 L .30364 .44349 L p .148 .41 .854 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54727 .55577 L p .858 .786 .779 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .5812 .49471 L p .819 .722 .757 r
F P
0 g
s
.18911 .47507 m .20422 .46445 L .22159 .51158 L p .887 .862 .81 r
F P
0 g
s
.22159 .51158 m .20758 .52532 L .18911 .47507 L p .887 .862 .81 r
F P
0 g
s
.33866 .49329 m .35097 .50679 L .36997 .5319 L p 0 0 .529 r
F P
0 g
s
.82447 .54169 m .81256 .54794 L .83332 .50678 L p .839 .997 .834 r
F P
0 g
s
.83332 .50678 m .84625 .49649 L .82447 .54169 L p .839 .997 .834 r
F P
0 g
s
.58318 .46329 m .59459 .46561 L .5812 .49471 L p .812 .702 .744 r
F P
0 g
s
.59459 .46561 m .58318 .46329 L .59048 .43782 L p .782 .68 .751 r
F P
0 g
s
.59048 .43782 m .60338 .43746 L .59459 .46561 L p .782 .68 .751 r
F P
0 g
s
.64247 .45591 m .62934 .44674 L .63446 .41811 L p .544 .521 .78 r
F P
0 g
s
.62934 .44674 m .61632 .44048 L .62066 .4131 L p .619 .575 .782 r
F P
0 g
s
.62066 .4131 m .63446 .41811 L .62934 .44674 L p .619 .575 .782 r
F P
0 g
s
.57202 .48992 m .5812 .49471 L .56404 .52294 L p .844 .737 .746 r
F P
0 g
s
.5812 .49471 m .57202 .48992 L .58318 .46329 L p .812 .702 .744 r
F P
0 g
s
.61632 .44048 m .60338 .43746 L .607 .41205 L p .692 .628 .78 r
F P
0 g
s
.607 .41205 m .62066 .4131 L .61632 .44048 L p .692 .628 .78 r
F P
0 g
s
.45392 .59294 m .46056 .59833 L .49023 .59499 L p .322 0 0 r
F P
0 g
s
.4939 .59493 m .49023 .59499 L .46056 .59833 L p 0 0 0 r
F P
0 g
s
.49023 .59499 m .4939 .59493 L .52216 .58161 L p .57 .937 .908 r
F P
0 g
s
.41632 .57548 m .42544 .58575 L .45392 .59294 L p .658 .112 0 r
F P
0 g
s
.46056 .59833 m .45392 .59294 L .42544 .58575 L p .55 0 0 r
F P
0 g
s
.65571 .46746 m .64247 .45591 L .64843 .42669 L p .476 .473 .775 r
F P
0 g
s
.63446 .41811 m .64843 .42669 L .64247 .45591 L p .544 .521 .78 r
F P
0 g
s
.52251 .5769 m .52216 .58161 L .4939 .59493 L p .772 .974 .919 r
F P
0 g
s
.52216 .58161 m .52251 .5769 L .54727 .55577 L p .858 .892 .859 r
F P
0 g
s
.60338 .43746 m .59048 .43782 L .59343 .41512 L p .758 .676 .77 r
F P
0 g
s
.59343 .41512 m .607 .41205 L .60338 .43746 L p .758 .676 .77 r
F P
0 g
s
.54419 .5485 m .54727 .55577 L .52251 .5769 L p .881 .863 .817 r
F P
0 g
s
.54727 .55577 m .54419 .5485 L .56404 .52294 L p .858 .786 .779 r
F P
0 g
s
.38085 .54529 m .39188 .55883 L .41632 .57548 L p .719 .195 0 r
F P
0 g
s
.42544 .58575 m .41632 .57548 L .39188 .55883 L p .674 .136 0 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54419 .5485 L p .873 .784 .759 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57202 .48992 L p .844 .737 .746 r
F P
0 g
s
.30364 .44349 m .31692 .45289 L .32636 .48203 L p .148 .41 .854 r
F P
0 g
s
.33866 .49329 m .32636 .48203 L .31692 .45289 L p .002 .28 .78 r
F P
0 g
s
.66906 .48073 m .65571 .46746 L .6626 .43822 L p .418 .435 .771 r
F P
0 g
s
.64843 .42669 m .6626 .43822 L .65571 .46746 L p .476 .473 .775 r
F P
0 g
s
.57174 .46331 m .58318 .46329 L .57202 .48992 L p .843 .727 .736 r
F P
0 g
s
.58318 .46329 m .57174 .46331 L .57757 .44148 L p .825 .714 .742 r
F P
0 g
s
.57757 .44148 m .59048 .43782 L .58318 .46329 L p .825 .714 .742 r
F P
0 g
s
.81256 .54794 m .80047 .55316 L .82018 .51579 L p .819 .992 .868 r
F P
0 g
s
.82018 .51579 m .83332 .50678 L .81256 .54794 L p .819 .992 .868 r
F P
0 g
s
.59048 .43782 m .57757 .44148 L .5799 .42222 L p .813 .714 .756 r
F P
0 g
s
.5799 .42222 m .59343 .41512 L .59048 .43782 L p .813 .714 .756 r
F P
0 g
s
.56279 .48631 m .57202 .48992 L .55769 .51601 L p .865 .751 .736 r
F P
0 g
s
.57202 .48992 m .56279 .48631 L .57174 .46331 L p .843 .727 .736 r
F P
0 g
s
.62066 .4131 m .607 .41205 L .60516 .39101 L p .656 .639 .822 r
F P
0 g
s
.607 .41205 m .59343 .41512 L .59183 .39666 L p .745 .693 .802 r
F P
0 g
s
.59183 .39666 m .60516 .39101 L .607 .41205 L p .745 .693 .802 r
F P
0 g
s
.68252 .49493 m .66906 .48073 L .67696 .4519 L p .374 .411 .77 r
F P
0 g
s
.6626 .43822 m .67696 .4519 L .66906 .48073 L p .418 .435 .771 r
F P
0 g
s
.63446 .41811 m .62066 .4131 L .61863 .38994 L p .546 .569 .829 r
F P
0 g
s
.60516 .39101 m .61863 .38994 L .62066 .4131 L p .656 .639 .822 r
F P
0 g
s
.59343 .41512 m .5799 .42222 L .57856 .40679 L p .81 .731 .776 r
F P
0 g
s
.57856 .40679 m .59183 .39666 L .59343 .41512 L p .81 .731 .776 r
F P
0 g
s
.35097 .50679 m .36338 .52156 L .38085 .54529 L p 0 0 .475 r
F P
0 g
s
.39188 .55883 m .38085 .54529 L .36338 .52156 L p 0 0 .489 r
F P
0 g
s
.64843 .42669 m .63446 .41811 L .63229 .39329 L p .426 .489 .822 r
F P
0 g
s
.61863 .38994 m .63229 .39329 L .63446 .41811 L p .546 .569 .829 r
F P
0 g
s
.52251 .5769 m .52287 .56973 L .54419 .5485 L p .881 .863 .817 r
F P
0 g
s
.54108 .53988 m .54419 .5485 L .52287 .56973 L p .893 .837 .783 r
F P
0 g
s
.54419 .5485 m .54108 .53988 L .55769 .51601 L p .873 .784 .759 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54108 .53988 L p .885 .782 .743 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56279 .48631 L p .865 .751 .736 r
F P
0 g
s
.80047 .55316 m .78816 .55666 L .80677 .52269 L p .784 .97 .918 r
F P
0 g
s
.80677 .52269 m .82018 .51579 L .80047 .55316 L p .784 .97 .918 r
F P
0 g
s
.56024 .46545 m .57174 .46331 L .56279 .48631 L p .869 .748 .727 r
F P
0 g
s
.57174 .46331 m .56024 .46545 L .56462 .44815 L p .859 .741 .732 r
F P
0 g
s
.56462 .44815 m .57757 .44148 L .57174 .46331 L p .859 .741 .732 r
F P
0 g
s
.4939 .59493 m .49765 .5918 L .52251 .5769 L p .772 .974 .919 r
F P
0 g
s
.52287 .56973 m .52251 .5769 L .49765 .5918 L p .861 .935 .87 r
F P
0 g
s
.57757 .44148 m .56462 .44815 L .56635 .433 L p .853 .743 .74 r
F P
0 g
s
.56635 .433 m .5799 .42222 L .57757 .44148 L p .853 .743 .74 r
F P
0 g
s
.69604 .50924 m .68252 .49493 L .6915 .46676 L p .348 .403 .777 r
F P
0 g
s
.67696 .4519 m .6915 .46676 L .68252 .49493 L p .374 .411 .77 r
F P
0 g
s
.46056 .59833 m .46736 .60073 L .4939 .59493 L p 0 0 0 r
F P
0 g
s
.49765 .5918 m .4939 .59493 L .46736 .60073 L p .494 .901 .911 r
F P
0 g
s
.31692 .45289 m .3301 .465 L .33866 .49329 L p .002 .28 .78 r
F P
0 g
s
.35097 .50679 m .33866 .49329 L .3301 .465 L p 0 .198 .726 r
F P
0 g
s
.5535 .48379 m .56279 .48631 L .55128 .50901 L p .881 .762 .726 r
F P
0 g
s
.56279 .48631 m .5535 .48379 L .56024 .46545 L p .869 .748 .727 r
F P
0 g
s
.5799 .42222 m .56635 .433 L .56531 .421 L p .855 .754 .751 r
F P
0 g
s
.56531 .421 m .57856 .40679 L .5799 .42222 L p .855 .754 .751 r
F P
0 g
s
.42544 .58575 m .43476 .59377 L .46056 .59833 L p .55 0 0 r
F P
0 g
s
.46736 .60073 m .46056 .59833 L .43476 .59377 L p .283 0 0 r
F P
0 g
s
.6626 .43822 m .64843 .42669 L .64617 .40062 L p .313 .413 .804 r
F P
0 g
s
.63229 .39329 m .64617 .40062 L .64843 .42669 L p .426 .489 .822 r
F P
0 g
s
.70957 .52281 m .69604 .50924 L .70617 .48181 L p .34 .414 .792 r
F P
0 g
s
.6915 .46676 m .70617 .48181 L .69604 .50924 L p .348 .403 .777 r
F P
0 g
s
.61863 .38994 m .60516 .39101 L .59792 .37577 L p .632 .689 .885 r
F P
0 g
s
.60516 .39101 m .59183 .39666 L .58572 .38369 L p .749 .739 .844 r
F P
0 g
s
.58572 .38369 m .59792 .37577 L .60516 .39101 L p .749 .739 .844 r
F P
0 g
s
.59183 .39666 m .57856 .40679 L .57362 .39622 L p .82 .763 .799 r
F P
0 g
s
.57362 .39622 m .58572 .38369 L .59183 .39666 L p .82 .763 .799 r
F P
0 g
s
.78816 .55666 m .7756 .55789 L .79307 .52674 L p .724 .913 .959 r
F P
0 g
s
.79307 .52674 m .80677 .52269 L .78816 .55666 L p .724 .913 .959 r
F P
0 g
s
.39188 .55883 m .40314 .57129 L .42544 .58575 L p .674 .136 0 r
F P
0 g
s
.43476 .59377 m .42544 .58575 L .40314 .57129 L p .547 0 0 r
F P
0 g
s
.52287 .56973 m .52324 .55998 L .54108 .53988 L p .893 .837 .783 r
F P
0 g
s
.53793 .52994 m .54108 .53988 L .52324 .55998 L p .899 .815 .756 r
F P
0 g
s
.54108 .53988 m .53793 .52994 L .55128 .50901 L p .885 .782 .743 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53793 .52994 L p .893 .78 .729 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .5535 .48379 L p .881 .762 .726 r
F P
0 g
s
.63229 .39329 m .61863 .38994 L .61026 .37259 L p .459 .598 .903 r
F P
0 g
s
.59792 .37577 m .61026 .37259 L .61863 .38994 L p .632 .689 .885 r
F P
0 g
s
.55158 .45733 m .56462 .44815 L .56024 .46545 L p .883 .76 .721 r
F P
0 g
s
.56462 .44815 m .55158 .45733 L .55273 .44687 L p .881 .761 .725 r
F P
0 g
s
.55273 .44687 m .56635 .433 L .56462 .44815 L p .881 .761 .725 r
F P
0 g
s
.57856 .40679 m .56531 .421 L .56156 .41296 L p .862 .772 .761 r
F P
0 g
s
.56156 .41296 m .57362 .39622 L .57856 .40679 L p .862 .772 .761 r
F P
0 g
s
.54865 .46936 m .56024 .46545 L .5535 .48379 L p .888 .763 .718 r
F P
0 g
s
.56024 .46545 m .54865 .46936 L .55158 .45733 L p .883 .76 .721 r
F P
0 g
s
.72307 .53486 m .70957 .52281 L .72091 .49599 L p .353 .448 .818 r
F P
0 g
s
.70617 .48181 m .72091 .49599 L .70957 .52281 L p .34 .414 .792 r
F P
0 g
s
.49765 .5918 m .50146 .58518 L .52287 .56973 L p .861 .935 .87 r
F P
0 g
s
.52324 .55998 m .52287 .56973 L .50146 .58518 L p .893 .885 .817 r
F P
0 g
s
.56635 .433 m .55273 .44687 L .55202 .43865 L p .883 .767 .73 r
F P
0 g
s
.55202 .43865 m .56531 .421 L .56635 .433 L p .883 .767 .73 r
F P
0 g
s
.7756 .55789 m .76278 .55641 L .77907 .52744 L p .636 .817 .97 r
F P
0 g
s
.77907 .52744 m .79307 .52674 L .7756 .55789 L p .636 .817 .97 r
F P
0 g
s
.67696 .4519 m .6626 .43822 L .6603 .41126 L p .222 .352 .785 r
F P
0 g
s
.64617 .40062 m .6603 .41126 L .6626 .43822 L p .313 .413 .804 r
F P
0 g
s
.54413 .48215 m .5535 .48379 L .54482 .50197 L p .893 .769 .718 r
F P
0 g
s
.5535 .48379 m .54413 .48215 L .54865 .46936 L p .888 .763 .718 r
F P
0 g
s
.73648 .54476 m .72307 .53486 L .73564 .50834 L p .39 .506 .855 r
F P
0 g
s
.72091 .49599 m .73564 .50834 L .72307 .53486 L p .353 .448 .818 r
F P
0 g
s
.46736 .60073 m .4743 .59937 L .49765 .5918 L p .494 .901 .911 r
F P
0 g
s
.50146 .58518 m .49765 .5918 L .4743 .59937 L p .774 .96 .929 r
F P
0 g
s
.3301 .465 m .34328 .47912 L .35097 .50679 L p 0 .198 .726 r
F P
0 g
s
.36338 .52156 m .35097 .50679 L .34328 .47912 L p 0 .17 .704 r
F P
0 g
s
.64617 .40062 m .63229 .39329 L .62282 .37398 L p .249 .47 .877 r
F P
0 g
s
.61026 .37259 m .62282 .37398 L .63229 .39329 L p .459 .598 .903 r
F P
0 g
s
.36338 .52156 m .37594 .53646 L .39188 .55883 L p 0 0 .489 r
F P
0 g
s
.40314 .57129 m .39188 .55883 L .37594 .53646 L p 0 .023 .569 r
F P
0 g
s
.76278 .55641 m .74973 .55203 L .7648 .52454 L p .538 .701 .945 r
F P
0 g
s
.7648 .52454 m .77907 .52744 L .76278 .55641 L p .538 .701 .945 r
F P
0 g
s
.56531 .421 m .55202 .43865 L .54948 .43323 L p .887 .776 .733 r
F P
0 g
s
.54948 .43323 m .56156 .41296 L .56531 .421 L p .887 .776 .733 r
F P
0 g
s
.74973 .55203 m .73648 .54476 L .7503 .51806 L p .452 .592 .901 r
F P
0 g
s
.73564 .50834 m .7503 .51806 L .73648 .54476 L p .39 .506 .855 r
F P
0 g
s
.7503 .51806 m .7648 .52454 L .74973 .55203 L p .452 .592 .901 r
F P
0 g
s
.52324 .55998 m .52361 .5477 L .53793 .52994 L p .899 .815 .756 r
F P
0 g
s
.53476 .51879 m .53793 .52994 L .52361 .5477 L p .902 .799 .736 r
F P
0 g
s
.53793 .52994 m .53476 .51879 L .54482 .50197 L p .893 .78 .729 r
F P
0 g
s
.59792 .37577 m .58572 .38369 L .57545 .37712 L p .775 .809 .88 r
F P
0 g
s
.58572 .38369 m .57362 .39622 L .56536 .39125 L p .842 .804 .814 r
F P
0 g
s
.56536 .39125 m .57545 .37712 L .58572 .38369 L p .842 .804 .814 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53476 .51879 L p .899 .778 .719 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54413 .48215 L p .893 .769 .718 r
F P
0 g
s
.57362 .39622 m .56156 .41296 L .55531 .40943 L p .875 .794 .766 r
F P
0 g
s
.55531 .40943 m .56536 .39125 L .57362 .39622 L p .875 .794 .766 r
F P
0 g
s
.43476 .59377 m .4443 .59846 L .46736 .60073 L p .283 0 0 r
F P
0 g
s
.4743 .59937 m .46736 .60073 L .4443 .59846 L p .238 .737 .906 r
F P
0 g
s
.61026 .37259 m .59792 .37577 L .58564 .36743 L p .638 .784 .952 r
F P
0 g
s
.57545 .37712 m .58564 .36743 L .59792 .37577 L p .775 .809 .88 r
F P
0 g
s
.50146 .58518 m .50533 .5749 L .52324 .55998 L p .893 .885 .817 r
F P
0 g
s
.52361 .5477 m .52324 .55998 L .50533 .5749 L p .903 .844 .776 r
F P
0 g
s
.53842 .46838 m .55158 .45733 L .54865 .46936 L p .899 .771 .712 r
F P
0 g
s
.55158 .45733 m .53842 .46838 L .53899 .46302 L p .898 .772 .714 r
F P
0 g
s
.53899 .46302 m .55273 .44687 L .55158 .45733 L p .898 .772 .714 r
F P
0 g
s
.53695 .47456 m .54865 .46936 L .54413 .48215 L p .9 .772 .711 r
F P
0 g
s
.54865 .46936 m .53695 .47456 L .53842 .46838 L p .899 .771 .712 r
F P
0 g
s
.6915 .46676 m .67696 .4519 L .67469 .42432 L p .16 .315 .772 r
F P
0 g
s
.6603 .41126 m .67469 .42432 L .67696 .4519 L p .222 .352 .785 r
F P
0 g
s
.55273 .44687 m .53899 .46302 L .53863 .45883 L p .899 .774 .715 r
F P
0 g
s
.53863 .45883 m .55202 .43865 L .55273 .44687 L p .899 .774 .715 r
F P
0 g
s
.26691 .40066 m .28089 .40242 L .27656 .43449 L p .653 .803 .955 r
F P
0 g
s
.27656 .43449 m .26264 .43514 L .26691 .40066 L p .653 .803 .955 r
F P
0 g
s
.29021 .43727 m .27656 .43449 L .28089 .40242 L p .536 .701 .946 r
F P
0 g
s
.56156 .41296 m .54948 .43323 L .54528 .431 L p .893 .785 .735 r
F P
0 g
s
.54528 .431 m .55531 .40943 L .56156 .41296 L p .893 .785 .735 r
F P
0 g
s
.25266 .40154 m .26691 .40066 L .26264 .43514 L p .745 .873 .939 r
F P
0 g
s
.26264 .43514 m .24844 .43899 L .25266 .40154 L p .745 .873 .939 r
F P
0 g
s
.28089 .40242 m .29462 .40703 L .29021 .43727 L p .536 .701 .946 r
F P
0 g
s
.30364 .44349 m .29021 .43727 L .29462 .40703 L p .417 .585 .91 r
F P
0 g
s
.53467 .48114 m .54413 .48215 L .5383 .49486 L p .901 .774 .711 r
F P
0 g
s
.54413 .48215 m .53467 .48114 L .53695 .47456 L p .9 .772 .711 r
F P
0 g
s
.40314 .57129 m .41463 .58141 L .43476 .59377 L p .547 0 0 r
F P
0 g
s
.4443 .59846 m .43476 .59377 L .41463 .58141 L p 0 .296 .706 r
F P
0 g
s
.55202 .43865 m .53863 .45883 L .53734 .45611 L p .9 .776 .716 r
F P
0 g
s
.53734 .45611 m .54948 .43323 L .55202 .43865 L p .9 .776 .716 r
F P
0 g
s
.6603 .41126 m .64617 .40062 L .63562 .3795 L p .05 .335 .815 r
F P
0 g
s
.62282 .37398 m .63562 .3795 L .64617 .40062 L p .249 .47 .877 r
F P
0 g
s
.52361 .5477 m .52398 .53314 L .53476 .51879 L p .902 .799 .736 r
F P
0 g
s
.53157 .50664 m .53476 .51879 L .52398 .53314 L p .904 .787 .722 r
F P
0 g
s
.53476 .51879 m .53157 .50664 L .5383 .49486 L p .899 .778 .719 r
F P
0 g
s
.4743 .59937 m .48137 .59372 L .50146 .58518 L p .774 .96 .929 r
F P
0 g
s
.50533 .5749 m .50146 .58518 L .48137 .59372 L p .866 .909 .859 r
F P
0 g
s
.62282 .37398 m .61026 .37259 L .59598 .36232 L p .38 .679 .976 r
F P
0 g
s
.58564 .36743 m .59598 .36232 L .61026 .37259 L p .638 .784 .952 r
F P
0 g
s
.23813 .4047 m .25266 .40154 L .24844 .43899 L p .808 .912 .91 r
F P
0 g
s
.24844 .43899 m .23395 .4456 L .23813 .4047 L p .808 .912 .91 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53157 .50664 L p .903 .777 .711 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53467 .48114 L p .901 .774 .711 r
F P
0 g
s
.29462 .40703 m .30814 .41446 L .30364 .44349 L p .417 .585 .91 r
F P
0 g
s
.31692 .45289 m .30364 .44349 L .30814 .41446 L p .32 .479 .862 r
F P
0 g
s
.50533 .5749 m .50925 .56106 L .52361 .5477 L p .903 .844 .776 r
F P
0 g
s
.52398 .53314 m .52361 .5477 L .50925 .56106 L p .905 .813 .746 r
F P
0 g
s
.54948 .43323 m .53734 .45611 L .53522 .45504 L p .902 .779 .716 r
F P
0 g
s
.53522 .45504 m .54528 .431 L .54948 .43323 L p .902 .779 .716 r
F P
0 g
s
.57545 .37712 m .56536 .39125 L .55427 .3923 L p .868 .838 .814 r
F P
0 g
s
.56536 .39125 m .55531 .40943 L .54697 .4107 L p .889 .811 .765 r
F P
0 g
s
.54697 .4107 m .55427 .3923 L .56536 .39125 L p .889 .811 .765 r
F P
0 g
s
.34328 .47912 m .35651 .49435 L .36338 .52156 L p 0 .17 .704 r
F P
0 g
s
.37594 .53646 m .36338 .52156 L .35651 .49435 L p 0 .19 .715 r
F P
0 g
s
.58564 .36743 m .57545 .37712 L .56162 .37751 L p .819 .872 .885 r
F P
0 g
s
.55427 .3923 m .56162 .37751 L .57545 .37712 L p .868 .838 .814 r
F P
0 g
s
.55531 .40943 m .54528 .431 L .53969 .43211 L p .899 .792 .734 r
F P
0 g
s
.53969 .43211 m .54697 .4107 L .55531 .40943 L p .899 .792 .734 r
F P
0 g
s
.22334 .40963 m .23813 .4047 L .23395 .4456 L p .847 .928 .883 r
F P
0 g
s
.23395 .4456 m .2192 .45435 L .22334 .40963 L p .847 .928 .883 r
F P
0 g
s
.70617 .48181 m .6915 .46676 L .68931 .43875 L p .133 .305 .773 r
F P
0 g
s
.67469 .42432 m .68931 .43875 L .6915 .46676 L p .16 .315 .772 r
F P
0 g
s
.4443 .59846 m .45405 .59894 L .4743 .59937 L p .238 .737 .906 r
F P
0 g
s
.48137 .59372 m .4743 .59937 L .45405 .59894 L p .664 .91 .978 r
F P
0 g
s
.37594 .53646 m .3887 .55029 L .40314 .57129 L p 0 .023 .569 r
F P
0 g
s
.41463 .58141 m .40314 .57129 L .3887 .55029 L p 0 .177 .705 r
F P
0 g
s
.52398 .53314 m .52436 .51671 L .53157 .50664 L p .904 .787 .722 r
F P
0 g
s
.52835 .49376 m .53157 .50664 L .52436 .51671 L p .905 .779 .712 r
F P
0 g
s
.53157 .50664 m .52835 .49376 L .53174 .48769 L p .903 .777 .711 r
F P
0 g
s
.52511 .48046 m .53842 .46838 L .53695 .47456 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .53899 .46302 L .53842 .46838 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .53695 .47456 L .53467 .48114 L closepath p .906 .776 .707 r
F P
0 g
s
.48137 .59372 m .48855 .58357 L .50533 .5749 L p .866 .909 .859 r
F P
0 g
s
.50925 .56106 m .50533 .5749 L .48855 .58357 L p .893 .857 .798 r
F P
0 g
s
.52511 .48046 m .53863 .45883 L .53899 .46302 L closepath p .906 .776 .707 r
F P
0 g
s
.30814 .41446 m .32149 .42451 L .31692 .45289 L p .32 .479 .862 r
F P
0 g
s
.3301 .465 m .31692 .45289 L .32149 .42451 L p .258 .402 .817 r
F P
0 g
s
.50925 .56106 m .51319 .54401 L .52398 .53314 L p .905 .813 .746 r
F P
0 g
s
.52436 .51671 m .52398 .53314 L .51319 .54401 L p .905 .793 .726 r
F P
0 g
s
.54528 .431 m .53522 .45504 L .53241 .4557 L p .903 .781 .716 r
F P
0 g
s
.53241 .4557 m .53969 .43211 L .54528 .431 L p .903 .781 .716 r
F P
0 g
s
.63562 .3795 m .62282 .37398 L .6065 .36163 L p .031 .468 .878 r
F P
0 g
s
.59598 .36232 m .6065 .36163 L .62282 .37398 L p .38 .679 .976 r
F P
0 g
s
.52511 .48046 m .53467 .48114 L .53174 .48769 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .53734 .45611 L .53863 .45883 L closepath p .906 .776 .707 r
F P
0 g
s
.59598 .36232 m .58564 .36743 L .56906 .3667 L p .693 .889 .969 r
F P
0 g
s
.56162 .37751 m .56906 .3667 L .58564 .36743 L p .819 .872 .885 r
F P
0 g
s
.67469 .42432 m .6603 .41126 L .64869 .38846 L p 0 .23 .75 r
F P
0 g
s
.63562 .3795 m .64869 .38846 L .6603 .41126 L p .05 .335 .815 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49376 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .53522 .45504 L .53734 .45611 L closepath p .906 .776 .707 r
F P
0 g
s
.20834 .41568 m .22334 .40963 L .2192 .45435 L p .867 .932 .864 r
F P
0 g
s
.2192 .45435 m .20422 .46445 L .20834 .41568 L p .867 .932 .864 r
F P
0 g
s
.41463 .58141 m .42638 .58807 L .4443 .59846 L p 0 .296 .706 r
F P
0 g
s
.45405 .59894 m .4443 .59846 L .42638 .58807 L p .238 .641 .96 r
F P
0 g
s
.51319 .54401 m .51716 .52436 L .52436 .51671 L p .905 .793 .726 r
F P
0 g
s
.52474 .49894 m .52436 .51671 L .51716 .52436 L p .905 .781 .713 r
F P
0 g
s
.52436 .51671 m .52474 .49894 L .52835 .49376 L p .905 .779 .712 r
F P
0 g
s
.85906 .48583 m .84625 .49649 L .84678 .44749 L p .915 .939 .807 r
F P
0 g
s
.84678 .44749 m .85986 .43317 L .85906 .48583 L p .915 .939 .807 r
F P
0 g
s
.48855 .58357 m .49581 .56906 L .50925 .56106 L p .893 .857 .798 r
F P
0 g
s
.51319 .54401 m .50925 .56106 L .49581 .56906 L p .901 .819 .757 r
F P
0 g
s
.52511 .48046 m .52835 .49376 L .52474 .49894 L closepath p .906 .776 .707 r
F P
0 g
s
.55427 .3923 m .54697 .4107 L .53707 .41675 L p .9 .817 .757 r
F P
0 g
s
.54697 .4107 m .53969 .43211 L .53308 .43653 L p .903 .795 .731 r
F P
0 g
s
.53308 .43653 m .53707 .41675 L .54697 .4107 L p .903 .795 .731 r
F P
0 g
s
.52511 .48046 m .53241 .4557 L .53522 .45504 L closepath p .906 .776 .707 r
F P
0 g
s
.53969 .43211 m .53241 .4557 L .52909 .45804 L p .905 .781 .715 r
F P
0 g
s
.52909 .45804 m .53308 .43653 L .53969 .43211 L p .905 .781 .715 r
F P
0 g
s
.56162 .37751 m .55427 .3923 L .54108 .39939 L p .89 .851 .798 r
F P
0 g
s
.53707 .41675 m .54108 .39939 L .55427 .3923 L p .9 .817 .757 r
F P
0 g
s
.45405 .59894 m .46399 .59462 L .48137 .59372 L p .664 .91 .978 r
F P
0 g
s
.48855 .58357 m .48137 .59372 L .46399 .59462 L p .821 .889 .892 r
F P
0 g
s
.72091 .49599 m .70617 .48181 L .70411 .4534 L p .141 .326 .789 r
F P
0 g
s
.68931 .43875 m .70411 .4534 L .70617 .48181 L p .133 .305 .773 r
F P
0 g
s
.32149 .42451 m .33475 .43677 L .3301 .465 L p .258 .402 .817 r
F P
0 g
s
.34328 .47912 m .3301 .465 L .33475 .43677 L p .234 .357 .785 r
F P
0 g
s
.51716 .52436 m .52114 .50288 L .52474 .49894 L p .905 .781 .713 r
F P
0 g
s
.52511 .48046 m .52474 .49894 L .52114 .50288 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .52909 .45804 L .53241 .4557 L closepath p .906 .776 .707 r
F P
0 g
s
.6065 .36163 m .59598 .36232 L .5766 .35999 L p .402 .801 .984 r
F P
0 g
s
.56906 .3667 m .5766 .35999 L .59598 .36232 L p .693 .889 .969 r
F P
0 g
s
.35651 .49435 m .36987 .50967 L .37594 .53646 L p 0 .19 .715 r
F P
0 g
s
.3887 .55029 m .37594 .53646 L .36987 .50967 L p .049 .253 .749 r
F P
0 g
s
.49581 .56906 m .50313 .55064 L .51319 .54401 L p .901 .819 .757 r
F P
0 g
s
.51716 .52436 m .51319 .54401 L .50313 .55064 L p .904 .795 .73 r
F P
0 g
s
.56906 .3667 m .56162 .37751 L .54512 .38496 L p .863 .896 .856 r
F P
0 g
s
.54108 .39939 m .54512 .38496 L .56162 .37751 L p .89 .851 .798 r
F P
0 g
s
.50313 .55064 m .51046 .52906 L .51716 .52436 L p .904 .795 .73 r
F P
0 g
s
.52114 .50288 m .51716 .52436 L .51046 .52906 L p .905 .782 .715 r
F P
0 g
s
.19318 .42214 m .20834 .41568 L .20422 .46445 L p .874 .927 .856 r
F P
0 g
s
.20422 .46445 m .18911 .47507 L .19318 .42214 L p .874 .927 .856 r
F P
0 g
s
.3887 .55029 m .40171 .56185 L .41463 .58141 L p 0 .177 .705 r
F P
0 g
s
.42638 .58807 m .41463 .58141 L .40171 .56185 L p .075 .39 .849 r
F P
0 g
s
.51046 .52906 m .5178 .5053 L .52114 .50288 L p .905 .782 .715 r
F P
0 g
s
.52511 .48046 m .52114 .50288 L .5178 .5053 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .52549 .46193 L .52909 .45804 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .52186 .46709 L .52549 .46193 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52186 .46709 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51546 .47978 L .51844 .47318 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51315 .48644 L .51546 .47978 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51165 .49269 L .51315 .48644 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51108 .49811 L .51165 .49269 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51147 .50231 L .51108 .49811 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51279 .50501 L .51147 .50231 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .51495 .50603 L .51279 .50501 L closepath p .906 .776 .707 r
F P
0 g
s
.52511 .48046 m .5178 .5053 L .51495 .50603 L closepath p .906 .776 .707 r
F P
0 g
s
.53308 .43653 m .52909 .45804 L .52549 .46193 L p .905 .781 .713 r
F P
0 g
s
.64869 .38846 m .63562 .3795 L .61725 .36492 L p 0 .245 .708 r
F P
0 g
s
.6065 .36163 m .61725 .36492 L .63562 .3795 L p .031 .468 .878 r
F P
0 g
s
.84625 .49649 m .83332 .50678 L .83358 .46139 L p .909 .942 .816 r
F P
0 g
s
.83358 .46139 m .84678 .44749 L .84625 .49649 L p .909 .942 .816 r
F P
0 g
s
.53707 .41675 m .53308 .43653 L .52588 .44398 L p .905 .793 .726 r
F P
0 g
s
.52549 .46193 m .52588 .44398 L .53308 .43653 L p .905 .781 .713 r
F P
0 g
s
.46399 .59462 m .47407 .58527 L .48855 .58357 L p .821 .889 .892 r
F P
0 g
s
.49581 .56906 m .48855 .58357 L .47407 .58527 L p .872 .846 .815 r
F P
0 g
s
.54108 .39939 m .53707 .41675 L .52626 .42721 L p .904 .812 .746 r
F P
0 g
s
.52588 .44398 m .52626 .42721 L .53707 .41675 L p .905 .793 .726 r
F P
0 g
s
.68931 .43875 m .67469 .42432 L .66203 .39993 L p 0 .173 .709 r
F P
0 g
s
.64869 .38846 m .66203 .39993 L .67469 .42432 L p 0 .23 .75 r
F P
0 g
s
.42638 .58807 m .43837 .59035 L .45405 .59894 L p .238 .641 .96 r
F P
0 g
s
.46399 .59462 m .45405 .59894 L .43837 .59035 L p .611 .803 .973 r
F P
0 g
s
.50473 .53046 m .51495 .50603 L .5178 .5053 L p .903 .781 .716 r
F P
0 g
s
.5178 .5053 m .51046 .52906 L .50473 .53046 L p .903 .781 .716 r
F P
0 g
s
.52588 .44398 m .52549 .46193 L .52186 .46709 L p .904 .779 .712 r
F P
0 g
s
.73564 .50834 m .72091 .49599 L .71904 .46712 L p .187 .379 .821 r
F P
0 g
s
.70411 .4534 m .71904 .46712 L .72091 .49599 L p .141 .326 .789 r
F P
0 g
s
.33475 .43677 m .34796 .45064 L .34328 .47912 L p .234 .357 .785 r
F P
0 g
s
.35651 .49435 m .34328 .47912 L .34796 .45064 L p .244 .345 .768 r
F P
0 g
s
.5766 .35999 m .56906 .3667 L .54921 .37378 L p .787 .94 .928 r
F P
0 g
s
.54512 .38496 m .54921 .37378 L .56906 .3667 L p .863 .896 .856 r
F P
0 g
s
.47407 .58527 m .48425 .57106 L .49581 .56906 L p .872 .846 .815 r
F P
0 g
s
.50313 .55064 m .49581 .56906 L .48425 .57106 L p .891 .813 .765 r
F P
0 g
s
.49449 .5525 m .50473 .53046 L .51046 .52906 L p .899 .793 .734 r
F P
0 g
s
.51046 .52906 m .50313 .55064 L .49449 .5525 L p .899 .793 .734 r
F P
0 g
s
.50037 .52843 m .51279 .50501 L .51495 .50603 L p .902 .779 .716 r
F P
0 g
s
.51495 .50603 m .50473 .53046 L .50037 .52843 L p .902 .779 .716 r
F P
0 g
s
.48425 .57106 m .49449 .5525 L .50313 .55064 L p .891 .813 .765 r
F P
0 g
s
.52186 .46709 m .51858 .45397 L .52588 .44398 L p .904 .779 .712 r
F P
0 g
s
.51858 .45397 m .52186 .46709 L .51844 .47318 L p .903 .777 .711 r
F P
0 g
s
.54512 .38496 m .54108 .39939 L .52664 .41212 L p .901 .84 .776 r
F P
0 g
s
.52626 .42721 m .52664 .41212 L .54108 .39939 L p .904 .812 .746 r
F P
0 g
s
.52626 .42721 m .52588 .44398 L .51858 .45397 L p .903 .786 .722 r
F P
0 g
s
.5766 .35999 m .58429 .35725 L .6065 .36163 L p .402 .801 .984 r
F P
0 g
s
.61725 .36492 m .6065 .36163 L .58429 .35725 L p 0 .535 .807 r
F P
0 g
s
.83332 .50678 m .82018 .51579 L .82018 .47384 L p .889 .939 .841 r
F P
0 g
s
.82018 .47384 m .83358 .46139 L .83332 .50678 L p .889 .939 .841 r
F P
0 g
s
.49769 .52309 m .51147 .50231 L .51279 .50501 L p .9 .776 .716 r
F P
0 g
s
.51279 .50501 m .50037 .52843 L .49769 .52309 L p .9 .776 .716 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51858 .45397 L p .903 .777 .711 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51546 .47978 L p .902 .774 .711 r
F P
0 g
s
.36987 .50967 m .38339 .52401 L .3887 .55029 L p .049 .253 .749 r
F P
0 g
s
.40171 .56185 m .3887 .55029 L .38339 .52401 L p .191 .349 .793 r
F P
0 g
s
.43837 .59035 m .45057 .58766 L .46399 .59462 L p .611 .803 .973 r
F P
0 g
s
.47407 .58527 m .46399 .59462 L .45057 .58766 L p .777 .824 .89 r
F P
0 g
s
.49689 .5148 m .51108 .49811 L .51147 .50231 L p .899 .774 .715 r
F P
0 g
s
.51147 .50231 m .49769 .52309 L .49689 .5148 L p .899 .774 .715 r
F P
0 g
s
.51546 .47978 m .50572 .47875 L .5117 .46583 L p .902 .774 .711 r
F P
0 g
s
.50572 .47875 m .51546 .47978 L .51315 .48644 L p .9 .772 .711 r
F P
0 g
s
.40171 .56185 m .41497 .57006 L .42638 .58807 L p .075 .39 .849 r
F P
0 g
s
.43837 .59035 m .42638 .58807 L .41497 .57006 L p .387 .584 .92 r
F P
0 g
s
.48789 .54942 m .50037 .52843 L .50473 .53046 L p .893 .786 .735 r
F P
0 g
s
.50473 .53046 m .49449 .5525 L .48789 .54942 L p .893 .786 .735 r
F P
0 g
s
.52664 .41212 m .52626 .42721 L .51528 .44142 L p .901 .798 .736 r
F P
0 g
s
.51858 .45397 m .51528 .44142 L .52626 .42721 L p .903 .786 .722 r
F P
0 g
s
.7503 .51806 m .73564 .50834 L .734 .47882 L p .272 .465 .866 r
F P
0 g
s
.71904 .46712 m .734 .47882 L .73564 .50834 L p .187 .379 .821 r
F P
0 g
s
.49804 .50413 m .51165 .49269 L .51108 .49811 L p .898 .772 .714 r
F P
0 g
s
.51108 .49811 m .49689 .5148 L .49804 .50413 L p .898 .772 .714 r
F P
0 g
s
.54921 .37378 m .54512 .38496 L .52703 .39909 L p .89 .877 .817 r
F P
0 g
s
.52664 .41212 m .52703 .39909 L .54512 .38496 L p .901 .84 .776 r
F P
0 g
s
.51315 .48644 m .50105 .49182 L .50572 .47875 L p .9 .772 .711 r
F P
0 g
s
.50105 .49182 m .51315 .48644 L .51165 .49269 L p .899 .771 .712 r
F P
0 g
s
.51165 .49269 m .49804 .50413 L .50105 .49182 L p .899 .771 .712 r
F P
0 g
s
.51528 .44142 m .51858 .45397 L .5117 .46583 L p .899 .778 .719 r
F P
0 g
s
.61725 .36492 m .62825 .37153 L .64869 .38846 L p 0 .245 .708 r
F P
0 g
s
.66203 .39993 m .64869 .38846 L .62825 .37153 L p 0 .099 .575 r
F P
0 g
s
.58429 .35725 m .5766 .35999 L .55336 .36596 L p .591 .926 .962 r
F P
0 g
s
.54921 .37378 m .55336 .36596 L .5766 .35999 L p .787 .94 .928 r
F P
0 g
s
.34796 .45064 m .36118 .46539 L .35651 .49435 L p .244 .345 .768 r
F P
0 g
s
.36987 .50967 m .35651 .49435 L .36118 .46539 L p .284 .36 .765 r
F P
0 g
s
.82018 .51579 m .80677 .52269 L .80651 .48388 L p .848 .922 .88 r
F P
0 g
s
.80651 .48388 m .82018 .47384 L .82018 .51579 L p .848 .922 .88 r
F P
0 g
s
.47539 .56683 m .48789 .54942 L .49449 .5525 L p .877 .797 .767 r
F P
0 g
s
.49449 .5525 m .48425 .57106 L .47539 .56683 L p .877 .797 .767 r
F P
0 g
s
.45057 .58766 m .46293 .57976 L .47407 .58527 L p .777 .824 .89 r
F P
0 g
s
.48425 .57106 m .47407 .58527 L .46293 .57976 L p .846 .812 .817 r
F P
0 g
s
.70411 .4534 m .68931 .43875 L .67562 .41284 L p 0 .166 .703 r
F P
0 g
s
.66203 .39993 m .67562 .41284 L .68931 .43875 L p 0 .173 .709 r
F P
0 g
s
.46293 .57976 m .47539 .56683 L .48425 .57106 L p .846 .812 .817 r
F P
0 g
s
.48382 .54155 m .49769 .52309 L .50037 .52843 L p .887 .776 .733 r
F P
0 g
s
.50037 .52843 m .48789 .54942 L .48382 .54155 L p .887 .776 .733 r
F P
0 g
s
.52703 .39909 m .52664 .41212 L .51196 .4297 L p .898 .814 .756 r
F P
0 g
s
.51528 .44142 m .51196 .4297 L .52664 .41212 L p .901 .798 .736 r
F P
0 g
s
.7648 .52454 m .7503 .51806 L .74892 .48756 L p .393 .578 .914 r
F P
0 g
s
.734 .47882 m .74892 .48756 L .7503 .51806 L p .272 .465 .866 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51528 .44142 L p .899 .778 .719 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50572 .47875 L p .894 .77 .717 r
F P
0 g
s
.80677 .52269 m .79307 .52674 L .79253 .4907 L p .778 .882 .922 r
F P
0 g
s
.79253 .4907 m .80651 .48388 L .80677 .52269 L p .778 .882 .922 r
F P
0 g
s
.41497 .57006 m .42846 .57402 L .43837 .59035 L p .387 .584 .92 r
F P
0 g
s
.45057 .58766 m .43837 .59035 L .42846 .57402 L p .616 .699 .904 r
F P
0 g
s
.55336 .36596 m .54921 .37378 L .52743 .38835 L p .86 .921 .869 r
F P
0 g
s
.52703 .39909 m .52743 .38835 L .54921 .37378 L p .89 .877 .817 r
F P
0 g
s
.51196 .4297 m .51528 .44142 L .50491 .45842 L p .893 .78 .729 r
F P
0 g
s
.38339 .52401 m .39711 .53628 L .40171 .56185 L p .191 .349 .793 r
F P
0 g
s
.41497 .57006 m .40171 .56185 L .39711 .53628 L p .356 .46 .829 r
F P
0 g
s
.48259 .52942 m .49689 .5148 L .49769 .52309 L p .883 .768 .73 r
F P
0 g
s
.49769 .52309 m .48382 .54155 L .48259 .52942 L p .883 .768 .73 r
F P
0 g
s
.58429 .35725 m .59214 .35808 L .61725 .36492 L p 0 .535 .807 r
F P
0 g
s
.62825 .37153 m .61725 .36492 L .59214 .35808 L p .338 0 0 r
F P
0 g
s
.50572 .47875 m .49588 .47704 L .50491 .45842 L p .894 .77 .717 r
F P
0 g
s
.49588 .47704 m .50572 .47875 L .50105 .49182 L p .888 .763 .718 r
F P
0 g
s
.77907 .52744 m .7648 .52454 L .76369 .49265 L p .535 .7 .946 r
F P
0 g
s
.74892 .48756 m .76369 .49265 L .7648 .52454 L p .393 .578 .914 r
F P
0 g
s
.79307 .52674 m .77907 .52744 L .77825 .49372 L p .671 .808 .949 r
F P
0 g
s
.77825 .49372 m .79253 .4907 L .79307 .52674 L p .671 .808 .949 r
F P
0 g
s
.4699 .55658 m .48382 .54155 L .48789 .54942 L p .864 .775 .761 r
F P
0 g
s
.48789 .54942 m .47539 .56683 L .4699 .55658 L p .864 .775 .761 r
F P
0 g
s
.76369 .49265 m .77825 .49372 L .77907 .52744 L p .535 .7 .946 r
F P
0 g
s
.4843 .51386 m .49804 .50413 L .49689 .5148 L p .882 .762 .725 r
F P
0 g
s
.49689 .5148 m .48259 .52942 L .4843 .51386 L p .882 .762 .725 r
F P
0 g
s
.36118 .46539 m .37448 .48019 L .36987 .50967 L p .284 .36 .765 r
F P
0 g
s
.38339 .52401 m .36987 .50967 L .37448 .48019 L p .348 .396 .77 r
F P
0 g
s
.50105 .49182 m .48884 .49597 L .49588 .47704 L p .888 .763 .718 r
F P
0 g
s
.48884 .49597 m .50105 .49182 L .49804 .50413 L p .884 .76 .721 r
F P
0 g
s
.49804 .50413 m .4843 .51386 L .48884 .49597 L p .884 .76 .721 r
F P
0 g
s
.52743 .38835 m .52703 .39909 L .50861 .41902 L p .891 .834 .783 r
F P
0 g
s
.51196 .4297 m .50861 .41902 L .52703 .39909 L p .898 .814 .756 r
F P
0 g
s
.42846 .57402 m .44215 .57318 L .45057 .58766 L p .616 .699 .904 r
F P
0 g
s
.46293 .57976 m .45057 .58766 L .44215 .57318 L p .75 .75 .852 r
F P
0 g
s
.55336 .36596 m .55759 .36137 L .58429 .35725 L p .591 .926 .962 r
F P
0 g
s
.59214 .35808 m .58429 .35725 L .55759 .36137 L p .239 .753 .853 r
F P
0 g
s
.45598 .5673 m .4699 .55658 L .47539 .56683 L p .824 .769 .801 r
F P
0 g
s
.47539 .56683 m .46293 .57976 L .45598 .5673 L p .824 .769 .801 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51196 .4297 L p .893 .78 .729 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49588 .47704 L p .882 .762 .726 r
F P
0 g
s
.44215 .57318 m .45598 .5673 L .46293 .57976 L p .75 .75 .852 r
F P
0 g
s
.50861 .41902 m .51196 .4297 L .49806 .45095 L p .885 .782 .743 r
F P
0 g
s
.30273 .37429 m .31552 .38056 L .29462 .40703 L p .54 .702 .945 r
F P
0 g
s
.29462 .40703 m .28089 .40242 L .30273 .37429 L p .54 .702 .945 r
F P
0 g
s
.30814 .41446 m .29462 .40703 L .31552 .38056 L p .48 .612 .905 r
F P
0 g
s
.31552 .38056 m .32813 .38883 L .30814 .41446 L p .48 .612 .905 r
F P
0 g
s
.32149 .42451 m .30814 .41446 L .32813 .38883 L p .439 .54 .862 r
F P
0 g
s
.4682 .54097 m .48259 .52942 L .48382 .54155 L p .856 .756 .751 r
F P
0 g
s
.48382 .54155 m .4699 .55658 L .4682 .54097 L p .856 .756 .751 r
F P
0 g
s
.28973 .37005 m .30273 .37429 L .28089 .40242 L p .61 .795 .97 r
F P
0 g
s
.28089 .40242 m .26691 .40066 L .28973 .37005 L p .61 .795 .97 r
F P
0 g
s
.62825 .37153 m .63949 .38058 L .66203 .39993 L p 0 .099 .575 r
F P
0 g
s
.67562 .41284 m .66203 .39993 L .63949 .38058 L p .485 0 0 r
F P
0 g
s
.39711 .53628 m .41104 .54551 L .41497 .57006 L p .356 .46 .829 r
F P
0 g
s
.42846 .57402 m .41497 .57006 L .41104 .54551 L p .516 .563 .842 r
F P
0 g
s
.71904 .46712 m .70411 .4534 L .68944 .42599 L p 0 .209 .734 r
F P
0 g
s
.67562 .41284 m .68944 .42599 L p .67774 .41584 L 0 .166 .703 r
F P
0 g
s
.68944 .42599 m .67562 .41284 L .65096 .391 L p .478 0 0 r
F P
0 g
s
.66264 .40165 m .68944 .42599 L p .65381 .39359 L .478 0 0 r
F P
0 g
s
.65096 .391 m .66264 .40165 L p .65381 .39359 L .478 0 0 r
F P
0 g
s
.66264 .40165 m .62531 .38239 L p .67108 .40936 L .476 0 0 r
F P
0 g
s
.68944 .42599 m .66264 .40165 L p .7006 .43567 L 0 .102 .591 r
F P
0 g
s
.63949 .38058 m .65096 .391 L .67562 .41284 L p .485 0 0 r
F P
0 g
s
.67447 .41136 m .7034 .43818 L p .6689 .40726 L 0 .102 .591 r
F P
0 g
s
.66264 .40165 m .67447 .41136 L p .6689 .40726 L 0 .102 .591 r
F P
0 g
s
.71743 .44827 m .7034 .43818 L .67447 .41136 L p 0 .233 .716 r
F P
0 g
s
.68639 .419 m .71743 .44827 L p .68542 .42076 L 0 .233 .716 r
F P
0 g
s
.67447 .41136 m .68639 .419 L p .68542 .42076 L 0 .233 .716 r
F P
0 g
s
.67447 .41136 m .63397 .38885 L p .67942 .41499 L 0 .248 .654 r
F P
0 g
s
.68639 .419 m .67447 .41136 L p .67942 .41499 L 0 .248 .654 r
F P
0 g
s
.67447 .41136 m .66264 .40165 L p .67108 .40936 L .476 0 0 r
F P
0 g
s
.63397 .38885 m .67447 .41136 L p .63284 .38682 L .476 0 0 r
F P
0 g
s
.62531 .38239 m .63397 .38885 L p .63284 .38682 L .476 0 0 r
F P
0 g
s
.63397 .38885 m .58479 .37263 L p .63498 .39065 L 0 .395 .723 r
F P
0 g
s
.64271 .39343 m .68639 .419 L p .64728 .39651 L 0 .248 .654 r
F P
0 g
s
.63397 .38885 m .64271 .39343 L p .64728 .39651 L 0 .248 .654 r
F P
0 g
s
.64271 .39343 m .63397 .38885 L p .63498 .39065 L 0 .395 .723 r
F P
0 g
s
.58479 .37263 m .63397 .38885 L p .58828 .37277 L .343 0 0 r
F P
0 g
s
.58006 .36987 m .58479 .37263 L p .58828 .37277 L .343 0 0 r
F P
0 g
s
.55759 .36137 m .55336 .36596 L .52783 .37997 L p .789 .957 .923 r
F P
0 g
s
.52743 .38835 m .52783 .37997 L .55336 .36596 L p .86 .921 .869 r
F P
0 g
s
.55759 .36137 m .5619 .3597 L .59214 .35808 L p .239 .753 .853 r
F P
0 g
s
.52783 .37997 m .52823 .37388 L .55759 .36137 L p .789 .957 .923 r
F P
0 g
s
.5619 .3597 m .55759 .36137 L .52823 .37388 L p .644 .95 .948 r
F P
0 g
s
.52823 .37388 m .52864 .36984 L .5619 .3597 L p .644 .95 .948 r
F P
0 g
s
.5663 .36044 m .5619 .3597 L .52864 .36984 L p .427 .866 .911 r
F P
0 g
s
.52864 .36984 m .52906 .36748 L .5663 .36044 L p .427 .866 .911 r
F P
0 g
s
.5708 .36292 m .5663 .36044 L .52906 .36748 L p .209 .733 .83 r
F P
0 g
s
.52906 .36748 m .52949 .36632 L .5708 .36292 L p .209 .733 .83 r
F P
0 g
s
.57539 .36635 m .5708 .36292 L .52949 .36632 L p .061 .625 .77 r
F P
0 g
s
.52949 .36632 m .52993 .36578 L .57539 .36635 L p .061 .625 .77 r
F P
0 g
s
.58006 .36987 m .57539 .36635 L .52993 .36578 L p .005 .576 .768 r
F P
0 g
s
.52993 .36578 m .53037 .36527 L .58006 .36987 L p .005 .576 .768 r
F P
0 g
s
.58479 .37263 m .58006 .36987 L .53037 .36527 L p .036 .589 .825 r
F P
0 g
s
.53037 .36527 m .53082 .36415 L .58479 .37263 L p .036 .589 .825 r
F P
0 g
s
.58479 .37263 m .53082 .36415 L p .5817 .3725 L .145 .641 .912 r
F P
0 g
s
.58958 .37379 m .64271 .39343 L p .59945 .37789 L 0 .395 .723 r
F P
0 g
s
.58479 .37263 m .58958 .37379 L p .59945 .37789 L 0 .395 .723 r
F P
0 g
s
.58958 .37379 m .58479 .37263 L p .5817 .3725 L .145 .641 .912 r
F P
0 g
s
.58958 .37379 m .53127 .36186 L p .58162 .37049 L .296 .693 .975 r
F P
0 g
s
.57539 .36635 m .58006 .36987 L .62531 .38239 L p .407 0 0 r
F P
0 g
s
.63397 .38885 m .62531 .38239 L .58006 .36987 L p .343 0 0 r
F P
0 g
s
.59439 .37268 m .58958 .37379 L p .58162 .37049 L .296 .693 .975 r
F P
0 g
s
.64271 .39343 m .58958 .37379 L p .63902 .39095 L .085 .564 .903 r
F P
0 g
s
.61677 .37503 m .62531 .38239 L .66264 .40165 L p .546 0 0 r
F P
0 g
s
.65149 .39527 m .64271 .39343 L p .63902 .39095 L .085 .564 .903 r
F P
0 g
s
.68639 .419 m .64271 .39343 L p .68718 .41758 L 0 .454 .854 r
F P
0 g
s
.69833 .42364 m .68639 .419 L p .68718 .41758 L 0 .454 .854 r
F P
0 g
s
.7034 .43818 m .68944 .42599 L p .7006 .43567 L 0 .102 .591 r
F P
0 g
s
.68944 .42599 m .70411 .4534 L p .67774 .41584 L 0 .166 .703 r
F P
0 g
s
.32813 .38883 m .3406 .39894 L .32149 .42451 L p .439 .54 .862 r
F P
0 g
s
.33475 .43677 m .32149 .42451 L .3406 .39894 L p .42 .49 .826 r
F P
0 g
s
.49588 .47704 m .48596 .47439 L .49806 .45095 L p .882 .762 .726 r
F P
0 g
s
.48596 .47439 m .49588 .47704 L .48884 .49597 L p .87 .749 .727 r
F P
0 g
s
.37448 .48019 m .38787 .49413 L .38339 .52401 L p .348 .396 .77 r
F P
0 g
s
.39711 .53628 m .38339 .52401 L .38787 .49413 L p .429 .449 .779 r
F P
0 g
s
.27651 .36768 m .28973 .37005 L .26691 .40066 L p .676 .872 .973 r
F P
0 g
s
.26691 .40066 m .25266 .40154 L .27651 .36768 L p .676 .872 .973 r
F P
0 g
s
.47046 .52109 m .4843 .51386 L .48259 .52942 L p .855 .744 .74 r
F P
0 g
s
.48259 .52942 m .4682 .54097 L .47046 .52109 L p .855 .744 .74 r
F P
0 g
s
.52783 .37997 m .52743 .38835 L .50522 .4095 L p .879 .857 .816 r
F P
0 g
s
.50861 .41902 m .50522 .4095 L .52743 .38835 L p .891 .834 .783 r
F P
0 g
s
.3406 .39894 m .35296 .4106 L .33475 .43677 L p .42 .49 .826 r
F P
0 g
s
.34796 .45064 m .33475 .43677 L .35296 .4106 L p .421 .463 .799 r
F P
0 g
s
.48884 .49597 m .47652 .49834 L .48596 .47439 L p .87 .749 .727 r
F P
0 g
s
.47652 .49834 m .48884 .49597 L .4843 .51386 L p .86 .742 .732 r
F P
0 g
s
.45379 .54868 m .4682 .54097 L .4699 .55658 L p .813 .735 .778 r
F P
0 g
s
.4699 .55658 m .45598 .5673 L .45379 .54868 L p .813 .735 .778 r
F P
0 g
s
.4843 .51386 m .47046 .52109 L .47652 .49834 L p .86 .742 .732 r
F P
0 g
s
.41104 .54551 m .42516 .55094 L .42846 .57402 L p .516 .563 .842 r
F P
0 g
s
.44215 .57318 m .42846 .57402 L .42516 .55094 L p .649 .644 .832 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50861 .41902 L p .885 .782 .743 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48596 .47439 L p .866 .752 .736 r
F P
0 g
s
.50522 .4095 m .50861 .41902 L .49116 .44341 L p .873 .784 .759 r
F P
0 g
s
.63949 .38058 m .62825 .37153 L .60017 .36189 L p .493 0 0 r
F P
0 g
s
.59214 .35808 m .60017 .36189 L .62825 .37153 L p .338 0 0 r
F P
0 g
s
.26306 .36694 m .27651 .36768 L .25266 .40154 L p .729 .924 .957 r
F P
0 g
s
.25266 .40154 m .23813 .4047 L .26306 .36694 L p .729 .924 .957 r
F P
0 g
s
.43942 .55206 m .45379 .54868 L .45598 .5673 L p .747 .7 .807 r
F P
0 g
s
.45598 .5673 m .44215 .57318 L .43942 .55206 L p .747 .7 .807 r
F P
0 g
s
.42516 .55094 m .43942 .55206 L .44215 .57318 L p .649 .644 .832 r
F P
0 g
s
.35296 .4106 m .36526 .42337 L .34796 .45064 L p .421 .463 .799 r
F P
0 g
s
.36118 .46539 m .34796 .45064 L .36526 .42337 L p .439 .456 .781 r
F P
0 g
s
.38787 .49413 m .4014 .50635 L .39711 .53628 L p .429 .449 .779 r
F P
0 g
s
.41104 .54551 m .39711 .53628 L .4014 .50635 L p .518 .51 .787 r
F P
0 g
s
.60017 .36189 m .59214 .35808 L .5619 .3597 L p .102 0 0 r
F P
0 g
s
.45657 .52519 m .47046 .52109 L .4682 .54097 L p .815 .717 .757 r
F P
0 g
s
.4682 .54097 m .45379 .54868 L .45657 .52519 L p .815 .717 .757 r
F P
0 g
s
.48596 .47439 m .47596 .47056 L .49116 .44341 L p .866 .752 .736 r
F P
0 g
s
.47596 .47056 m .48596 .47439 L .47652 .49834 L p .845 .729 .736 r
F P
0 g
s
.734 .47882 m .71904 .46712 L .7034 .43818 L p 0 .3 .795 r
F P
0 g
s
.68944 .42599 m .7034 .43818 L .71904 .46712 L p 0 .209 .734 r
F P
0 g
s
.36526 .42337 m .37753 .43673 L .36118 .46539 L p .439 .456 .781 r
F P
0 g
s
.37448 .48019 m .36118 .46539 L .37753 .43673 L p .471 .466 .771 r
F P
0 g
s
.46414 .4985 m .47652 .49834 L .47046 .52109 L p .827 .716 .743 r
F P
0 g
s
.47046 .52109 m .45657 .52519 L .46414 .4985 L p .827 .716 .743 r
F P
0 g
s
.52823 .37388 m .52783 .37997 L .50179 .40118 L p .856 .882 .857 r
F P
0 g
s
.50522 .4095 m .50179 .40118 L .52783 .37997 L p .879 .857 .816 r
F P
0 g
s
.47652 .49834 m .46414 .4985 L .47596 .47056 L p .845 .729 .736 r
F P
0 g
s
.2494 .36743 m .26306 .36694 L .23813 .4047 L p .768 .951 .935 r
F P
0 g
s
.23813 .4047 m .22334 .40963 L .2494 .36743 L p .768 .951 .935 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50522 .4095 L p .873 .784 .759 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47596 .47056 L p .845 .739 .747 r
F P
0 g
s
.50179 .40118 m .50522 .4095 L .48419 .43581 L p .858 .786 .779 r
F P
0 g
s
.4014 .50635 m .41505 .51607 L .41104 .54551 L p .518 .51 .787 r
F P
0 g
s
.42516 .55094 m .41104 .54551 L .41505 .51607 L p .608 .573 .789 r
F P
0 g
s
.44267 .52576 m .45657 .52519 L .45379 .54868 L p .761 .68 .773 r
F P
0 g
s
.45379 .54868 m .43942 .55206 L .44267 .52576 L p .761 .68 .773 r
F P
0 g
s
.41505 .51607 m .42882 .52268 L .42516 .55094 L p .608 .573 .789 r
F P
0 g
s
.43942 .55206 m .42516 .55094 L .42882 .52268 L p .691 .631 .785 r
F P
0 g
s
.37753 .43673 m .3898 .45006 L .37448 .48019 L p .471 .466 .771 r
F P
0 g
s
.38787 .49413 m .37448 .48019 L .3898 .45006 L p .514 .489 .766 r
F P
0 g
s
.42882 .52268 m .44267 .52576 L .43942 .55206 L p .691 .631 .785 r
F P
0 g
s
.47596 .47056 m .4659 .46542 L .48419 .43581 L p .845 .739 .747 r
F P
0 g
s
.4659 .46542 m .47596 .47056 L .46414 .4985 L p .814 .705 .744 r
F P
0 g
s
.45171 .49616 m .46414 .4985 L .45657 .52519 L p .785 .684 .753 r
F P
0 g
s
.45657 .52519 m .44267 .52576 L .45171 .49616 L p .785 .684 .753 r
F P
0 g
s
.23554 .36871 m .2494 .36743 L .22334 .40963 L p .794 .961 .918 r
F P
0 g
s
.22334 .40963 m .20834 .41568 L .23554 .36871 L p .794 .961 .918 r
F P
0 g
s
.46414 .4985 m .45171 .49616 L .4659 .46542 L p .814 .705 .744 r
F P
0 g
s
.3898 .45006 m .40211 .46275 L .38787 .49413 L p .514 .489 .766 r
F P
0 g
s
.4014 .50635 m .38787 .49413 L .40211 .46275 L p .565 .522 .765 r
F P
0 g
s
.74892 .48756 m .734 .47882 L .71743 .44827 L p .13 .43 .871 r
F P
0 g
s
.7034 .43818 m .71743 .44827 L .734 .47882 L p 0 .3 .795 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50179 .40118 L p .858 .786 .779 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .4659 .46542 L p .821 .724 .758 r
F P
0 g
s
.65096 .391 m .63949 .38058 L .60838 .36785 L p .551 0 0 r
F P
0 g
s
.60017 .36189 m .60838 .36785 L .63949 .38058 L p .493 0 0 r
F P
0 g
s
.50179 .40118 m .49832 .39403 L .52823 .37388 L p .856 .882 .857 r
F P
0 g
s
.49832 .39403 m .50179 .40118 L .47717 .42815 L p .839 .787 .802 r
F P
0 g
s
.43927 .49123 m .45171 .49616 L .44267 .52576 L p .735 .645 .76 r
F P
0 g
s
.44267 .52576 m .42882 .52268 L .43927 .49123 L p .735 .645 .76 r
F P
0 g
s
.52864 .36984 m .52823 .37388 L .49832 .39403 L p .817 .903 .901 r
F P
0 g
s
.85986 .43317 m .84678 .44749 L .82413 .39801 L p .903 .854 .783 r
F P
0 g
s
.82413 .39801 m .8366 .38074 L .85986 .43317 L p .903 .854 .783 r
F P
0 g
s
.40211 .46275 m .41445 .47418 L .4014 .50635 L p .565 .522 .765 r
F P
0 g
s
.41505 .51607 m .4014 .50635 L .41445 .47418 L p .622 .561 .765 r
F P
0 g
s
.60838 .36785 m .60017 .36189 L .5663 .36044 L p .304 0 0 r
F P
0 g
s
.5619 .3597 m .5663 .36044 L .60017 .36189 L p .102 0 0 r
F P
0 g
s
.42684 .48382 m .43927 .49123 L .42882 .52268 L p .679 .603 .764 r
F P
0 g
s
.42882 .52268 m .41505 .51607 L .42684 .48382 L p .679 .603 .764 r
F P
0 g
s
.4659 .46542 m .45579 .45892 L .47717 .42815 L p .821 .724 .758 r
F P
0 g
s
.45579 .45892 m .4659 .46542 L .45171 .49616 L p .779 .677 .752 r
F P
0 g
s
.41445 .47418 m .42684 .48382 L .41505 .51607 L p .622 .561 .765 r
F P
0 g
s
.45171 .49616 m .43927 .49123 L .45579 .45892 L p .779 .677 .752 r
F P
0 g
s
.22154 .37026 m .23554 .36871 L .20834 .41568 L p .81 .959 .909 r
F P
0 g
s
.20834 .41568 m .19318 .42214 L .22154 .37026 L p .81 .959 .909 r
F P
0 g
s
.84678 .44749 m .83358 .46139 L .81157 .41482 L p .899 .855 .79 r
F P
0 g
s
.81157 .41482 m .82413 .39801 L .84678 .44749 L p .899 .855 .79 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49832 .39403 L p .839 .787 .802 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45579 .45892 L p .794 .708 .77 r
F P
0 g
s
.76369 .49265 m .74892 .48756 L .73145 .45527 L p .335 .577 .93 r
F P
0 g
s
.71743 .44827 m .73145 .45527 L .74892 .48756 L p .13 .43 .871 r
F P
0 g
s
.44565 .45111 m .45579 .45892 L .43927 .49123 L p .74 .648 .758 r
F P
0 g
s
.43927 .49123 m .42684 .48382 L .44565 .45111 L p .74 .648 .758 r
F P
0 g
s
.45579 .45892 m .44565 .45111 L .47008 .42042 L p .794 .708 .77 r
F P
0 g
s
.49832 .39403 m .4948 .38791 L .52864 .36984 L p .817 .903 .901 r
F P
0 g
s
.4948 .38791 m .49832 .39403 L .47008 .42042 L p .813 .786 .827 r
F P
0 g
s
.43547 .44213 m .44565 .45111 L .42684 .48382 L p .699 .619 .763 r
F P
0 g
s
.42684 .48382 m .41445 .47418 L .43547 .44213 L p .699 .619 .763 r
F P
0 g
s
.83358 .46139 m .82018 .47384 L .79883 .43008 L p .882 .853 .81 r
F P
0 g
s
.79883 .43008 m .81157 .41482 L .83358 .46139 L p .882 .853 .81 r
F P
0 g
s
.77825 .49372 m .76369 .49265 L .74537 .45847 L p .532 .702 .948 r
F P
0 g
s
.73145 .45527 m .74537 .45847 L .76369 .49265 L p .335 .577 .93 r
F P
0 g
s
.42526 .43217 m .43547 .44213 L .41445 .47418 L p .659 .592 .769 r
F P
0 g
s
.41445 .47418 m .40211 .46275 L .42526 .43217 L p .659 .592 .769 r
F P
0 g
s
.38408 .38857 m .39445 .39941 L .36526 .42337 L p .535 .55 .817 r
F P
0 g
s
.36526 .42337 m .35296 .4106 L .38408 .38857 L p .535 .55 .817 r
F P
0 g
s
.37753 .43673 m .36526 .42337 L .39445 .39941 L p .557 .546 .798 r
F P
0 g
s
.37364 .37827 m .38408 .38857 L .35296 .4106 L p .522 .566 .842 r
F P
0 g
s
.35296 .4106 m .3406 .39894 L .37364 .37827 L p .522 .566 .842 r
F P
0 g
s
.52906 .36748 m .52864 .36984 L .4948 .38791 L p .758 .912 .943 r
F P
0 g
s
.39445 .39941 m .40476 .4105 L .37753 .43673 L p .557 .546 .798 r
F P
0 g
s
.3898 .45006 m .37753 .43673 L .40476 .4105 L p .586 .554 .785 r
F P
0 g
s
.41503 .42153 m .42526 .43217 L .40211 .46275 L p .62 .569 .775 r
F P
0 g
s
.40211 .46275 m .3898 .45006 L .41503 .42153 L p .62 .569 .775 r
F P
0 g
s
.40476 .4105 m .41503 .42153 L .3898 .45006 L p .586 .554 .785 r
F P
0 g
s
.3631 .36873 m .37364 .37827 L .3406 .39894 L p .518 .598 .873 r
F P
0 g
s
.3406 .39894 m .32813 .38883 L .3631 .36873 L p .518 .598 .873 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .4948 .38791 L p .813 .786 .827 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44565 .45111 L p .763 .691 .782 r
F P
0 g
s
.66264 .40165 m .65096 .391 L .61677 .37503 L p .546 0 0 r
F P
0 g
s
.60838 .36785 m .61677 .37503 L .65096 .391 L p .551 0 0 r
F P
0 g
s
.44565 .45111 m .43547 .44213 L .46294 .41262 L p .763 .691 .782 r
F P
0 g
s
.82018 .47384 m .80651 .48388 L .78586 .4428 L p .847 .846 .842 r
F P
0 g
s
.78586 .4428 m .79883 .43008 L .82018 .47384 L p .847 .846 .842 r
F P
0 g
s
.35245 .36012 m .3631 .36873 L .32813 .38883 L p .526 .645 .909 r
F P
0 g
s
.32813 .38883 m .31552 .38056 L .35245 .36012 L p .526 .645 .909 r
F P
0 g
s
.5663 .36044 m .5708 .36292 L .60838 .36785 L p .304 0 0 r
F P
0 g
s
.79253 .4907 m .77825 .49372 L .75912 .45744 L p .685 .784 .925 r
F P
0 g
s
.74537 .45847 m .75912 .45744 L .77825 .49372 L p .532 .702 .948 r
F P
0 g
s
.61677 .37503 m .60838 .36785 L .5708 .36292 L p .395 0 0 r
F P
0 g
s
.80651 .48388 m .79253 .4907 L .77262 .45212 L p .786 .827 .884 r
F P
0 g
s
.77262 .45212 m .78586 .4428 L .80651 .48388 L p .786 .827 .884 r
F P
0 g
s
.34167 .35252 m .35245 .36012 L .31552 .38056 L p .544 .705 .945 r
F P
0 g
s
.31552 .38056 m .30273 .37429 L .34167 .35252 L p .544 .705 .945 r
F P
0 g
s
.75912 .45744 m .77262 .45212 L .79253 .4907 L p .685 .784 .925 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43547 .44213 L p .731 .674 .795 r
F P
0 g
s
.43547 .44213 m .42526 .43217 L .45573 .40475 L p .731 .674 .795 r
F P
0 g
s
.4948 .38791 m .49124 .38262 L .52906 .36748 L p .758 .912 .943 r
F P
0 g
s
.49124 .38262 m .4948 .38791 L .46294 .41262 L p .782 .783 .853 r
F P
0 g
s
.33076 .34594 m .34167 .35252 L .30273 .37429 L p .571 .77 .973 r
F P
0 g
s
.30273 .37429 m .28973 .37005 L .33076 .34594 L p .571 .77 .973 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49124 .38262 L p .782 .783 .853 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42526 .43217 L p .698 .659 .808 r
F P
0 g
s
.42526 .43217 m .41503 .42153 L .44846 .39682 L p .698 .659 .808 r
F P
0 g
s
.52949 .36632 m .52906 .36748 L .49124 .38262 L p .68 .903 .975 r
F P
0 g
s
.31969 .34032 m .33076 .34594 L .28973 .37005 L p .602 .832 .987 r
F P
0 g
s
.28973 .37005 m .27651 .36768 L .31969 .34032 L p .602 .832 .987 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41503 .42153 L p .665 .647 .823 r
F P
0 g
s
.41503 .42153 m .40476 .4105 L .44112 .38881 L p .665 .647 .823 r
F P
0 g
s
.48762 .37791 m .49124 .38262 L .45573 .40475 L p .746 .776 .878 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48762 .37791 L p .746 .776 .878 r
F P
0 g
s
.49124 .38262 m .48762 .37791 L .52949 .36632 L p .68 .903 .975 r
F P
0 g
s
.5708 .36292 m .57539 .36635 L .61677 .37503 L p .395 0 0 r
F P
0 g
s
.73145 .45527 m .71743 .44827 L .68639 .419 L p .007 .416 .858 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40476 .4105 L p .633 .64 .839 r
F P
0 g
s
.40476 .4105 m .39445 .39941 L .43372 .38074 L p .633 .64 .839 r
F P
0 g
s
.30848 .33551 m .31969 .34032 L .27651 .36768 L p .634 .88 .987 r
F P
0 g
s
.27651 .36768 m .26306 .36694 L .30848 .33551 L p .634 .88 .987 r
F P
0 g
s
.62531 .38239 m .61677 .37503 L .57539 .36635 L p .407 0 0 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39445 .39941 L p .605 .638 .857 r
F P
0 g
s
.39445 .39941 m .38408 .38857 L .42626 .3726 L p .605 .638 .857 r
F P
0 g
s
.48395 .37348 m .48762 .37791 L .44846 .39682 L p .704 .766 .9 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48395 .37348 L p .704 .766 .9 r
F P
0 g
s
.52993 .36578 m .52949 .36632 L .48762 .37791 L p .595 .875 .993 r
F P
0 g
s
.29711 .33131 m .30848 .33551 L .26306 .36694 L p .666 .912 .978 r
F P
0 g
s
.26306 .36694 m .2494 .36743 L .29711 .33131 L p .666 .912 .978 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38408 .38857 L p .58 .644 .878 r
F P
0 g
s
.38408 .38857 m .37364 .37827 L .41873 .36438 L p .58 .644 .878 r
F P
0 g
s
.48762 .37791 m .48395 .37348 L .52993 .36578 L p .595 .875 .993 r
F P
0 g
s
.74537 .45847 m .73145 .45527 L .69833 .42364 L p .296 .592 .946 r
F P
0 g
s
.68639 .419 m .69833 .42364 L .73145 .45527 L p .007 .416 .858 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37364 .37827 L p .561 .657 .901 r
F P
0 g
s
.37364 .37827 m .3631 .36873 L .41113 .35609 L p .561 .657 .901 r
F P
0 g
s
.48024 .369 m .48395 .37348 L .44112 .38881 L p .66 .753 .919 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48024 .369 L p .66 .753 .919 r
F P
0 g
s
.28562 .32748 m .29711 .33131 L .2494 .36743 L p .695 .928 .967 r
F P
0 g
s
.2494 .36743 m .23554 .36871 L .28562 .32748 L p .695 .928 .967 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .3631 .36873 L p .549 .679 .924 r
F P
0 g
s
.3631 .36873 m .35245 .36012 L .40346 .34772 L p .549 .679 .924 r
F P
0 g
s
.75912 .45744 m .74537 .45847 L .71022 .42455 L p .531 .704 .95 r
F P
0 g
s
.69833 .42364 m .71022 .42455 L .74537 .45847 L p .296 .592 .946 r
F P
0 g
s
.53037 .36527 m .52993 .36578 L .48395 .37348 L p .522 .837 .999 r
F P
0 g
s
.48395 .37348 m .48024 .369 L .53037 .36527 L p .522 .837 .999 r
F P
0 g
s
.47648 .36416 m .48024 .369 L .43372 .38074 L p .619 .739 .932 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47648 .36416 L p .619 .739 .932 r
F P
0 g
s
.8366 .38074 m .82413 .39801 L .77815 .35197 L p .861 .777 .767 r
F P
0 g
s
.77815 .35197 m .78901 .33274 L .8366 .38074 L p .861 .777 .767 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35245 .36012 L p .545 .707 .946 r
F P
0 g
s
.35245 .36012 m .34167 .35252 L .39573 .33928 L p .545 .707 .946 r
F P
0 g
s
.27399 .32374 m .28562 .32748 L .23554 .36871 L p .719 .931 .96 r
F P
0 g
s
.23554 .36871 m .22154 .37026 L .27399 .32374 L p .719 .931 .96 r
F P
0 g
s
.77262 .45212 m .75912 .45744 L .72198 .42133 L p .681 .754 .907 r
F P
0 g
s
.71022 .42455 m .72198 .42133 L .75912 .45744 L p .531 .704 .95 r
F P
0 g
s
.82413 .39801 m .81157 .41482 L .76723 .3707 L p .856 .776 .772 r
F P
0 g
s
.76723 .3707 m .77815 .35197 L .82413 .39801 L p .856 .776 .772 r
F P
0 g
s
.81157 .41482 m .79883 .43008 L .75619 .3879 L p .842 .776 .788 r
F P
0 g
s
.75619 .3879 m .76723 .3707 L .81157 .41482 L p .842 .776 .788 r
F P
0 g
s
.78586 .4428 m .77262 .45212 L .73358 .41391 L p .766 .771 .857 r
F P
0 g
s
.72198 .42133 m .73358 .41391 L .77262 .45212 L p .681 .754 .907 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34167 .35252 L p .55 .74 .964 r
F P
0 g
s
.34167 .35252 m .33076 .34594 L .38792 .33076 L p .55 .74 .964 r
F P
0 g
s
.79883 .43008 m .78586 .4428 L .74498 .40258 L p .815 .775 .816 r
F P
0 g
s
.74498 .40258 m .75619 .3879 L .79883 .43008 L p .815 .775 .816 r
F P
0 g
s
.47269 .35867 m .47648 .36416 L .42626 .3726 L p .584 .725 .94 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47269 .35867 L p .584 .725 .94 r
F P
0 g
s
.73358 .41391 m .74498 .40258 L .78586 .4428 L p .766 .771 .857 r
F P
0 g
s
.53082 .36415 m .53037 .36527 L .48024 .369 L p .477 .799 1 r
F P
0 g
s
.48024 .369 m .47648 .36416 L .53082 .36415 L p .477 .799 1 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33076 .34594 L p .564 .773 .976 r
F P
0 g
s
.33076 .34594 m .31969 .34032 L .38005 .32217 L p .564 .773 .976 r
F P
0 g
s
.46887 .35228 m .47269 .35867 L .41873 .36438 L p .559 .715 .945 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46887 .35228 L p .559 .715 .945 r
F P
0 g
s
.71022 .42455 m .69833 .42364 L .65149 .39527 L p .3 .628 .962 r
F P
0 g
s
.64271 .39343 m .65149 .39527 L .69833 .42364 L p 0 .454 .854 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31969 .34032 L p .585 .803 .983 r
F P
0 g
s
.31969 .34032 m .30848 .33551 L .3721 .3135 L p .585 .803 .983 r
F P
0 g
s
.53127 .36186 m .53082 .36415 L .47648 .36416 L p .465 .768 .996 r
F P
0 g
s
.47648 .36416 m .47269 .35867 L .53127 .36186 L p .465 .768 .996 r
F P
0 g
s
.46501 .34481 m .46887 .35228 L .41113 .35609 L p .546 .71 .947 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46501 .34481 L p .546 .71 .947 r
F P
0 g
s
.53082 .36415 m .53127 .36186 L .58958 .37379 L p .145 .641 .912 r
F P
0 g
s
.72198 .42133 m .71022 .42455 L .66025 .39373 L p .533 .707 .951 r
F P
0 g
s
.65149 .39527 m .66025 .39373 L .71022 .42455 L p .3 .628 .962 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30848 .33551 L p .611 .827 .983 r
F P
0 g
s
.30848 .33551 m .29711 .33131 L .36408 .30475 L p .611 .827 .983 r
F P
0 g
s
.46114 .33616 m .46501 .34481 L .40346 .34772 L p .545 .709 .947 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46114 .33616 L p .545 .709 .947 r
F P
0 g
s
.53172 .35792 m .53127 .36186 L .47269 .35867 L p .479 .745 .987 r
F P
0 g
s
.47269 .35867 m .46887 .35228 L .53172 .35792 L p .479 .745 .987 r
F P
0 g
s
.73358 .41391 m .72198 .42133 L .66896 .38845 L p .663 .726 .897 r
F P
0 g
s
.66025 .39373 m .66896 .38845 L .72198 .42133 L p .533 .707 .951 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29711 .33131 L p .638 .842 .979 r
F P
0 g
s
.29711 .33131 m .28562 .32748 L .35599 .29592 L p .638 .842 .979 r
F P
0 g
s
.58958 .37379 m .59439 .37268 L .65149 .39527 L p .085 .564 .903 r
F P
0 g
s
.66025 .39373 m .65149 .39527 L .59439 .37268 L p .355 .675 .977 r
F P
0 g
s
.45725 .32631 m .46114 .33616 L .39573 .33928 L p .555 .713 .946 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45725 .32631 L p .555 .713 .946 r
F P
0 g
s
.53127 .36186 m .53172 .35792 L .59439 .37268 L p .296 .693 .975 r
F P
0 g
s
.74498 .40258 m .73358 .41391 L .67757 .37936 L p .732 .726 .845 r
F P
0 g
s
.66896 .38845 m .67757 .37936 L .73358 .41391 L p .663 .726 .897 r
F P
0 g
s
.53218 .35198 m .53172 .35792 L .46887 .35228 L p .508 .726 .971 r
F P
0 g
s
.46887 .35228 m .46501 .34481 L .53218 .35198 L p .508 .726 .971 r
F P
0 g
s
.75619 .3879 m .74498 .40258 L .68608 .36671 L p .771 .722 .806 r
F P
0 g
s
.67757 .37936 m .68608 .36671 L .74498 .40258 L p .732 .726 .845 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28562 .32748 L p .663 .848 .971 r
F P
0 g
s
.28562 .32748 m .27399 .32374 L .34782 .287 L p .663 .848 .971 r
F P
0 g
s
.78901 .33274 m .77815 .35197 L .71103 .31356 L p .812 .719 .763 r
F P
0 g
s
.71103 .31356 m .71927 .29362 L .78901 .33274 L p .812 .719 .763 r
F P
0 g
s
.77815 .35197 m .76723 .3707 L .70279 .333 L p .806 .717 .767 r
F P
0 g
s
.70279 .333 m .71103 .31356 L .77815 .35197 L p .806 .717 .767 r
F P
0 g
s
.76723 .3707 m .75619 .3879 L .69448 .35101 L p .793 .718 .781 r
F P
0 g
s
.68608 .36671 m .69448 .35101 L .75619 .3879 L p .771 .722 .806 r
F P
0 g
s
.69448 .35101 m .70279 .333 L .76723 .3707 L p .793 .718 .781 r
F P
0 g
s
.45335 .31534 m .45725 .32631 L .38792 .33076 L p .571 .72 .943 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45335 .31534 L p .571 .72 .943 r
F P
0 g
s
.66896 .38845 m .66025 .39373 L .59921 .36877 L p .536 .709 .951 r
F P
0 g
s
.59439 .37268 m .59921 .36877 L .66025 .39373 L p .355 .675 .977 r
F P
0 g
s
.59921 .36877 m .59439 .37268 L .53172 .35792 L p .437 .715 .983 r
F P
0 g
s
.53172 .35792 m .53218 .35198 L .59921 .36877 L p .437 .715 .983 r
F P
0 g
s
.53264 .34382 m .53218 .35198 L .46501 .34481 L p .543 .711 .949 r
F P
0 g
s
.46501 .34481 m .46114 .33616 L .53264 .34382 L p .543 .711 .949 r
F P
0 g
s
.44943 .30339 m .45335 .31534 L .38005 .32217 L p .593 .729 .939 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44943 .30339 L p .593 .729 .939 r
F P
0 g
s
.67757 .37936 m .66896 .38845 L .60401 .36178 L p .636 .706 .897 r
F P
0 g
s
.59921 .36877 m .60401 .36178 L .66896 .38845 L p .536 .709 .951 r
F P
0 g
s
.5331 .33341 m .53264 .34382 L .46114 .33616 L p .576 .698 .925 r
F P
0 g
s
.46114 .33616 m .45725 .32631 L .5331 .33341 L p .576 .698 .925 r
F P
0 g
s
.60401 .36178 m .59921 .36877 L .53218 .35198 L p .539 .71 .951 r
F P
0 g
s
.44549 .29066 m .44943 .30339 L .3721 .3135 L p .615 .737 .933 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44549 .29066 L p .615 .737 .933 r
F P
0 g
s
.53218 .35198 m .53264 .34382 L .60401 .36178 L p .539 .71 .951 r
F P
0 g
s
.68608 .36671 m .67757 .37936 L .60879 .35164 L p .692 .695 .849 r
F P
0 g
s
.60401 .36178 m .60879 .35164 L .67757 .37936 L p .636 .706 .897 r
F P
0 g
s
.53356 .3209 m .5331 .33341 L .45725 .32631 L p .605 .689 .902 r
F P
0 g
s
.45725 .32631 m .45335 .31534 L .53356 .3209 L p .605 .689 .902 r
F P
0 g
s
.44153 .27742 m .44549 .29066 L .36408 .30475 L p .637 .745 .927 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44153 .27742 L p .637 .745 .927 r
F P
0 g
s
.69448 .35101 m .68608 .36671 L .61354 .33856 L p .724 .686 .813 r
F P
0 g
s
.60879 .35164 m .61354 .33856 L .68608 .36671 L p .692 .695 .849 r
F P
0 g
s
.60879 .35164 m .60401 .36178 L .53264 .34382 L p .606 .696 .907 r
F P
0 g
s
.53264 .34382 m .5331 .33341 L .60879 .35164 L p .606 .696 .907 r
F P
0 g
s
.70279 .333 m .69448 .35101 L .61825 .32296 L p .744 .681 .79 r
F P
0 g
s
.61354 .33856 m .61825 .32296 L .69448 .35101 L p .724 .686 .813 r
F P
0 g
s
.71103 .31356 m .70279 .333 L .62293 .30542 L p .756 .68 .778 r
F P
0 g
s
.61825 .32296 m .62293 .30542 L .70279 .333 L p .744 .681 .79 r
F P
0 g
s
.53401 .30656 m .53356 .3209 L .45335 .31534 L p .63 .684 .882 r
F P
0 g
s
.45335 .31534 m .44943 .30339 L .53401 .30656 L p .63 .684 .882 r
F P
0 g
s
.43754 .26392 m .44153 .27742 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.71927 .29362 m .71103 .31356 L .62759 .28666 L p .763 .683 .774 r
F P
0 g
s
.62293 .30542 m .62759 .28666 L .71103 .31356 L p .756 .68 .778 r
F P
0 g
s
.61354 .33856 m .60879 .35164 L .5331 .33341 L p .648 .682 .868 r
F P
0 g
s
.62759 .28666 m .63227 .26744 L .71927 .29362 L p .763 .683 .774 r
F P
0 g
s
.5331 .33341 m .53356 .3209 L .61354 .33856 L p .648 .682 .868 r
F P
0 g
s
.53447 .29082 m .53401 .30656 L .44943 .30339 L p .65 .682 .867 r
F P
0 g
s
.44943 .30339 m .44549 .29066 L .53447 .29082 L p .65 .682 .867 r
F P
0 g
s
.61825 .32296 m .61354 .33856 L .53356 .3209 L p .676 .672 .838 r
F P
0 g
s
.53356 .3209 m .53401 .30656 L .61825 .32296 L p .676 .672 .838 r
F P
0 g
s
.62293 .30542 m .61825 .32296 L .53401 .30656 L p .695 .667 .818 r
F P
0 g
s
.53493 .27417 m .53447 .29082 L .44549 .29066 L p .667 .684 .857 r
F P
0 g
s
.44549 .29066 m .44153 .27742 L .53493 .27417 L p .667 .684 .857 r
F P
0 g
s
.53401 .30656 m .53447 .29082 L .62293 .30542 L p .695 .667 .818 r
F P
0 g
s
.62759 .28666 m .62293 .30542 L .53447 .29082 L p .709 .666 .806 r
F P
0 g
s
.53539 .25714 m .53493 .27417 L .44153 .27742 L p .68 .69 .852 r
F P
0 g
s
.44153 .27742 m .43754 .26392 L .53539 .25714 L p .68 .69 .852 r
F P
0 g
s
.63227 .26744 m .62759 .28666 L .53493 .27417 L p .718 .671 .802 r
F P
0 g
s
.53447 .29082 m .53493 .27417 L .62759 .28666 L p .709 .666 .806 r
F P
0 g
s
.53493 .27417 m .53539 .25714 L .63227 .26744 L p .718 .671 .802 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?n^/=X00ol0003o]j_=okN[c@04okN[c@_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00006On^/=X00ol0003o
]j_=okN[c@0?okN[c@_o00006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oo
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`Co00000_nW`>/00ol0003o[[3Jojj`fP0Nojj`fP03o`000?ngZlgo]j_=01[o]j_=
1ol0000Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0ol0
0007ojO0j`03o`000?n^/=[o[[3J01go[[3J00?o0000okN[cOngZld07_ngZld00ol0003o`jk6ol>^
aP03o`00017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4
o`0000[oYl3[00?o0000ojj`f_n^/=X03_n^/=X@o`0001oo]j_=00?o0000ol>^a_o3[/H01?o3[/H3
o`0000kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool4o`00
00goYl3[0ol00002ojj`fPgo00003onZ[m/00ol0003o]J[>okFZcP02okFZcPSo00004ongZld00ol0
003o`jk6ol>^aP07ol>^aP?o00002oooool00ol0003oooooooooo`0cooooo`;o0000;_ooool001_o
oooo00?oEEEEofIVI_l000001_ooool2o`0000[ooooo00?o0000ooooooooool0HOooool4o`0000go
Yl3[1?l00002oj>nk@03o`000?nZ[m_oZZoK01coZZoK00?o0000okFZc_neZ/h02_neZ/h7o`0000co
]j_=00?o0000ol>^a_o3[/H02_o3[/H4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
0ol0000=ojO0j`Co00001_nS_^d00ol0003oZZoKojZ_f`0LojZ_f`03o`000?neZ/ko]J[>017o]J[>
2?l00003okN[c@03o`000?o3[/Ko`jk600oo`jk60ol00005ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:oooool002Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Hooooo`Co00002onW`>/5o`0000_oXkk]00?o0000ojZ_fonZ[m/06onZ[m/00ol0003o]J[>okFZ
cP0IokFZcPCo00005?o3[/H3o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000;
ojO0j`Co00004?nS_^d00ol0003oZZoKojZ_f`0KojZ_f`03o`000?neZ/ko]J[>01co]J[>00?o0000
ol6^aol000000_l0000Col>^aP?o0000=oooool00ol0003oooooooooo`0Zooooo`009?ooool2o`00
00kooooo00?o0000ooooooooool0DOooool2o`0000;oZMWh00?o0000ojO0jonW`>/01OnW`>/4o`00
017oXkk]1?l00002ojZ_faco00007_neZ/h00ol0003o`Jk7ol6^a`02ol6^a`?o00004_o3[/H4o`00
03Gooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@ooooo`03o`000?oooooooooo04ko
oooo0_l00005ojWIn003o`000?nW`>_oYl3[00;oYl3[0_l0000@oj>nk@Go00000onM_>h00ol0003o
YZkMojJ^g@0KojJ^g@04o`000?naZ]7o/J[Aok6Zd@Ko00005OneZ/h00ol0003o`Jk7ol6^a`05ol6^
a`?o00003oo3[/H01?l0003o`jk6ol>^a_o3[/H3o`0003?ooooo00?o0000ooooooooool0:?ooool0
02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1;ooooo`;o00001onYfOP3o`00
00koXkk]1_l00008oiflkP03o`000?nV[]goYZkM01_oYZkM00?o0000ok6ZdOnaZ]401onaZ]46o`00
00ko]J[>00?o0000ol6^aoo1[/L02Oo1[/L3o`0000co`jk600?o0000ol>^a_o3[/H00_o3[/H01?l0
003ockS3o`000?l0000`ooooo`;o0000:_ooool002?ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`18ooooo`;o00001_nYfOP3o`0000;oXmOj00?o0000oj>nkOnS_^d01onS_^d5o`00
00ooWKc^00?o0000ojJ^gOnV[]d06_nV[]d00ol0003o/J[Aok6Zd@0=ok6Zd@Ko00002?neZ/h00ol0
003o`Jk7ol6^a`0<ol6^a`;o00002_o3[/H01Ol0003o`jk6ol>^a_o3[/Ko000000CockS30_l0000`
ooooo`03o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0AOooool2o`0000KoZMWh0_l00006oj?GnP03o`000?nS_^goXkk]00;oXkk]1?l0000Aoifl
kPCo00000onV[]d<o`0000goYZkM00?o0000ok6ZdOnaZ]404onaZ]46o`0000;o]J[>00?o0000ol6^
aoo1[/L03_o1[/L3o`0000Ko`jk60_l00003ol>^aP03o`000?o?^<?ockS300CockS300?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Vooooo`008oooool2o`0001Cooooo00?o0000oooooooo
ool0@Oooool3o`0000KoZMWh0_l00008oj?GnPCo00003onM_>h7o`0000?oUk[`00?o0000oj6_hOnQ
[n403OnQ[n4>o`0001_o/J[A0ol0000Col6^a`Ko000000Go`jk6o`000?o3[/Ko`jk6o`000008olnh
``;o0000;_ooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo03kooooo0_l00006ojWIn0?o00001onSeoX3o`000003oicCnol0003oWKc^00[o
WKc^1_l0000;oiNjl003o`000?nQ[n7oXJoQ01WoXJoQ00?o0000ojf/e_n][=H01Ol0000Fok6Zd@03
o`000?nn[/[o000000;o00003oo1[/L6o`0000;o`jk600?o0000ol>^a_l000002_o?^<<2o`0002go
oooo00?o0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0kooooo`;o00001_nYfOP2o`0000SoXmOj0_l00005oicCn`03o`000?nM_>koWKc^00?oWKc^
1Ol0000AoiNjl003o`000?nQ[n7oXJoQ01WoXJoQ00?o0000ojf/e_n][=H01On][=H5o`00013o/J[A
00?o0000okj^b_nn[/X00onn[/X3o`0000Wo`Jk70ol00006ol6^a`Go00003?o?^<<2o`0002_ooooo
00?o0000ooooooooool09Oooool002?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0hooooo`;o00001OnYfOP3o`0000OoXmOj0ol00007oicCn`;o000000?oWKc^o`000?nG^_004_nG
^_07o`0000CoXJoQ0ol0000Coj6_h@03o`000?n][=Ko[JcF00[o[JcF1?l0000<ok6Zd@03o`000?nn
[/[o_Zk:00Ko_Zk:0ol00003ol6^a`?o00003?o1[/L2o`0000kockS30_l0000Yooooo`;o00002?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd02?ooool002;ooooo0ol0000Hooooo`03o`000?oooooooooo03Gooooo0_l00005ojWIn0;o0000
1onSeoX3o`0000OoW=?k0ol00003oiG=n`03o`000?nG^_3oUk[`00CoUk[`3Ol00006oi:hl@03o`00
0?nJ/>KoV[3V00GoV[3V3Ol00006oj6_h@03o`000?n][=Ko[JcF00ko[JcF1Ol00007ok6Zd@03o`00
0?nn[/[o_Zk:00Wo_Zk:0ol0000?ol6^a`Co00003_o?^<<2o`0002Wooooo00?o0000ooooooooool0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oo
oooo000Rooooo`03o`000?oooooooooo01Wooooo0_l0000cooooo`;o00001OnYfOP2o`0000OoXmOj
0_l00007oicCn`?o00001_nEcO/2o`000003oiNjl?l0003o000000;o00004onB^?400ol0003oV[3V
oiZ`iP0BoiZ`iPOo00005On][=H5o`000003ok6ZdOl0003o_Zk:00So_Zk:0ol00003okj^bP?o0000
2oo1[/L01Ol0003oc[O4oljga?l0003oc[O400;o00003_o?^<<2o`0002Oooooo00?o0000oooooooo
ool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01_ooool002;o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`Co00000onYfOP2o`0000Ko
XmOj0ol00006oicCn`?o00001_nEcO/3o`0000;oT<Gi00?o0000oi:hlOnB^?405_nB^?400ol0003o
V[3VoiZ`iP0GoiZ`iP03o`000?nU[]koYJkN00Go00004on][=H2o`0000Ko_Zk:0ol00009okj^bP?o
00002?o1[/L01Ol0003oc[O4oljga?o>]lCo000000;oc[O40_l0000>olnh``03o`000?oooooooooo
02Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0/ooooo`03o`000?nhk_Go^>ke00;o^>ke0ol00006oj?GnP;o00001_nLdo/3o`0000KoULgk0ol0
0006oi35n@03o`000?nB^?7oT[Sa00[oT[Sa3?l0000IoiZ`iP03o`000?nU[]koYJkN00GoYJkN1?l0
000@ojf/eP03o`000?ni[m3o000000Co00003onn[/X3o`0000Co`Jk700?o0000oljga?o>]l@00oo>
]l@01?l0003oc[O4oljga?o>]l@2o`0000gockS30_l0000Vooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_ooool00ol0003o^>keokS^m@02okS^
m@04o`000?nakOOo/Nggok7]m`;o00000_nSeoX2o`0000GoW=?k0ol00006oiG=n`?o00002?n@aOT3
o`000003oi:hlOl0003o000000So00002on>]_800ol0003oTk;/oi>bk004oi>bk0go00001OnJ/>H0
0ol0003oYJkNojF^gP0:ojF^gPCo00002on][=H00ol0003o^Jo@o`000002o`000004okV_d?l0003o
0000o`00017o_Zk:0ol000000oo1[/Oo0000oljga004oljga003o`000?o>]lCoc[O400?oc[O40_l0
000=olnh``;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0:ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
:?ooool00ol0003o^>keokS^m@02okS^m@03o`000?nakOOo/Ngg00?o/Ngg1?l00004oicCn`;o0000
1_nEcO/3o`0000OoT<Gi1?l00002ohbmmP03o`000?n>]_;oS[Kb01GoS[Kb00?o0000oi>bk?nC/^`0
4?nC/^`6o`00013oYJkN1Ol00005ojf/eP?o00001oni[m03o`00017o_Zk:0_l00006oljga003o`00
0?o>]lCoc[O400Coc[O400?o0000olnh`oo?^<<03?o?^<<00ol0003oooooooooo`0Pooooo`?o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000Qooooo`03
o`000?oooooooooo02Kooooo00?o0000okS^mOnhk_D00_nhk_D00ol0003o/Nggok7]m`03ok7]m`03
o`000?nZjO[oZ^Wj00;oZ^Wj0ol00007oiG=n`;o00001_n@aOT4o`0000OoS;gf00?o0000ohjfl_n>
]_802On>]_8<o`0001OoTk;/00?o0000oi^bj?nK/^P01Ol0000>ojF^gPGo000000?o[JcFo`000?ni
[m002_ni[m03o`0000ko_Zk:00Co0000ol^gaol0003o00001Oo>]l@00ol0003oc[O4oljga004oljg
a0;o00003?o?^<<2o`0002Cooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Wooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Tooooo`03
o`000?nhk_Go^>ke00;o^>ke00?o0000ok7]monakOL00onakOL00ol0003oZ^Wjoj[YnP02oj[YnP04
o`000?nRhOcoX^7loj;Qo0;o00000onEcO/00ol0003oT<Gioi35n@03oi35n@Co00002_n<_OH3o`00
00;oS[Kb2?l0000;oh^elP03o`000?n;]_;oRkKb00;oRkKb2?l0000;oi>bk003o`000?nK/^SoVk;X
00GoVk;X1?l00009ojF^gP?o00000_nU[]h2o`0000oo^Jo@0ol0000:okj^bP03o`000?o;]lOobkO7
00;obkO700?o0000oljga?o>]l@00oo>]l@00ol0003oc[O4oljga005oljga0;o00002Oo?^<<01?l0
003og<K4omc6a?l0000Sooooo`03o`000?oooooooooo01oooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool08_ooool01?l0003o^>keokS^mOnhk_D2o`0000Co/Ngg0_l00003oj[YnP;o00001OnR
hO`4o`0000?oT<Gi0ol0000;ohbmmP?o00000on;]?800ol0003oRkGboh^elP0Coh^elP03o`000?n;
]_;oRkKb00WoRkKb2?l00003oi>bk003o`000?nK/^SoVk;X00WoVk;X1?l00002ojF^gP?o00001_nU
[]h00ol0003o/K7Io`000002o`0000ko^Jo@0ol00007okj^bP03o`000?o;]lOobkO700?obkO70_l0
0003oljga003o`000?o>]lCoc[O400Ooc[O40_l00006olnh``03o`000?oLa/Cog<K400;og<K400?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo023ooooo00Go0000okS^mOnhk_Go^>keo`000005ok7]m`03o`000?nZjO[oZ^Wj00;oZ^Wj
00?o0000oj;Qo?nRhO`00onRhO`2o`0000?oV]Cl0ol0000;ohbmmPCo00001on;]?800ol0003oRkGb
oh^elP08oh^elP_o00004on;]_84o`0000ooVk;X1Ol00006ojF^gP03o`000?na/MWo/K7I00;o/K7I
0ol0000>okV_d0?o00001?nn[/X00ol0003obkO7ol^ga`05ol^ga`;o00000_o>]l@00ol0003oc[O4
oljga008oljga0;o00001?o?^<<00ol0003og<K4omc6a003omc6a003o`000?oooooooooo027ooooo
00?o0000ooooooooool07Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool2o`0002Gooooo00?o0000ooooooooool07_ooool01Ol0003o^>keokS^mOnhk_Go000000Go
/Ngg00Co0000oj[Yn_nZjO[oZ^Wj0_l00005oj;Qo003o`000?nJe?coV]Cl00;oV]Cl00Go0000oi;5
nOnBaOWoT/Gio`000006ohbmmPCo00002_n;]?83o`000003oh^el_l0003o000000Ko00002_n;]O80
0ol0003oP[Whoh:in004oh:in0_o00001On;]_800ol0003oRKGcohVel`04o`0000KoVk;X0ol00005
oi^bj0Co000000?oYJkNo`000?na/MT01ona/MT3o`0000ko^Jo@1?l0000:ol^ga`04o`000?o>]lCo
c[O4o`0000_oc[O40_l000000oo?^<?o0000omc6a006omc6a003o`000?oooooooooo023ooooo00?o
0000ooooooooool07Oooool0023ooooo0_l0000Wooooo`03o`000?oooooooooo01cooooo00Go0000
okS^mOnhk_Go^>keo`000004ok7]m`;o00000onZjOX00ol0003oX^7loj;Qo003oj;Qo0;o00000onJ
e?`2o`0000GoT/Gi00Co0000ohbmm_n<_OKoS;gf0_l0000:oh^dlPCo00000_n<[N`00ol0003oRkGb
oh^elP0Boh^elP03o`000?n2^OSoP[Wh00koP[Wh1_l00006ohVel`Ko00003?nK/^P2o`0000_o/K7I
0ol0000>okV_d003o`000?o;]lOobkO700WobkO70ol0000=oljga003o`000?oLa/Cog<K400Oog<K4
00?o0000ooooooooool07oooool2o`0001kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool06_ooool01Ol0003o^>keokS^mOnhk_Go000000Co/Ngg00Co0000oj[Yn_nZjO[o
Z^Wj0_l00004oj;Qo0;o00001?nJe?`00ol0003oT/Gioi;5n@05oi;5n@?o00002?n;]?85o`0000Oo
S:g/00?o0000oh^el_n;]O802?n;]O8;o`0000[oP[Wh00?o0000oh:in?n2^OP01on2^OP01?l0003o
KkOkofngnol00003ohVel`?o000000?oRKGco`000?l000000_l0000;oi^bj004o`000?nR]>Go0000
o`0000_o/K7I0_l0000<okV_d003o`000?o5^<ko000000_obkO70_l0000<oljga003o`000?oLa/Co
g<K400Sog<K400?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`008?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01Sooooo00Co0000okS^mOnhk_Go^>ke1OnakOL0
1Ol0003oZ^Wjoj[Yn_nZjO[o000000GoX^7l00?o0000oi[Do?nJe?`00_nJe?`2o`0000KoT/Gi0_l0
0003oh^dl@;o00000on;]?83o`0000_oS:g/0ol000000on;]O;o0000o`000006o`0000[oSkOa00?o
0000ogZno?mj__`02Omj__`:o`0000?oKkOk1_l00005ohVel`Co00001_nK/^P00ol0003oX[CUoj:d
i@02oj:di@?o00002_na/MT3o`0000So^Jo@00Co0000olFhc_o5^<koaKS>0_l0000;ol^ga`03o`00
0?o>]lCoc[O400Soc[O400?o0000om_6aOl000002_oLa/@00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_oo
ool01?l0003o^>keokS^mOnhk_D5ok7]m`05o`000?nZjO[oZ^Wjoj[Yn_l000001?nRhO`2o`0000Co
V]Cl00?o0000oi;5nOnBaOT01?nBaOT2o`0000KoRkCa0ol0000;ohb]k0Co00000on?Z>H00ol0003o
SkOaohngl@0=ohngl@Go00002Omj__`00ol0003oN[klogZno007ogZno0Co00001om_]o/3o`0000Go
RKGc1?l00002oi^bj003o`000?nR]>GoX[CU00GoX[CU0_l0000;ok6af@?o00001?ni[m000ol0003o
aKS>olFhcP04olFhcP03o`000?o;]lOobkO700WobkO70_l00008oljga004o`000?oKa/GoflK5o`00
00[og<K400?o0000ooooooooool07oooool00ol0003oooooooooo`0Jooooo`008?ooool2o`0002_o
oooo00?o0000ooooooooool05?ooool01?l0003o^>keokS^mOnhk_D5ok7]m`CoZ^Wj1OnRhO`00ol0
003oV]Cloi[Do003oi[Do003o`000?nBaOWoT/Gi00?oT/Gi0_l00006oh^dl@;o00000_n6YNP00ol0
003oS:g/ohb]k005ohb]k0Co00002?n?Z>H00ol0003oSkOaohngl@04ohngl@So00001?nE^O000ol0
003oMlCnogO4oP08ogO4oP[o00001_m;/OT3o`0000CoKkOk1?l00005ohVel`;o00002_nR]>D2o`00
00co/K7I0ol000000oni[m3o0000olFhcP06olFhcP;o00002Oo;]lL01?l0003obkO7o`000?l00005
oljga003o`000?oKa/GoflK500;oflK500?o0000omc6a?oLa/@02?oLa/@00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool04_ooool01?l0003o^>keokS^mOnhk_D5ok7]m`03oj[Yn_l0003o000000?o00000onRhO`6
oi[Do003o`000?nBaOWoT/Gi00?oT/Gi00?o0000oh^dlOn;]?401?n;]?42o`0000GoQZGX00Co0000
ohb]k?n<[NcoS:g/0ol0000;ohnXiP?o000000CoSkOao`000?l0003o00002_nE^O05o`0000WoMlCn
2_l00002obFTj@;o00001om;/OT3o`0000?oKkOk1?l00002ohVel`03o`000?n9]O?o000000[oX[CU
0ol0000<ok6af@03o`000?o5^<koaKS>00SoaKS>00?o0000ol^gaoo;]lL01oo;]lL01?l0003obkO7
ol^gaol00003oljga003o`000?oKa/GoflK500CoflK500?o0000omc6a?oLa/@02?oLa/@00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo000Pooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool04?ooool;o`0000;oa??_00?o0000ok[/m?njk?@01Ol00003oi[Do0GoT/Gi
0_l00005oh^dl@;o00001on6YNP3o`0000_oSjSV1?l00003oiBTh003o`000?nE^O3oUKW`00CoUKW`
1ol00004oijmkP?o00002?mjc?l3o`0000;oQMKo00?o[^Oio`000?l000000ole^m@00onTlo;o9JCY
obFTj@02obFTj@Co00001?m;/OT4o`0000;oKkOk0_l00005ohVel`;o00002OnR]>D2o`0000[o/K7I
00?o0000ok^if?o5^<h02Oo5^<h2o`0000SobkO700?o0000ol^gaoo;]lL00_l000000oo>]lCo0000
om_6a@06om_6a@03o`000?oLa/Cog<K400Sog<K400?o0000ooooooooool07Oooool2o`0001[ooooo
000Pooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03_ooool2o`0000;ocoGX00?o
0000ol_fjoo;m^/00_o;m^/01Ol0003oa??_olCckoo4lnoo000000Co^^cd00Co0000ojgOnOn]goWo
[Moi1?l00003oi;5n@03o`000?n;]?7oRkCa00CoRkCa00?o0000ohJUj?n6YNP01On6YNP2o`0000?o
Q9WO00?o0000ohnXi_n?Z>H01On?Z>H3o`0000OoU:CP0_l000000onE^O3o0000o`000009oijmkPCo
00000_nX`>/00ol0003oQMKoohGFo`03ohGFo`?o00000_nHgoh2ojkWn@;o000000GodNOVo`000?nT
lo;oY??bo`000002olWdk004omc[g_l0003obO3]olW`k@;og>GK0_lUY>T5o`000004oeL00?m;/OWo
0000o`0000?oFZcj00?o0000ohVelon9]O<00on9]O<3o`0000SoX[CU0_l00007ok6af@03o`000?nk
^MSo^kWH00;o^kWH00?o0000olFhc_o5^<h01oo5^<h2o`0000OobkO700Go0000ol^gaoo;]lOobkO7
o`000009om_6a@03o`000?oLa/Cog<K400Sog<K400?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Hooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo00Co
0000oloej?o?mNSo00001?o;m^/01Ol0003oa??_olCckoo4lnoo000000Co^^cd00?o0000ojgOnOn]
goT00on]goT00ol0003oW<_hoic;n003o`0000GoRkCa0_l00007ohJUj003o`000?n4VMooQ9WO00Co
Q9WO00Co0000ohnXi_n?Z>KoSjSV0ol00007oiBTh0?o00000_nJXm/00ol0003oW[g^oijmkP06oijm
kP?o00001_nX`>/2o`000005ohGFool0003o0000o`000?nHgoh01?n^ioT01?l0003o`^Waol;YlOoA
inH2o`0000?obOC/0_oLjmh2o`0000Cog>GK00?o0000om7Oh_oAgn800_oAgn801?l0003o9JCYo`00
0?l00003oaF@i`CoFZcj0_l00005ohVel`;o00002?nR]>D3o`0000?o/K7I00?o0000ok^if?nk^MP0
1?nk^MP2o`0000WoaKS>00?o0000ol^gaoo;]lL01?o;]lL01?l0003obkO7ol^gaoo;]lL2o`0000Wo
flK500?o0000omc6a?oLa/@02?oLa/@00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oo
oooo000Oooooo`;o0000<Oooool00ol0003oooooooooo`0;ooooo`05o`000?o?mNSocoGXoloej?l0
00000oo;m^/00ol0003oa??_olCck`02olCck`05o`000?njk?Co^^cdok[/m?l000001On]goT00ol0
003oW<_hoic;n002oic;n004o`000?n:/o7o0000o`0000;oRkCa00?o0000ohJUj?n6YNP01On6YNP2
o`0000OoQ9WO0ol00009oiBTh0;o00001_nJXm/00ol0003oW[g^oijmkP02oijmkP;o00001onX`>/6
o`000003oiSOo_n^ioWo[^Oi00;o[^Oi00Co0000ol;YlOo2jO7o`^Wa0_oAinH01?l0003ofn7Ko`00
0?o9m>`3omc[gP03o`000?oSh=7o000000;og>GK1ol00004olK?h@03o`000?lET>Oo5I3W00?o5I3W
1?mJ[?X2o`0000CoRKGc0_l00009oj:di@;o000000?o/K7Io`000?nk^MP01onk^MP2o`0000SoaKS>
0_l00005ol^ga`03o`000?o;]lOo000000;oelK900?o0000om_6aOoKa/D01ooKa/D00ol0003og<K4
omc6a008omc6a003o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool001oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`04o`000?o?mNSocoGXo`0000CoboK[
00Go0000olCckoo4lnooa??_o`000003ok[/m003o`000?n]goWo[Moi00?o[Moi00?o0000oic;n?nL
boP00_nLboP00ol0003oR[?aohZcl@02ohZcl@;o00001_n6YNP2o`0000SoQ9WO00?o0000ohF@eol0
00002?nDY>02o`0000SoVZ?K0ol00008ojS0j`Oo000000?o_/KPo`000?n^ioT00_n^ioT01?l0003o
`^Waol;YlOo2jO42om7WiP;o000000?ofn7Ko`000?l000000_oLjmh2o`000003on?PdOl0003og>GK
00;o000000?ohmW<o`000?oNe]000ooNe]001Ol0003oelg@o`000?o6cn7o000000?o_kgH00?o0000
oaF@iolET>L00_lET>L01?l0003oFZcjoeZ/n_mJ[?X2o`0000CoRKGc0ol00008oj:di@03o`000?nk
^MSo^kWH00Wo^kWH00?o0000olFhc_o5^<h01oo5^<h00ol0003obkO7ol^ga`03ol^ga`03o`000?oG
a/WoelK900;oelK900?o0000om_6aOoKa/D01ooKa/D00ol0003og<K4omc6a008omc6a003o`000?oo
oooooooo01cooooo00?o0000ooooooooool05_ooool001oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`08ooooo`04o`000?o?mNSocoGXo`0000CoboK[00Go0000olCckoo4lnooa??_
o`000004ok[/m003o`000?n]goWo[Moi00;o[Moi00?o0000oic;n?nLboP00_nLboP00ol0003oR[?a
ohZcl@03ohZcl@;oNYcW00?o0000ohJUj?n6YNP00_n6YNP00ol0003oQ9WOohBIg`06ohBIg`;o0000
0on5T=L00ol0003oU:CPoiBTh003oiBTh0;o00002?nJXm/2o`000003oj:Se_l0003oZ<3[00GoZ<3[
0ol000000onda>Ko0000o`000002o`0000?o_/KP0_l00005ol;Yl@;odNOV00So0000om_QfooKhM_o
0000on7Kd?l0003og>_No`0000?ohn3A0_l00002on?Ic003o`000?oNe]3og]K@00;og]K@00Go0000
omO=d?oGcM3oelg@o`000004oknmf004o`000?nQ/>;oXK3Roj6`hP?o5I3W0_l00002oeZ/nP;o0000
1On9]O<2o`0000GoX[CU00Co0000ojViiOnY^NGo00002_nk^MP2o`0000SoaKS>0_l00003ol^ga`;o
00001?oGa/T00ol0003oflK5om_6a@07om_6a@03o`000?oLa/Cog<K400Oog<K400?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Kooooo00Go0000oloej?o?mNSocoGXo`000003ol_fj`05o`000?o4lnooa??_olCc
kol000001?njk?@00ol0003o[MoiojgOn@02ojgOn@03o`000?nLboSoW<_h00;oW<_h00?o0000ohZc
lOn:/o400on:/o401Ol0003oNYcWogZLiomjW>Oo000000;oQZGX00?o0000ohBIgon4VMl01On4VMl2
o`0000KoQI3G00Co0000oiBTh?nDY>3o00002OnJXm/2o`0000CoXZ?F00Co0000ojS0jonX`>_oZ<3[
0_l000001_nda>Ko0000o`000?l0003o]<CVo`0000?o_/KP0_l00002olS8fP03o`000?o2jO7o`^Wa
00?odNOV00Co0000om_QfooKhM_o00000_oQfm001?oLjmkohn3Aon?PdOoSh=42o`0000CohmW<00Go
0000omkFd?oNe]3og]K@o`000003omO=d0;o00001Ono_MP01_l0003oXK3Roj6`h_nQ/>;o0000ogFI
i`?o5I3W00?o0000oeZ/n_mJ[?X00_l00005ohVel`?o000000?oX[CUo`000?nY^ND01?nY^ND00ol0
003o^kWHok^if008ok^if0;o00002?o5^<h01Ol0003obkO7o`000?oGa/Wo000000GoelK900?o0000
om_6aOoKa/D01ooKa/D00ol0003og<K4omc6a005omc6a003o`000?oWf/So000001gooooo0ol0000F
ooooo`007oooool2o`0003Gooooo0_l00006ooooo`04o`000?o?mNSocoGXo`0000CoboK[00Go0000
olCckoo4lnooa??_o`000003ok[/m003o`000?n]goWo[Moi00?o[Moi00Go0000oic;n?nLboSoW<_h
o`000005ohZcl@03o`000?mjW>OoNYcW00?oNYcW0_l00007ohBIg`03o`000?n5T=OoQI3G00KoQI3G
0ol00007oiZSf`?o00001_nRXmH3o`000004okC4i_l0003o0000o`0000;o]<CV00?o0000okk6h?nn
a^000_nna^000ol0003ob<SJolS8fP02olS8fP;o00000ooAinH01?l0003ofn7Kom_Qfol00002on7K
d007o`000?oSh=7ohn3Aon?PdOl0003oi]O6o`000004on?Ic004o`000?oNe]3og]K@o`0000?oelg@
00Co0000om73c?oA`lco00001?no_MP00ol0003oXK3Roj6`hP06o`0000;o5I3W0_l000001?mJ[?[o
0000o`000?l00005ohVel`03o`000?nY^NGoZKWU00GoZKWU0_l0000:ok^if003o`000?o5^<koaKS>
00KoaKS>0_l00002omO6b@03o`000?oGa/WoelK900?oelK900?o0000om_6aOoKa/D01ooKa/D00ol0
003og<K4omc6a003omc6a004o`000?oWf/Soim[8o`0001oooooo00?o0000ooooooooool05?ooool0
01kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`05o`000?o?mNSocoGX
oloej?l000000oo;m^/01Ol0003oa??_olCckoo4lnoo000000Co^^cd00?o0000ojgOnOn]goT00_n]
goT00ol0003oW<_hoic;n002oic;n003o`000?n:/o7oR[?a00;oR[?a00?o0000ogZLiomjW>L01?mj
W>L2og2:g0;o00000on4VMl2o`0000SoQI3G00Go0000ohR<dOn8S=7oR8cAo`000004oiZSf`;o0000
1onRXmH2o`000004ojZUd_l0003o0000o`0000Co]<CV00Co0000okk6h?nna^3o_/KP0_l00004olS8
fP03o`000?o@bM?o000000;odNOV0ooKhM/3on7Kd0;o00000_oSh=401?l0003oi]O6onKGa_l00002
on?Ic0Oo000000?oelg@o`000?oA`l`00_oA`l`01?l0003o_kgHoknmf?no_MP4o`0000;oYj?B1?n;
TM@2o`000003ocmhh?lET>Oo000000;o000000GoFZcjo`000?l0003oRKGco`000003ohRdl`SoZKWU
0_l00009ok^if0;o00001_o5^<h00ol0003od<K@o`000002omO6b@03o`000?oGa/WoelK900?oelK9
00?o0000om_6aOoKa/D01ooKa/D01Ol0003og<K4omc6a?oLa/Co000000?oim[800?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003oooooooooo`0hooooo`05o`00
0?ooooooooooooooool000000_o?mNP00ol0003oboK[ol_fj`02ol_fj`04o`000?o4lnooa??_o`00
00Co^^cd00?o0000ojgOnOn]goT00_n]goT00ol0003oW<_hoic;n002oic;n003o`000?n:/o7oR[?a
00;oR[?a00?o0000ogZLiomjW>L01?mjW>L00ol0003oL8[Log2:g002og2:g003o`000?n4VMooQ9WO
00SoQI3G0_l00005ohR<d@04o`000?nJXm_oVZ?Ko`0000SoXZ?F1?l00002ojZUdP04o`000?nda>Ko
]<CVo`0000?o_/KP0_l00005olS8fP03o`000?o@bM?od<WC00;o00000ooKhM/3on7Kd004o`000?oT
eLSo0000on?Pd@?oi]O600Ko0000on?Ic?l0003o0000onKA`Ol00002on??``04o`000?oOblCogl_4
o`0000GodL?<0ol00002okjac@CoYj?B00?o0000oh^Ae?n;TM@00_n;TM@2ofemdP04ocmhh?l0003o
0000o`1dfPCo00001On8]?<2o`0000OoZKWU0_l00009ok^if0;o00000oo5^<h01Ol0003od<K@om36
d?o@a]3o000000;oelK900?o0000omO6bOoGa/T00ooGa/T00ol0003oflK5om_6a@07om_6a@03o`00
0?oLa/Co000000Goim[800?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
o`000003oloej005o`000?o;m^_oboK[ol_fjol000000oo4lnl01Ol0003o^^cdok[/m?njk?Co0000
00Co[Moi00?o0000oic;n?nLboP00_nLboP00ol0003oR[?aohZcl@03ohZcl@03o`000?mjW>OoNYcW
00?oNYcW00?o0000og2:g?m`R]`01?m`R]`00ol0003oQI3GohF@e`06ohF@e`03o`000?n8S=7oR8cA
00GoR8cA0_l00008oj:SeP?o00001OnZYM82o`0000Co_/KP00?o0000olS8f_o8b=X00oo8b=X2o`00
00;od<WC00?o0000omK9cOl000000_oKhM/3on7Kd004o`000?oTeLSoi=G8o`0000Coi]O600?o0000
onKA`OoVdL400_oVdL42on??``05o`000?oOblCogl_4omo;a?l000001?oA`l`2o`0000Co_[7=00Go
0000ojNSd_nWXm;oYj?Bo`000004oh^Ae008o`000?m]OM;oKGgBo`000?l<EM3o03nWo`000?l0M=X3
odbPmPKoR;Cc0_l00007ojVii@03o`000?nk^MSo^kWH00So^kWH00?o0000olFhc_l000001Oo@a]00
0ol0003oelK9o`000006omO6b@03o`000?oKa/GoflK500OoflK500?o0000onOJb?oWf/P01?oWf/P0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo000Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`0jooooo`05o`000?o?mNSocoGXoloej?l000000oo;
m^/01_l0003oa??_olCckoo4lnoo0000ok[/m0ko00001?n:/o400ol0003oNYcWogZLi`03ogZLi`03
o`000?m`R]coL8[L00GoL8[L00?oJggCo`000?n5T=L01On5T=L00ol0003oR8cAohR<d@05ohR<d@03
o`000?n>Rlco000000GoXZ?F0ol00007ojZUdP04o`000?nbZ<ko/ZS>o`0000;o_/KP00?o0000olS8
f_o8b=X00oo8b=X01Ol0003od<WCom39doo@bM?o000000?oe/W=00?o0000on7Kd?oQfm000_oQfm03
onCEb004o`000?oVelKoi]O6onKGaP;o00000ooVdL401?l0003ohlo3on??`ol00002omo;a003o`00
0?oLaL;o000000;odL?<00?o0000olnka_l000001?nn/Ld01Ol0003oYj?BojNSd_nWXm;o000000Co
Ri7D00Co0000ofemd_m]OM;oKGgB0_l000001?l<EM3o03nWo`1df_l00003odbPmP03o`000?n8]??o
R;Cc00?oR;Cc00?o0000ojViiOnY^ND01OnY^ND2o`0000Wo^kWH00?o0000om36d?o@a]001Oo@a]00
0ol0003oelK9o`000006omO6b@03o`000?oKa/GoflK500KoflK500?o0000onOJb?oWf/P01OoWf/P0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03
ooooo`004oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0>_ooool0
1Ol0003ocoGXoloej?o?mNSo000000?oboK[00?o0000olCckol000000ol00002olkYj003o`000?nn
go3o_]o`00;o_]o`00?o0000ojO=m?nWcO@00_nWcO@2ohVclP;o000000?oR[?ao`000?mjW>L01Omj
W>L00ol0003oL8[Log2:g004og2:g004o`000?m[OM?oJggCo`0000?oQI3G0_l00007ohR<d@06o`00
0?n>RlcoSX_<ohj;c?l0003oXZ?F1?l00008ojZUdP04o`000?nbZ<ko/ZS>ok:XcP;o00001_o8b=X0
1Ol0003od<WCom39doo@bM?o000000Coe/W=00Co0000on7Kd?oQfm3ohM_@0ooTeLP2o`0000;oi]O6
00?o0000onO?__l000000_oVdL401?l0003ohlo3on??`ol00002omo;a006o`000?oLaL;og<G2o`00
0?oA`lco00000_o?^lH00ol0003o_[7=okjac@02okjac@03o`000?nWXm;oYj?B00;oYj?B00Go0000
oh^Ae?n;TMCoRi7Do`000003ofemdP;oD6W=00Ko0000o`aEd?l0>[oo03nWo`1df_l00002odbPmP;o
00001?n8]?<2o`0000OoZKWU0_l00006ok^if0;o00002?o@a]000ol0003oelK9o`000006omO6b@03
o`000?oKa/GoflK500CoflK500?o0000onKJb_l000001_oWf/P00ol0003oooooooooo`0Mooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000>_ooool01Ol0003ocoGXoloej?o?mNSo000000?oboK[0ol000000ooH
kN;o0000olkYj003olkYj003o`000?nngo3o_]o`00;o_]o`00?o0000ojO=m?nWcO@00_nWcO@4ohVc
lP;o00001OmjW>L00ol0003oL8[Log2:g004og2:g003o`000?m[OM?oJggC00;oJggC00?o0000ohF@
eon5T=L02?n8S=401?l0003oSX_<ohj;c?n>Rl`3o`0000;oXZ?F00?o0000ojZUd_nZYM801OnZYM82
o`0000?o/ZS>00Co0000ok^/bonk[<_o00001?o8b=X4om39d`03o`000?oFbLgoe/W=00;oe/W=00Co
0000om_9aol0003ohM_@0ooTeLP01Ol0003oiM31o`000?oVelKo000000;oilnn00Co0000onKA`OoV
dL7o00000_oScl<01?l0003ogl_4omo;a?l00003omc5`P03o`000?o?^lKock_600;ock_600Go0000
okjacOnn/Lgo_[7=o`000004ojNSdP03o`000?n;TMCoRi7D00;oRi7D00Co0000ofemd_m]OM;o0000
0om@JLd01_l0003o03Zoo`0j_ol0?jOo07CJo`0000;oC:3f0_l00004ohRdl`;o00001onY^ND00ol0
003o^kWHok^if002ok^if004o`000?o4aM_oa<GKo`0000Sod<K@00?o0000omO6bOl000001_oGa/T0
0ol0003oflK5om_6a@02om_6a@04o`000?oVf/[oi][:o`0000Koim[800?o0000ooooooooool07ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0jooooo`04o`000?o?mNSocoGXo`0000;oboK[
0_l00004omS]hP03o`000?o>jNSoc^WX00;oc^WX00?o0000okkOl?nngo000_nngo000ol0003oYlgd
ojO=m002ojO=m004o`000?n9/o;oRK?bohVclP;oJYGX0ol000000omjW>Oo0000og2:g005og2:g003
o`000?m[OM?oJggC00CoJggC00?o0000ohR<dOn8S=401On8S=42o`000004ohj;c?l0003o0000o`00
00?oSX_<00?o0000ojZUd_nZYM801_nZYM800ol0003o/ZS>ok:XcP02ok:XcP03o`000?nk[<_o^jc;
00;o^jc;00?o0000olS8f_o8b=X01?o@bM<5omK9c@04o`000?oKbLOoflW7o`0000?oi=G800Go0000
onG@`OoUd<7o0000onKGaP02onO?_P03o`000?oVdL7oi]7100Go000000?ogl_4o`000?oLaL800_oL
aL82o`0000Cock_600Go0000okjacOnn/Lgo_[7=o`000004ojNSdP03o`000?n;TMCoRi7D00;oRi7D
00Co0000ofemd_m]OM;o00001?m@JLd01?l0003o03Zoo`000?l0;;D3o`0000;oC:3f00?o0000ohRd
lon8]?<00on8]?<00ol0003oZKWUojVii@05ojVii@;o000000?o^kWHo`000?o4aM/00oo4aM/00ol0
003od<K@om36d006om36d0;o00001ooGa/T01Ol0003oflK5om_6aOoKa/Go000000?oi][:00?o0000
onOJb?oWf/P01?oWf/P00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool001?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo03Wooooo00Co0000oloej?o?mNSocoGX0ol000000ooMk]go0000omS]hP03omS]hP03o`000?o>
jNSoc^WX00;oc^WX00Go0000okkOl?nngo3o_]o`o`000004ojO=m003o`000?n9/o;oRK?b00;oRK?b
1OmZUNP00ol0003oL8[Log2:g004og2:g003o`000?m[OM?oJggC00GoJggC00?oJgK<o`000?n8S=40
1?n8S=44o`0000GoSX_<00?o0000oiJ=b?l000001OnZYM82o`0000Co/ZS>00?o0000ok^/bonk[</0
1?nk[</00ol0003od<WCom39d`02om39d`Goe/W=00Go0000om_9aooKbLOoflW7o`000002onCEb005
o`000?oUd<7oiM31onG@`Ol000000ooWckh01?l0003oi]71onO;^ol00002onK:^`03o`000?oTb;co
000000?og<G200?o0000om[1`?l000001?o?^lH00ol0003o_[7=o`000008o`0000?oRi7D00Co0000
ofemd_m]OM;o00001?m@JLd00olhF/So0000o`0j_`02o`0/]@03o`0oYol0M=[o000000;oC:3f0_l0
0004ohRdl`;o00001_nY^ND2o`0000Koa<GK00?o0000om36d?o@a]001_o@a]02o`0000OoelK900?o
0000om_6aOl000001?oVf/X00ol0003oim[8onOJb004onOJb003o`000?oooooooooo01oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`004oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0>?ooool00ol0003ocoGXoloej002o`0000CogNkM00?o
0000omS]h_oHkN800_oHkN800ol0003oc^WXolkYj002olkYj005o`000?nngo3o_]o`okkOl?l00000
1?nWcO@00ol0003oRK?bohVclP02ohVclP03o`000?mZUNSoJYGX00;oJYGX00?oDG[Lo`000?m`R]`0
1?m`R]`00ol0003oJggCof]md`04of]md`04o`000?m[M/coJgK<o`0000;oR8cA0ol00007ohj;c005
o`000?nFSLSoUXg8oiJ=b?l000001?nZYM85ok:XcP03o`000?nk[<_o^jc;00Go^jc;0_l00002om39
d`Goe/W=00Ko0000om_9aooKbLOoflW7o`000?oOb<82o`0000CoiM3100Go0000onO?__oWckkoilnn
o`000002onO;^`03o`000?oVb[_oi/Zk00;oi<Rl00Co0000omc5`_oLaL;o00000_oJ`L001?l0003o
ck_6olnka_o?^lH3o`0000;o`Zg500?o0000ok6PaonaX<L00_naX<L01_l0003oWY?8o`000?l0003o
Ri7Do`0000?oKGgB00co0000oe1YcOm@JLgoD6W=o`000?lhF/So03Zoo`000?l0;;Go0000o`0Z/ol0
?jL2o`0000;oC:3f0_l00004ohRdl`;o00000onY^ND01?l0003o[/7Xojk1j?l00006olC5f`03o`00
0?o@a]3od<K@00Kod<K@0_l00007omO6b@03o`000?oVf/[oi][:00Coi][:00?o0000onOJb?oWf/P0
0ooWf/P00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>Oooool3o`000003omo]
fol0003ogNkM00?ogNkM00?o0000omS]h_oHkN800_oHkN800ol0003oc^WXolkYj002olkYj005o`00
0?nngo3o_]o`okkOl?l000001?nWcO@00ol0003oRK?bohVclP02ohVclP03o`000?mZUNSoJYGX00;o
JYGX0_mAN]`01Ol0003oL8[Log2:g?m`R]co000000KoJggC00Co0000of]fc?m[M/coJgK<1?l00008
ohj;c003o`000?nFSLSoUXg800?oUXg800?o0000ojZUd_nZYM801OnbZ<h00ol0003o^jc;ok^/b`05
ok^/b`04o`000?o3/<So`k38o`0000Goe/W=00Go0000om_9aooKbLOoflW7o`000002omo8`P03o`00
0?oUd<7oiM3100;oiM310_l00002onO?_P;o000000Soil^ko`000?oVb[_oi/Zko`000?oTb;co0000
on?6^`;o00000ooJ`L04o`000003om2f`Ol0003o`Zg500;o`Zg500?o0000ok6PaonaX<L00_naX<L0
0ol0003oWY?8oijCb002oijCb0;o00000_m]OM801Ol0003oD6W=oe1YcOm@JLgo000000;o>5[800?o
03Zoo`000?l0;;D00_l0:[<01?l0>kOo0000o`000?l00002odbPmP03o`000?n8]??oR;Cc00?oR;Cc
00?o0000ojViiOl000001?n^`NP00ol0003oa<GKolC5f`04olC5f`03o`000?o@a]3od<K@00Kod<K@
0_l00006omO6b@03o`000?oVf/[oi][:00Coi][:00?o0000onOJb?oWf/P01?oWf/P00ol0003ooooo
ooooo`0Oooooo`;o00001oooool00ol0003oooooooooo`05ooooo`007Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oOkM_ogngK00;ogngK00?o0000omg^gOoMk]d00_oMk]d00ol0003of>gRomS]
hP02omS]hP05o`000?o>jNSoc^WXolkYj?l000001?nngo000ol0003oYlgdojO=m002ojO=m003o`00
0?n9/o;oRK?b00;oRK?b00Go0000ofZEj?mZUNSoJYGXo`000003oe5jg003o`000?m`R]co000000Oo
JggC1?l00002of]fc003o`000?n>RlcoSX_<00KoSX_<00?o0000oiJ=b?nFSLP01OnFSLP00ol0003o
/ZS>ok:XcP03ok:XcP03o`000?nk[<_o^jc;00Go^jc;00Co0000ol>`b?o3/<So`k380_l00003omK9
c@05o`000?oKbLOoflW7om_9aol000000ooOb<803ol0003oiM31onG@`OoUd<7o0000onK<_?l0003o
ilnno`000?oWbkWo0000onO;^ol0003oi/Zko`000002onC8_003o`000?oSa[_o000000Cof/7000?o
0000om2f`Oo@]/400_o@]/401Ol0003o`Zg5ol:]aOo2[LGo000000?o/J3700?o0000oijCb?nNTlP0
0onNTlP2oh^5a`03o`000?m]OM;o000000?oD6W=00Oo0000ocQJb?lhF/So>5[8o`000?l0;;Go0000
00;o02Zc00Co03^go`000?l0M=[o00000_m<X?H2o`0000;oR;Cc0ol00006ojk1j003o`000?o4aM_o
a<GK00Coa<GK00?o0000om36d?o@a]001_o@a]000ol0003oelK9omO6b@03omO6b@03o`000?oQf/oo
000000Koi][:00?o0000onOJb?oWf/P00ooWf/P00ol0003oooooooooo`0Nooooo`03o`000?oooooo
000000Gooooo00?oEEEEofIVI_l000001oooool001gooooo00?o0000ooooooooool0=oooool00ol0
003ogngKomo]f`02omo]f`03o`000?oMk]gogNkM00;ogNkM00?o0000omS]h_oHkN800_oHkN801Ol0
003oc^WXolkYj?o>jNSo000000Co_]o`00?o0000ojO=m?nWcO@00_nWcO@01Ol0003oRK?bohVcl_n9
/o;o000000CoJYGX00?o0000oe5jg?mAN]`00_mAN]`2o`0000KoJggC0_l00005of]fc003o`000?n>
RlcoSX_<00GoSX_<00?o0000oiJ=b?nFSLP01OnFSLP00ol0003oWY76o`000004ok:XcPOo^jc;00Go
0000ol>`b?o3/<So`k38o`000002ol^ea@03o`000?oFbLgoe/W=00?oflW700Co0000omo8`_oOb<;o
glS20_l00002onG@`@03o`000?oVc;coi/bl00;o000000Coil^io`000?oWbk_oil^k0_l00002onC8
_004o`000?oSa[_ohlJko`0000?of/700_l00004om2f`@05o`000?o2[LGo`Zg5ol:]aOl000000ona
X<L00ol0003oWY?8oijCb003oijCb0?oRhG700?oKGgBo`000?m@JLd00om@JLd01ol0003o>5[8ocQJ
b?lhF/So0000o`0/]Ol000000_l0:[<2o`000003o`5Zfol0003o000000Co00000on7]?<00ol0003o
[/7Xojk1j004ojk1j003o`000?o4aM_oa<GK00Coa<GK00?o0000om36d?o@a]001_o@a]001Ol0003o
elK9omO6bOoGa/Wo000000;ohM[?00?o0000onKJb_oVf/X01?oVf/X00ol0003oim[8onOJb004onOJ
b003o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool001cooooo00?o0000oooooooo
ool0>?ooool00ol0003ogngKomo]f`02omo]f`03o`000?oMk]gogNkM00;ogNkM00Go0000omS]h_oH
kN;of>gRo`000004olkYj005o`000?nngo3o_]o`okkOl?l000001?nWcO@00ol0003oRK?bohVclP02
ohVclP03o`000?mZUNSoJYGX00;oJYGX00?o0000oe5jg?mAN]`00_mAN]`2od9Vd@03o`000?m[OM?o
JggC00?o00001_m[M/`00ol0003oL7C7o`000005ohj;c003o`000?nFSLSoUXg800GoUXg800Go0000
oijAa_nNTLKoWY76o`000002ok:XcPOo^jc;00Go0000ol>`b?o3/<So`k38o`000004ol^ea@03o`00
0?oKbLOoflW700;oflW700Co0000omo8`_oOb<;o00000_oRb;h2o`0000?oi/bl00[o0000onO;^OoW
bkWo0000onO;^ol0003oi/Zko`000?oTb;co00000_oSa[/2o`0000;of/7000?o0000omZn_Ol00000
0oo@]/401Ol0003o`Zg5ol:]aOo2[LGo000000Co/J3700?o0000oijCb?nNTlP00_nNTlP00ol0003o
RhG7oh^5a`02oh^5a`;o00000om@JLd01ol0003o>5[8ocQJb?lhF/So:535o`000?l0;;D00_l0:[<2
o`0e^`03o`000?l1J]_o0F[K00CoBiOb1?n7]?<00ol0003o[/7Xojk1j004ojk1j003o`000?o4aM_o
a<GK00Coa<GK00?o0000om36d?o@a]001_o@a]000ol0003oelK9o`000004on7Jc`03o`000?oVf/[o
i][:00?oi][:00?o0000onOJb?oWf/P01?oWf/P00ol0003oooooooooo`0Oooooo`?o00003Oooool0
01cooooo00?o0000ooooooooool0>?ooool00ol0003ogngKomo]f`02omo]f`03o`000?oMk]gogNkM
00;ogNkM00Go0000omS]h_oHkN;of>gRo`000004olkYj005o`000?nngo3o_]o`okkOl?l000001?nW
cO@00ol0003oRK?bohVclP02ohVclP03o`000?mZUNSoJYGX00;oJYGX00?o0000oe5jg?mAN]`00_mA
N]`2od9Vd@?o00000_m[OM<00ol0003oJgK<of]fc003of]fc005o`000?m`M<OoL7C7og1daol00000
0on>Rl`00ol0003oUXg8oiJ=b005oiJ=b003o`000?nNTLKoWY7600?oWY7600?o0000ok^/bonk[</0
1Onk[</01Ol0003o`k38ol>`b?o3/<So000000GobkG500Go0000om_9aooKbLOoflW7o`000002omo8
`P05o`000?oRb;koh/Rnon;8__l000001?oVc;`00ol0003oil^ionO;^@05o`000004onC8_?l0003o
hlJko`0000;oh/Bj0_l00002omZn_@05o`000?o@]/7od;K1om2f`Ol000000oo2[LD00ol0003o/J37
ok6Pa`02ok6Pa`03o`000?nNTlSoWY?800;oWY?800?o0000oh^5aon;QLL00_n;QLL2ogUiaP;o0000
00?oD6W=o`000?lhF/P00_lhF/P01?l0003o:535o`000?l00002o`0Z/`;o03Fk00?o0000o`5Zfol1
J]/01?m;Uo84ohNdl`03o`000?n^`NSo[/7X00Co[/7X00?o0000olC5foo4aM/01?o4aM/00ol0003o
d<K@om36d005om36d0;o00001OoQf/l00ol0003oi][:onKJbP04onKJbP03o`000?oWf/Soim[800?o
im[800?o0000ooooooooool07?ooool3o`0000;ooooo00?o0000ooooooooool02oooool001cooooo
0_l0000iooooo`03o`000?oOkM_ogngK00;ogngK00Go0000omg^gOoMk]gogNkMo`000004omS]hP03
o`000?o>jNSoc^WX00;oc^WX00?o0000okkOl?nngo002_l000000on9/o;o0000ofZEj003ofZEj004
o`000?mAN]coDG[Loe5jg0?o00000_m2I]400ol0003oJggCo`000006of]fc003o`000?m`M<OoL7C7
00;oL7C700?o0000ohj;c?l000001onFSLP00ol0003oWY76oijAaP04oijAaP;o00001Onk[</00ol0
003o`k38ol>`b002ol>`b003o`000?o;]LGobkG500;obkG500Go0000om:i`_l0003oflW7o`000003
omo8`P05o`000?oRb;koh/Rnon;8__l000000ooVc;`2o`000004onO;^Ol0003o0000onO7]`;o0000
00Goi/Ngo`000?oSa[_ohlJko`000002on;4^P04o`000?oJ_[gof[jmo`0000Cod;K100Go0000ol:]
aOo2[LGo`Zg5o`000004ok6Pa`03o`000?nNTlSoWY?800;oWY?800?o0000oh^5aon;QLL00_n;QLL4
ogUiaP03oe1YcOl0003o>5[800;o>5[800Oo0000obQ@aOlXD<Go02beo`000?l0:[?o000000;o03Fk
00Co0000o`5Zfol1J]_o00000om;Uo801Ol0003oQkCcohNdlon7]??o000000Ko[/7X00?o0000olC5
foo4aM/01?o4aM/00ol0003od<K@om36d003om36d003o`000?oHf=Oo000000KohM[?00?o0000onKJ
b_oVf/X00ooVf/X00ol0003oim[8onOJb004onOJb003o`000?oooooooooo01Sooooo0ol00005oooo
o`03o`000?oooooooooo00_ooooo000Looooo`03o`000?oooooooooo03Sooooo00?o0000omo]fooO
kM/00_oOkM/01Ol0003ogNkMomg^gOoMk]go000000Cof>gR00?o0000olkYj?o>jNP00_o>jNP3o`00
0003olOFiOn^b^ko[/[^00?o[/[^1?n8/o83o`0000;oJYGX00?o0000oe5jg?l000000_l000000omA
N]co0000od9Vd@03od9Vd@03o`000?m[M/coJgK<00CoJgK<00?o0000og1daom`M<L01?m`M<L00ol0
003oUXg8oiJ=b005oiJ=b003o`000?nNTLKoWY7600CoWY7600Co0000ojRGa?nXUlCo00000onk[</0
0ol0003o`k38ol>`b002ol>`b003o`000?o;]LGobkG500;obkG500Go0000om:i`_oB^L;od[W2o`00
0003omo8`P04o`000?oRb;koh/Rnon;8_P;o00000_oVc;`01Ol0003oilVho`000?oWbkWo000000?o
ilNg0_oVakL00ol0003ohlJko`000002on;4^P05on72^Ol0003of[jmomZn_Ol000000oo@]/48o`00
0003ok6Paol0003oWY?800CoWY?800Go0000oh^5aon;QLOoRhG7o`000005ogUiaP05o`000?lhF/So
>5[8ocQJb?l000000olXD<D01?l0003oooooo`0Z/ol00002o`0e^`04o`000?l1J]_o0F[Ko`0000?o
BiOb00Go0000ohNdlon7]??oQkCco`000006ojk1j003o`000?o4aM_oa<GK00Coa<GK00Go0000om36
d?o@a]3od<K@o`000003omSHe`03o`000?oQf/oohM[?00?ohM[?00?o0000onKJb_oVf/X01?oVf/X0
0ol0003oim[8onOJb003onOJb003o`000?oooooooooo01Gooooo0ol00008ooooo`03o`000?oooooo
oooo00_ooooo000Looooo`03o`000?oooooooooo03Sooooo00?o0000omo]fooOkM/00_oOkM/01Ol0
003ogNkMomg^gOoMk]go000000Cof>gR00Co0000olkYj?o>jNSoc^WX0_l00004olOFi@Go[/[^1?n8
/o82oeN@j`Co00000omAN]`00ol0003o@VKAod9Vd@03od9Vd@03o`000?m[M/coJgK<00CoJgK<00?o
0000og1daom`M<L01?m`M<L00omhMlGo0000oiJ=b004oiJ=b003o`000?nNTLKoWY7600CoWY7600?o
0000ojRGa?nXUl@00_nXUl@00ol0003o^jc;o`000004ol>`b003o`000?o;]LGobkG500;obkG500?o
0000om:i`_oB^L800_oB^L82o`000003omo8`_l0003oh/Rn00?oh/Rn00Co0000onC7^_l0003o0000
0_oWbKP3o`000003onO7]ol0003o000000;oi/Ng00Coi/Jgo`000?oRa;[o00000_oQ`[T00ol0003o
f[jmomZn_@04o`000003om>f_Ol0003ob:k000;ob:k000?o0000ok^T`OnkY<400ol00004oijCb005
o`000?n;QLOoRhG7oh^5aol000001OmiNLH00om[KlGo0000ocQJb002ocQJb007o`000?lXD<Go:535
obQ@aOl0003o02Zco`000002o`0e^`05o`1<bol0003o0F[Ko`5Zfol000000om;Uo801Ol0003oQkCc
ohNdlon7]??o000000Ko[/7X00?o0000olC5foo4aM/01?o4aM/00ol0003od<K@o`000004omSHe`;o
00001OoQf/l00ol0003oi][:onKJbP03onKJbP03o`000?oWf/Soim[800;oim[80_l0000Cooooo`Co
00002oooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0hooooo`05o`00
0?oOkM_ogngKomo]fol000001?oMk]d00ol0003of>gRomS]hP02omS]hPCo000000?oe]_Lo`000?o7
e^D00oo7e^D00ol0003o[/[^ojk:kP02ojk:kP04o`000?n8/o;oR;?bohRclP?o000000?oEi3[o`00
0?l000000omAN]`00ol0003o@VKAod9Vd@03od9Vd@03oc]Kb?l0003oJgK<00?oJgK<00?o0000og1d
aom`M<L01?m`M<L01?l0003oN7O5ogQgaOl00003oiJ=b003o`000?nNTLKoWY7600CoWY7600?o0000
ojRGa?nXUl@01?nXUl@00ol0003o`k38ol>`b003ol>`b005o`000?o;]LGobkG5ol^eaOl000001?oB
^L801?l0003of;foomRm_ol00004on;8_P04o`000?oTak[oi<Njo`0000?oilVh00Co0000onO7]_l0
003oilNg0_l000000ooVakOo0000onK6]`02o`0000;ohL:i00?o0000omZn_OoJ_[d00_l00003om>f
_@03o`000?o8[/3ob:k000;ob:k000Ko0000ok^T`OnkY<7o^jC1o`000?n^VL84o`0000CoRhG700?o
0000ogUia_miNLH00omiNLH2of]_a@04o`000?lhF/So>5[8o`0000?o:53500Co8Tk5o`000?l0:[?o
00000_l0=K/01Ol0C<_o0000o`5Zfol1J]_o000000?oBiOb00Go0000ohNdlon7]??oQkCco`000006
ojk1j003o`000?o4aM_oa<GK00?oa<GK0_l00006omSHe`03o`000?oQf/oohM[?00CohM[?00?o0000
onKJb_oVf/X00ooVf/X01_l0003oim[8onOJb?l0003oj_3>o`00013ooooo0ol0000@ooooo`03o`00
0?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000omo]fooOkM_ogngK
o`000004omg^g@04o`000?oHkN;of>gRomS]hP;o00001?oFfm`00ol0003oamKUolOFi@02olOFi@03
o`000?n^b^ko[/[^00;o[/[^1?l000001?n8/o;o0000oeN@jomGT>/2obEXfP;o000000?oDG[Lo`00
0?m2I]400om2I]401?l0003o>e_8oc]Kb?l00002of]fc003o`000?m`M<OoL7C700GoL7C700Oo0000
ogQgaOmhMlGoN7O5o`000?nFSLSo000000OoWY7600?o0000ojRGa?nXUl@01?nXUl@2o`0000?o`k38
00?o0000ol^eaOo;]LD00_o;]LD01Ol0003od[W2om:i`_oB^L;o000000?of;fo0_l00002on;8_P05
o`000?oTak[oi<NjonC7^_l000000ooWbKP00ol0003oilNfo`000002o`000003onK7]ol0003oi/Jg
00;o00000ooQ`[T3o`000003om^m^ol0003odkJm00;odkJm00Go0000olR^`?o8[/3ob:k0o`000004
ok^T`@03o`000?n^VL;o[YW200;o[YW20_l00003oh^5a`03o`000?miNLKoNGW600;oNGW600Oo0000
of]_aOm[KlGoJfo5o`000?lhF/So000000?o:53500Co0000ob9>aOl0003o00000_l0=K/00ol0003o
04c;o`000002o`5Zf`05o`000?m;Uo;oBiObod^Gl_l000000on7]?<00ol0003o[/7Xojk1j004ojk1
j007o`000?o4aM_oa<GKolC5fol0003obM?Ro`000006omSHe`;o00001OoQf/l00ol0003oi][:onKJ
bP03onKJbP03o`000?oWf/So000000;oj_3>00?o0000ooooooooool02oooool3o`0001?ooooo00?o
0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0>Oooool01Ol0003ogngKomo]fooO
kM_o000000CogNkM00Ko0000omS]h_l0003o0000omkMeOl00005omKKg003o`000?o7e^GoamKU00;o
amKU00?o0000ojk:k_l000000ol00003ohRclP04o`000?mGT>_oEi3[oeN@j`?o9FSJ0_l00004od9V
d@07o`000?lkFlSo>e_8oc]Kb?l0003oJgK<o`000006og1da`03o`000?mhMlGoN7O500?oN7O500?o
0000oijAa_nNTLH01OnNTLH00ol0003oZ9O4ojRGa004ojRGa006o`000?nbW/?o/Yk3o`000?o3/<So
00001?o;]LD00ol0003od[W2om:i`P02om:i`P04o`000?oH_Koof;foo`0000;ogL2l00?o0000on;8
__l000000_oTakX01?l0003oi/Nho`000?oWbKP3o`000008onO7]ol0003o0000o`000?oVa[Oo0000
onK6]ol00003on72^@05o`000?oK_K_ofkfkom^m^ol000000ooC][d01Ol0003ob:k0olR^`?o8[/3o
000000?o^jC100?o0000ojjI`_n^VL800on^VL800ol0003oXI32o`000002oh^5a`03o`000?miNLKo
NGW600;oNGW600?o0000of]_aOm[KlD00_m[KlD00olhF/So0000obQ@a@02obQ@a@05o`000?lRC/Go
8Tk5o`0Z/ol000000_l0=K/01_l0003o04c;o`000?l0003o0F[Ko`0000?oBiOb00Go0000ohNdlon7
]??oQkCco`000006ojk1j003o`000?o4aM_o000000?obM?R00?o0000omSHeooHf=L01?oHf=L2o`00
00GohM[?00?o0000onKJb_oVf/X00ooVf/X01Ol0003oj_3>on[`c_oZl<ko000000Wooooo1?l0000F
ooooo`03o`000?oooooooooo00[ooooo000Kooooo`;o0000>Oooool00ol0003ogngKomo]f`02omo]
f`03o`000?oMk]gogNkM00;ogNkM0_l00004omkMe@03o`000?oFfmcoe]_L00;oe]_L00Co0000olOF
iOo7e^GoamKU0ol00003ojk:kP05o`000?n8/o;oR;?bohRcl_l000000omGT>/01Ol0003o9FSJobEX
f_lUJ=[o000000Co@VKA00?o0000oc]Kb?lkFlP00_lkFlP00ol0003oL7C7og1da`05og1da`03o`00
0?mhMlGoN7O500?oN7O500?o0000oijAa_nNTLH01?nNTLH00ol0003oZ9O4ojRGa004ojRGa003o`00
0?nbW/?o/Yk300;o/Yk30_l00003ol^ea@03o`000?oB^L;od[W200;od[W200Go0000omRm_ooH_Koo
f;foo`000003omg0_004o`000?oTak[oi<Njo`0000;oi/Nh00?o0000onO9^?l000000_l000000ooW
akOo0000o`000002o`000007onK6]ol0003o0000on72^Ol0003oh/:ho`000002om^m^`05o`000?oC
][godkJmom>f_Ol000001?o8[/001Ol0003o^jC1ok^T`OnkY<7o000000Co[YW200Co0000oj6@`_nQ
T<;oXI320_l00005ogUiaP03o`000?m[KlGoJfo500?oJfo500Go0000obQ@aOlXD<Go:535o`000003
ob9>a@05o`000?l0=K_o03Fko`000?l0C</00_lQK]h3o`0000?oBiOb00Go0000ohNdlon7]??oQkCc
o`000005ojk1j0;o00001?o9dn800ol0003of=SGomSHe`04omSHe`03o`000?oQf/oo000000CohM[?
00?o0000onKJb_oVf/X00_oVf/X2o`0000?oj_3>00?o0000ooooooooool01?ooool3o`0001[ooooo
00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003ogngKomo]
f`02omo]f`04o`000?oMk]gogNkMomg^g@;o00001OoNgMD00ol0003oe]_LomKKg002omKKg0Co0000
0_o7e^D01Ol0003o[/[^ojk:k_n^b^ko000000CoR;?b00Co0000oeN@jomGT>_o00000olUJ=X00ol0
AlOo0000od9Vd@02od9Vd@03o`000?lkFlSo>e_800;o>e_800?o?US4o`000?m`M<L01?m`M<L00ol0
003oN7O5ogQga@03ogQga@03o`000?n3OLCo000000GoWY7600?o0000ojRGa?nXUl@00onXUl@00ol0
003o/Yk3ok:N``03ok:N``05o`000?nmYL;o0000ol^eaOl000001OoB^L801?l0003of;foomRm_ol0
0004omg0_0;o000000?oi<Njo`000?oVakP00_oVakP00ol0003oilNfo`000005o`000003onK6]ol0
003oiLFf00;o00000_oR`[P01?l0003ofkfkom^m^ol00003om>f_@05o`000?o8[/3ob:k0olR^`?l0
00001?nkY<400ol0003o[YW2ojjI`P02ojjI`P03o`000?nQT<;oXI3200;oXI320_l00004ogUiaP03
o`000?m[KlGoJfo500?oJfo500?oGfW5o`000?lXD<D00_lXD<D01?l0003o8Tk5ob9>aOlRC/D2o`00
0003o`0e^ol0003o04c;00Co8FkN1Ol00003ohNdl`03o`000?n^`NSo000000;o000000?o[lS/o`00
0?o9dn801?o9dn800ol0003of=SGomSHe`04omSHe`;o00001OoQf/l01_l0003oi][:onKJb_l0003o
j?7@o`0000?oj_3>00Co0000oooooooooooooooo0ol0000Mooooo`03o`000?oooooooooo00[ooooo
000Kooooo`03o`000?oooooooooo03Sooooo00?o0000omo]fooOkM/00_oOkM/01_l0003ogNkMo`00
0?l0003oh]g@o`0000Gog]gE00?o0000omKKg?oFfm`01?l00004olOFi@03o`000?n^b^ko[/[^00;o
[/[^00Go0000ohRcl_n8/o;oR;?bo`000003oeN@j`06o`000?lUJ=[o9FSJo`000?l0AlOo00000_m2
I]400ol0003o>e_8oc]Kb002oc]Kb0;o?US400?o0000og1daom`M<L00_m`M<L00ol0003oN7O5ogQg
a@03ogQga@04o`000?n3OLCoPgg4o`0000?oWY7600?o0000ojRGa?nXUl@01?nXUl@00ol0003o/Yk3
ok:N``02ok:N``04o`000?nmYL;o_JG2okfU`P;o00001?oB^L801?l0003of;foomRm_ol00004omg0
_004o`000?oQ`kWohL>io`0000Coi/Nh00?o0000onO7]_l000001?l000001OoVa[Oo0000onG5]_oU
aKKo000000?oh/:h00Co0000om^m^ooK_K_o00000ooC][d01Ol0003ob:k0olR^`?o8[/3o000000?o
^jC100?o0000ojjI`_n^VL800on^VL800ol0003oXI32oj6@`P02oj6@`P03o`000?nDQl;o000000?o
NGW600?o0000of]_aOm[KlD00om[KlD2oemYa@04o`000?lXD<Go:535o`0000?o8Tk50_lTDlT2o`00
00;o04c;0olQK]h4oeFCkPKo00001On_b>`00ol0003obM?RolWChP02olWChP03o`000?oHf=Oof=SG
00Cof=SG00?o0000on7Jcol000001?oQf/l00ol0003oi][:o`000002onSad004o`000?oZl<koj_3>
on[`cPCo00008?ooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0hoooo
o`03o`000?oOkM_ogngK00;ogngK0_l00004on;Md003o`000?oNgMGog]gE00;og]gE0ol00003omKK
g003o`000?o7e^GoamKU00?oamKU00Go0000ojk:k_n^b^ko[/[^o`000003ohRclP05o`000?mGT>_o
Ei3[oeN@jol000000olUJ=X2o`17a`;o00001OlkFlP01?l0003o?US4ociHa?l00002og1da`03o`00
0?mhMlGoN7O500?oN7O500?o0000oh=ma?n3OL@00_n3OL@00ol0003oWY76o`000006ojRGa003o`00
0?nbW/?o/Yk300?o/Yk300Oo0000okfU`_nmYL;o_JG2o`000?o7[L3o000000;od[W200Go0000omRm
_ooH_Koof;foo`000004omg0_004o`000?oQ`kWohL>io`0000?oi/Nh0_l000000ooWakKo0000o`00
0004o`0000;oiLFf00Goi/Ffo`000?oR`[Soh/:ho`000002om^m^`05o`000?oC][godkJmom>f_Ol0
00001?o8[/001Ol0003o^jC1ok^T`OnkY<7o000000Co[YW200?o0000oj6@`_nQT<800_nQT<801ol0
003oU8O2oiB7`_nDQl;o0000ogUia_l000001Om[KlD01ol0003oGfW5oemYaOmOJLGo0000obQ@aOl0
00000olRC/D01ol0003o95?9obACbOl0=K_o0000o`1<bol000000olQK]h4oeFCkPCoR;?b00?o0000
ojo8k?n_b>`00on_b>`00ol0003obM?RolWChP03olWChP03o`000?oHf=Oof=SG00Cof=SG00?o0000
on7Jcol000000ooQf/l2o`0000?oj?7@00Go0000on[`c_oZl<koj_3>o`00000Sooooo`03o`000?oo
oooooooo00[ooooo000Jooooo`?o0000>Oooool01?l0003ogngKomo]fooOkM/2o`0000Goh]g@00?o
0000omkMeOoNgMD00_l000000ooNgMGo0000omKKg003omKKg003o`000?o7e^GoamKU00?oamKU00Go
0000ojk:k_n^b^ko[/[^o`000003ohRclP03o`000?mGT>_oEi3[00;oEi3[00Co0000obEXf_lUJ=[o
00000_l0AlL00ol0003o>e_8oc]Kb003oc]Kb007o`000?lnF<Co?US4ociHa?l0003oL7C7o`000005
ogQga@03o`000?n3OLCoPgg400?oPgg400?o0000ojRGa?nXUl@01?nXUl@00ol0003o/Yk3ok:N``03
ok:N``05o`000?nmYL;o_JG2okfU`_l000000oo7[L000ol0003od[W2o`000002omRm_`03o`000?oM
`;cogL2l00;ogL2l00So0000on73^OoQ`kWo0000onC5]ol0003oi/Nho`0000;oilJf1_l000001OoU
aKKo0000onK5]_oVaKKo000000;oh/:h00?o0000om^m^ol000001ol000000oo8[/3o0000ok^T`@03
ok^T`@03o`000?n^VL;o[YW200;o[YW200?o0000oj6@`_nQT<800_nQT<800ol0003oU8O2oiB7`P02
oiB7`P;o00001Om[KlD00ol0003oGfW5oemYa@02oemYa@03obQ@aOl0003o8Tk500;o8Tk500Go0000
obACbOlTDlWo95?9o`000002o`1<b`04o`000?lQK]ko8FkNo`0000CoEI?^1?n8/o800ol0003o[lS/
ojo8k003ojo8k003o`000?o9dn;obM?R00;obM?R00?o0000omSHeooHf=L01?oHf=L02?l0003ohM[?
on7Jcol0003ohM[?o`000?oSl=Oo00000ooXlM001Ol0003oj_3>on[`c_oZl<ko000002Cooooo00?o
0000ooooooooool02Oooool001[ooooo00?o0000ooooooooool0>Oooool01_l0003ogngKomo]fol0
003ohmc?o`0000Goh]g@0ol00003omkMe@03o`000?oFfmcoe]_L00?oe]_L00?o0000olOFiOo7e^D0
0_o7e^D00ol0003o[/[^ojk:kP02ojk:kP05o`000?n8/o;oR;?bohRcl_l000000omGT>/01?l0003o
9FSJobEXf_l00002o`17a`03o`0b^Ol0003o>e_800;o>e_800?o0000ociHa?lnF<@00olnF<@00ol0
003oN7O5ogQga@03ogQga@03o`000?n3OLCoPgg400CoPgg400?oT8G3o`000?nXUl@01?nXUl@00ol0
003o/Yk3ok:N``03ok:N``05o`000?nmYL;o_JG2okfU`_l000001?o7[L03o`000003omRm_ol0003o
gL2l00?ogL2l00Co0000on73^OoQ`kWo00000_oTaKL01?l0003oilJfonO6]_oWa[H7o`0000;oi/Ff
00?o0000on;2^?l000000ol000000ooN_k[o0000omNj_002omNj_003o`000?o?/kkock>n00Co0000
00?o^jC1o`000?n^VL801?n^VL800ol0003oXI32oj6@`P02oj6@`P03o`000?nDQl;oU8O200?oU8O2
00?o0000of]_aOm[KlD00om[KlD00ol0003oGfW5oemYa@03oemYa@05o`000?lRC/Go8Tk5ob9>aOl0
00001?lTDlT3o`0000?o8FkN00Go0000oeFCk_mETnkoEI?^o`000003ohRclP03o`000?n_b>co[lS/
00?o[lS/00?o0000olWCh_o9dn800oo9dn800ol0003of=SGomSHe`04omSHe`04o`000?oQf/oo0000
o`0000;oho3G00Go0000onSad?oXlM3oj?7@o`000003on[`cP03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02Oooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0iooooo`03o`000?oOkM_o000000?ohmc?
00?o0000on;Md?l000000_l000000ooRgM3o0000omkMe@04omkMe@03o`000?oFfmcoe]_L00;oe]_L
00?o0000olOFiOo7e^D00_o7e^D>o`0000?o9FSJ00Go0000o`17aol0003o03:io`000002oc]Kb003
o`000?lnF<Co?US400?o?US400?o0000ogQgaOmhMlD00omhMlD00ol0003oPgg4oh=ma003oh=ma004
o`000?n@QL?oT8G3o`0000?oZ9O400?o0000ok:N`onbW/<00onbW/<01Ol0003o_JG2okfU`_nmYL;o
000000Goajg000?o0000om2d__o@];h00_l00003omg0_004o`000?oQ`kWohL>io`0000?oi<Fg0_l0
00000ooWa[Ko0000o`000005o`0000;oi/Ff0ol00002on?3]`03o`000?oN_k[o000000?oekZl00?o
0000olnc__o?/kh00_o?/kh00ol0003oaZboolJ/_`03o`0000?o[YW200?o0000oj6@`_nQT<800_nQ
T<800ol0003oU8O2oiB7`P04oiB7`P03o`000?m[KlGoJfo500;oJfo500?o0000oemYaOmOJLD01?mO
JLD00omIIlKo0000ob9>a@02ob9>a@04o`000?lTDlWo95?9obACb@;o;f7B0_l00002ob5^gP03o`00
0?mETnkoEI?^00;oEI?^00Go0000ohRcl_n8/o;oR;?bo`000005ojo8k003o`000?o9dn;obM?R00;o
bM?R00?o0000omSHeooHf=L01?oHf=L01?l0003ohM[?o`000?l00002on?`e`05o`000?oXlM3oj?7@
onSad?l000000ooZl<h00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00001?nH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03Wooooo0_l00003on?Lc`?o00001?oRgM000ol0003og]gEomkMe@03omkMe@03o`000?oFfmco
e]_L00;oe]_L00?o0000olOFiOo7e^D00_l000000oo7b]co0000ok74j002ok74j005o`000?n7/o;o
Qk?bohNcl_l000000om3SNh3o`000004obEXf_l0003o04O7o`17a`;o03:i00?o0000oc]Kb?l00000
1OlnF<@00om8G<?o0000ogQga@03ogQga@03o`000?n3OLCoPgg400?oPgg400Oo0000oi25`on@QL?o
T8G3o`000?nXUlCo000000Go/Yk300?o0000okfU`_nmYL800_nmYL800ol0003oajg0olN]`002olN]
`006o`000?o@];kod;Bnom2d__l0003of;Zl0_l000001OoM`;co0000on73^OoQ`kWo000000;oi<Fg
00Go0000onK6]_oVa[Ko0000onO6]008o`000005onK5]_l0003ohl>gon?3]ol000000_oN_kX01Ol0
003oekZlomNj_?oG^[co000000?ock>n00?o0000olJ/_oo6[;l00_o6[;l00ol0003o_:C1o`000002
ojjI`P03o`000?nQT<;oXI3200;oXI3200?o0000oiB7`_nDQl800onDQl800ol0003oRX33o`000003
of]_a@03o`000?mOJLGoGfW500CoGfW50_mIIlH01?l0003o8Tk5ob9>aOl00003obACb@05o`000?l_
HM;o;f7Bo`1<bol000000_lQK]h01Ol0003oEI?^oeFCk_mETnko000000CoR;?b00?o0000ojo8k?n_
b>`00on_b>`00ol0003obM?RolWChP02olWChP03o`000?oHf=Oof=SG00?of=SG0_l00002on?`e`03
o`000?oSl=Oo000000?oj?7@00Go0000on[`c_oZl<koj_3>o`00000Tooooo`03o`000?oooooooooo
00Wooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0iooooo`03o`000?oSg<oo000000;o000000?ohmc?o`000?oRgM001?oRgM000ol0003o
g]gEomkMe@03omkMe@03o`000?oFfmcoe]_L00?oe]_L0_l00004olO:g005o`000?naa>So/LCXok74
j?l000000on7/o801?l0003o@hg^od>=k_m3SNh2o`1Dc`05obEXf_l0003o04O7o`17aol000000_l0
<[T2o`0000Co?US400Co0000odQL`om8G<?o00000_mhMlD00ol0003oPgg4oh=ma004oh=ma003o`00
0?n@QL?oT8G300;oT8G30_l00005ok:N``05o`000?nmYL;o_JG2okfU`_l000001Oo7[L001?l0003o
d;Bnom2d__l00004omRj_0?o000000GohL>io`000?oTaKOoi<Fgo`000002onK6]P;o000000?oilJd
o`000?l000000ol00002onK5]P05o`000?oS`kOohl>gon?3]ol000000_oN_kX01?l0003oekZlomNj
_?l00004olnc_P05o`000?o6[;ooaZboolJ/_ol000000onlY<400ol0003o[YW2o`000004oj6@`P03
o`000?nDQl;oU8O200;oU8O200Go0000ohZ0`on:P<?oRX33o`000002of]_a@03o`000?mOJLGoGfW5
00?oGfW500Oo0000oeUWa_mIIlKoFFO6o`000?lRC/Go000000?o95?900Go0000obmQd_l_HM;o;f7B
o`000003ob5^gP05o`000?mETnkoEI?^oeFCk_l000000on8/o800ol0003o[lS/ojo8k003ojo8k003
o`000?o9dn;obM?R00;obM?R00?o0000omSHeooHf=L00_oHf=L00ol0003ofNcQo`000003on?`e`;o
00000ooXlM001Ol0003oj_3>on[`c_oZl<ko000002Cooooo00?o0000ooooooooool02Oooool000?o
oooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03So
oooo0ol00005on?Lc`03o`000?oRgM3oh]g@00?oh]g@00?o0000omkMeOoNgMD00ooNgMD01?l0003o
e]_LomKKg?oFfm`2o`0000Koal[L00Go0000ok74j?naa>So/LCXo`000003ohNclP04o`000?m3SNko
@hg^od>=kP;o05C?00Co9FSJo`000?l0AlOo00000ol0<[T00ol0003o?US4ociHa002ociHa007o`00
0?m8G<?oB5c3odQL`ol0003oN7O5o`000005oh=ma003o`000?n@QL?oT8G300?oT8G30_nOSl<2o`00
00;o/Yk300?o0000okfU`_nmYL800_nmYL800ol0003oajg0olN]`002olN]`005o`000?o@];kod;Bn
om2d__l000001?oH^[`00ol0003og[njomjo^P0=o`000005onO6]?l0003oi/FfonK5]_l000000_oS
`kL01?l0003og[njomjo^_l00003omNj_005o`000?o?/kkock>nolnc__l000001?o6[;l00ol0003o
_:C1okbT`@02okbT`@;o00000onQT<800ol0003oU8O2oiB7`P03oiB7`P03o`000?n:P<?oRX3300;o
RX330_l00006oemYa@03o`000?mIIlKoFFO600;oFFO600?o8Tk5o`000?lTDlT00_lTDlT00ol0003o
;f7BobmQdP02obmQdP;o000000?o8FkNo`000?mETnh00_mETnh00ol0003oR;?bohRclP02ohRclP03
o`000?n_b>co[lS/00?o[lS/00?o0000olWCh_o9dn800_o9dn801?l0003of=SGomSHeol00002omW/
h@04o`000?oSl=Ooho3Gon?`e`;o00000ooXlM001Ol0003oj_3>on[`c_oZl<ko000002Cooooo00?o
0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool00ol0003ohmc?on?Lc`03on?Lc`03o`000?oR
gM3oh]g@00?oh]g@00?o0000omkMeOoNgMD00ooNgMD01_l0003oe]_LomKKg?l0003odl_Bo`0000Oo
al[L00Go0000ok74j?naa>So/LCXo`000003ohNclP04o`000?m3SNko@hg^od>=kP;o05C?00Co0000
o`17aol0AlOo00000_l0<[T00ol0003o?US4ociHa002ociHa003o`000?m8G<?oB5c300;oB5c30_l0
0005oh=ma003o`000?n@QL?oT8G300;oT8G300?o0000oin?`onOSl<00_nOSl<00ol0003o/Yk3o`00
0004okfU`P03o`000?o7[L3oajg000;oajg000Go0000om2d__o@];kod;Bno`000003omRj_005o`00
0?oN_k[og[njomjo^_l000000_oS`kL01?l0003oi/FfonK5]_l00002onO6]0[o000000Gohl>go`00
0?oN_k[og[njo`000003omNj_005o`000?o?/kkock>nolnc__l000000oo6[;l00ol0003o_:C1okbT
`@03okbT`@03o`000?ncWL;o000000;oXI3200?o0000oiB7`_nDQl800_nDQl800ol0003oRX33ohZ0
``04ohZ0``03o`000?mOJLGoGfW500CoGfW500?o0000oeUWa_mIIlH00omIIlH01Ol0003o95?9obAC
bOlTDlWo000000Co;f7B0_m5Mmd00ol0003o8FkNo`000003oeFCkP05o`000?n8/o;oR;?bohRcl_l0
00001On_b>`00ol0003obM?RolWChP02olWChP03o`000?oHf=Oo000000?ofNcQ00?o0000on?`eooS
l=L00_oSl=L01Ol0003oj?7@onSad?oXlM3o000000?oj_3>00?o0000ooooooooool08_ooool00ol0
003oooooooooo`09ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0<oooool3o`0000Gooooo00?o0000on?LcooSg<l00ooSg<l00ol0003o
h]g@on;Md003on;Md003o`000?oNgMGog]gE00?og]gE00?o0000omKKg?l000000ooCbm800ol0003o
al[LolO:g004olO:g003o`000?naa>So/LCX00;o/LCX00Go0000ohNcl_n7/o;oQk?bo`000003od>=
kP05o`1Dcol07jKo0000o`17aol000000_l0<[T2o`0000?o?US400?o0000odQL`om8G<<00_m8G<<2
oeUUa@05o`000?n3OLCoPgg4oh=ma?l000001On@QL<00ol0003oWho3oin?``03oin?``;o00000onm
YL800ol0003oajg0olN]`002olN]`005o`000?o@];kod;Bnom2d__l000001?oH^[`01?l0003og[nj
omjo^_l00003on?3]`03o`000?oVaKKoi/Ff00?o000000GoilJdo`000?l0003oilJdo`000002onK6
]P03o`000?oTa;Ooi<Bg00?o000000Gog[njo`000?oG^[coekZlo`000004olnc_P05o`000?o6[;oo
aZboolJ/_ol000001?nlY<401ol0003o/ig2ok>M`_ncWL;o0000oj6@`_l000001?nDQl800ol0003o
RX33ohZ0``04ohZ0``03oh9la?l0003oGfW500?oGfW500?o0000oeUWa_mIIlH01?mIIlH00omGJL[o
0000obACb@02obACb@05o`000?l_HM;o;f7BobmQd_l000000om5Mmd01Ol0003oEI?^oeFCk_mETnko
000000CoR;?b00?o0000ojo8k?n_b>`00on_b>`01?l0003obM?RolWCh_o9dn82o`0000CofNcQ00?o
0000on?`eooSl=L00_oSl=L2o`0000;oj?7@00Go0000on[`c_oZl<koj_3>o`00000Uooooo`03o`00
0?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<?ooool3o`0000Sooooo00?o0000on?LcooSg<l01?oSg<l00ol0003oh]g@
on;Md003on;Md003o`000?oNgMGog]gE00;og]gE0_l00005om?;dP03o`000?o7b]coal[L00Coal[L
00?o0000ok74j?naa>P00_naa>P01Ol0003oQk?bohNcl_n7/o;o000000?o@hg^00Co05C?o`0OY_l0
003o00000ol0<[T01Ol0:kCo0000ociHa?lnF<Co000000CoB5c30omIILD01?l0003oPgg4oh=ma?l0
0005oi25``03o`000?nOSl?oWho300?oWho300Ko0000ojfJ`ol0003o0000okfU`_l00004olN]`005
o`000?o@];kod;Bnom2d__l000000ooH^[`01Ol0003og[njomjo^_oN_k[o000000;ohl>g00?o0000
onK5]_oVaKH00ol000001OoWa[Co0000o`000?oWa[Co000000;oi/Jf00Go0000onC4]ooTa;Ooi<Bg
o`000002on73^@?o000000?oekZlo`000?o?/kh00_o?/kh01Ol0003oaZboolJ/_oo6[;oo000000Co
_:C100?o0000ok>M`_ncWL800oncWL800ol0003oU8O2oiB7`P02oiB7`P03o`000?n:P<?oRX3300Co
RX3300Co0000oh9la?n2O<Co00000omOJLD00ol0003oFFO6oeUWaP03oeUWaP04o`000?mGJL[oEfW:
o`0000;o95?900Go0000obmQd_l_HM;o;f7Bo`000004odEgg@;o00000_mETnh00ol0003oR;?bohRc
lP02ohRclP03o`000?n_b>co[lS/00;o[lS/00Ko0000olWCh_l0003o0000olOQk?l00004omW/h@05
o`000?oSl=Ooho3Gon?`eol000000_oXlM000ol0003oj?7@o`000002on[`cP;o00009Oooool00ol0
003oooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000oooo
ooooool0;Oooool3o`0000cooooo00?o0000on?LcooSg<l00ooSg<l00ol0003oh]g@on;Md003on;M
d007o`000?oNgMGog]gEomkMeOl0003ofL_<o`000006om?;dP03o`000?o7b]coal[L00Coal[L00Go
0000ok74j?naa>So/LCXo`000004ohNclP08o`000?m3SNko@hg^o`000?l0E<oo01nVo`17aol00002
o`0b^@;o02^d0_l00004odQL``03o`000?mIILGoFFG500;oFFG500?o0000oh=ma?l000001?n@QL<0
0ol0003oWho3oin?``03oin?``03o`000?n]V/?o[I[300;o[I[30_l00003olN]`005o`000?o@];ko
d;Bnom2d__l000001?oH^[`01Ol0003og[njomjo^_oN_k[o000000;ohl>g0ol000000ooVaKKo0000
onO6]005o`0000;oi/Jf00Co0000onC4]ooTa;Oo00000ooQ`kT00ol0003ogL2lomg0_003o`0000;o
ck>n00Go0000olJ/_oo6[;ooaZboo`000004okbT`@03o`000?ncWL;o/ig200?o/ig20_l00002oiB7
`P03o`000?n:P<?oRX3300CoRX3300?o0000oh9la?n2O<@00_n2O<@01?l0003oGfW5oemYaOl00005
oeUWaP07o`000?mGJL[oEfW:oeMYb_l0003o95?9o`000003obmQdP03o`000?m5MmgoAGOM00;oAGOM
0_mTTnT3o`0000CoR;?b00Co0000ojo8k?n_b>co[lS/0ol00003olOQk003o`000?oIk>7ofNcQ00;o
fNcQ00Go0000on?`eooSl=Ooho3Go`000002onSad004o`000?oXlM3o0000on[`cP;o00009_ooool0
0ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0Zooooo`?o00003oooool00ol0
003ohmc?on?Lc`04on?Lc`03o`000?oRgM3oh]g@00;oh]g@00Co0000omkMeOoNgMGo00000ooIbl`0
0ol0003odl_Bom?;dP04om?;dP03o`000?o7b]coal[L00Coal[L00Go0000ok74j?naa>So/LCXo`00
0004ohNclP03o`000?m3SNko@hg^00;o000000Go01nVo`000?l0<[Wo03:io`000002o`0[]003o`00
0?m8G<?oB5c300;oB5c300?o0000oeUUaOmIILD00omIILD00ol0003oT8G3oi25``03oi25``03o`00
0?nOSl?oWho300?oWho300?o0000ojfJ`on]V/<00_n]V/<01_l0003o_:G2o`000?l0003oajg0o`00
00?od;Bn00Go0000omRj_?oH^[cof;Zlo`000003omjo^P03o`000?oS`kOo000000;o00000_oVaKH0
0ol0003oilJdo`000004o`000004onO6]_l0003oi/Jfo`0000;oi<Bg00Co0000on73^OoQ`kWo0000
0ooM`;`00ol0003of;bnomRl_P02o`0000CoaZbo00Go0000okbT`OnlY<7o_:C1o`000005ok>M`P06
o`000?nYUl?oZIO3o`000?nDQl;o00001_n:P<<00ol0003oPWc4oh9la003oh9la0;o00001OmIIlH0
0ol0003oEfW:oeMYbP03oeMYbP03obACbOl0003o;f7B00;o;f7B00?o0000odEggOm5Mmd00_m5Mmd0
0ol0003oI9?YofBCj@02ofBCj@So00000_n[c_801Ol0003oan7/olOQk?o7hNco000000CofNcQ00Go
0000on?`eooSl=Ooho3Go`000003onSad0?o000000?of_kCo`000?ooool09Oooool00ol0003ooooo
ooooo`08ooooo`006Oooool2o`0002Sooooo0ol0000Booooo`03o`000?oSg<oohmc?00Cohmc?00?o
0000on;Md?oRgM000ooRgM02o`0000GofL_<00?o0000om?;d_oCbm801?oCbm800ol0003oal[LolO:
g003olO:g003o`000?naa>So/LCX00;o/LCX00?o0000ohNcl_n7/o800_n7/o801?l0003o@hg^od>=
k_l0E<l2o`0000;o03:i00Co0000o`0[]?l0:kCo00001?m8G<<00ol0003oFFG5oeUUa@03oeUUa@03
ofebaol0003oT8G300;oT8G300?o0000oin?`onOSl<01?nOSl<01Ol0003o[I[3ojfJ`on]V/?o0000
00Co_:G20ol00002om2d_P06o`000?oH^[cof;ZlomRj_?l0003og[nj1?l00002on;2^003o`000?oV
aKKo000000Oo00000_oWa[H01?l0003oi<BgonC4]ol00003on73^@04o`000?oM`;cogL2lo`0000Co
f;bn0_l00002olJ/_`03o`000?nlY<7o_:C100;o_:C100?o0000ok>M`_ncWL800_ncWL800ol0003o
ZIO3ojVG``02ojVG``03o`000?n:P<?oRX3300CoRX3300?o0000oh9la?n2O<@01On2O<@00ol0003o
FFO6oeUWaP03oeUWaP03o`000?mGJL[oEfW:00CoEfW:0_l00003obmQdP05o`000?m5MmgoAGOModEg
gOl000001?mTTnT5ohRclP03o`000?n[c_;oZlkb00;oZlkb00Go0000olOQk?o7hNcoan7/o`000004
omW/h@05o`000?oSl=Ooho3Gon?`eol000000ooXlM02o`000003om[ndol0003ooooo02Kooooo00?o
0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool09?ooool3o`0001Kooooo00?o0000
on?LcooSg<l00ooSg<l00ol0003oh]g@on;Md003on;Md003o`000?oIblcofL_<00GofL_<00?o0000
om?;d_oCbm801?oCbm800ol0003oal[LolO:g003olO:g003o`000?naa>So/LCX00;o/LCX00?o0000
ohNcl_n7/o801Ol000001Ol0E<oo0000o`000?l0<[Wo000000;o02^d0_l00003odQL``03o`000?mI
ILGoFFG500?oFFG50_m]L/L01?l0003oT8G3oi25`ol00005oin?``03o`000?n]V/?o[I[300;o[I[3
00?o0000okbU`_nlYL800_nlYL800ol0003ob:o0olR_`008o`0000;og;fk00Co0000on;2^?oR`[So
h/:h0_l000000ooUaKKo0000o`000005o`0000;oilJf0_l000001OoTa;Oo0000on73^OoQ`kWo0000
00?ogL2l00Go0000omRl__oH_;kof;bno`000002om6h`@03o`000?o6[;oo000000?o_:C100?o0000
ok>M`_ncWL800oncWL800ol0003oZIO3ojVG``02ojVG``;o00001?n:P<<00ol0003oPWc4oh9la006
oh9la003og]ja_l0003oFFO600?oFFO600?o0000oeMYb_mGJLX01?mGJLX2oeYbd@04o`000?l_HM;o
;f7Bo`0000?oAGOM00?o0000ofBCjOmTTnT00_mTTnT00ol0003oR;?bohRclP02ohRclP03o`000?n[
c_;oZlkb00;oZlkb00Go0000olOQk?o7hNcoan7/o`000004omW/h@05o`000?oSl=Ooho3Gon?`eol0
00000_oXlM000ol0003oe_oEo`000002o`0002Oooooo00?o0000ooooooooool02?ooool001Sooooo
00?o0000ooooooooool08_ooool3o`0001Wooooo00?o0000on?LcooSg<l01?oSg<l01?l0003oh]g@
on;Md?oRgM02o`0000SofL_<00?o0000om?;d_oCbm801?oCbm800ol0003oal[LolO:g003olO:g003
o`000?naa>So/LCX00Co00001?n7]?<2o`000005o`1Dcol0003o0000o`0b^Ol000000_l0:k@01Ol0
<;Oo0000odQL`om8G<?o000000CoFFG500Oo0000ofebaom]L/OoKG;7o`000?n@QL?o000000GoWho3
00?o0000ojfJ`on]V/<00_n]V/<00ol0003o_:G2okbU`P02okbU`P05o`000?o8[l3ob:o0olR_`?l0
00000ooC]kh01Ol0003og;fkombm^ooL_K_o000000?oh/:h0_l000001?oUaKKo0000o`000?oWa[@2
o`000003onO7]_l0003oilNf00;o00000_oVakP2o`0000;ohL>i00Co0000omg0_?oM`;co00000ooH
_;h00ol0003odKS1om6h`@02om6h`@;o00000_nlY<400ol0003o/ig2ok>M`P03ok>M`P03o`000?nY
Ul?oZIO300;oZIO300Co0000oj6BaOnQT/Go00000on:P<<00ol0003oPWc4oh9la005oh9la004o`00
0?mkN/KoNg[6o`0000;oFFO600?o0000oeMYb_mGJLX01?mGJLX01ol0003oFW;AoeYbdOmJL]7o0000
obmQd_l000000om5Mmd00ol0003oI9?YofBCj@02ofBCj@03o`000?n8/o;oR;?b00;oR;?b00?o0000
oj_>l_n[c_800_n[c_801Ol0003oan7/olOQk?o7hNco000000CofNcQ00_o0000on?`eooSl=Ooho3G
o`000?oXlM3o0000omKoeOl0003of_kCo`00000Xooooo`03o`000?oooooooooo00Sooooo000Hoooo
o`03o`000?oooooooooo023ooooo0_l0000Looooo`03o`000?oSg<oohmc?00Cohmc?00Co0000on;M
d?oRgM3o00000_oLblP00ol0003ofL_<omW;c006omW;c003o`000?oCbm;odl_B00Codl_B00?o0000
olO:g?o7b]`00oo7b]`2o`0000Co[kgT1On7]?<01_l0003o=I3_o`000?l07jKo03:io`0000;o02^d
0_l000000om8G<?o0000oeUUa@04oeUUa@03o`000?m]L/OoKG;700;oKG;70_l00005oin?``05o`00
0?n]V/?o[I[3ojfJ`ol000001?nlYL800ol0003ob:o0olR_`002olR_`005o`000?oC]kkodkNnom>g
__l000000ooL_K/00ol0003oh/:hon;2^002o`000003onG5]_l0003oi/Jg00Co000000CoilNfo`00
0?oWakKo00000ooVakP01Ol0003oi<Njo`000?oQ`kWo000000;ogL2l00Go0000omRl__oH_;kof;bn
o`000004om6h`@05o`000?o:]<Co0000okbT`Ol000001?ncWL800ol0003oZIO3ojVG``02ojVG``03
o`000?nQT/GoXI;500;oXI;500?o0000ohZ0`ol000001on2O<@00ol0003oNg[6og]jaP02og]jaP03
o`000?mIIlKo000000KoEfW:00?o0000oeYbdOmJL]400_mJL]400ol_HM;o0000odEgg@02odEgg@03
o`000?mTTnWoI9?Y00;oI9?Y00?o0000ohRcl_n8/o800_n8/o800ol0003oZlkboj_>lP02oj_>lP05
o`000?o7hNcoan7/olOQk?l000001?oIk>401?l0003oho3Gon?`eooSl=L2o`0000;oe_oE00Co0000
om[ndol0003o0000:?ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0M
ooooo`?o00007oooool00ol0003ohmc?on?Lc`03on?Lc`03o`000?oRgM3o000000Cog<_800?o0000
omW;c?oIbl`01_oIbl`00ol0003odl_Bom?;dP04om?;dP05o`000?o7b]coal[LolO:g?l000000_o2
_]H5ojnmi003o`000?n7]??oQkCc00;oQkCc00Go0000ocF@kol0003o01nVo`000002o`0[]004o`00
0?l0<;Oo0000o`0000GoFFG500?o0000ofebaom]L/L00_m]L/L2ohB2b@05o`000?nOSl?oWho3oin?
`ol000001?n]V/<00ol0003o_:G2okbU`P02okbU`P05o`000?o8[l3ob:o0olR_`?l000000ooC]kh0
0ol0003og;fkombm^`02ombm^`?o000000KohL>io`000?l0003oi/Jgo`000?oVa[L3o`000004onO7
]_l0003oilNfo`0000;oi/Nh00Go0000onC7^_oTak[oi<Njo`000003omg0_004o`000?oH_;kof;bn
o`0000CodKS100Go0000olZda?o:]<Cob[C4o`000004ok>M`P03o`000?nYUl?oZIO300?oZIO300?o
0000oj6BaOnQT/D00onQT/D00ol0003oPWc4oh9la005oh9la003o`000?mkN/KoNg[600CoNg[600?o
0000oeMYb_mGJLX01?mGJLX00ol0003oFW;AoeYbd@04oeYbd@;o00000_m5Mmd00ol0003oI9?YofBC
j@02ofBCj@03o`000?n8/o;oR;?b00;oR;?b00?o0000oj_>l_n[c_800_n[c_801Ol0003oan7/olOQ
k?o7hNco000000CofNcQ00?o0000on?`eooSl=L00_l00002omKoe@03o`000?oJo]?o000000;ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`006?ooool2o`0001_ooooo0ol0
000Rooooo`03o`000?oSg<oohmc?00Cohmc?00?o0000omc;b?oLblP01?oLblP00ol0003ofL_<omW;
c005omW;c003o`000?oCbm;odl_B00Godl_B00?o0000olO:g?l000001?o2_]H00ol0003o[kgTojnm
i002ojnmi003o`000?n7]??oQkCc00;oQkCc00Co0000ocF@kol0003o00000_l0:k@00ol0003o032g
o`0`]`02o`0000CoFFG500?o0000ofebaom]L/L00_m]L/L3ohB2b@04o`000?nOSl?oWho3o`0000Co
[I[300?o0000okbU`_nlYL800_nlYL801Ol0003ob:o0olR_`?o8[l3o000000?odkNn00Co0000ombm
^ooL_K_og;fk0_l00002on73^@;o000000Goi/Jgo`000?oVa[Oo0000onO7]`03o`000003onO7]_l0
003o000000;oi/Nh00Go0000onC7^_oTak[oi<Njo`000002omg0_005o`000?oH_;kof;bnomRl__l0
00000ooA^<400ol0003ob[C4olZda002olZda0;o00000oncWL800ol0003oZIO3ojVG``02ojVG``03
o`000?nQT/GoXI;500CoXI;50_l00005oh9la003o`000?mkN/KoNg[600GoNg[60_l00005oeMYbP03
o`000?mJL]7oFW;A00CoFW;A0_mSPMX00ol0003oAGOMo`000004ofBCj@03o`000?n8/o;oR;?b00;o
R;?b00?o0000oj_>l_n[c_800_n[c_801Ol0003oan7/olOQk?o7hNco000000CofNcQ00Go0000on?`
eol0003odOgNo`000002omKoe@03o`000?oJo]?o000000;ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Gooooo`?o00009Oooool00ol0
003ohmc?on?Lc`03on?Lc`;o00001ooLblP00ol0003ofL_<omW;c005omW;c003o`000?oCbm;odl_B
00Godl_B00?o0000ol:ne_o2_]H01?o2_]H00ol0003o[kgTojnmi003ojnmi004o`000?n7]??oQkCc
ohNdl`;o000000Co=I3_o`000?l0:kCo00000_l0<;L2o`a0_`05o`000?mIILGoFFG5oeUUaOl00000
1?m]L/L01ol0003oQ8;9ohB2bOn4P/Wo0000oin?`ol000000on]V/<00ol0003o_:G2okbU`P02okbU
`P03o`000?o8[l3ob:o000;ob:o000Go0000om>g__oC]kkodkNno`000002ombm^`;o00000ooQ`kT0
1?l0003oi/Jgo`000?oVa[L4o`000003onO7]_l0003o000000;oilVh0_l00003onC7^P05o`000?oR
b;ko0000omg0_?l000000_oH_;h01Ol0003odKS1om6h`OoA^<7o000000Cob[C400Ko0000ol:_aoo2
[lOo0000ok>M`_l00004ojVG``03o`000?nQT/GoXI;500CoXI;500Co0000oiV>aonIS/Oo00000on2
O<@00ol0003oNg[6og]jaP05og]jaP04o`000?mhO<_oN7c;o`0000CoEfW:00?o0000oeYbdOmJL]40
0omJL]401_l0003oHh7Jof>1f_mSPM[oAGOMo`0000CoI9?Y00?o0000ohRcl_n8/o800_n8/o800ol0
003oZlkboj_>lP02oj_>lP05o`000?o7hNcoan7/olOQk?l000001?oIk>42o`000005om7mg_l0003o
e_oEomKoeOl000000_oJo]<01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool0
1oooool001Sooooo00?o0000ooooooooool05?ooool3o`0002Wooooo00Go0000on?LcooSg<oohmc?
o`000002omg;aP03o`000?oLblSog<_800Gog<_800?o0000omW;c?oIbl`01OoIbl`00ol0003odl_B
om?;dP03om?;dP03o`000?o<_Lcoc;g<00Ko`[kF0_l00004ojnmi003o`000?n7]??oQkCc00;oQkCc
00Go0000ocF@kol0003o02^do`000002o`0`]`;o342o00?o0000oeUUaOl000001Om]L/L00ol0003o
Q8;9ohB2b@02ohB2b@;o00000on]V/<00ol0003o_:G2okbU`P02okbU`P03o`000?o8[l3ob:o000;o
b:o000?o0000om>g__oC]kh01?l000001?oJ_[go0000on73^OoQ`kT2o`000003onK6]ol0003oi/Jg
00Co000000?oilNfo`000?oWbKP00_oWbKP2o`0000;oi<Nj00Go0000on;8__oRb;koh/Rno`000002
omRl_P05o`000?oA^<7odKS1om6h`Ol000001?o:]<@00ol0003o`Zo7ol:_a`02ol:_a`03o`000?nY
Ul?oZIO300;oZIO300?o0000oj6BaOnQT/D01?nQT/D00ol0003oVHk7oiV>a`02oiV>a`03o`000?n2
O<Co000000OoNg[600?o0000ogQlbomhO</00_mhO</01?l0003oEfW:oeMYb_l00006oeYbd@03o`00
0?mSPM[oHh7J00;oHh7J0_l00003ofBCj@03o`000?n8/o;oR;?b00;oR;?b00?o0000oj_>l_n[c_80
0_n[c_801Ol0003oan7/olOQk?o7hNco000000?ofNcQ0_l00002om7mgP06o`000?oFomGoe_oEo`00
0?oJo]?o00001Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Goooo
o`03o`000?oooooooooo01;ooooo0ol0000/ooooo`04o`000?oSg<oohmc?o`0000CogL_600?o0000
omc;b?oLblP01OoLblP00ol0003ofL_<omW;c005omW;c005o`000?oCbm;odl_Bom?;d_l000001?o<
_L`00ol0003o`[kFol:neP04ol:neP03o`000?n__NCo[kgT00;o[kgT00?o0000ohNdlon7]?<00_n7
]?<01?l0003o=I3_o`0[]?l00002o`0`]`?o342o0_l00005ofeba`03o`000?n4P/WoQ8;900;oQ8;9
0_nKT/T2o`000003ojfJ`ol0003o_:G200?o_:G200?o0000olR_`?o8[l000_o8[l001?l0003odkNn
o`000?l00004omZn_@04o`000?oQ`kWo0000on;4^P;o000000Coi/Jgo`000?l0003oilNg1?l00003
onO9^004o`000?oTak[oi<Njo`0000Coh/Rn0_l000000ooH_;ko0000om6h`@02om6h`@05o`000?o:
]<Cob[C4olZda?l000001?o2[lL00ol0003o^Z_:o`000003ojVG``03o`000?nQT/GoXI;500?oXI;5
00?o0000oiV>aonIS/L00onIS/L2o`0000OoNg[600?o0000ogQlbomhO</01?mhO</00ol0003oEfW:
o`000005oeYbd@03o`000?mSPM[oHh7J00?oHh7J0_mcUnH2o`000003ofBCjOl0003oR;?b00?oR;?b
00?o0000oj_>l_n[c_800_n[c_801?l0003oan7/olOQk?o7hN`4o`000004olShjol0003odOgNo`00
00;oe_oE00Co0000om[ndooJo]?o00001_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Oooooo000Gooooo`03o`000?oooooooooo00oooooo0ol0000_ooooo`03o`000?oSg<oo0000
00KogL_600?o0000omc;b?oLblP01OoLblP00ol0003ofL_<omW;c005omW;c003o`000?oCbm;o0000
00Koc;g<00?o0000ol:ne_o2_]H01?o2_]H00ol0003o[kgTojnmi002ojnmi0;o00000on7]?<00ol0
003o001io`000002o`0`]`04o`000?l<@;oo342oo`a0_`;o00000om]L/L00ol0003oQ8;9ohB2b@03
ohB2b@CoVi;91?l000000onlYL;o0000olR_`003olR_`0?o000000?od;O1o`000?oJ_[d00_oJ_[d0
0ol0003ohL>io`000002on;4^P03o`000?oVa[Ooi/Jg00;o000000GoilNgo`000?l0003oil^io`00
0002onO9^0;o00000_oTakX01Ol0003oh/Rnon;8__oRb;ko000000;oglS200Go0000om6h`OoA^<7o
dKS1o`000003olZda003o`000?o2[lOo`Zo700;o`Zo700Oo0000okZ[b_njZl[o^Z_:o`000?nYUl?o
000000GoXI;500?o0000oiV>aonIS/L00onIS/L00ol0003oThg:o`000006og]jaP03o`000?mhO<_o
N7c;00KoN7c;00?o0000oeYbdOmJL]400omJL]400ol0003oHh7Jof>1fP03of>1fP03o`000?mcUnKo
LiOV00;oLiOV00?oI9?Yo`000?n8/o800on8/o800ol0003oZlkboj_>lP02oj_>lP03o`000?o7hNco
000000;o00000oo8n>/01_l0003odOgNom7mg_l0003oe_oEo`0000;of_kC00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo000Gooooo`;o00003Ooo
ool3o`0003?ooooo00?o0000omg;a_oMblH01_oMblH00ol0003og<_8omc;b005omc;b003o`000?oI
blcofL_<00GofL_<00?o0000olbmc?o<_L`01_o<_L`2o`0000Go`[kF0_l00004ojnmi007o`000?n7
]??oQkCcohNdlol0003o001mo`000002o`0`]`?o342o0_l`FL/01?l0003oKG;7ofebaol00004ohB2
b@03o`000?nKT/WoVi;900;oVi;91?n`XLP7o`0000?od;O100Co0000omZn_OoJ_[gof[jm0_l00003
on;4^P04o`000?oVa[Oo0000onK7]`Co000000Coil^io`000?oWbKSo00000_oVc;`2o`0000?oh/Rn
00Co0000omo8`_oOb<;oglS20_l000000ooA^<7o0000olZda003olZda005o`000?o2[lOo`Zo7ol:_
aol000001?njZlX2o`0000GoXI;500?o0000oiV>aonIS/L00onIS/L01Ol0003oThg:oi>=b_nCSL[o
000000GoNg[600?o0000ogQlbomhO</01OmhO</00ol0003oMh;Ao`000004oeYbd@03o`000?mSPM[o
Hh7J00?oHh7J00?o0000og>Gi_mcUnH00omcUnH<o`0000;o^NWe00Oo0000olShjoo8n>_ob?S[o`00
0?oAoMko000000;oe_oE00Co0000om[ndooJo]?o00002?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000fooooo`03o`00
0?oMblKogL_600KogL_600?o0000omc;b?oLblP01_oLblP00ol0003ofL_<omW;c003omW;c003o`00
0?oA_<KodKc600Woc;g<00?o0000ol:ne_o2_]H01?o2_]H00ol0003o[kgTojnmi002ojnmi003o`00
0?n7]??oQkCc00;o000000Co001mo`000?l0<;Oo00000_l<@;l01_l0003o<5W;oc1Ibol0003oKG;7
o`0000CoQ8;900?o0000oi^BbOnKT/T00_nKT/T00ol0003o/:78ok2Qb002ok2Qb003o`000?o2[/Go
`Zk500;o`Zk500Go0000om2g`Oo@]l7od;O1o`000003omZn_@06o`000?oRa;[oh/Bjon;4^_l0003o
hlJk1Ol000000ooWbk[o0000onO;^@02o`0000?oi/bl00Go0000on;8__oRb;koh/Rno`000003omo8
`P04o`000?oKbLOoflW7o`0000Cob[C400Go0000ol:_aoo2[lOo`Zo7o`000004okZ[bP04o`000?nb
Ylgo/ZO=o`0000?oXI;500?o0000oiV>aonIS/L00onIS/L00ol0003oThg:oi>=bP03oi>=bP05o`00
0?mkN/KoNg[6og]ja_l000001omhO</01Ol0003oMh;AogN2dOmgP]7o000000;oFW;A00?o0000of>1
f_mSPMX00omSPMX00ol0003oLiOVog>GiP04og>GiP03o`000?n9/o7oRK?a00;oRK?a00?o0000oj;A
n?nRdOP00_nRdOP01?l0003o^NWeokWYmOl00003olShj`03o`000?oAoMko000000;oe_oE00Co0000
om[ndooJo]?o00002_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000G
ooooo`03o`000?oooooooooo00Kooooo0ol0000jooooo`03o`000?oMblKogL_600KogL_600?o0000
omc;b?oLblP01_oLblP01Ol0003ofL_<omW;c?oIblco000000CodKc600?o0000olbmc?o<_L`01_o<
_L`00ol0003o`[kFol:neP04ol:neP04o`000?n__NCo[kgTojnmi0?o00000on7]?<00ol007go0000
o`000003o`a0_`?o<5W;0_l00004ohB2b@03o`000?nKT/WoVi;900;oVi;900?o0000ok2Qb?n`XLP0
0_n`XLP00ol0003o`Zk5ol:^a@02ol:^a@05o`000?o@]l7od;O1om2g`Ol000000_oJ_[d2o`0000;o
h/Bj00co0000on?6^ooSa[_o0000onC9_?l0003oi/^ko`000?oWbk[o0000onO;^Ol00004onK<_005
o`000?oRb;koh/Rnon;8__l000000_oOb<801Ol0003oflW7om_9aooKbLOo000000?ob[C400Go0000
ol:_aoo2[lOo`Zo7o`000004okZ[bP03o`000?nbYlgo/ZO=00;o/ZO=00?o0000oj6BaOl000001OnI
S/L00ol0003oThg:oi>=bP05oi>=bP03o`000?mkN/Ko000000OoN7c;00?o0000ogN2dOmgP]400omg
P]400ol0003oFW;Ao`000005of>1fP03o`000?mcUnKoLiOV00?oLiOV00?o0000ohVclOn9/o400_n9
/o400ol0003oX]7hoj;An002oj;An005o`000?nijOGo^NWeokWYmOl000000_o8n>/01?l0003odOgN
om7mg_l00002omKoe@04o`000?oJo]?of_kCo`0000_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`03ooooo`?o0000?_ooool00ol0003o
gL_6omg;aP06omg;aP03o`000?oLblSog<_800Kog<_800?o0000omW;c?l000001_oA_<H2o`0000Oo
c;g<0_l00005ol:neP03o`000?n__NCo000000?oZkOR0on7]?<01?l007Wo001mo`0`]ol00002o`a0
_`05o`000?l`FL_o<5W;oc1Ibol000001?n4P/T00ol0003oVi;9oi^Bb@02oi^Bb@03o`000?n`XLSo
/:7800;o/:7800?o0000ol:^aOo2[/D00_o2[/D02Ol0003od;O1om2g`Oo@]l7o0000omZn_Ol0003o
fl70o`000002on;4^P03o`000?oSa[_o000000;oi<Vl0_l000001OoWbk[o0000onO;^OoWbkWo0000
00?oi/bl0_l00002on;8_P04o`000?oOb<;oglS2o`0000?oflW700Go0000omK9cOl0003ob[C4o`00
0003ol:_a`03o`000?njZl[o^Z_:00;o^Z_:00?o0000ok:WcOnbYld00onbYld2o`0000GoVHk700?o
0000oi>=b_nCSLX01_nCSLX2o`0000OoN7c;00?o0000ogN2dOmgP]401?mgP]43o`0000GoHh7J00?o
0000og>Gi_mcUnH00omcUnH00ol0003oRK?aohVcl@02ohVcl@03o`000?nRdOSoX]7h00;oX]7h00Co
0000okWYmOnijOGo00000oo8n>/00ol0003odOgNo`000002omKoe@04o`000?oJo]?o0000o`0000co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`005_ooool01?l0003ooooo
ooooooooool3o`0004;ooooo00?o0000omg;a_oMblH01_oMblH00ol0003og<_8omc;b006omc;b003
o`000?oA_<KodKc600OodKc600?o0000olbmc?o<_L`01_o<_L`00ol0003o`[kFol:neP03ol:neP03
o`000?n[]n;oZkOR00CoZkOR00Go0000ohNdlol0003o001mo`000002o`a0_`06o`000?l`FL_o<5W;
oc1IbomKMMCo00000on4P/T01Ol0003oVi;9oi^BbOnKT/Wo000000Go/:7800?o0000ol:^aOo2[/D0
0_o2[/D01?l0003od;O1om2g`Oo@]l42o`0000?ofl700_l00002on?6^`08o`000?oTbKco0000onK;
^ol0003oil^jo`000?oWbkT2o`0000;oi/bl00?o0000onK@`OoVd<400_l00002omo8`P05o`000?oK
bLOoflW7om_9aol000000_oFbLd2o`0000?o`Zo700Co0000okZ[b_njZl[o^Z_:0_l00005ok:Wc@04
o`000?n[Y=3oZjC@o`0000?oVHk700?o0000oi>=b_nCSLX01_nCSLX01?l0003oSXk>ohj>c_l00005
ogQlb`03o`000?mgP]7oMh;A00CoMh;A00Co0000ogZ<f_mjS=[oNXcJ0_l00002of>1fP03o`000?mc
UnKoLiOV00?oLiOV00?o0000ohVclOn9/o400_n9/o400ol0003oX]7hoj;An002oj;An005o`000?ni
jOGo^NWeokWYmOl000000_o8n>/01?l0003odOgNom7mg_l00002omKoe@;o000000?o^?gJo`000?oo
ool03?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo000Fooooo`Co0000
A_ooool00ol0003ogL_6omg;aP06omg;aP03o`000?oLblSog<_800Gog<_800?o0000om>l`ooA_<H0
2?oA_<H2o`0000Ooc;g<00Go0000ol:ne_o2_]Ko`[kFo`000002ok^ee0OoZkOR0_l000001?l01I7o
0000o`a0_ol00003oc1Ib`05o`000?mKMMCo0000ohB2bOl000001?nKT/T00ol0003o/:78ok2Qb002
ok2Qb003o`000?o2[/Go`Zk500;o`Zk500Co0000om2g`Oo@]l7od;O10_l00004om_1`004o`000?oS
a[_ohlJko`0000;oi<Vl0_l00002onO;^P;o000000Coim2no`000?oVc;co00000ooVd<401Ol0003o
glS2omo8`_oOb<;o000000;oflW700Co0000omK9cOoFbLgo00000_o@bM<00ol0003o`Zo7o`000003
okZ[bP03o`000?nbYlgo/ZO=00?o/ZO=0_l00004oj^Td003o`000?nIS/Oo000000OoThg:0_l00004
ohj>cP05o`000?mhO<_oN7c;ogQlbol000001_mgP]400ol0003oNXcJogZ<fP04ogZ<fP03o`000?mS
PM[o000000CoLiOV00?o0000ohVclOn9/o400on9/o400ol0003oX]7hoj;An002oj;An004o`000?ni
jOGo^NWeo`0000?ob?S[00Co0000om7mg_l0003oe_oE0_l00002okSmfP03o`000?oooooooooo00go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`005_ooool2o`0004Wooooo
00?o0000omg;a_oMblH01OoMblH00ol0003og<_8omc;b004omc;b005o`000?oC_<?odkc3om>l`ol0
00002OoA_<H00ol0003oc;g<olbmc005olbmc003o`000?o2_]Ko000000Go^kGD00?o0000oj^gh_n[
]n801?n[]n801?l007go00FAo`000?l00003oc1Ib`03o`000?mKMMCoFgGD00;o00001?nKT/T00ol0
003o/:78ok2Qb002ok2Qb003o`000?o2[/Go`Zk500;o`Zk500Ko0000om2g`Ol0003o0000om2laol0
0003om_1`0;o000000SohlJko`000?oTbKcoi<Vlo`000?oVbk_o0000onO;^P;o00000_oWd;h2o`00
00?oi]310_l00002omo8`P04o`000?oKbLOoflW7o`0000;oe/W=00Co0000om39doo@bM?od<WC0_l0
0003okZ[bP03o`000?nbYlgo/ZO=00;o/ZO=0_l00006oj^Td0;o00001onCSLX00ol0003oSXk>ohj>
cP05ohj>cP03o`000?mhO<_o000000KoMh;A00?o0000ogZ<f_mjS=X01OmjS=X3o`0000CoLiOV00?o
0000ohVclOn9/o400_n9/o400ol0003oX]7hoj;An002oj;An004o`000?nijOGo^NWeo`0000?ob?S[
00?o0000om7mg_oAoMh00ol00002okSmfP03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`06ooooo`003?ooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0Aoooool00ol0003ogL_6omg;aP05omg;aP03o`000?oLblSog<_800;og<_800?o
0000om>l`ooC_<<00ooC_<<2o`0000SodKc600?o0000olbmc?o<_L`01Oo<_L`00ol0003o^kGDok^e
e006ok^ee0;o00001?n[]n801?l007go00FAo`a0_ol00002oc1Ib`04o`000?mKMMCoFgGDoe]ee0Co
000000?oVi;9o`000?n`XLP00on`XLP00ol0003o`Zk5ol:^a@02ol:^a@;o00000oo@_<L01?l0003o
fl70om_1`?l00002omg6`P;o000000Coi<Vlo`000?oVbk_oi/^k0_l000001OoVdL7o0000onO@__oW
d;ko000000?oi]3100?o0000onCFb?oTe/P00_l00002om_9a`04o`000?oFbLgoe/W=o`0000?od<WC
00Ko0000olS8f_o8b=[o0000okZ[b_l00004ok:Wc@03o`000?n[Y=3oZjC@00CoZjC@0_l000000onS
XmCo0000oi>=bP05oi>=bP03o`000?n>S/koSXk>00KoSXk>0ol00005ogN2d@03o`000?mjS=[oNXcJ
00GoNXcJ00Go0000oh2MiOn0WNGoP9gUo`000002og>GiP03o`000?n9/o7oRK?a00?oRK?a00Go0000
oj;An?nRdOSoX]7ho`000003okWYm@05o`000?o8n>_ob?S[o`000?oAoMh00_l000001Onanm_o0000
okSmf_nhoM[o000001;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`00
3_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oooooo00?o0000omg;a_oMblH0
1OoMblH01Ol0003og<_8omc;b?oLblSo000000Oodkc300?o0000om6la_oA_<H01_oA_<H2o`0000Go
c;g<00?o0000ol>cb_l000002?nk]M@2o`0000?oZkOR00?o001mo`05TOl000000ol`FL/00ol0003o
FgGDoe]ee004ohB@e`Go000000Co/:78o`000?o2[/Go`Zk50ol00004om2la`03o`000?oK`L3o0000
00?ogLK20_l000001?oTbKco0000o`000?l00003onKA`@;oim2n0_l00002onK@`@05o`000?oTe/So
i=K8onCFb?l000000_oKbLL01?l0003oe/W=omK9cOl00003om39d`04o`000?o8b=[ob<SJolS8fP;o
00000onbYld2o`0000KoZjC@00?o0000oj>Se?nSXm@00_nSXm@01?l0003oThg:oi>=b_nCSLX2o`00
00OoSXk>0_l00003oh^Ae005o`000?mgP]7oMh;AogN2dOl000001omjS=X00ol0003oP9gUoh2Mi@03
oh2Mi@03o`000?mcUnKo000000CoRK?a00?o0000oj;An?nRdOP00_nRdOP01?l0003o^NWeokWYmOl0
0003olShj`?o000000Go/O_Ko`000?nhoM[o^?gJo`00000Dooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`16ooooo`03o`000?oMblKogL_600KogL_600?o0000omc;b?l000002OoC_<<00ol0003odKc6om6l
aP07om6laP05o`000?o<_Lcoc;g<olbmc?l000001?o3/lX2o`0000Oo^kGD0_l00002oj^ghP03o`00
0?l0;KCo000000;o<5W;00Co0000oe]ee?mKMMCo00001?n4T=L4ojJTe0Co00000_no/lh00ol0003o
d;c7om2la`02om2la`;o00001?oMa/801_l0003oh<c4o`000?l0003oi=33o`0000;oi]7100Oo0000
onO@__l0003oimS6o`000?oVd<7o000000?oi=K80_l000001OoKbLOo0000omK9cOoFbLgo000000?o
d<WC00Go0000olS8f_o8b=[ob<SJo`000002okk6h003o`000?nbYlgo000000KoZjC@0_l00006oj>S
e003o`000?nCSL[o000000OoSXk>0_l00006oh^Ae003o`000?mgP]7o000000OoNXcJ00?o0000oh2M
iOn0WND01?n0WND5o`0000;oRK?a00Go0000oj;An?nRdOSoX]7ho`000003okWYm@Co000000Co[OWT
o`000?nanm_o00000_nhoMX00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`0004Oooooo00?o0000
omg;a_oMblH01_oMblH2o`0000[odkc30_l00008om6laP03o`000?o<_Lco000000Oo`k?:0_l00007
ok^ee0;o000000KoZkORo`000?l0;KCo0000oc1Ibol00003oe]ee005o`000?n4T=OoQ93GohB@eol0
00001?nVY=@00ol0003o_k?>oknccP02oknccP04o`000?o@_<Ood;c7om2la`;o00001?oMa/801?l0
003oh<c4on3<a?l00002onC@``03o`000?oVdL7oi]7100;o00000_oWf<H2o`0000?oi=K800Co0000
on7LdOl0003o00000_oFbLd00ol0003od<WCom39d`02o`0000;ob<SJ0_l00003okk6h0;o00001On[
Y=02o`0000SoXj?D0_l00007ohj>cP03o`000?n;TMCoRi7D00KoRi7D0_l00007ogZ<fP03o`000?n0
WNGoP9gU00CoP9gU00?o0000ohZclOn:/o400on:/o44o`0000;oX]7h1_l00002ojgii003o`000?na
nm_o000000;o^?gJ00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool0
0ol0003ogL_6omg;aP05omg;aP03o`000?oD_<;o000000_odkc300?o0000om6la_oA_<H01_oA_<H0
0ol0003o`k?:ol>cbP08ol>cbP;o00001onk]M@2o`000004o`05TOl0;KCo<5W;o`0000?oFgGD00Go
0000ohB@eon4T=OoQ93Go`000004ojJTe003o`000?no/lko_k?>00;o_k?>00Ko0000om2laoo@_<Oo
0000om;4cOl00003omg6`P04o`000?oPc<Coh<c4o`0000;oi=3300?o0000onKA`OoVdL400_l00002
onOHaP;o00000ooTe/P01Ol0003ohMcAo`000?oKi=_o000000;oe/W=0oo@bM<2olS8fP;o00000onn
a^02o`000003okC4i_l0003oZjC@00?oZjC@00?o0000oj>Se?nSXm@01OnSXm@3o`0000;oW:;I00?o
0000ohj>c_n>S/h00_n>S/h2o`0000OoRi7D0_l00002ohVIg003o`000?mjS=[oNXcJ00?oNXcJ00?o
0000oh2MiOn0WND00on0WND2o`0000GoR[?a00?o0000oiO=nonGcO/00_nGcO/4o`0000;oZOCb00Ko
0000ojgii?n]nNCo0000ok7kfol00002okSmfP03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04Gooooo00?o0000omg;a_oMblH00ooMblH01?l0003oe;c2omBl`_oD_<82o`0000[o
dkc300?o0000om6la_oA_<H01OoA_<H00ol0003oak74o`00000:ol>cbP03o`000?nk]MCo^kGD00Ko
^kGD00?o0000o`05TOl0;K@00_l00002oe]ee005o`000?n4T=OoQ93GohB@eol000001?nVY=@00ol0
003o_k?>oknccP02oknccP03o`000?o@_<Oo000000?od/C=00Co0000omg6`_oMa/;o00000_oPc<@0
1Ol0003oi=33onC@`ol0003oi]7100;o00000_oWf<H00ol0003oi>;Ao`000002onCFb003o`000?oQ
g=7o000000;ofnCK0_l00003om39d`;ob<SJ00Co0000okk6h?nna^3o_/KP0_l00004okC4iP04o`00
0?n[Y=3o0000o`0000GoXj?D0ol00006oibRf@04o`000?n>S/ko0000o`0000OoRi7D0_l00005ohVI
g005o`000?mjS=[oNXcJogZ<f_l000001On0WND00ol0003oR[?aohZcl@04ohZcl@03o`000?nGcO_o
Ulgk00;oUlgk00Co0000oj;Uo?nRiOco00000_nYm?801_l0003o[OWTojgii?l0003o/O_Ko`0000;o
^?gJ00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Go
oooo000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0AOooool01Ol0003ogL_6
omg;a_oMblKo000000Koe;c200?o0000om>l`ooC_<<02?oC_<<2o`0000CodKc600?o0000olNaa?o7
/L@00_o7/L@2o`0000So`k?:0_l00008ok^ee003o`000?lCHmWo4f?I00?o00001?n4T=L00ol0003o
YZCDojJTe002ojJTe004o`000?no/lko_k?>oknccP;o00001?oBa<d00ol0003ogLK2o`000002on3<
a004o`000?oTd<?oi=33onC@``;o000000Coi=_<o`000?oWf<Ko00000_oTh]401Ol0003oi=K8o`00
0?oQg=7o000000;ofnCK00?o0000om3Ziol000000_o@bM<00oo8b=[o0000o`000002okk6h0;o0000
1Onda>H3o`0000GoXj?D0_l00008oibRf@?o00001on;TM@2o`0000SoRIWL00?o0000ogZ<f_l00000
1On0WND00ol0003oR[?aohZcl@03ohZcl@;o00001?nGcO/01?l0003oX^Gloj;Uo?l00002ojWdlP06
o`000?n]nNCo[OWTo`000?nanm_o00000_nhoMX00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01Oooool000cooooo00?oEEEEofIVI_l000004Oooool2o`00
04Kooooo00?o0000omg;a_l000002?oD_<800ol0003odkc3om>l``09om>l``04o`000?oA_<KodKc6
o`0000Ooak740_l00008ol>cbP;o00001_nk]M@2o`0000?o4f?I00?oFgGDo`000?n4T=L00_n4T=L0
0ol0003oYZCDojJTe002ojJTe003o`000?no/lko_k?>00;o00001_oBa<d3o`000006on3<a?l0003o
i=33onC@`ol0003oi]710_oTfl`2o`0000?oi>;A0_l000001OoQg=7o0000om_TfooKi=_o000000;o
d>[W0_l000001?o8b=[o0000okk6h?nna^02o`0000Co]<CV0ol00003ojS0j`03o`000?nSXmCo0000
00;o00001onLX]T3o`0000?oUjCN00?o0000oh^Ae?n;TM@00_n;TM@2o`0000[oRIWL0ol00003oh2M
i@;o00001On:/o400ol0003oUlgkoiO=n`02oiO=n`;o00000_nRiO`01?l0003oZOCbo`000?l00002
ojgii003o`000?nanm_o000000;o^?gJ00?o0000ooooooooool07Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo04Cooooo0_l00009omBl
`P;o00002_oC_<<00ol0003odKc6o`000009olNaa0;o00002?o3/lX2o`0000?o^kGD00Co0000ok6_
eOna[mGo02fd0olCHmT3o`000003ohB@eol0003oYZCD00?oYZCD0ol000000ono_m[o0000om;4c@04
om;4c@04o`000?oHcm7of<oAomS?d@Go00000_oTfl`00ol0003oimS6onCRd@02onCRd@;o00000_oQ
g=42om_Tf`05o`000?o@j^Oo0000o`000?nokO800_l000000onna^3o0000o`000003okC4iP?o0000
1OnX`>/3o`0000KoW:;I1?l00007oiNTgP04o`000?n;TMCo0000o`0000WoRIWL0ol00003ohVTiP03
o`000?n0WNGo000000GoR[?a0_l00004oiO=n`03o`000?nRiOcoX^Gl00;o000000?oZOCbo`000?n]
nN@00_n]nN@00ol0003o/O_Ko`000002okSmfP03o`000?oooooooooo01kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`15ooooo`03o`00
0?oD_<;oe;c200Soe;c200?o0000om>l`ooC_<<02?oC_<<00ol0003oak74olNaa00:olNaa0;o0000
2?o3/lX2o`000003ok^ee?l0003o/JoE00;o/JoE00Co02fdoa=SfOlCHmWo00000_mSUN/7o`0000Co
_koJ00Go0000om;4cOoBa<god/C=o`000004omS?d@06o`000?oOf=3ogmS@omoHd?l0003oi=_<0_l0
0003onCRd@04o`000?oLkmko0000on7Ld@;ofnCK0_o@j^L7o`0000;o]<CV0ol00003ojS0j`Go0000
0onN_Nh00ol0003oW:;IoibRf@03o`0000[oUjCN0ol00008ohVIg0?o00001_n9Y>H3o`0000CoR[?a
00?o0000oiO=nonGcO/00_nGcO/2o`0000;oX^Gl00Co0000ojWdl_nYm?;o00000on]nN@00ol0003o
/O_Ko`000002okSmfP03o`000?oooooooooo023ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`04ooooo`009?ooool2o`0004Kooooo0_l00009omBl`P;o00002?oC_<<00ol0003obK71
o`00000<olNaa0;o00002?o3/lX00ol0003o/JoEok6_e@03ok6_e@04o`000?lCHmWo4f?Io`0000;o
HiG[00?o0000oifbionM/^L00_nM/^L00ol0003o_koJoknofP03oknofP03o`000?oBa<go000000Co
f<oA00Co0000omoHd?oOf=3ogmS@0ol000000ooMj=_o0000onCRd@02o`000003omc_g_l0003o0000
00;ofnCK00?od>[Wo`000?l000002Ol000000onX`>_o0000o`000003o`0000GoW[g^1_l00008oiNT
gPGo00000onBYn@00ol0003oRIWLohVIg003ohVIg0;o00001_n9Y>H3o`0000?oRkCa0_l000000on:
/o7o0000oiO=n`03oiO=n`05o`000?nRiOcoX^Gloj;Uo?l000000_nYm?801ol0003o[OWTojgii?n]
nNCo0000ok7kfol000000_nhoMX00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool002Kooooo00?o0000ooooooooool0AOooool00ol0003oe;c2omBl
`P08omBl`P03o`000?oC_<?odkc300Codkc300?o0000olVa`Oo9/L400_o9/L42o`0000_oak740_l0
0006ol>cbP03o`000?ni[<co000000;o00000_na[mD00ol0003o4f?Io`000003of>Ej`03o`000?nM
/^OoWK;W00;oWK;W00?o0000oknof_no_mX00ono_mX2o`0000?of<oA00Co0000omoHd?oOf=3ogmS@
0_l00003omgXf`03o`000?oTh]7og>oN00;o000000CoaOW[o`000?oKi=_od>[W3Ol00003oijmkPOo
00001OnE^O001?l0003oUjCNoiNTg_nGY=h5o`0000WoTZOT00?o0000ohVIg?l000000_l00005ohVT
iP?o00001on;]?44o`0000;oUlgk00Go0000oj;Uo?nRiOcoX^Glo`000002ojWdlP04o`000?n]nNCo
[OWTojgii0Ko00009_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo000W
ooooo`03o`000?oooooooooo04Gooooo0_l00009omBl`P03o`000?oC_<?odkc300?odkc300?o0000
olVa`Oo9/L401?o9/L42o`0000_oak740_l00003ol>cbP03o`000?ni[<co^Jc<00?o^Jc<1?l00000
0olCHmWo0000of>Ej`02of>Ej`03o`000?nM/^OoWK;W00;oWK;W00Co0000oknof_no_m[o00000oo6
d^<2o`000003omS?dOl0003o000000;o00001?oMj=/01?l0003oi>;Ao`000?l00002olGij`;o0000
00?od>[Wo`000?l000003ol00005oiFil0_o00002onBYn@6o`0000GoRJCV0_l00007oh^dl@?o0000
1?n=a_/4o`000003oj;Uo?l0003o000000Oo000000?oX_?_o`000?l00000:?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo000Xooooo`03o`000?oooooooooo04Kooooo00?o
0000omBl`_oD_<801ooD_<82o`0000;odkc300?o0000olVa`Oo9/L401oo9/L42o`0000_oak740_l0
00000oo3/l[o0000okV/c007okV/c0?o00000omSUN/00ol0003oWK;Woifbi`02oifbi`03o`000?no
_m[o000000Koa];S0_l00002om;Si004o`000?oMj=_ogNSKomgXf`?o000000?oaOW[o`000?l00000
1ol00004og>no@oo00002On?]o400ol0003oTZOToi:Wi002oi:Wi0So00001_n>[N/00ol0003oRJCV
o`000002o`0000KoRkCa0ol00004ohg6n`?o00000on?eol4o`0000;oTnce1?l000000onRlnoo0000
ooooo`0Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool002Wooooo0_l0
0017ooooo`;o00002OoD_<800ol0003odkc3o`00000;olVa`@;o00002oo7/L@00ol0003o^Jc<okV/
c00:okV/c0Go00000_nM/^L3o`0000Goa];S00?o0000om;Si?oBhn@00_oBhn@00ol0003ogNSKo`00
000Ho`0000;oLkkm00?o0000ohnglOn?]o401on?]o4<o`0000_oSZg[1_l00005oh^dl@?o00001On=
a_/2o`0000?oSmOo1Ol00002oi?/m@Co000000?oX_?_o`000?l00000;Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooooooo04Kooooo00?o0000
omBl`_oD_<801ooD_<800ol0003obK71olVa`@0<olVa`@;o00002Oo7/L@00ol0003o_J[7okfZa`02
o`0000[o^Jc<0_llY?D3o`0000CoW<gi0_l000000oo6d^?o0000om;Si004om;Si0;o000000?oa_G]
o`000?l000001_l000000on9]_?o0000ohZflP04ohZflQGo00002On;]O800ol0003oSZg[ohj]j`02
ohj]j`Wo00001_n;]?400ol0003oRkCao`000002o`0000GoSLKk0ol00002ohoGo`?o000000?oTNCl
o`000?l000000_nCk?D2o`000003oiS`l?l0003oX_?_00;o0000;oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo04Kooooo0_l00007omBl
`P04o`000?o;/L7o0000o`0000gobK710_l00006olNaa003o`000?nmZ/Oo_J[700Co_J[70ol00007
okV/c0;o00000_llY?D2o`0000CoW<gi1ol000000oo6mNgo0000o`000003o`0000GoW;7V1ol00009
ohZflQ[o00003On;]?45o`0000GoSLKk0_l00003ohoGo`;o000000CoTNClo`000?l0003o00000_nC
k?D2o`000003oiS`l?l0003o000000;o0000<_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo000]ooooo`03o`000?oooooooooo04Oooooo00?o0000omBl`_oD_<800ooD_<80
0ol0003obk71ol^a`@03ol^a`@;o00003?o9/L42o`0000?oak7400?o0000okfZaonmZ/L02?nmZ/L3
o`0000Oo^Jc<00Ko0000ocbTmOllY?Go0000oic=nOl00006ojWXnP03o`000?o6mNgo000000GoYjcK
1?l00002oibaiP03o`000?nD/^_oU;;[00?oU;;[2_l00003ohZflP03o`000?n;]O;oRkGb00ooRkGb
00?o0000oh^dlOn;]?402?n;]?46o`0000GoR[gg00?o0000ohg6nol000000_l00002ohoGo`?o0000
00?oTNClo`000?l000000onCk?D2o`000005oiS`l?l0003o0000oj;ckol00000=Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000^ooooo`;o0000B?ooool2o`0000;oe;c2
00?o0000ol^a`Oo;/L401_o;/L42o`0000cobK710_l000000oo7/LCo0000okfZa`0<okfZa`?o0000
1oni[<`2o`000003ojWXn_l0003o000000Co00003?nW[=/6o`0000coU;;[3ol00007oh^elP04o`00
0?n;]?7oRkCaoh^dl@Ko00002On:_OL5o`000004ohoGool0003o0000o`0000;oTNCl0_l00003oi?/
m@;o00000_nHl?001?l0003oX_?_o`000?l0000gooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00oooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003oe;c2o`00000:ol^a
`@?o00002oo9/L400ol0003o_J[7okfZa`0?okfZa`?o00001?ni[<`00ol0003o[ZWCojjYd`05ojjY
d`Co00002_nW[=/00ol0003oW:oToib_i002oib_i0Oo00002OnD/^/00ol0003oS[KbohjflP08ohjf
lP_o00002?n:_OL7o`0000?oRlOk1Ol000000onAi?co0000o`000003oi?/m@;o00000_nHl?04o`00
03Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003o
ooooooooo`17ooooo`03o`000?o;/L7obk7100cobk710_l00009olVa`@03o`000?noZLCo_jW400Co
00003_nmZ/L4o`0000co[ZWC1?l00006ojN/f`03o`000?nL[nCoW:oT00WoW:oT1ol00003oiBbj`03
o`000?n>]_;oS[Kb013oS[Kb00Co0000ohZmmon:_OOoR[gg1_l00005oh_7n`Go00000on>coh5o`00
0003oi?/mOl0003o000000;oV?3`0_l000000onRlnoo0000ooooo`0kooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00oooool003;ooooo00?o0000ooooooooool0B?ooool2o`0000go
bk710_l00006olVa`@03o`000?noZLCo_jW400Go_jW41?l0000=okfZa`03o`000?n^ZM?o[ZWC00ko
[ZWC1Ol000000onW[=_o0000oib_i00Aoib_i1[o00001_n;ao/5o`0000CoS/on1?l00003oi?FoPGo
000000?oV?3`o`000?nRlnl00_l0000nooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00oooool003?ooooo0_l0001;ooooo`;o00003?o;/L43o`0000?obK7100?o0000oknYa?noZL@0
2OnoZL@3o`0000[o_J[700Co0000ok:Xc_nbZ<ko/ZS>1_l0000<ojjYd`So00003onL[n@00ol0003o
T[Saoi:hl@0Boi:hl@03o`000?n;ao_oRlOk00Go00001On>coh4o`0000CoTmKn0ol00003oi[Ko@Go
0000@Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000eooooo`03o`00
0?oooooooooo04[ooooo0ol0000<ol^a`@;o000000?obK71o`000?noZL@03OnoZL@4o`0000Ko_J[7
00?o0000ok:Xc_nbZ<h01onbZ<h5o`0000So[ZWC00?o0000oj>]gonS[Ml01?nS[Ml;o`0000GoW:oT
00?o0000oi:hlOnB^?402?nB^?4<o`0000KoS/on1?l00004oi?FoPCo00000onJfod6o`0004?ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003ooooooooo
o`1<ooooo`;o00003?o;/L400ol0003o_jW4oknYa00AoknYa0Co000000?o_J[7o`000?nbZ<h03_nb
Z<h6o`0000;o[ZWC00?o0000oj>]gonS[Ml03onS[Ml@o`0000_oUk[`00?o0000ohk?o_n>coh01?l0
0005oi?FoP?o00001?nJfod3o`000003oj;No?l0003o000004Oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`00=oooool2o`0004kooooo0_l0000:ol^a`@03o`000?o1Z/?o
`J[300Co00004OnoZL@2o`0001Go/ZS>3ol0000:oj>]g`03o`000?nG^_3oUk[`00WoUk[`3Ol00005
oi?FoPCo00001?nJfod3o`000004oj;No?l0003o0000o`0004[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`?o00001_o;/L40
0ol0003o`J[3ol6Z``05ol6Z``Co00003_noZL@01?l0003o]JO;okFWboneYl/6o`0000ko/ZS>00?o
0000ojR/fonX[=/02_nX[=/Fo`0000coWKc^00?o0000oi?Fo_nCe_h00ol00005oi[Ko@?o00000_nR
g_`2o`0004kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00>_ooool0
0ol0003oooooooooo`1?ooooo`;o00001?o;/L400ol0003o`J[3ol6Z``09ol6Z``Co00002_noZL@0
0ol0003o]JO;okFWb`07okFWb`Ko00002?nbZ<h00ol0003oZ:cKojR/f`0EojR/f`03o`000?nM_>ko
WKc^017oWKc^1_l00005oi[Ko@?o00000onRg_`2o`00053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`1@ooooo`?o000000?obk71o`00
0?o1Z/<03_o1Z/<4o`0000Go_jW400?o0000okFWboneYl/03_neYl/6o`0000;o/ZS>00?o0000ojR/
fonX[=/05OnX[=/00ol0003oWKc^oiflkP09oiflkPSo00001OnS_^d00ol0003oV]_moi[Ko@03o`00
00?oX]kl0ol0001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003co
oooo0_l0001Cooooo`03o`000?o1Z/?o`J[301;o`J[31?l000000onoZLCo0000okFWb`0EokFWb`oo
00002onX[=/01?l0003oWKc^oiflk_nM_>h8o`0000_oXkk]1Ol00004oj;No0;o0000Eoooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000nooooo`03o`000?oooooooooo05?o
oooo1?l0000Bol6Z``;o00006?neYl/00ol0003o[:gHojb]f00:ojb]f0oo00003OnS_^d6o`0000Co
Yl3[00?o0000oj;No?l000000_l0001Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00Oooool003oooooo00?o0000ooooooooool0E_ooool4o`0000oo`J[300?o0000okNXb_ngZ<X0
0_ngZ<X9o`0000_o]JO;00?o0000ojb]f?n/[MP05On/[MP00ol0003oXkk]oj>nk@07oj>nk@Oo0000
2?nW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00@?oo
ool00ol0003oooooooooo`1Iooooo`Go00002_o1Z/<00ol0003o]jS:okNXbP0;okNXbPSo00000one
Yl/00ol0003o[:gHojb]f00Fojb]f003o`000?nS_^goXkk]00Ko00002_nW`>/5o`0006;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00@Oooool2o`0005_ooooo00?o0000
ooooooooool01?l00005ol6Z``03o`000?ngZ<[o]jS:01Co]jS:7ol0000;ojO0j`Go0000J?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0013ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool01?ooool4o`000003ol6Z`ol0003o]jS:01So]jS:00?o0000ojn^
eon_[]L05_n_[]L00ol0003oYl3[ojO0j`06ojO0j`Go0000K_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool02?ooool2o`0001Wo]jS:00?o0000ojn^eon_[]L05on_[]L00ol0003oYl3[ojO0j`05o`0007?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00AOooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00kooooo2Ol0000<okNXbP03o`000?n_[]Oo[jkG017o[jkG
2Ol0001iooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo0016ooooo`;o0000E_oo
ool00ol0003oooooooooo`0Gooooo`Wo00000ongZ<X00ol0003o[jkGojn^e`04ojn^e`go0000Pooo
ool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00B?ooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo023ooooo2_l0002Aooooo`03o`000?oooooooooo00Kooooo0Ol00001
ooooo`7ooooo0019ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0^oooool00ol0
003oooooooooo`06ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooooooo0;cooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004_ooooo
0_l0001Aooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo
0Oooool004gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2mooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo001>ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0__ooool00ol0003oooooooooo`04ooooo`7o00000Oooool004oooooo0_l0001=oooo
o`03o`000?oooooooooo0;oooooo00?o0000ooooooooool00oooool1o`00007ooooo001Aooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`02ooooo`7o
00000Oooool005;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`30ooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00Doooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo0<7ooooo00Go0000ooooooooooooooooo`000001ooooo`00E?ooool2o`0004Sooooo00?o
0000ooooooooool0`_ooool01?l0003oooooooooool00001ooooo`00E_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooool000000Oooool005Oooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo007o0000001Hoooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0a?ooool1o`00007ooooo0Ol0000005Wo
oooo0_l00013ooooo`03o`000?oooooooooo0<Gooooo0_l0000005_ooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`34ooooo`?o0000001Looooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0`?ooool4o`0000?ooooo001Mooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0_?ooool4o`0000Oooooo001Nooooo`;o0000?_ooool00ol0003oooooooooo`2hoooo
o`Co00002oooool0063ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2dooooo`Co
00003oooool0067ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2aooooo`?o0000
4oooool006;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2]ooooo`Co00005_oo
ool006?ooooo0_l0000iooooo`03o`000?oooooooooo0:Wooooo1?l0000Jooooo`00IOooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo0:Gooooo1?l0000Nooooo`00I_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo0:;ooooo1?l0000Rooooo`00Ioooool2o`0003Cooooo
00?o0000ooooooooool0W_ooool4o`0002Kooooo001Yooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0V_ooool4o`0002[ooooo001Zooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0U_ooool4o`0002kooooo001[ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0T_ooool4o`0003;ooooo001/ooooo`;o0000;oooool00ol0003oooooooooo`2>ooooo`Co
0000=_ooool006kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:ooooo`Co0000
>_ooool006oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`27ooooo`?o0000?_oo
ool0073ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co0000@Oooool0
077ooooo0_l0000Zooooo`03o`000?oooooooooo07oooooo1?l00015ooooo`00Loooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo07_ooooo1?l00019ooooo`00M?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001=ooooo`00MOooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo07?ooooo1?l0001Aooooo`00M_ooool2o`0002Gooooo00?o0000
ooooooooool0Koooool4o`0005Gooooo001hooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0Joooool4o`0005Wooooo001iooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0Ioooool4o`0005gooooo001jooooo`;o00008Oooool00ol0003oooooooooo`1Sooooo`Co0000
HOooool007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Pooooo`?o0000IOoo
ool007gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Looooo`Co0000J?ooool0
07kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Hooooo`Co0000K?ooool007oo
oooo0_l0000Looooo`03o`000?oooooooooo05Cooooo1?l0001`ooooo`00POooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo053ooooo1?l0001dooooo`00P_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04cooooo1?l0001hooooo`00Poooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04Sooooo1?l0001looooo`00Q?ooool2o`0001Oooooo00?o0000oooo
ooooool0A?ooool4o`00083ooooo0026ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0@?ooool4o`0008Cooooo0027ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
??ooool4o`0008Sooooo0028ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>Ooo
ool3o`0008cooooo0029ooooo`;o00004_ooool00ol0003oooooooooo`0eooooo`Co0000Soooool0
08_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0booooo`Co0000Toooool008co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`Co0000Uoooool008gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`Co0000Voooool008kooooo0_l0
000<ooooo`03o`000?oooooooooo02Kooooo1?l0002Oooooo`00T?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02;ooooo1?l0002Sooooo`00TOooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01kooooo1?l0002Wooooo`00T_ooool2o`0000Sooooo00?o0000oooooooo
ool06_ooool4o`000:_ooooo002Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool4o`000:oooooo002Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool4o`000;?ooooo002Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool3
o`000;Oooooo002Gooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`Co0000^_ooool009Wo
oooo00Co0000oooooooooooo00002Oooool4o`000;kooooo002Jooooo`03o`000?oooooo000000Go
oooo1?l00032ooooo`00Voooool2o`000003ooooool0003o000000;o0000a_ooool009cooooo0_l0
003:ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51726 .64678 m .51694 .65827 L .43899 .65168 L p .713 .672 .808 r
F P
0 g
s
.51694 .65827 m .51726 .64678 L .59258 .64491 L p .681 .692 .854 r
F P
0 g
s
.59258 .64491 m .59527 .65394 L .51694 .65827 L p .681 .692 .854 r
F P
0 g
s
.59527 .65394 m .59258 .64491 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44241 .63841 L .51726 .64678 L p .713 .672 .808 r
F P
0 g
s
.51757 .63542 m .51726 .64678 L .44241 .63841 L p .706 .669 .812 r
F P
0 g
s
.51726 .64678 m .51757 .63542 L .58987 .63592 L p .671 .688 .858 r
F P
0 g
s
.58987 .63592 m .59258 .64491 L .51726 .64678 L p .671 .688 .858 r
F P
0 g
s
.44241 .63841 m .43899 .65168 L .36521 .63435 L p .748 .678 .783 r
F P
0 g
s
.44241 .63841 m .44583 .62536 L .51757 .63542 L p .706 .669 .812 r
F P
0 g
s
.5179 .62457 m .51757 .63542 L .44583 .62536 L p .695 .67 .822 r
F P
0 g
s
.51757 .63542 m .5179 .62457 L .58715 .62717 L p .657 .688 .867 r
F P
0 g
s
.58715 .62717 m .58987 .63592 L .51757 .63542 L p .657 .688 .867 r
F P
0 g
s
.59258 .64491 m .58987 .63592 L .65915 .62672 L p .64 .746 .925 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59258 .64491 L p .64 .746 .925 r
F P
0 g
s
.36521 .63435 m .37169 .6201 L .44241 .63841 L p .748 .678 .783 r
F P
0 g
s
.44583 .62536 m .44241 .63841 L .37169 .6201 L p .742 .676 .786 r
F P
0 g
s
.37169 .6201 m .37817 .60614 L .44583 .62536 L p .742 .676 .786 r
F P
0 g
s
.44925 .61307 m .44583 .62536 L .37817 .60614 L p .733 .678 .797 r
F P
0 g
s
.44583 .62536 m .44925 .61307 L .5179 .62457 L p .695 .67 .822 r
F P
0 g
s
.51822 .6146 m .5179 .62457 L .44925 .61307 L p .679 .677 .84 r
F P
0 g
s
.5179 .62457 m .51822 .6146 L .58441 .61884 L p .641 .691 .881 r
F P
0 g
s
.58441 .61884 m .58715 .62717 L .5179 .62457 L p .641 .691 .881 r
F P
0 g
s
.58987 .63592 m .58715 .62717 L .65355 .62061 L p .623 .74 .931 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58987 .63592 L p .623 .74 .931 r
F P
0 g
s
.37817 .60614 m .38462 .59317 L .44925 .61307 L p .733 .678 .797 r
F P
0 g
s
.45266 .60204 m .44925 .61307 L .38462 .59317 L p .717 .684 .817 r
F P
0 g
s
.44925 .61307 m .45266 .60204 L .51822 .6146 L p .679 .677 .84 r
F P
0 g
s
.51854 .6058 m .51822 .6146 L .45266 .60204 L p .656 .688 .868 r
F P
0 g
s
.51822 .6146 m .51854 .6058 L .58167 .6111 L p .621 .697 .899 r
F P
0 g
s
.58167 .6111 m .58441 .61884 L .51822 .6146 L p .621 .697 .899 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72992 .61072 L p .644 .847 .978 r
F P
0 g
s
.72992 .61072 m .73799 .61332 L .67023 .63881 L p .644 .847 .978 r
F P
0 g
s
.58715 .62717 m .58441 .61884 L .6479 .61445 L p .606 .734 .935 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58715 .62717 L p .606 .734 .935 r
F P
0 g
s
.38462 .59317 m .39103 .58177 L .45266 .60204 L p .717 .684 .817 r
F P
0 g
s
.45605 .59271 m .45266 .60204 L .39103 .58177 L p .691 .695 .849 r
F P
0 g
s
.45266 .60204 m .45605 .59271 L .51854 .6058 L p .656 .688 .868 r
F P
0 g
s
.37169 .6201 m .36521 .63435 L .29943 .6068 L p .783 .702 .775 r
F P
0 g
s
.51886 .59838 m .51854 .6058 L .45605 .59271 L p .621 .703 .904 r
F P
0 g
s
.51854 .6058 m .51886 .59838 L .57892 .60405 L p .596 .707 .921 r
F P
0 g
s
.57892 .60405 m .58167 .6111 L .51854 .6058 L p .596 .707 .921 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72179 .608 L p .622 .84 .983 r
F P
0 g
s
.72179 .608 m .72992 .61072 L .66471 .63279 L p .622 .84 .983 r
F P
0 g
s
.29943 .6068 m .30879 .59247 L .37169 .6201 L p .783 .702 .775 r
F P
0 g
s
.37817 .60614 m .37169 .6201 L .30879 .59247 L p .779 .701 .778 r
F P
0 g
s
.58441 .61884 m .58167 .6111 L .64221 .60824 L p .589 .727 .939 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58441 .61884 L p .589 .727 .939 r
F P
0 g
s
.39103 .58177 m .39738 .57247 L .45605 .59271 L p .691 .695 .849 r
F P
0 g
s
.45942 .58535 m .45605 .59271 L .39738 .57247 L p .646 .709 .893 r
F P
0 g
s
.45605 .59271 m .45942 .58535 L .51886 .59838 L p .621 .703 .904 r
F P
0 g
s
.30879 .59247 m .31812 .57851 L .37817 .60614 L p .779 .701 .778 r
F P
0 g
s
.38462 .59317 m .37817 .60614 L .31812 .57851 L p .77 .703 .789 r
F P
0 g
s
.31812 .57851 m .3274 .56568 L .38462 .59317 L p .77 .703 .789 r
F P
0 g
s
.39103 .58177 m .38462 .59317 L .3274 .56568 L p .753 .708 .81 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71357 .60494 L p .602 .825 .985 r
F P
0 g
s
.71357 .60494 m .72179 .608 L .65915 .62672 L p .602 .825 .985 r
F P
0 g
s
.51918 .59246 m .51886 .59838 L .45942 .58535 L p .564 .721 .947 r
F P
0 g
s
.51886 .59838 m .51918 .59246 L .57615 .59777 L p .567 .721 .945 r
F P
0 g
s
.57615 .59777 m .57892 .60405 L .51886 .59838 L p .567 .721 .945 r
F P
0 g
s
.58167 .6111 m .57892 .60405 L .63648 .60198 L p .577 .722 .942 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58167 .6111 L p .577 .722 .942 r
F P
0 g
s
.39738 .57247 m .40368 .56563 L .45942 .58535 L p .646 .709 .893 r
F P
0 g
s
.46278 .58015 m .45942 .58535 L .40368 .56563 L p .561 .72 .947 r
F P
0 g
s
.45942 .58535 m .46278 .58015 L .51918 .59246 L p .564 .721 .947 r
F P
0 g
s
.3274 .56568 m .33658 .55465 L .39103 .58177 L p .753 .708 .81 r
F P
0 g
s
.39738 .57247 m .39103 .58177 L .33658 .55465 L p .722 .716 .844 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70526 .60137 L p .586 .803 .982 r
F P
0 g
s
.70526 .60137 m .71357 .60494 L .65355 .62061 L p .586 .803 .982 r
F P
0 g
s
.33658 .55465 m .34566 .546 L .39738 .57247 L p .722 .716 .844 r
F P
0 g
s
.40368 .56563 m .39738 .57247 L .34566 .546 L p .667 .723 .891 r
F P
0 g
s
.5195 .58806 m .51918 .59246 L .46278 .58015 L p .474 .732 .983 r
F P
0 g
s
.51918 .59246 m .5195 .58806 L .57338 .59223 L p .537 .736 .967 r
F P
0 g
s
.57338 .59223 m .57615 .59777 L .51918 .59246 L p .537 .736 .967 r
F P
0 g
s
.57892 .60405 m .57615 .59777 L .6307 .59568 L p .569 .719 .943 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57892 .60405 L p .569 .719 .943 r
F P
0 g
s
.40368 .56563 m .40993 .56145 L .46278 .58015 L p .561 .72 .947 r
F P
0 g
s
.46613 .5771 m .46278 .58015 L .40993 .56145 L p .4 .702 .983 r
F P
0 g
s
.46278 .58015 m .46613 .5771 L .5195 .58806 L p .474 .732 .983 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69686 .5971 L p .575 .775 .974 r
F P
0 g
s
.69686 .5971 m .70526 .60137 L .6479 .61445 L p .575 .775 .974 r
F P
0 g
s
.34566 .546 m .35463 .54012 L .40368 .56563 L p .667 .723 .891 r
F P
0 g
s
.40993 .56145 m .40368 .56563 L .35463 .54012 L p .559 .718 .947 r
F P
0 g
s
.73799 .61332 m .72992 .61072 L .7844 .57939 L p .665 .933 .97 r
F P
0 g
s
.7844 .57939 m .79464 .57831 L .73799 .61332 L p .665 .933 .97 r
F P
0 g
s
.57615 .59777 m .57338 .59223 L .62488 .58932 L p .57 .72 .943 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57615 .59777 L p .57 .72 .943 r
F P
0 g
s
.51982 .58504 m .5195 .58806 L .46613 .5771 L p .344 .719 .985 r
F P
0 g
s
.5195 .58806 m .51982 .58504 L .57058 .5874 L p .509 .755 .984 r
F P
0 g
s
.57058 .5874 m .57338 .59223 L .5195 .58806 L p .509 .755 .984 r
F P
0 g
s
.40993 .56145 m .41614 .55993 L .46613 .5771 L p .4 .702 .983 r
F P
0 g
s
.46949 .57605 m .46613 .5771 L .41614 .55993 L p .136 .605 .923 r
F P
0 g
s
.46949 .57605 m .42234 .56089 L p .46006 .57269 L 0 .429 .736 r
F P
0 g
s
.46949 .57605 m .51982 .58504 L p .4769 .57869 L .344 .719 .985 r
F P
0 g
s
.52014 .5832 m .51982 .58504 L .46949 .57605 L p .195 .674 .932 r
F P
0 g
s
.47286 .5767 m .52014 .5832 L p .47622 .577 L .195 .674 .932 r
F P
0 g
s
.46949 .57605 m .47286 .5767 L p .47622 .577 L .195 .674 .932 r
F P
0 g
s
.47286 .5767 m .46949 .57605 L p .46006 .57269 L 0 .429 .736 r
F P
0 g
s
.46613 .5771 m .46949 .57605 L p .4769 .57869 L .344 .719 .985 r
F P
0 g
s
.42234 .56089 m .46949 .57605 L p .42688 .56317 L .136 .605 .923 r
F P
0 g
s
.41614 .55993 m .42234 .56089 L p .42688 .56317 L .136 .605 .923 r
F P
0 g
s
.42234 .56089 m .38105 .54028 L p .41656 .55797 L 0 .263 .637 r
F P
0 g
s
.42234 .56089 m .42856 .56395 L .47286 .5767 L p 0 .429 .736 r
F P
0 g
s
.42856 .56395 m .42234 .56089 L p .41656 .55797 L 0 .263 .637 r
F P
0 g
s
.47286 .5767 m .42856 .56395 L p .46896 .57635 L .326 0 0 r
F P
0 g
s
.47625 .57858 m .47286 .5767 L p .46896 .57635 L .326 0 0 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68836 .59203 L p .569 .746 .96 r
F P
0 g
s
.68836 .59203 m .69686 .5971 L .64221 .60824 L p .569 .746 .96 r
F P
0 g
s
.35463 .54012 m .3635 .53724 L .40993 .56145 L p .559 .718 .947 r
F P
0 g
s
.41614 .55993 m .40993 .56145 L .3635 .53724 L p .345 .662 .973 r
F P
0 g
s
.72992 .61072 m .72179 .608 L .77406 .58029 L p .64 .926 .974 r
F P
0 g
s
.77406 .58029 m .7844 .57939 L .72992 .61072 L p .64 .926 .974 r
F P
0 g
s
.30879 .59247 m .29943 .6068 L .24558 .56996 L p .818 .742 .78 r
F P
0 g
s
.24558 .56996 m .25745 .55654 L .30879 .59247 L p .818 .742 .78 r
F P
0 g
s
.31812 .57851 m .30879 .59247 L .25745 .55654 L p .814 .742 .784 r
F P
0 g
s
.25745 .55654 m .26927 .54354 L .31812 .57851 L p .814 .742 .784 r
F P
0 g
s
.3274 .56568 m .31812 .57851 L .26927 .54354 L p .804 .743 .796 r
F P
0 g
s
.26927 .54354 m .28098 .53175 L .3274 .56568 L p .804 .743 .796 r
F P
0 g
s
.33658 .55465 m .3274 .56568 L .28098 .53175 L p .784 .746 .818 r
F P
0 g
s
.57338 .59223 m .57058 .5874 L .61901 .58292 L p .58 .724 .941 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57338 .59223 L p .58 .724 .941 r
F P
0 g
s
.28098 .53175 m .29255 .52186 L .33658 .55465 L p .784 .746 .818 r
F P
0 g
s
.34566 .546 m .33658 .55465 L .29255 .52186 L p .748 .748 .852 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67976 .5861 L p .57 .718 .942 r
F P
0 g
s
.67976 .5861 m .68836 .59203 L .63648 .60198 L p .57 .718 .942 r
F P
0 g
s
.51982 .58504 m .52014 .5832 L .56777 .58314 L p .493 .776 .995 r
F P
0 g
s
.56777 .58314 m .57058 .5874 L .51982 .58504 L p .493 .776 .995 r
F P
0 g
s
.72179 .608 m .71357 .60494 L .76361 .58059 L p .62 .907 .984 r
F P
0 g
s
.76361 .58059 m .77406 .58029 L .72179 .608 L p .62 .907 .984 r
F P
0 g
s
.29255 .52186 m .30396 .51448 L .34566 .546 L p .748 .748 .852 r
F P
0 g
s
.35463 .54012 m .34566 .546 L .30396 .51448 L p .682 .743 .898 r
F P
0 g
s
.3635 .53724 m .3723 .53736 L .41614 .55993 L p .345 .662 .973 r
F P
0 g
s
.42234 .56089 m .41614 .55993 L .3723 .53736 L p .008 .494 .869 r
F P
0 g
s
.57058 .5874 m .56777 .58314 L .61309 .57646 L p .599 .731 .937 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57058 .5874 L p .599 .731 .937 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67108 .5793 L p .576 .693 .921 r
F P
0 g
s
.67108 .5793 m .67976 .5861 L .6307 .59568 L p .576 .693 .921 r
F P
0 g
s
.30396 .51448 m .3152 .51001 L .35463 .54012 L p .682 .743 .898 r
F P
0 g
s
.3635 .53724 m .35463 .54012 L .3152 .51001 L p .557 .716 .947 r
F P
0 g
s
.71357 .60494 m .70526 .60137 L .75301 .5799 L p .606 .876 .992 r
F P
0 g
s
.75301 .5799 m .76361 .58059 L .71357 .60494 L p .606 .876 .992 r
F P
0 g
s
.52047 .58221 m .52014 .5832 L .47286 .5767 L p .08 .621 .85 r
F P
0 g
s
.52014 .5832 m .52047 .58221 L .56493 .57929 L p .499 .802 .999 r
F P
0 g
s
.56493 .57929 m .56777 .58314 L .52014 .5832 L p .499 .802 .999 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66231 .5717 L p .587 .674 .9 r
F P
0 g
s
.66231 .5717 m .67108 .5793 L .62488 .58932 L p .587 .674 .9 r
F P
0 g
s
.38105 .54028 m .34818 .51525 L p .37933 .53794 L 0 .234 .688 r
F P
0 g
s
.38105 .54028 m .42234 .56089 L p .3824 .54211 L .008 .494 .869 r
F P
0 g
s
.38981 .54558 m .42856 .56395 L p .38741 .54345 L 0 .263 .637 r
F P
0 g
s
.38105 .54028 m .38981 .54558 L p .38741 .54345 L 0 .263 .637 r
F P
0 g
s
.38981 .54558 m .38105 .54028 L p .37933 .53794 L 0 .234 .688 r
F P
0 g
s
.35906 .52248 m .38981 .54558 L p .35377 .51932 L 0 .234 .688 r
F P
0 g
s
.34818 .51525 m .35906 .52248 L p .35377 .51932 L 0 .234 .688 r
F P
0 g
s
.35906 .52248 m .33851 .49589 L p .36522 .52615 L 0 .185 .703 r
F P
0 g
s
.38981 .54558 m .35906 .52248 L p .39261 .54805 L .465 0 0 r
F P
0 g
s
.36999 .53155 m .39862 .55263 L p .36181 .52457 L .465 0 0 r
F P
0 g
s
.35906 .52248 m .36999 .53155 L p .36181 .52457 L .465 0 0 r
F P
0 g
s
.38105 .54028 m .3723 .53736 L .33727 .5105 L p .014 .45 .869 r
F P
0 g
s
.33727 .5105 m .34818 .51525 L .38105 .54028 L p .014 .45 .869 r
F P
0 g
s
.40752 .56067 m .39862 .55263 L .36999 .53155 L p .544 0 0 r
F P
0 g
s
.3723 .53736 m .38105 .54028 L p .3824 .54211 L .008 .494 .869 r
F P
0 g
s
.36999 .53155 m .381 .54166 L .40752 .56067 L p .544 0 0 r
F P
0 g
s
.36999 .53155 m .35099 .50646 L p .37881 .53909 L 0 .129 .658 r
F P
0 g
s
.381 .54166 m .36999 .53155 L p .37881 .53909 L 0 .129 .658 r
F P
0 g
s
.36999 .53155 m .35906 .52248 L p .36522 .52615 L 0 .185 .703 r
F P
0 g
s
.39862 .55263 m .38981 .54558 L p .39261 .54805 L .465 0 0 r
F P
0 g
s
.3152 .51001 m .3263 .50868 L .3635 .53724 L p .557 .716 .947 r
F P
0 g
s
.3723 .53736 m .3635 .53724 L .3263 .50868 L p .334 .629 .96 r
F P
0 g
s
.47286 .5767 m .47625 .57858 L .52047 .58221 L p .08 .621 .85 r
F P
0 g
s
.70526 .60137 m .69686 .5971 L .74225 .57792 L p .593 .829 .989 r
F P
0 g
s
.74225 .57792 m .75301 .5799 L .70526 .60137 L p .593 .829 .989 r
F P
0 g
s
.56777 .58314 m .56493 .57929 L .60713 .56996 L p .626 .741 .93 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56777 .58314 L p .626 .741 .93 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65347 .56342 L p .602 .661 .88 r
F P
0 g
s
.65347 .56342 m .66231 .5717 L .61901 .58292 L p .602 .661 .88 r
F P
0 g
s
.69686 .5971 m .68836 .59203 L .73134 .57441 L p .58 .773 .971 r
F P
0 g
s
.73134 .57441 m .74225 .57792 L .69686 .5971 L p .58 .773 .971 r
F P
0 g
s
.3263 .50868 m .33727 .5105 L .3723 .53736 L p .334 .629 .96 r
F P
0 g
s
.5208 .58165 m .52047 .58221 L .47625 .57858 L p .04 .603 .793 r
F P
0 g
s
.52047 .58221 m .5208 .58165 L .56207 .57563 L p .533 .833 .999 r
F P
0 g
s
.56207 .57563 m .56493 .57929 L .52047 .58221 L p .533 .833 .999 r
F P
0 g
s
.56493 .57929 m .56207 .57563 L .60112 .5634 L p .66 .753 .919 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57929 L p .66 .753 .919 r
F P
0 g
s
.43482 .56857 m .42856 .56395 L .38981 .54558 L p .49 0 0 r
F P
0 g
s
.42856 .56395 m .43482 .56857 L .47625 .57858 L p .326 0 0 r
F P
0 g
s
.79464 .57831 m .7844 .57939 L .82432 .54001 L p .742 .978 .92 r
F P
0 g
s
.82432 .54001 m .83625 .53514 L .79464 .57831 L p .742 .978 .92 r
F P
0 g
s
.68836 .59203 m .67976 .5861 L .72028 .56926 L p .569 .715 .941 r
F P
0 g
s
.72028 .56926 m .73134 .57441 L .68836 .59203 L p .569 .715 .941 r
F P
0 g
s
.47969 .58114 m .47625 .57858 L .43482 .56857 L p .396 0 0 r
F P
0 g
s
.47625 .57858 m .47969 .58114 L .5208 .58165 L p .04 .603 .793 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64458 .55466 L p .621 .655 .862 r
F P
0 g
s
.64458 .55466 m .65347 .56342 L .61309 .57646 L p .621 .655 .862 r
F P
0 g
s
.23509 .5028 m .24865 .49294 L .28098 .53175 L p .831 .795 .817 r
F P
0 g
s
.28098 .53175 m .26927 .54354 L .23509 .5028 L p .831 .795 .817 r
F P
0 g
s
.29255 .52186 m .28098 .53175 L .24865 .49294 L p .807 .794 .84 r
F P
0 g
s
.24865 .49294 m .26203 .48498 L .29255 .52186 L p .807 .794 .84 r
F P
0 g
s
.30396 .51448 m .29255 .52186 L .26203 .48498 L p .763 .786 .873 r
F P
0 g
s
.22138 .51385 m .23509 .5028 L .26927 .54354 L p .844 .795 .804 r
F P
0 g
s
.26927 .54354 m .25745 .55654 L .22138 .51385 L p .844 .795 .804 r
F P
0 g
s
.67976 .5861 m .67108 .5793 L .70908 .56246 L p .561 .665 .907 r
F P
0 g
s
.70908 .56246 m .72028 .56926 L .67976 .5861 L p .561 .665 .907 r
F P
0 g
s
.7844 .57939 m .77406 .58029 L .81228 .54463 L p .723 .974 .925 r
F P
0 g
s
.81228 .54463 m .82432 .54001 L .7844 .57939 L p .723 .974 .925 r
F P
0 g
s
.20758 .52532 m .22138 .51385 L .25745 .55654 L p .847 .793 .799 r
F P
0 g
s
.25745 .55654 m .24558 .56996 L .20758 .52532 L p .847 .793 .799 r
F P
0 g
s
.26203 .48498 m .2752 .47947 L .30396 .51448 L p .763 .786 .873 r
F P
0 g
s
.3152 .51001 m .30396 .51448 L .2752 .47947 L p .686 .765 .912 r
F P
0 g
s
.52113 .58107 m .5208 .58165 L .47969 .58114 L p .089 .645 .794 r
F P
0 g
s
.5208 .58165 m .52113 .58107 L .55918 .57192 L p .592 .865 .994 r
F P
0 g
s
.55918 .57192 m .56207 .57563 L .5208 .58165 L p .592 .865 .994 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63564 .54562 L p .643 .654 .846 r
F P
0 g
s
.63564 .54562 m .64458 .55466 L .60713 .56996 L p .643 .654 .846 r
F P
0 g
s
.56207 .57563 m .55918 .57192 L .59506 .55679 L p .696 .764 .904 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56207 .57563 L p .696 .764 .904 r
F P
0 g
s
.2752 .47947 m .28816 .47682 L .3152 .51001 L p .686 .765 .912 r
F P
0 g
s
.3263 .50868 m .3152 .51001 L .28816 .47682 L p .558 .714 .945 r
F P
0 g
s
.67108 .5793 m .66231 .5717 L .69777 .55415 L p .559 .626 .875 r
F P
0 g
s
.69777 .55415 m .70908 .56246 L .67108 .5793 L p .559 .626 .875 r
F P
0 g
s
.38981 .54558 m .39862 .55263 L .43482 .56857 L p .49 0 0 r
F P
0 g
s
.44114 .57404 m .43482 .56857 L .39862 .55263 L p .561 0 0 r
F P
0 g
s
.43482 .56857 m .44114 .57404 L .47969 .58114 L p .396 0 0 r
F P
0 g
s
.77406 .58029 m .76361 .58059 L .80008 .54842 L p .703 .96 .946 r
F P
0 g
s
.80008 .54842 m .81228 .54463 L .77406 .58029 L p .703 .96 .946 r
F P
0 g
s
.48317 .5837 m .47969 .58114 L .44114 .57404 L p .384 0 0 r
F P
0 g
s
.47969 .58114 m .48317 .5837 L .52113 .58107 L p .089 .645 .794 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62665 .53654 L p .668 .66 .832 r
F P
0 g
s
.62665 .53654 m .63564 .54562 L .60112 .5634 L p .668 .66 .832 r
F P
0 g
s
.28816 .47682 m .30093 .47725 L .3263 .50868 L p .558 .714 .945 r
F P
0 g
s
.33727 .5105 m .3263 .50868 L .30093 .47725 L p .363 .613 .946 r
F P
0 g
s
.66231 .5717 m .65347 .56342 L .68638 .54459 L p .562 .599 .848 r
F P
0 g
s
.68638 .54459 m .69777 .55415 L .66231 .5717 L p .562 .599 .848 r
F P
0 g
s
.55625 .56791 m .55918 .57192 L .52113 .58107 L p .665 .888 .979 r
F P
0 g
s
.55918 .57192 m .55625 .56791 L .58896 .55013 L p .731 .773 .886 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55918 .57192 L p .731 .773 .886 r
F P
0 g
s
.76361 .58059 m .75301 .5799 L .7877 .55082 L p .68 .928 .97 r
F P
0 g
s
.7877 .55082 m .80008 .54842 L .76361 .58059 L p .68 .928 .97 r
F P
0 g
s
.52147 .57998 m .52113 .58107 L .48317 .5837 L p .227 .744 .853 r
F P
0 g
s
.52113 .58107 m .52147 .57998 L .55625 .56791 L p .665 .888 .979 r
F P
0 g
s
.65347 .56342 m .64458 .55466 L .67493 .53414 L p .572 .584 .826 r
F P
0 g
s
.67493 .53414 m .68638 .54459 L .65347 .56342 L p .572 .584 .826 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61764 .52769 L p .695 .669 .82 r
F P
0 g
s
.61764 .52769 m .62665 .53654 L .59506 .55679 L p .695 .669 .82 r
F P
0 g
s
.30093 .47725 m .31354 .48075 L .33727 .5105 L p .363 .613 .946 r
F P
0 g
s
.34818 .51525 m .33727 .5105 L .31354 .48075 L p .123 .462 .889 r
F P
0 g
s
.64458 .55466 m .63564 .54562 L .66345 .52322 L p .588 .578 .81 r
F P
0 g
s
.66345 .52322 m .67493 .53414 L .64458 .55466 L p .588 .578 .81 r
F P
0 g
s
.39862 .55263 m .40752 .56067 L .44114 .57404 L p .561 0 0 r
F P
0 g
s
.44757 .57956 m .44114 .57404 L .40752 .56067 L p .563 0 0 r
F P
0 g
s
.44114 .57404 m .44757 .57956 L .48317 .5837 L p .384 0 0 r
F P
0 g
s
.75301 .5799 m .74225 .57792 L .77511 .55137 L p .649 .871 .982 r
F P
0 g
s
.77511 .55137 m .7877 .55082 L .75301 .5799 L p .649 .871 .982 r
F P
0 g
s
.48671 .58557 m .48317 .5837 L .44757 .57956 L p .291 0 0 r
F P
0 g
s
.48317 .5837 m .48671 .58557 L .52147 .57998 L p .227 .744 .853 r
F P
0 g
s
.55328 .56335 m .55625 .56791 L .52147 .57998 L p .735 .897 .952 r
F P
0 g
s
.55625 .56791 m .55328 .56335 L .5828 .54342 L p .764 .78 .865 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55625 .56791 L p .764 .78 .865 r
F P
0 g
s
.63564 .54562 m .62665 .53654 L .65196 .51232 L p .609 .582 .798 r
F P
0 g
s
.65196 .51232 m .66345 .52322 L .63564 .54562 L p .609 .582 .798 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60859 .5193 L p .724 .682 .81 r
F P
0 g
s
.60859 .5193 m .61764 .52769 L .58896 .55013 L p .724 .682 .81 r
F P
0 g
s
.74225 .57792 m .73134 .57441 L .76231 .54974 L p .608 .795 .971 r
F P
0 g
s
.76231 .54974 m .77511 .55137 L .74225 .57792 L p .608 .795 .971 r
F P
0 g
s
.52181 .57789 m .52147 .57998 L .48671 .58557 L p .43 .862 .929 r
F P
0 g
s
.52147 .57998 m .52181 .57789 L .55328 .56335 L p .735 .897 .952 r
F P
0 g
s
.31354 .48075 m .32605 .48711 L .34818 .51525 L p .123 .462 .889 r
F P
0 g
s
.35906 .52248 m .34818 .51525 L .32605 .48711 L p 0 .303 .792 r
F P
0 g
s
.62665 .53654 m .61764 .52769 L .64049 .50191 L p .635 .593 .79 r
F P
0 g
s
.64049 .50191 m .65196 .51232 L .62665 .53654 L p .635 .593 .79 r
F P
0 g
s
.73134 .57441 m .72028 .56926 L .74931 .54578 L p .567 .714 .941 r
F P
0 g
s
.74931 .54578 m .76231 .54974 L .73134 .57441 L p .567 .714 .941 r
F P
0 g
s
.61764 .52769 m .60859 .5193 L .62903 .49244 L p .665 .611 .785 r
F P
0 g
s
.62903 .49244 m .64049 .50191 L .61764 .52769 L p .665 .611 .785 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55328 .56335 L p .794 .784 .844 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59952 .51156 L p .752 .697 .799 r
F P
0 g
s
.59952 .51156 m .60859 .5193 L .5828 .54342 L p .752 .697 .799 r
F P
0 g
s
.55028 .55803 m .55328 .56335 L .52181 .57789 L p .79 .891 .916 r
F P
0 g
s
.55328 .56335 m .55028 .55803 L .5766 .53665 L p .794 .784 .844 r
F P
0 g
s
.40752 .56067 m .41654 .56878 L .44757 .57956 L p .563 0 0 r
F P
0 g
s
.45411 .58427 m .44757 .57956 L .41654 .56878 L p .5 0 0 r
F P
0 g
s
.44757 .57956 m .45411 .58427 L .48671 .58557 L p .291 0 0 r
F P
0 g
s
.72028 .56926 m .70908 .56246 L .73614 .53948 L p .532 .641 .903 r
F P
0 g
s
.73614 .53948 m .74931 .54578 L .72028 .56926 L p .532 .641 .903 r
F P
0 g
s
.49032 .58608 m .48671 .58557 L .45411 .58427 L p .086 0 0 r
F P
0 g
s
.48671 .58557 m .49032 .58608 L .52181 .57789 L p .43 .862 .929 r
F P
0 g
s
.60859 .5193 m .59952 .51156 L .61759 .48432 L p .698 .633 .78 r
F P
0 g
s
.61759 .48432 m .62903 .49244 L .60859 .5193 L p .698 .633 .78 r
F P
0 g
s
.32605 .48711 m .33851 .49589 L .35906 .52248 L p 0 .303 .792 r
F P
0 g
s
.70908 .56246 m .69777 .55415 L .72285 .53106 L p .508 .585 .867 r
F P
0 g
s
.72285 .53106 m .73614 .53948 L .70908 .56246 L p .508 .585 .867 r
F P
0 g
s
.41654 .56878 m .40752 .56067 L .381 .54166 L p .548 0 0 r
F P
0 g
s
.52216 .57437 m .52181 .57789 L .49032 .58608 L p .628 .936 .963 r
F P
0 g
s
.52181 .57789 m .52216 .57437 L .55028 .55803 L p .79 .891 .916 r
F P
0 g
s
.69777 .55415 m .68638 .54459 L .70947 .52089 L p .497 .546 .837 r
F P
0 g
s
.70947 .52089 m .72285 .53106 L .69777 .55415 L p .497 .546 .837 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55028 .55803 L p .818 .786 .822 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59041 .50466 L p .78 .713 .79 r
F P
0 g
s
.59041 .50466 m .59952 .51156 L .5766 .53665 L p .78 .713 .79 r
F P
0 g
s
.68638 .54459 m .67493 .53414 L .69605 .50948 L p .497 .524 .815 r
F P
0 g
s
.69605 .50948 m .70947 .52089 L .68638 .54459 L p .497 .524 .815 r
F P
0 g
s
.24784 .44599 m .26201 .4429 L .2752 .47947 L p .759 .825 .904 r
F P
0 g
s
.2752 .47947 m .26203 .48498 L .24784 .44599 L p .759 .825 .904 r
F P
0 g
s
.28816 .47682 m .2752 .47947 L .26201 .4429 L p .677 .784 .93 r
F P
0 g
s
.67493 .53414 m .66345 .52322 L .68264 .49747 L p .508 .515 .799 r
F P
0 g
s
.68264 .49747 m .69605 .50948 L .67493 .53414 L p .508 .515 .799 r
F P
0 g
s
.23343 .45132 m .24784 .44599 L .26203 .48498 L p .812 .846 .875 r
F P
0 g
s
.26203 .48498 m .24865 .49294 L .23343 .45132 L p .812 .846 .875 r
F P
0 g
s
.83625 .53514 m .82432 .54001 L .84605 .4944 L p .838 .975 .88 r
F P
0 g
s
.84605 .4944 m .85906 .48583 L .83625 .53514 L p .838 .975 .88 r
F P
0 g
s
.59952 .51156 m .59041 .50466 L .60617 .47786 L p .733 .659 .776 r
F P
0 g
s
.60617 .47786 m .61759 .48432 L .59952 .51156 L p .733 .659 .776 r
F P
0 g
s
.66345 .52322 m .65196 .51232 L .66928 .48552 L p .528 .519 .789 r
F P
0 g
s
.66928 .48552 m .68264 .49747 L .66345 .52322 L p .528 .519 .789 r
F P
0 g
s
.54724 .55176 m .55028 .55803 L .52216 .57437 L p .829 .874 .877 r
F P
0 g
s
.55028 .55803 m .54724 .55176 L .57035 .52982 L p .818 .786 .822 r
F P
0 g
s
.65196 .51232 m .64049 .50191 L .65598 .47431 L p .557 .533 .784 r
F P
0 g
s
.65598 .47431 m .66928 .48552 L .65196 .51232 L p .557 .533 .784 r
F P
0 g
s
.26201 .4429 m .27594 .44241 L .28816 .47682 L p .677 .784 .93 r
F P
0 g
s
.30093 .47725 m .28816 .47682 L .27594 .44241 L p .56 .713 .944 r
F P
0 g
s
.21881 .45837 m .23343 .45132 L .24865 .49294 L p .842 .854 .853 r
F P
0 g
s
.24865 .49294 m .23509 .5028 L .21881 .45837 L p .842 .854 .853 r
F P
0 g
s
.64049 .50191 m .62903 .49244 L .64278 .46449 L p .593 .556 .782 r
F P
0 g
s
.64278 .46449 m .65598 .47431 L .64049 .50191 L p .593 .556 .782 r
F P
0 g
s
.62903 .49244 m .61759 .48432 L .62966 .45661 L p .636 .586 .781 r
F P
0 g
s
.62966 .45661 m .64278 .46449 L .62903 .49244 L p .636 .586 .781 r
F P
0 g
s
.20402 .46652 m .21881 .45837 L .23509 .5028 L p .858 .856 .838 r
F P
0 g
s
.23509 .5028 m .22138 .51385 L .20402 .46652 L p .858 .856 .838 r
F P
0 g
s
.27594 .44241 m .28966 .44472 L .30093 .47725 L p .56 .713 .944 r
F P
0 g
s
.31354 .48075 m .30093 .47725 L .28966 .44472 L p .414 .612 .931 r
F P
0 g
s
.58126 .4987 m .59041 .50466 L .57035 .52982 L p .806 .729 .78 r
F P
0 g
s
.59041 .50466 m .58126 .4987 L .59475 .47325 L p .768 .685 .772 r
F P
0 g
s
.59475 .47325 m .60617 .47786 L .59041 .50466 L p .768 .685 .772 r
F P
0 g
s
.45411 .58427 m .46077 .58733 L .49032 .58608 L p .086 0 0 r
F P
0 g
s
.494 .5846 m .49032 .58608 L .46077 .58733 L p .246 .756 .867 r
F P
0 g
s
.49032 .58608 m .494 .5846 L .52216 .57437 L p .628 .936 .963 r
F P
0 g
s
.61759 .48432 m .60617 .47786 L .61662 .45108 L p .682 .62 .78 r
F P
0 g
s
.61662 .45108 m .62966 .45661 L .61759 .48432 L p .682 .62 .78 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54724 .55176 L p .838 .787 .802 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58126 .4987 L p .806 .729 .78 r
F P
0 g
s
.41654 .56878 m .42573 .57602 L .45411 .58427 L p .5 0 0 r
F P
0 g
s
.46077 .58733 m .45411 .58427 L .42573 .57602 L p .34 0 0 r
F P
0 g
s
.33851 .49589 m .35099 .50646 L .36999 .53155 L p 0 .185 .703 r
F P
0 g
s
.82432 .54001 m .81228 .54463 L .83293 .50267 L p .827 .976 .887 r
F P
0 g
s
.83293 .50267 m .84605 .4944 L .82432 .54001 L p .827 .976 .887 r
F P
0 g
s
.52252 .56908 m .52216 .57437 L .494 .5846 L p .762 .942 .94 r
F P
0 g
s
.52216 .57437 m .52252 .56908 L .54724 .55176 L p .829 .874 .877 r
F P
0 g
s
.18911 .47507 m .20402 .46652 L .22138 .51385 L p .862 .853 .832 r
F P
0 g
s
.22138 .51385 m .20758 .52532 L .18911 .47507 L p .862 .853 .832 r
F P
0 g
s
.60617 .47786 m .59475 .47325 L .60364 .4482 L p .729 .656 .778 r
F P
0 g
s
.60364 .4482 m .61662 .45108 L .60617 .47786 L p .729 .656 .778 r
F P
0 g
s
.381 .54166 m .39216 .55186 L .41654 .56878 L p .548 0 0 r
F P
0 g
s
.42573 .57602 m .41654 .56878 L .39216 .55186 L p .479 0 0 r
F P
0 g
s
.54416 .54444 m .54724 .55176 L .52252 .56908 L p .854 .853 .841 r
F P
0 g
s
.54724 .55176 m .54416 .54444 L .56404 .52294 L p .838 .787 .802 r
F P
0 g
s
.28966 .44472 m .3032 .44981 L .31354 .48075 L p .414 .612 .931 r
F P
0 g
s
.32605 .48711 m .31354 .48075 L .3032 .44981 L p .266 .498 .893 r
F P
0 g
s
.57208 .49372 m .58126 .4987 L .56404 .52294 L p .829 .744 .77 r
F P
0 g
s
.58126 .4987 m .57208 .49372 L .58331 .47058 L p .801 .711 .766 r
F P
0 g
s
.58331 .47058 m .59475 .47325 L .58126 .4987 L p .801 .711 .766 r
F P
0 g
s
.81228 .54463 m .80008 .54842 L .81965 .5099 L p .805 .965 .909 r
F P
0 g
s
.81965 .5099 m .83293 .50267 L .81228 .54463 L p .805 .965 .909 r
F P
0 g
s
.59475 .47325 m .58331 .47058 L .59068 .44806 L p .773 .691 .773 r
F P
0 g
s
.59068 .44806 m .60364 .4482 L .59475 .47325 L p .773 .691 .773 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54416 .54444 L p .854 .786 .784 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57208 .49372 L p .829 .744 .77 r
F P
0 g
s
.64278 .46449 m .62966 .45661 L .63487 .43017 L p .561 .551 .801 r
F P
0 g
s
.62966 .45661 m .61662 .45108 L .62105 .42604 L p .626 .598 .802 r
F P
0 g
s
.62105 .42604 m .63487 .43017 L .62966 .45661 L p .626 .598 .802 r
F P
0 g
s
.61662 .45108 m .60364 .4482 L .60733 .42514 L p .691 .645 .799 r
F P
0 g
s
.60733 .42514 m .62105 .42604 L .61662 .45108 L p .691 .645 .799 r
F P
0 g
s
.65598 .47431 m .64278 .46449 L .64884 .4372 L p .501 .51 .798 r
F P
0 g
s
.63487 .43017 m .64884 .4372 L .64278 .46449 L p .561 .551 .801 r
F P
0 g
s
.3032 .44981 m .31662 .45749 L .32605 .48711 L p .266 .498 .893 r
F P
0 g
s
.33851 .49589 m .32605 .48711 L .31662 .45749 L p .146 .396 .844 r
F P
0 g
s
.494 .5846 m .49774 .58063 L .52252 .56908 L p .762 .942 .94 r
F P
0 g
s
.52288 .5618 m .52252 .56908 L .49774 .58063 L p .832 .911 .892 r
F P
0 g
s
.52252 .56908 m .52288 .5618 L .54416 .54444 L p .854 .853 .841 r
F P
0 g
s
.46077 .58733 m .46757 .58797 L .494 .5846 L p .246 .756 .867 r
F P
0 g
s
.49774 .58063 m .494 .5846 L .46757 .58797 L p .575 .913 .972 r
F P
0 g
s
.66928 .48552 m .65598 .47431 L .66296 .44662 L p .451 .478 .796 r
F P
0 g
s
.64884 .4372 m .66296 .44662 L .65598 .47431 L p .501 .51 .798 r
F P
0 g
s
.60364 .4482 m .59068 .44806 L .5937 .4276 L p .75 .687 .791 r
F P
0 g
s
.5937 .4276 m .60733 .42514 L .60364 .4482 L p .75 .687 .791 r
F P
0 g
s
.54106 .53601 m .54416 .54444 L .52288 .5618 L p .869 .833 .809 r
F P
0 g
s
.54416 .54444 m .54106 .53601 L .55769 .51601 L p .854 .786 .784 r
F P
0 g
s
.35099 .50646 m .36355 .51803 L .381 .54166 L p 0 .129 .658 r
F P
0 g
s
.39216 .55186 m .381 .54166 L .36355 .51803 L p 0 .137 .667 r
F P
0 g
s
.56283 .4897 m .57208 .49372 L .55769 .51601 L p .849 .757 .761 r
F P
0 g
s
.57208 .49372 m .56283 .4897 L .57184 .4698 L p .83 .735 .759 r
F P
0 g
s
.57184 .4698 m .58331 .47058 L .57208 .49372 L p .83 .735 .759 r
F P
0 g
s
.42573 .57602 m .43509 .58142 L .46077 .58733 L p .34 0 0 r
F P
0 g
s
.46757 .58797 m .46077 .58733 L .43509 .58142 L p 0 .542 .796 r
F P
0 g
s
.58331 .47058 m .57184 .4698 L .57772 .4506 L p .812 .722 .765 r
F P
0 g
s
.57772 .4506 m .59068 .44806 L .58331 .47058 L p .812 .722 .765 r
F P
0 g
s
.80008 .54842 m .7877 .55082 L .80615 .51541 L p .769 .937 .938 r
F P
0 g
s
.80615 .51541 m .81965 .5099 L .80008 .54842 L p .769 .937 .938 r
F P
0 g
s
.68264 .49747 m .66928 .48552 L .67724 .45778 L p .415 .459 .798 r
F P
0 g
s
.66296 .44662 m .67724 .45778 L .66928 .48552 L p .451 .478 .796 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54106 .53601 L p .866 .785 .769 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56283 .4897 L p .849 .757 .761 r
F P
0 g
s
.59068 .44806 m .57772 .4506 L .58009 .43335 L p .8 .722 .778 r
F P
0 g
s
.58009 .43335 m .5937 .4276 L .59068 .44806 L p .8 .722 .778 r
F P
0 g
s
.39216 .55186 m .40351 .56115 L .42573 .57602 L p .479 0 0 r
F P
0 g
s
.43509 .58142 m .42573 .57602 L .40351 .56115 L p 0 .236 .664 r
F P
0 g
s
.69605 .50948 m .68264 .49747 L .69166 .46988 L p .394 .455 .805 r
F P
0 g
s
.67724 .45778 m .69166 .46988 L .68264 .49747 L p .415 .459 .798 r
F P
0 g
s
.7877 .55082 m .77511 .55137 L .79241 .51863 L p .714 .883 .959 r
F P
0 g
s
.79241 .51863 m .80615 .51541 L .7877 .55082 L p .714 .883 .959 r
F P
0 g
s
.31662 .45749 m .32996 .46735 L .33851 .49589 L p .146 .396 .844 r
F P
0 g
s
.35099 .50646 m .33851 .49589 L .32996 .46735 L p .074 .326 .805 r
F P
0 g
s
.5603 .47074 m .57184 .4698 L .56283 .4897 L p .854 .754 .752 r
F P
0 g
s
.57184 .4698 m .5603 .47074 L .56471 .45559 L p .844 .747 .756 r
F P
0 g
s
.56471 .45559 m .57772 .4506 L .57184 .4698 L p .844 .747 .756 r
F P
0 g
s
.62105 .42604 m .60733 .42514 L .60553 .40559 L p .657 .656 .837 r
F P
0 g
s
.60733 .42514 m .5937 .4276 L .59212 .41056 L p .736 .703 .82 r
F P
0 g
s
.59212 .41056 m .60553 .40559 L .60733 .42514 L p .736 .703 .82 r
F P
0 g
s
.63487 .43017 m .62105 .42604 L .61906 .40436 L p .564 .597 .845 r
F P
0 g
s
.60553 .40559 m .61906 .40436 L .62105 .42604 L p .657 .656 .837 r
F P
0 g
s
.55352 .48654 m .56283 .4897 L .55128 .50901 L p .865 .767 .752 r
F P
0 g
s
.56283 .4897 m .55352 .48654 L .5603 .47074 L p .854 .754 .752 r
F P
0 g
s
.49774 .58063 m .50154 .57385 L .52288 .5618 L p .832 .911 .892 r
F P
0 g
s
.52324 .55241 m .52288 .5618 L .50154 .57385 L p .864 .873 .843 r
F P
0 g
s
.52288 .5618 m .52324 .55241 L .54106 .53601 L p .869 .833 .809 r
F P
0 g
s
.53792 .5265 m .54106 .53601 L .52324 .55241 L p .877 .815 .784 r
F P
0 g
s
.54106 .53601 m .53792 .5265 L .55128 .50901 L p .866 .785 .769 r
F P
0 g
s
.70947 .52089 m .69605 .50948 L .70618 .48211 L p .39 .468 .82 r
F P
0 g
s
.69166 .46988 m .70618 .48211 L .69605 .50948 L p .394 .455 .805 r
F P
0 g
s
.57772 .4506 m .56471 .45559 L .56647 .44208 L p .838 .749 .764 r
F P
0 g
s
.56647 .44208 m .58009 .43335 L .57772 .4506 L p .838 .749 .764 r
F P
0 g
s
.5937 .4276 m .58009 .43335 L .57877 .41918 L p .796 .737 .797 r
F P
0 g
s
.57877 .41918 m .59212 .41056 L .5937 .4276 L p .796 .737 .797 r
F P
0 g
s
.46757 .58797 m .4745 .58557 L .49774 .58063 L p .575 .913 .972 r
F P
0 g
s
.50154 .57385 m .49774 .58063 L .4745 .58557 L p .759 .927 .943 r
F P
0 g
s
.64884 .4372 m .63487 .43017 L .63274 .40673 L p .464 .532 .842 r
F P
0 g
s
.61906 .40436 m .63274 .40673 L .63487 .43017 L p .564 .597 .845 r
F P
0 g
s
.77511 .55137 m .76231 .54974 L .77843 .51915 L p .642 .804 .961 r
F P
0 g
s
.77843 .51915 m .79241 .51863 L .77511 .55137 L p .642 .804 .961 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53792 .5265 L p .876 .784 .756 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55352 .48654 L p .865 .767 .752 r
F P
0 g
s
.72285 .53106 m .70947 .52089 L .72076 .49361 L p .404 .5 .843 r
F P
0 g
s
.70618 .48211 m .72076 .49361 L .70947 .52089 L p .39 .468 .82 r
F P
0 g
s
.43509 .58142 m .44465 .58412 L .46757 .58797 L p 0 .542 .796 r
F P
0 g
s
.4745 .58557 m .46757 .58797 L .44465 .58412 L p .392 .799 .981 r
F P
0 g
s
.36355 .51803 m .37624 .52969 L .39216 .55186 L p 0 .137 .667 r
F P
0 g
s
.40351 .56115 m .39216 .55186 L .37624 .52969 L p 0 .209 .727 r
F P
0 g
s
.76231 .54974 m .74931 .54578 L .76423 .51677 L p .564 .713 .941 r
F P
0 g
s
.76423 .51677 m .77843 .51915 L .76231 .54974 L p .564 .713 .941 r
F P
0 g
s
.58009 .43335 m .56647 .44208 L .56544 .43112 L p .838 .759 .775 r
F P
0 g
s
.56544 .43112 m .57877 .41918 L .58009 .43335 L p .838 .759 .775 r
F P
0 g
s
.66296 .44662 m .64884 .4372 L .64662 .41235 L p .37 .47 .832 r
F P
0 g
s
.63274 .40673 m .64662 .41235 L .64884 .4372 L p .464 .532 .842 r
F P
0 g
s
.73614 .53948 m .72285 .53106 L .73534 .50363 L p .439 .552 .874 r
F P
0 g
s
.72076 .49361 m .73534 .50363 L .72285 .53106 L p .404 .5 .843 r
F P
0 g
s
.74931 .54578 m .73614 .53948 L .74985 .51151 L p .493 .625 .909 r
F P
0 g
s
.74985 .51151 m .76423 .51677 L .74931 .54578 L p .493 .625 .909 r
F P
0 g
s
.73534 .50363 m .74985 .51151 L .73614 .53948 L p .439 .552 .874 r
F P
0 g
s
.54868 .4731 m .5603 .47074 L .55352 .48654 L p .872 .768 .745 r
F P
0 g
s
.5603 .47074 m .54868 .4731 L .55162 .46261 L p .868 .765 .747 r
F P
0 g
s
.55162 .46261 m .56471 .45559 L .5603 .47074 L p .868 .765 .747 r
F P
0 g
s
.56471 .45559 m .55162 .46261 L .55278 .45331 L p .865 .766 .751 r
F P
0 g
s
.55278 .45331 m .56647 .44208 L .56471 .45559 L p .865 .766 .751 r
F P
0 g
s
.54414 .48409 m .55352 .48654 L .54482 .50197 L p .877 .774 .745 r
F P
0 g
s
.55352 .48654 m .54414 .48409 L .54868 .4731 L p .872 .768 .745 r
F P
0 g
s
.52324 .55241 m .52361 .54098 L .53792 .5265 L p .877 .815 .784 r
F P
0 g
s
.53475 .516 m .53792 .5265 L .52361 .54098 L p .883 .801 .764 r
F P
0 g
s
.53792 .5265 m .53475 .516 L .54482 .50197 L p .876 .784 .756 r
F P
0 g
s
.50154 .57385 m .50539 .56411 L .52324 .55241 L p .864 .873 .843 r
F P
0 g
s
.52361 .54098 m .52324 .55241 L .50539 .56411 L p .878 .839 .803 r
F P
0 g
s
.32996 .46735 m .3433 .47882 L .35099 .50646 L p .074 .326 .805 r
F P
0 g
s
.36355 .51803 m .35099 .50646 L .3433 .47882 L p .056 .297 .785 r
F P
0 g
s
.40351 .56115 m .41506 .56854 L .43509 .58142 L p 0 .236 .664 r
F P
0 g
s
.44465 .58412 m .43509 .58142 L .41506 .56854 L p .003 .479 .867 r
F P
0 g
s
.60553 .40559 m .59212 .41056 L .586 .39809 L p .736 .743 .857 r
F P
0 g
s
.59212 .41056 m .57877 .41918 L .57382 .40905 L p .803 .765 .818 r
F P
0 g
s
.57382 .40905 m .586 .39809 L .59212 .41056 L p .803 .765 .818 r
F P
0 g
s
.61906 .40436 m .60553 .40559 L .59826 .39089 L p .636 .7 .892 r
F P
0 g
s
.586 .39809 m .59826 .39089 L .60553 .40559 L p .736 .743 .857 r
F P
0 g
s
.4745 .58557 m .48155 .57971 L .50154 .57385 L p .759 .927 .943 r
F P
0 g
s
.50539 .56411 m .50154 .57385 L .48155 .57971 L p .836 .889 .879 r
F P
0 g
s
.56647 .44208 m .55278 .45331 L .55208 .44583 L p .866 .772 .756 r
F P
0 g
s
.55208 .44583 m .56544 .43112 L .56647 .44208 L p .866 .772 .756 r
F P
0 g
s
.67724 .45778 m .66296 .44662 L .6607 .42065 L p .294 .421 .82 r
F P
0 g
s
.64662 .41235 m .6607 .42065 L .66296 .44662 L p .37 .47 .832 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53475 .516 L p .882 .782 .746 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54414 .48409 L p .877 .774 .745 r
F P
0 g
s
.57877 .41918 m .56544 .43112 L .56168 .42344 L p .844 .775 .785 r
F P
0 g
s
.56168 .42344 m .57382 .40905 L .57877 .41918 L p .844 .775 .785 r
F P
0 g
s
.63274 .40673 m .61906 .40436 L .61067 .38755 L p .498 .63 .91 r
F P
0 g
s
.59826 .39089 m .61067 .38755 L .61906 .40436 L p .636 .7 .892 r
F P
0 g
s
.44465 .58412 m .45438 .58343 L .4745 .58557 L p .392 .799 .981 r
F P
0 g
s
.48155 .57971 m .4745 .58557 L .45438 .58343 L p .671 .881 .976 r
F P
0 g
s
.56544 .43112 m .55208 .44583 L .54954 .44067 L p .869 .78 .76 r
F P
0 g
s
.54954 .44067 m .56168 .42344 L .56544 .43112 L p .869 .78 .76 r
F P
0 g
s
.50539 .56411 m .50929 .55149 L .52361 .54098 L p .878 .839 .803 r
F P
0 g
s
.52398 .5277 m .52361 .54098 L .50929 .55149 L p .884 .814 .774 r
F P
0 g
s
.52361 .54098 m .52398 .5277 L .53475 .516 L p .883 .801 .764 r
F P
0 g
s
.53156 .50468 m .53475 .516 L .52398 .5277 L p .886 .79 .75 r
F P
0 g
s
.53475 .516 m .53156 .50468 L .5383 .49486 L p .882 .782 .746 r
F P
0 g
s
.53695 .4765 m .54868 .4731 L .54414 .48409 L p .884 .777 .739 r
F P
0 g
s
.54868 .4731 m .53695 .4765 L .53843 .47112 L p .882 .776 .74 r
F P
0 g
s
.53843 .47112 m .55162 .46261 L .54868 .4731 L p .882 .776 .74 r
F P
0 g
s
.55162 .46261 m .53843 .47112 L .53901 .46638 L p .882 .777 .741 r
F P
0 g
s
.53901 .46638 m .55278 .45331 L .55162 .46261 L p .882 .777 .741 r
F P
0 g
s
.37624 .52969 m .38911 .54046 L .40351 .56115 L p 0 .209 .727 r
F P
0 g
s
.41506 .56854 m .40351 .56115 L .38911 .54046 L p 0 .337 .818 r
F P
0 g
s
.53467 .48215 m .54414 .48409 L .5383 .49486 L p .885 .779 .739 r
F P
0 g
s
.54414 .48409 m .53467 .48215 L .53695 .4765 L p .884 .777 .739 r
F P
0 g
s
.64662 .41235 m .63274 .40673 L .62325 .38794 L p .335 .535 .901 r
F P
0 g
s
.61067 .38755 m .62325 .38794 L .63274 .40673 L p .498 .63 .91 r
F P
0 g
s
.69166 .46988 m .67724 .45778 L .675 .4309 L p .244 .392 .813 r
F P
0 g
s
.6607 .42065 m .675 .4309 L .67724 .45778 L p .294 .421 .82 r
F P
0 g
s
.48155 .57971 m .4887 .57024 L .50539 .56411 L p .836 .889 .879 r
F P
0 g
s
.50929 .55149 m .50539 .56411 L .4887 .57024 L p .867 .849 .824 r
F P
0 g
s
.55278 .45331 m .53901 .46638 L .53864 .46258 L p .882 .778 .742 r
F P
0 g
s
.53864 .46258 m .55208 .44583 L .55278 .45331 L p .882 .778 .742 r
F P
0 g
s
.3433 .47882 m .35668 .49117 L .36355 .51803 L p .056 .297 .785 r
F P
0 g
s
.37624 .52969 m .36355 .51803 L .35668 .49117 L p .089 .31 .788 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53156 .50468 L p .887 .781 .739 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53467 .48215 L p .885 .779 .739 r
F P
0 g
s
.586 .39809 m .57382 .40905 L .56551 .40369 L p .82 .801 .834 r
F P
0 g
s
.57382 .40905 m .56168 .42344 L .55541 .41958 L p .855 .795 .791 r
F P
0 g
s
.55541 .41958 m .56551 .40369 L .57382 .40905 L p .855 .795 .791 r
F P
0 g
s
.26639 .40708 m .28039 .40898 L .27594 .44241 L p .654 .793 .949 r
F P
0 g
s
.27594 .44241 m .26201 .4429 L .26639 .40708 L p .654 .793 .949 r
F P
0 g
s
.28966 .44472 m .27594 .44241 L .28039 .40898 L p .562 .713 .942 r
F P
0 g
s
.59826 .39089 m .586 .39809 L .57567 .39108 L p .756 .801 .888 r
F P
0 g
s
.56551 .40369 m .57567 .39108 L .586 .39809 L p .82 .801 .834 r
F P
0 g
s
.25216 .40734 m .26639 .40708 L .26201 .4429 L p .73 .851 .938 r
F P
0 g
s
.26201 .4429 m .24784 .44599 L .25216 .40734 L p .73 .851 .938 r
F P
0 g
s
.41506 .56854 m .42682 .57314 L .44465 .58412 L p .003 .479 .867 r
F P
0 g
s
.45438 .58343 m .44465 .58412 L .42682 .57314 L p .367 .696 .983 r
F P
0 g
s
.28039 .40898 m .29417 .41319 L .28966 .44472 L p .562 .713 .942 r
F P
0 g
s
.3032 .44981 m .28966 .44472 L .29417 .41319 L p .469 .623 .918 r
F P
0 g
s
.55208 .44583 m .53864 .46258 L .53736 .45999 L p .883 .781 .743 r
F P
0 g
s
.53736 .45999 m .54954 .44067 L .55208 .44583 L p .883 .781 .743 r
F P
0 g
s
.56168 .42344 m .54954 .44067 L .54533 .43819 L p .874 .788 .762 r
F P
0 g
s
.54533 .43819 m .55541 .41958 L .56168 .42344 L p .874 .788 .762 r
F P
0 g
s
.50929 .55149 m .51322 .53627 L .52398 .5277 L p .884 .814 .774 r
F P
0 g
s
.52436 .51289 m .52398 .5277 L .51322 .53627 L p .887 .796 .754 r
F P
0 g
s
.52398 .5277 m .52436 .51289 L .53156 .50468 L p .886 .79 .75 r
F P
0 g
s
.61067 .38755 m .59826 .39089 L .58592 .38209 L p .642 .778 .946 r
F P
0 g
s
.57567 .39108 m .58592 .38209 L .59826 .39089 L p .756 .801 .888 r
F P
0 g
s
.2377 .40944 m .25216 .40734 L .24784 .44599 L p .784 .887 .919 r
F P
0 g
s
.24784 .44599 m .23343 .45132 L .2377 .40944 L p .784 .887 .919 r
F P
0 g
s
.52835 .49275 m .53156 .50468 L .52436 .51289 L p .888 .784 .74 r
F P
0 g
s
.53156 .50468 m .52835 .49275 L .53174 .48769 L p .887 .781 .739 r
F P
0 g
s
.45438 .58343 m .46427 .57889 L .48155 .57971 L p .671 .881 .976 r
F P
0 g
s
.4887 .57024 m .48155 .57971 L .46427 .57889 L p .794 .868 .903 r
F P
0 g
s
.29417 .41319 m .30778 .41968 L .3032 .44981 L p .469 .623 .918 r
F P
0 g
s
.31662 .45749 m .3032 .44981 L .30778 .41968 L p .389 .538 .884 r
F P
0 g
s
.4887 .57024 m .49592 .55725 L .50929 .55149 L p .867 .849 .824 r
F P
0 g
s
.51322 .53627 m .50929 .55149 L .49592 .55725 L p .879 .819 .785 r
F P
0 g
s
.6607 .42065 m .64662 .41235 L .63604 .39169 L p .178 .434 .866 r
F P
0 g
s
.62325 .38794 m .63604 .39169 L .64662 .41235 L p .335 .535 .901 r
F P
0 g
s
.70618 .48211 m .69166 .46988 L .68949 .44224 L p .223 .387 .816 r
F P
0 g
s
.675 .4309 m .68949 .44224 L .69166 .46988 L p .244 .392 .813 r
F P
0 g
s
.54954 .44067 m .53736 .45999 L .53523 .45879 L p .885 .783 .744 r
F P
0 g
s
.53523 .45879 m .54533 .43819 L .54954 .44067 L p .885 .783 .744 r
F P
0 g
s
.52511 .48046 m .53695 .4765 L .53467 .48215 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53843 .47112 L .53695 .4765 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53901 .46638 L .53843 .47112 L closepath p .889 .781 .735 r
F P
0 g
s
.22303 .41296 m .2377 .40944 L .23343 .45132 L p .82 .905 .899 r
F P
0 g
s
.23343 .45132 m .21881 .45837 L .22303 .41296 L p .82 .905 .899 r
F P
0 g
s
.52511 .48046 m .53467 .48215 L .53174 .48769 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .53864 .46258 L .53901 .46638 L closepath p .889 .781 .735 r
F P
0 g
s
.51322 .53627 m .51717 .51894 L .52436 .51289 L p .887 .796 .754 r
F P
0 g
s
.52474 .49698 m .52436 .51289 L .51717 .51894 L p .888 .785 .742 r
F P
0 g
s
.52436 .51289 m .52474 .49698 L .52835 .49275 L p .888 .784 .74 r
F P
0 g
s
.62325 .38794 m .61067 .38755 L .5963 .37683 L p .452 .706 .976 r
F P
0 g
s
.58592 .38209 m .5963 .37683 L .61067 .38755 L p .642 .778 .946 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49275 L closepath p .889 .781 .735 r
F P
0 g
s
.30778 .41968 m .32125 .4283 L .31662 .45749 L p .389 .538 .884 r
F P
0 g
s
.32996 .46735 m .31662 .45749 L .32125 .4283 L p .335 .472 .85 r
F P
0 g
s
.38911 .54046 m .40217 .54938 L .41506 .56854 L p 0 .337 .818 r
F P
0 g
s
.42682 .57314 m .41506 .56854 L .40217 .54938 L p .218 .492 .899 r
F P
0 g
s
.52511 .48046 m .53736 .45999 L .53864 .46258 L closepath p .889 .781 .735 r
F P
0 g
s
.56551 .40369 m .55541 .41958 L .54703 .41984 L p .868 .81 .791 r
F P
0 g
s
.55541 .41958 m .54533 .43819 L .53972 .43858 L p .88 .795 .762 r
F P
0 g
s
.53972 .43858 m .54703 .41984 L .55541 .41958 L p .88 .795 .762 r
F P
0 g
s
.57567 .39108 m .56551 .40369 L .55438 .40351 L p .843 .831 .835 r
F P
0 g
s
.54703 .41984 m .55438 .40351 L .56551 .40369 L p .868 .81 .791 r
F P
0 g
s
.49592 .55725 m .50319 .5411 L .51322 .53627 L p .879 .819 .785 r
F P
0 g
s
.51717 .51894 m .51322 .53627 L .50319 .5411 L p .885 .798 .759 r
F P
0 g
s
.35668 .49117 m .37016 .50357 L .37624 .52969 L p .089 .31 .788 r
F P
0 g
s
.38911 .54046 m .37624 .52969 L .37016 .50357 L p .167 .357 .808 r
F P
0 g
s
.52511 .48046 m .52835 .49275 L .52474 .49698 L closepath p .889 .781 .735 r
F P
0 g
s
.46427 .57889 m .4743 .57031 L .4887 .57024 L p .794 .868 .903 r
F P
0 g
s
.49592 .55725 m .4887 .57024 L .4743 .57031 L p .846 .838 .838 r
F P
0 g
s
.42682 .57314 m .43879 .57422 L .45438 .58343 L p .367 .696 .983 r
F P
0 g
s
.46427 .57889 m .45438 .58343 L .43879 .57422 L p .623 .793 .964 r
F P
0 g
s
.85906 .48583 m .84605 .4944 L .84655 .44514 L p .884 .922 .844 r
F P
0 g
s
.84655 .44514 m .85986 .43317 L .85906 .48583 L p .884 .922 .844 r
F P
0 g
s
.54533 .43819 m .53523 .45879 L .53242 .45906 L p .886 .785 .744 r
F P
0 g
s
.53242 .45906 m .53972 .43858 L .54533 .43819 L p .886 .785 .744 r
F P
0 g
s
.52511 .48046 m .53523 .45879 L .53736 .45999 L closepath p .889 .781 .735 r
F P
0 g
s
.58592 .38209 m .57567 .39108 L .56177 .3901 L p .793 .854 .896 r
F P
0 g
s
.55438 .40351 m .56177 .3901 L .57567 .39108 L p .843 .831 .835 r
F P
0 g
s
.20817 .41739 m .22303 .41296 L .21881 .45837 L p .839 .911 .885 r
F P
0 g
s
.21881 .45837 m .20402 .46652 L .20817 .41739 L p .839 .911 .885 r
F P
0 g
s
.51717 .51894 m .52114 .5001 L .52474 .49698 L p .888 .785 .742 r
F P
0 g
s
.52511 .48046 m .52474 .49698 L .52114 .5001 L closepath p .889 .781 .735 r
F P
0 g
s
.50319 .5411 m .51049 .52239 L .51717 .51894 L p .885 .798 .759 r
F P
0 g
s
.52114 .5001 m .51717 .51894 L .51049 .52239 L p .888 .786 .743 r
F P
0 g
s
.72076 .49361 m .70618 .48211 L .70413 .45374 L p .234 .408 .831 r
F P
0 g
s
.68949 .44224 m .70413 .45374 L .70618 .48211 L p .223 .387 .816 r
F P
0 g
s
.52511 .48046 m .53242 .45906 L .53523 .45879 L closepath p .889 .781 .735 r
F P
0 g
s
.675 .4309 m .6607 .42065 L .64907 .39822 L p .058 .353 .826 r
F P
0 g
s
.63604 .39169 m .64907 .39822 L .6607 .42065 L p .178 .434 .866 r
F P
0 g
s
.32125 .4283 m .33463 .4387 L .32996 .46735 L p .335 .472 .85 r
F P
0 g
s
.3433 .47882 m .32996 .46735 L .33463 .4387 L p .311 .432 .823 r
F P
0 g
s
.4743 .57031 m .48441 .55782 L .49592 .55725 L p .846 .838 .838 r
F P
0 g
s
.50319 .5411 m .49592 .55725 L .48441 .55782 L p .869 .813 .792 r
F P
0 g
s
.51049 .52239 m .5178 .50188 L .52114 .5001 L p .888 .786 .743 r
F P
0 g
s
.52511 .48046 m .52114 .5001 L .5178 .50188 L closepath p .889 .781 .735 r
F P
0 g
s
.63604 .39169 m .62325 .38794 L .60685 .37517 L p .2 .57 .939 r
F P
0 g
s
.5963 .37683 m .60685 .37517 L .62325 .38794 L p .452 .706 .976 r
F P
0 g
s
.54703 .41984 m .53972 .43858 L .53309 .44183 L p .884 .798 .759 r
F P
0 g
s
.53972 .43858 m .53242 .45906 L .5291 .4608 L p .888 .786 .743 r
F P
0 g
s
.5291 .4608 m .53309 .44183 L .53972 .43858 L p .888 .786 .743 r
F P
0 g
s
.52511 .48046 m .5291 .4608 L .53242 .45906 L closepath p .889 .781 .735 r
F P
0 g
s
.5963 .37683 m .58592 .38209 L .56924 .37993 L p .689 .863 .965 r
F P
0 g
s
.56177 .3901 m .56924 .37993 L .58592 .38209 L p .793 .854 .896 r
F P
0 g
s
.84605 .4944 m .83293 .50267 L .83314 .45675 L p .877 .924 .852 r
F P
0 g
s
.83314 .45675 m .84655 .44514 L .84605 .4944 L p .877 .924 .852 r
F P
0 g
s
.55438 .40351 m .54703 .41984 L .53709 .42425 L p .878 .817 .785 r
F P
0 g
s
.53309 .44183 m .53709 .42425 L .54703 .41984 L p .884 .798 .759 r
F P
0 g
s
.52511 .48046 m .52549 .46388 L .5291 .4608 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .52186 .4681 L .52549 .46388 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52186 .4681 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51547 .47876 L .51844 .47318 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51316 .48447 L .51547 .47876 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51166 .4899 L .51316 .48447 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51109 .49468 L .51166 .4899 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51148 .49849 L .51109 .49468 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .5128 .50105 L .51148 .49849 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .51496 .50221 L .5128 .50105 L closepath p .889 .781 .735 r
F P
0 g
s
.52511 .48046 m .5178 .50188 L .51496 .50221 L closepath p .889 .781 .735 r
F P
0 g
s
.48441 .55782 m .49459 .54182 L .50319 .5411 L p .869 .813 .792 r
F P
0 g
s
.51049 .52239 m .50319 .5411 L .49459 .54182 L p .881 .796 .762 r
F P
0 g
s
.19318 .42214 m .20817 .41739 L .20402 .46652 L p .846 .907 .877 r
F P
0 g
s
.20402 .46652 m .18911 .47507 L .19318 .42214 L p .846 .907 .877 r
F P
0 g
s
.43879 .57422 m .45093 .5713 L .46427 .57889 L p .623 .793 .964 r
F P
0 g
s
.4743 .57031 m .46427 .57889 L .45093 .5713 L p .756 .813 .897 r
F P
0 g
s
.50478 .52299 m .51496 .50221 L .5178 .50188 L p .887 .785 .744 r
F P
0 g
s
.5178 .50188 m .51049 .52239 L .50478 .52299 L p .887 .785 .744 r
F P
0 g
s
.49459 .54182 m .50478 .52299 L .51049 .52239 L p .881 .796 .762 r
F P
0 g
s
.40217 .54938 m .41545 .55559 L .42682 .57314 L p .218 .492 .899 r
F P
0 g
s
.43879 .57422 m .42682 .57314 L .41545 .55559 L p .449 .626 .928 r
F P
0 g
s
.53309 .44183 m .5291 .4608 L .52549 .46388 L p .888 .785 .742 r
F P
0 g
s
.56177 .3901 m .55438 .40351 L .54112 .4086 L p .864 .844 .823 r
F P
0 g
s
.53709 .42425 m .54112 .4086 L .55438 .40351 L p .878 .817 .785 r
F P
0 g
s
.73534 .50363 m .72076 .49361 L .71888 .46445 L p .277 .456 .857 r
F P
0 g
s
.70413 .45374 m .71888 .46445 L .72076 .49361 L p .234 .408 .831 r
F P
0 g
s
.37016 .50357 m .38377 .51516 L .38911 .54046 L p .167 .357 .808 r
F P
0 g
s
.40217 .54938 m .38911 .54046 L .38377 .51516 L p .281 .431 .834 r
F P
0 g
s
.50043 .52069 m .5128 .50105 L .51496 .50221 L p .885 .783 .744 r
F P
0 g
s
.51496 .50221 m .50478 .52299 L .50043 .52069 L p .885 .783 .744 r
F P
0 g
s
.33463 .4387 m .34797 .45039 L .3433 .47882 L p .311 .432 .823 r
F P
0 g
s
.35668 .49117 m .3433 .47882 L .34797 .45039 L p .315 .417 .807 r
F P
0 g
s
.53709 .42425 m .53309 .44183 L .52588 .44775 L p .886 .796 .754 r
F P
0 g
s
.52549 .46388 m .52588 .44775 L .53309 .44183 L p .888 .785 .742 r
F P
0 g
s
.52588 .44775 m .52549 .46388 L .52186 .4681 L p .888 .784 .74 r
F P
0 g
s
.83293 .50267 m .81965 .5099 L .81957 .46717 L p .857 .917 .871 r
F P
0 g
s
.81957 .46717 m .83314 .45675 L .83293 .50267 L p .857 .917 .871 r
F P
0 g
s
.45093 .5713 m .46322 .56421 L .4743 .57031 L p .756 .813 .897 r
F P
0 g
s
.48441 .55782 m .4743 .57031 L .46322 .56421 L p .822 .807 .837 r
F P
0 g
s
.49775 .51561 m .51148 .49849 L .5128 .50105 L p .883 .781 .743 r
F P
0 g
s
.5128 .50105 m .50043 .52069 L .49775 .51561 L p .883 .781 .743 r
F P
0 g
s
.48801 .53833 m .50043 .52069 L .50478 .52299 L p .875 .789 .762 r
F P
0 g
s
.50478 .52299 m .49459 .54182 L .48801 .53833 L p .875 .789 .762 r
F P
0 g
s
.60685 .37517 m .5963 .37683 L .57682 .37309 L p .487 .814 1 r
F P
0 g
s
.56924 .37993 m .57682 .37309 L .5963 .37683 L p .689 .863 .965 r
F P
0 g
s
.56924 .37993 m .56177 .3901 L .54519 .39532 L p .834 .878 .875 r
F P
0 g
s
.54112 .4086 m .54519 .39532 L .56177 .3901 L p .864 .844 .823 r
F P
0 g
s
.52186 .4681 m .51858 .45593 L .52588 .44775 L p .888 .784 .74 r
F P
0 g
s
.51858 .45593 m .52186 .4681 L .51844 .47318 L p .887 .781 .739 r
F P
0 g
s
.68949 .44224 m .675 .4309 L .66232 .40678 L p 0 .307 .8 r
F P
0 g
s
.64907 .39822 m .66232 .40678 L .675 .4309 L p .058 .353 .826 r
F P
0 g
s
.54112 .4086 m .53709 .42425 L .52626 .43255 L p .883 .813 .774 r
F P
0 g
s
.52588 .44775 m .52626 .43255 L .53709 .42425 L p .886 .796 .754 r
F P
0 g
s
.46322 .56421 m .47559 .55307 L .48441 .55782 L p .822 .807 .837 r
F P
0 g
s
.49459 .54182 m .48441 .55782 L .47559 .55307 L p .856 .797 .792 r
F P
0 g
s
.47559 .55307 m .48801 .53833 L .49459 .54182 L p .856 .797 .792 r
F P
0 g
s
.49695 .5081 m .51109 .49468 L .51148 .49849 L p .882 .779 .742 r
F P
0 g
s
.51148 .49849 m .49775 .51561 L .49695 .5081 L p .882 .779 .742 r
F P
0 g
s
.64907 .39822 m .63604 .39169 L .6176 .37675 L p 0 .41 .843 r
F P
0 g
s
.60685 .37517 m .6176 .37675 L .63604 .39169 L p .2 .57 .939 r
F P
0 g
s
.74985 .51151 m .73534 .50363 L .73366 .47351 L p .351 .528 .89 r
F P
0 g
s
.71888 .46445 m .73366 .47351 L .73534 .50363 L p .277 .456 .857 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51858 .45593 L p .887 .781 .739 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51547 .47876 L p .885 .779 .739 r
F P
0 g
s
.41545 .55559 m .42891 .5584 L .43879 .57422 L p .449 .626 .928 r
F P
0 g
s
.45093 .5713 m .43879 .57422 L .42891 .5584 L p .624 .709 .907 r
F P
0 g
s
.52626 .43255 m .52588 .44775 L .51858 .45593 L p .886 .79 .75 r
F P
0 g
s
.49809 .49867 m .51166 .4899 L .51109 .49468 L p .882 .777 .741 r
F P
0 g
s
.51109 .49468 m .49695 .5081 L .49809 .49867 L p .882 .777 .741 r
F P
0 g
s
.51547 .47876 m .50573 .47677 L .5117 .46583 L p .885 .779 .739 r
F P
0 g
s
.50573 .47677 m .51547 .47876 L .51316 .48447 L p .884 .777 .739 r
F P
0 g
s
.81965 .5099 m .80615 .51541 L .80579 .47565 L p .818 .897 .898 r
F P
0 g
s
.80579 .47565 m .81957 .46717 L .81965 .5099 L p .818 .897 .898 r
F P
0 g
s
.50108 .48797 m .51316 .48447 L .51166 .4899 L p .883 .777 .74 r
F P
0 g
s
.51166 .4899 m .49809 .49867 L .50108 .48797 L p .883 .777 .74 r
F P
0 g
s
.51316 .48447 m .50108 .48797 L .50573 .47677 L p .884 .777 .739 r
F P
0 g
s
.48395 .53083 m .49775 .51561 L .50043 .52069 L p .87 .78 .76 r
F P
0 g
s
.50043 .52069 m .48801 .53833 L .48395 .53083 L p .87 .78 .76 r
F P
0 g
s
.34797 .45039 m .36132 .46279 L .35668 .49117 L p .315 .417 .807 r
F P
0 g
s
.37016 .50357 m .35668 .49117 L .36132 .46279 L p .346 .425 .801 r
F P
0 g
s
.38377 .51516 m .39755 .52507 L .40217 .54938 L p .281 .431 .834 r
F P
0 g
s
.41545 .55559 m .40217 .54938 L .39755 .52507 L p .412 .515 .854 r
F P
0 g
s
.54519 .39532 m .54112 .4086 L .52665 .41869 L p .876 .836 .803 r
F P
0 g
s
.52626 .43255 m .52665 .41869 L .54112 .4086 L p .883 .813 .774 r
F P
0 g
s
.76423 .51677 m .74985 .51151 L .74841 .48017 L p .45 .618 .922 r
F P
0 g
s
.73366 .47351 m .74841 .48017 L .74985 .51151 L p .351 .528 .89 r
F P
0 g
s
.57682 .37309 m .56924 .37993 L .54929 .38468 L p .767 .91 .937 r
F P
0 g
s
.54519 .39532 m .54929 .38468 L .56924 .37993 L p .834 .878 .875 r
F P
0 g
s
.51858 .45593 m .51528 .4442 L .52626 .43255 L p .886 .79 .75 r
F P
0 g
s
.51528 .4442 m .51858 .45593 L .5117 .46583 L p .882 .782 .746 r
F P
0 g
s
.80615 .51541 m .79241 .51863 L .79178 .48153 L p .756 .859 .926 r
F P
0 g
s
.79178 .48153 m .80579 .47565 L .80615 .51541 L p .756 .859 .926 r
F P
0 g
s
.42891 .5584 m .44255 .55734 L .45093 .5713 L p .624 .709 .907 r
F P
0 g
s
.46322 .56421 m .45093 .5713 L .44255 .55734 L p .737 .752 .864 r
F P
0 g
s
.52665 .41869 m .52626 .43255 L .51528 .4442 L p .882 .8 .764 r
F P
0 g
s
.47012 .54328 m .48395 .53083 L .48801 .53833 L p .846 .778 .786 r
F P
0 g
s
.48801 .53833 m .47559 .55307 L .47012 .54328 L p .846 .778 .786 r
F P
0 g
s
.48271 .51982 m .49695 .5081 L .49775 .51561 L p .866 .772 .756 r
F P
0 g
s
.49775 .51561 m .48395 .53083 L .48271 .51982 L p .866 .772 .756 r
F P
0 g
s
.77843 .51915 m .76423 .51677 L .76305 .48388 L p .561 .713 .943 r
F P
0 g
s
.74841 .48017 m .76305 .48388 L .76423 .51677 L p .45 .618 .922 r
F P
0 g
s
.6176 .37675 m .60685 .37517 L .58452 .36947 L p .188 .663 .933 r
F P
0 g
s
.57682 .37309 m .58452 .36947 L .60685 .37517 L p .487 .814 1 r
F P
0 g
s
.79241 .51863 m .77843 .51915 L .77752 .48435 L p .668 .797 .943 r
F P
0 g
s
.77752 .48435 m .79178 .48153 L .79241 .51863 L p .668 .797 .943 r
F P
0 g
s
.44255 .55734 m .4563 .55226 L .46322 .56421 L p .737 .752 .864 r
F P
0 g
s
.47559 .55307 m .46322 .56421 L .4563 .55226 L p .805 .77 .821 r
F P
0 g
s
.76305 .48388 m .77752 .48435 L .77843 .51915 L p .561 .713 .943 r
F P
0 g
s
.4563 .55226 m .47012 .54328 L .47559 .55307 L p .805 .77 .821 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51528 .4442 L p .882 .782 .746 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50573 .47677 L p .877 .775 .745 r
F P
0 g
s
.70413 .45374 m .68949 .44224 L .6758 .41648 L p 0 .302 .797 r
F P
0 g
s
.66232 .40678 m .6758 .41648 L .68949 .44224 L p 0 .307 .8 r
F P
0 g
s
.48439 .50605 m .49809 .49867 L .49695 .5081 L p .866 .767 .751 r
F P
0 g
s
.49695 .5081 m .48271 .51982 L .48439 .50605 L p .866 .767 .751 r
F P
0 g
s
.54929 .38468 m .54519 .39532 L .52704 .40649 L p .862 .866 .841 r
F P
0 g
s
.52665 .41869 m .52704 .40649 L .54519 .39532 L p .876 .836 .803 r
F P
0 g
s
.36132 .46279 m .37471 .47519 L .37016 .50357 L p .346 .425 .801 r
F P
0 g
s
.38377 .51516 m .37016 .50357 L .37471 .47519 L p .397 .453 .801 r
F P
0 g
s
.39755 .52507 m .41149 .53254 L .41545 .55559 L p .412 .515 .854 r
F P
0 g
s
.42891 .5584 m .41545 .55559 L .41149 .53254 L p .541 .596 .858 r
F P
0 g
s
.50573 .47677 m .4959 .47422 L .50491 .45842 L p .877 .775 .745 r
F P
0 g
s
.4959 .47422 m .50573 .47677 L .50108 .48797 L p .872 .769 .745 r
F P
0 g
s
.66232 .40678 m .64907 .39822 L .62856 .38101 L p 0 .286 .75 r
F P
0 g
s
.6176 .37675 m .62856 .38101 L .64907 .39822 L p 0 .41 .843 r
F P
0 g
s
.4889 .49048 m .50108 .48797 L .49809 .49867 L p .868 .766 .747 r
F P
0 g
s
.49809 .49867 m .48439 .50605 L .4889 .49048 L p .868 .766 .747 r
F P
0 g
s
.50108 .48797 m .4889 .49048 L .4959 .47422 L p .872 .769 .745 r
F P
0 g
s
.51528 .4442 m .51195 .43313 L .52665 .41869 L p .882 .8 .764 r
F P
0 g
s
.51195 .43313 m .51528 .4442 L .50491 .45842 L p .876 .784 .756 r
F P
0 g
s
.52704 .40649 m .52665 .41869 L .51195 .43313 L p .876 .814 .784 r
F P
0 g
s
.46841 .52906 m .48271 .51982 L .48395 .53083 L p .84 .761 .775 r
F P
0 g
s
.48395 .53083 m .47012 .54328 L .46841 .52906 L p .84 .761 .775 r
F P
0 g
s
.58452 .36947 m .57682 .37309 L .55346 .37674 L p .628 .909 .983 r
F P
0 g
s
.54929 .38468 m .55346 .37674 L .57682 .37309 L p .767 .91 .937 r
F P
0 g
s
.41149 .53254 m .42558 .53694 L .42891 .5584 L p .541 .596 .858 r
F P
0 g
s
.44255 .55734 m .42891 .5584 L .42558 .53694 L p .652 .662 .847 r
F P
0 g
s
.45408 .53521 m .46841 .52906 L .47012 .54328 L p .798 .741 .8 r
F P
0 g
s
.47012 .54328 m .4563 .55226 L .45408 .53521 L p .798 .741 .8 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51195 .43313 L p .876 .784 .756 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .4959 .47422 L p .865 .767 .752 r
F P
0 g
s
.37471 .47519 m .38818 .4869 L .38377 .51516 L p .397 .453 .801 r
F P
0 g
s
.39755 .52507 m .38377 .51516 L .38818 .4869 L p .464 .495 .806 r
F P
0 g
s
.47062 .5114 m .48439 .50605 L .48271 .51982 L p .84 .75 .765 r
F P
0 g
s
.48271 .51982 m .46841 .52906 L .47062 .5114 L p .84 .75 .765 r
F P
0 g
s
.55346 .37674 m .54929 .38468 L .52743 .39613 L p .831 .899 .888 r
F P
0 g
s
.52704 .40649 m .52743 .39613 L .54929 .38468 L p .862 .866 .841 r
F P
0 g
s
.42558 .53694 m .43979 .53788 L .44255 .55734 L p .652 .662 .847 r
F P
0 g
s
.4563 .55226 m .44255 .55734 L .43979 .53788 L p .737 .709 .825 r
F P
0 g
s
.43979 .53788 m .45408 .53521 L .4563 .55226 L p .737 .709 .825 r
F P
0 g
s
.58452 .36947 m .59237 .36876 L .6176 .37675 L p .188 .663 .933 r
F P
0 g
s
.62856 .38101 m .6176 .37675 L .59237 .36876 L p 0 .463 .785 r
F P
0 g
s
.71888 .46445 m .70413 .45374 L .68945 .42634 L p .022 .34 .82 r
F P
0 g
s
.6758 .41648 m .68945 .42634 L .70413 .45374 L p 0 .302 .797 r
F P
0 g
s
.52743 .39613 m .52704 .40649 L .50859 .42289 L p .867 .83 .809 r
F P
0 g
s
.51195 .43313 m .50859 .42289 L .52704 .40649 L p .876 .814 .784 r
F P
0 g
s
.50859 .42289 m .51195 .43313 L .49806 .45095 L p .866 .785 .769 r
F P
0 g
s
.4959 .47422 m .486 .47089 L .49806 .45095 L p .865 .767 .752 r
F P
0 g
s
.486 .47089 m .4959 .47422 L .4889 .49048 L p .854 .755 .752 r
F P
0 g
s
.47662 .49154 m .4889 .49048 L .48439 .50605 L p .845 .748 .757 r
F P
0 g
s
.48439 .50605 m .47062 .5114 L .47662 .49154 L p .845 .748 .757 r
F P
0 g
s
.4889 .49048 m .47662 .49154 L .486 .47089 L p .854 .755 .752 r
F P
0 g
s
.31522 .38497 m .3279 .39257 L .30778 .41968 L p .516 .642 .911 r
F P
0 g
s
.30778 .41968 m .29417 .41319 L .31522 .38497 L p .516 .642 .911 r
F P
0 g
s
.32125 .4283 m .30778 .41968 L .3279 .39257 L p .481 .581 .878 r
F P
0 g
s
.30239 .379 m .31522 .38497 L .29417 .41319 L p .566 .714 .941 r
F P
0 g
s
.29417 .41319 m .28039 .40898 L .30239 .379 L p .566 .714 .941 r
F P
0 g
s
.3279 .39257 m .34044 .40165 L .32125 .4283 L p .481 .581 .878 r
F P
0 g
s
.33463 .4387 m .32125 .4283 L .34044 .40165 L p .462 .537 .848 r
F P
0 g
s
.38818 .4869 m .40174 .49721 L .39755 .52507 L p .464 .495 .806 r
F P
0 g
s
.41149 .53254 m .39755 .52507 L .40174 .49721 L p .54 .546 .809 r
F P
0 g
s
.45679 .51423 m .47062 .5114 L .46841 .52906 L p .802 .725 .78 r
F P
0 g
s
.46841 .52906 m .45408 .53521 L .45679 .51423 L p .802 .725 .78 r
F P
0 g
s
.28938 .37466 m .30239 .379 L .28039 .40898 L p .621 .787 .961 r
F P
0 g
s
.28039 .40898 m .26639 .40708 L .28938 .37466 L p .621 .787 .961 r
F P
0 g
s
.6758 .41648 m .66232 .40678 L .63973 .38723 L p 0 .224 .7 r
F P
0 g
s
.62856 .38101 m .63973 .38723 L .66232 .40678 L p 0 .286 .75 r
F P
0 g
s
.59237 .36876 m .58452 .36947 L .55769 .37143 L p .394 .826 .958 r
F P
0 g
s
.55346 .37674 m .55769 .37143 L .58452 .36947 L p .628 .909 .983 r
F P
0 g
s
.34044 .40165 m .35289 .41198 L .33463 .4387 L p .462 .537 .848 r
F P
0 g
s
.34797 .45039 m .33463 .4387 L .35289 .41198 L p .46 .511 .824 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50859 .42289 L p .866 .785 .769 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .486 .47089 L p .85 .758 .761 r
F P
0 g
s
.27618 .37184 m .28938 .37466 L .26639 .40708 L p .675 .849 .966 r
F P
0 g
s
.26639 .40708 m .25216 .40734 L .27618 .37184 L p .675 .849 .966 r
F P
0 g
s
.40174 .49721 m .4154 .5055 L .41149 .53254 L p .54 .546 .809 r
F P
0 g
s
.42558 .53694 m .41149 .53254 L .4154 .5055 L p .617 .599 .81 r
F P
0 g
s
.55769 .37143 m .55346 .37674 L .52783 .38768 L p .771 .926 .937 r
F P
0 g
s
.52743 .39613 m .52783 .38768 L .55346 .37674 L p .831 .899 .888 r
F P
0 g
s
.44296 .51422 m .45679 .51423 L .45408 .53521 L p .752 .691 .794 r
F P
0 g
s
.45408 .53521 m .43979 .53788 L .44296 .51422 L p .752 .691 .794 r
F P
0 g
s
.46428 .4908 m .47662 .49154 L .47062 .5114 L p .814 .725 .766 r
F P
0 g
s
.47062 .5114 m .45679 .51423 L .46428 .4908 L p .814 .725 .766 r
F P
0 g
s
.35289 .41198 m .36527 .4232 L .34797 .45039 L p .46 .511 .824 r
F P
0 g
s
.36132 .46279 m .34797 .45039 L .36527 .4232 L p .473 .502 .807 r
F P
0 g
s
.50859 .42289 m .50519 .41357 L .52743 .39613 L p .867 .83 .809 r
F P
0 g
s
.50519 .41357 m .50859 .42289 L .49116 .44341 L p .854 .786 .784 r
F P
0 g
s
.52783 .38768 m .52743 .39613 L .50519 .41357 L p .852 .848 .839 r
F P
0 g
s
.486 .47089 m .47602 .46661 L .49116 .44341 L p .85 .758 .761 r
F P
0 g
s
.47602 .46661 m .486 .47089 L .47662 .49154 L p .831 .736 .76 r
F P
0 g
s
.4154 .5055 m .42915 .51128 L .42558 .53694 L p .617 .599 .81 r
F P
0 g
s
.43979 .53788 m .42558 .53694 L .42915 .51128 L p .689 .648 .804 r
F P
0 g
s
.42915 .51128 m .44296 .51422 L .43979 .53788 L p .689 .648 .804 r
F P
0 g
s
.47662 .49154 m .46428 .4908 L .47602 .46661 L p .831 .736 .76 r
F P
0 g
s
.73366 .47351 m .71888 .46445 L .70324 .4354 L p .116 .414 .862 r
F P
0 g
s
.68945 .42634 m .70324 .4354 L .71888 .46445 L p .022 .34 .82 r
F P
0 g
s
.26277 .37033 m .27618 .37184 L .25216 .40734 L p .72 .894 .959 r
F P
0 g
s
.25216 .40734 m .2377 .40944 L .26277 .37033 L p .72 .894 .959 r
F P
0 g
s
.36527 .4232 m .37761 .43487 L .36132 .46279 L p .473 .502 .807 r
F P
0 g
s
.37471 .47519 m .36132 .46279 L .37761 .43487 L p .499 .507 .796 r
F P
0 g
s
.59237 .36876 m .60037 .37044 L .62856 .38101 L p 0 .463 .785 r
F P
0 g
s
.63973 .38723 m .62856 .38101 L .60037 .37044 L p 0 .311 .658 r
F P
0 g
s
.45189 .48805 m .46428 .4908 L .45679 .51423 L p .775 .694 .775 r
F P
0 g
s
.45679 .51423 m .44296 .51422 L .45189 .48805 L p .775 .694 .775 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50519 .41357 L p .854 .786 .784 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47602 .46661 L p .83 .745 .77 r
F P
0 g
s
.37761 .43487 m .38995 .44652 L .37471 .47519 L p .499 .507 .796 r
F P
0 g
s
.38818 .4869 m .37471 .47519 L .38995 .44652 L p .535 .525 .791 r
F P
0 g
s
.24919 .36982 m .26277 .37033 L .2377 .40944 L p .754 .921 .946 r
F P
0 g
s
.2377 .40944 m .22303 .41296 L .24919 .36982 L p .754 .921 .946 r
F P
0 g
s
.46598 .46126 m .47602 .46661 L .46428 .4908 L p .802 .714 .767 r
F P
0 g
s
.46428 .4908 m .45189 .48805 L .46598 .46126 L p .802 .714 .767 r
F P
0 g
s
.55769 .37143 m .562 .36848 L .59237 .36876 L p .394 .826 .958 r
F P
0 g
s
.60037 .37044 m .59237 .36876 L .562 .36848 L p .129 .666 .85 r
F P
0 g
s
.47602 .46661 m .46598 .46126 L .48419 .43581 L p .83 .745 .77 r
F P
0 g
s
.68945 .42634 m .6758 .41648 L .6511 .39454 L p 0 .225 .704 r
F P
0 g
s
.63973 .38723 m .6511 .39454 L .6758 .41648 L p 0 .224 .7 r
F P
0 g
s
.50519 .41357 m .50176 .40522 L .52783 .38768 L p .852 .848 .839 r
F P
0 g
s
.50176 .40522 m .50519 .41357 L .48419 .43581 L p .838 .787 .802 r
F P
0 g
s
.43948 .48322 m .45189 .48805 L .44296 .51422 L p .729 .66 .781 r
F P
0 g
s
.44296 .51422 m .42915 .51128 L .43948 .48322 L p .729 .66 .781 r
F P
0 g
s
.38995 .44652 m .4023 .45764 L .38818 .4869 L p .535 .525 .791 r
F P
0 g
s
.40174 .49721 m .38818 .4869 L .4023 .45764 L p .579 .552 .788 r
F P
0 g
s
.562 .36848 m .55769 .37143 L .52824 .38107 L p .669 .928 .972 r
F P
0 g
s
.52783 .38768 m .52824 .38107 L .55769 .37143 L p .771 .926 .937 r
F P
0 g
s
.52824 .38107 m .52783 .38768 L .50176 .40522 L p .827 .866 .874 r
F P
0 g
s
.74841 .48017 m .73366 .47351 L .7171 .44272 L p .252 .515 .908 r
F P
0 g
s
.70324 .4354 m .7171 .44272 L .73366 .47351 L p .116 .414 .862 r
F P
0 g
s
.4023 .45764 m .41467 .46773 L .40174 .49721 L p .579 .552 .788 r
F P
0 g
s
.4154 .5055 m .40174 .49721 L .41467 .46773 L p .629 .586 .787 r
F P
0 g
s
.42707 .47637 m .43948 .48322 L .42915 .51128 L p .68 .623 .785 r
F P
0 g
s
.42915 .51128 m .4154 .5055 L .42707 .47637 L p .68 .623 .785 r
F P
0 g
s
.41467 .46773 m .42707 .47637 L .4154 .5055 L p .629 .586 .787 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50176 .40522 L p .838 .787 .802 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46598 .46126 L p .807 .732 .781 r
F P
0 g
s
.45588 .45481 m .46598 .46126 L .45189 .48805 L p .769 .689 .774 r
F P
0 g
s
.45189 .48805 m .43948 .48322 L .45588 .45481 L p .769 .689 .774 r
F P
0 g
s
.23543 .36994 m .24919 .36982 L .22303 .41296 L p .777 .932 .934 r
F P
0 g
s
.22303 .41296 m .20817 .41739 L .23543 .36994 L p .777 .932 .934 r
F P
0 g
s
.46598 .46126 m .45588 .45481 L .47717 .42815 L p .807 .732 .781 r
F P
0 g
s
.85986 .43317 m .84655 .44514 L .8239 .39554 L p .875 .847 .813 r
F P
0 g
s
.8239 .39554 m .8366 .38074 L .85986 .43317 L p .875 .847 .813 r
F P
0 g
s
.76305 .48388 m .74841 .48017 L .73096 .44755 L p .41 .622 .939 r
F P
0 g
s
.7171 .44272 m .73096 .44755 L .74841 .48017 L p .252 .515 .908 r
F P
0 g
s
.50176 .40522 m .49829 .39778 L .52824 .38107 L p .827 .866 .874 r
F P
0 g
s
.49829 .39778 m .50176 .40522 L .47717 .42815 L p .818 .786 .822 r
F P
0 g
s
.60037 .37044 m .60854 .37385 L .63973 .38723 L p 0 .311 .658 r
F P
0 g
s
.6511 .39454 m .63973 .38723 L .60854 .37385 L p .343 0 0 r
F P
0 g
s
.44574 .44729 m .45588 .45481 L .43948 .48322 L p .734 .662 .779 r
F P
0 g
s
.43948 .48322 m .42707 .47637 L .44574 .44729 L p .734 .662 .779 r
F P
0 g
s
.84655 .44514 m .83314 .45675 L .81113 .40995 L p .87 .847 .819 r
F P
0 g
s
.81113 .40995 m .8239 .39554 L .84655 .44514 L p .87 .847 .819 r
F P
0 g
s
.52824 .38107 m .52865 .3761 L .562 .36848 L p .669 .928 .972 r
F P
0 g
s
.52865 .3761 m .52824 .38107 L .49829 .39778 L p .791 .88 .911 r
F P
0 g
s
.22154 .37026 m .23543 .36994 L .20817 .41739 L p .79 .93 .926 r
F P
0 g
s
.20817 .41739 m .19318 .42214 L .22154 .37026 L p .79 .93 .926 r
F P
0 g
s
.70324 .4354 m .68945 .42634 L .66266 .40199 L p 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .68945 .42634 L p .65394 .39689 L 0 .225 .704 r
F P
0 g
s
.67435 .40865 m .70324 .4354 L p .6689 .40713 L 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .67435 .40865 L p .6689 .40713 L 0 .284 .757 r
F P
0 g
s
.66266 .40199 m .62532 .38269 L p .67097 .40686 L 0 .308 .703 r
F P
0 g
s
.67435 .40865 m .66266 .40199 L p .67097 .40686 L 0 .308 .703 r
F P
0 g
s
.6511 .39454 m .66266 .40199 L p .65394 .39689 L 0 .225 .704 r
F P
0 g
s
.66266 .40199 m .6511 .39454 L .61686 .37822 L p .334 0 0 r
F P
0 g
s
.62532 .38269 m .66266 .40199 L p .62024 .37997 L .334 0 0 r
F P
0 g
s
.61686 .37822 m .62532 .38269 L p .62024 .37997 L .334 0 0 r
F P
0 g
s
.562 .36848 m .5664 .36747 L .60037 .37044 L p .129 .666 .85 r
F P
0 g
s
.62532 .38269 m .61686 .37822 L .57543 .36896 L p 0 .414 .694 r
F P
0 g
s
.58006 .37013 m .62532 .38269 L p .5791 .36997 L 0 .414 .694 r
F P
0 g
s
.57543 .36896 m .58006 .37013 L p .5791 .36997 L 0 .414 .694 r
F P
0 g
s
.62532 .38269 m .58006 .37013 L p .63016 .38529 L 0 .465 .774 r
F P
0 g
s
.5664 .36747 m .562 .36848 L .52865 .3761 L p .524 .889 .975 r
F P
0 g
s
.52865 .3761 m .52907 .37249 L .5664 .36747 L p .524 .889 .975 r
F P
0 g
s
.60854 .37385 m .60037 .37044 L .5664 .36747 L p 0 .514 .736 r
F P
0 g
s
.5664 .36747 m .57087 .36784 L .60854 .37385 L p 0 .514 .736 r
F P
0 g
s
.57087 .36784 m .5664 .36747 L .52907 .37249 L p .374 .818 .948 r
F P
0 g
s
.52907 .37249 m .5295 .36982 L .57087 .36784 L p .374 .818 .948 r
F P
0 g
s
.57543 .36896 m .57087 .36784 L .5295 .36982 L p .263 .749 .922 r
F P
0 g
s
.5295 .36982 m .52993 .36764 L .57543 .36896 L p .263 .749 .922 r
F P
0 g
s
.58006 .37013 m .57543 .36896 L .52993 .36764 L p .217 .71 .92 r
F P
0 g
s
.52993 .36764 m .53037 .36544 L .58006 .37013 L p .217 .71 .92 r
F P
0 g
s
.63389 .38641 m .67435 .40865 L p .63283 .38667 L 0 .308 .703 r
F P
0 g
s
.62532 .38269 m .63389 .38641 L p .63283 .38667 L 0 .308 .703 r
F P
0 g
s
.63389 .38641 m .62532 .38269 L p .63008 .38524 L 0 .465 .774 r
F P
0 g
s
.63016 .38529 m .63389 .38641 L .63008 .38524 L 0 .465 .774 r
F
.60854 .37385 m .61686 .37822 L .6511 .39454 L p .343 0 0 r
F P
0 g
s
.61686 .37822 m .60854 .37385 L .57087 .36784 L p .166 0 0 r
F P
0 g
s
.57087 .36784 m .57543 .36896 L .61686 .37822 L p .166 0 0 r
F P
0 g
s
.63389 .38641 m .58475 .37063 L p .63482 .38618 L .057 .56 .884 r
F P
0 g
s
.64253 .38858 m .63389 .38641 L p .63482 .38618 L .057 .56 .884 r
F P
0 g
s
.58006 .37013 m .58475 .37063 L .63389 .38641 L p 0 .465 .774 r
F P
0 g
s
.58006 .37013 m .53037 .36544 L p .58098 .37027 L .237 .704 .945 r
F P
0 g
s
.58475 .37063 m .58006 .37013 L p .58098 .37027 L .237 .704 .945 r
F P
0 g
s
.67435 .40865 m .63389 .38641 L p .67918 .41 L 0 .432 .827 r
F P
0 g
s
.68612 .41361 m .67435 .40865 L p .67918 .41 L 0 .432 .827 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49829 .39778 L p .818 .786 .822 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45588 .45481 L p .781 .716 .791 r
F P
0 g
s
.43556 .43881 m .44574 .44729 L .42707 .47637 L p .697 .636 .784 r
F P
0 g
s
.42707 .47637 m .41467 .46773 L .43556 .43881 L p .697 .636 .784 r
F P
0 g
s
.45588 .45481 m .44574 .44729 L .47008 .42042 L p .781 .716 .791 r
F P
0 g
s
.77752 .48435 m .76305 .48388 L .74475 .44929 L p .559 .714 .944 r
F P
0 g
s
.73096 .44755 m .74475 .44929 L .76305 .48388 L p .41 .622 .939 r
F P
0 g
s
.83314 .45675 m .81957 .46717 L .79824 .42309 L p .853 .844 .835 r
F P
0 g
s
.79824 .42309 m .81113 .40995 L .83314 .45675 L p .853 .844 .835 r
F P
0 g
s
.42534 .42954 m .43556 .43881 L .41467 .46773 L p .661 .613 .79 r
F P
0 g
s
.41467 .46773 m .4023 .45764 L .42534 .42954 L p .661 .613 .79 r
F P
0 g
s
.41509 .4197 m .42534 .42954 L .4023 .45764 L p .628 .594 .797 r
F P
0 g
s
.4023 .45764 m .38995 .44652 L .41509 .4197 L p .628 .594 .797 r
F P
0 g
s
.81957 .46717 m .80579 .47565 L .78516 .43417 L p .82 .835 .861 r
F P
0 g
s
.78516 .43417 m .79824 .42309 L .81957 .46717 L p .82 .835 .861 r
F P
0 g
s
.79178 .48153 m .77752 .48435 L .7584 .44763 L p .68 .778 .925 r
F P
0 g
s
.74475 .44929 m .7584 .44763 L .77752 .48435 L p .559 .714 .944 r
F P
0 g
s
.4048 .40954 m .41509 .4197 L .38995 .44652 L p .598 .581 .806 r
F P
0 g
s
.38995 .44652 m .37761 .43487 L .4048 .40954 L p .598 .581 .806 r
F P
0 g
s
.49829 .39778 m .49477 .39118 L .52865 .3761 L p .791 .88 .911 r
F P
0 g
s
.49477 .39118 m .49829 .39778 L .47008 .42042 L p .794 .784 .844 r
F P
0 g
s
.39445 .39932 m .4048 .40954 L .37761 .43487 L p .573 .577 .818 r
F P
0 g
s
.37761 .43487 m .36527 .4232 L .39445 .39932 L p .573 .577 .818 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44574 .44729 L p .753 .701 .802 r
F P
0 g
s
.44574 .44729 m .43556 .43881 L .46294 .41262 L p .753 .701 .802 r
F P
0 g
s
.80579 .47565 m .79178 .48153 L .77189 .44251 L p .765 .815 .893 r
F P
0 g
s
.77189 .44251 m .78516 .43417 L .80579 .47565 L p .765 .815 .893 r
F P
0 g
s
.38405 .38929 m .39445 .39932 L .36527 .4232 L p .555 .582 .836 r
F P
0 g
s
.36527 .4232 m .35289 .41198 L .38405 .38929 L p .555 .582 .836 r
F P
0 g
s
.7584 .44763 m .77189 .44251 L .79178 .48153 L p .68 .778 .925 r
F P
0 g
s
.37357 .37969 m .38405 .38929 L .35289 .41198 L p .545 .598 .858 r
F P
0 g
s
.35289 .41198 m .34044 .40165 L .37357 .37969 L p .545 .598 .858 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49477 .39118 L p .794 .784 .844 r
F P
0 g
s
.363 .37069 m .37357 .37969 L .34044 .40165 L p .544 .626 .884 r
F P
0 g
s
.34044 .40165 m .3279 .39257 L .363 .37069 L p .544 .626 .884 r
F P
0 g
s
.52907 .37249 m .52865 .3761 L .49477 .39118 L p .741 .884 .945 r
F P
0 g
s
.35232 .36244 m .363 .37069 L .3279 .39257 L p .552 .667 .913 r
F P
0 g
s
.3279 .39257 m .31522 .38497 L .35232 .36244 L p .552 .667 .913 r
F P
0 g
s
.7171 .44272 m .70324 .4354 L .67435 .40865 L p 0 .393 .841 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43556 .43881 L p .724 .686 .813 r
F P
0 g
s
.43556 .43881 m .42534 .42954 L .45573 .40475 L p .724 .686 .813 r
F P
0 g
s
.34153 .35499 m .35232 .36244 L .31522 .38497 L p .568 .716 .941 r
F P
0 g
s
.31522 .38497 m .30239 .379 L .34153 .35499 L p .568 .716 .941 r
F P
0 g
s
.49477 .39118 m .49121 .38523 L .52907 .37249 L p .741 .884 .945 r
F P
0 g
s
.49121 .38523 m .49477 .39118 L .46294 .41262 L p .764 .78 .865 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49121 .38523 L p .764 .78 .865 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42534 .42954 L p .694 .673 .825 r
F P
0 g
s
.42534 .42954 m .41509 .4197 L .44846 .39682 L p .694 .673 .825 r
F P
0 g
s
.33061 .34837 m .34153 .35499 L .30239 .379 L p .591 .768 .964 r
F P
0 g
s
.30239 .379 m .28938 .37466 L .33061 .34837 L p .591 .768 .964 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41509 .4197 L p .665 .664 .838 r
F P
0 g
s
.41509 .4197 m .4048 .40954 L .44112 .38881 L p .665 .664 .838 r
F P
0 g
s
.73096 .44755 m .7171 .44272 L .68612 .41361 L p .174 .525 .92 r
F P
0 g
s
.67435 .40865 m .68612 .41361 L .7171 .44272 L p 0 .393 .841 r
F P
0 g
s
.5295 .36982 m .52907 .37249 L .49121 .38523 L p .681 .876 .972 r
F P
0 g
s
.31955 .3425 m .33061 .34837 L .28938 .37466 L p .618 .818 .977 r
F P
0 g
s
.28938 .37466 m .27618 .37184 L .31955 .3425 L p .618 .818 .977 r
F P
0 g
s
.4876 .37973 m .49121 .38523 L .45573 .40475 L p .731 .773 .886 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .4876 .37973 L p .731 .773 .886 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .4048 .40954 L p .638 .658 .853 r
F P
0 g
s
.4048 .40954 m .39445 .39932 L .43372 .38074 L p .638 .658 .853 r
F P
0 g
s
.49121 .38523 m .4876 .37973 L .5295 .36982 L p .681 .876 .972 r
F P
0 g
s
.30835 .33729 m .31955 .3425 L .27618 .37184 L p .646 .857 .98 r
F P
0 g
s
.27618 .37184 m .26277 .37033 L .30835 .33729 L p .646 .857 .98 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39445 .39932 L p .614 .658 .869 r
F P
0 g
s
.39445 .39932 m .38405 .38929 L .42626 .3726 L p .614 .658 .869 r
F P
0 g
s
.74475 .44929 m .73096 .44755 L .69792 .41612 L p .387 .641 .956 r
F P
0 g
s
.68612 .41361 m .69792 .41612 L .73096 .44755 L p .174 .525 .92 r
F P
0 g
s
.48394 .37444 m .4876 .37973 L .44846 .39682 L p .696 .764 .904 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48394 .37444 L p .696 .764 .904 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38405 .38929 L p .594 .663 .887 r
F P
0 g
s
.38405 .38929 m .37357 .37969 L .41873 .36438 L p .594 .663 .887 r
F P
0 g
s
.52993 .36764 m .5295 .36982 L .4876 .37973 L p .618 .856 .988 r
F P
0 g
s
.29702 .33256 m .30835 .33729 L .26277 .37033 L p .672 .885 .976 r
F P
0 g
s
.26277 .37033 m .24919 .36982 L .29702 .33256 L p .672 .885 .976 r
F P
0 g
s
.4876 .37973 m .48394 .37444 L .52993 .36764 L p .618 .856 .988 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37357 .37969 L p .58 .676 .906 r
F P
0 g
s
.37357 .37969 m .363 .37069 L .41113 .35609 L p .58 .676 .906 r
F P
0 g
s
.7584 .44763 m .74475 .44929 L .7097 .41562 L p .559 .716 .946 r
F P
0 g
s
.69792 .41612 m .7097 .41562 L .74475 .44929 L p .387 .641 .956 r
F P
0 g
s
.48024 .36909 m .48394 .37444 L .44112 .38881 L p .66 .753 .919 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48024 .36909 L p .66 .753 .919 r
F P
0 g
s
.28557 .32812 m .29702 .33256 L .24919 .36982 L p .695 .899 .97 r
F P
0 g
s
.24919 .36982 m .23543 .36994 L .28557 .32812 L p .695 .899 .97 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .363 .37069 L p .571 .694 .925 r
F P
0 g
s
.363 .37069 m .35232 .36244 L .40346 .34772 L p .571 .694 .925 r
F P
0 g
s
.77189 .44251 m .7584 .44763 L .72139 .41178 L p .676 .754 .909 r
F P
0 g
s
.7097 .41562 m .72139 .41178 L .7584 .44763 L p .559 .716 .946 r
F P
0 g
s
.53037 .36544 m .52993 .36764 L .48394 .37444 L p .566 .828 .995 r
F P
0 g
s
.48394 .37444 m .48024 .36909 L .53037 .36544 L p .566 .828 .995 r
F P
0 g
s
.4765 .36344 m .48024 .36909 L .43372 .38074 L p .626 .741 .93 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .4765 .36344 L p .626 .741 .93 r
F P
0 g
s
.8366 .38074 m .8239 .39554 L .77795 .34956 L p .84 .779 .793 r
F P
0 g
s
.77795 .34956 m .78901 .33274 L .8366 .38074 L p .84 .779 .793 r
F P
0 g
s
.78516 .43417 m .77189 .44251 L .73297 .40456 L p .75 .77 .869 r
F P
0 g
s
.72139 .41178 m .73297 .40456 L .77189 .44251 L p .676 .754 .909 r
F P
0 g
s
.8239 .39554 m .81113 .40995 L .76686 .36595 L p .835 .778 .797 r
F P
0 g
s
.76686 .36595 m .77795 .34956 L .8239 .39554 L p .835 .778 .797 r
F P
0 g
s
.27399 .32374 m .28557 .32812 L .23543 .36994 L p .714 .901 .963 r
F P
0 g
s
.23543 .36994 m .22154 .37026 L .27399 .32374 L p .714 .901 .963 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35232 .36244 L p .57 .718 .942 r
F P
0 g
s
.35232 .36244 m .34153 .35499 L .39573 .33928 L p .57 .718 .942 r
F P
0 g
s
.69792 .41612 m .68612 .41361 L .64253 .38858 L p .167 .571 .934 r
F P
0 g
s
.63389 .38641 m .64253 .38858 L .68612 .41361 L p 0 .432 .827 r
F P
0 g
s
.81113 .40995 m .79824 .42309 L .7557 .38109 L p .821 .777 .811 r
F P
0 g
s
.7557 .38109 m .76686 .36595 L .81113 .40995 L p .821 .777 .811 r
F P
0 g
s
.79824 .42309 m .78516 .43417 L .7444 .39417 L p .795 .775 .835 r
F P
0 g
s
.73297 .40456 m .7444 .39417 L .78516 .43417 L p .75 .77 .869 r
F P
0 g
s
.7444 .39417 m .7557 .38109 L .79824 .42309 L p .795 .775 .835 r
F P
0 g
s
.47271 .35723 m .4765 .36344 L .42626 .3726 L p .599 .731 .937 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47271 .35723 L p .599 .731 .937 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34153 .35499 L p .575 .744 .957 r
F P
0 g
s
.34153 .35499 m .33061 .34837 L .38792 .33076 L p .575 .744 .957 r
F P
0 g
s
.53081 .36274 m .53037 .36544 L .48024 .36909 L p .532 .799 .995 r
F P
0 g
s
.48024 .36909 m .4765 .36344 L .53081 .36274 L p .532 .799 .995 r
F P
0 g
s
.53037 .36544 m .53081 .36274 L .58475 .37063 L p .237 .704 .945 r
F P
0 g
s
.7097 .41562 m .69792 .41612 L .65122 .38851 L p .396 .671 .971 r
F P
0 g
s
.64253 .38858 m .65122 .38851 L .69792 .41612 L p .167 .571 .934 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33061 .34837 L p .587 .77 .967 r
F P
0 g
s
.33061 .34837 m .31955 .3425 L .38005 .32217 L p .587 .77 .967 r
F P
0 g
s
.4689 .35028 m .47271 .35723 L .41873 .36438 L p .58 .724 .941 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .4689 .35028 L p .58 .724 .941 r
F P
0 g
s
.53126 .35907 m .53081 .36274 L .4765 .36344 L p .52 .774 .989 r
F P
0 g
s
.4765 .36344 m .47271 .35723 L .53126 .35907 L p .52 .774 .989 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31955 .3425 L p .604 .794 .972 r
F P
0 g
s
.31955 .3425 m .30835 .33729 L .3721 .3135 L p .604 .794 .972 r
F P
0 g
s
.58475 .37063 m .58949 .36983 L .64253 .38858 L p .057 .56 .884 r
F P
0 g
s
.58949 .36983 m .58475 .37063 L .53081 .36274 L p .309 .718 .977 r
F P
0 g
s
.72139 .41178 m .7097 .41562 L .65991 .3857 L p .56 .718 .946 r
F P
0 g
s
.65122 .38851 m .65991 .3857 L .7097 .41562 L p .396 .671 .971 r
F P
0 g
s
.65122 .38851 m .64253 .38858 L .58949 .36983 L p .257 .654 .965 r
F P
0 g
s
.46506 .34244 m .4689 .35028 L .41113 .35609 L p .57 .72 .943 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46506 .34244 L p .57 .72 .943 r
F P
0 g
s
.53081 .36274 m .53126 .35907 L .58949 .36983 L p .309 .718 .977 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30835 .33729 L p .624 .813 .973 r
F P
0 g
s
.30835 .33729 m .29702 .33256 L .36408 .30475 L p .624 .813 .973 r
F P
0 g
s
.73297 .40456 m .72139 .41178 L .66857 .37986 L p .662 .731 .901 r
F P
0 g
s
.65991 .3857 m .66857 .37986 L .72139 .41178 L p .56 .718 .946 r
F P
0 g
s
.46119 .33363 m .46506 .34244 L .40346 .34772 L p .569 .719 .943 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46119 .33363 L p .569 .719 .943 r
F P
0 g
s
.53172 .35404 m .53126 .35907 L .47271 .35723 L p .526 .752 .979 r
F P
0 g
s
.47271 .35723 m .4689 .35028 L .53172 .35404 L p .526 .752 .979 r
F P
0 g
s
.65991 .3857 m .65122 .38851 L .59427 .36716 L p .437 .706 .979 r
F P
0 g
s
.58949 .36983 m .59427 .36716 L .65122 .38851 L p .257 .654 .965 r
F P
0 g
s
.59427 .36716 m .58949 .36983 L .53126 .35907 L p .405 .731 .991 r
F P
0 g
s
.7444 .39417 m .73297 .40456 L .67717 .37094 L p .722 .731 .858 r
F P
0 g
s
.66857 .37986 m .67717 .37094 L .73297 .40456 L p .662 .731 .901 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29702 .33256 L p .645 .825 .97 r
F P
0 g
s
.29702 .33256 m .28557 .32812 L .35599 .29592 L p .645 .825 .97 r
F P
0 g
s
.53126 .35907 m .53172 .35404 L .59427 .36716 L p .405 .731 .991 r
F P
0 g
s
.45731 .32383 m .46119 .33363 L .39573 .33928 L p .577 .722 .942 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45731 .32383 L p .577 .722 .942 r
F P
0 g
s
.7557 .38109 m .7444 .39417 L .68569 .35914 L p .758 .728 .825 r
F P
0 g
s
.67717 .37094 m .68569 .35914 L .7444 .39417 L p .722 .731 .858 r
F P
0 g
s
.53217 .34736 m .53172 .35404 L .4689 .35028 L p .544 .735 .964 r
F P
0 g
s
.4689 .35028 m .46506 .34244 L .53217 .34736 L p .544 .735 .964 r
F P
0 g
s
.76686 .36595 m .7557 .38109 L .69415 .34487 L p .78 .726 .803 r
F P
0 g
s
.68569 .35914 m .69415 .34487 L .7557 .38109 L p .758 .728 .825 r
F P
0 g
s
.77795 .34956 m .76686 .36595 L .70254 .32872 L p .792 .726 .79 r
F P
0 g
s
.69415 .34487 m .70254 .32872 L .76686 .36595 L p .78 .726 .803 r
F P
0 g
s
.78901 .33274 m .77795 .34956 L .7109 .31138 L p .797 .727 .787 r
F P
0 g
s
.70254 .32872 m .7109 .31138 L .77795 .34956 L p .792 .726 .79 r
F P
0 g
s
.7109 .31138 m .71927 .29362 L .78901 .33274 L p .797 .727 .787 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28557 .32812 L p .664 .83 .963 r
F P
0 g
s
.28557 .32812 m .27399 .32374 L .34782 .287 L p .664 .83 .963 r
F P
0 g
s
.66857 .37986 m .65991 .3857 L .59905 .36222 L p .562 .72 .947 r
F P
0 g
s
.59427 .36716 m .59905 .36222 L .65991 .3857 L p .437 .706 .979 r
F P
0 g
s
.4534 .31311 m .45731 .32383 L .38792 .33076 L p .589 .727 .939 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .4534 .31311 L p .589 .727 .939 r
F P
0 g
s
.59905 .36222 m .59427 .36716 L .53172 .35404 L p .495 .731 .977 r
F P
0 g
s
.53172 .35404 m .53217 .34736 L .59905 .36222 L p .495 .731 .977 r
F P
0 g
s
.53263 .33888 m .53217 .34736 L .46506 .34244 L p .568 .721 .945 r
F P
0 g
s
.46506 .34244 m .46119 .33363 L .53263 .33888 L p .568 .721 .945 r
F P
0 g
s
.67717 .37094 m .66857 .37986 L .60384 .35477 L p .64 .715 .902 r
F P
0 g
s
.59905 .36222 m .60384 .35477 L .66857 .37986 L p .562 .72 .947 r
F P
0 g
s
.44947 .30157 m .4534 .31311 L .38005 .32217 L p .606 .734 .935 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44947 .30157 L p .606 .734 .935 r
F P
0 g
s
.60384 .35477 m .59905 .36222 L .53217 .34736 L p .565 .721 .946 r
F P
0 g
s
.53309 .32858 m .53263 .33888 L .46119 .33363 L p .592 .709 .925 r
F P
0 g
s
.46119 .33363 m .45731 .32383 L .53309 .32858 L p .592 .709 .925 r
F P
0 g
s
.53217 .34736 m .53263 .33888 L .60384 .35477 L p .565 .721 .946 r
F P
0 g
s
.68569 .35914 m .67717 .37094 L .60861 .34477 L p .687 .705 .861 r
F P
0 g
s
.60384 .35477 m .60861 .34477 L .67717 .37094 L p .64 .715 .902 r
F P
0 g
s
.44552 .28939 m .44947 .30157 L .3721 .3135 L p .623 .74 .931 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44552 .28939 L p .623 .74 .931 r
F P
0 g
s
.69415 .34487 m .68569 .35914 L .61336 .33239 L p .717 .697 .831 r
F P
0 g
s
.60861 .34477 m .61336 .33239 L .68569 .35914 L p .687 .705 .861 r
F P
0 g
s
.60861 .34477 m .60384 .35477 L .53263 .33888 L p .615 .707 .91 r
F P
0 g
s
.53354 .31655 m .53309 .32858 L .45731 .32383 L p .615 .701 .906 r
F P
0 g
s
.45731 .32383 m .4534 .31311 L .53354 .31655 L p .615 .701 .906 r
F P
0 g
s
.53263 .33888 m .53309 .32858 L .60861 .34477 L p .615 .707 .91 r
F P
0 g
s
.44155 .27677 m .44552 .28939 L .36408 .30475 L p .64 .746 .925 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44155 .27677 L p .64 .746 .925 r
F P
0 g
s
.70254 .32872 m .69415 .34487 L .6181 .31794 L p .735 .693 .81 r
F P
0 g
s
.61336 .33239 m .6181 .31794 L .69415 .34487 L p .717 .697 .831 r
F P
0 g
s
.7109 .31138 m .70254 .32872 L .62282 .30191 L p .747 .692 .799 r
F P
0 g
s
.6181 .31794 m .62282 .30191 L .70254 .32872 L p .735 .693 .81 r
F P
0 g
s
.61336 .33239 m .60861 .34477 L .53309 .32858 L p .65 .694 .878 r
F P
0 g
s
.534 .30303 m .53354 .31655 L .4534 .31311 L p .635 .696 .889 r
F P
0 g
s
.4534 .31311 m .44947 .30157 L .534 .30303 L p .635 .696 .889 r
F P
0 g
s
.71927 .29362 m .7109 .31138 L .62753 .28487 L p .754 .695 .796 r
F P
0 g
s
.62282 .30191 m .62753 .28487 L .7109 .31138 L p .747 .692 .799 r
F P
0 g
s
.43754 .26392 m .44155 .27677 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53309 .32858 m .53354 .31655 L .61336 .33239 L p .65 .694 .878 r
F P
0 g
s
.62753 .28487 m .63227 .26744 L .71927 .29362 L p .754 .695 .796 r
F P
0 g
s
.6181 .31794 m .61336 .33239 L .53354 .31655 L p .675 .685 .852 r
F P
0 g
s
.53446 .28835 m .534 .30303 L .44947 .30157 L p .652 .694 .877 r
F P
0 g
s
.44947 .30157 m .44552 .28939 L .53446 .28835 L p .652 .694 .877 r
F P
0 g
s
.53354 .31655 m .534 .30303 L .6181 .31794 L p .675 .685 .852 r
F P
0 g
s
.62282 .30191 m .6181 .31794 L .534 .30303 L p .692 .681 .835 r
F P
0 g
s
.53492 .2729 m .53446 .28835 L .44552 .28939 L p .666 .696 .868 r
F P
0 g
s
.44552 .28939 m .44155 .27677 L .53492 .2729 L p .666 .696 .868 r
F P
0 g
s
.534 .30303 m .53446 .28835 L .62282 .30191 L p .692 .681 .835 r
F P
0 g
s
.62753 .28487 m .62282 .30191 L .53446 .28835 L p .704 .68 .824 r
F P
0 g
s
.63227 .26744 m .62753 .28487 L .53492 .2729 L p .712 .684 .821 r
F P
0 g
s
.53446 .28835 m .53492 .2729 L .62753 .28487 L p .704 .68 .824 r
F P
0 g
s
.53539 .25714 m .53492 .2729 L .44155 .27677 L p .677 .7 .864 r
F P
0 g
s
.44155 .27677 m .43754 .26392 L .53539 .25714 L p .677 .7 .864 r
F P
0 g
s
.53492 .2729 m .53539 .25714 L .63227 .26744 L p .712 .684 .821 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?n]/md00ol0003o]ZoBokJ_dP04okJ_dP_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00006On]/md00ol0003o
]ZoBokJ_dP0?okJ_dP_o00006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oo
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`Co00000_nW`>/00ol0003o[K?Mojfcg@0Nojfcg@03o`000?nf[m;o]ZoB01[o]ZoB
1ol0000Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0ol0
0007ojO0j`03o`000?n]/mgo[K?M01go[K?M00?o0000okJ_d_nf[m807_nf[m800ol0003o`K7;ol6a
b`03o`00017ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4
o`0000[oYl3[00?o0000ojfcgOn]/md03_n]/md@o`0001oo]ZoB00?o0000ol6aboo1/L/01?o1/L/3
o`0000kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool4o`00
00goYl3[0ol00002ojfcg@go00003onZ/]h00ol0003o]:kBokB^dP02okB^dPSo00004onf[m800ol0
003o`K7;ol6ab`07ol6ab`?o00002oooool00ol0003oooooooooo`0cooooo`;o0000;_ooool001_o
oooo00?oEEEEofIVI_l000001_ooool2o`0000[ooooo00?o0000ooooooooool0HOooool4o`0000go
Yl3[1?l00002oj>nk003o`000?nZ/]koZ[;N01coZ[;N00?o0000okB^d_nd[]802_nd[]87o`0000co
]ZoB00?o0000ol6aboo1/L/02_o1/L/4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
0ol0000=ojO0j`Co00001_nS_^`00ol0003oZ[;NojZbgP0LojZbgP03o`000?nd[];o]:kB017o]:kB
2?l00003okJ_dP03o`000?o1/L_o`K7;00oo`K7;0ol00005ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:oooool002Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Hooooo`Co00002onW`>/5o`0000_oXkk/00?o0000ojZbg_nZ/]h06onZ/]h00ol0003o]:kBokB^
dP0IokB^dPCo00005?o1/L/3o`0000;ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000;
ojO0j`Co00003_nS_^`3o`0000;oZ[;N7?l0000NokB^dP03o`000?no/Lco_k7<00?o00004_o1/L/3
o`0003Oooooo00?o0000ooooooooool0:_ooool002Cooooo0_l0000>ooooo`03o`000?oooooooooo
057ooooo0_l00002ojWDmP03o`000?nW`>_oYl3[00GoYl3[1?l0000=oj>nk0Go00000_nO_Nh00ol0
003oY[7PojJah00KojJah004o`000?na[]Go/JkEok6^e@Ko00005Ond[]800ol0003o_k7<oknac003
oknac0?o00004Oo1/L/4o`0003Gooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@oooo
o`03o`000?oooooooooo04kooooo0_l00005ojWDmP03o`000?nW`>_oYl3[00;oYl3[0_l0000=oj>n
k0Co00001onO_Nh00ol0003oY[7PojJah00KojJah003o`000?na[]Go/JkE00Oo/JkE1_l0000?okB^
dP03o`000?no/Lco_k7<00Ko_k7<0ol0000>ol6ab`04o`000?o1/L_o`K7;ol6ab`?o0000<oooool0
0ol0003oooooooooo`0Xooooo`009?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04_ooooo0_l00007ojWDmP?o00003?nS_^`5o`0000coWkg^00?o0000ojJah?nV/N006_nV/N000ol0
003o/JkEok6^e@0=ok6^e@Ko00002?nd[]800ol0003o_k7<oknac00:oknac0?o00002oo1/L/00ol0
003o`K7;ol6ab`02ol6ab`04o`000?o<^/Wo0000o`00033ooooo0_l0000Zooooo`008oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo0_l00006ojWDmP?o00000_nUdoP00ol0
003oXkk/oj>nk006oj>nk0Co00003_nO_Nh4o`0000?oY[7P3?l0000=ojJah003o`000?na[]Go/JkE
01?o/JkE1_l00002okB^dP03o`000?no/Lco_k7<00go_k7<0ol00008ol6ab`05o`000?o1/L_o`K7;
ol6abol000001?o<^/T2o`00033ooooo00?o0000ooooooooool09oooool002?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001_nYe?H2o`0000KoYM?h00?o0000oj>n
k?nS_^`00_nS_^`3o`0000goWkg^1Ol00003oi^kk`03o`000?nR/^?oX[;S00goX[;S3_l0000Kok6^
e@?o00004_no/L`3o`0000Co`K7;0_l00003ol6ab`03o`000?o<^/Woc;[900Coc;[900?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Vooooo`008oooool2o`0001Cooooo00?o0000oooooooo
ool0@Oooool3o`0000KoZMCf0_l00008ojGCn0?o00003OnO_Nh5o`0000WoVk__00?o0000oj:bhonR
/^<06OnR/^<01?l0003o[:oJojb_f_n/[mX5o`0001Go/JkE00?o0000okbacol000000_l0000Aokna
c0Co000000Go`K7;o`000?o1/L_o`K7;o`000008olbjb@;o0000;_ooool00ol0003oooooooooo`0V
ooooo`008oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo0_l00006ojWD
mP?o00001onUdoP3o`000003oio@nOl0003oWkg^00SoWkg^1Ol0000>oi^kk`03o`000?nR/^?oX[;S
01WoX[;S00?o0000ojb_f_n/[mX01_n/[mX6o`0000ko/JkE00?o0000okbaconl/Ll00onl/Ll3o`00
00co_k7<0ol00002oknac0Co000000?o`K7;o`000?o<^/T02Oo<^/T2o`0002gooooo00?o0000oooo
ooooool09Oooool002?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0kooooo`;o
00001_nYe?H2o`0000SoYM?h0_l00005oio@n@03o`000?nO_NkoWkg^00;oWkg^1?l0000@oi^kk`Go
00001?nR/^<3o`0001?oX[;S00?o0000ojb_f_n/[mX03?n/[mX6o`0000So/JkE00?o0000okbaconl
/Ll01_nl/Ll3o`0000Ko_k7<0ol00008oknac0;o00003Oo<^/T2o`0002_ooooo00?o0000oooooooo
ool09Oooool002?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`;o0000
1OnYe?H3o`0000OoYM?h0ol00007oio@n@Co00003?nK^nl9o`0000CoU[[`00?o0000oifcionM/nL0
1OnM/nL=o`0000KoX[;S00?o0000ojb_f_n/[mX04_n/[mX5o`0000?o/JkE00?o0000okbaconl/Ll0
2Onl/Ll6o`0000co_k7<0ol0000=olbjb@;o0000:Oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Sooooo000Rooooo`?o
00006?ooool00ol0003oooooooooo`0eooooo`;o00001OnYe?H2o`0000OoYM?h0ol00007oio@n@?o
00000onJboP00ol0003oVk__oi^kk`03oi^kk`Oo00003OnF^_000ol0003oWK?Woifci`0Boifci`Oo
00006On/[mX3o`0000co_;7?1_l0000;oknac003o`000?o:^L[o000000;ob[W:00?o0000olbjbOo<
^/T02oo<^/T2o`0002Wooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Oooooo000Rooooo`03o`000?oooooooooo01Wo
oooo0_l0000cooooo`;o00001OnYe?H2o`0000OoYM?h0_l00007oio@n@?o00001_nJboP2o`000003
oi^kkol0003o000001KoU[[`00?o0000oifcionM/nL05onM/nL01?l0003oY[7PojJah?nV/N05o`00
01?o[:oJ00?o0000okNbe?l000000_l00005okbac`?o00001_nl/Ll3o`0000So_k7<00Co0000olZi
b_o:^L[o00000_o:^LX2o`0000goc;[90_l0000Wooooo`03o`000?oooooooooo00Gooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Kooooo000Rooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0;_ooool4o`0000?oZMCf0_l00006ojGCn0?o00001onOd?T2
o`0000KoV/_h0ol00002oiK5m`03o`000?nF^_3oU[[`013oU[[`1ol0000Ioifci`03o`000?nV/N3o
Y[7P00KoY[7P1Ol0000=ojb_fP03o`000?ng/]Co]k;D00?o]k;D1Ol0000<okbac`?o00001?no/L`0
0ol0003ob[W:olZibP02olZibP04o`000?o:^L[ob[W:olZibP;o00003Oo<^/T00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;?ooool00ol0003o]^KfokKVmP02okKVmP?o00001_nUdoP2o`0000OoWm3i0ol00005oi[;n0?o
00001_nFaOL00ol0003oU[[`oiJjl004oiJjl0_o00001_nC^?400ol0003oUkG/oiNek004oiNek0go
00001OnM/nL00ol0003oY[7PojJah00<ojJah0Go00002?n/[mX00ol0003o]k;DokNbe002okNbe0?o
000000Co]k;Do`000?l0003o00003_nl/Ll3o`000003oknac?l0003ob[W:00Cob[W:00?o0000olZi
b_o:^LX00_o:^LX2o`0000coc;[90_l0000Vooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0:_ooool00ol0003o]^KfokKVmP02okKVmP04o`000?na
i_So/NKhok7Vn0;o00000_nUdoP2o`0000OoWm3i0_l00005oi[;n0?o00002?nFaOL3o`000003oiJj
l?l0003o000000;o00004_nC^?400ol0003oUkG/oiNek00@oiNek0Ko00004onV/N05o`0000?o[:oJ
00?o0000okNbe?l000000_l00007okNbe0?o00003_nl/Ll00ol0003ob[W:olZibP04olZibP03o`00
0?o:^L[ob[W:00Cob[W:0_l0000<olbjb@;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0:ooooo`001Ol00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0:?ooool00ol0003o]^KfokKVmP02okKVmP03o`000?nai_So/NKh00?o
/NKh0ol00006oio@n@?o00001?nJboP3o`0000SoU/Gg0ol00002oi>nm003o`000?nC^?7oTkSa013o
TkSa1_l0000GoiNek004o`000?nM]>SoWKCXoifdj0Go00004?nV/N05o`0000go]k;D0ol0000;okba
c`03o`000?o7^Lgo000000Gob[W:00?o0000olZib_o:^LX01Oo:^LX00ol0003oc;[9olbjb@0;olbj
b@03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`0:ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool00oooool2o`00027ooooo00?o0000ooooooooool09_ooool00ol0003o]^KfokKVmP02
okKVmP03o`000?nai_So/NKh00?o/NKh00Co0000ojcRnOn/h_Wo[>;i0_l00003oio@n@03o`000?nJ
boSoV/_h00?oV/_h0_l00008oiK5m`?o00001_nC__@00ol0003oTkSaoi>hl@04oi>hl@_o00001OnA
^?400ol0003oTKSaoi6hl@04oi6hl@co00001OnG]N`00ol0003oWKCXoifdj006oifdj0Go00002_nV
/N04o`000004ojndg?l0003o0000o`0000ko]k;D0ol00007okbac`03o`000?o7^LgoakW=00;oakW=
0_l00003olZibP03o`000?o:^L[ob[W:00Gob[W:0_l0000;olbjb@;o00009?ooool02Ol0003ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002Oooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000okKVm_nfi_H00_nfi_H00ol0003o/NKhok7V
n003ok7Vn003o`000?n/h_Wo[>;i00?o[>;i1?l00004oi[;n003o`000?nFaOOoU/Gg00GoU/Gg1?l0
0008oi>nm0?o000000?oTkSao`000?l000000_l0000Aoi6hl@03o`000?nA^?7oTKSa00ooTKSa1_l0
000=oifdj0Go00000_nV/N03o`0000?oY[7P00?o0000ojndg?n_]=`00_n_]=`3o`0000ko]k;D0ol0
0004okbac`03o`000?o7^LgoakW=00CoakW=00Go0000olZib_o:^L[ob[W:o`000008olZibP;o0000
2?o<^/T01?l0003oelO;omO7bol0000Sooooo`03o`000?oooooooooo01oooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool08_ooool00ol0003o]^KfokKVmP02okKVmP03o`000?nai_So/NKh00;o
/NKh0_l00005ojcRn@03o`000?nUfo[oYM_j00;oYM_j0ol00006oiK5m`?o00002OnC__@3o`0000?o
TKOa00?o0000oi6hlOnA^?403onA^?46o`0001GoTKSa00?o0000oi2hl_n@^?801Ol0000:oifdj0Ko
00000_nV/N000ol0003o[kCLojndg006ojndg0?o00003_ng/]@3o`000003okbacol0003oakW=00Ko
akW=0_l000000oo:^L[o0000olZibP09olZibP;o00001Oo<^/T00ol0003oelO;omO7b`02omO7b`03
o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Pooooo`03o`000?nfi_Ko]^Kf00;o]^Kf00?o0000ok7Vn?nai_P00_nai_P00ol0003o
[>;iojcRn@03ojcRn@;o00001?nUfoX01Ol0003oW]7joikAn_nNdO[o000000?oU/Gg0_l00008oi>n
m0Co00001onA]o400ol0003oTKSaoi6hl@04oi6hl@[o00001OnA^?400ol0003oRkcfoh^lmP04oh^l
mP_o00001?nA^?400ol0003oT;Sboi2hlP05oi2hlPGo00000onM]>P2o`0000KoWKCX0ol0000;ojnd
g0?o00003_ng/]@00ol0003oakW=olNic@08olNic@?o00002oo:^LX00ol0003oc;[9olbjb@02olbj
b@03o`000?oGal_oelO;00?oelO;00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Moooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o00009Oooool00ol0
003oooooooooo`0Nooooo`04o`000?nfi_Ko]^KfokKVmP;o00001?nai_P00ol0003o[>;iojcRn@03
ojcRn@03o`000?nUfo[oYM_j00;oYM_j0_l00004oikAnP?o00001onC__@4o`0000[oTKOa0ol00000
1?nA^?7o0000o`000?l0000Aoi6hl@03o`000?n;_?KoRkcf00koRkcf1Ol0000<oi2hlPGo00002?nM
]>P01?l0003oXkOVo`000?l0000;ojndg0;o00003?ng/]@00ol0003o`[[Co`00000:olNic@;o0000
2oo:^LX2o`000003olbjbOl0003oelO;00KoelO;00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Mooooo`008?ooool2o`0002Oooooo00?o0000ooooooooool07?ooool01Ol0003o]^KfokKV
m_nfi_Ko000000Co/NKh0_l00004ojcRn@;o00001?nUfoX00ol0003oW]7joikAnP03oikAnP04o`00
0?nGa?KoUlCfoiO4mP;o00000onC__@2o`0000_oTKOa0ol00002oi:ak003o`000?nA^?7oTKSa00ko
TKSa1_l0000:oh^lmP03o`000?n;_?KoRkcf00OoRkcf00?o0000ogjkn_mn^oX01?l00003oi2hlP?o
00001On@^?85o`0000;oWKCX00?o0000oj>gi_nS]nH00onS]nH2o`0000[o[kCL0ol00008okNbe003
o`000?o2^]?o`[[C00;o`[[C00?o0000olNicOo7^Ld01oo7^Ld3o`0000_ob[W:00?o0000omO7booG
al/01ooGal/00ol0003oooooooooo`0Oooooo`;o00007_ooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Jooooo`05o`000?nfi_Ko]^KfokKVm_l000001?nai_P00ol0003o
[>;iojcRn@03ojcRn@03o`000?nUfo[oYM_j00;oYM_j0_l00004oikAnP;o00001OnGa?H3o`0000[o
TKOa1?l00006oi:ak003o`000?nA^?7oTKSa00CoTKSa2Ol00005oiBil003o`000?n6`?[oQ/3j00Wo
Q/3j2_l00006ogjknPKo00002_n@^?82o`0000SoXkOV0ol0000:ojndg0?o00001?ng/]@00ol0003o
`[[Col:jd`04ol:jd`;o00002?o7^Ld01?l0003oakW=o`000?l00009olZibP;o00002OoGal/00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo000Pooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool06?ooool01Ol0003o]^KfokKVm_nfi_Ko000000Co/NKh00?o0000ojcR
nOn/h_T00on/h_T00ol0003oYM_jojGKnP02ojGKnP03o`000?nNdO[oW]7j00?oW]7j00?o0000oiO4
m_nGa?H01?nGa?H01Ol0003oTKO`oi6gl?nA]o3o000000KoTKOa0ol00009oi:ak0?o000000CoTKSa
o`000?l0003o00003OnD^O04o`0000WoQ/3j00?o0000ohK0n_n6`?X01on6`?X00ol0003oIk_mofNk
o@04o`0000KoO[_j1?l00007oi2hlP03o`000?n?^?;o000000WoXkOV0ol0000:ojndg0?o000000?o
]k;Do`000?o2^]<01oo2^]<2o`0000OoakW=00Co0000olNicOo7^Lgo00001oo:^LX01?l0003oeLO<
omG7c?l00009omO7b`03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool0023ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`05o`000?nfi_Ko]^KfokKVm_l0
00001?nai_P00ol0003o[>;iojcRn@02ojcRn@;o00000onUfoX2o`0000CoW]7j0_l00005oiO4mP;o
00001OnA]o001?l0003oTKOaoi6glOnA]o42o`0000WoT[7/0ol00003oiB]i`03o`000?nD^O3oU;W`
00SoU;W`1_l00003oiVkk`03o`000?n5a_goQLKm00SoQLKm3Ol00003ofNko@Go00001Omn^oX5o`00
0003oi2hl_l0003oSkSb00CoSkSb0_l00008oj>giP;o00002on_]=`00ol0003o`[[Col:jd`09ol:j
d`03o`000?o7^LgoakW=00GoakW=00?o0000olNicOo7^Ld00_l00004olZibP03o`000?oEalcoeLO<
00;oeLO<00?o0000omO7booGal/01ooGal/00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01[ooooo000Pooooo`;o0000:oooool00ol0003oooooooooo`0Dooooo`03o`000?nfi_Ko]^Kf00;o
]^Kf1?nai_P5ojcRn@03o`000?nUfo[oYM_j00;oYM_j00?o0000oikAn_nNdOX00_nNdOX2o`0000Ko
UlCf00?o0000oi6gl?nA]o001OnA]o03o`0000WoT[7/0ol00007oiB]i`03o`000?nD^O3oU;W`00?o
U;W`1?l00007oiVkk`Co00002On5a_d:o`0000?oCkOj00?o0000ofNkoOmW^od01OmW^od4o`0000Ko
O[_j0_l00007ohnhlP?o00001onS]nH3o`0000So[kCL00?o0000okRkfol000002_o2^]<2o`0000Go
akW=00?o0000olNicOo7^Ld00_o7^Ld2o`000003olZib_l0003oeLO<00GoeLO<00?o0000omO7booG
al/01ooGal/00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool04_ooool00ol0003o]^KfokKVmP02okKVmPCo/NKh
1On/h_T00ol0003oYM_jojGKnP02ojGKnP03o`000?nNdO[oW]7j00;oW]7j00?o0000oiO4m_nGa?H0
1?nGa?H2o`0000OoTKO`00Co0000ohfZjOn=Z^Wo00001_nB/N`3o`0000[oU:gW0_l000000onD^O3o
0000oiVkk`06oiVkk`Ko00001?nP_Nh00ol0003oR<cnohS<oP0:ohS<oPGo00001?ll]?42o`0000Go
CkOj00?o0000ofNkoOmW^od00_mW^od4o`0000;oO[_j00Co0000ofndn_m_]?[o00002?n?^?82o`00
00SoXkOV0_l00005ojndg004o`000?nh^m_o^;_KokRkf`;o00002_o2^]<2o`0000CoakW=00?o0000
olNicOo7^Ld00oo7^Ld00ol0003oeLO<omG7c006omG7c003o`000?oGal_oelO;00OoelO;00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`008?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo013ooooo00?o0000okKVm_nfi_H00_nfi_H00onai_So0000o`000003o`00
00?o[>;i1OnUfoX5oikAnP03o`000?nGa?KoUlCf00CoUlCf00?o0000oi6gl?nA]o001OnA]o02o`00
00CoSJ[Y00Co0000oi:ak?nB/NcoT[7/0_l0000:oiB]i`?o00000_nHZN<00ol0003oVK__oiVkk`03
oiVkk`?o00002OnP_Nh3o`0000?oR<cn1?l000001?n@doko0000o`000?l00002oi3CoP?o00001?lg
]N/00ol0003o?;Caocbdl@03ocbdl@Go00000_m?]oX2o`000003ofNkoOl0003o000000KoKkCj0_l0
0006ohnhlP;o00002?nS]nH3o`000003ojndg?l0003o^;_K00Go^;_K0_l0000:ol:jd`03o`000?o7
^LgoakW=00;oakW=00?o0000olNicOo7^Ld00_o7^Ld2o`0000SoeLO<00?o0000omO7booGal/01ooG
al/00ol0003oooooooooo`0Mooooo`;o00006_ooool0023ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0>ooooo`Oo00000_o6k^l00ol0003o`N_bol7[lP09o`0000?oW]7j1onGa?H0
0ol0003oTKO`oi6gl004oi6gl0;o00001_n=Z^T3o`0000[oU:gW0ol00005oiRYh`;o000000?oVK__
o`000?nP_Nh02OnP_Nh4o`0000;oZ<3[00?o0000oi3Co_n@doh00on@doh6o`0000;oW]_l00?o[^3h
o`000?l000001_mOdO83ohKSn@Co=kG[00?o0000ocbdlOll]?400ol00002o`j?hP03o`000?m1YoOo
000000KoKkCj0ol00005ohnhlP?o00002?nS]nH00ol0003o^;_KokRkf`07okRkf`03o`000?o2^]?o
`[[C00So`[[C0_l00003olNic@04o`000?o7^LgoakW=o`0000;od/K?00?o0000omG7c?oEal`01_oE
al`00ol0003oelO;omO7b`07omO7b`03o`000?oooooooooo01gooooo00?o0000ooooooooool06?oo
ool001oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0=ooooo`05o`000?o:k^go
b^k]ol[^kOl000000oo6k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o^>Ce00?o
0000ojcImon/fOL00ol00006oiO4mP03o`000?nA]o3oTKO`00CoTKO`00?o0000ohfZjOn=Z^T01?n=
Z^T2o`0000?oRj3R00?o0000oiB]ionD[NL01?nD[NL3o`0000GoV:WS0ol00002oifXgP03o`000?nP
_NkoX;g^00GoX;g^1?l00006ojS0j`;o000000CoT=?no`000?l0003o00001OnNfo`2ojkPn0;o0000
00?o_N;ao`000?n6hoT01?n6hoT01?n[kOSo0000olG]kol00003oj3Xn`Co00000omld?l2o`1gaP?o
3XoR00Co0000od6Wmol0003o00001Om_]?X2o`0000KoSkSb0_l00005oj>giP03o`000?nY^nKoZK_V
00Wo^;_K0_l0000:ol:jd`;o000000CoakW=o`000?o7^Lgo00001?oBa/l00ol0003oeLO<omG7c006
omG7c003o`000?oGal_oelO;00OoelO;00?o0000ooooooooool07Oooool00ol0003oooooooooo`0G
ooooo`007oooool2o`00037ooooo00?o0000ooooooooool02oooool01Ol0003ob^k]ol[^kOo:k^go
000000?oa^k_00?o0000ol7[l_o1jo800_o1jo800ol0003o^>CeokSTm@02okSTm@03o`000?n/fOOo
[=Wg00;o[=Wg00?o0000oik9m_l000000_l00002oiO4mPKoTKO`0_l00006ohfZj@03o`000?n;X>;o
Rj3R00CoRj3R00?o0000oiB]ionD[NL00ol00006oiRYh`;o00001_nMZ=h01?l0003oX;g^oj2mk_nP
_Nh3o`0000OoZ<3[1_l00004oikKo0Co[^3h00Co0000okgRlOnmh_7o_N;a0_l000001?n6hoWoZngh
oj_]n?l00002olG]k`;o000000?oX>Sko`000?l000000oo4j>l00ol0003o/=cgok3Lm`03ok3Lm`;o
00000_l0MlH2o`j?hP;o000000?o@JOgo`000?l000001?m_]?X3o`0000GoSkSb0ol000000onS]nKo
0000ojVkiP04ojVkiP03o`000?nh^m_o^;_K00Ko^;_K00?o0000ol:jdoo2^]<02Oo2^]<00ol0003o
akW=o`000006om;6c`03o`000?oEalcoeLO<00KoeLO<00?o0000omO7booGal/01ooGal/00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool01?l0003ob^k]ol[^kOl00004olK^k`05o`000?o1jo;o`N_bol7[
l_l000001?nhi?D00ol0003o[=WgojcIm`02ojcIm`03o`000?nNbOKoW/Wf00?oW/Wf0_l00005oi6g
l003o`000?n=Z^WoSJ[Y00CoSJ[Y0_l00007oh^PhP?o00001onHZN<2o`0000SoWJSN0ol00008ojS0
j`Ko000000Co//?Wo`000?l0003oW]_l1?n^h?P01?l0003o_N;aokgRlOnmh_46o`0000?oaNg_0_l0
00000ooDi^?o0000olCXk`02olCXk`?o00001On`g?L2o`0000?oY<Ob0_mc]?T00ol0MlKo3XoRo`j?
hP02o`000003od6Wmol0003o000000CoKkCj0_l00006ohnhlP03o`000?nY^nKoZK_V00GoZK_V0_l0
0007okRkf`;o00002_o2^]<3o`0000Kod/K?00?o0000omG7c?oEal`01_oEal`00ol0003oelO;omO7
b`07omO7b`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`05o`000?o:k^gob^k]ol[^kOl000000oo6
k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o^>Ce00Go0000ojcImon/fOOo[=Wg
o`000006oik9mP04o`000?n@]_3o0000o`0000;oTKO`1_n=Z^T2o`0000SoRj3R00Co0000oh^Ifon;
VM_o00001OnHZN<2o`0000SoWJSN0_l000000onSZ=[o0000ojS0j`05ojS0j`?o000000?o//?Wo`00
0?l000000_nb`nL2o`000003ok_5h_l0003o[^3h00;o[^3h00Co0000okgRlOnmh_7o_N;a0_l00002
ol[Qj@03o`000?oCgMoo000000;oaNg_00?o0000omCVhooDi^<00_l000000oo4j>oo0000o`000002
omGPg`03o`000?o;f^Gobm[U00;obm[U0_l00006ojC7lP05o`000?mc]?WoLkCiog>dnOl0MlH00_l>
Sn85o`0000?oKkCj0ol000000on?^?;o0000ohnglP02ohnglPSoZK_V0_l00007okRkf`03o`000?o2
^]?o`[[C00Oo`[[C00Co0000ol_6eOl0003o00001_oBa/l00ol0003oeLO<omG7c006omG7c003o`00
0?oGal_oelO;00GoelO;0_l0000Oooooo`03o`000?oooooooooo01Gooooo000Oooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01_ooool01Ol0003ob^k]ol[^kOo:k^go000000Coa^k_
00Go0000ol7[l_o1jo;o`N_bo`000004okSTm@03o`000?n/fOOo[=Wg00;o[=Wg00?o0000oik9m_nN
bOH00onNbOH00ol0003oT;K`oi2fl002oi2fl0;o00001On=Z^T00ol0003oRj3Roh^PhP06oh^PhP;o
00001?n;VM/01?l0003oV:WSoiRYhol00009oifXgP;o00001?nSZ=X01?l0003oZ<3[ojS0jonX`>/2
o`000004ok;3iol0003o0000o`0000;o//?W0_l00003ok_5hP;o00001?nmh_42o`0000;ob^7Y00?o
0000om?MgooCgMl00_l00003omCVh`;o000000?og=gGo`000?oEh=l00ooEh=l00ol0003obm[Uol_J
i@03ol_Ji@04o`000?o1cN?o`LgSo`0000GoY<Ob0ol000001Omc]?Wo0000oc>Al?l0MlKo3XoR00Ko
00000om_]?X00ol0003oSkObohnglP03ohnglP;o00001onY^nH2o`0000Ko^;_K0_l00006ol:jd`05
o`000?o;a]GoblKEol_6eOl000001ooBa/l00ol0003oeLO<omG7c006omG7c003o`000?oGal_oelO;
00?oelO;00Co0000omoHd?oOf=3o00007Oooool3o`0001Kooooo000Oooooo`;o0000=Oooool2o`00
00Kooooo00Go0000ol[^kOo:k^gob^k]o`000003olK^k`03o`000?o1jo;o`N_b00;o`N_b00Go0000
okSTmOnhi?Go^>Ceo`000004ojcIm`03o`000?nNbOKoW/Wf00?oW/Wf00?o0000oi2fl?n@]_000on@
]_001?l0003oQ:CYo`000?l00002ohfZj@03o`000?n;X>;oRj3R00GoRj3R0_l00006oh^If`?o0000
1onMZ=h3o`0000KoXjSJ0ol000001?nb`nOo0000o`000?l00002ok;3i`?o00000onkaN82o`000003
ol?7gOl0003o_N;a00;o_N;a00Go0000ol[QjOo:hNWob^7Yo`000002om?Mg`03o`000?oJfMKo0000
00;oe>KS00Co0000omcMeooLgMOo00000ooEh=l2o`000003ol_JiOl0003o000000;obm[U00?o0000
ol7=hoo1cN<00_o1cN<01_l0003oY<Obo`000?l0003oX[?To`0000?oOj7X1_l000000ol>Sn;o0000
o`000003o`0000?oIJ_h1_n?]o82o`0000OoZK_V00?o0000okRkfonh^m/01Onh^m/2o`0000?o`[[C
00?o0000ol_6eOo;a]D00oo;a]D00ol0003od/K?om;6c`05om;6c`03o`000?oEalcoeLO<00KoeLO<
00Go0000omO7booGal_oelO;o`000003omoHd003o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`05o`00
0?o:k^gob^k]ol[^kOl000000oo6k^l00ol0003o`N_bol7[lP02ol7[lP03o`000?nhi?Go^>Ce00;o
^>Ce00Go0000ojcImon/fOOo[=Wgo`000005oik9mP03o`000?n@]_3oT;K`00?oT;K`00?o0000ohBT
jOn4Y>T00_n4Y>T2o`0000OoRj3R00?o0000oh^Ifon;VM/01On;VM/01Ol0003oSYCFohjDe_n>U=Ko
000000CoWJSN0_l00007oj>XfP;o000000CoZZWFo`000?l0003o00001?nb`nL00ol0003o^lGRok_5
hP02ok_5hP;o00000oo3amd2o`0000Gob^7Y0_oCgMl2o`0000;of]WF00?oe>KSo`000?oLgML00ooL
gML01_l0003oeN3Oo`000?l0003ogMSBo`0000?oemCE0_l00006ol7=h`03o`000?nR/nCoX[?T00;o
X[?T00Go0000ognQj?moXNSoOj7Xo`000002oeF8iP;o000000?o06SGo`000?l0K]<00olZT^l5ofF[
n003o`000?n?]o;oSkOb00?oSkOb00?o0000ojVki_nY^nH01OnY^nH2o`0000Oo^;_K00?o0000ol:j
dol000001oo;a]D00ol0003od/K?om;6c`05om;6c`03o`000?oEalcoeLO<00KoeLO<00?o0000omO7
bol000001?oOf=000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo000Nooooo`03
o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`000002ol[^k@03o`000?o6k^ooa^k_
00;oa^k_00Go0000ol7[l_o1jo;o`N_bo`000004okSTm@03o`000?n/fOOo[=Wg00;o[=Wg00?o0000
oik9m_nNbOH00_nNbOH00ol0003oT;K`oi2fl003oi2fl003o`000?n4Y>WoQ:CY00?oQ:CY0_mkU>02
o`0000?oRj3R0_l00007oh^If`03o`000?n>U=KoSYCF00?oSYCF00Co0000oifXg_nMZ=ko00002?nS
Z=X4o`0000;oZZWF00Co0000ok;3ionb`nOo00001?nkaN82o`0000Co`lOM00Co0000ol_8f?o;b=So
00000_o:hNT3om?Mg`05o`000?oJfMKof]WFom[Ie_l000001?oLgML3o`0000?ogMSB00?o0000omOD
eOoGe=D00_oGe=D01Ol0003odLgEom7=eOl0003o`LgS00;o000000?o_;kKo`000?nR/n@00onR/n@0
0ol0003oOj7XognQj002ognQj003o`000?mER>KoEHSV00;o;FoM0ol000001?l0K]?o:Y;_obZBkolZ
T^l4ofF[n0;o00001?n?]o82o`0000OoZK_V0_l00006okRkf`03o`000?o;a]GoblKE00OoblKE00?o
0000om;6cooBa/l01OoBa/l00ol0003oeLO<omG7c006omG7c003o`000?oOf=3ogmS@00CogmS@00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000003ol[^k@05o`000?o6
k^ooa^k_olK^kol000001?o1jo801Ol0003o^>CeokSTmOnhi?Go000000Co[=Wg00?o0000oik9m_nN
bOH00onNbOH00ol0003oT;K`oi2fl002oi2fl003o`000?n4Y>WoQ:CY00?oQ:CY00?o0000og^Dh?mk
U>000_mkU>000ol0003oRj3Roh^PhP08oh^If`03o`000?n>U=KoSYCF00CoSYCF0_l00008oj>XfP?o
00001OnZZMH2o`0000Co^lGR0_l00004ol?7g@;o00000oo;b=P2o`0000?odmgO00Ko0000om[Ie_oJ
fMKof]WFomgDcol00003omcMe`03o`000?oPe/go000000CogMSB00Go0000omODeOoGe=GoemCEo`00
0004om7=e@03o`000?nl_]_o_;kK00;o_;kK00?o0000oj:ci?nR/n@00_nR/n@01Ol0003oOj7XognQ
j?moXNSo000000?oEHSV0ol]Kmd3o`000003o`1^dolZT^oo:Y;_00;o00000omUZoP2o`0000CoSkOb
0_l00007ojVkiP03o`000?nh^m_o^;_K00;o^;_K00?o0000oko5g_noaMh02?o;a]D2o`0000Ood/K?
00?o0000omG7c?oEal`01OoEal`00ol0003ogmS@omoHd004omoHd003o`000?oooooooooo01kooooo
00?o0000ooooooooool04_ooool001?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo03[ooooo00Go0000ol[^kOo:k^gob^k]o`000004olK^k`05o`000?o1jo;o`N_bol7[
l_l000001?nhi?D00ol0003o[=WgojcIm`02ojcIm`03o`000?nNbOKoW/Wf00;oW/Wf00?o0000oi2f
l?n@]_000_n@]_000ol0003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP00?o0000oh^I
fon;VM/01On;VM/2o`0000KoSYCF00?o0000oi:CdOl000001OnSZ=X3o`0000OoZZWF00Co0000ok6/
dona[=?o00000_nkaN800ol0003o`lOMol?7g@03ol?7g@03o`000?o;b=SoblSH00;oblSH00?o0000
om79d_l000000_oCgMl4om[IeP;ogMC?00Co0000omcMeooLgMOo00000_oPe/d00ol0003ogMSBomgH
dP02omgHdP04o`000?oGe=GoemCEo`0000CodLgE0_l00005okbnf`05o`000?nR/nCoX[?Toj:ci?l0
00001?moXNP01?l0003oEHSVoeF8i_l00002obe_g@;o3U[C00Co0000o`0i/ol0003o06kC0_lZT^l2
o`0000?oIJ_h00?o0000ohngl_n?]o800on?]o800ol0003oZK_VojVkiP05ojVkiP;o000000?o^;_K
o`000?noaMh00onoaMh00ol0003oblKEol_6e@05ol_6e@;o00001ooBa/l00ol0003oeLO<omG7c003
omG7c003o`000?oNf=7o000000KogmS@00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`Co000000?o410@ooooooooool00oooool001?ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo03[ooooo00Go0000ol[^kOo:k^gob^k]o`000003olK^k`03o`000?o1
jo;o`N_b00;o`N_b00Go0000okSTmOnhi?Go^>Ceo`000004ojcIm`03o`000?nNbOKoW/Wf00;oW/Wf
00?o0000oi2fl?n@]_000on@]_000ol0003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP
00?oMXWIo`000?n;VM/01?n;VM/00ol0003oSYCFohjDeP05ohjDeP06o`000?nBTm7oTY?Aoi:CdOl0
003oXjSJ1?l00007ojZYeP;o00000ona[=<2o`0000Ko`lOM00Co0000ol_8f?o;b=SoblSH0_l00003
om79dP03o`000?oJfMKof]WF00;of]WF0ooMe<l00ol0003og=gGon3Fc@02on3Fc@04o`000?oMf=;o
gMSBomgHdPGo00001?oAcMD01?l0003ocL?Aolg3dOl00005okbnf`Wo00000omER>H00ol0003o;FoM
obe_g@03o`iJd`03o`000?l0>KCo000000;o000000?o:Y;_o`000?l000000_mUZoP2o`0000CoSkOb
0_l00006ojVkiP;o00001_noaMh00ol0003oblKEol_6e@05ol_6e@;o00001ooBa/l01Ol0003oeLO<
omG7c?oEalco000000;og]SA00?o0000omoHd?oOf=001?oOf=000ol0003oooooooooo`0Mooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o0000>_ooool01Ol0003ob^k]ol[^kOo:k^go000000?oa^k_00?o0000ol7[
l_o1jo800_o1jo800ol0003o^>Ceo`000009o`0000;oW/Wf00?o0000oi2fl?n@]_000on@]_000ol0
003oQ:CYohBTj@03ohBTj@03o`000?mkU>3oNiCP00CoNiCP00Co0000ogJ9fOmfRMWo00000on;VM/0
0ol0003oSYCFohjDeP05ohjDeP04o`000?nBTm7oTY?Aoi:Cd@?o00000_nSZ=X00ol0003oZZWFojZY
eP04ojZYeP;o00001?na[=<01?l0003o^Jo@okV_d?l00004ol?7g@05o`000?o;b=SoblSHol_8f?l0
00001?oAbM82o`0000?of]WF0ooMe<l2o`0000Coh=K=00Ko0000omgHd_l0003o0000on3Ab?l00002
omk?bP05o`000?oJbl[o0000om7=eOl000000oo=`m400ol0003o_;kKo`000002o`000003okbcdOnX
YmKoZ:OF00;oZ:OF1?n@V=P3o`0000;oEHSV00?o0000obe_gOl000000ol>F]<00ol0003o03Vdo`00
0003o`000003obZBkol0003o000000;oIJ_h0_l00004ohnglP;o00000onY^nH01?l0003o[L7Xojg1
j?l00006oko5gP03o`000?o;a]GoblKE00GoblKE0_l00007om;6c`03o`000?oEalco000000Cog]SA
00?o0000omoHd?oOf=000ooOf=000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool001?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo03[ooooo00Co0000ol[^kOo:k^go00001?o6k^l00ol0003o`N_bo`000004o`0000;o
b>?[00?o0000ok[Il?njfO000_njfO000ol0003oYl_bojO;lP05o`0000;oT;K`00?o0000ohBTjOn4
Y>T00on4Y>T00ol0003oNiCPog^Dh004og^Dh003o`000?mfRMWoMXWI00;oMXWI00?o0000oh^Ifon;
VM/01_n>U=H2o`000004oi:CdOl0003o0000o`0000;oTY?A0ol00006ojZYeP03o`000?na[=?o/JcC
00?o/JcC00?o0000okV_d?ni[m000_ni[m000ol0003o`lOMol?7g@04ol_8f003o`000?oAbM;odLWB
00;odLWB00Go0000omK9cOoFbLgo0000om[IeP03omgDc`03o`000?oPd<So000000?oh=K=0_l00004
on3Ab0;og/o:00Go0000om[;b_oJbl[of/_:o`000005olg3d@03o`000?nl/m7o_;?A00;o_;?A00Go
0000ojRWe_nXYmKoZ:OFo`000004oi2Hf0;oMXSG0ol00002obe_g@03o`000?l>F]?o3U[C00;o04k<
00?o0000o`0i]?l000000ol000000olZT^oo0000ofF[n002ofF[n003o`000?n?]o;oSkOb00?oSkOb
00?o0000ojVki_l000001?n]`NP00ol0003o_lGNoko5gP04oko5gP03o`000?o;a]GoblKE00CoblKE
00?o0000ol_6eOl000001ooBa/l00ol0003og]SAomkHd@03omkHd@03o`000?oOf=3ogmS@00CogmS@
00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
000Cooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0iooooo`06o`00
0?o:k^gob^k]ol[^kOl0003oa^k_1Ol00002om7WiP03o`000?o8hn_ob>?[00;ob>?[00?o0000ok[I
l?njfO000_njfO001?l0003oYl_bojO;l_nWbo84ohnfl@?o00001On4Y>T00ol0003oNiCPog^Dh003
og^Dh003o`000?mfRMWoMXWI00CoMXWI0_l00005ohjDePCo00001?nBTm401Ol0003oVIC>oiVDc_nI
U<ko000000CoZZWF00?o0000ok6/dona[=<00ona[=<00ol0003o^Jo@okV_d004okV_d003o`000?o;
b=SoblSH00;oblSH00?o0000om79d_oAbM800_oAbM801Ol0003oe/W=omK9cOoFbLgo000000?ogMC?
00Co0000on3@b?oPd<So00000_oPe/d00ol0003oh]36o`000003on3Ab0;og/o:00?o0000om[;b_oJ
blX00_oJblX01ol0003ocL?Aolg3dOo=`m7o0000ol^lc?l000001?nl/m401Ol0003oZ:OFojRWe_nX
YmKo000000CoT9SH00?o0000ogJ8eomfR=L00_mfR=L00ol0003o;FoMo`000003o`iJd`;o04k<00Co
0000o`0i]?l0B<7o06CG1Ol00002ofF[n0;o00000_n?]o83o`0000Ko[L7X00?o0000oko5g_noaMh0
1?noaMh00ol0003oblKEol_6e@04ol_6e@03o`000?o;a]Go000000God/K?0_l00006omkHd@03o`00
0?oOf=3ogmS@00?ogmS@00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?o:k^gob^k]00Co00000_oFjN800ol0003odNOVom7WiP02om7WiP03o`00
0?o8hn_ob>?[00;ob>?[00?o0000ok[Il?njfO000_njfO001?l0003oYl_bojO;l_nWbo85ohnfl@;o
N9o[0ol000000on4Y>Wo0000og^Dh004og^Dh003o`000?mfRMWoMXWI00GoMXWI0_meP]800ol0003o
SYCFohjDeP03o`0000KoTY?A00?o0000oiVDc_nIU<h00onIU<h00ol0003oZZWFojZYeP06ok6/d`03
o`000?ni[m3o^Jo@00Co^Jo@00?o0000ol2ccOl000000_o;b=P5om79dP03o`000?oFbLgoe/W=00;o
e/W=00Co0000omgDcooMe<oo00000ooPd<P00ol0003oh=K=on;@aP02on;@aP04o`000?oPdLSoh=78
o`0000;og/o:00Wo0000om[;b_oJbl[of/_:o`000?oHa/So0000olg3dOl000000_o;_<`00ol0003o
_;?Aokbcd@02okbcd@03o`000?nXYmKoZ:OF00;oZ:OF00Go0000oi2Hf?n@V=SoT9SHo`000004ogJ8
e`;oGWSD00Go;FoMo`000?l>F]?o3U[Co`000002o`1>c003o`000?l0>KCo04S100;o06CG00?o0000
obb6jol000001_l00003ohnglP03o`000?n]`NSo[L7X00Co[L7X00?o0000oko5g_noaMh01?noaMh0
0ol0003oblKEol_6e@04ol_6e@03o`000?o;a]Go000000?od/K?00Co0000om[HeOoJf=Go00001OoN
f=400ol0003ogmS@omoHd003omoHd003o`000?oooooooooo023ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`004oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
000iooooo`?o000000?of>SPo`000?oFjN800ooFjN800ol0003odNOVom7WiP02om7WiP05o`000?o8
hn_ob>?[olSSjol000001?njfO000ol0003oYl_bojO;lP02ojO;lP03o`000?n?]_7oSkKa00;oSkKa
1OmhWn/2o`0000GoNiCP00?o0000ogJ9fOmfRMT01?mfRMT00ol0003oMH;BogF2dP04o`0000OoTY?A
00?o0000oiVDc_nIU<h01OnIU<h00ol0003o/JcCok6/d`04ok6/d`03o`000?ni[m3o^Jo@00Co^Jo@
00Go0000ol2ccOo0/lgo`;?=o`000005om79dP03o`000?oFbLgoe/W=00;oe/W=00Co0000om[9b?l0
003ogMC?1?oPd<P01Ol0003oh]36on;@a_oRd<Ko000000;oh=781?l00003om[;bP05o`000?oHa/So
f<K8omS6b?l000000oo;_<`00ol0003o_;?Aokbcd@02okbcd@03o`000?nXYmKoZ:OF00;oZ:OF00Go
0000oi2Hf?n@V=SoT9SHo`000004ogJ8e`04o`000?mNN=CoGWSDo`0000?o3U[C00Ko0000o`1>c?l0
CLco04g<o`000?l0B<42o`1Te`04o`000?l/Q^_o;8K[o`0000CoHjCd1?n?]o800ol0003o[L7Xojg1
j004ojg1j003o`000?noaMko_lGN00Co_lGN00?o0000ol_6eOo;a]D01?o;a]D01Ol0003oblKEo`00
0?oBa/oo000000?of]SE00?o0000omkHdOoNf=401?oNf=400ol0003ogmS@omoHd003omoHd003o`00
0?oooooooooo01oooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Mooooo`03o`000?oo
oooooooo03Oooooo00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhP03o`000?oA
inKodNOV00;odNOV00Go0000olSSjoo8hn_ob>?[o`000004ok[Il003o`000?nWbo;oYl_b00;oYl_b
00?o0000ohnflOn?]_400_n?]_400ol0003oN9o[ogROj`02ogROj`;oHhWR00Go0000og^Dh?mkU>3o
NiCPo`000006ogJ9f@Co00000_meP]800ol0003oTY?Aoi:Cd@05oi:Cd@03o`000?nIU<koVIC>00Go
VIC>0_l00005ok6/d`03o`000?ni[m3o^Jo@00Co^Jo@00?o0000ol2ccOo0/ld00_o0/ld2o`0000?o
dLWB00?o0000omK9cOoFbLd00_oFbLd01?l0003of/W8om[9b?l00004on3@b0;o00000ooRd<H01?l0
003oh=78on;<`_l00002on7;``;o000000?of/_:o`000?oHa/P00_oHa/P00ooF`/Ko0000ol^lc003
ol^lc005o`000?nl/m7o_;?AokbcdOl000001?nXYmH00ol0003oT9SHoi2Hf002oi2Hf005o`000?mf
R=OoMXSGogJ8eol000000omNN=@2o`000004o`iJdol0003o04k<o`1>c0?o04g<00Co04S1o`1Teol0
I=Oo00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm0CoSkOb00?o0000ojg1j?n]`NP01?n]`NP00ol0
003o_lGNoko5gP04oko5gP03o`000?o;a]GoblKE00?oblKE00Co0000ol_6eOl0003o00001OoJf=D0
0ol0003og]SAomkHd@03omkHd@03o`000?oOf=3ogmS@00?ogmS@00?o0000ooooooooool07_ooool0
0ol0003oooooo`000005ooooo`03oeEEEOmVIVKo000000Oooooo000Mooooo`03o`000?oooooooooo
03Oooooo00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhP03o`000?oAinKodNOV
00;odNOV00Go0000olSSjoo8hn_ob>?[o`000004ok[Il003o`000?nWbo;oYl_b00;oYl_b00Go0000
ohnflOn?]_7oSkKao`000005ogROj`?oHhWR00?o0000og^Dh?l000001_mfRMT2o`0000GoMH;B00?o
NH3>o`000?nBTm401?nBTm400ol0003oVIC>oiVDcP05oiVDcP04o`000?nPV<coX9S<o`0000Co/JcC
1_ni[m000ol0003o`;?=ol2cc@02ol2cc@04o`000?o7]l[oakO:o`0000;odLWB1?oFbLd01Ol0003o
f/W8om[9b?oJbLSo000000?oh=3800?o0000on7<`ol000000_oRd<H2o`0000;oh/c200?o0000on7;
`ooQbl<00_oObL<01?l0003of<K8omS6b?l00002omK2aP03o`000?o;_<cobkc<00;obkc<00?o0000
okbcdOl000002?l00003oi2Hf005o`000?mfR=OoMXSGogJ8eol000000omNN=@2od][d@05o`000?l>
F]?o0000o`1>c?l000000ol0CL`2o`000005o`1Teol0003o;8K[obb6jol000001?mSY?@01Ol0003o
SkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh00ol0003oblKEol_6e@03ol_6
e@03o`000?oAeMco000000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003ogmS@omoHd004omoH
d003o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool001cooooo00?o0000oooooooo
ool0>?ooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR00?o0000om7Wi_oA
inH00_oAinH01Ol0003ob>?[olSSjoo8hn_o000000Co^]W`00Go0000ojO;l_nWbo;oYl_bo`000004
ohnfl@03o`000?mhWn_oN9o[00;oN9o[00?o0000of>9h_mSRN800_mSRN82o`0000?oMXWI1?l00005
ogF2dP04o`000?miP<koNH3>o`0000?oTY?A00?o0000oiVDc_nIU<h01OnIU<h00ol0003oX9S<oj2H
c002oj2Hc003o`000?na[=?o/JcC00Ko^Jo@00?o0000ol2ccOo0/ld00_o0/ld00ol0003oakO:olNg
bP02olNgbP03o`000?oFbLgoe/W=00;oe/W=00Co0000om[9b?oJbLSof/W80_l00002on3@b00:o`00
0?oQc<?ohLc3o`000?oRd<Ko0000on;;`Ol0003oh/c2o`0000;ohL_300Ko0000omo9`ooObL?o0000
omS6b?l00003omK2aP04o`000?o;_<cobkc<ol^lc0?o00000_no[lX00ol0003o/:G<ok2Uc002ok2U
c006o`000?nPVLgo0000o`000?n@V=So00000omfR=L01Ol0003oGWSDoeihe?mNN=Co000000?oBf_A
00Co0000o`1>c?l0C/co00000_l0CL`2o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mS
Y?@00_mSY?@01Ol0003oSkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh02Ol0
003oblKEol_6eOo;a]Go0000om7Eg?l0003odMGLo`000004om[He@03o`000?oNf=7og]SA00Cog]SA
00?o0000omoHd?oOf=000ooOf=000ol0003oooooooooo`0Oooooo`?o00003Oooool001cooooo00?o
0000ooooooooool0>?ooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR00?o
0000om7Wi_oAinH00_oAinH01Ol0003ob>?[olSSjoo8hn_o000000Co^]W`00Go0000ojO;l_nWbo;o
Yl_bo`000004ohnfl@03o`000?mhWn_oN9o[00;oN9o[00?o0000of>9h_mSRN800_mSRN82oeEhf@?o
00000_mfRMT00ol0003oMH;BogF2dP03ogF2dP03o`000?miP<koNH3>00;oNH3>00?o0000oi:CdOl0
00001onIU<h00ol0003oX9S<oj2Hc004oj2Hc0;o00001Oni[m000ol0003o`;?=ol2cc@02ol2cc@03
o`000?o7]l[oakO:00?oakO:00Go0000omK9cOoFbLgoe/W=o`000003om[9b003o`000?oMb<CogLS4
00;o00000ooQc<<01?l0003oh]36on;;`OoRbl42on;<`P03o`000?oQbl?o000000;oglW300?o0000
omk7`_l000001?oF`/H4o`000003olbhaol0003o_jo:00;o_jo:00?o0000ok2Uc?n`YL`00_n`YL`0
0ol0003oX9W=oj2Ic@02oj2Ic@;o00000_mfR=L01Ol0003oGWSDoeihe?mNN=Co000000CoBf_A0_l0
00001?l0C/co04g<o`1=c?l0CL`2o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mSY?@0
0_mSY?@01Ol0003oSkObohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh01?noaMh00ol0003o
blKEo`000002om7Eg003o`000?oAeMco000000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003o
gmS@omoHd003omoHd003o`000?oooooooooo01cooooo0ol00002ooooo`03o`000?oooooooooo00_o
oooo000Looooo`;o0000>Oooool00ol0003of>SPomSXh002omSXh003o`000?oFjN;oe^WR00;oe^WR
00Go0000om7Wi_oAinKodNOVo`000004olSSj`03o`000?njfO3o^]W`00;o^]W`00Go0000ojO;l_nW
bo;oYl_bo`000004ohnfl@03o`000?mhWn_oN9o[00;oN9o[00Co0000of>9h_mSRN;oHhWR0ol00000
0omEN=Wo0000ogJ9f@02ogJ9f@03o`000?meP];oMH;B00?oMH;B00?o0000ogV0c_miP<h00omiP<h0
0ol0003oVIC>oiVDcP05oiVDcP03o`000?nPV<coX9S<00GoX9S<00?o0000ojVLb_l000000oni[m00
0ol0003o`;?=ol2cc@02ol2cc@03o`000?o7]l[oakO:00?oakO:00Go0000oljkaol0003oe/W=o`00
0003om[9b005o`000?oMb<CogLS4omg8a?l000000ooQc<<2o`0000;oh/_100So0000on;<`_oRc<;o
0000on7;`ol0003oglW3o`0000;og/O200?o0000omK2a_oF`/H00_oF`/H00ol0003oc;S7olbha`02
olbha`05o`000?no[l[o_jo:okn_b_l000000on`YL`00ol0003oX9W=oj2Ic@03oj2Ic@;oShg=00?o
0000ogJ8eol000000omNN=@00ol0003oBf_Aod][d@02od][d@;o?VC@00Go04k<o`000?l0CLco04g<
o`000002o`EGd@03o`000?l0I=Oo000000;o;8K[00?o0000of>Tm?mSY?@00_mSY?@01Ol0003oSkOb
ohngl_n?]o;o000000Ko[L7X00?o0000oko5g_noaMh00onoaMh2o`0000CodMGL00?o0000om7Eg?l0
00001?oJf=D00ol0003og]SAomkHd@04omkHd@03o`000?oOf=3ogmS@00?ogmS@00?o0000oooooooo
ool06?ooool3o`0000Gooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0
>?ooool00ol0003of>SPomSXh002omSXh005o`000?oFjN;oe^WRomKYh_l000001?oAinH00ol0003o
b>?[olSSj`02olSSj`05o`000?njfO3o^]W`ok[Il?l000001?nWbo800ol0003oSkKaohnfl@02ohnf
l@03o`000?mhWn_oN9o[00;oN9o[1?l000000omSRN;o0000oeEhf@02oeEhf@03o`000?mfRMWo0000
00GoMH;B00?o0000ogV0c_miP<h01?miP<h00omoPL_o0000oiVDcP04oiVDcP03o`000?nPV<coX9S<
00GoX9S<00Oo0000ojVLb_nYW<[oZIc:o`000?ni[m3o000000Go`;?=00?o0000olNgb_o7]lX00_o7
]lX01Ol0003oc[_7oljkaoo>^lOo000000?of/W800?o0000omg8a?oMb<@00_oMb<@01_l0003ohLc3
on7<`ol0003oh/Zoo`0000;oh/_100?o0000on;<`_l000000_l000001?oObL?o0000omk7`_oNal82
o`0000;oe/;600?o0000omJo`ol000001?o<^<L01Ol0003o_jo:okn_b_no[l[o000000?o/:G<00?o
0000oj2IcOnPVLd00onPVLd4ohn=c@;o00000omNN=@01Ol0003oBf_Aod][dOm;Jm7o000000;o?VC@
00Go04k<o`000?l0CLco04g<o`000002o`EGd@?o00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm005
o`000?n?]o;oSkObohngl_l000001_n]`NP01ol0003o_lGNoko5g_noaMko0000ol?@i?l000001OoA
eM`2o`0000Gof]SE00?o0000omkHdOoNf=400ooNf=400ol0003ogmS@omoHd002omoHd0;o00005ooo
ool3o`0000Sooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?ooool0
0ol0003of>SPomSXh002omSXh005o`000?oFjN;oe^WRomKYh_l000001?oAinH01Ol0003ob>?[olSS
joo8hn_o000000Co^]W`00?o0000ojO;l_nWbo800_nWbo801Ol0003oSkKaohnflOn?]_7o000000?o
N9o[0ol00004of>9hP03o`000?mEN=WoEGSI00;oEGSI00?o0000ogF2d_meP]801?meP]800ol0003o
NH3>ogV0cP03ogV0cP04o`000?moPL_oOh7;o`0000?oVIC>00?o0000oj2Hc?nPV<`01OnPV<`00ol0
003oZIc:ojVLbP03ojVLbP03o`000?o0/lgo`;?=00?o`;?=00?o0000olNgb_o7]lX00_o7]lX00ol0
003oc[_7oljka`02oljka`;o000000?of/W8o`000?oMb<@00ooMb<@01?l0003oh<S1o`000?l00002
on;:_`04o`000?oRbl7o0000on;<`P;o000000?oh/Rno`000?l000000_oNal800ol0003ogLG1omg5
`@02o`0000;oe[o300Go0000olbhaoo<^<Ooc;S7o`000003okn_bP03o`000?n`YLco/:G<00;o/:G<
00?o0000oj2IcOnPVLd00_nPVLd00ol0003oShg=ohn=c@02ohn=c@;oP8;<0_l000000omNN=Co0000
od][d@02od][d@05o`000?lnI=3o?VC@ociTd?l000000_l0CL`00ol0003o1EOAo`EGd@02oaeYg0;o
00000_l/Q^/00ol0003oHjCdof>Tm002of>Tm005o`000?n?]o;oSkObohngl_l000001_n]`NP00ol0
003o_lGNo`000003ol?@i003o`000?oAeMcodMGL00?odMGL0_l00004om[He@03o`000?oNf=7og]SA
00Cog]SA00Ko0000omoHd?oOf=3o0000on;/f?l0000Cooooo`Co00002oooool00ol0003ooooooooo
o`0;ooooo`007?ooool00ol0003oooooooooo`0hooooo`05o`000?oHj>3of>SPomSXh?l000001?oF
jN800ol0003odNOVom7WiP02om7WiP05o`000?o8hn_ob>?[olSSjol000000_njfO0:o`000003ohnf
lOl0003o000000;o000000?oN9o[o`000?mSRN801?mSRN800ol0003oEGSIoeEhf@02oeEhf@03odm^
d_l0003oMH;B00?oMH;B00?o0000ogV0c_miP<h01?miP<h01ol0003oOh7;ogn1bomoPL_o0000oiVD
c_l000001onPV<`00ol0003oZIc:ojVLbP04ojVLbP;o00000oo0/ld00ol0003oakO:olNgbP02olNg
bP03o`000?o>^lOoc[_700;oc[_700Co0000omBnaOoD_/Go00001?oMb<@01?l0003oh<S1on38`Ol0
0003on;:_`06o`000?oRbl7o0000o`000?oSbKko00000_oRb;h00ol0003og/O2o`000003omg5`@05
o`000?oF_l?oe[o3omJo`ol000000oo<^<L01Ol0003o_jo:okn_b_no[l[o000000Co/:G<00?o0000
oj2IcOnPVLd00_nPVLd00ol0003oShg=ohn=c@02ohn=c@CoP8;<00?oGWSDo`000?m;Jm400_m;Jm40
0ol0003o?VC@ociTd002ociTd0;o000000Co04g<o`000?l5Em7o1EOA0olMJM`2o`000003obb6jol0
003oHjCd00?oHjCd00Go0000ohngl_n?]o;oSkObo`000005ojg1j0;o00001?o3d>@00ol0003odMGL
om7Eg003om7Eg0;o00001OoJf=D00ol0003og]SAomkHd@03omkHd@03o`000?oOf=3o000000;oh^cH
00?o0000ooooooooool03_ooool3o`00013ooooo00?o0000ooooooooool02_ooool001_ooooo00?o
0000ooooooooool0>Oooool01Ol0003of>SPomSXh?oHj>3o000000Coe^WR00?o0000om7Wi_oAinH0
0_oAinH00ol0003ob>?[olSSj`04o`0000;o`]?W1On]b>h2ohnfl@Ko000000?oN9o[o`000?mSRN80
0omSRN800ol0003oEGSIoeEhf@03oeEhf@;oCfkB00Co0000ogF2d_meP];o00001_miP<h00ol0003o
Oh7;ogn1b`03ogn1b`03o`000?nPV<coX9S<00GoX9S<00?o0000ojVLb_nYW<X01?nYW<X01_l0003o
/Z;8ok:Rb?l0003o`;?=o`0000CoakO:00?o0000oljkaoo>^lL00_o>^lL01?l0003oe;k5omBnaOoD
_/D2o`0000?ogLS400Co0000on38`OoPb<7o00000ooRb[l3o`0000;ohlVn00Goh/Rno`000?oRb;ko
h/Nno`000002omg5`@03o`000?oMa<3o000000;oe[o300?o0000olbhaoo<^<L00_o<^<L01Ol0003o
_jo:okn_b_no[l[o000000Co/:G<00?o0000oj2IcOnPVLd00_nPVLd01Ol0003oShg=ohn=cOn?SLgo
000000GoP8;<0_l00003od][d@04o`000?lnI=3o?VC@ociTd0;o>F?@00Go04g<o`000?l5Em7o1EOA
o`000002oaeYg0;o@8?X0ol00004of>Tm006o`000?n?]o;oSkObohngl_l0003o[L7X0ol000000on^
anco0000ol?@i004ol?@i003o`000?oAeMcodMGL00?odMGL0_l00004om[He@03o`000?oNf=7og]SA
00?og]SA0_l00003on;/f003o`000?oooooooooo00_ooooo0ol0000Cooooo`03o`000?oooooooooo
00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000omSXh?oHj>3of>SPo`000004omKY
hP03o`000?oAinKodNOV00;odNOV0ol000000oo?f=oo0000ol;Ci`04ol;Ci`?o[LS^0ol00002ohnf
l@CoJIc^0ol00003of>9hP03o`000?mEN=WoEGSI00;oEGSI00Oo0000odm^d_m?K];oCfkBo`000?me
P];o000000KoNH3>00?o0000ogn1bomoPL/00omoPL/00on8Q/[o0000oj2Hc004oj2Hc003o`000?nY
W<[oZIc:00CoZIc:00?o0000ok:Rb?nbX/P00_nbX/P2o`0000?oakO:00?o0000oljkaoo>^lL00_o>
^lL01Ol0003oe;k5omBnaOoD_/Go000000;ofL;200?o0000omg8a?l000000_oPb<400ol0003ohLRn
o`000002on;:_`04o`000?oSb;go0000on?9_P;o000000Koh/Rno`000?oRakko0000omg5`Ol00002
omg4`004o`000?oF_l?oe[o3o`0000;oc;S72Ol000000on`YLco0000oj2Ic@04oj2Ic@05o`000?n?
SLgoShg=ohn=cOl000001On0P/`2og=jb`04o`000?m;Jm7oBf_Ao`0000?o?VC@00Go0000ocUSd?li
Hm3o04g<o`000002o`EGd@03o`000?lMJMco7FWL00Co@8?X2_l00005ojk7k003o`000?o3d>Co`m3T
00;o`m3T00?o0000om7Eg?oAeM`01?oAeM`00ol0003of]SEom[He@02om[He@03o`000?oNf=7og]SA
00;og]SA00?o0000on3/f_l000000ooRk=P00ol0003oooooooooo`07ooooo`Co00005_ooool00ol0
003oooooooooo`0:ooooo`006oooool2o`0003Wooooo00?o0000omSXh?oHj>000_oHj>000ol0003o
e^WRomKYhP02omKYhP04o`000?oAinKodNOVom7WiP;o00001?o?f=l00ol0003o`]?Wol;Ci`02ol;C
i`?o00000_n]b>h01?l0003oSkKaohnflOn?]_44ofVLkP;oA7oT0_l000000omSRN;o0000oeEhf@03
oeEhf@03o`000?m?K];oCfkB00;oCfkB0_l00005ogV0cP03o`000?moPL_oOh7;00?oOh7;00Co0000
ohR6b_n8Q/[o00000onPV<`00ol0003oZIc:ojVLbP04ojVLbP03o`000?nbX/So/Z;800?o/Z;800Go
0000ok^Yaol0003oakO:o`000005oljka`04o`000?oD_/Goe;k5o`0000CofL;200Co0000on38`OoP
b<7o00000_oQb;h02ol0003oh/Zoo`000?l0003ohlRmo`000?oSbKko0000on;8__l0003oh/Nn00?o
00000_oMa<000ol0003oe[o3o`000004o`0000;ockS300Go0000olF`aOo5/<GoaK35o`000002okZW
a`?o00001?nPVLd01Ol0003oShg=ohn=cOn?SLgo000000GoP8;<0omcN//00ol0003oBf_Ao`000003
ociTd005o`000?liHm3o>F?@ocUSd?l000000ol5Em400ol0003o7FWLoaeYg003od23j0GoJ9o`1?n?
]_400ol0003o[/O/ojk7k003ojk7k003o`000?o3d>Co`m3T00?o`m3T00?o0000om7Eg?oAeM`00ooA
eM`2o`0000Cof]SE00Co0000omkHdOoNf=7o00000_oPk=X01Ol0003oh^cHon;/f?oRk=So000000Ko
oooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo
00?o0000omSXh?oHj>000_oHj>000ol0003oe^WRomKYhP02omKYhPCo000000?oem[Jo`000?o?f=l0
0oo?f=l00ol0003o`]?Wo`000003o`0000Co[LS^00Go0000ohnflOn?]_7oSkKao`000004ofVLkP?o
A7oT0_l00004oeEhf@03o`000?m?K];oCfkB00;oCfkB0_m@J/h00ol0003oNH3>ogV0cP02ogV0cP03
o`000?moPL_oOh7;00?oOh7;00Oo0000ohR6b_n8Q/[oR8K:o`000?nPV<co000000KoZIc:00?o0000
ok:Rb?nbX/P00onbX/P01?l0003o^jW7ok^YaonkZLL2o`0000Coc[_700Go0000omBnaOoD_/Goe;k5
o`000004omW2`P;o000000?oh<S1o`000?oQb;h00_oQb;h01Ol0003ohlRmo`000?l0003ohlVn00?o
000000Coh/Nno`000?oQakgo00000ooMa<02o`0000;of;o100Go0000olnh`oo?^<?ockS3o`000003
olF`a@03o`000?njYlOo^ZO700;o^ZO700?o0000ojjNaol000000ol00004ohn=c@03o`000?n0P/co
P8;<00;oP8;<00?o0000og=jbomcN//00_mcN//00om;Jm7o0000ociTd002ociTd003o`000?liHm3o
>F?@00;o>F?@0_l000001Ol5Em7o0000oaeYg?lMJMco000000?o@8?X1OmXWo04ohnfl@03o`000?n^
anco[/O/00?o[/O/00?o0000ol?@i?o3d>@00_o3d>@00ol0003odMGLom7Eg004om7Eg003o`000?oJ
f=Gof]SE00;of]SE00?o0000omkHdOl000000ooPk=X01Ol0003oh^cHon;/f?oRk=So000000?ooooo
0ol0000Mooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o
0000omSXh?oHj>000_oHj>001?l0003oe^WRomKYh_oFjN82o`0000Goem[J00?o0000oloHgoo?f=l0
0ol00004ol;Ci`03o`000?n]b>ko[LS^00;o[LS^00Co0000ohnflOn?]_7o00001?mYW>h01?l0003o
A7oTodAoi?m4On@2o`0000?oEGSI00?o0000odm^d_m?K]800_m?K]83oe1ZcP04o`000?miP<koNH3>
o`0000GoOh7;00?o0000ohR6b_n8Q/X00on8Q/X2o`0000KoZIc:00?o0000ok:Rb?nbX/P00_nbX/P0
0ol0003o^jW7ok^Ya`02ok^Ya`06o`000?o4/<Ko0000o`000?o>^lOo00000ooD_/D00ol0003ofL;2
omW2`P02omW2`P04o`000?oMa<3ogLC0o`0000CohLRn00?o0000on?8_Ol000000ol000002_oRb;ko
0000o`000?oQakgohLJmo`000?oMa<3o0000omk3_ol00002omRo`@03o`000?o?^<?ockS300;ockS3
00Go0000olF`aOo5/<GoaK35o`000003okZWa`03o`000?n^W/Oo[Yk700?o[Yk70_l00003ohn=c@03
o`000?n0P/coP8;<00;oP8;<00?o0000og=jbomcN//00omcN//2o`0000?o?VC@00Co0000ocUSd?li
Hm3o>F?@0_lkJ=@00ol0003o1EOAo`000002oaeYg004o`000?m0PnSo@8?Xo`0000CoJ9o`00Go0000
ohnflOn?]_7oSkKao`000005ojk7k003o`000?o3d>Co`m3T00?o`m3T00?o0000om7Eg?oAeM`00ooA
eM`2o`0000?of]SE0_l00004on3/fP04o`000?oRk=Soh^cHon;/f0Co00008?ooool00ol0003ooooo
ooooo`0:ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`000?oHj>3of>SP00;of>SP00Ko
0000omKYh_l0003o0000om_Ke_l00005omOJfP?o00000_o?f=l00ol0003o`]?Wol;Ci`02ol;Ci`03
o`000?n]b>ko[LS^00;o[LS^00Go0000ohnflOn?]_7oSkKao`000003ofVLkP04o`000?m4OnCoA7oT
odAoi0;o9FGH00Co0000oeEhfOmEN=Wo00001?m?K]801ol0003oD6[>oe1Zc_m@J/ko0000ogV0c_l0
00001OmoPL/00ol0003oR8K:ohR6bP03ohR6bP;oU8g90_l00003ojVLbP03o`000?nbX/So/Z;800?o
/Z;800Go0000ok^YaonkZLOo^jW7o`000004olB`aP;o00000ooD_/D01Ol0003ofL;2omW2`_oI`/;o
000000?ogLC000Co0000on78__oQb;kohLRn0_l000000ooSb;go0000o`000005o`0000;ohLJm0_l0
0002omk3_`04o`000?oH_l7of;o1o`0000?ockS300?o0000olF`aOo5/<D00_o5/<D01Ol0003o^ZO7
okZWaonjYlOo000000Go[Yk700?o0000oj:Faol000000_l00005oh22c003o`000?mcN/_oLg[;00?o
Lg[;0_mZML`01?l0003o?VC@ociTd?l00003ocUSd005o`000?lkJ=Co>fSDoc]Xe?l000000_lMJM`0
1Ol0003o@8?Xod23j?m0PnSo000000CoJ9o`00Go0000ohnflOn?]_7oSkKao`000005ojk7k003o`00
0?o3d>Co`m3T00;o`m3T00?o0000om7Eg?oAeM`01?oAeM`2o`000004om[HeOl0003ofn[No`0000Co
h>cJ00Go0000on;/f?oRk=Soh^cHo`00000Sooooo`03o`000?oooooooooo00[ooooo000Jooooo`?o
0000>Oooool00ol0003of>SPomSXh002omSXh0;o00001?oKfmH00ol0003oem[JomOJfP03o`0000Co
cmSO00?o0000ol;Cioo2dnL00oo2dnL01Ol0003o[LS^ojg8k_n]b>ko000000?oSkKa00?o0000ofVL
k_mYW>h00_mYW>h01?l0003oA7oTodAoi?l00002obEUf0;o00001Om?K]800ol0003oD6[>oe1ZcP02
oe1ZcP03o`000?moPL_oOh7;00?oOh7;00?o0000ohR6b_n8Q/X00on8Q/X00ol0003oU8g9oiB=b@02
oiB=b@03o`000?nYW<[o000000Go/Z;800?o0000ok^YaonkZLL00_nkZLL00ol0003oa;36olB`aP02
olB`aP05o`000?o=]/Co0000omBnaOl000001?oI`/802?l0003ogLC0omg4`?l0003oh<Jno`000?oQ
b;ko00000_oSakd4o`000003on?7_?l0003o000000?ohLJm00Co0000omk3_ooN`koo00000ooH_l40
1Ol0003ockS3olnh`oo?^<?o000000?oaK3500?o0000okZWaonjYlL00_njYlL00ol0003o[Yk7ojjN
a`02ojjNa`03o`000?nRU/OoXYK700;oXYK70_l00004oh22c003o`000?mcN/_oLg[;00;oLg[;00Oo
0000ofYec?mZMLcoJWG<o`000?lnI=3o000000?o>F?@00?o0000oc]Xe?lkJ=@00_lkJ=@2o`000005
oaeYg?l0003o@8?Xod23j?l000001?mXWo000ol0003oSkKaohnfl@02ohnfl@03o`000?n^anco[/O/
00;o[/O/00?o0000ol?@i?o3d>@00oo3d>@00ol0003odMGLom7Eg003om7Eg003o`000?oJf=Go0000
00;ofn[N00?o0000on3/f_oPk=X00_oPk=X01Ol0003oh^cHon;/f?oRk=So000002Cooooo00?o0000
ooooooooool02Oooool001[ooooo00?o0000ooooooooool0>Oooool01?l0003of>SPomSXh?oHj>02
o`0000Gofm_F0ol00003omOJfP03o`000?o?f=oocmSO00;ocmSO00?o0000ol;Cioo2dnL00_o2dnL0
0ol0003o[LS^ojg8kP02ojg8kP04o`000?n?]_7oSkKao`0000CoJIc^00Co0000odAoi?m4OnCoA7oT
0olUIMP2o`0000?oCfkB00?o0000oe1Zc_m@J/h00om@J/h00omHK<go0000ogn1b`03ogn1b`03o`00
0?n8Q/[oR8K:00?oR8K:00?o0000oiB=bOnDSLT00onDSLT2o`0000Co/Z;800?o0000ok^YaonkZLL0
0_nkZLL00ol0003oa;36olB`aP02olB`aP04o`000?o=]/CocKK4olffa0?o00000_oI`/801Ol0003o
gLC0omg4`?oMa<3o000000;oh<Jn00Co0000on?7_OoSakgohlNm1_l00002on76_@03o`000?oQa[go
000000;og/>o00Co0000omRo`OoH_l7o00001?o?^<<01Ol0003oaK35olF`aOo5/<Go000000?o^ZO7
00?o0000ojjNaon^W/L00on^W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nGS/So000000?oP8;<
00?o0000og=jbomcN//00_mcN//00ol0003oJWG<ofYec002ofYec003ociTd?l0003o>F?@00;o>F?@
00?o0000oc]Xe?lkJ=@00_lkJ=@2odIdf`03o`000?lMJMco000000;o@8?X00?o0000ofROl?mXWo00
0_mXWo001Ol0003oSkKaohnflOn?]_7o000000Co[/O/00?o0000ol?@i?o3d>@00oo3d>@00ol0003o
dMGLom7Eg003om7Eg0?o00000_oKj]h00ol0003oh>cJon3/fP02on3/fP05o`000?oRk=Soh^cHon;/
f?l000009?ooool00ol0003oooooooooo`09ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Wooooo00Ko0000
omSXh?l0003o0000omcJe?l00002om_KePCo00001OoGf]X00ol0003ocmSOoloHg`02oloHg`03o`00
0?o2dnOo`]?W00?o`]?W00Go0000ojg8k_n]b>ko[LS^o`000003ohnfl@05o`000?mYW>koJIc^ofVL
k_l000000om4On@00ol0003o9FGHobEUf002oa9CcP04o`000?m?K];oCfkBo`0000GoD6[>0_mHK<d0
1?l0003oOh7;ogn1bol00006ohR6bP03o`000?nDSLWoU8g900?oU8g90_nQU/T01Ol0003o/Z;8ok:R
b?nbX/So000000Co^jW700?o0000olB`a_o4/<H00_o4/<H01Ol0003ocKK4olffa?o=]/Co000000;o
e;c20ol00002omg4`004o`000?oPa[koh<Jnon36_P;o000000?ohlNmo`000?l000001_l00002on76
_@03o`000?oN`koo000000_o00000_o5/<D01Ol0003o^ZO7okZWaonjYlOo000000Co[Yk700?o0000
oj:FaonRU/L00_nRU/L01ol0003oUhk8oiN>b?nGS/So0000oh22c?l000001OmcN//00ol0003oJWG<
ofYec003ofYec0;o00000oliHm001Ol0003o>fSDoc]Xe?lkJ=Co000000?oAWCK00Go0000od23j?m0
PnSo@8?Xo`000003ofROl003o`000?n?]_7oSkKa00;oSkKa00?o0000ojk7k?n^an`00_n^an`00ol0
003o`m3Tol?@i003ol?@i003o`000?oAeMcodMGL00;o000000KodNGUo`000?oKj]ko0000om_Zg_l0
0004on3/fP05o`000?oRk=Soh^cHon;/f?l000009?ooool00ol0003oooooooooo`09ooooo`0000Co
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0iooooo`;o00000ooLf]@3o`0000Cofm_F00?o0000omOJf_oGf]X00_oGf]X00ol0003ocmSO
oloHg`02oloHg`03o`000?o2dnOo`]?W00?o`]?W00Go0000ojg8k_n]b>ko[LS^o`000003ohnfl@03
o`000?mYW>koJIc^00;oJIc^00Co0000odAoi?m4OnCo00000_lUIMP01_l0003o4U?>oa9Cc_l0003o
CfkBo`0000CoD6[>00Oo0000oeQ/cOmHK<goF6c=o`000?moPL_o000000GoR8K:00?o0000oiB=bOnD
SLT00onDSLT01ol0003oXIK9oj6FbOnQU/Wo0000ok:Rb?l000001?nkZLL00ol0003oa;36olB`aP02
olB`aP05o`000?o=]/CocKK4olffa?l000001?oD_<801Ol0003of/70o`000?oMa<3o000000;oh<Jn
00Go0000on;7_OoRakgo0000on?7_006o`0000?ohLJm0_l00002omo4_P04o`000?oJ`L3of/70o`00
00?oe;c200?o0000olffa?o=]/@00ol00003okZWa`03o`000?n^W/Oo[Yk700;o[Yk700?o0000oj:F
aonRU/L00_nRU/L00ol0003oUhk8oiN>b002oiN>b0;o00001?mcN//00ol0003oJWG<ofYec004ofYe
c0;oI7C>00Co0000ocUSd?liHm3o00000olkJ=@00ol0003oAWCKodIdf`02odIdf`;o000000?o@8?X
o`000?mXWo000omXWo001Ol0003oSkKaohnflOn?]_7o000000Co[/O/00?o0000ol?@i?o3d>@00oo3
d>@00ol0003odMGLo`000003om7Ui@03o`000?oKj]kofn[N00;o00001?oPk=X01Ol0003oh^cHon;/
f?oRk=So000002Cooooo00?o0000ooooooooool02Oooool000?ooooo00?o410@ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Wooooo00?o0000omcJe?l000000_l0
00000ooLf]Co0000om_KeP04om_KeP03o`000?oGf][oem[J00?oem[J00?o0000oloHgoo?f=l00_o?
f=l00ol0003o`]?Wol;Ci`02ol;Ci`03o`000?n]b>ko[LS^00Ko00001?mYW>h01Ol0003oA7oTodAo
i?m4OnCo000000;o9FGH0olBDlh2o`0000CoD6[>00?o0000oeQ/cOmHK<d00_mHK<d2o`0000GoR8K:
00?o0000oiB=bOnDSLT00onDSLT00ol0003oXIK9oj6Fb@02oj6Fb@;o00001?nkZLL01Ol0003oa;36
olB`a_o4/<Ko000000CocKK400Go0000omBl`_oD_<;oe;c2o`000003om[1`0Ko000000?oh/Nmo`00
0?l000001ol00002on;6_@04o`000?oOa;koglBno`0000;of/7000Go0000omBl`_oD_<;oe;c2o`00
0004olffa003o`000?o4[lGo000000;o00001On^W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nG
S/SoUhk800?oUhk80_l00003og=jb`03o`000?mZMLcoJWG<00?oJWG<00Oo0000ofAdc_mTM<koI7C>
o`000?liHm3o000000?o>fSD00?o0000odIdfom6M=/00_m6M=/2oeV7h`03o`000?m0PnSo000000?o
J9o`00?o0000ohnflOn?]_400_n?]_400ol0003o[/O/ojk7k002ojk7k003o`000?o3d>Co`m3T00;o
`m3T0_l00004om7Ui@05o`000?oKj]kofn[Nom_Zg_l000001?oPk=X01Ol0003oh^cHon;/f?oRk=So
000002Cooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool03Oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Sooooo0ol00004omcJe003o`000?oKfmKofm_F
00?ofm_F00?o0000omOJf_oGf]X00ooGf]X00ol0003ocmSOoloHg`02oloHg`03o`000?o2dnOo`]?W
00;o`]?W0ol00002ojo3j@03o`000?n>]_7oS[Ka00Ko00000om4On@01?l0003o9FGHobEUf?l00003
oa9CcP03o`000?m@J/koD6[>00;oD6[>00?o0000oeQ/cOmHK<d00_mHK<d2ofEcc@05o`000?n8Q/[o
R8K:ohR6b_l000001OnDSLT00ol0003oXIK9oj6Fb@03oj6Fb@03o`000?n^WlSo000000;o^jW700?o
0000olB`a_o4/<H00_o4/<H01Ol0003ocKK4olffa?o=]/Co000000Coe;c200Go0000om[1`?oJ`L3o
f/70o`000002omo4_P03o`000?oRa[goh/Jm00Oo000000GohlNlo`000?oRa[goh/Jmo`000003omo4
_P04o`000?oJ`L3of/70o`0000?oe;c200Go0000olffa?o=]/CocKK4o`000004olB_a@;o00000on^
W/L00ol0003oXYK7oj:Fa`02oj:Fa`03o`000?nGS/SoUhk800CoUhk800?o0000ohj8b?l000000_mc
N//00ol0003oJWG<ofYec003ofYec003o`000?mTM<koI7C>00;oI7C>00?o>F?@o`000?lkJ=@00_lk
J=@00ol0003oAWCKodIdf`02odIdf`05o`000?mIQn?oFHOSoeV7hol000001?mXWo000ol0003oSkKa
ohnfl@02ohnfl@06o`000?n^anco[/O/ojk7k?l0003o`m3T0ol000000oo1fngo0000om7Ui@03om7U
i@05o`000?oKj]kofn[Nom_Zg_l000001?oPk=X01Ol0003oh^cHon;/f?oRk=So000002Cooooo00?o
0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool00ol0003og=[DomcJe003omcJe003o`000?oK
fmKofm_F00?ofm_F00?o0000omOJf_oGf]X00_oGf]X00ol0003ocmSOoloHg`02oloHg`03o`000?o2
dnOo000000;o000000?o`lWOo`000?n_`nT00on_`nT01?l0003oS[KaohjflOl00003oebLlP?o0000
00GoA7oTo`000?lUIMSo9FGHo`000003oa9CcP03o`i<b?l0003oD6[>00;oD6[>00?o0000oeQ/cOmH
K<d00_mHK<d3ofEcc@04o`000?n8Q/[oR8K:o`0000GoU8g900?o0000oj6FbOnQU/T00_nQU/T01ol0
003o[Yo8ojjOb?n^WlSo0000ok^Yaol000000oo4/<H00ol0003ocKK4olffa002olffa005o`000?oD
_<;oe;c2omBl`_l000000ooJ`L001Ol0003oglBnomo4__oOa;ko000000;oh/Jm00?o0000on?7_?l0
00001ol000001OoRa[go0000omo4__oOa;ko000000;of/7000?o0000omBl`_oD_<800_oD_<801Ol0
003ocKK4olffa?o=]/Co000000Coa:o500Ko0000ok^Xa_l0003o0000ojjNaol00004oj:Fa`03o`00
0?nGS/SoUhk800?oUhk800Co0000ohj8b?n>R<SoSXS80_l00006ofYec003o`000?mTM<koI7C>00?o
I7C>0_l00003oc]Xe005o`000?m6M=_oAWCKodIdfol000001?mIQn<5o`0000CoSkKa00?o0000ojk7
k?n^an`00ol00004ol7Kk@03o`000?oAiNGodNGU00;odNGU00Co0000om_Zg_oKj]kofn[N0_l00003
on3/fP05o`000?oRk=Soh^cHon;/f?l000009?ooool00ol0003oooooooooo`09ooooo`000oooool0
0ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool3
o`0000Gooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_Fom_KeP03om_KeP03o`000?oGf][o
em[J00?oem[J00Co0000oloHgoo?f=oocmSO0_l00005ol?9g`03o`000?n_`nWo[l?Y00;o[l?Y00Co
0000ohjflOn>]_7o00000omLW?801Ol0003o7gKSo`000?m4OnCo000000;o9FGH00Ko0000oa9Cc_lB
Dlko0000o`i<b?l00002oe1ZcP03o`000?mHK<goF6c=00;oF6c=00Oo0000ofEccOmULlgoIG?=o`00
0?n8Q/[o000000CoU8g900?o0000oj6FbOnQU/T00onQU/T00ol0003o[Yo8ojjOb002ojjOb0?o0000
0_o4/<H01Ol0003ocKK4olffa?o=]/Co000000?oe;c200?o0000om[1`?oJ`L000_oJ`L001Ol0003o
glBnomo4__l0003oh/Jm00Go000000GohlNlo`000?l0003ohlNlo`000002on;7_@?o000000GoglBn
o`000?oJ`L3of/70o`000003omBl`P05o`000?o=]/CocKK4olffa?l000001?o4[lD00ol0003o^jS6
ok^XaP02ok^XaP;o00000onRU/L00ol0003oUhk8oiN>b004oiN>b003o`000?n>R<SoSXS800;oSXS8
0_l00004ofYec003o`000?mTM<koI7C>00CoI7C>0_mSMm401?l0003o>fSDoc]Xe?l00003odIdf`03
o`000?mIQn?oFHOS00;oFHOS1?mcW^`8o`0000;oZlca00?o0000ol7KkOo1fnd00_o1fnd00ol0003o
dNGUom7Ui@02om7Ui@07o`000?oKj]kofn[Nom_Zg_l0003oh>cJo`000002on3/fP03o`000?oRk=So
h^cH00;o00009Oooool00ol0003oooooooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo0ol00008ooooo`03o`000?oLf]Co
g=[D00?og=[D00?o0000om_Ke_oKfmH00ooKfmH00ol0003oem[JomOJfP03omOJfP06o`000?o?f=oo
cmSOo`000?o>bmOo00001_o3bMl00ol0003o[l?Yojo3j@02ojo3j@04o`000?n>]_7oS[Kao`0000?o
G9cb00?o0000oamfholOM^<00_l000000olUIMSo0000oa9CcP02oa9CcP;o3Tc80_l00005oeQ/c@03
o`000?mULlgoIG?=00;oIG?=0_l00004oiB=b@03o`000?nQU/WoXIK900?oXIK900?o0000ojjOb?n^
WlP00_n^WlP00ol0003o^ZS7okZXa`04o`0000;ocKK400Go0000omBl`_oD_<;oe;c2o`000004om[1
`0Go00000_oRa[d2o`000005on?7_?l0003o0000on?7_?l000000ooRakd00ol0003oh<Jnon36_P03
o`000003om[1`?l0003oe;c200;oe;c200Go0000olffa?o=]/CocKK4o`000004olB_a@03o`000?nk
Z<Ko^jS600;o^jS600?o0000ok:Raol000000_nRU/L00ol0003oUhk8oiN>b003oiN>b003o`000?n>
R<SoSXS800?oSXS800?o0000ohN4bOl000000omZML`00ol0003oI7C>ofAdcP03ofAdcP07o`000?mS
Mm7oHgOAof=gdOl0003o>fSDo`000003odIdf`03o`000?mIQn?oFHOS00;oFHOS00?o0000og>Nk?mc
W^`00_mcW^`5ohnfl@05o`000?n[c?7oZlcaoj_<lOl000001?o1fnd00ol0003odNGUom7Ui@02om7U
i@05o`000?oKj]kofn[Nom_Zg_l000000_oPk=X01ol0003oh>cJo`000?oRk=So0000omKihOl00000
9Oooool00ol0003oooooooooo`08ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo
00?o0000ooooooooool0;Oooool3o`0000cooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_F
om_KeP03om_KeP03o`000?oGf][oem[J00;oem[J00?o0000oloHgol000000oo>bmL00ol0003o`lWO
ol?9g`04ol?9g`05o`000?n_`nWo[l?Yojo3jOl000000on>]_401_l0003oG9cboebLl_mLW?;o0000
oamfh`;o04g:0_l00003oa9CcP03o`000?l>C<So3Tc800;o00000omHK<d00ol0003oIG?=ofEcc@03
ofEcc@;oMWk>00Co0000oiB=bOnDSLWo00001OnQU/T00ol0003o[Yo8ojjOb002ojjOb003o`000?nj
Z<Oo^ZS700;o^ZS700?o0000olJaa_o6/LH03?l00002omk4_`03o`000?oRa[go000000;o000000?o
hlNlo`000?l000000ol00002on;7_@05o`000?oPa[koh<Jnon36__l000000_oMa<03o`0000;oe;c2
00Go0000olffa?o=]/CocKK4o`000003olB_a@03o`000?nkZ<Ko^jS600;o^jS600Oo0000ok:Raonb
X/Oo/Z;7o`000?nRU/Oo000000CoUhk800?o0000ohj8b?n>R<P00on>R<P01Ol0003oQhC9ohN4bOn7
Q<Wo000000;oJWG<00?o0000ofAdc_mTM<h00omTM<h00ol0003oHgOAof=gd@02of=gd@03oc]Xe?l0
003oAWCK00;oAWCK00?o0000oeV7homIQn<00_mIQn<00ol0003oLik/og>Nk002og>Nk003o`000?n?
]_7oSkKa00;oSkKa00Go0000oj_<lOn[c?7oZlcao`000004ol7Kk@03o`000?oAiNGodNGU00;odNGU
00Go0000om_Zg_oKj]kofn[No`000002on3/fP06o`000?oPk=[o0000o`000?oFnN7o00009_ooool0
0ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0Zooooo`?o00003oooool00ol0
003og=[DomcJe003omcJe003o`000?oKfmKofm_F00?ofm_F00?o0000omOJf_oGf]X00_oGf]X2o`00
00Goc/_G00?o0000ol?9goo3bMl00oo3bMl00ol0003o[l?Yojo3j@02ojo3j@05o`000?n>]_7oS[Ka
ohjflOl000000omLW?801_l0003o7gKSo`1=b_l0CL[o9FGHo`0000;o4U?>00?o0000o`i<b?l>C<P0
0_lFClT01?l0003oF6c=oeQ/cOl00005ofEcc@?oMWk>00?o0000oiB=bOl000001OnQU/T00ol0003o
[Yo8ojjOb002ojjOb005o`000?njZ<Oo^ZS7okZXaol000001?o6/LH01Ol0003od;W4om2ia?o@^LCo
000000Cof;o100Co0000omk4_ooNa;oog/Bo0_l000000ooQa[go0000on?7_005o`000004on?7_Ol0
003oh/Nmo`0000;oh<Jn00Go0000omg4`?oMa<3ogLC0o`000002omW1`P?o00000_o=]/@01Ol0003o
a:o5olB_aOo4[lGo000000Co^jS600?o0000ok:RaonbX/L00onbX/L2o`0000CoUhk800?o0000ohj8
b?n>R<P00_n>R<P00ol0003oQhC9ohN4b@03ohN4b@;o00001OmTM<h00ol0003oHgOAof=gd@04of=g
d@;o00000_m6M=/00ol0003oFHOSoeV7h`02oeV7h`03o`000?mcW^coLik/00;oLik/00?o0000ohnf
lOn?]_400_n?]_401Ol0003oZlcaoj_<lOn[c?7o000000Co`M_]00?o0000om7UiOoAiND00_oAiND0
1Ol0003ofn[Nom_Zg_oKj]ko000000?oh>cJ0_l00002omKih@03o`000?oooooooooo02Cooooo00?o
0000ooooooooool02?ooool001Wooooo0_l0000Xooooo`?o00004_ooool00ol0003og=[DomcJe004
omcJe003o`000?oKfmKofm_F00;ofm_F00?o0000omOJf_oGf]X00_l000000ooDbm7o0000olk;e`05
olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o0000ojo3jOn_`nT00_n_`nT01Ol0003oS[KaohjflOn>
]_7o000000?oG9cb00Co0000oamfhol0CL[o04g:0_l000001OlBDlko0000o`i<b?l>C<So000000;o
5To900?o0000oeQ/cOl000001?mULld00ol0003oMWk>ogIncP02ogIncP;o00001?nQU/T00ol0003o
[Yo8ojjOb002ojjOb003o`000?njZ<Oo^ZS700;o^ZS700?o0000olJaa_o6/LH00_o6/LH01Ol0003o
d;W4om2ia?o@^LCo000000?of;o100Co0000omk4_ooNa;oog/Bo0_l000000ooQa[go0000o`000006
o`0000;ohlNm00Co0000on36__oPa[ko00000ooMa<000ol0003ofL72omW1`P02omW1`P05o`000?oD
_/Go0000olffa?l000000oo4[lD00ol0003o^jS6ok^XaP02ok^XaP03o`000?nbX/Oo/Z;700?o/Z;7
00?o0000ojZLb?l000000_nGS/P00ol0003oSXS8ohj8b003ohj8b003o`000?n7Q<WoQhC900CoQhC9
00?o0000ofAdc_mTM<h00omTM<h00ol0003oHgOAof=gd@04of=gd@;oIgoG00?o0000odIdfol00000
1?mIQn<00ol0003oLik/og>Nk002og>Nk003o`000?n?]_7oSkKa00;oSkKa00Go0000oj_<lOn[c?7o
Zlcao`000004ol7Kk@03o`000?oAiNGodNGU00;odNGU00Ko0000om_Zg_oKj]kofn[No`000?oPk=X2
o`000004om?ihol0003oe_WQo`0002Oooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000
ooooooooool09?ooool3o`0001Kooooo00?o0000omcJe?oLf]@00ooLf]@00ol0003ofm_Fom_KeP03
om_KeP;o00001?oDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3bMoo`lWO00Co`lWO00?o0000
ojo3jOn_`nT00_n_`nT01Ol0003oS[KaohjflOn>]_7o000000;oG9cb00Co0000oamfholOM^?o04g:
0_l0;k<2o`0000?o3Tc80olFClT2o`0000CoIG?=00?o0000ogInc_mfO/h00_mfO/h2ohZ;c`;o0000
0_nQU/T00ol0003o[Yo8ojjOb002ojjOb003o`000?njZ<Oo^ZS700;o^ZS700Go0000olJaa_o6/LKo
a[76o`000003om2ia003o`000?oH_l7of;o100;of;o100?o0000omk4_ooNa;l00_l000001OoQa[go
0000on77_Ol0003ohlNl00;o000000?ohlRmo`000?l000000_oSakd2o`000003on36__l0003ogLC0
00;ogLC000Go0000omW1`_oI`L;ofL72o`000003omBna@;o00000_o4[lD00ol0003o^jS6ok^XaP02
ok^XaP03o`000?nbX/Oo/Z;700?o/Z;700Oo0000ojZLb?nZW<SoZYc8o`000?nGS/So000000CoSXS8
00?o0000ohN4bOn7Q<T01On7Q<T2o`0000CoI7C>00?o0000of=gdOmSMm400omSMm401_l0003oIgoG
ofMoeomWOmOoAWCKo`0000CoFHOS00?o0000og>Nk?mcW^`00_mcW^`00ol0003oSkKaohnfl@02ohnf
l@05o`000?n[c?7oZlcaoj_<lOl000001?o1fnd00ol0003odNGUom7Ui@02om7Ui@04o`000?oKj]ko
fn[Nom_ZgP;o00000_oCnN<01?l0003oe_WQo`000?l0000Wooooo`03o`000?oooooooooo00Sooooo
000Hooooo`03o`000?oooooooooo02;ooooo0ol0000Iooooo`03o`000?oLf]Cog=[D00?og=[D00?o
0000om_Ke_oKfmH00ooKfmH00ol0003oe<_AomC;d@04omC;d@03o`000?o>bmOoc/_G00?oc/_G00?o
0000ol?9goo3bMl01?o3bMl01Ol0003o[l?Yojo3jOn_`nWo000000CoS[Ka00Co0000oebLl_mLW?;o
00000_lOM^<01Ol0CL[o02nco`0_/olBDlko000000;o3Tc800Go0000oaI?bOlFClWo5To9o`000004
ofEcc@03o`000?mfO/koMWk>00;oMWk>1?n:Rll00ol0003oXIK9o`000004ojjOb005o`000?njZ<Oo
^ZS7okZXaol000001?o6/LH01Ol0003od;W4om2ia?o@^LCo000000Cof;o10ol000000ooMa<3o0000
o`000002on77_@Co000000?ohlRmo`000?oSb;d00_l00002on78_P;o00000_oMa<001Ol0003ofL72
omW1`_oI`L;o000000Coe;k500Go0000oljjaol0003oa:o5o`000003ok^XaP03o`000?nbX/Oo/Z;7
00?o/Z;700?o0000ojZLb?nZW<P00onZW<P00ol0003oSXS8ohj8b002ohj8b003o`000?n7Q<WoQhC9
00GoQhC900Co0000oh:3c?n2Plco00000_mTM<h00ol0003oHgOAof=gd@04of=gd@03o`000?mWOmOo
IgoG00;oIgoG0_l00003oeV7h`03o`000?mcW^coLik/00;oLik/00?o0000ohnflOn?]_400_n?]_40
0ol0003oZlcaoj_<l@02oj_<l@05o`000?o1fngo`M_]ol7KkOl000001?oAiND00ol0003ofn[Nom_Z
gP02o`0000?odoWS00?o0000omKihOl00000:?ooool00ol0003oooooooooo`08ooooo`006?ooool0
0ol0003oooooooooo`0Pooooo`;o00007?ooool00ol0003og=[DomcJe004omcJe004o`000?oKfmKo
fm_Fom_KeP;o00001ooDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o
0000ojo3jOn_`nT00_n_`nT00ol0003oS[Kaohjfl@02ohjfl@07o`000?mLW?;oG9cbo`000?lOM^?o
0000o`1=bP02o`0_/`04o`000?l>C<So3Tc8o`0000?o5To900?o:U_>o`000?mULld00_mULld00ol0
003oMWk>ogIncP02ogIncP03o`000?n:RlooRX_?00;oRX_?0_l00003ojjOb003o`000?njZ<Oo^ZS7
00;o^ZS700?o0000olJaa_o6/LH00_o6/LH01Ol0003od;W4om2ia?o@^LCo000000;of;o10_l00003
omg4`0;o00000_oQakd00ol0003oh/Nno`000002o`000004on?8_Ol0003ohlRmo`0000?ohLRn00Go
0000on38`Ol0003ogLC0o`000003omW1`P05o`000?oD_/Goe;k5omBnaOl000000oo>^/L2o`0000?o
^jS600?o0000ok:RaonbX/L00_nbX/L00ol0003oZYc8ojZLb004ojZLb0;o00000on>R<P00ol0003o
QhC9ohN4b@04ohN4b@03o`000?n2PlcoPX?<00;oPX?<00?o0000ofAdc_l000001OmSMm400ol0003o
IgoGofMoe`03ofMoe`;oL8gO0_l000000omIQn?o0000og>Nk003og>Nk003o`000?n?]_7oSkKa00;o
SkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1fngo000000CodNGU00Go0000om_Z
g_l0003oc_OXo`000002om?ih`03o`000?oFnN7oe_WQ00;o0000:?ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Mooooo`?o00007oooool00ol0003og=[DomcJe003omcJ
e004o`000?oKfmKofm_Fo`0000;of<_=00?o0000omC;dOoDbm401OoDbm400ol0003oc/_Golk;e`03
olk;e`03o`000?o3bMoo`lWO00?o`lWO00?o0000ojo3jOn_`nT00_n_`nT00ol0003oS[Kaohjfl@06
o`000008oamfhol0003o04g:o`0_/ol08JSo0000o`i<b?l00003oaI?b@03o`000?lZFlko000000;o
IG?=00?o0000ogInc_mfO/h00_mfO/h00ol0003oRX_?ohZ;c`02ohZ;c`;oWIW?0_l000000on^WlSo
0000okZXa`03okZXa`03o`000?o6/LKoa[7600;oa[7600?o0000om2ia?o@^L@01?l000001?oG_l?o
0000omg4`?oMa<02o`0000;ohLNm00Co0000on;7__l0003ohlRn0ol000000ooSb;go0000o`000002
on78_P05o`000?oPb<7oh<S1on38`Ol000000ooI`L801Ol0003oe;k5omBnaOoD_/Go000000Coc[[7
00Go0000olNfb_l0003o^jS6o`000004ok:Ra`03o`000?nZW<SoZYc800CoZYc800Ko0000oj:Gb_nR
Ul[o0000ohj8b?l00006ohN4b@03o`000?n2PlcoPX?<00CoPX?<0_l00005of=gd@03o`000?mWOmOo
IgoG00;oIgoG00?o0000og2=gom`SMl00_m`SMl00omIQn?o0000og>Nk003og>Nk003o`000?n?]_7o
SkKa00;oSkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1fngo000000CodNGU0_l0
00000oo>mnSo0000om?ih`02om?ih`03o`000?oFnN7o000000;ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`07ooooo`006?ooool2o`0001_ooooo0ol0000Rooooo`03o`000?oLf]Co
g=[D00?og=[D00?o0000om_Ke_l000001?oHbld00ol0003oe<_AomC;d@05omC;d@03o`000?o>bmOo
c/_G00?oc/_G00?o0000ol?9goo3bMl00oo3bMl00ol0003o[l?Yojo3j@04o`0000CoS[Ob00?oEJ7e
o`000?l000000_l000000ol0CL[o02nco`0QZ002o`0000Co5To90_lZFlh2o`0000GoMWk>00?o0000
ohZ;con:Rll00_n:Rll4oifIc`Co000000?o^ZS7o`000?o6/LH00oo6/LH00ol0003od;W4o`000002
o`0000Coeko300Go0000omg4`?l0003ogLG1o`000002on77_@Go000000OohlRmo`000?l0003oh/Zo
o`000?oQb;ko000000Coh<S100Go0000omW1`_oI`L;ofL72o`000002omBna@03o`000?o>^/Ooc[[7
00;oc[[700Go0000olNfb_o7]/[oakK:o`000005ok:Ra`03o`000?nZW<SoZYc800?oZYc800?o0000
oj:Gb_nRUlX00_nRUlX00ol0003oQhC9ohN4b@04ohN4b@03o`000?n2PlcoPX?<00GoPX?<00?o0000
ogn6d?l000001?mSMm400ol0003oIgoGofMoe`02ofMoe`03o`000?m`SMooL8gO00?oL8gO0_l00003
og>Nk003o`000?n?]_7oSkKa00;oSkKa00?o0000oj_<lOn[c?400_n[c?401Ol0003o`M_]ol7KkOo1
fngo000000;odNGU0ol00002olkgj004o`000?oCnN?odoWSo`0000;oe_WQ00Co0000oooooooooooo
00009oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Gooooo`?o0000
9Oooool00ol0003og=[DomcJe003omcJe0;o00001_oHbld00ol0003oe<_AomC;d@05omC;d@03o`00
0?o>bmOoc/_G00;oc/_G00?o0000ol?9goo3bMl00oo3bMl3o`0000Co[[kU1On>]o83oeFQm@?o0000
00Co02nco`0QZ?l>C<So00000olFClT00ol0003o:U_>obYKcP02o`0000?oMWk>00?o0000ohZ;con:
Rll00_n:Rll00ol0003oWIW?oifIc`02oifIc`Co/:G=2?l00002olfia`07o`000?oG_l?oeko3omNo
`ol0003ogLC0o`000003omg5`@Co000000GohlRno`000?l0003ohlRmo`000003on;:_`;o00000ooP
b<401Ol0003ogLS4o`000?oI`L;o000000?oe;k500Go0000oljjaoo>^/Ooc[[7o`000004olNfbP;o
00000onbX/L00ol0003oZYc8ojZLb003ojZLb003o`000?nRUl[oXYO:00?oXYO:0_l00005ohN4b@03
o`000?n2PlcoPX?<00CoPX?<00Go0000ogn6d?moQ]3oOhK@o`000002of=gd@03o`000?mWOmOoIgoG
00?oIgoG00?o0000og2=gom`SMl00om`SMl01_l0003oOYoXo`000?l0003oLik/o`0000CoSkKa00?o
0000oj_<lOn[c?400_n[c?400ol0003o`M_]ol7Kk@04o`0000;oa>o`00?o0000olkgj?l000000ooC
nN<01?l0003oe_WQomKihOl00003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
1oooool001Sooooo00?o0000ooooooooool05?ooool3o`0002Wooooo00Oo0000omcJe?oLf]Cog=[D
o`000?oHblco000000Oof<_=00?o0000omC;dOoDbm401?oDbm400ol0003oc/_Golk;e`03olk;e`05
o`000?o3bMoo`lWOol?9gol000000ono_mX5ojjni@03o`000?n>]o;oS[Ob00;oS[Ob00So0000oeFQ
mOmEXOGo0000o`=cg_l0003o02nco`0QZ0;o00000_lFClT00ol0003o:U_>obYKcP02odM^e@04o`00
0?mfO/koMWk>o`0000CoRX_?00?o0000oifIconMVLl00_nMVLl00ol0003o/:G=ok2Uc@02ok2Uc@03
o`000?o0/<_o`;3;00;o`;3;00Go0000olfiaoo=^LOocKW7o`000003omNo``;o00001?oMaL42o`00
0003on;8__l0003ohlRn00Co00000ooRb[l01Ol0003oh<S1on38`OoPb<7o000000?ogLS400Go0000
omBnaOoD_/Goe;k5o`000003oljja`03o`000?o7]/[oakK:00;oakK:00Ko0000ol2bc?o0//co0000
ok:Raol00005ojZLb003o`000?nRUl[oXYO:00?oXYO:00Co0000oi^Dc?nKU<co00000on7Q<T00ol0
003oPX?<oh:3c004oh:3c003o`000?moQ]3oOhK@00?oOhK@00?o0000of=gdOl000001?mWOmL00ol0
003oL8gOog2=g`03og2=g`03o`000?mnWnSoOYoX00?oOYoX1?l000000on?]_7o0000oj_<l@03oj_<
l@?o000000?o]^;eo`000?o4ko000_o4ko001?l0003oc_OXolkgj?l00002om?ih`04o`000?oFnN7o
e_WQo`0000Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`005oooool0
0ol0003oooooooooo`0Booooo`?o0000;?ooool01?l0003og=[DomcJe?l00003omS;c003o`000?oH
blgof<_=00Gof<_=00?o0000omC;dOoDbm401?oDbm400ol0003oc/_Golk;e`03olk;e`03o`000?o3
bMoo000000Go_koJ00?o0000ojjniOn^_^D00_n^_^D00ol0003oS[ObohjglP02ohjglP07o`000?mE
XOGoEJ7eo`000?l3Lmko0000o`0_/`02o`0SZP03o`000?lFClWo000000;o:U_>00Ko0000odM^eOm7
K]Go0000ogInc_l00004ohZ;c`03o`000?nMVLooWIW?00;oWIW?00?o0000ok2UcOn`YLd00_n`YLd0
0ol0003o`;3;ol2`b`02ol2`b`05o`000?o=^LOocKW7olfiaol000000_oG_l<2o`0000CogLG10ol0
00000ooRb;ko0000o`000002o`000004on?;`Ol0003oh/Zoon;:_`;o00000_oPb<402Ol0003ogLS4
omg8a?oMb<Co0000om[9b?l0003oe;k5o`000003oljja`03o`000?o7]/[oakK:00;oakK:00Co0000
ol2bc?o0//co`;;<0_l00005ojZLb003o`000?nRUl[oXYO:00?oXYO:00?o0000oi^Dc?nKU<`00_nK
U<`00ol0003oQhC9o`000006oh:3c003o`000?moQ]3oOhK@00GoOhK@00?o0000ofMoeomWOmL00omW
OmL00ol0003oL8gOog2=g`03og2=g`03o`000?mnWnSoOYoX00?oOYoX00Co0000oi2fl?n@]_3oT;K`
1ol00002okKRm@03o`000?o4ko3oa>o`00;oa>o`00?o0000olkgj?l000000ooCnN<01?l0003oe_WQ
omKihOl00006ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo
00?o0000ooooooooool03oooool3o`0002oooooo00?o0000omcJe?l000001OoHbl`00ol0003of<_=
omS;c@05omS;c@03o`000?oDbm7oe<_A00Coe<_A00?o0000olk;eoo>bmL00oo>bmL00ol0003o_koJ
oknofP05oknofP03o`000?n^_^Go[[kU00?o[[kU00Co0000ohjgl_n>]o;oS[Ob0_l000000omEXOGo
0000o`000002o`0000;o02>Z0_l00003obYKcP?oAfkE0_l00004ohZ;c`03o`000?nMVLooWIW?00;o
WIW?00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`09o`000?o=^LOocKW7olfi
aol0003oeko3o`000?oG`/Ko000000?ogLG100Co0000omk7`_l0003oglW30ol000001_oRc<;o0000
on?;`Ol0003oh/Zoo`0000;oh/g30_l00003omg8a005o`000?oJbLSof/W8om[9b?l000000oo>^/L0
0ol0003oakK:olNfbP02olNfbP05o`000?o0//co`;;<ol2bc?l000000_ni[/l01Ol0003oZYc8ojZL
b?nZW<So000000GoXYO:00?o0000oi^Dc?nKU<`00onKU<`2o`0000KoPX?<00?o0000ogn6d?moQ]00
1OmoQ]000ol0003oOh_Fo`000003ofMoe`03o`000?m`SMooL8gO00CoL8gO00?o0000ogjOj?mnWnP0
0_mnWnP00ol0003oT;K`oi2fl003oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go
00000oo4ko001?l0003oc_OXolkgj?l00002om?ih`04o`000?oFnN7oe_WQo`0000Oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2o`0000gooooo0ol0000coooo
o`03o`000?oHblcof<_<00Gof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;
d@05o`000?o>bmOoc/_Golk;eol000000_o8_]47oknofP;o00001?n^_^D00ol0003oS[ObohjglP02
ohjglP03o`000?mEXOGoEJ7e00;o000000Go026Xo`0SZ_l08j[o5To9o`000002obYKcP04o`000?m7
K]GoAfkEodM^e@;o00000on:Rll01Ol0003oWIW?oifIconMVLoo000000Go/:G=00Go0000ol2`boo0
/<_o`;3;o`000004olfia`;o00000_oG`/H01_l0003ogLG1omg5`Ol0003og/O2o`0000;oglW300Ko
0000on7;`ol0003oh/c2o`000?oSbl42o`0000?oh/g300Go0000omg8a?oMb<CogLS4o`000003om[9
b005o`000?oFbLgo0000oljjaol000001?o7]/X01Ol0003o`;;<ol2bc?o0//co000000Co^Jk?00?o
0000ojZLb?l000001OnRUlX00ol0003oViC<oi^Dc003oi^Dc004o`000?nFTlooUY??o`0000GoPX?<
00?o0000ogn6d?moQ]001?moQ]001Ol0003oOh_Fogn;e_moRmKo000000;oIgoG00?o0000og2=gom`
SMl00om`SMl00ol0003oOYoXogjOj003ogjOj003o`000?n@]_3oT;K`00;oT;K`00?o0000ojC=m_nT
cOH00_nTcOH01?l0003o]^;eokKRmOl00004olC_l003o`000?o>mnSo000000?odoWS00Co0000omKi
hOoFnN7o00002?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo000Goooo
o`03o`000?oooooooooo00Wooooo0ol0000fooooo`03o`000?oHblcof<_<00Kof<_<00?o0000omS;
cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;d@03o`000?o>bmOo000000Cob;kA00?o0000okno
f_no_mX01Ono_mX00ol0003o[[kUojjni@02ojjni@03o`000?n>]o;oS[Ob00;oS[Ob00Ko0000oeFQ
mOmEXOGo0000o`=cg_l08JP2o`0SZP04o`000?lZFlko:U_>o`0000?oAfkE0_mYPmX3o`0000CoWIW?
00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`04o`000?o=^LOocKW7olfia`;o
00001?oG`/H2o`00000:omk7`_l0003oglW3omo9`ol0003ohL_3o`000?oRc<;o0000on?;`@;o0000
0ooRcL<2o`0000;ogLS400Go0000om[9b?oJbLSof/W8o`000003omK9c@03o`000?o7]/[oakK:00;o
akK:00Go0000ol2bc?o0//co`;;<o`000005okV^c`;o00001OnRUlX00ol0003oViC<oi^Dc003oi^D
c003o`000?nFTlooUY??00;oUY??00Go0000oh:3c?n2PlcoPX?<o`000006ogn6d003o`000?moRmKo
Oh_F00?oOh_F00?o0000ofMoeol000001Om`SMl00ol0003oOYoXogjOj002ogjOj003o`000?n@]_3o
T;K`00?oT;K`00?o0000ojC=m_nTcOH00_nTcOH01?l0003o]^;eokKRmOl00003olC_l004o`000?o>
mnSoc_OXo`0000;odoWS00Co0000omKihOoFnN7o00002_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Kooooo0ol0000jooooo`03o`00
0?oHblcof<_<00Kof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@05omC;d@03o`00
0?o8_]7ob;kA00Cob;kA0_l00006oknofP03o`000?n^_^Go[[kU00;o[[kU0_l00003ohjglP0;o`00
0?mEXOGoEJ7eo`000?l3Lmko0000o`0SZ_l0=K[o0000obYKc_l000000om7K]D01?l0003oJH?JofV3
f_mYPmX2o`0000?oWIW?00?o0000ok2UcOn`YLd00_n`YLd00ol0003o`;3;ol2`b`02ol2`b`Co0000
00?oc;g<o`000?oG`/H00_oG`/H2o`0000;og/O200?o0000omo9`ol000000_oQbl<01_l0003oh/c2
o`000?l0003oh]36o`0000;oh/g300?o0000on3@b?oPd<P00_l00003om[9b004o`000?oFbLgoe/W=
omK9c@;o00000oo7]/X01Ol0003o`;;<ol2bc?o0//co000000Go^Jk?00Co0000ok6[dOnaZm7o0000
0onRUlX00ol0003oViC<oi^Dc003oi^Dc003o`000?nFTlooUY??00CoUY??00?o0000oh:3c?l00000
1_moQ]000ol0003oOh_Fogn;eP04ogn;eP?o00001?m`SMl00ol0003oOYoXogjOj003ogjOj003o`00
0?n@]_3oT;K`00;oT;K`00?o0000ojC=m_nTcOH00_nTcOH01?l0003o]^;eokKRmOl00003olC_l004
o`000?o>mnSoc_OXo`0000?odoWS00Co0000omKihOoFnN7o00002oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0000noooo
o`03o`000?oHblcof<_<00Kof<_<00?o0000omS;cOoHbld01?oHbld00ol0003oe<_AomC;d@03omC;
d@03o`000?o=_/_ocKk;00Oob;kA00?o0000oknof_no_mX01?no_mX2o`0000Co[[kU00Go0000ohjg
l_n>]o;oS[Obo`000002oeFQm@05o`000?l3Lmko0000o`0SZ_l0=KX00_l00003odM^e@04o`000?mY
Pm[oJH?JofV3fP;oRYSK1?l00004ok2Uc@03o`000?o0/<_o`;3;00?o00001?o<_L`02?l0003oel;6
omO2a_l0003of<O9o`000?oNal;o00000_oObL<01?l0003ohL_3o`000?oRc<82o`0000;oh]3600?o
0000on;=`ol000000ooPd<P01Ol0003of/W8om[9b?oJbLSo000000?oe/W=00Ko0000om79d_oAbM;o
0000olNfb_l00003ol2bc003o`000?ni[/oo^Jk?00;o^Jk?0_l00004ok6[d@03o`000?nRUl[o0000
00GoViC<00?o0000oiJCconFTll01OnFTll3o`0000GoOhK@00?o0000ogn;e_moRmH01?moRmH01?l0
003oPYGMoh:EgOn2UMd2o`0000;oL8gO00?o0000ogjOj?mnWnP00_mnWnP00ol0003oT;K`oi2fl003
oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go00000oo4ko001?l0003oc_OXolkg
j?l00002om?ih`04o`000?oFnN7o0000o`0000cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo00?o0000omS;c?oH
bl`01OoHbl`00ol0003of<_=omS;c@05omS;c@05o`000?oDbm7oe<_AomC;dOl000001?o=_//00ol0
003ob;kAolRnd@04olRnd@;o00001_no_mX00ol0003o[[kUojjni@02ojjni@03o`000?n>]o;oS[Ob
00Ko00000_l08jX00ol0=K[o:U_>o`000002odM^e@05o`000?mYPm[oJH?JofV3f_l000001?n:V=/8
o`0000;o_;GC00?o0000olbmc?o<_L`00_o<_L`00ol0003oel;6o`000003omS7b@;o000000CoglW3
o`000?oQbl?ohL_30_l000001?oQdLSo0000on;@a_oRd<H2o`0000?oh=380_l00002om[9b005o`00
0?oFbLgoe/W=omK9cOl000000ooAbM82o`0000?o`;;<00?o0000okV^coni[/l00_ni[/l00ol0003o
/J_Aok6[d@04ok6[d@;o00001OnKU<`00ol0003oUY??oiJCc`05oiJCc`05o`000?nBUM?oTYGCoi:E
dol000000omoQ]000ol0003oOh_Fogn;eP04ogn;eP03o`000?n2UMgoPYGM00CoPYGM00?o0000og2=
gol000001?mnWnP00ol0003oT;K`oi2fl002oi2fl003o`000?nTcOKoY<gf00;oY<gf00Co0000okKR
mOnfh_Go00000oo4ko001?l0003oc_OXolkgj?l00003om?ih`;o000000?o_O[[o`000?ooool03?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo000Fooooo`Co0000A_ooool0
0ol0003of<_<omS;c005omS;c003o`000?oHblgof<_=00Gof<_=00?o0000omC;dOl000001_o=_//2
o`0000Kob;kA00?o0000oknof_no_mX01?no_mX01?l0003o[[kUojjniOn^_^D3o`0000?oSkOb0omH
ZOT01?l0003o02>Zo`000?l0=KX2o`0000;oAfkE00Go0000ofV3f_mYPm[oJH?Jo`000003ohZHf`Go
YZWH00?o0000okbedonl]M<00_nl]M<00ol0003oc;g<olbmc002olbmc0;o00001?oHalT00ol0003o
flc:o`000003o`0000?ohM780_oRd<H2o`0000?oh=3800?o0000omkEcooNeLl00_l00003omK9c@05
o`000?oAbM;odLWBom79d_l000000_o;b=P00ol0003o`;;<o`000004okV^c`03o`000?naZm7o/J_A
00?o/J_A0_l00002oj^Xe005o`000?nKU<coViC<oi^Dc?l000001_nFTll2o`0000GoTYGC00?o0000
ogn6d?l000001_moRmH00ol0003oPYGMoh:Eg@05oh:Eg@?o00000omnWnP00ol0003oT;K`oi2fl003
oi2fl005o`000?nTcOKoY<gfojC=m_l000000onfh_D01Ol0003oa>o`olC_l?o4ko3o000000;oc_OX
1?l00002okgjj`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`005_ooool2o`0004Wooooo00?o0000omS;c?oHbl`01OoHbl`00ol0003of<_=omS;
c@05omS;c@03o`000?o=_/_ocKk;00OocKk;00?o0000olRndOo8_]401?o8_]400ol0003o_koJokno
fP04oknofP03o`000?n^_^Go000000?oZ[WT1On?]o801?l0003oF:WioeRYnOl08jX2o`000004o`1F
dOl0003oAfkEo`0000?oJH?J00Go0000ohZHfon:V=_oRYSKo`000004ojJYf003o`000?nl]M?o_;GC
00;o_;GC00Co0000olbmc?o<_Lcoc;g<0_l00004omS7b@04o`000?oKc<[oflc:o`0000;og]3:00So
0000on7Ab?oQdLSo0000on;@a_l0003oh=K=o`0000;oh=3800?o0000omkEcooNeLl00_l00003omK9
c@05o`000?oAbM;odLWBom79d_l000000oo;b=P2o`0000?o^Jk?0_l00004ok6[d@;o00001On[Z=@0
0ol0003oViC<o`000006oiJCc`03o`000?nBUM?oTYGC00GoTYGC0ol00005ogn;eP03o`000?n2UMgo
PYGM00GoPYGM00Co0000ohRTion8Y>OoR:CW0_l000000omnWnSo0000oi2fl003oi2fl003o`000?nT
cOKoY<gf00;oY<gf00Co0000okKRmOnfh_Go00000oo4ko000ol0003oc_OXo`000002o`000005okWi
k?l0003o_O[[okgjjol000004Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`17ooooo`03o`00
0?oHblcof<_<00Gof<_<00?o0000omS;cOoHbld00ooHbld00ol0003od;g8om2mb009olfnb`;o0000
1Oo8_]42o`0000Go_koJ00?o0000ojZii?nZ^N@01?nZ^N@00ol0003oSkObohnglP02ohnglP08o`00
0?mHZOWo0000o`0e^_l0003o05KAodM^eOl00003ofV3fP05o`000?n:V=_oRYSKohZHfol000001?nV
ZMP00ol0003o_;GCokbed`03okbed`05o`000?o<_Lco0000olk5d_l000000ooHalT01?l0003oflc:
om_<b_l00002omk@bP04o`000?oQdLSohM78on7Ab0;o00000_oPe/d00ol0003oh=38o`000002omkE
c`03o`000?oJf]Oo000000;oe/W=00?o0000om79d_oAbM800_l00003ol_8f006o`000?o3amgo`lOM
o`000?ni[/oo00001OnaZm400ol0003oZjSDoj^Xe005oj^Xe0;o00001_nFTll00ol0003oTYGCoi:E
d`05oi:Ed`05o`000?n?VMWoSiWIohnIfOl000000omoRmH00ol0003oPYGMoh:Eg@05oh:Eg@03o`00
0?n8Y>OoR:CW00?oR:CW1Ol00002oi2fl005o`000?nTcOKoY<gfojC=m_l000000onfh_D01?l0003o
a>o`olC_l?o4ko02o`0000?o^OW/00Co0000okgjjonmn^_o00004_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Aoooool00ol0003of<_<omS;c005omS;c005o`000?oHblgof<_=omS;cOl000001?o@_LP0
0ol0003ocKk;olfnb`07olfnb`03o`000?o8_]7ob;kA00Cob;kA00Go0000oknof_no_m[o_koJo`00
0002okRgf003o`000?nZ^NCoZ[WT00CoZ[WT0_l00003ohnglP;o000000?o03Fjo`000?l0E]400_l0
0002ofV3fP03o`000?n:V=_oRYSK00;oRYSK00?o0000ojJYf?nVZMP00_nVZMP00ol0003o_;GCokbe
d`02okbed`;o00000oo>aM800ol0003of<O9o`000003om_<bP04o`000?oNd<[og]3:o`0000;ohM78
00?o0000on;@a_oPe/d00_oPe/d2o`0000;og]G?00Co0000om[JeooJf]Oof][G0_l00002om79dP04
o`000?o;b=SoblSHol_8f0;o00000oo3amd2o`0000Co/J_A0_l00006oj^Xe0;o00000_nTYmP01?l0
003oUY??oiJCconFTll2o`0000KoTYGC0_l00005ohnIf@03o`000?moRmKo000000KoPYGM0_l00005
ohRTi`03o`000?nA]_3oTKK`00?oTKK`1?l00002ojC=mPWo00000oninN`01?l0003o_O[[okgjjol0
000Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool000kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`16ooooo`03o`000?oHblcof<_<00Kof<_<00?o0000
omS;cOl000001_o@_LP2o`0000SocKk;00?o0000olRndOo8_]401?o8_]400ol0003o_koJo`000005
okRgf0;o00001OnZ^N@3o`0000;oSkOb00Go0000o`0e^_l0003o0000ocMmiP02o`000003ofV3f_l0
003oRYSK00;oRYSK00?o0000ojJYf?nVZMP00_nVZMP01?l0003o_;GCokbedonl]M<2o`0000Goc/GB
0_l00002om_<bP06o`000?oNd<[og]3:omk@b_l0003ohM780_l00003on3Fc@;o00000_oNeLl01?l0
003of][Gom[JeooJf]L2o`0000;odLWB00Go0000ol_8f?o;b=SoblSHo`000003ol?7g@;o00000_nk
aN801?l0003o/J_Ao`000?l00006oj^Xe0;o00001OnTYmP00ol0003oUY??o`000006oi:Ed`;o0000
1on?VMT3o`0000GoPYGM00?o0000ohRTion8Y>L01?n8Y>L00ol0003oTKK`oi6fl003oi6fl003o`00
0?nKboSoVl_h00;oVl_h1?l00003ojk]n003o`000?ncmO;o000000?o^OW/00Co0000okgjjonmn^_o
00005_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`00
0?oooooooooo00[ooooo0_l00017ooooo`03o`000?oHblcof<_<00Kof<_<00?o0000om2mb?o@_LP0
1oo@_LP00ol0003ocKk;olfnb`06olfnb`;o00001Oo8_]400ol0003o^;OHokRgf006okRgf0;o0000
1_nZ^N@2o`0000;oSkOb00?o0000o`1FdOl000000olgONH3o`000003ohZHfol0003oYZWH00?oYZWH
1?l000000onl`=go0000olk5dP03olk5dP06o`000?oBc]Kod/kFo`000?oKc<[o00000_oNd<X01Ol0
003ohM78o`000?oMfM;o000000;oh=K=00Go0000omgOeol0003og]G?o`000003om[Je`03o`000?oD
gn3o000000;odLWB0oo;b=P00ol0003o`lOMol?7g@02o`0000Co^lGR0_l00006oj^Xe0;o00001onT
YmP2o`0000KoTYGC00?o0000ohnIfOn?VMT01On?VMT2o`0000?oSj3O00Go0000oh:EgOn2UMgoPYGM
o`000006ohRTi`03o`000?nA]_3oTKK`00?oTKK`00?o0000oi_;n?nKboP00_nKboP01?l0003oY]kk
ojKNnol00003ojk]n003o`000?ncmO;o000000?o^OW/00Co0000okgjjonmn^_o00006?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool00ol0003of<_<omS;c005omS;c003o`000?oA_LOod;g800So
d;g800?o0000olfnboo=_//01oo=_//01Ol0003ob;kAolRndOo8_]7o000000;o`;G?00?o0000okRg
f?nh]mP01_nh]mP2o`0000KoZ[WT0_l000001?n?]o;o0000o`1FdOl00002ocMmiP03o`000?mbX>go
LZ3]00Oo00001Onl`=d01?l0003oc/GBolk5d_l00004om;>ePGo00000ooMfM800ol0003oh=K=o`00
0002omgOe`03o`000?oNeLoof][G00;of][G00?o0000omCOh?oDgn000_l00003ol_8f004o`000?o3
amgo`lOMo`0000?o^lGR0ol000000onb`nOo0000oj^Xe003oj^Xe0;o00001_nTYmP3o`0000;oWZOL
00Co0000oi:EdonBUM?oTYGC0_l00006ohnIf@;o00001_n?X=l00ol0003oPYGMo`000005ohRTi`;o
00001?nA]_02o`0000CoVl_h00Co0000ojKNnonVg__o00000on^kOP00ol0003o/oGbo`000003okWi
k004o`000?nmn^_o_O[[o`0001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05
ooooo`003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04Gooooo00?o0000omS;
c?oHbl`00ooHbl`01?l0003odKg7om6maooA_LL2o`0000Ood;g80_l00008olfnb`03o`000?o8_]7o
000000Go`;G?0_l00007okRgf0;o00001_nZ^N@5o`0000;o=ggV00Co0000og:PkOmbX>go00001?nO
]NP00ol0003o_<3Mokc0g@03okc0g@03o`000?o>aM;o000000God/kF00Go0000omSFe_oHe]Kof=KF
o`000002omgIdP03o`000?oPe/gogMoG00;ogMoG0_l00002om[Je`;o000000Goe=oPo`000?l0003o
b^CZo`000002ol_8f0;o`lOM0_l00002ok_5hP;o00001Onb`nL01?l0003oZjSDo`000?l00005ojBW
f0?o00001_nNYm`00ol0003oTYGCo`000006ohnIf@;o00002?n?X=l2o`0000GoR:CW00?o0000oi6f
l?nA]_000onA]_000ol0003oVl_hoi_;n002oi_;n0;o00000_nVg_/01ol0003o[^ghojk]n?n^kOSo
0000ok?el_l000000oninN`01?l0003o_O[[okgjjol0000Kooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`15ooooo`05o`000?oHblcof<_<omS;c?l000001_oA_LL00ol0003od;g8om2mb006om2mb003o`00
0?o=_/_ocKk;00KocKk;00?o0000ol2ecoo0]Ll01_o0]Ll2o`0000Oo^;OH0_l00006ojZii004o`00
0?n?^?;o0000o`0000;o=ggV00Co0000og:PkOmbX>go00001?nO]NP00ol0003o_<3Mokc0g@03okc0
g@03o`000?oBc]Kod/kF00?od/kF00Go0000omSFe_oHe]Kof=KFo`000002omgIdP;o00000_oMgmL2
o`000005omCYi?l0003of][Gom[JeooDgn000_l00003ol[TjP;o000000?o`lOMo`000?l000000_nk
aN82o`0000Ko//?W0ol00005ojBWf0;o00002?nNYm`4o`0000CoSiWI0_l00008ohnPg`;o00000_n?
Z^P01Ol0003oR:CWohRTion8Y>Oo000000CoTKK`0_l00004oi_;n003o`000?nVg__oY]kk00;o0000
0_n^kOP2o`000003ok?el_l0003o^OW/00;o^OW/00Co0000okgjjonmn^_o00007Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo
0_l00016ooooo`03o`000?oHblco000000SodKg700?o0000om2mb?o@_LP01_o@_LP00ol0003ocKk;
olfnb`05olfnb`03o`000?o5/lWo000000So`;G?0ol00006okRgf0;o00001?nZ^N@01?l0003oYKGT
o`000?l0?:T3o`0000?oLZ3]00?o0000oinej?nO]NP00_nO]NP01?l0003o_<3Mo`000?l00003ol7@
i@;o000000?od/kFo`000?oHe]H00_oHe]H4o`000004omKShOl0003ogMoGo`0000?oe>WT00Co0000
om[JeooDgn3o00000_o:i>X3o`000004okcUlol0003o0000ok_5hP?o00001Onb`nL3o`0000?oZ<3[
00?o0000ojBWf?l000000_l00007oijWg0?o00001?nJZN401?l0003oSiWIo`000?l00008ohnPg`;o
00001On?Z^P00ol0003oR:CWo`000004oi6fl003o`000?nKboSoVl_h00;oVl_h0_l00002ojKNn`05
o`000?n^kOSo[^ghojk]n?l000000_ncmO801Ol0003o^OW/okWik?ninNco000000;o_O[[00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Roooo
o`03o`000?oooooooooo04Cooooo00?o0000om6maooA_LL02?oA_LL2o`0000Ood;g80_l00004olfn
b`03o`000?o5/lWoaK?900;oaK?90_l00008ol2ec`;o00001_nh]mP2o`000003ojZii?l0003oYKGT
00CoYKGT00?o03bYo`000?l000000ombX>d00ol0003oWkGXoinej003o`0000Oo`M3U1_l00003omKS
h@03o`000?oMgmOo000000?oe>WT0_l000000ooDgn3o0000ol[TjP02o`000003okcUlol0003o0000
00Co00001Onb`nL3o`0000GoZ<3[0ol00006oijWg0Co00001_nJZN43o`0000OoSj3O0ol00007ohnZ
j0Co00000_nA]_000ol0003oVl_hoi_;n002oi_;n005o`000?nVg__oY]kkojKNnol000000on^kOP0
1?l0003o/oGbok?el_l00003okWik004o`000?nmn^_o_O[[o`00023ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`15ooooo`03o`000?oA
_LOodKg700SodKg700?o0000om2mb?o@_LP01_o@_LP01?l0003ocKk;olfnbol00007olFcb@;o0000
2?o0]Ll2o`0000Ko^;OH00?o0000ojFei?nU]N@01OnU]N@00ol0?:Wo0000o`000005o`0000CoWl_f
00Go0000ol7@iOo1d>Go`M3Uo`000005ol_Ni`03o`000?oFhn7oe^?Q00?o00000_oDjN@5o`000003
ol[Tj_l0003o000000Ko00000_nGgOh00ol0003o//?Wok;3i`03o`0000?oZ<3[1Ol00003oj2mkP03
o`000?nNYmcoWZOL00?o00001_nJZN44o`0000?oUZcV00?o0000ohnPgon?X=l00_n?X=l2o`0000Oo
Sj[X0ol00004oi6gl0Co00000_nKboP01Ol0003oY]kkojKNnonVg__o000000?o[^gh00Co0000ok?e
l_ncmO;o00000oninN`01?l0003o_O[[okgjjol0000Rooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01?ooool002Cooooo0_l00016ooooo`;o00002OoA_LL2o`0000Ood;g800?o0000
olfnbol000002Oo5/lT2o`0000So`;G?0_l00004okRgf004o`000?n`/MWo/;7Io`0000GoYKGT00Co
03bYo`000?l0N]go00000omM/_/00ol0003oWl_foio;mP02oio;mP03o`000?o1d>Go000000GobmkW
1?l000000oo2kO7o0000o`000002o`000003ol?al?l0003o000000;o000000Co_>Gco`000?l0003o
Z^?j0_l00003oiOMoPGo000000?oZ<3[o`000?l000000ol00005oj2mkPKo00001_nJZN43o`0000So
UZcV00Co0000ohnPgol0003o00001_n?Z^P3o`0000CoTKO`0ol00004oiC5n0Co000000?oY]kko`00
0?n^kOP00_n^kOP01?l0003o/oGbok?el_l00003okWik004o`000?nmn^_o_O[[o`0002Cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15
ooooo`03o`000?oA_LOodKg700SodKg700?o0000om2mb?o@_LP01Oo@_LP00ol0003oaK?9olFcb@0:
olFcb@03o`000?o0]Loo`;G?00Oo`;G?0_l000000onh]mSo0000ok2af@05ok2af@?o00000_nU]N@0
1?l0003o07[Mo`000?l00003oefbn`04o`000?nOboKoWl_foio;mPSo00000_o2kO43o`0000;o`o7`
1_l00002oj[SnPgo00000onP_Nh7o`0000GoVK__00?o0000oiZYhOnJZN401?l00009oiJ/iPGo0000
1On?Z^P2o`0000GoTKO`0_l00005oiC5n0;o00000onGe?d@o`0002Kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`009oooool00ol0003oooooooooo`15ooooo`;o00002OoA
_LL00ol0003od;g8om2mb004om2mb003o`000?o7/lOo000000_oaK?90_l00009ol2ec`03o`000?n`
/MWo/;7I00So/;7I1ol00002oefbn`?o00001_n[hOT01?l0003o`^gao`000?l00002oi?Yn003o`00
0?o3lO3o000001Wo00002OnI^nl6o`0000SoUZcV1Ol00005oi>aj`03o`000?n?Z^So000000;o0000
1OnA]o02o`0000CoU<Gh0ol00003oiODo@;o00000_nKh?d2o`000003oikXnol0003o000000?oXngi
00Co0000oj[^n?l0003o0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Co
oooo000Xooooo`03o`000?oooooooooo04Kooooo00?o0000om6maooA_LL01ooA_LL2o`0000?od;g8
00?o0000olNcaoo7/lL00_o7/lL3o`0000WoaK?90_l00007ol2ec`03o`000?ng[m7o000000;o0000
2On`/MT6o`0000KoI<ck2Ol00002ogVkn`?o000000?oF;Slo`000?l000002_l00006ogk6oP03o`00
0?nI^nooVK__00;oVK__2?l00005oiBil004o`000?nF[>KoUZcVoiJ/iPGo00002?nC/N/5o`0000Co
TKO`0ol00004oiC5n0;o00000onGe?d3o`0000;oVn3m0_l00002oikXn`04o`000?nSkOWoXngioj?]
n@;o000000?oZ^kho`000?ooool0:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo000Yooooo`;o0000Aoooool2o`0000WodKg700?o0000om2mb?l000002?o7/lL2o`0000Wo
aK?90_l00004ol2ec`03o`000?ng[m7o]joA00?o]joA0ol00009ok2af@?o00000_nU]N@8o`0000Oo
T;Sb1?l000000omi^o_o0000o`00000Do`0000KoU;W`2ol00007oi>aj`Ko00001OnA]o401?l0003o
TKO`o`000?l00005oiC5n0;o00000onGe?d2o`0000?oVn3m0_l00002oikXn`;o00000_nSkOT2o`00
0003oj[^n?l0003o000002gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04oooo
o`00:oooool00ol0003oooooooooo`16ooooo`03o`000?oA_LOodKg700OodKg700?o0000olNcaoo7
/lL02Oo7/lL2o`0000WoaK?90_l000000oo0]Loo0000okN_d@08okN_d@?o00002On`/MT2o`0000[o
W[?W1Ol00005oi2hlPOo00001?n9_?LAo`0000WoTKSa00Co0000oi>ajonC/N_oTk7[1Ol0000:oi6g
l@?o00001?nDaOP3o`0000?oUmCm0_l00003oi_Po@;o00000_nNj?/2o`0000?oXngi00Co0000oj[^
n?l0003o0000;oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000/oooo
o`03o`000?oooooooooo04Kooooo0_l00007om6ma`03o`000?o8/lKo000000_oak?70_l00009olFc
b@03o`000?ng[m7o]joA00_o]joA0ol00007ok2af@03o`000?nW/=koYk3N00Co00002OnN/nL5o`00
0003oi2hl_l0003oTKSa00CoTKSa2Ol00003ohVlm`03o`000?nA^?7oTKSa00OoTKSa3?l0000:oi6g
l@Go00000onA__D01?l0003oU<Gho`000?l00003oiODo@?o00001?nKh?d01Ol0003oW^SkoikXnonN
j?_o000000?oXngi1?l0000booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00ooo
ool002gooooo00?o0000ooooooooool0Aoooool00ol0003odKg7om6ma`03om6ma`03o`000?o8/lKo
b;?600;ob;?60_l0000:olNca`;o00001oo5/lT00ol0003o^jg<ok^]c002o`0000co]joA0ol00004
ok2af@03o`000?nW/=koYk3N00CoYk3N1Ol00009oijci`Oo00002OnA^?4=o`0000WoTKSa00?o0000
oi6glOnA]o401_nA]o44o`0000OoTKke1Ol000000onGe?go0000o`000005oi_Po@;o00000_nNj?/2
o`0000;oXngi0_l000000onZk_So0000ooooo`0dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool002kooooo0_l00018ooooo`;o00000_oA_LL00ol0003ob;?6olRcaP05olRc
aP;o00002_o7/lL3o`0000?oaK?900?o0000ok^]c?nk[L`01Onk[L`3o`0000[o]joA1?l0000<ojN`
gPCo00001_nN/nL00ol0003oV;C[oiRdj`03oiRdj`[o00000onA^?400ol0003oTKSaoi6hl@0@oi6h
l@03o`000?nA]o7oTKOa00Go00001_nA__D5o`0000?oTlKi1?l00004oi_Po@;o00000_nNj?/2o`00
00?oXngi00Co0000oj[^n?l0003o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000om6maol000002Oo8/lH2o`00
00_oak?70_l000000oo5/lWo0000ok^]c009ok^]c0Co00002Ong[m400ol0003oYk3NojN`gP0>ojN`
gPCo000000?oW[?Wo`000?nH]>/03onH]>/Io`0000OoTKke1?l00004oi?6n@Co00001?nFcO/01?l0
003oVn3mo`000?l00003oikXn`04o`000?nSkOWoXngioj?]n@Co0000>Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo04Oooooo00?o0000
olRca_o8/lH02_o8/lH3o`0000[oak?700?o0000ok^]c?nk[L`03Onk[L`4o`0000Go]joA00Co0000
ojf]eon][MOo[JgG1Ol0000<ojN`gPSo00003_nH]>/00ol0003oTkSaoi>hl@0Aoi>hl@03o`000?nA
__GoTKke00Go00001?nCa_T4o`0000OoU/gk1Ol000000onNj?_o0000o`000002oj?]n@;o000000?o
Z^kho`000?ooool0>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000b
ooooo`03o`000?oooooooooo04Sooooo00?o0000olRca_o8/lH02oo8/lH2o`0000Soak?700?o0000
okf]bOnm[LT01?l0000=ok^]c0?o000000?o]joAo`000?n][ML02?n][ML6o`0000OoYk3N00?o0000
oijbi_nN/^H01?nN/^H;o`0000CoV;C[00?o0000oi>hlOnC^?401onC^?4<o`0000KoTlKi0ol00007
oiK=n`Co00000onJdo`5o`000003oj?]nOl0003oZ^kh00;o0000?_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo000cooooo`;o0000Boooool2o`0000_ob;?60_l00005olNc
a`03o`000?nm[LWo_Jg900Go_Jg91?l0000<ok^]c0;o00003on][ML5o`0000;oYk3N00?o0000oijb
i_nN/^H03onN/^H>o`0000_oU[[`00?o0000oi?6nOnCa_T01?l00006oiK=n`Co00001?nJdo`3o`00
00?oWmOk1Ol00011ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003Go
oooo00?o0000ooooooooool0B_ooool3o`0000[ob;?60_l00003olNca`03o`000?nm[LWo_Jg900Wo
_Jg90ol0000:ok^]c004o`000?naZm;o/J_Bok6[dPKo00002on][ML?o`0000WoW[;V00?o0000oiJj
l?nF^_002OnF^_0<o`0000KoU/gk1?l00004oi[Co0Co00000onOeo/6o`0004?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`1<ooooo`;o
00002_o8/lH2o`000003olNcaol0003o_Jg900go_Jg91?l00006ok^]c003o`000?naZm;o/J_B00Oo
/J_B1Ol00008ojf]e`03o`000?nT/>7oY;3Q00[oY;3Q5Ol0000;oi^kk`03o`000?nFcO_oU/gk00Co
00001OnJdo`3o`0000CoWmOk0ol000000onTf?[o0000o`000017ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool003Oooooo0_l0001>ooooo`;o00002_o8/lH00ol0003o_Jg9
okf]b@0Aokf]b@Co000000?o^jg<o`000?naZm803_naZm86o`0000;o[JgG00?o0000ojB`hOnT/>40
5?nT/>400ol0003oVk__oi^kk`0?oi^kk`Oo00001OnJdo`4o`0000CoWmOk0ol000001?nTf?[o0000
o`000?l0001:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Wooooo
00?o0000ooooooooool0COooool3o`0000Oob;?600?o0000okn]b?no[LP01?l0000Aokf]b@;o0000
5OnaZm8?o`0000_oY;3Q00?o0000oi^kkonK^nl00onK^nl;o`0000KoWkg^00?o0000oi[Co?nJdo`0
0ol00005oioGn`?o00000_nTf?X2o`0004kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`00>_ooool00ol0003oooooooooo`1?ooooo`;o00001?o8/lH00ol0003o_jg8okn]
b005okn]b0Co00003_nm[LT01?l0003o]:_?okB[condZll6o`0000ko/J_B00?o0000ojR`gOnX/=d0
2_nX/=dAo`0000koWkg^1_l00005oioGn`?o00000onTf?X2o`00053ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`1@ooooo`?o000000?o
b;?6o`000?no[LP02_no[LP4o`0000[o_Jg900?o0000okB[condZll01ondZll6o`0000So/J_B00?o
0000ojR`gOnX/=d05OnX/=d00ol0003oWkg^oinmkP09oinmkPSo00001OnS_^`00ol0003oWmOkoioG
n`03o`0000?oY=Sj0ol0001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool003cooooo0_l0001Cooooo`03o`000?no[LSo_jg800ko_jg81?l00005okf]b@03o`000?ndZloo
]:_?00ko]:_?1_l00002ok6[dP03o`000?nX/=goZ;3M01GoZ;3M00Co0000oinmk_nO_NkoWkg^2?l0
000;oj>nk0Go00001?nTf?X2o`0005Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`01ooooo`00?_ooool00ol0003oooooooooo`1Cooooo`Co00003_no[LP4o`000003okf]bOl0003o
]:_?01Go]:_?7_l0000=oj>nk0Ko00001?nW`>/00ol0003oY=Sjo`000002o`0005[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`1Foooo
o`Co00003_no[LP2o`0001So]:_?00?o0000oj^`fon[/=/05On[/=/00ol0003oXkk/oj>nk007oj>n
k0Oo00002?nW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01oooo
o`00@?ooool00ol0003oooooooooo`1Iooooo`Go00002_no[LP00ol0003o]Zc>okJ/cP02okJ/cPWo
00002ondZll00ol0003oZk3Koj^`f`0Foj^`f`03o`000?nS_^coXkk/00Ko00002_nW`>/5o`0006;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00@Oooool2o`0005_ooooo
00?o0000ooooooooool01?l00006okn]b003o`000?nf[<ko]Zc>00_o]Zc>2?l00003okB[c`03o`00
0?n[/=_oZk3K00[oZk3K3ol0000;ojO0j`Go0000J?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo007ooooo0013ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01?oo
ool4o`000003okn]b?l0003o]Zc>01Go]Zc>4?l0000<ojjafP03o`000?nW`>_oYl3[00KoYl3[1Ol0
001^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`08ooooo`;o00006Onf[<h00ol0003o[[7JojjafP0G
ojjafP03o`000?nW`>_oYl3[00Go0000Loooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo007ooooo0015ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool03_ooool9o`00
00co]Zc>00?o0000ojjaf_n^/MX04On^/MX9o`0007Wooooo00?o0000ooooooooool02?ooool1o`00
007ooooo0Oooool004Kooooo0_l0001Fooooo`03o`000?oooooooooo01Oooooo2Ol00003okJ/cP03
o`000?n^/M[o[[7J00Co[[7J3Ol00023ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo0018ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08?ooool:o`00097ooooo
00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001:
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05
ooooo`7o00000Oooool1ooooo`00Boooool2o`00057ooooo00?o0000ooooooooool0_Oooool00ol0
003oooooooooo`04ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00Coooool2o`0004gooooo00?o0000ooooooooool0_oooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool0057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`30
ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Cooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo0000
007ooooo001Dooooo`;o0000B?ooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`00
007ooooo001Fooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0`oooool00ol0003o
ooooo`000001ooooo`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0<?ooooo
00?o0000ooooooooool00Ol0000005Sooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`34ooooo`7o00000Oooool1o`000000FOooool2o`0004?ooooo00?o0000ooooooooool0aOooool2
o`000000Foooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo0ol0000005co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`30ooooo`Co00000oooool005gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2looooo`Co00001oooool005kooooo0_l0
000nooooo`03o`000?oooooooooo0;Sooooo1?l0000;ooooo`00H?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo0;Cooooo1?l0000?ooooo`00HOooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo0;7ooooo0ol0000Cooooo`00H_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo0:gooooo1?l0000Fooooo`00Hoooool2o`0003Wooooo00?o0000ooooooooool0
ZOooool4o`0001[ooooo001Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOoo
ool4o`0001kooooo001Vooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4
o`0002;ooooo001Wooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00009_ooool006Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Jooooo`Co0000:_ooool006[ooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Fooooo`Co0000;_ooool006_ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Booooo`Co0000<_ooool006cooooo0_l0000_
ooooo`03o`000?oooooooooo08kooooo1?l0000fooooo`00K_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo08[ooooo1?l0000jooooo`00Koooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo08Oooooo0ol0000nooooo`00L?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo08?ooooo1?l00011ooooo`00LOooool2o`0002[ooooo00?o0000ooooooooool0Oooo
ool4o`0004Gooooo001cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Noooool4
o`0004Wooooo001dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`00
04gooooo001eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00057o
oooo001fooooo`;o00009Oooool00ol0003oooooooooo`1_ooooo`Co0000EOooool007Sooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000FOooool007Wooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000GOooool007[ooooo0_l0000Qoooo
o`03o`000?oooooooooo06?ooooo1?l0001Qooooo`00O?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo063ooooo0ol0001Uooooo`00OOooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo05cooooo1?l0001Xooooo`00O_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo05Sooooo1?l0001/ooooo`00Ooooool2o`0001cooooo00?o0000ooooooooool0E?ooool4
o`00073ooooo0021ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`00
07Cooooo0022ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool4o`0007So
oooo0023ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007cooooo
0024ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000P?ooool008Kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Q?ooool008Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0looooo`Co0000R?ooool008Sooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0iooooo`?o0000S?ooool008Wooooo0_l0000Booooo`03o`00
0?oooooooooo03Gooooo1?l0002?ooooo`00Roooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03;ooooo1?l0002Cooooo`00S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02kooooo1?l0002Gooooo`00SOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
02[ooooo1?l0002Kooooo`00S_ooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`0009oo
oooo002@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`000:?ooooo
002Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:Oooooo002B
ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Zoooool009Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000[oooool009Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Co0000/oooool009Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`?o0000]oooool009Oooooo0_l00003ooooo`03o`000?oo
oooooooo00_ooooo1?l0002jooooo`00VOooool01?l0003oooooooooool00009ooooo`Co0000__oo
ool009[ooooo00?o0000ooooool000001Oooool4o`000<;ooooo002Kooooo`;o000000?oooooo`00
0?l000000_l00036ooooo`00W?ooool2o`000<[ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .64975 m .51694 .65827 L .43899 .65168 L p .689 .716 .87 r
F P
0 g
s
.51694 .65827 m .51725 .64975 L .59261 .64645 L p .669 .727 .893 r
F P
0 g
s
.59261 .64645 m .59527 .65394 L .51694 .65827 L p .669 .727 .893 r
F P
0 g
s
.59527 .65394 m .59261 .64645 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44231 .64262 L .51725 .64975 L p .689 .716 .87 r
F P
0 g
s
.51756 .64124 m .51725 .64975 L .44231 .64262 L p .685 .715 .872 r
F P
0 g
s
.51725 .64975 m .51756 .64124 L .58993 .63894 L p .664 .725 .895 r
F P
0 g
s
.58993 .63894 m .59261 .64645 L .51725 .64975 L p .664 .725 .895 r
F P
0 g
s
.44231 .64262 m .43899 .65168 L .36521 .63435 L p .711 .719 .856 r
F P
0 g
s
.59261 .64645 m .58993 .63894 L .65915 .62672 L p .65 .749 .922 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59261 .64645 L p .65 .749 .922 r
F P
0 g
s
.44231 .64262 m .44564 .6336 L .51756 .64124 L p .685 .715 .872 r
F P
0 g
s
.51788 .63289 m .51756 .64124 L .44564 .6336 L p .678 .716 .877 r
F P
0 g
s
.51756 .64124 m .51788 .63289 L .58722 .63149 L p .658 .725 .899 r
F P
0 g
s
.58722 .63149 m .58993 .63894 L .51756 .64124 L p .658 .725 .899 r
F P
0 g
s
.36521 .63435 m .37145 .62527 L .44231 .64262 L p .711 .719 .856 r
F P
0 g
s
.44564 .6336 m .44231 .64262 L .37145 .62527 L p .708 .718 .857 r
F P
0 g
s
.58993 .63894 m .58722 .63149 L .65355 .62061 L p .644 .747 .924 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58993 .63894 L p .644 .747 .924 r
F P
0 g
s
.37145 .62527 m .37772 .61628 L .44564 .6336 L p .708 .718 .857 r
F P
0 g
s
.44899 .62483 m .44564 .6336 L .37772 .61628 L p .701 .719 .864 r
F P
0 g
s
.44564 .6336 m .44899 .62483 L .51788 .63289 L p .678 .716 .877 r
F P
0 g
s
.51819 .62484 m .51788 .63289 L .44899 .62483 L p .669 .719 .886 r
F P
0 g
s
.51788 .63289 m .51819 .62484 L .58451 .62417 L p .65 .727 .905 r
F P
0 g
s
.58451 .62417 m .58722 .63149 L .51788 .63289 L p .65 .727 .905 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72983 .60915 L p .656 .786 .944 r
F P
0 g
s
.72983 .60915 m .73799 .61332 L .67023 .63881 L p .656 .786 .944 r
F P
0 g
s
.37772 .61628 m .38401 .60762 L .44899 .62483 L p .701 .719 .864 r
F P
0 g
s
.45235 .61651 m .44899 .62483 L .38401 .60762 L p .69 .723 .875 r
F P
0 g
s
.44899 .62483 m .45235 .61651 L .51819 .62484 L p .669 .719 .886 r
F P
0 g
s
.58722 .63149 m .58451 .62417 L .6479 .61445 L p .638 .745 .926 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58722 .63149 L p .638 .745 .926 r
F P
0 g
s
.37145 .62527 m .36521 .63435 L .29943 .6068 L p .733 .733 .851 r
F P
0 g
s
.51851 .6172 m .51819 .62484 L .45235 .61651 L p .657 .725 .899 r
F P
0 g
s
.51819 .62484 m .51851 .6172 L .58177 .61703 L p .642 .73 .913 r
F P
0 g
s
.58177 .61703 m .58451 .62417 L .51819 .62484 L p .642 .73 .913 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72161 .60492 L p .649 .784 .946 r
F P
0 g
s
.72161 .60492 m .72983 .60915 L .66471 .63279 L p .649 .784 .946 r
F P
0 g
s
.29943 .6068 m .30841 .59829 L .37145 .62527 L p .733 .733 .851 r
F P
0 g
s
.37772 .61628 m .37145 .62527 L .30841 .59829 L p .73 .732 .853 r
F P
0 g
s
.38401 .60762 m .39032 .59954 L .45235 .61651 L p .69 .723 .875 r
F P
0 g
s
.45572 .60881 m .45235 .61651 L .39032 .59954 L p .674 .728 .89 r
F P
0 g
s
.45235 .61651 m .45572 .60881 L .51851 .6172 L p .657 .725 .899 r
F P
0 g
s
.58451 .62417 m .58177 .61703 L .64221 .60824 L p .632 .743 .928 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58451 .62417 L p .632 .743 .928 r
F P
0 g
s
.51883 .61005 m .51851 .6172 L .45572 .60881 L p .642 .733 .914 r
F P
0 g
s
.51851 .6172 m .51883 .61005 L .57901 .61013 L p .634 .735 .921 r
F P
0 g
s
.57901 .61013 m .58177 .61703 L .51851 .6172 L p .634 .735 .921 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71332 .60054 L p .643 .779 .946 r
F P
0 g
s
.71332 .60054 m .72161 .60492 L .65915 .62672 L p .643 .779 .946 r
F P
0 g
s
.30841 .59829 m .31742 .5899 L .37772 .61628 L p .73 .732 .853 r
F P
0 g
s
.38401 .60762 m .37772 .61628 L .31742 .5899 L p .722 .733 .86 r
F P
0 g
s
.39032 .59954 m .39663 .59224 L .45572 .60881 L p .674 .728 .89 r
F P
0 g
s
.4591 .60184 m .45572 .60881 L .39663 .59224 L p .652 .735 .91 r
F P
0 g
s
.45572 .60881 m .4591 .60184 L .51883 .61005 L p .642 .733 .914 r
F P
0 g
s
.58177 .61703 m .57901 .61013 L .63648 .60198 L p .628 .742 .929 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58177 .61703 L p .628 .742 .929 r
F P
0 g
s
.31742 .5899 m .32644 .5819 L .38401 .60762 L p .722 .733 .86 r
F P
0 g
s
.39032 .59954 m .38401 .60762 L .32644 .5819 L p .709 .735 .872 r
F P
0 g
s
.51916 .60345 m .51883 .61005 L .4591 .60184 L p .624 .742 .931 r
F P
0 g
s
.51883 .61005 m .51916 .60345 L .57624 .60348 L p .625 .742 .931 r
F P
0 g
s
.57624 .60348 m .57901 .61013 L .51883 .61005 L p .625 .742 .931 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70497 .59594 L p .636 .772 .945 r
F P
0 g
s
.70497 .59594 m .71332 .60054 L .65355 .62061 L p .636 .772 .945 r
F P
0 g
s
.39663 .59224 m .40294 .58586 L .4591 .60184 L p .652 .735 .91 r
F P
0 g
s
.46249 .59566 m .4591 .60184 L .40294 .58586 L p .623 .742 .932 r
F P
0 g
s
.4591 .60184 m .46249 .59566 L .51916 .60345 L p .624 .742 .931 r
F P
0 g
s
.32644 .5819 m .33545 .57459 L .39032 .59954 L p .709 .735 .872 r
F P
0 g
s
.39663 .59224 m .39032 .59954 L .33545 .57459 L p .689 .738 .888 r
F P
0 g
s
.57901 .61013 m .57624 .60348 L .6307 .59568 L p .626 .741 .93 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57901 .61013 L p .626 .741 .93 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69655 .59106 L p .631 .762 .941 r
F P
0 g
s
.69655 .59106 m .70497 .59594 L .6479 .61445 L p .631 .762 .941 r
F P
0 g
s
.51948 .59738 m .51916 .60345 L .46249 .59566 L p .604 .752 .948 r
F P
0 g
s
.51916 .60345 m .51948 .59738 L .57345 .59708 L p .618 .749 .94 r
F P
0 g
s
.57345 .59708 m .57624 .60348 L .51916 .60345 L p .618 .749 .94 r
F P
0 g
s
.73799 .61332 m .72983 .60915 L .78416 .57634 L p .673 .822 .955 r
F P
0 g
s
.78416 .57634 m .79464 .57831 L .73799 .61332 L p .673 .822 .955 r
F P
0 g
s
.33545 .57459 m .34446 .56816 L .39663 .59224 L p .689 .738 .888 r
F P
0 g
s
.40294 .58586 m .39663 .59224 L .34446 .56816 L p .661 .74 .909 r
F P
0 g
s
.40294 .58586 m .40927 .58048 L .46249 .59566 L p .623 .742 .932 r
F P
0 g
s
.4659 .59027 m .46249 .59566 L .40927 .58048 L p .587 .748 .954 r
F P
0 g
s
.46249 .59566 m .4659 .59027 L .51948 .59738 L p .604 .752 .948 r
F P
0 g
s
.57624 .60348 m .57345 .59708 L .62488 .58932 L p .626 .741 .93 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57624 .60348 L p .626 .741 .93 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68806 .58585 L p .628 .751 .936 r
F P
0 g
s
.68806 .58585 m .69655 .59106 L .64221 .60824 L p .628 .751 .936 r
F P
0 g
s
.72983 .60915 m .72161 .60492 L .77362 .57428 L p .666 .82 .957 r
F P
0 g
s
.77362 .57428 m .78416 .57634 L .72983 .60915 L p .666 .82 .957 r
F P
0 g
s
.30841 .59829 m .29943 .6068 L .24558 .56996 L p .75 .755 .856 r
F P
0 g
s
.51981 .59181 m .51948 .59738 L .4659 .59027 L p .584 .762 .964 r
F P
0 g
s
.51948 .59738 m .51981 .59181 L .57063 .59091 L p .614 .758 .948 r
F P
0 g
s
.57063 .59091 m .57345 .59708 L .51948 .59738 L p .614 .758 .948 r
F P
0 g
s
.34446 .56816 m .35346 .56279 L .40294 .58586 L p .661 .74 .909 r
F P
0 g
s
.40927 .58048 m .40294 .58586 L .35346 .56279 L p .623 .741 .932 r
F P
0 g
s
.24558 .56996 m .25696 .56264 L .30841 .59829 L p .75 .755 .856 r
F P
0 g
s
.31742 .5899 m .30841 .59829 L .25696 .56264 L p .747 .755 .858 r
F P
0 g
s
.40927 .58048 m .41561 .57609 L .4659 .59027 L p .587 .748 .954 r
F P
0 g
s
.46933 .58562 m .4659 .59027 L .41561 .57609 L p .546 .752 .972 r
F P
0 g
s
.4659 .59027 m .46933 .58562 L .51981 .59181 L p .584 .762 .964 r
F P
0 g
s
.72161 .60492 m .71332 .60054 L .76299 .57198 L p .658 .812 .957 r
F P
0 g
s
.76299 .57198 m .77362 .57428 L .72161 .60492 L p .658 .812 .957 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67949 .58029 L p .626 .74 .929 r
F P
0 g
s
.67949 .58029 m .68806 .58585 L .63648 .60198 L p .626 .74 .929 r
F P
0 g
s
.57345 .59708 m .57063 .59091 L .61901 .58292 L p .629 .742 .929 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57345 .59708 L p .629 .742 .929 r
F P
0 g
s
.25696 .56264 m .26835 .55545 L .31742 .5899 L p .747 .755 .858 r
F P
0 g
s
.32644 .5819 m .31742 .5899 L .26835 .55545 L p .739 .755 .865 r
F P
0 g
s
.35346 .56279 m .36246 .55856 L .40927 .58048 L p .623 .741 .932 r
F P
0 g
s
.41561 .57609 m .40927 .58048 L .36246 .55856 L p .573 .738 .954 r
F P
0 g
s
.52014 .58665 m .51981 .59181 L .46933 .58562 L p .566 .773 .976 r
F P
0 g
s
.51981 .59181 m .52014 .58665 L .56779 .58493 L p .614 .767 .954 r
F P
0 g
s
.56779 .58493 m .57063 .59091 L .51981 .59181 L p .614 .767 .954 r
F P
0 g
s
.26835 .55545 m .27973 .54871 L .32644 .5819 L p .739 .755 .865 r
F P
0 g
s
.33545 .57459 m .32644 .5819 L .27973 .54871 L p .723 .754 .877 r
F P
0 g
s
.71332 .60054 m .70497 .59594 L .75228 .56929 L p .65 .799 .954 r
F P
0 g
s
.75228 .56929 m .76299 .57198 L .71332 .60054 L p .65 .799 .954 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67086 .57437 L p .626 .73 .922 r
F P
0 g
s
.67086 .57437 m .67949 .58029 L .6307 .59568 L p .626 .73 .922 r
F P
0 g
s
.41561 .57609 m .42198 .57263 L .46933 .58562 L p .546 .752 .972 r
F P
0 g
s
.47278 .58158 m .46933 .58562 L .42198 .57263 L p .504 .754 .985 r
F P
0 g
s
.46933 .58562 m .47278 .58158 L .52014 .58665 L p .566 .773 .976 r
F P
0 g
s
.57063 .59091 m .56779 .58493 L .61309 .57646 L p .635 .745 .927 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57063 .59091 L p .635 .745 .927 r
F P
0 g
s
.27973 .54871 m .29108 .54269 L .33545 .57459 L p .723 .754 .877 r
F P
0 g
s
.34446 .56816 m .33545 .57459 L .29108 .54269 L p .7 .752 .893 r
F P
0 g
s
.36246 .55856 m .37146 .55547 L .41561 .57609 L p .573 .738 .954 r
F P
0 g
s
.42198 .57263 m .41561 .57609 L .37146 .55547 L p .515 .731 .971 r
F P
0 g
s
.70497 .59594 m .69655 .59106 L .74149 .5661 L p .641 .781 .949 r
F P
0 g
s
.74149 .5661 m .75228 .56929 L .70497 .59594 L p .641 .781 .949 r
F P
0 g
s
.52047 .58177 m .52014 .58665 L .47278 .58158 L p .555 .783 .984 r
F P
0 g
s
.52014 .58665 m .52047 .58177 L .56493 .57906 L p .618 .777 .957 r
F P
0 g
s
.56493 .57906 m .56779 .58493 L .52014 .58665 L p .618 .777 .957 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66216 .56814 L p .629 .721 .913 r
F P
0 g
s
.66216 .56814 m .67086 .57437 L .62488 .58932 L p .629 .721 .913 r
F P
0 g
s
.29108 .54269 m .3024 .53762 L .34446 .56816 L p .7 .752 .893 r
F P
0 g
s
.35346 .56279 m .34446 .56816 L .3024 .53762 L p .667 .748 .911 r
F P
0 g
s
.56779 .58493 m .56493 .57906 L .60713 .56996 L p .645 .748 .924 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56779 .58493 L p .645 .748 .924 r
F P
0 g
s
.42198 .57263 m .42839 .56994 L .47278 .58158 L p .504 .754 .985 r
F P
0 g
s
.47626 .57796 m .47278 .58158 L .42839 .56994 L p .469 .755 .992 r
F P
0 g
s
.47278 .58158 m .47626 .57796 L .52047 .58177 L p .555 .783 .984 r
F P
0 g
s
.69655 .59106 m .68806 .58585 L .73059 .56232 L p .633 .761 .94 r
F P
0 g
s
.73059 .56232 m .74149 .5661 L .69655 .59106 L p .633 .761 .94 r
F P
0 g
s
.3024 .53762 m .31369 .53367 L .35346 .56279 L p .667 .748 .911 r
F P
0 g
s
.36246 .55856 m .35346 .56279 L .31369 .53367 L p .622 .74 .931 r
F P
0 g
s
.37146 .55547 m .38048 .55344 L .42198 .57263 L p .515 .731 .971 r
F P
0 g
s
.42839 .56994 m .42198 .57263 L .38048 .55344 L p .453 .719 .981 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .6534 .56162 L p .634 .715 .905 r
F P
0 g
s
.6534 .56162 m .66216 .56814 L .61901 .58292 L p .634 .715 .905 r
F P
0 g
s
.5208 .57701 m .52047 .58177 L .47626 .57796 L p .556 .794 .988 r
F P
0 g
s
.52047 .58177 m .5208 .57701 L .56204 .57323 L p .629 .787 .958 r
F P
0 g
s
.56204 .57323 m .56493 .57906 L .52047 .58177 L p .629 .787 .958 r
F P
0 g
s
.68806 .58585 m .67949 .58029 L .71961 .5579 L p .625 .739 .929 r
F P
0 g
s
.71961 .5579 m .73059 .56232 L .68806 .58585 L p .625 .739 .929 r
F P
0 g
s
.56493 .57906 m .56204 .57323 L .60112 .5634 L p .657 .752 .92 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57906 L p .657 .752 .92 r
F P
0 g
s
.31369 .53367 m .32495 .53092 L .36246 .55856 L p .622 .74 .931 r
F P
0 g
s
.37146 .55547 m .36246 .55856 L .32495 .53092 L p .566 .727 .95 r
F P
0 g
s
.79464 .57831 m .78416 .57634 L .82392 .53563 L p .704 .846 .95 r
F P
0 g
s
.82392 .53563 m .83625 .53514 L .79464 .57831 L p .704 .846 .95 r
F P
0 g
s
.42839 .56994 m .43484 .5678 L .47626 .57796 L p .469 .755 .992 r
F P
0 g
s
.47978 .57455 m .47626 .57796 L .43484 .5678 L p .452 .759 .995 r
F P
0 g
s
.47626 .57796 m .47978 .57455 L .5208 .57701 L p .556 .794 .988 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64459 .55489 L p .642 .711 .897 r
F P
0 g
s
.64459 .55489 m .6534 .56162 L .61309 .57646 L p .642 .711 .897 r
F P
0 g
s
.38048 .55344 m .38954 .55229 L .42839 .56994 L p .453 .719 .981 r
F P
0 g
s
.43484 .5678 m .42839 .56994 L .38954 .55229 L p .401 .706 .984 r
F P
0 g
s
.67949 .58029 m .67086 .57437 L .70855 .55285 L p .62 .719 .917 r
F P
0 g
s
.70855 .55285 m .71961 .5579 L .67949 .58029 L p .62 .719 .917 r
F P
0 g
s
.78416 .57634 m .77362 .57428 L .81153 .53602 L p .698 .845 .953 r
F P
0 g
s
.81153 .53602 m .82392 .53563 L .78416 .57634 L p .698 .845 .953 r
F P
0 g
s
.52114 .57219 m .5208 .57701 L .47978 .57455 L p .57 .806 .988 r
F P
0 g
s
.5208 .57701 m .52114 .57219 L .55913 .56733 L p .645 .796 .955 r
F P
0 g
s
.55913 .56733 m .56204 .57323 L .5208 .57701 L p .645 .796 .955 r
F P
0 g
s
.32495 .53092 m .33619 .52939 L .37146 .55547 L p .566 .727 .95 r
F P
0 g
s
.38048 .55344 m .37146 .55547 L .33619 .52939 L p .502 .707 .962 r
F P
0 g
s
.56204 .57323 m .55913 .56733 L .59506 .55679 L p .672 .757 .914 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56204 .57323 L p .672 .757 .914 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63572 .54803 L p .652 .71 .89 r
F P
0 g
s
.63572 .54803 m .64459 .55489 L .60713 .56996 L p .652 .71 .89 r
F P
0 g
s
.25696 .56264 m .24558 .56996 L .20758 .52532 L p .761 .782 .871 r
F P
0 g
s
.67086 .57437 m .66216 .56814 L .69741 .54721 L p .617 .701 .904 r
F P
0 g
s
.69741 .54721 m .70855 .55285 L .67086 .57437 L p .617 .701 .904 r
F P
0 g
s
.77362 .57428 m .76299 .57198 L .79906 .53607 L p .689 .836 .954 r
F P
0 g
s
.79906 .53607 m .81153 .53602 L .77362 .57428 L p .689 .836 .954 r
F P
0 g
s
.43484 .5678 m .44135 .56594 L .47978 .57455 L p .452 .759 .995 r
F P
0 g
s
.48333 .57109 m .47978 .57455 L .44135 .56594 L p .459 .769 .997 r
F P
0 g
s
.47978 .57455 m .48333 .57109 L .52114 .57219 L p .57 .806 .988 r
F P
0 g
s
.20758 .52532 m .22083 .51981 L .25696 .56264 L p .761 .782 .871 r
F P
0 g
s
.26835 .55545 m .25696 .56264 L .22083 .51981 L p .758 .782 .873 r
F P
0 g
s
.38954 .55229 m .39865 .55177 L .43484 .5678 L p .401 .706 .984 r
F P
0 g
s
.44135 .56594 m .43484 .5678 L .39865 .55177 L p .37 .7 .984 r
F P
0 g
s
.22083 .51981 m .23406 .51444 L .26835 .55545 L p .758 .782 .873 r
F P
0 g
s
.27973 .54871 m .26835 .55545 L .23406 .51444 L p .748 .78 .879 r
F P
0 g
s
.33619 .52939 m .34744 .52896 L .38048 .55344 L p .502 .707 .962 r
F P
0 g
s
.38954 .55229 m .38048 .55344 L .34744 .52896 L p .438 .684 .968 r
F P
0 g
s
.66216 .56814 m .6534 .56162 L .68621 .54107 L p .617 .687 .893 r
F P
0 g
s
.68621 .54107 m .69741 .54721 L .66216 .56814 L p .617 .687 .893 r
F P
0 g
s
.23406 .51444 m .24725 .50952 L .27973 .54871 L p .748 .78 .879 r
F P
0 g
s
.29108 .54269 m .27973 .54871 L .24725 .50952 L p .73 .776 .89 r
F P
0 g
s
.76299 .57198 m .75228 .56929 L .78649 .5356 L p .675 .819 .952 r
F P
0 g
s
.78649 .5356 m .79906 .53607 L .76299 .57198 L p .675 .819 .952 r
F P
0 g
s
.52148 .56713 m .52114 .57219 L .48333 .57109 L p .596 .817 .984 r
F P
0 g
s
.52114 .57219 m .52148 .56713 L .55618 .56128 L p .665 .802 .948 r
F P
0 g
s
.55618 .56128 m .55913 .56733 L .52114 .57219 L p .665 .802 .948 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62679 .54113 L p .665 .712 .883 r
F P
0 g
s
.62679 .54113 m .63572 .54803 L .60112 .5634 L p .665 .712 .883 r
F P
0 g
s
.55913 .56733 m .55618 .56128 L .58896 .55013 L p .688 .761 .908 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55913 .56733 L p .688 .761 .908 r
F P
0 g
s
.24725 .50952 m .26039 .50531 L .29108 .54269 L p .73 .776 .89 r
F P
0 g
s
.3024 .53762 m .29108 .54269 L .26039 .50531 L p .704 .769 .903 r
F P
0 g
s
.6534 .56162 m .64459 .55489 L .67495 .53458 L p .621 .677 .882 r
F P
0 g
s
.67495 .53458 m .68621 .54107 L .6534 .56162 L p .621 .677 .882 r
F P
0 g
s
.75228 .56929 m .74149 .5661 L .77383 .53442 L p .659 .796 .948 r
F P
0 g
s
.77383 .53442 m .78649 .5356 L .75228 .56929 L p .659 .796 .948 r
F P
0 g
s
.44135 .56594 m .44793 .56405 L .48333 .57109 L p .459 .769 .997 r
F P
0 g
s
.48692 .56732 m .48333 .57109 L .44793 .56405 L p .491 .785 .997 r
F P
0 g
s
.48333 .57109 m .48692 .56732 L .52148 .56713 L p .596 .817 .984 r
F P
0 g
s
.26039 .50531 m .27346 .50205 L .3024 .53762 L p .704 .769 .903 r
F P
0 g
s
.31369 .53367 m .3024 .53762 L .27346 .50205 L p .668 .757 .917 r
F P
0 g
s
.34744 .52896 m .35871 .52947 L .38954 .55229 L p .438 .684 .968 r
F P
0 g
s
.39865 .55177 m .38954 .55229 L .35871 .52947 L p .384 .663 .968 r
F P
0 g
s
.39865 .55177 m .40784 .55159 L .44135 .56594 L p .37 .7 .984 r
F P
0 g
s
.44793 .56405 m .44135 .56594 L .40784 .55159 L p .371 .706 .985 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61782 .5343 L p .678 .716 .877 r
F P
0 g
s
.61782 .5343 m .62679 .54113 L .59506 .55679 L p .678 .716 .877 r
F P
0 g
s
.27346 .50205 m .28648 .4999 L .31369 .53367 L p .668 .757 .917 r
F P
0 g
s
.32495 .53092 m .31369 .53367 L .28648 .4999 L p .622 .74 .931 r
F P
0 g
s
.52183 .56164 m .52148 .56713 L .48692 .56732 L p .631 .825 .975 r
F P
0 g
s
.52148 .56713 m .52183 .56164 L .55321 .55498 L p .688 .807 .939 r
F P
0 g
s
.55321 .55498 m .55618 .56128 L .52148 .56713 L p .688 .807 .939 r
F P
0 g
s
.74149 .5661 m .73059 .56232 L .76107 .53241 L p .642 .768 .94 r
F P
0 g
s
.76107 .53241 m .77383 .53442 L .74149 .5661 L p .642 .768 .94 r
F P
0 g
s
.55618 .56128 m .55321 .55498 L .5828 .54342 L p .705 .766 .9 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55618 .56128 L p .705 .766 .9 r
F P
0 g
s
.64459 .55489 m .63572 .54803 L .66364 .5279 L p .628 .672 .873 r
F P
0 g
s
.66364 .5279 m .67495 .53458 L .64459 .55489 L p .628 .672 .873 r
F P
0 g
s
.28648 .4999 m .29943 .49893 L .32495 .53092 L p .622 .74 .931 r
F P
0 g
s
.33619 .52939 m .32495 .53092 L .29943 .49893 L p .568 .716 .942 r
F P
0 g
s
.73059 .56232 m .71961 .5579 L .74821 .52952 L p .625 .739 .929 r
F P
0 g
s
.74821 .52952 m .76107 .53241 L .73059 .56232 L p .625 .739 .929 r
F P
0 g
s
.35871 .52947 m .37003 .53066 L .39865 .55177 L p .384 .663 .968 r
F P
0 g
s
.40784 .55159 m .39865 .55177 L .37003 .53066 L p .353 .65 .967 r
F P
0 g
s
.44793 .56405 m .45458 .5618 L .48692 .56732 L p .491 .785 .997 r
F P
0 g
s
.49056 .56298 m .48692 .56732 L .45458 .5618 L p .541 .803 .994 r
F P
0 g
s
.48692 .56732 m .49056 .56298 L .52183 .56164 L p .631 .825 .975 r
F P
0 g
s
.63572 .54803 m .62679 .54113 L .65231 .5212 L p .638 .672 .866 r
F P
0 g
s
.65231 .5212 m .66364 .5279 L .63572 .54803 L p .638 .672 .866 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .6088 .52761 L p .694 .722 .871 r
F P
0 g
s
.6088 .52761 m .61782 .5343 L .58896 .55013 L p .694 .722 .871 r
F P
0 g
s
.40784 .55159 m .41711 .55139 L .44793 .56405 L p .371 .706 .985 r
F P
0 g
s
.45458 .5618 m .44793 .56405 L .41711 .55139 L p .405 .724 .989 r
F P
0 g
s
.71961 .5579 m .70855 .55285 L .73527 .52574 L p .609 .711 .917 r
F P
0 g
s
.73527 .52574 m .74821 .52952 L .71961 .5579 L p .609 .711 .917 r
F P
0 g
s
.5502 .54835 m .55321 .55498 L .52183 .56164 L p .71 .808 .926 r
F P
0 g
s
.55321 .55498 m .5502 .54835 L .5766 .53665 L p .721 .77 .891 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55321 .55498 L p .721 .77 .891 r
F P
0 g
s
.29943 .49893 m .31234 .49915 L .33619 .52939 L p .568 .716 .942 r
F P
0 g
s
.34744 .52896 m .33619 .52939 L .31234 .49915 L p .511 .689 .948 r
F P
0 g
s
.52218 .55557 m .52183 .56164 L .49056 .56298 L p .667 .829 .961 r
F P
0 g
s
.52183 .56164 m .52218 .55557 L .5502 .54835 L p .71 .808 .926 r
F P
0 g
s
.62679 .54113 m .61782 .5343 L .64094 .51467 L p .651 .676 .861 r
F P
0 g
s
.64094 .51467 m .65231 .5212 L .62679 .54113 L p .651 .676 .861 r
F P
0 g
s
.70855 .55285 m .69741 .54721 L .72225 .52114 L p .597 .685 .903 r
F P
0 g
s
.72225 .52114 m .73527 .52574 L .70855 .55285 L p .597 .685 .903 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59973 .52116 L p .71 .73 .867 r
F P
0 g
s
.59973 .52116 m .6088 .52761 L .5828 .54342 L p .71 .73 .867 r
F P
0 g
s
.37003 .53066 m .38142 .53221 L .40784 .55159 L p .353 .65 .967 r
F P
0 g
s
.41711 .55139 m .40784 .55159 L .38142 .53221 L p .353 .652 .968 r
F P
0 g
s
.31234 .49915 m .32523 .50046 L .34744 .52896 L p .511 .689 .948 r
F P
0 g
s
.35871 .52947 m .34744 .52896 L .32523 .50046 L p .457 .66 .949 r
F P
0 g
s
.45458 .5618 m .46132 .55888 L .49056 .56298 L p .541 .803 .994 r
F P
0 g
s
.49425 .55785 m .49056 .56298 L .46132 .55888 L p .599 .816 .983 r
F P
0 g
s
.49056 .56298 m .49425 .55785 L .52218 .55557 L p .667 .829 .961 r
F P
0 g
s
.41711 .55139 m .42648 .55081 L .45458 .5618 L p .405 .724 .989 r
F P
0 g
s
.46132 .55888 m .45458 .5618 L .42648 .55081 L p .464 .75 .991 r
F P
0 g
s
.69741 .54721 m .68621 .54107 L .70918 .51587 L p .59 .665 .891 r
F P
0 g
s
.70918 .51587 m .72225 .52114 L .69741 .54721 L p .59 .665 .891 r
F P
0 g
s
.61782 .5343 m .6088 .52761 L .62954 .50849 L p .667 .684 .857 r
F P
0 g
s
.62954 .50849 m .64094 .51467 L .61782 .5343 L p .667 .684 .857 r
F P
0 g
s
.54717 .54132 m .5502 .54835 L .52218 .55557 L p .731 .807 .912 r
F P
0 g
s
.5502 .54835 m .54717 .54132 L .57035 .52982 L p .737 .774 .883 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .5502 .54835 L p .737 .774 .883 r
F P
0 g
s
.52253 .54878 m .52218 .55557 L .49425 .55785 L p .702 .827 .942 r
F P
0 g
s
.52218 .55557 m .52253 .54878 L .54717 .54132 L p .731 .807 .912 r
F P
0 g
s
.68621 .54107 m .67495 .53458 L .69608 .51012 L p .587 .651 .88 r
F P
0 g
s
.69608 .51012 m .70918 .51587 L .68621 .54107 L p .587 .651 .88 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59061 .515 L p .726 .739 .862 r
F P
0 g
s
.59061 .515 m .59973 .52116 L .5766 .53665 L p .726 .739 .862 r
F P
0 g
s
.32523 .50046 m .33812 .50269 L .35871 .52947 L p .457 .66 .949 r
F P
0 g
s
.37003 .53066 m .35871 .52947 L .33812 .50269 L p .415 .637 .947 r
F P
0 g
s
.6088 .52761 m .59973 .52116 L .61812 .50281 L p .684 .695 .854 r
F P
0 g
s
.61812 .50281 m .62954 .50849 L .6088 .52761 L p .684 .695 .854 r
F P
0 g
s
.38142 .53221 m .39289 .53375 L .41711 .55139 L p .353 .652 .968 r
F P
0 g
s
.42648 .55081 m .41711 .55139 L .39289 .53375 L p .384 .669 .971 r
F P
0 g
s
.83625 .53514 m .82392 .53563 L .84551 .48896 L p .737 .85 .933 r
F P
0 g
s
.84551 .48896 m .85906 .48583 L .83625 .53514 L p .737 .85 .933 r
F P
0 g
s
.67495 .53458 m .66364 .5279 L .68296 .50411 L p .59 .643 .871 r
F P
0 g
s
.68296 .50411 m .69608 .51012 L .67495 .53458 L p .59 .643 .871 r
F P
0 g
s
.46132 .55888 m .46814 .55501 L .49425 .55785 L p .599 .816 .983 r
F P
0 g
s
.49798 .55174 m .49425 .55785 L .46814 .55501 L p .653 .822 .964 r
F P
0 g
s
.49425 .55785 m .49798 .55174 L .52253 .54878 L p .702 .827 .942 r
F P
0 g
s
.42648 .55081 m .43595 .54951 L .46132 .55888 L p .464 .75 .991 r
F P
0 g
s
.46814 .55501 m .46132 .55888 L .43595 .54951 L p .536 .774 .986 r
F P
0 g
s
.66364 .5279 m .65231 .5212 L .66983 .49812 L p .598 .642 .865 r
F P
0 g
s
.66983 .49812 m .68296 .50411 L .66364 .5279 L p .598 .642 .865 r
F P
0 g
s
.5441 .53384 m .54717 .54132 L .52253 .54878 L p .749 .804 .897 r
F P
0 g
s
.54717 .54132 m .5441 .53384 L .56404 .52294 L p .752 .777 .874 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54717 .54132 L p .752 .777 .874 r
F P
0 g
s
.82392 .53563 m .81153 .53602 L .83193 .49196 L p .732 .849 .936 r
F P
0 g
s
.83193 .49196 m .84551 .48896 L .82392 .53563 L p .732 .849 .936 r
F P
0 g
s
.59973 .52116 m .59061 .515 L .60667 .49776 L p .704 .709 .852 r
F P
0 g
s
.60667 .49776 m .61812 .50281 L .59973 .52116 L p .704 .709 .852 r
F P
0 g
s
.52289 .5412 m .52253 .54878 L .49798 .55174 L p .731 .821 .921 r
F P
0 g
s
.52253 .54878 m .52289 .5412 L .5441 .53384 L p .749 .804 .897 r
F P
0 g
s
.33812 .50269 m .35104 .50559 L .37003 .53066 L p .415 .637 .947 r
F P
0 g
s
.38142 .53221 m .37003 .53066 L .35104 .50559 L p .394 .623 .944 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58144 .50918 L p .742 .748 .858 r
F P
0 g
s
.58144 .50918 m .59061 .515 L .57035 .52982 L p .742 .748 .858 r
F P
0 g
s
.65231 .5212 m .64094 .51467 L .65671 .49239 L p .612 .646 .86 r
F P
0 g
s
.65671 .49239 m .66983 .49812 L .65231 .5212 L p .612 .646 .86 r
F P
0 g
s
.81153 .53602 m .79906 .53607 L .81827 .49457 L p .721 .84 .938 r
F P
0 g
s
.81827 .49457 m .83193 .49196 L .81153 .53602 L p .721 .84 .938 r
F P
0 g
s
.39289 .53375 m .40446 .53491 L .42648 .55081 L p .384 .669 .971 r
F P
0 g
s
.43595 .54951 m .42648 .55081 L .40446 .53491 L p .441 .695 .973 r
F P
0 g
s
.64094 .51467 m .62954 .50849 L .6436 .48719 L p .63 .656 .857 r
F P
0 g
s
.6436 .48719 m .65671 .49239 L .64094 .51467 L p .63 .656 .857 r
F P
0 g
s
.20348 .47193 m .21781 .46895 L .23406 .51444 L p .756 .808 .895 r
F P
0 g
s
.23406 .51444 m .22083 .51981 L .20348 .47193 L p .756 .808 .895 r
F P
0 g
s
.24725 .50952 m .23406 .51444 L .21781 .46895 L p .745 .804 .9 r
F P
0 g
s
.18911 .47507 m .20348 .47193 L .22083 .51981 L p .759 .808 .892 r
F P
0 g
s
.22083 .51981 m .20758 .52532 L .18911 .47507 L p .759 .808 .892 r
F P
0 g
s
.21781 .46895 m .23207 .46637 L .24725 .50952 L p .745 .804 .9 r
F P
0 g
s
.26039 .50531 m .24725 .50952 L .23207 .46637 L p .726 .796 .908 r
F P
0 g
s
.46814 .55501 m .47504 .54997 L .49798 .55174 L p .653 .822 .964 r
F P
0 g
s
.50175 .54453 m .49798 .55174 L .47504 .54997 L p .699 .82 .94 r
F P
0 g
s
.49798 .55174 m .50175 .54453 L .52289 .5412 L p .731 .821 .921 r
F P
0 g
s
.59061 .515 m .58144 .50918 L .59518 .49341 L p .723 .724 .85 r
F P
0 g
s
.59518 .49341 m .60667 .49776 L .59061 .515 L p .723 .724 .85 r
F P
0 g
s
.43595 .54951 m .44553 .54715 L .46814 .55501 L p .536 .774 .986 r
F P
0 g
s
.47504 .54997 m .46814 .55501 L .44553 .54715 L p .606 .791 .97 r
F P
0 g
s
.23207 .46637 m .24624 .46445 L .26039 .50531 L p .726 .796 .908 r
F P
0 g
s
.27346 .50205 m .26039 .50531 L .24624 .46445 L p .699 .783 .916 r
F P
0 g
s
.79906 .53607 m .78649 .5356 L .80453 .49651 L p .703 .824 .94 r
F P
0 g
s
.80453 .49651 m .81827 .49457 L .79906 .53607 L p .703 .824 .94 r
F P
0 g
s
.54101 .52591 m .5441 .53384 L .52289 .5412 L p .765 .8 .882 r
F P
0 g
s
.5441 .53384 m .54101 .52591 L .55769 .51601 L p .765 .78 .865 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .5441 .53384 L p .765 .78 .865 r
F P
0 g
s
.62954 .50849 m .61812 .50281 L .63051 .48272 L p .652 .671 .856 r
F P
0 g
s
.63051 .48272 m .6436 .48719 L .62954 .50849 L p .652 .671 .856 r
F P
0 g
s
.24624 .46445 m .26033 .46339 L .27346 .50205 L p .699 .783 .916 r
F P
0 g
s
.28648 .4999 m .27346 .50205 L .26033 .46339 L p .664 .764 .924 r
F P
0 g
s
.35104 .50559 m .364 .50884 L .38142 .53221 L p .394 .623 .944 r
F P
0 g
s
.39289 .53375 m .38142 .53221 L .364 .50884 L p .397 .623 .943 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57222 .50371 L p .757 .758 .853 r
F P
0 g
s
.57222 .50371 m .58144 .50918 L .56404 .52294 L p .757 .758 .853 r
F P
0 g
s
.52325 .53278 m .52289 .5412 L .50175 .54453 L p .754 .813 .9 r
F P
0 g
s
.52289 .5412 m .52325 .53278 L .54101 .52591 L p .765 .8 .882 r
F P
0 g
s
.26033 .46339 m .27432 .46334 L .28648 .4999 L p .664 .764 .924 r
F P
0 g
s
.29943 .49893 m .28648 .4999 L .27432 .46334 L p .623 .739 .93 r
F P
0 g
s
.78649 .5356 m .77383 .53442 L .7907 .49759 L p .679 .8 .939 r
F P
0 g
s
.7907 .49759 m .80453 .49651 L .78649 .5356 L p .679 .8 .939 r
F P
0 g
s
.61812 .50281 m .60667 .49776 L .61742 .47917 L p .676 .689 .854 r
F P
0 g
s
.61742 .47917 m .63051 .48272 L .61812 .50281 L p .676 .689 .854 r
F P
0 g
s
.40446 .53491 m .41615 .53533 L .43595 .54951 L p .441 .695 .973 r
F P
0 g
s
.44553 .54715 m .43595 .54951 L .41615 .53533 L p .511 .724 .969 r
F P
0 g
s
.27432 .46334 m .28822 .46437 L .29943 .49893 L p .623 .739 .93 r
F P
0 g
s
.31234 .49915 m .29943 .49893 L .28822 .46437 L p .577 .71 .933 r
F P
0 g
s
.58144 .50918 m .57222 .50371 L .58366 .4898 L p .742 .739 .849 r
F P
0 g
s
.58366 .4898 m .59518 .49341 L .58144 .50918 L p .742 .739 .849 r
F P
0 g
s
.77383 .53442 m .76107 .53241 L .77678 .49764 L p .652 .771 .936 r
F P
0 g
s
.77678 .49764 m .7907 .49759 L .77383 .53442 L p .652 .771 .936 r
F P
0 g
s
.47504 .54997 m .48202 .5436 L .50175 .54453 L p .699 .82 .94 r
F P
0 g
s
.50556 .53617 m .50175 .54453 L .48202 .5436 L p .734 .814 .914 r
F P
0 g
s
.50175 .54453 m .50556 .53617 L .52325 .53278 L p .754 .813 .9 r
F P
0 g
s
.44553 .54715 m .45522 .54351 L .47504 .54997 L p .606 .791 .97 r
F P
0 g
s
.48202 .5436 m .47504 .54997 L .45522 .54351 L p .666 .799 .946 r
F P
0 g
s
.364 .50884 m .37704 .5121 L .39289 .53375 L p .397 .623 .943 r
F P
0 g
s
.40446 .53491 m .39289 .53375 L .37704 .5121 L p .424 .635 .944 r
F P
0 g
s
.60667 .49776 m .59518 .49341 L .60434 .47663 L p .701 .708 .853 r
F P
0 g
s
.60434 .47663 m .61742 .47917 L .60667 .49776 L p .701 .708 .853 r
F P
0 g
s
.28822 .46437 m .30206 .46648 L .31234 .49915 L p .577 .71 .933 r
F P
0 g
s
.32523 .50046 m .31234 .49915 L .30206 .46648 L p .533 .679 .932 r
F P
0 g
s
.53788 .51752 m .54101 .52591 L .52325 .53278 L p .777 .796 .868 r
F P
0 g
s
.54101 .52591 m .53788 .51752 L .55128 .50901 L p .776 .782 .857 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54101 .52591 L p .776 .782 .857 r
F P
0 g
s
.76107 .53241 m .74821 .52952 L .76277 .49661 L p .624 .739 .929 r
F P
0 g
s
.76277 .49661 m .77678 .49764 L .76107 .53241 L p .624 .739 .929 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56293 .49859 L p .77 .766 .85 r
F P
0 g
s
.56293 .49859 m .57222 .50371 L .55769 .51601 L p .77 .766 .85 r
F P
0 g
s
.52362 .52354 m .52325 .53278 L .50556 .53617 L p .771 .805 .88 r
F P
0 g
s
.52325 .53278 m .52362 .52354 L .53788 .51752 L p .777 .796 .868 r
F P
0 g
s
.74821 .52952 m .73527 .52574 L .74869 .49448 L p .596 .706 .92 r
F P
0 g
s
.74869 .49448 m .76277 .49661 L .74821 .52952 L p .596 .706 .92 r
F P
0 g
s
.57222 .50371 m .56293 .49859 L .57208 .48691 L p .76 .753 .847 r
F P
0 g
s
.57208 .48691 m .58366 .4898 L .57222 .50371 L p .76 .753 .847 r
F P
0 g
s
.30206 .46648 m .31584 .46958 L .32523 .50046 L p .533 .679 .932 r
F P
0 g
s
.33812 .50269 m .32523 .50046 L .31584 .46958 L p .496 .651 .928 r
F P
0 g
s
.41615 .53533 m .42795 .53468 L .44553 .54715 L p .511 .724 .969 r
F P
0 g
s
.45522 .54351 m .44553 .54715 L .42795 .53468 L p .583 .749 .957 r
F P
0 g
s
.73527 .52574 m .72225 .52114 L .73455 .49136 L p .573 .677 .91 r
F P
0 g
s
.73455 .49136 m .74869 .49448 L .73527 .52574 L p .573 .677 .91 r
F P
0 g
s
.59518 .49341 m .58366 .4898 L .59124 .47516 L p .726 .727 .851 r
F P
0 g
s
.59124 .47516 m .60434 .47663 L .59518 .49341 L p .726 .727 .851 r
F P
0 g
s
.72225 .52114 m .70918 .51587 L .72039 .48742 L p .555 .652 .9 r
F P
0 g
s
.72039 .48742 m .73455 .49136 L .72225 .52114 L p .555 .652 .9 r
F P
0 g
s
.70918 .51587 m .69608 .51012 L .70623 .48289 L p .545 .635 .89 r
F P
0 g
s
.70623 .48289 m .72039 .48742 L .70918 .51587 L p .545 .635 .89 r
F P
0 g
s
.69608 .51012 m .68296 .50411 L .69208 .47807 L p .544 .625 .883 r
F P
0 g
s
.69208 .47807 m .70623 .48289 L .69608 .51012 L p .544 .625 .883 r
F P
0 g
s
.37704 .5121 m .39015 .51499 L .40446 .53491 L p .424 .635 .944 r
F P
0 g
s
.41615 .53533 m .40446 .53491 L .39015 .51499 L p .47 .658 .943 r
F P
0 g
s
.68296 .50411 m .66983 .49812 L .67797 .47327 L p .55 .623 .877 r
F P
0 g
s
.67797 .47327 m .69208 .47807 L .68296 .50411 L p .55 .623 .877 r
F P
0 g
s
.45522 .54351 m .46501 .5384 L .48202 .5436 L p .666 .799 .946 r
F P
0 g
s
.48907 .53584 m .48202 .5436 L .46501 .5384 L p .713 .8 .919 r
F P
0 g
s
.48202 .5436 m .48907 .53584 L .50556 .53617 L p .734 .814 .914 r
F P
0 g
s
.50941 .52669 m .50556 .53617 L .48907 .53584 L p .759 .806 .89 r
F P
0 g
s
.50556 .53617 m .50941 .52669 L .52362 .52354 L p .771 .805 .88 r
F P
0 g
s
.66983 .49812 m .65671 .49239 L .66391 .46883 L p .565 .628 .873 r
F P
0 g
s
.66391 .46883 m .67797 .47327 L .66983 .49812 L p .565 .628 .873 r
F P
0 g
s
.65671 .49239 m .6436 .48719 L .64991 .46503 L p .587 .641 .871 r
F P
0 g
s
.64991 .46503 m .66391 .46883 L .65671 .49239 L p .587 .641 .871 r
F P
0 g
s
.31584 .46958 m .32959 .4735 L .33812 .50269 L p .496 .651 .928 r
F P
0 g
s
.35104 .50559 m .33812 .50269 L .32959 .4735 L p .47 .629 .922 r
F P
0 g
s
.53473 .50871 m .53788 .51752 L .52362 .52354 L p .786 .791 .857 r
F P
0 g
s
.53788 .51752 m .53473 .50871 L .54482 .50197 L p .785 .783 .85 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53788 .51752 L p .785 .783 .85 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55358 .49377 L p .781 .774 .846 r
F P
0 g
s
.55358 .49377 m .56293 .49859 L .55128 .50901 L p .781 .774 .846 r
F P
0 g
s
.6436 .48719 m .63051 .48272 L .63597 .46216 L p .615 .659 .87 r
F P
0 g
s
.63597 .46216 m .64991 .46503 L .6436 .48719 L p .615 .659 .87 r
F P
0 g
s
.58366 .4898 m .57208 .48691 L .57811 .47473 L p .749 .746 .849 r
F P
0 g
s
.57811 .47473 m .59124 .47516 L .58366 .4898 L p .749 .746 .849 r
F P
0 g
s
.63051 .48272 m .61742 .47917 L .62208 .46041 L p .646 .68 .868 r
F P
0 g
s
.62208 .46041 m .63597 .46216 L .63051 .48272 L p .646 .68 .868 r
F P
0 g
s
.52399 .51355 m .52362 .52354 L .50941 .52669 L p .783 .797 .864 r
F P
0 g
s
.52362 .52354 m .52399 .51355 L .53473 .50871 L p .786 .791 .857 r
F P
0 g
s
.56293 .49859 m .55358 .49377 L .56045 .48466 L p .775 .766 .844 r
F P
0 g
s
.56045 .48466 m .57208 .48691 L .56293 .49859 L p .775 .766 .844 r
F P
0 g
s
.42795 .53468 m .43986 .5327 L .45522 .54351 L p .583 .749 .957 r
F P
0 g
s
.46501 .5384 m .45522 .54351 L .43986 .5327 L p .646 .767 .937 r
F P
0 g
s
.61742 .47917 m .60434 .47663 L .60823 .45993 L p .678 .703 .865 r
F P
0 g
s
.60823 .45993 m .62208 .46041 L .61742 .47917 L p .678 .703 .865 r
F P
0 g
s
.32959 .4735 m .34334 .47803 L .35104 .50559 L p .47 .629 .922 r
F P
0 g
s
.364 .50884 m .35104 .50559 L .34334 .47803 L p .459 .616 .917 r
F P
0 g
s
.39015 .51499 m .40337 .51716 L .41615 .53533 L p .47 .658 .943 r
F P
0 g
s
.42795 .53468 m .41615 .53533 L .40337 .51716 L p .527 .685 .939 r
F P
0 g
s
.46501 .5384 m .47488 .53177 L .48907 .53584 L p .713 .8 .919 r
F P
0 g
s
.49619 .52673 m .48907 .53584 L .47488 .53177 L p .746 .797 .894 r
F P
0 g
s
.48907 .53584 m .49619 .52673 L .50941 .52669 L p .759 .806 .89 r
F P
0 g
s
.60434 .47663 m .59124 .47516 L .59441 .46075 L p .71 .725 .861 r
F P
0 g
s
.59441 .46075 m .60823 .45993 L .60434 .47663 L p .71 .725 .861 r
F P
0 g
s
.51329 .51618 m .50941 .52669 L .49619 .52673 L p .777 .798 .869 r
F P
0 g
s
.50941 .52669 m .51329 .51618 L .52399 .51355 L p .783 .797 .864 r
F P
0 g
s
.57208 .48691 m .56045 .48466 L .56495 .47523 L p .769 .761 .846 r
F P
0 g
s
.56495 .47523 m .57811 .47473 L .57208 .48691 L p .769 .761 .846 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53473 .50871 L p .792 .784 .845 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54417 .4892 L p .79 .779 .843 r
F P
0 g
s
.54417 .4892 m .55358 .49377 L .54482 .50197 L p .79 .779 .843 r
F P
0 g
s
.53155 .49954 m .53473 .50871 L .52399 .51355 L p .793 .788 .848 r
F P
0 g
s
.53473 .50871 m .53155 .49954 L .5383 .49486 L p .792 .784 .845 r
F P
0 g
s
.59124 .47516 m .57811 .47473 L .5806 .46285 L p .739 .745 .856 r
F P
0 g
s
.5806 .46285 m .59441 .46075 L .59124 .47516 L p .739 .745 .856 r
F P
0 g
s
.43986 .5327 m .45187 .52922 L .46501 .5384 L p .646 .767 .937 r
F P
0 g
s
.47488 .53177 m .46501 .5384 L .45187 .52922 L p .697 .777 .913 r
F P
0 g
s
.55358 .49377 m .54417 .4892 L .54875 .48295 L p .787 .775 .842 r
F P
0 g
s
.54875 .48295 m .56045 .48466 L .55358 .49377 L p .787 .775 .842 r
F P
0 g
s
.52436 .50293 m .52399 .51355 L .51329 .51618 L p .792 .791 .851 r
F P
0 g
s
.52399 .51355 m .52436 .50293 L .53155 .49954 L p .793 .788 .848 r
F P
0 g
s
.34334 .47803 m .35711 .48287 L .364 .50884 L p .459 .616 .917 r
F P
0 g
s
.37704 .5121 m .364 .50884 L .35711 .48287 L p .465 .615 .913 r
F P
0 g
s
.40337 .51716 m .41668 .51831 L .42795 .53468 L p .527 .685 .939 r
F P
0 g
s
.43986 .5327 m .42795 .53468 L .41668 .51831 L p .587 .712 .93 r
F P
0 g
s
.47488 .53177 m .48483 .52364 L .49619 .52673 L p .746 .797 .894 r
F P
0 g
s
.50335 .51639 m .49619 .52673 L .48483 .52364 L p .77 .793 .872 r
F P
0 g
s
.49619 .52673 m .50335 .51639 L .51329 .51618 L p .777 .798 .869 r
F P
0 g
s
.56045 .48466 m .54875 .48295 L .55174 .47651 L p .784 .773 .843 r
F P
0 g
s
.55174 .47651 m .56495 .47523 L .56045 .48466 L p .784 .773 .843 r
F P
0 g
s
.57811 .47473 m .56495 .47523 L .56678 .46611 L p .763 .761 .851 r
F P
0 g
s
.56678 .46611 m .5806 .46285 L .57811 .47473 L p .763 .761 .851 r
F P
0 g
s
.51721 .50481 m .51329 .51618 L .50335 .51639 L p .789 .791 .854 r
F P
0 g
s
.51329 .51618 m .51721 .50481 L .52436 .50293 L p .792 .791 .851 r
F P
0 g
s
.45187 .52922 m .46396 .52417 L .47488 .53177 L p .697 .777 .913 r
F P
0 g
s
.48483 .52364 m .47488 .53177 L .46396 .52417 L p .736 .783 .89 r
F P
0 g
s
.35711 .48287 m .37091 .48772 L .37704 .5121 L p .465 .615 .913 r
F P
0 g
s
.39015 .51499 m .37704 .5121 L .37091 .48772 L p .487 .624 .911 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53155 .49954 L p .797 .784 .841 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53468 .4848 L p .797 .783 .84 r
F P
0 g
s
.53468 .4848 m .54417 .4892 L .5383 .49486 L p .797 .783 .84 r
F P
0 g
s
.52835 .49009 m .53155 .49954 L .52436 .50293 L p .798 .786 .842 r
F P
0 g
s
.53155 .49954 m .52835 .49009 L .53174 .48769 L p .797 .784 .841 r
F P
0 g
s
.41668 .51831 m .43008 .51817 L .43986 .5327 L p .587 .712 .93 r
F P
0 g
s
.45187 .52922 m .43986 .5327 L .43008 .51817 L p .644 .735 .916 r
F P
0 g
s
.54417 .4892 m .53468 .4848 L .53697 .48161 L p .796 .782 .84 r
F P
0 g
s
.53697 .48161 m .54875 .48295 L .54417 .4892 L p .796 .782 .84 r
F P
0 g
s
.56495 .47523 m .55174 .47651 L .55293 .47032 L p .782 .773 .845 r
F P
0 g
s
.55293 .47032 m .56678 .46611 L .56495 .47523 L p .782 .773 .845 r
F P
0 g
s
.63597 .46216 m .62208 .46041 L .62019 .44274 L p .618 .686 .891 r
F P
0 g
s
.62208 .46041 m .60823 .45993 L .60651 .44441 L p .659 .71 .885 r
F P
0 g
s
.60651 .44441 m .62019 .44274 L .62208 .46041 L p .659 .71 .885 r
F P
0 g
s
.52474 .49184 m .52436 .50293 L .51721 .50481 L p .797 .786 .843 r
F P
0 g
s
.52436 .50293 m .52474 .49184 L .52835 .49009 L p .798 .786 .842 r
F P
0 g
s
.60823 .45993 m .59441 .46075 L .5929 .44754 L p .698 .732 .877 r
F P
0 g
s
.5929 .44754 m .60651 .44441 L .60823 .45993 L p .698 .732 .877 r
F P
0 g
s
.48483 .52364 m .49484 .51418 L .50335 .51639 L p .77 .793 .872 r
F P
0 g
s
.51057 .50504 m .50335 .51639 L .49484 .51418 L p .786 .789 .855 r
F P
0 g
s
.50335 .51639 m .51057 .50504 L .51721 .50481 L p .789 .791 .854 r
F P
0 g
s
.64991 .46503 m .63597 .46216 L .63395 .44248 L p .577 .661 .895 r
F P
0 g
s
.62019 .44274 m .63395 .44248 L .63597 .46216 L p .618 .686 .891 r
F P
0 g
s
.59441 .46075 m .5806 .46285 L .57933 .45208 L p .732 .751 .867 r
F P
0 g
s
.57933 .45208 m .5929 .44754 L .59441 .46075 L p .732 .751 .867 r
F P
0 g
s
.54875 .48295 m .53697 .48161 L .53846 .47834 L p .795 .781 .84 r
F P
0 g
s
.53846 .47834 m .55174 .47651 L .54875 .48295 L p .795 .781 .84 r
F P
0 g
s
.46396 .52417 m .47612 .5176 L .48483 .52364 L p .736 .783 .89 r
F P
0 g
s
.49484 .51418 m .48483 .52364 L .47612 .5176 L p .764 .785 .87 r
F P
0 g
s
.66391 .46883 m .64991 .46503 L .64781 .44348 L p .541 .64 .897 r
F P
0 g
s
.63395 .44248 m .64781 .44348 L .64991 .46503 L p .577 .661 .895 r
F P
0 g
s
.52115 .49282 m .51721 .50481 L .51057 .50504 L p .796 .787 .843 r
F P
0 g
s
.51721 .50481 m .52115 .49282 L .52474 .49184 L p .797 .786 .843 r
F P
0 g
s
.5806 .46285 m .56678 .46611 L .56578 .45791 L p .76 .766 .857 r
F P
0 g
s
.56578 .45791 m .57933 .45208 L .5806 .46285 L p .76 .766 .857 r
F P
0 g
s
.37091 .48772 m .38476 .49223 L .39015 .51499 L p .487 .624 .911 r
F P
0 g
s
.40337 .51716 m .39015 .51499 L .38476 .49223 L p .522 .641 .908 r
F P
0 g
s
.43008 .51817 m .44356 .51659 L .45187 .52922 L p .644 .735 .916 r
F P
0 g
s
.46396 .52417 m .45187 .52922 L .44356 .51659 L p .692 .753 .899 r
F P
0 g
s
.67797 .47327 m .66391 .46883 L .66176 .44551 L p .513 .625 .899 r
F P
0 g
s
.64781 .44348 m .66176 .44551 L .66391 .46883 L p .541 .64 .897 r
F P
0 g
s
.55174 .47651 m .53846 .47834 L .53905 .47521 L p .794 .781 .841 r
F P
0 g
s
.53905 .47521 m .55293 .47032 L .55174 .47651 L p .794 .781 .841 r
F P
0 g
s
.56678 .46611 m .55293 .47032 L .55223 .46479 L p .78 .776 .849 r
F P
0 g
s
.55223 .46479 m .56578 .45791 L .56678 .46611 L p .78 .776 .849 r
F P
0 g
s
.49484 .51418 m .5049 .50361 L .51057 .50504 L p .786 .789 .855 r
F P
0 g
s
.51782 .49296 m .51057 .50504 L .5049 .50361 L p .796 .786 .844 r
F P
0 g
s
.51057 .50504 m .51782 .49296 L .52115 .49282 L p .796 .787 .843 r
F P
0 g
s
.47612 .5176 m .48833 .50965 L .49484 .51418 L p .764 .785 .87 r
F P
0 g
s
.5049 .50361 m .49484 .51418 L .48833 .50965 L p .783 .785 .854 r
F P
0 g
s
.69208 .47807 m .67797 .47327 L .67581 .44827 L p .496 .617 .901 r
F P
0 g
s
.66176 .44551 m .67581 .44827 L .67797 .47327 L p .513 .625 .899 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49009 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53468 .4848 L .53174 .48769 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52835 .49009 L .52474 .49184 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53697 .48161 L .53468 .4848 L closepath p .8 .785 .838 r
F P
0 g
s
.38476 .49223 m .39867 .4961 L .40337 .51716 L p .522 .641 .908 r
F P
0 g
s
.41668 .51831 m .40337 .51716 L .39867 .4961 L p .564 .664 .905 r
F P
0 g
s
.44356 .51659 m .4571 .51351 L .46396 .52417 L p .692 .753 .899 r
F P
0 g
s
.47612 .5176 m .46396 .52417 L .4571 .51351 L p .731 .766 .881 r
F P
0 g
s
.52511 .48046 m .52474 .49184 L .52115 .49282 L closepath p .8 .785 .838 r
F P
0 g
s
.55293 .47032 m .53905 .47521 L .53868 .47243 L p .794 .782 .842 r
F P
0 g
s
.53868 .47243 m .55223 .46479 L .55293 .47032 L p .794 .782 .842 r
F P
0 g
s
.52511 .48046 m .53846 .47834 L .53697 .48161 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52115 .49282 L .51782 .49296 L closepath p .8 .785 .838 r
F P
0 g
s
.70623 .48289 m .69208 .47807 L .68996 .45143 L p .491 .619 .905 r
F P
0 g
s
.67581 .44827 m .68996 .45143 L .69208 .47807 L p .496 .617 .901 r
F P
0 g
s
.85906 .48583 m .84551 .48896 L .84593 .43898 L p .758 .834 .91 r
F P
0 g
s
.84593 .43898 m .85986 .43317 L .85906 .48583 L p .758 .834 .91 r
F P
0 g
s
.48833 .50965 m .50058 .50059 L .5049 .50361 L p .783 .785 .854 r
F P
0 g
s
.51499 .49225 m .5049 .50361 L .50058 .50059 L p .795 .785 .844 r
F P
0 g
s
.5049 .50361 m .51499 .49225 L .51782 .49296 L p .796 .786 .844 r
F P
0 g
s
.52511 .48046 m .53905 .47521 L .53846 .47834 L closepath p .8 .785 .838 r
F P
0 g
s
.4571 .51351 m .47069 .50896 L .47612 .5176 L p .731 .766 .881 r
F P
0 g
s
.48833 .50965 m .47612 .5176 L .47069 .50896 L p .76 .775 .865 r
F P
0 g
s
.52511 .48046 m .51782 .49296 L .51499 .49225 L closepath p .8 .785 .838 r
F P
0 g
s
.5929 .44754 m .57933 .45208 L .57434 .44315 L p .731 .764 .879 r
F P
0 g
s
.57933 .45208 m .56578 .45791 L .562 .45119 L p .76 .774 .864 r
F P
0 g
s
.562 .45119 m .57434 .44315 L .57933 .45208 L p .76 .774 .864 r
F P
0 g
s
.84551 .48896 m .83193 .49196 L .83199 .44464 L p .754 .833 .912 r
F P
0 g
s
.83199 .44464 m .84593 .43898 L .84551 .48896 L p .754 .833 .912 r
F P
0 g
s
.56578 .45791 m .55223 .46479 L .54969 .46031 L p .781 .78 .852 r
F P
0 g
s
.54969 .46031 m .562 .45119 L .56578 .45791 L p .781 .78 .852 r
F P
0 g
s
.39867 .4961 m .41264 .49904 L .41668 .51831 L p .564 .664 .905 r
F P
0 g
s
.43008 .51817 m .41668 .51831 L .41264 .49904 L p .611 .69 .899 r
F P
0 g
s
.72039 .48742 m .70623 .48289 L .70418 .45462 L p .499 .631 .91 r
F P
0 g
s
.68996 .45143 m .70418 .45462 L .70623 .48289 L p .491 .619 .905 r
F P
0 g
s
.52511 .48046 m .53868 .47243 L .53905 .47521 L closepath p .8 .785 .838 r
F P
0 g
s
.26501 .42404 m .27905 .42629 L .27432 .46334 L p .656 .767 .931 r
F P
0 g
s
.27432 .46334 m .26033 .46339 L .26501 .42404 L p .656 .767 .931 r
F P
0 g
s
.28822 .46437 m .27432 .46334 L .27905 .42629 L p .623 .739 .93 r
F P
0 g
s
.60651 .44441 m .5929 .44754 L .58673 .43643 L p .694 .75 .895 r
F P
0 g
s
.57434 .44315 m .58673 .43643 L .5929 .44754 L p .731 .764 .879 r
F P
0 g
s
.27905 .42629 m .293 .42943 L .28822 .46437 L p .623 .739 .93 r
F P
0 g
s
.30206 .46648 m .28822 .46437 L .293 .42943 L p .591 .709 .925 r
F P
0 g
s
.25085 .42261 m .26501 .42404 L .26033 .46339 L p .685 .79 .93 r
F P
0 g
s
.26033 .46339 m .24624 .46445 L .25085 .42261 L p .685 .79 .93 r
F P
0 g
s
.55223 .46479 m .53868 .47243 L .53739 .47019 L p .794 .783 .843 r
F P
0 g
s
.53739 .47019 m .54969 .46031 L .55223 .46479 L p .794 .783 .843 r
F P
0 g
s
.47069 .50896 m .4843 .50311 L .48833 .50965 L p .76 .775 .865 r
F P
0 g
s
.50058 .50059 m .48833 .50965 L .4843 .50311 L p .781 .78 .852 r
F P
0 g
s
.50058 .50059 m .51284 .49073 L .51499 .49225 L p .795 .785 .844 r
F P
0 g
s
.52511 .48046 m .51499 .49225 L .51284 .49073 L closepath p .8 .785 .838 r
F P
0 g
s
.293 .42943 m .30684 .43344 L .30206 .46648 L p .591 .709 .925 r
F P
0 g
s
.31584 .46958 m .30206 .46648 L .30684 .43344 L p .562 .679 .918 r
F P
0 g
s
.23658 .42189 m .25085 .42261 L .24624 .46445 L p .709 .808 .927 r
F P
0 g
s
.24624 .46445 m .23207 .46637 L .23658 .42189 L p .709 .808 .927 r
F P
0 g
s
.62019 .44274 m .60651 .44441 L .5992 .43115 L p .648 .731 .909 r
F P
0 g
s
.58673 .43643 m .5992 .43115 L .60651 .44441 L p .694 .75 .895 r
F P
0 g
s
.83193 .49196 m .81827 .49457 L .818 .44984 L p .742 .826 .916 r
F P
0 g
s
.818 .44984 m .83199 .44464 L .83193 .49196 L p .742 .826 .916 r
F P
0 g
s
.52511 .48046 m .53739 .47019 L .53868 .47243 L closepath p .8 .785 .838 r
F P
0 g
s
.4843 .50311 m .49792 .49618 L .50058 .50059 L p .781 .78 .852 r
F P
0 g
s
.51284 .49073 m .50058 .50059 L .49792 .49618 L p .794 .783 .843 r
F P
0 g
s
.73455 .49136 m .72039 .48742 L .71846 .45748 L p .519 .65 .917 r
F P
0 g
s
.70418 .45462 m .71846 .45748 L .72039 .48742 L p .499 .631 .91 r
F P
0 g
s
.30684 .43344 m .32062 .43827 L .31584 .46958 L p .562 .679 .918 r
F P
0 g
s
.32959 .4735 m .31584 .46958 L .32062 .43827 L p .54 .654 .909 r
F P
0 g
s
.49792 .49618 m .51152 .48851 L .51284 .49073 L p .794 .783 .843 r
F P
0 g
s
.52511 .48046 m .51284 .49073 L .51152 .48851 L closepath p .8 .785 .838 r
F P
0 g
s
.41264 .49904 m .42667 .50082 L .43008 .51817 L p .611 .69 .899 r
F P
0 g
s
.44356 .51659 m .43008 .51817 L .42667 .50082 L p .656 .714 .891 r
F P
0 g
s
.2222 .42171 m .23658 .42189 L .23207 .46637 L p .727 .82 .922 r
F P
0 g
s
.23207 .46637 m .21781 .46895 L .2222 .42171 L p .727 .82 .922 r
F P
0 g
s
.52511 .48046 m .53527 .46865 L .53739 .47019 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .53244 .46791 L .53527 .46865 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52911 .46803 L .53244 .46791 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52549 .469 L .52911 .46803 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .52185 .47076 L .52549 .469 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47076 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51548 .4761 L .51844 .47318 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51318 .47931 L .51548 .4761 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51169 .4826 L .51318 .47931 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51113 .48574 L .51169 .4826 L closepath p .8 .785 .838 r
F P
0 g
s
.52511 .48046 m .51152 .48851 L .51113 .48574 L closepath p .8 .785 .838 r
F P
0 g
s
.81827 .49457 m .80453 .49651 L .80395 .45429 L p .722 .813 .921 r
F P
0 g
s
.80395 .45429 m .818 .44984 L .81827 .49457 L p .722 .813 .921 r
F P
0 g
s
.63395 .44248 m .62019 .44274 L .61175 .42738 L p .598 .708 .921 r
F P
0 g
s
.5992 .43115 m .61175 .42738 L .62019 .44274 L p .648 .731 .909 r
F P
0 g
s
.54969 .46031 m .53739 .47019 L .53527 .46865 L p .795 .785 .844 r
F P
0 g
s
.74869 .49448 m .73455 .49136 L .73277 .45969 L p .548 .677 .923 r
F P
0 g
s
.71846 .45748 m .73277 .45969 L .73455 .49136 L p .519 .65 .917 r
F P
0 g
s
.32062 .43827 m .33433 .44377 L .32959 .4735 L p .54 .654 .909 r
F P
0 g
s
.34334 .47803 m .32959 .4735 L .33433 .44377 L p .527 .635 .901 r
F P
0 g
s
.562 .45119 m .54969 .46031 L .54545 .45719 L p .783 .785 .854 r
F P
0 g
s
.53527 .46865 m .54545 .45719 L .54969 .46031 L p .795 .785 .844 r
F P
0 g
s
.4971 .49069 m .51113 .48574 L .51152 .48851 L p .794 .782 .842 r
F P
0 g
s
.51152 .48851 m .49792 .49618 L .4971 .49069 L p .794 .782 .842 r
F P
0 g
s
.20772 .42187 m .2222 .42171 L .21781 .46895 L p .738 .825 .918 r
F P
0 g
s
.21781 .46895 m .20348 .47193 L .20772 .42187 L p .738 .825 .918 r
F P
0 g
s
.42667 .50082 m .44073 .50131 L .44356 .51659 L p .656 .714 .891 r
F P
0 g
s
.4571 .51351 m .44356 .51659 L .44073 .50131 L p .697 .735 .88 r
F P
0 g
s
.80453 .49651 m .7907 .49759 L .78983 .45775 L p .695 .793 .926 r
F P
0 g
s
.78983 .45775 m .80395 .45429 L .80453 .49651 L p .695 .793 .926 r
F P
0 g
s
.76277 .49661 m .74869 .49448 L .74709 .46097 L p .584 .707 .928 r
F P
0 g
s
.73277 .45969 m .74709 .46097 L .74869 .49448 L p .548 .677 .923 r
F P
0 g
s
.54545 .45719 m .53527 .46865 L .53244 .46791 L p .795 .786 .844 r
F P
0 g
s
.57434 .44315 m .562 .45119 L .55567 .44644 L p .764 .783 .869 r
F P
0 g
s
.54545 .45719 m .55567 .44644 L .562 .45119 L p .783 .785 .854 r
F P
0 g
s
.48303 .49497 m .4971 .49069 L .49792 .49618 L p .781 .776 .849 r
F P
0 g
s
.49792 .49618 m .4843 .50311 L .48303 .49497 L p .781 .776 .849 r
F P
0 g
s
.7907 .49759 m .77678 .49764 L .77564 .46006 L p .661 .768 .929 r
F P
0 g
s
.77564 .46006 m .78983 .45775 L .7907 .49759 L p .661 .768 .929 r
F P
0 g
s
.77678 .49764 m .76277 .49661 L .76138 .46113 L p .623 .739 .93 r
F P
0 g
s
.74709 .46097 m .76138 .46113 L .76277 .49661 L p .584 .707 .928 r
F P
0 g
s
.44073 .50131 m .45483 .50046 L .4571 .51351 L p .697 .735 .88 r
F P
0 g
s
.47069 .50896 m .4571 .51351 L .45483 .50046 L p .732 .753 .869 r
F P
0 g
s
.76138 .46113 m .77564 .46006 L .77678 .49764 L p .623 .739 .93 r
F P
0 g
s
.4982 .48446 m .51169 .4826 L .51113 .48574 L p .794 .781 .841 r
F P
0 g
s
.51113 .48574 m .4971 .49069 L .4982 .48446 L p .794 .781 .841 r
F P
0 g
s
.33433 .44377 m .34801 .44975 L .34334 .47803 L p .527 .635 .901 r
F P
0 g
s
.35711 .48287 m .34334 .47803 L .34801 .44975 L p .524 .625 .893 r
F P
0 g
s
.64781 .44348 m .63395 .44248 L .62441 .42506 L p .546 .682 .928 r
F P
0 g
s
.61175 .42738 m .62441 .42506 L .63395 .44248 L p .598 .708 .921 r
F P
0 g
s
.46893 .4983 m .48303 .49497 L .4843 .50311 L p .76 .767 .858 r
F P
0 g
s
.4843 .50311 m .47069 .50896 L .46893 .4983 L p .76 .767 .858 r
F P
0 g
s
.19318 .42214 m .20772 .42187 L .20348 .47193 L p .743 .825 .916 r
F P
0 g
s
.20348 .47193 m .18911 .47507 L .19318 .42214 L p .743 .825 .916 r
F P
0 g
s
.45483 .50046 m .46893 .4983 L .47069 .50896 L p .732 .753 .869 r
F P
0 g
s
.53244 .46791 m .5398 .45565 L .54545 .45719 L p .795 .786 .844 r
F P
0 g
s
.5398 .45565 m .53244 .46791 L .52911 .46803 L p .796 .786 .843 r
F P
0 g
s
.58673 .43643 m .57434 .44315 L .56593 .43671 L p .736 .78 .888 r
F P
0 g
s
.55567 .44644 m .56593 .43671 L .57434 .44315 L p .764 .783 .869 r
F P
0 g
s
.50116 .47795 m .51318 .47931 L .51169 .4826 L p .795 .781 .84 r
F P
0 g
s
.51169 .4826 m .4982 .48446 L .50116 .47795 L p .795 .781 .84 r
F P
0 g
s
.55567 .44644 m .54545 .45719 L .5398 .45565 L p .786 .788 .855 r
F P
0 g
s
.34801 .44975 m .36166 .45597 L .35711 .48287 L p .524 .625 .893 r
F P
0 g
s
.37091 .48772 m .35711 .48287 L .36166 .45597 L p .532 .623 .887 r
F P
0 g
s
.52911 .46803 m .53312 .4558 L .5398 .45565 L p .796 .786 .843 r
F P
0 g
s
.53312 .4558 m .52911 .46803 L .52549 .469 L p .797 .786 .843 r
F P
0 g
s
.50576 .47159 m .51548 .4761 L .51318 .47931 L p .796 .782 .84 r
F P
0 g
s
.51318 .47931 m .50116 .47795 L .50576 .47159 L p .796 .782 .84 r
F P
0 g
s
.48465 .48578 m .4982 .48446 L .4971 .49069 L p .782 .774 .846 r
F P
0 g
s
.4971 .49069 m .48303 .49497 L .48465 .48578 L p .782 .774 .846 r
F P
0 g
s
.52549 .469 m .52588 .45765 L .53312 .4558 L p .797 .786 .843 r
F P
0 g
s
.52588 .45765 m .52549 .469 L .52185 .47076 L p .798 .786 .842 r
F P
0 g
s
.5992 .43115 m .58673 .43643 L .57627 .42823 L p .699 .773 .909 r
F P
0 g
s
.56593 .43671 m .57627 .42823 L .58673 .43643 L p .736 .78 .888 r
F P
0 g
s
.66176 .44551 m .64781 .44348 L .63718 .42403 L p .5 .658 .931 r
F P
0 g
s
.62441 .42506 m .63718 .42403 L .64781 .44348 L p .546 .682 .928 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51548 .4761 L p .797 .783 .84 r
F P
0 g
s
.51548 .4761 m .50576 .47159 L .5117 .46583 L p .797 .783 .84 r
F P
0 g
s
.52185 .47076 m .51857 .46107 L .52588 .45765 L p .798 .786 .842 r
F P
0 g
s
.51857 .46107 m .52185 .47076 L .51844 .47318 L p .797 .784 .841 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51857 .46107 L p .797 .784 .841 r
F P
0 g
s
.36166 .45597 m .37531 .46219 L .37091 .48772 L p .532 .623 .887 r
F P
0 g
s
.38476 .49223 m .37091 .48772 L .37531 .46219 L p .55 .63 .883 r
F P
0 g
s
.56593 .43671 m .55567 .44644 L .5472 .444 L p .77 .792 .871 r
F P
0 g
s
.5398 .45565 m .5472 .444 L .55567 .44644 L p .786 .788 .855 r
F P
0 g
s
.5472 .444 m .5398 .45565 L .53312 .4558 L p .789 .791 .854 r
F P
0 g
s
.47104 .48632 m .48465 .48578 L .48303 .49497 L p .763 .762 .852 r
F P
0 g
s
.48303 .49497 m .46893 .4983 L .47104 .48632 L p .763 .762 .852 r
F P
0 g
s
.48906 .47618 m .50116 .47795 L .4982 .48446 L p .784 .774 .843 r
F P
0 g
s
.4982 .48446 m .48465 .48578 L .48906 .47618 L p .784 .774 .843 r
F P
0 g
s
.37531 .46219 m .38897 .46812 L .38476 .49223 L p .55 .63 .883 r
F P
0 g
s
.39867 .4961 m .38476 .49223 L .38897 .46812 L p .576 .643 .88 r
F P
0 g
s
.61175 .42738 m .5992 .43115 L .58667 .42113 L p .651 .762 .93 r
F P
0 g
s
.57627 .42823 m .58667 .42113 L .5992 .43115 L p .699 .773 .909 r
F P
0 g
s
.67581 .44827 m .66176 .44551 L .65008 .42407 L p .464 .64 .932 r
F P
0 g
s
.63718 .42403 m .65008 .42407 L .66176 .44551 L p .5 .658 .931 r
F P
0 g
s
.45738 .4859 m .47104 .48632 L .46893 .4983 L p .739 .746 .858 r
F P
0 g
s
.46893 .4983 m .45483 .50046 L .45738 .4859 L p .739 .746 .858 r
F P
0 g
s
.53312 .4558 m .53717 .44405 L .5472 .444 L p .789 .791 .854 r
F P
0 g
s
.53717 .44405 m .53312 .4558 L .52588 .45765 L p .792 .79 .851 r
F P
0 g
s
.38897 .46812 m .40264 .47351 L .39867 .4961 L p .576 .643 .88 r
F P
0 g
s
.41264 .49904 m .39867 .4961 L .40264 .47351 L p .607 .662 .877 r
F P
0 g
s
.57627 .42823 m .56593 .43671 L .55465 .43323 L p .746 .795 .892 r
F P
0 g
s
.5472 .444 m .55465 .43323 L .56593 .43671 L p .77 .792 .871 r
F P
0 g
s
.49597 .46684 m .50576 .47159 L .50116 .47795 L p .787 .776 .842 r
F P
0 g
s
.50116 .47795 m .48906 .47618 L .49597 .46684 L p .787 .776 .842 r
F P
0 g
s
.4437 .4844 m .45738 .4859 L .45483 .50046 L p .71 .727 .864 r
F P
0 g
s
.45483 .50046 m .44073 .50131 L .4437 .4844 L p .71 .727 .864 r
F P
0 g
s
.40264 .47351 m .41632 .47813 L .41264 .49904 L p .607 .662 .877 r
F P
0 g
s
.42667 .50082 m .41264 .49904 L .41632 .47813 L p .642 .683 .874 r
F P
0 g
s
.55465 .43323 m .5472 .444 L .53717 .44405 L p .777 .797 .869 r
F P
0 g
s
.43001 .4818 m .4437 .4844 L .44073 .50131 L p .677 .706 .869 r
F P
0 g
s
.44073 .50131 m .42667 .50082 L .43001 .4818 L p .677 .706 .869 r
F P
0 g
s
.52588 .45765 m .52627 .44661 L .53717 .44405 L p .792 .79 .851 r
F P
0 g
s
.52627 .44661 m .52588 .45765 L .51857 .46107 L p .793 .788 .848 r
F P
0 g
s
.41632 .47813 m .43001 .4818 L .42667 .50082 L p .642 .683 .874 r
F P
0 g
s
.47689 .47385 m .48906 .47618 L .48465 .48578 L p .769 .762 .847 r
F P
0 g
s
.48465 .48578 m .47104 .48632 L .47689 .47385 L p .769 .762 .847 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50576 .47159 L p .79 .779 .843 r
F P
0 g
s
.50576 .47159 m .49597 .46684 L .50491 .45842 L p .79 .779 .843 r
F P
0 g
s
.62441 .42506 m .61175 .42738 L .59718 .41546 L p .595 .744 .947 r
F P
0 g
s
.58667 .42113 m .59718 .41546 L .61175 .42738 L p .651 .762 .93 r
F P
0 g
s
.51857 .46107 m .51525 .45151 L .52627 .44661 L p .793 .788 .848 r
F P
0 g
s
.51525 .45151 m .51857 .46107 L .5117 .46583 L p .792 .784 .845 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51525 .45151 L p .792 .784 .845 r
F P
0 g
s
.68996 .45143 m .67581 .44827 L .6631 .42486 L p .444 .63 .933 r
F P
0 g
s
.65008 .42407 m .6631 .42486 L .67581 .44827 L p .464 .64 .932 r
F P
0 g
s
.58667 .42113 m .57627 .42823 L .56216 .42355 L p .714 .796 .916 r
F P
0 g
s
.55465 .43323 m .56216 .42355 L .57627 .42823 L p .746 .795 .892 r
F P
0 g
s
.53717 .44405 m .54125 .43298 L .55465 .43323 L p .777 .797 .869 r
F P
0 g
s
.54125 .43298 m .53717 .44405 L .52627 .44661 L p .783 .796 .864 r
F P
0 g
s
.46465 .47082 m .47689 .47385 L .47104 .48632 L p .749 .747 .85 r
F P
0 g
s
.47104 .48632 m .45738 .4859 L .46465 .47082 L p .749 .747 .85 r
F P
0 g
s
.48611 .46177 m .49597 .46684 L .48906 .47618 L p .775 .766 .845 r
F P
0 g
s
.48906 .47618 m .47689 .47385 L .48611 .46177 L p .775 .766 .845 r
F P
0 g
s
.56216 .42355 m .55465 .43323 L .54125 .43298 L p .759 .804 .888 r
F P
0 g
s
.63718 .42403 m .62441 .42506 L .60779 .41118 L p .535 .721 .959 r
F P
0 g
s
.59718 .41546 m .60779 .41118 L .62441 .42506 L p .595 .744 .947 r
F P
0 g
s
.70418 .45462 m .68996 .45143 L .67625 .42604 L p .442 .63 .934 r
F P
0 g
s
.6631 .42486 m .67625 .42604 L .68996 .45143 L p .444 .63 .933 r
F P
0 g
s
.52627 .44661 m .52666 .43602 L .54125 .43298 L p .783 .796 .864 r
F P
0 g
s
.52666 .43602 m .52627 .44661 L .51525 .45151 L p .786 .791 .857 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49597 .46684 L p .781 .774 .846 r
F P
0 g
s
.49597 .46684 m .48611 .46177 L .49806 .45095 L p .781 .774 .846 r
F P
0 g
s
.59718 .41546 m .58667 .42113 L .56973 .4151 L p .671 .793 .94 r
F P
0 g
s
.56216 .42355 m .56973 .4151 L .58667 .42113 L p .714 .796 .916 r
F P
0 g
s
.45236 .46702 m .46465 .47082 L .45738 .4859 L p .726 .73 .853 r
F P
0 g
s
.45738 .4859 m .4437 .4844 L .45236 .46702 L p .726 .73 .853 r
F P
0 g
s
.51525 .45151 m .51191 .44216 L .52666 .43602 L p .786 .791 .857 r
F P
0 g
s
.51191 .44216 m .51525 .45151 L .50491 .45842 L p .785 .783 .85 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51191 .44216 L p .785 .783 .85 r
F P
0 g
s
.47617 .45631 m .48611 .46177 L .47689 .47385 L p .76 .754 .847 r
F P
0 g
s
.47689 .47385 m .46465 .47082 L .47617 .45631 L p .76 .754 .847 r
F P
0 g
s
.54125 .43298 m .54536 .42278 L .56216 .42355 L p .759 .804 .888 r
F P
0 g
s
.54536 .42278 m .54125 .43298 L .52666 .43602 L p .771 .803 .879 r
F P
0 g
s
.44003 .46242 m .45236 .46702 L .4437 .4844 L p .7 .711 .856 r
F P
0 g
s
.4437 .4844 m .43001 .4818 L .44003 .46242 L p .7 .711 .856 r
F P
0 g
s
.56973 .4151 m .56216 .42355 L .54536 .42278 L p .735 .81 .911 r
F P
0 g
s
.65008 .42407 m .63718 .42403 L .61852 .40814 L p .479 .696 .964 r
F P
0 g
s
.60779 .41118 m .61852 .40814 L .63718 .42403 L p .535 .721 .959 r
F P
0 g
s
.71846 .45748 m .70418 .45462 L .6895 .42726 L p .458 .642 .936 r
F P
0 g
s
.67625 .42604 m .6895 .42726 L .70418 .45462 L p .442 .63 .934 r
F P
0 g
s
.42765 .45705 m .44003 .46242 L .43001 .4818 L p .674 .692 .859 r
F P
0 g
s
.43001 .4818 m .41632 .47813 L .42765 .45705 L p .674 .692 .859 r
F P
0 g
s
.60779 .41118 m .59718 .41546 L .57739 .40791 L p .617 .785 .962 r
F P
0 g
s
.56973 .4151 m .57739 .40791 L .59718 .41546 L p .671 .793 .94 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48611 .46177 L p .77 .767 .85 r
F P
0 g
s
.48611 .46177 m .47617 .45631 L .49116 .44341 L p .77 .767 .85 r
F P
0 g
s
.52666 .43602 m .52705 .42602 L .54536 .42278 L p .771 .803 .879 r
F P
0 g
s
.52705 .42602 m .52666 .43602 L .51191 .44216 L p .777 .795 .868 r
F P
0 g
s
.41525 .45098 m .42765 .45705 L .41632 .47813 L p .648 .674 .861 r
F P
0 g
s
.41632 .47813 m .40264 .47351 L .41525 .45098 L p .648 .674 .861 r
F P
0 g
s
.46617 .45042 m .47617 .45631 L .46465 .47082 L p .743 .741 .85 r
F P
0 g
s
.46465 .47082 m .45236 .46702 L .46617 .45042 L p .743 .741 .85 r
F P
0 g
s
.40281 .44434 m .41525 .45098 L .40264 .47351 L p .624 .659 .864 r
F P
0 g
s
.40264 .47351 m .38897 .46812 L .40281 .44434 L p .624 .659 .864 r
F P
0 g
s
.50854 .43307 m .51191 .44216 L .49806 .45095 L p .776 .782 .857 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50854 .43307 L p .776 .782 .857 r
F P
0 g
s
.51191 .44216 m .50854 .43307 L .52705 .42602 L p .777 .795 .868 r
F P
0 g
s
.73277 .45969 m .71846 .45748 L .70284 .42812 L p .488 .661 .938 r
F P
0 g
s
.6895 .42726 m .70284 .42812 L .71846 .45748 L p .458 .642 .936 r
F P
0 g
s
.39034 .4373 m .40281 .44434 L .38897 .46812 L p .604 .649 .868 r
F P
0 g
s
.38897 .46812 m .37531 .46219 L .39034 .4373 L p .604 .649 .868 r
F P
0 g
s
.37784 .43003 m .39034 .4373 L .37531 .46219 L p .589 .644 .873 r
F P
0 g
s
.37531 .46219 m .36166 .45597 L .37784 .43003 L p .589 .644 .873 r
F P
0 g
s
.54536 .42278 m .54952 .41356 L .56973 .4151 L p .735 .81 .911 r
F P
0 g
s
.54952 .41356 m .54536 .42278 L .52705 .42602 L p .754 .811 .898 r
F P
0 g
s
.57739 .40791 m .56973 .4151 L .54952 .41356 L p .702 .815 .935 r
F P
0 g
s
.36529 .42274 m .37784 .43003 L .36166 .45597 L p .58 .645 .88 r
F P
0 g
s
.36166 .45597 m .34801 .44975 L .36529 .42274 L p .58 .645 .88 r
F P
0 g
s
.6631 .42486 m .65008 .42407 L .62938 .4061 L p .436 .675 .964 r
F P
0 g
s
.61852 .40814 m .62938 .4061 L .65008 .42407 L p .479 .696 .964 r
F P
0 g
s
.35269 .41559 m .36529 .42274 L .34801 .44975 L p .577 .653 .889 r
F P
0 g
s
.34801 .44975 m .33433 .44377 L .35269 .41559 L p .577 .653 .889 r
F P
0 g
s
.34003 .40877 m .35269 .41559 L .33433 .44377 L p .58 .668 .899 r
F P
0 g
s
.33433 .44377 m .32062 .43827 L .34003 .40877 L p .58 .668 .899 r
F P
0 g
s
.32728 .4024 m .34003 .40877 L .32062 .43827 L p .59 .688 .91 r
F P
0 g
s
.32062 .43827 m .30684 .43344 L .32728 .4024 L p .59 .688 .91 r
F P
0 g
s
.45611 .44408 m .46617 .45042 L .45236 .46702 L p .723 .726 .853 r
F P
0 g
s
.45236 .46702 m .44003 .46242 L .45611 .44408 L p .723 .726 .853 r
F P
0 g
s
.31445 .39659 m .32728 .4024 L .30684 .43344 L p .605 .713 .92 r
F P
0 g
s
.30684 .43344 m .293 .42943 L .31445 .39659 L p .605 .713 .92 r
F P
0 g
s
.61852 .40814 m .60779 .41118 L .58513 .40193 L p .558 .769 .977 r
F P
0 g
s
.57739 .40791 m .58513 .40193 L .60779 .41118 L p .617 .785 .962 r
F P
0 g
s
.74709 .46097 m .73277 .45969 L .71624 .4283 L p .529 .687 .939 r
F P
0 g
s
.70284 .42812 m .71624 .4283 L .73277 .45969 L p .488 .661 .938 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47617 .45631 L p .757 .759 .854 r
F P
0 g
s
.47617 .45631 m .46617 .45042 L .48419 .43581 L p .757 .759 .854 r
F P
0 g
s
.30152 .39139 m .31445 .39659 L .293 .42943 L p .624 .739 .929 r
F P
0 g
s
.293 .42943 m .27905 .42629 L .30152 .39139 L p .624 .739 .929 r
F P
0 g
s
.52705 .42602 m .52745 .41668 L .54952 .41356 L p .754 .811 .898 r
F P
0 g
s
.52745 .41668 m .52705 .42602 L .50854 .43307 L p .764 .799 .881 r
F P
0 g
s
.50513 .42428 m .50854 .43307 L .49116 .44341 L p .765 .78 .865 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50513 .42428 L p .765 .78 .865 r
F P
0 g
s
.28847 .3868 m .30152 .39139 L .27905 .42629 L p .645 .765 .936 r
F P
0 g
s
.27905 .42629 m .26501 .42404 L .28847 .3868 L p .645 .765 .936 r
F P
0 g
s
.50854 .43307 m .50513 .42428 L .52745 .41668 L p .764 .799 .881 r
F P
0 g
s
.76138 .46113 m .74709 .46097 L .72968 .42749 L p .576 .714 .936 r
F P
0 g
s
.71624 .4283 m .72968 .42749 L .74709 .46097 L p .529 .687 .939 r
F P
0 g
s
.44599 .43731 m .45611 .44408 L .44003 .46242 L p .703 .712 .855 r
F P
0 g
s
.44003 .46242 m .42765 .45705 L .44599 .43731 L p .703 .712 .855 r
F P
0 g
s
.67625 .42604 m .6631 .42486 L .64037 .40478 L p .413 .663 .963 r
F P
0 g
s
.62938 .4061 m .64037 .40478 L .6631 .42486 L p .436 .675 .964 r
F P
0 g
s
.58513 .40193 m .57739 .40791 L .55372 .40534 L p .66 .815 .958 r
F P
0 g
s
.54952 .41356 m .55372 .40534 L .57739 .40791 L p .702 .815 .935 r
F P
0 g
s
.55372 .40534 m .54952 .41356 L .52745 .41668 L p .732 .818 .918 r
F P
0 g
s
.27531 .38279 m .28847 .3868 L .26501 .42404 L p .665 .788 .94 r
F P
0 g
s
.26501 .42404 m .25085 .42261 L .27531 .38279 L p .665 .788 .94 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46617 .45042 L p .742 .75 .859 r
F P
0 g
s
.46617 .45042 m .45611 .44408 L .47717 .42815 L p .742 .75 .859 r
F P
0 g
s
.77564 .46006 m .76138 .46113 L .74312 .42551 L p .622 .739 .931 r
F P
0 g
s
.72968 .42749 m .74312 .42551 L .76138 .46113 L p .576 .714 .936 r
F P
0 g
s
.62938 .4061 m .61852 .40814 L .59297 .39705 L p .501 .749 .984 r
F P
0 g
s
.58513 .40193 m .59297 .39705 L .61852 .40814 L p .558 .769 .977 r
F P
0 g
s
.4358 .43015 m .44599 .43731 L .42765 .45705 L p .683 .699 .858 r
F P
0 g
s
.42765 .45705 m .41525 .45098 L .4358 .43015 L p .683 .699 .858 r
F P
0 g
s
.26203 .37925 m .27531 .38279 L .25085 .42261 L p .683 .807 .941 r
F P
0 g
s
.25085 .42261 m .23658 .42189 L .26203 .37925 L p .683 .807 .941 r
F P
0 g
s
.78983 .45775 m .77564 .46006 L .75656 .42222 L p .665 .761 .922 r
F P
0 g
s
.74312 .42551 m .75656 .42222 L .77564 .46006 L p .622 .739 .931 r
F P
0 g
s
.52745 .41668 m .52785 .40803 L .55372 .40534 L p .732 .818 .918 r
F P
0 g
s
.52785 .40803 m .52745 .41668 L .50513 .42428 L p .75 .803 .895 r
F P
0 g
s
.50169 .41582 m .50513 .42428 L .48419 .43581 L p .752 .777 .874 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50169 .41582 L p .752 .777 .874 r
F P
0 g
s
.6895 .42726 m .67625 .42604 L .65147 .40383 L p .413 .661 .962 r
F P
0 g
s
.64037 .40478 m .65147 .40383 L .67625 .42604 L p .413 .663 .963 r
F P
0 g
s
.80395 .45429 m .78983 .45775 L .76997 .41763 L p .7 .779 .912 r
F P
0 g
s
.75656 .42222 m .76997 .41763 L .78983 .45775 L p .665 .761 .922 r
F P
0 g
s
.42556 .42265 m .4358 .43015 L .41525 .45098 L p .664 .687 .862 r
F P
0 g
s
.41525 .45098 m .40281 .44434 L .42556 .42265 L p .664 .687 .862 r
F P
0 g
s
.50513 .42428 m .50169 .41582 L .52785 .40803 L p .75 .803 .895 r
F P
0 g
s
.24863 .37609 m .26203 .37925 L .23658 .42189 L p .698 .82 .94 r
F P
0 g
s
.23658 .42189 m .2222 .42171 L .24863 .37609 L p .698 .82 .94 r
F P
0 g
s
.818 .44984 m .80395 .45429 L .78335 .41181 L p .728 .791 .902 r
F P
0 g
s
.76997 .41763 m .78335 .41181 L .80395 .45429 L p .7 .779 .912 r
F P
0 g
s
.59297 .39705 m .58513 .40193 L .55797 .3981 L p .613 .809 .975 r
F P
0 g
s
.55372 .40534 m .55797 .3981 L .58513 .40193 L p .66 .815 .958 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45611 .44408 L p .726 .741 .864 r
F P
0 g
s
.45611 .44408 m .44599 .43731 L .47008 .42042 L p .726 .741 .864 r
F P
0 g
s
.55797 .3981 m .55372 .40534 L .52785 .40803 L p .704 .822 .938 r
F P
0 g
s
.83199 .44464 m .818 .44984 L .79668 .40494 L p .747 .8 .894 r
F P
0 g
s
.78335 .41181 m .79668 .40494 L .818 .44984 L p .728 .791 .902 r
F P
0 g
s
.85986 .43317 m .84593 .43898 L .82329 .38909 L p .762 .805 .887 r
F P
0 g
s
.82329 .38909 m .8366 .38074 L .85986 .43317 L p .762 .805 .887 r
F P
0 g
s
.84593 .43898 m .83199 .44464 L .80999 .39727 L p .759 .804 .889 r
F P
0 g
s
.80999 .39727 m .82329 .38909 L .84593 .43898 L p .759 .804 .889 r
F P
0 g
s
.79668 .40494 m .80999 .39727 L .83199 .44464 L p .747 .8 .894 r
F P
0 g
s
.41526 .41492 m .42556 .42265 L .40281 .44434 L p .647 .679 .866 r
F P
0 g
s
.40281 .44434 m .39034 .4373 L .41526 .41492 L p .647 .679 .866 r
F P
0 g
s
.64037 .40478 m .62938 .4061 L .60092 .39305 L p .455 .729 .985 r
F P
0 g
s
.59297 .39705 m .60092 .39305 L .62938 .4061 L p .501 .749 .984 r
F P
0 g
s
.23513 .37315 m .24863 .37609 L .2222 .42171 L p .708 .826 .938 r
F P
0 g
s
.2222 .42171 m .20772 .42187 L .23513 .37315 L p .708 .826 .938 r
F P
0 g
s
.40489 .40702 m .41526 .41492 L .39034 .4373 L p .633 .675 .872 r
F P
0 g
s
.39034 .4373 m .37784 .43003 L .40489 .40702 L p .633 .675 .872 r
F P
0 g
s
.49821 .40766 m .50169 .41582 L .47717 .42815 L p .737 .774 .883 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49821 .40766 L p .737 .774 .883 r
F P
0 g
s
.70284 .42812 m .6895 .42726 L .6627 .40289 L p .435 .669 .961 r
F P
0 g
s
.65147 .40383 m .6627 .40289 L .6895 .42726 L p .413 .661 .962 r
F P
0 g
s
.52785 .40803 m .52826 .40004 L .55797 .3981 L p .704 .822 .938 r
F P
0 g
s
.52826 .40004 m .52785 .40803 L .50169 .41582 L p .732 .805 .91 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44599 .43731 L p .709 .732 .869 r
F P
0 g
s
.44599 .43731 m .4358 .43015 L .46294 .41262 L p .709 .732 .869 r
F P
0 g
s
.22154 .37026 m .23513 .37315 L .20772 .42187 L p .714 .827 .935 r
F P
0 g
s
.20772 .42187 m .19318 .42214 L .22154 .37026 L p .714 .827 .935 r
F P
0 g
s
.50169 .41582 m .49821 .40766 L .52826 .40004 L p .732 .805 .91 r
F P
0 g
s
.39446 .39908 m .40489 .40702 L .37784 .43003 L p .622 .675 .88 r
F P
0 g
s
.37784 .43003 m .36529 .42274 L .39446 .39908 L p .622 .675 .88 r
F P
0 g
s
.60092 .39305 m .59297 .39705 L .56228 .39171 L p .565 .797 .986 r
F P
0 g
s
.55797 .3981 m .56228 .39171 L .59297 .39705 L p .613 .809 .975 r
F P
0 g
s
.56228 .39171 m .55797 .3981 L .52826 .40004 L p .673 .822 .955 r
F P
0 g
s
.38396 .39118 m .39446 .39908 L .36529 .42274 L p .615 .68 .888 r
F P
0 g
s
.36529 .42274 m .35269 .41559 L .38396 .39118 L p .615 .68 .888 r
F P
0 g
s
.65147 .40383 m .64037 .40478 L .60896 .38967 L p .429 .714 .984 r
F P
0 g
s
.60092 .39305 m .60896 .38967 L .64037 .40478 L p .455 .729 .985 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .4358 .43015 L p .693 .724 .874 r
F P
0 g
s
.4358 .43015 m .42556 .42265 L .45573 .40475 L p .693 .724 .874 r
F P
0 g
s
.71624 .4283 m .70284 .42812 L .67401 .40158 L p .474 .685 .959 r
F P
0 g
s
.6627 .40289 m .67401 .40158 L .70284 .42812 L p .435 .669 .961 r
F P
0 g
s
.49469 .39977 m .49821 .40766 L .47008 .42042 L p .721 .77 .891 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49469 .39977 L p .721 .77 .891 r
F P
0 g
s
.37339 .38341 m .38396 .39118 L .35269 .41559 L p .612 .69 .898 r
F P
0 g
s
.35269 .41559 m .34003 .40877 L .37339 .38341 L p .612 .69 .898 r
F P
0 g
s
.52826 .40004 m .52867 .39262 L .56228 .39171 L p .673 .822 .955 r
F P
0 g
s
.52867 .39262 m .52826 .40004 L .49821 .40766 L p .712 .805 .923 r
F P
0 g
s
.49821 .40766 m .49469 .39977 L .52867 .39262 L p .712 .805 .923 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42556 .42265 L p .677 .718 .88 r
F P
0 g
s
.42556 .42265 m .41526 .41492 L .44846 .39682 L p .677 .718 .88 r
F P
0 g
s
.36273 .37584 m .37339 .38341 L .34003 .40877 L p .613 .704 .909 r
F P
0 g
s
.34003 .40877 m .32728 .4024 L .36273 .37584 L p .613 .704 .909 r
F P
0 g
s
.60896 .38967 m .60092 .39305 L .56664 .38603 L p .525 .783 .991 r
F P
0 g
s
.56228 .39171 m .56664 .38603 L .60092 .39305 L p .565 .797 .986 r
F P
0 g
s
.56664 .38603 m .56228 .39171 L .52867 .39262 L p .64 .818 .968 r
F P
0 g
s
.72968 .42749 m .71624 .4283 L .68541 .39959 L p .523 .705 .954 r
F P
0 g
s
.67401 .40158 m .68541 .39959 L .71624 .4283 L p .474 .685 .959 r
F P
0 g
s
.6627 .40289 m .65147 .40383 L .6171 .38659 L p .428 .708 .982 r
F P
0 g
s
.60896 .38967 m .6171 .38659 L .65147 .40383 L p .429 .714 .984 r
F P
0 g
s
.49114 .39208 m .49469 .39977 L .46294 .41262 L p .705 .766 .9 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49114 .39208 L p .705 .766 .9 r
F P
0 g
s
.35199 .36852 m .36273 .37584 L .32728 .4024 L p .618 .721 .92 r
F P
0 g
s
.32728 .4024 m .31445 .39659 L .35199 .36852 L p .618 .721 .92 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41526 .41492 L p .663 .714 .887 r
F P
0 g
s
.41526 .41492 m .40489 .40702 L .44112 .38881 L p .663 .714 .887 r
F P
0 g
s
.52867 .39262 m .52909 .38567 L .56664 .38603 L p .64 .818 .968 r
F P
0 g
s
.52909 .38567 m .52867 .39262 L .49469 .39977 L p .69 .803 .935 r
F P
0 g
s
.74312 .42551 m .72968 .42749 L .69687 .39662 L p .574 .724 .944 r
F P
0 g
s
.68541 .39959 m .69687 .39662 L .72968 .42749 L p .523 .705 .954 r
F P
0 g
s
.49469 .39977 m .49114 .39208 L .52909 .38567 L p .69 .803 .935 r
F P
0 g
s
.34115 .36148 m .35199 .36852 L .31445 .39659 L p .625 .74 .929 r
F P
0 g
s
.31445 .39659 m .30152 .39139 L .34115 .36148 L p .625 .74 .929 r
F P
0 g
s
.6171 .38659 m .60896 .38967 L .57106 .38081 L p .499 .769 .992 r
F P
0 g
s
.56664 .38603 m .57106 .38081 L .60896 .38967 L p .525 .783 .991 r
F P
0 g
s
.48754 .38451 m .49114 .39208 L .45573 .40475 L p .688 .761 .908 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48754 .38451 L p .688 .761 .908 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40489 .40702 L p .65 .713 .893 r
F P
0 g
s
.40489 .40702 m .39446 .39908 L .43372 .38074 L p .65 .713 .893 r
F P
0 g
s
.57106 .38081 m .56664 .38603 L .52909 .38567 L p .61 .81 .977 r
F P
0 g
s
.67401 .40158 m .6627 .40289 L .62534 .3835 L p .449 .711 .979 r
F P
0 g
s
.6171 .38659 m .62534 .3835 L .6627 .40289 L p .428 .708 .982 r
F P
0 g
s
.33021 .35473 m .34115 .36148 L .30152 .39139 L p .635 .759 .937 r
F P
0 g
s
.30152 .39139 m .28847 .3868 L .33021 .35473 L p .635 .759 .937 r
F P
0 g
s
.75656 .42222 m .74312 .42551 L .70836 .39248 L p .622 .74 .931 r
F P
0 g
s
.69687 .39662 m .70836 .39248 L .74312 .42551 L p .574 .724 .944 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39446 .39908 L p .64 .713 .901 r
F P
0 g
s
.39446 .39908 m .38396 .39118 L .42626 .3726 L p .64 .713 .901 r
F P
0 g
s
.52951 .37903 m .52909 .38567 L .49114 .39208 L p .669 .798 .944 r
F P
0 g
s
.49114 .39208 m .48754 .38451 L .52951 .37903 L p .669 .798 .944 r
F P
0 g
s
.31917 .34824 m .33021 .35473 L .28847 .3868 L p .646 .777 .943 r
F P
0 g
s
.28847 .3868 m .27531 .38279 L .31917 .34824 L p .646 .777 .943 r
F P
0 g
s
.52909 .38567 m .52951 .37903 L .57106 .38081 L p .61 .81 .977 r
F P
0 g
s
.76997 .41763 m .75656 .42222 L .71987 .38706 L p .664 .752 .916 r
F P
0 g
s
.70836 .39248 m .71987 .38706 L .75656 .42222 L p .622 .74 .931 r
F P
0 g
s
.48391 .37696 m .48754 .38451 L .44846 .39682 L p .672 .757 .914 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48391 .37696 L p .672 .757 .914 r
F P
0 g
s
.62534 .3835 m .6171 .38659 L .57554 .37582 L p .492 .759 .99 r
F P
0 g
s
.57106 .38081 m .57554 .37582 L .6171 .38659 L p .499 .769 .992 r
F P
0 g
s
.68541 .39959 m .67401 .40158 L .63367 .38005 L p .487 .719 .973 r
F P
0 g
s
.62534 .3835 m .63367 .38005 L .67401 .40158 L p .449 .711 .979 r
F P
0 g
s
.78335 .41181 m .76997 .41763 L .73138 .38033 L p .697 .761 .901 r
F P
0 g
s
.71987 .38706 m .73138 .38033 L .76997 .41763 L p .664 .752 .916 r
F P
0 g
s
.57554 .37582 m .57106 .38081 L .52951 .37903 L p .587 .8 .981 r
F P
0 g
s
.30803 .34196 m .31917 .34824 L .27531 .38279 L p .657 .792 .946 r
F P
0 g
s
.27531 .38279 m .26203 .37925 L .30803 .34196 L p .657 .792 .946 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38396 .39118 L p .632 .717 .908 r
F P
0 g
s
.38396 .39118 m .37339 .38341 L .41873 .36438 L p .632 .717 .908 r
F P
0 g
s
.79668 .40494 m .78335 .41181 L .74289 .37239 L p .722 .767 .888 r
F P
0 g
s
.73138 .38033 m .74289 .37239 L .78335 .41181 L p .697 .761 .901 r
F P
0 g
s
.52994 .3725 m .52951 .37903 L .48754 .38451 L p .65 .791 .95 r
F P
0 g
s
.48754 .38451 m .48391 .37696 L .52994 .3725 L p .65 .791 .95 r
F P
0 g
s
.48024 .36934 m .48391 .37696 L .44112 .38881 L p .657 .752 .92 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48024 .36934 L p .657 .752 .92 r
F P
0 g
s
.52951 .37903 m .52994 .3725 L .57554 .37582 L p .587 .8 .981 r
F P
0 g
s
.29678 .33584 m .30803 .34196 L .26203 .37925 L p .667 .802 .947 r
F P
0 g
s
.26203 .37925 m .24863 .37609 L .29678 .33584 L p .667 .802 .947 r
F P
0 g
s
.80999 .39727 m .79668 .40494 L .7544 .3634 L p .739 .771 .879 r
F P
0 g
s
.74289 .37239 m .7544 .3634 L .79668 .40494 L p .722 .767 .888 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37339 .38341 L p .627 .723 .916 r
F P
0 g
s
.37339 .38341 m .36273 .37584 L .41113 .35609 L p .627 .723 .916 r
F P
0 g
s
.69687 .39662 m .68541 .39959 L .64206 .37595 L p .534 .728 .963 r
F P
0 g
s
.63367 .38005 m .64206 .37595 L .68541 .39959 L p .487 .719 .973 r
F P
0 g
s
.82329 .38909 m .80999 .39727 L .76591 .35359 L p .749 .773 .873 r
F P
0 g
s
.7544 .3634 m .76591 .35359 L .80999 .39727 L p .739 .771 .879 r
F P
0 g
s
.63367 .38005 m .62534 .3835 L .58007 .37078 L p .503 .754 .985 r
F P
0 g
s
.57554 .37582 m .58007 .37078 L .62534 .3835 L p .492 .759 .99 r
F P
0 g
s
.8366 .38074 m .82329 .38909 L .77744 .34327 L p .752 .774 .871 r
F P
0 g
s
.76591 .35359 m .77744 .34327 L .82329 .38909 L p .749 .773 .873 r
F P
0 g
s
.58007 .37078 m .57554 .37582 L .52994 .3725 L p .574 .789 .98 r
F P
0 g
s
.28544 .3298 m .29678 .33584 L .24863 .37609 L p .676 .808 .946 r
F P
0 g
s
.24863 .37609 m .23513 .37315 L .28544 .3298 L p .676 .808 .946 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36273 .37584 L p .625 .731 .923 r
F P
0 g
s
.36273 .37584 m .35199 .36852 L .40346 .34772 L p .625 .731 .923 r
F P
0 g
s
.47653 .36153 m .48024 .36934 L .43372 .38074 L p .645 .748 .924 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47653 .36153 L p .645 .748 .924 r
F P
0 g
s
.77744 .34327 m .78901 .33274 L .8366 .38074 L p .752 .774 .871 r
F P
0 g
s
.53037 .36591 m .52994 .3725 L .48391 .37696 L p .634 .783 .953 r
F P
0 g
s
.48391 .37696 m .48024 .36934 L .53037 .36591 L p .634 .783 .953 r
F P
0 g
s
.70836 .39248 m .69687 .39662 L .65052 .37095 L p .58 .736 .949 r
F P
0 g
s
.64206 .37595 m .65052 .37095 L .69687 .39662 L p .534 .728 .963 r
F P
0 g
s
.52994 .3725 m .53037 .36591 L .58007 .37078 L p .574 .789 .98 r
F P
0 g
s
.27399 .32374 m .28544 .3298 L .23513 .37315 L p .682 .81 .944 r
F P
0 g
s
.23513 .37315 m .22154 .37026 L .27399 .32374 L p .682 .81 .944 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35199 .36852 L p .626 .74 .93 r
F P
0 g
s
.35199 .36852 m .34115 .36148 L .39573 .33928 L p .626 .74 .93 r
F P
0 g
s
.64206 .37595 m .63367 .38005 L .58465 .36542 L p .528 .751 .978 r
F P
0 g
s
.58007 .37078 m .58465 .36542 L .63367 .38005 L p .503 .754 .985 r
F P
0 g
s
.47278 .35347 m .47653 .36153 L .42626 .3726 L p .635 .745 .927 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47278 .35347 L p .635 .745 .927 r
F P
0 g
s
.58465 .36542 m .58007 .37078 L .53037 .36591 L p .571 .778 .976 r
F P
0 g
s
.71987 .38706 m .70836 .39248 L .65902 .36486 L p .623 .741 .931 r
F P
0 g
s
.65052 .37095 m .65902 .36486 L .70836 .39248 L p .58 .736 .949 r
F P
0 g
s
.53081 .35906 m .53037 .36591 L .48024 .36934 L p .623 .774 .953 r
F P
0 g
s
.48024 .36934 m .47653 .36153 L .53081 .35906 L p .623 .774 .953 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34115 .36148 L p .629 .75 .935 r
F P
0 g
s
.34115 .36148 m .33021 .35473 L .38792 .33076 L p .629 .75 .935 r
F P
0 g
s
.53037 .36591 m .53081 .35906 L .58465 .36542 L p .571 .778 .976 r
F P
0 g
s
.469 .34506 m .47278 .35347 L .41873 .36438 L p .629 .742 .929 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .469 .34506 L p .629 .742 .929 r
F P
0 g
s
.65052 .37095 m .64206 .37595 L .58928 .3595 L p .56 .748 .965 r
F P
0 g
s
.58465 .36542 m .58928 .3595 L .64206 .37595 L p .528 .751 .978 r
F P
0 g
s
.73138 .38033 m .71987 .38706 L .66755 .35759 L p .658 .744 .913 r
F P
0 g
s
.65902 .36486 m .66755 .35759 L .71987 .38706 L p .623 .741 .931 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33021 .35473 L p .634 .76 .939 r
F P
0 g
s
.33021 .35473 m .31917 .34824 L .38005 .32217 L p .634 .76 .939 r
F P
0 g
s
.58928 .3595 m .58465 .36542 L .53081 .35906 L p .578 .768 .969 r
F P
0 g
s
.53125 .35177 m .53081 .35906 L .47653 .36153 L p .618 .765 .95 r
F P
0 g
s
.47653 .36153 m .47278 .35347 L .53125 .35177 L p .618 .765 .95 r
F P
0 g
s
.74289 .37239 m .73138 .38033 L .67611 .34911 L p .686 .745 .896 r
F P
0 g
s
.66755 .35759 m .67611 .34911 L .73138 .38033 L p .658 .744 .913 r
F P
0 g
s
.46518 .33625 m .469 .34506 L .41113 .35609 L p .626 .741 .93 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46518 .33625 L p .626 .741 .93 r
F P
0 g
s
.53081 .35906 m .53125 .35177 L .58928 .3595 L p .578 .768 .969 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31917 .34824 L p .64 .768 .941 r
F P
0 g
s
.31917 .34824 m .30803 .34196 L .3721 .3135 L p .64 .768 .941 r
F P
0 g
s
.65902 .36486 m .65052 .37095 L .59395 .35281 L p .593 .745 .949 r
F P
0 g
s
.58928 .3595 m .59395 .35281 L .65052 .37095 L p .56 .748 .965 r
F P
0 g
s
.7544 .3634 m .74289 .37239 L .68469 .3395 L p .707 .745 .882 r
F P
0 g
s
.67611 .34911 m .68469 .3395 L .74289 .37239 L p .686 .745 .896 r
F P
0 g
s
.53169 .3439 m .53125 .35177 L .47278 .35347 L p .617 .756 .945 r
F P
0 g
s
.47278 .35347 m .469 .34506 L .53169 .3439 L p .617 .756 .945 r
F P
0 g
s
.59395 .35281 m .58928 .3595 L .53125 .35177 L p .591 .759 .958 r
F P
0 g
s
.46133 .32702 m .46518 .33625 L .40346 .34772 L p .626 .741 .93 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46133 .32702 L p .626 .741 .93 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30803 .34196 L p .647 .775 .941 r
F P
0 g
s
.30803 .34196 m .29678 .33584 L .36408 .30475 L p .647 .775 .941 r
F P
0 g
s
.76591 .35359 m .7544 .3634 L .69328 .32891 L p .721 .745 .871 r
F P
0 g
s
.68469 .3395 m .69328 .32891 L .7544 .3634 L p .707 .745 .882 r
F P
0 g
s
.53125 .35177 m .53169 .3439 L .59395 .35281 L p .591 .759 .958 r
F P
0 g
s
.66755 .35759 m .65902 .36486 L .59865 .34519 L p .624 .741 .931 r
F P
0 g
s
.59395 .35281 m .59865 .34519 L .65902 .36486 L p .593 .745 .949 r
F P
0 g
s
.77744 .34327 m .76591 .35359 L .7019 .31756 L p .729 .746 .865 r
F P
0 g
s
.69328 .32891 m .7019 .31756 L .76591 .35359 L p .721 .745 .871 r
F P
0 g
s
.53214 .33535 m .53169 .3439 L .469 .34506 L p .62 .748 .938 r
F P
0 g
s
.469 .34506 m .46518 .33625 L .53214 .33535 L p .62 .748 .938 r
F P
0 g
s
.45745 .31735 m .46133 .32702 L .39573 .33928 L p .628 .742 .929 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45745 .31735 L p .628 .742 .929 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29678 .33584 L p .654 .779 .94 r
F P
0 g
s
.29678 .33584 m .28544 .3298 L .35599 .29592 L p .654 .779 .94 r
F P
0 g
s
.59865 .34519 m .59395 .35281 L .53169 .3439 L p .608 .75 .945 r
F P
0 g
s
.78901 .33274 m .77744 .34327 L .71056 .3057 L p .733 .747 .864 r
F P
0 g
s
.7019 .31756 m .71056 .3057 L .77744 .34327 L p .729 .746 .865 r
F P
0 g
s
.67611 .34911 m .66755 .35759 L .60338 .33657 L p .65 .737 .913 r
F P
0 g
s
.59865 .34519 m .60338 .33657 L .66755 .35759 L p .624 .741 .931 r
F P
0 g
s
.53169 .3439 m .53214 .33535 L .59865 .34519 L p .608 .75 .945 r
F P
0 g
s
.71056 .3057 m .71927 .29362 L .78901 .33274 L p .733 .747 .864 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28544 .3298 L p .66 .781 .938 r
F P
0 g
s
.28544 .3298 m .27399 .32374 L .34782 .287 L p .66 .781 .938 r
F P
0 g
s
.45353 .30727 m .45745 .31735 L .38792 .33076 L p .632 .743 .928 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45353 .30727 L p .632 .743 .928 r
F P
0 g
s
.5326 .32604 m .53214 .33535 L .46518 .33625 L p .625 .742 .931 r
F P
0 g
s
.46518 .33625 m .46133 .32702 L .5326 .32604 L p .625 .742 .931 r
F P
0 g
s
.60338 .33657 m .59865 .34519 L .53214 .33535 L p .625 .742 .931 r
F P
0 g
s
.68469 .3395 m .67611 .34911 L .60813 .32693 L p .671 .733 .897 r
F P
0 g
s
.60338 .33657 m .60813 .32693 L .67611 .34911 L p .65 .737 .913 r
F P
0 g
s
.53214 .33535 m .5326 .32604 L .60338 .33657 L p .625 .742 .931 r
F P
0 g
s
.44959 .29682 m .45353 .30727 L .38005 .32217 L p .638 .745 .926 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44959 .29682 L p .638 .745 .926 r
F P
0 g
s
.53305 .31599 m .5326 .32604 L .46133 .32702 L p .632 .736 .923 r
F P
0 g
s
.46133 .32702 m .45745 .31735 L .53305 .31599 L p .632 .736 .923 r
F P
0 g
s
.69328 .32891 m .68469 .3395 L .61291 .31633 L p .687 .73 .883 r
F P
0 g
s
.60813 .32693 m .61291 .31633 L .68469 .3395 L p .671 .733 .897 r
F P
0 g
s
.60813 .32693 m .60338 .33657 L .5326 .32604 L p .64 .734 .917 r
F P
0 g
s
.44561 .28606 m .44959 .29682 L .3721 .3135 L p .644 .747 .924 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44561 .28606 L p .644 .747 .924 r
F P
0 g
s
.5326 .32604 m .53305 .31599 L .60813 .32693 L p .64 .734 .917 r
F P
0 g
s
.7019 .31756 m .69328 .32891 L .6177 .30488 L p .698 .728 .874 r
F P
0 g
s
.61291 .31633 m .6177 .30488 L .69328 .32891 L p .687 .73 .883 r
F P
0 g
s
.53351 .30521 m .53305 .31599 L .45745 .31735 L p .64 .732 .915 r
F P
0 g
s
.45745 .31735 m .45353 .30727 L .53351 .30521 L p .64 .732 .915 r
F P
0 g
s
.61291 .31633 m .60813 .32693 L .53305 .31599 L p .654 .729 .904 r
F P
0 g
s
.71056 .3057 m .7019 .31756 L .62253 .29278 L p .706 .728 .868 r
F P
0 g
s
.6177 .30488 m .62253 .29278 L .7019 .31756 L p .698 .728 .874 r
F P
0 g
s
.4416 .27506 m .44561 .28606 L .36408 .30475 L p .65 .749 .922 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .4416 .27506 L p .65 .749 .922 r
F P
0 g
s
.53305 .31599 m .53351 .30521 L .61291 .31633 L p .654 .729 .904 r
F P
0 g
s
.53398 .2938 m .53351 .30521 L .45353 .30727 L p .648 .73 .909 r
F P
0 g
s
.45353 .30727 m .44959 .29682 L .53398 .2938 L p .648 .73 .909 r
F P
0 g
s
.6177 .30488 m .61291 .31633 L .53351 .30521 L p .666 .724 .893 r
F P
0 g
s
.71927 .29362 m .71056 .3057 L .62738 .28022 L p .709 .73 .866 r
F P
0 g
s
.62253 .29278 m .62738 .28022 L .71056 .3057 L p .706 .728 .868 r
F P
0 g
s
.43754 .26392 m .4416 .27506 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53351 .30521 m .53398 .2938 L .6177 .30488 L p .666 .724 .893 r
F P
0 g
s
.62738 .28022 m .63227 .26744 L .71927 .29362 L p .709 .73 .866 r
F P
0 g
s
.53444 .28189 m .53398 .2938 L .44959 .29682 L p .655 .729 .903 r
F P
0 g
s
.44959 .29682 m .44561 .28606 L .53444 .28189 L p .655 .729 .903 r
F P
0 g
s
.62253 .29278 m .6177 .30488 L .53398 .2938 L p .675 .722 .885 r
F P
0 g
s
.53398 .2938 m .53444 .28189 L .62253 .29278 L p .675 .722 .885 r
F P
0 g
s
.62738 .28022 m .62253 .29278 L .53444 .28189 L p .682 .722 .88 r
F P
0 g
s
.53491 .26961 m .53444 .28189 L .44561 .28606 L p .661 .729 .9 r
F P
0 g
s
.44561 .28606 m .4416 .27506 L .53491 .26961 L p .661 .729 .9 r
F P
0 g
s
.63227 .26744 m .62738 .28022 L .53491 .26961 L p .686 .724 .879 r
F P
0 g
s
.53444 .28189 m .53491 .26961 L .62738 .28022 L p .682 .722 .88 r
F P
0 g
s
.53539 .25714 m .53491 .26961 L .4416 .27506 L p .666 .731 .898 r
F P
0 g
s
.4416 .27506 m .43754 .26392 L .53539 .25714 L p .666 .731 .898 r
F P
0 g
s
.53491 .26961 m .53539 .25714 L .63227 .26744 L p .686 .724 .879 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?nZ^nD00ol0003o[kWQojnih@04ojnih@_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00006OnZ^nD00ol0003o
[kWQojnih@0?ojnih@_o00006oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02oo
oooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`Co00000_nW`>/00ol0003oZ[_UojZki@0NojZki@03o`000?n_^N7o[kWQ01[o[kWQ
1ol0000Dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;_ooool001gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo073ooooo0ol0
0007ojO0j`03o`000?nZ^nGoZ[_U01GoZ[_U2Ol0000Pojnih@03o`000?ne^]go]K[M00?o00004Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo000Mooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1[ooooo`Co00002_nW`>/0
0ol0003oZ[_UojZki@06ojZki@oo00002?nY^^H00ol0003o[[SQojjhh@03ojjhh@_o00003on_^N40
0ol0003o]K[MokFjg@04okFjg@?o00003_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Vooooo`Co00003OnW`>/3o`0000;oZ[_U1Ol0000GojVjiP03o`000?n^^>7o[[SQ
00ko[[SQ2_l00005ojnih@03o`000?ne^]go]K[M00Oo]K[M0ol0000;ooooo`03o`000?oooooooooo
03?ooooo0_l0000^ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o00002_ooool00ol0003o
ooooooooo`1Qooooo`Co00003OnW`>/4o`0000;oY[o/00?o0000ojVji_nY^^H07?nY^^H00ol0003o
[[SQojjhh@0Hojjhh@Go00003One^]d4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05gooooo
0ol0000=ojO0j`Co00001onV_n`00ol0003oZK[VojVjiP0<ojVjiQ3o00007_n^^>401?l0003o];[N
okBjg_l0000>okFjg@?o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_o
oooo000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool4o`0000_oYl3[
1Ol00009ojJok0?o00000_nY^^H<o`0000ooYk[W00?o0000ojbhh_n/^>800_n/^>87o`0001;o[[SQ
00?o0000okBjg_nd^]h01?nd^]h3o`0000co]K[M0ol00002ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0:_ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`1Dooooo`?o00002onW`>/4o`0000[oY[o/1?l00002ojBok003o`000?nW^^OoYk[W01_oYk[W00?o
0000ojbhh_n/^>802On/^>87o`0000_o[[SQ00?o0000okBjg_nd^]h01ond^]h3o`0000co]K[M0ol0
000gooooo`03o`000?oooooooooo02[ooooo000Tooooo`;o00003_ooool00ol0003oooooooooo`1A
ooooo`;o00000_nXao000ol0003oYl3[ojO0j`05ojO0j`Co00002_nV_n`4o`0000KoY;o/00?o0000
ojNjionW^^L06onW^^L00ol0003o[;SRojbhhP0@ojbhhPOo00001?n^^>400ol0003o];[NokBjgP0:
okBjgP?o00002one^]d4o`0003Gooooo00?o0000ooooooooool0:Oooool002?ooooo0_l0000@oooo
o`03o`000?oooooooooo04kooooo0_l00005ojS7l003o`000?nW`>_oYl3[00;oYl3[0_l0000:ojJo
k0Co00002onT_n`00ol0003oYk[WojNji`0<ojNji`oo00006On/^>84o`00013o];[N0ol00008okFj
g@04o`000?ne^]go]K[MokFjg@?o0000<oooool00ol0003oooooooooo`0Xooooo`009?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04_ooooo0_l00007ojS7l0?o00002onV_n`3o`00
00goY;o/0ol00002ojNji`co00003_nU^^P00ol0003oZ[WTojZii002ojZii0Oo00004On/^>800ol0
003o/[[Ook:jg`02o`0000oo];[N0ol00005okFjg@03o`000?ne^]go]K[M00;o]K[M00Co0000ok^o
gOl0003o0000<?ooool2o`0002[ooooo000Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool2o`0000OoZ<O`0_l00002ojO7l003o`000?nV_ncoY[o/00GoY[o/1?l0000;ojBo
k0Go00000_nS_^d00ol0003oYK[XojFjj00JojFjj003o`000?nZ^NCoZ[WT00WoZ[WT1ol0000:ojbh
hP03o`000?nb^]oo/[[O00?o/[[O0ol0000>okBjgP?o00000_ne^]d01Ol0003o]K[MokFjgOne^]go
000000Co^koM0_l0000`ooooo`03o`000?oooooooooo02Oooooo000Sooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0AOooool2o`0000OoZ<O`0_l00005ojO7l003o`000?nV_ncoY[o/
00;oY[o/0_l0000;ojBok0Co00002?nS_^d00ol0003oYK[XojFjj00IojFjj003o`000?nZ^NCoZ[WT
013oZ[WT1ol00002ojbhhP03o`000?nb^]oo/[[O00Oo/[[O1?l0000=okBjgP?o00000_ne^]d00ol0
003o^koMok^og@05ok^og@03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool002?o
oooo0_l0000Dooooo`03o`000?oooooooooo047ooooo0ol00006ojS7l0?o00001onWao03o`0000_o
Y;o/1?l0000;oj>nk@?o00000_nU^^PIo`0001WoZ[WT0ol0000=ok:jg`?o00002?nd^]h3o`000004
okBjg_l0003o0000o`0000Wo^koM0_l0000^ooooo`03o`000?oooooooooo02Kooooo000Sooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool2o`0000OoZ<O`0_l00008ojO7l0;o
000000?oYLK`o`000?nT_n`01_nT_n`5o`0000[oXkk]1Ol00002oj6nk@03o`000?nS^n[oXk_Z01So
Xk_Z00?o0000ojNjionW^^L00_nW^^L9o`0000koZ[WT00?o0000ojnjh_n_^^800_l0000<ok:jg`Co
000000Co];[No`000?l0003o00001Ond^]h2o`000003okZngOl0003o^koM00So^koM0_l0000]oooo
o`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0>oooool2o`0000OoZ<O`0_l00007ojO7l0?o00001?nUa_000ol0003oY;o/ojBok002ojBok0;o
00002_nS_^d5o`0000OoXKk]00?o0000oj>kj_nS^nX05onS^nX00ol0003oYk[WojNji`0<ojNji`Wo
00001?nZ^N@00ol0003o[k[RojnjhP04ojnjhP?o00002_nb^]l5o`0000Ko];[N0_l00003okZng@03
o`000?nk_mgo^koM00Oo^koM0_l0000[ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool2o`0000OoZ<O`0_l00007ojO7l0;o0000
1onUa_03o`0000WoXkk]1Ol0000=oj6nk@03o`000?nS^n[oXk_Z00[oXk_Z3Ol0000GojNji`Co0000
2_n_^^83o`0000Co/[[O0ol00005ok:jg`?o00000_nd^]h01?l0003o^[kMokZngOl00003okZng@;o
00002Onk_md2o`0002Wooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`008_ooool3o`0001Sooooo00?o0000oooo
ooooool0=Oooool2o`0000OoZ<O`0_l00007ojO7l0;o00001_nUa_03o`0000?oXlC`00?o0000oj>n
kOnS_^d00_nS_^d4o`0000ooXKk]1?l00002oj>kjP[o00003?nQ_>`01?l0003oXk_Zoj>kj_nS^nX7
o`00013oYk[W00Co0000oj^kiOn[^nGo00002_n_^^84o`0000_o/[[O0_l00003okZng@03o`000?nj
_]go^[kM00?o^[kM0_l00009ok^og@;o0000:Oooool00ol0003oooooooooo`05ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01oooool002;ooooo00?o
0000ooooooooool06Oooool2o`0003?ooooo0_l00006ojS7l0?o00001_nWao03o`0000KoYLK`0_l0
0006oj?4l0Co00003_nQ_^d6o`0000?oX;g]00?o0000oj6lk?nQ_>`05_nQ_>`00ol0003oXk_Zoj>k
jP08oj>kjPKo00002_nW^^L00ol0003oZk_Uoj^ki@03oj^ki@?o00000on_^^83o`0000;o[k[R0ol0
000:ok:jg`03o`000?nh_]ko^[kM00;o^[kM00?o0000okZngOnj_]d01?nj_]d2o`0000Wo^koM0_l0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_oo
ool3o`0000KoZ<O`00?o0000ojO7l?nWao001OnWao02o`0000OoYLK`0_l00005oj?4l0?o00000_nR
`_000ol0003oXKk]oj6nk@08oj6nk@Go00002_nP_Nd00ol0003oXKc/oj6lk00Eoj6lk003o`000?nS
^n[oXk_Z00koXk_Z1ol00002ojNji`03o`000?n[^nGoZk_U00OoZk_U0ol00008ojnjhP?o00001_nb
^]l00ol0003o^;kNokRngP02okRngP03o`000?nj_]go000000Oo^[kM0_l00009ok^og@03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0/ooooo`04o`000?n^co7o[/oaojk?l@;o00000_nXao000ol0003oYlO`ojO7l005ojO7
l0;o00001_nUa_03o`0000GoXlC`0_l00006oj;2l003o`000?nQ_^goXKk]00;oXKk]1Ol0000<oj2m
k@Co00000_nQ_>`Fo`0001OoXk_Z0ol00006oj^ki@?o00000on[^nD3o`0000So[k[R0ol00002ok:j
g`03o`000?nh_]ko^;kN00Go^;kN0_l00008okZng@03o`000?nk_mgo^koM00Oo^koM0_l0000Voooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_oo
ool00ol0003o[/oaojk?l@03ojk?l@?o00001_nWao02o`0000KoYLK`0_l00006oj?4l0;o00002?nR
`_04o`0000goX;g]1Ol00003oj2mkP03o`000?nO_NkoWkg^01GoWkg^00?o0000oinmk_nO_Nh00_nO
_Nh8o`0000goXk_Z00?o0000ojJljOnV_>T01?l00009oj^ki@?o00002?n_^^82o`0000Wo^;kN0_l0
0008okZng@;o00002Onk_md2o`0002Cooooo00?o0000ooooooooool00oooool01Ol@413ooooooooo
oooooooo410@00cooooo00?o0000ooooooooool02_ooool000Go00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo02Sooooo00?o0000ojk?lOn^co400on^co401?l0003o[Lkbojg>l_n]c_82o`0000;o
YlO`00?o0000ojG6l?nUa_001OnUa_02o`0000GoXlC`0ol00007oj;2l0?o000000?oXKo_o`000?nP
_Nd02?nP_Nd6o`0000WoX;g^00?o0000oinmk_nO_Nh05?nO_Nh00ol0003oWkg^oinmkP0:oinmkPSo
00001?nS^nX00ol0003oY[cYo`000002o`0000;oY[cY0ol0000:oj^ki@?o00001On_^^801?l0003o
];kQokBnhOl00008okRngP?o00002?nj_]d2o`0000Wo^koM00?o0000ooooooooool08?ooool3o`00
00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o00008Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_800on]c_83
o`0000KoYLK`0_l00005oj?4l0;o00002?nR`_02o`0000GoXKo_00?o0000oj2mkOnP_Nd00onP_Nd3
o`0000goX;g^1?l00003oinmkQ?o00005?nO_Nh6o`0000SoY[cY1?l00009oj^ki@?o000000?o[k[R
o`000?nd_^401?nd_^42o`0000Ko^;kN00Co0000okRng_l0003o00002?nj_]d2o`0000Ko^koM00?o
0000ol36g_l000009?ooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00002Oooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000
ojk?lOn^co400on^co400ol0003o[Lkbojg>lP03ojg>lP04o`000?nZcO;oZ/gboj[=lP;o00000_nU
a_000ol0003oXlC`oj?4l004oj?4l0;o00001onR`_03o`0000OoXKo_0_l000000onP_Ngo0000oj2m
kP0<oj2mkPGo00000onP_Nh00ol0003oW[o`oijol00Coijol003o`000?nK_o7oVkoa00;oVkoa1ol0
0009oinmkPCo00000_nO_Nh00ol0003oY[cYojJlj@09ojJlj@?o00002On[^nD00ol0003o];kQokBn
h@06okBnh@;o00001Onh_]h00ol0003o^;kNokRngP02o`0000So^[kM00?o0000ok^ogOnk_md00_nk
_md01Ol0003o`<KNol36g_o0a]ko000002?ooooo00?o0000ooooooooool07oooool000Oooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Rooooo`03o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_80
0on]c_800ol0003oZ/gboj[=lP03oj[=lP?o00001OnSa?02o`0000OoX/;`0_l00008oj6ok`;o0000
0_nP_Nh00ol0003oX;g^oj2mkP07oj2mkPGo00002OnP_Nh00ol0003oW[o`oijol00Boijol003o`00
0?nK_o7oVkoa00WoVkoa2Ol00002oinmkP03o`000?nO_NkoWkg^00CoWkg^0ol00009ojJlj@?o0000
1_n[^nD00ol0003o[kkUo`000008okBnh@;o00000onh_]h00ol0003o^;kNokRngP02okRngP;o0000
1onj_]d2o`000003ok^ogOl0003o`<KN00Co`<KN00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo023ooooo00?o0000ojk?lOn^co40
0on^co400ol0003o[Lkbojg>lP03ojg>lP03o`000?nZcO;oZ/gb00?oZ/gb00Go0000ojS:l_nXb_;o
Z<[bo`000002oj?4l003o`000?nR`_3oX/;`00GoX/;`0ol00007oj6ok`?o00001OnP_Nh00ol0003o
X;g^oj2mkP02oj2mkPCo00003?nP_Nh3o`0000?oW[o`4_l0000?oi^ol@;o000000?oVkoao`000?l0
00000_l0000:oinmkP?o00002OnV_>T3o`0000;oZk_U00?o0000ojnniOn__^D00_n__^D2o`0000Oo
];kQ0_l00002okRngP03o`000?nh_]ko^;kN00?o^;kN00?o0000okZngOnj_]d01Onj_]d2o`0000Oo
`<KN00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`;o00009Oooool00ol0003oooooooooo`0Nooooo`03
o`000?n^co7o[/oa00?o[/oa00?o0000ojg>l_n]c_800on]c_800ol0003oZ/gboj[=lP03oj[=lP03
o`000?nXb_;oZ<[b00;oZ<[b0ol00006oj;2l0;o00002?nQ_nl2o`0000SoX;g^1?l0000<oj2mkPGo
00000_nQ_Nd00ol0003oWL7aoig1l@0Boig1l@03o`000?nG`_GoUl;e00;oUl;e1ol000001?nK_o7o
0000o`000?l00006oi^ol@04o`000?nG__;oUkkbo`0000[oWkg^0ol00009ojJlj@;o00001on__^D0
0ol0003o];kQokBnh@06okBnh@04o`000?nh_]ko^;kNo`0000Go^;kN0_l00004okZng@04o`000?no
aMoo_lGOo`0000Oo`<KN00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`008?oo
ool2o`0002Oooooo00?o0000ooooooooool07?ooool00ol0003o[/oaojk?l@02ojk?l@;o00001On]
c_800ol0003oZ/gboj[=lP03oj[=lP03o`000?nXb_;oZ<[b00;oZ<[b00Co0000ojG6lOnUa_7oYLKa
0_l00002oj;2l0;o00002?nQ_nl2o`0000OoX;g^0ol000000onO^nco0000oj2mkP08oj2mkPGo0000
2?nQ_Nd00ol0003oWL7aoig1l@07oig1l@_o00002OnG`_D9o`0000;oVkoa00?o0000oiNnl_nG__80
1?nG__83o`0000SoWkg^0ol00006ojJlj@03o`000?nX_^WoZ;kY00Oo[kkU0_l00007okBnh@?o0000
1onh_]h2o`000003okZngOl0003o_lGO00?o_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003ooooo
ooooo`0Oooooo`;o00007_ooool0027ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?n^co7o[/oa00;o[/oa00?o0000ojg>l_n]c_801?n]c_800ol0003oZ/gboj[=
lP02oj[=lP;o00001?nXb_800ol0003oYLKaojG6l@03ojG6l@?o00002?nQ_nl2o`0000OoX;g^0_l0
0005oinkk003o`000?nP_NkoX;g^00;oX;g^1?l0000;oj6mk@?o00000_nM`O47o`0000[oW/?c00Co
0000oi?4n?nCa?SoTlCh1ol00008oiO2m@?o00002OnG__83o`0000SoWkg^0ol00002ojJlj@03o`00
0?nX_^WoZ;kY00;oZ;kY0_l00006ojnni@;o00001ond_^42o`0000So^;kN00?o0000oko5gonoaMl0
1?noaMl00ol0003o`<KNol36gP05ol36gP03o`000?oooooooooo023ooooo00?o0000ooooooooool0
6oooool0023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?n^
co7o[/oa00;o[/oa00?o0000ojg>l_n]c_800on]c_82o`0000CoZ/gb00?o0000ojS:l_nXb_800onX
b_800ol0003oYLKaojG6l@03ojG6l@05o`000?nR`^ooX/;_oj;2kol000001OnQ_nl2o`0000KoX;g^
0ol00007oinkk0Co00002onQ_Nd5o`0000;oX[k]00?o0000oik3lonN`o<04OnN`o<01?l0003oTlCh
oi?4n?nCa?P3o`0000CoTlCh1_l00003oiO2m@05o`000?n?_oOoSkogohnomol000002OnG__83o`00
00SoWkg^0_l00007ojRnj@;o00001_n__^D2o`0000Oo];kQ0_l00004okRngP04o`000?nmaN7o_LGQ
o`0000Ko_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01_ooooo000Pooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0
003o[/oaojk?l@02ojk?l@03o`000?n]c_;o[Lkb00?o[Lkb00?o0000oj[=l_nZcO800onZcO800ol0
003oZ<[bojS:lP03ojS:lP03o`000?nUa_7oYLKa00?oYLKa00?o0000oj;2konR`^l00onR`^l01?l0
003oXKo_oj6okol00006oj2mkP?o00001onO^n`3o`0000;oX;WZ00?o0000oj6mkOnQ_Nd01_nQ_Nd4
o`0000SoX[k]00?o0000oik3lonN`o<01onN`o<=o`0000goTlCh0ol00007ohnom`?o00001onG__83
o`0000GoWkg^00?o0000oinmk_nO_Nh02?nX_^T00ol0003o[kkUojnni@05ojnni@;o00001_nd_^43
o`000003okRng_l0003o_LGQ00?o_LGQ00?o0000oko5gonoaMl01?noaMl00ol0003o`<KNol36gP05
ol36gP03o`000?oooooooooo01oooooo00?o0000ooooooooool06_ooool0023ooooo0_l0000[oooo
o`03o`000?oooooooooo01Cooooo00?o0000ojk?lOn^co400_n^co400ol0003o[Lkbojg>lP03ojg>
lP03o`000?nZcO;oZ/gb00?oZ/gb00?o0000ojS:l_nXb_800onXb_800ol0003oYLKaojG6l@03ojG6
l@03o`000?nR`^ooX/;_00CoX/;_0ol00005oj2mkP;o00001onO^n`3o`0000KoX;WZ00?o0000oj6m
kOnQ_Nd00_nQ_Nd3o`0000WoX[k]1?l000000onN`o?o0000o`000006o`0000OoWlKc0ol00005oi;7
n@Wo00001?nCa?P01?l0003oQl3johO0n_l00007ohnom`?o00001onG__83o`000003oinmk_l0003o
Wkg^00CoWkg^00?o0000ojRnjOnX_^T01?nX_^T2o`0000Oo[kkU00?o0000okBnhOnd_^400ond_^40
1?l0003o];kQo`000?l00006okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000ol36g_o0a]h01Oo0
a]h00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool04_ooool00ol0003o[/oaojk?l@02ojk?l@03o`000?n]c_;o
[Lkb00?o[Lkb00?o0000oj[=l_nZcO800onZcO800ol0003oZ<[bojS:lP02ojS:lP;o00001?nUa_42
o`0000KoX/;_00Go0000oinmkOnO_NgoWkg]o`000002oj2mkP;o00001onO^n`2o`0000WoX;WZ0ol0
0008oj:nk@Ko00001?nU_n`00ol0003oWlKcoio6l`06oio6l`Wo00003onBaoT4o`0000KoQl3j0ol0
0005ohnom`?o00001onG__800ol0003oWkg^oinmkP05oinmkP;o00001_nX_^T2o`0000Ko[kkU0_l0
0004okBnh@04o`000?nha>?o^<CSo`0000Ko_LGQ00?o0000oko5gonoaMl01?noaMl00ol0003o`<KN
ol36gP05ol36gP03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool0023ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?n^co7o[/oa00?o[/oa1On]
c_800ol0003oZ/gboj[=lP02oj[=lP;o00001?nXb_800ol0003oYLKaojG6l@03ojG6l@03o`000?nR
`^ooX/;_00CoX/;_0_l00004oinmk@?o00001_nO^n`3o`0000SoX;WZ0ol00002oj6gj003o`000?nR
_^goX[k]00;oX[k]1?l00009ojFok0?o00000_nOa_<5o`000004oj;8lol0003o0000o`0000CoX/Sc
00?o0000oi;9n_nBbOX00_nBbOX9o`0000CoT/Oi00Co0000oh31o?n0`OcoP<7l1on7`?X3o`0000Go
Skog0ol00002oiNnlP04o`000?nD_?;oU;cboiBllPSoWkg^0_l00006ojRnj@03o`000?n__^Go[kkU
00Go[kkU0_l000001?nd_^7o0000okS4hol00002okS4h`03o`000?nmaN7o_LGQ00Co_LGQ00?o0000
oko5gonoaMl01?noaMl00ol0003o`<KNol36gP05ol36gP03o`000?oooooooooo01gooooo0_l0000J
ooooo`008?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo0ol00003ojk?
l@Ko[Lkb1OnZcO85ojS:lP03o`000?nUa_7oYLKa00?oYLKa00?o0000oj;2konR`^l01?nR`^l00ol0
003oWkg]oinmk@03oinmk@04o`000?nN^>_oW[S[oijhj`;o00000_nO^n`2o`0000WoX;WZ0_l00005
oj6gj0Co00002_nU_n`4o`0000;oZ<3[00?o0000oj;8lonRb?<00onRb?<3o`0000?oX/Sc1Ol0000=
oi;9nPCo00001on0`O`2o`0000GoQl3j0ol00005ohnom`;o00001_nD_?800ol0003oWkg^oinmkP05
oinmkP03o`000?nX_^WoZ;kY00CoZ;kY0_l00006ojnni@;o00000onha><01?l0003o^<CSokS4hol0
0006okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000ol36g_o0a]h01Oo0a]h00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo000Oooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool03Oooool00ol0003o]]?_okKCk`05o`0000?o[Lkb1OnZcO86ojS:lPCoYLKa0_l00006
oj;2k`03o`000?nO_NgoWkg]00?oWkg]00?o0000oijhjonN^>/00onN^>/3o`0000SoX;WZ0ol00005
oj6gj0;o00000_nS]^H00ol0003oYKo/ojFok005ojFok0Co00001onX`>/00ol0003oX/Sco`000002
o`000003oj;8lol0003o000000?o00001?nVb_<00ol0003oU/ckoiK<n`06oiK<n`So00000omm`_d0
0ol0003oP<7loh31o005oh31o0?o00001?n7`?X3o`000003ohnomol0003oR;[f00;oR;[f1_nD_?82
o`0000KoWkg^0_l00006ojRnj@;o00000on__^D01?l0003o//;Vok;2i_l00002okS4h`05o`000?nh
a>?o^<CSokS4hol000001_nmaN400ol0003o_lGOoko5g`04oko5g`03o`000?o0a]ko`<KN00Go`<KN
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`007oooool2o`00037ooooo00?o
0000ooooooooool02oooool00ol0003o]]?_okKCk`02okKCk`04o`000?nedo3o]M?`okGCl0Co0000
0onZcO86ojS:lPCoYLKa00?o0000oj;2konR`^l01?nR`^l2o`0000CoWkg]0_l00005oijhj`05o`00
0?nL]>SoW;CXoibdj?l000001OnP^NX2o`0000KoXKOX0_l00005oj>fiP04o`000?nU_ncoYKo/ojFo
k0?o00002OnX`>/6o`0000_oY/[c00?o0000oiK<nonFc?/03?nFc?/01Ol0003oOlCmogo4oOmoa?go
000000CoOL;m0ol00004oh31o0?o00001?n7`?X00ol0003oR;[fohRjmP04ohRjmP03o`000?nD_?;o
U;cb00?oU;cb0_l00006oinmkP;o00001_nX_^T00ol0003o[kkUo`000004ok;2iP04o`000?nha>?o
^<CSo`0000?o^<CS00?o0000okg5hOnmaN401?nmaN400ol0003o_lGOoko5g`04oko5g`03o`000?o0
a]ko`<KN00Go`<KN00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`007oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo00Go0000okKCkonfdnoo]]?_o`00
0005okGCl003o`000?nbdO3o/]7`00Go00000onXb_85ojG6l@KoX/;_00?o0000oinmkOnO_Nd00onO
_Nd00ol0003oW[S[oijhj`04oijhj`03o`000?nL]>SoW;CX00?oW;CX00?o0000oj2ij_nP^NX00_l0
0006oj6gj0;o00001onS]^H3o`0000WoZ<3[1Ol000000on/`NWo0000ojK:l`06ojK:l`So00000onF
c?/;o`0000OoOlCm0ol00002ogg2o@Co00000on0`O`3o`0000?oO;Si00?o0000ohRjm_n8^_H01?n8
^_H2o`0000CoU;cb0_l00006oinmkP03o`000?nX_^WoZ;kY00?oZ;kY0_l00006ok;2iP04o`000?nh
a>?o^<CSo`0000?o^<CS00?o0000okg5hOnmaN401?nmaN400ol0003o_lGOoko5g`04oko5g`03o`00
0?o0a]ko`<KN00Co`<KN0_l0000Nooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003o]]?_okKCk`02okKCk`03o`000?ne
do3o]M?`00;o]M?`00?o0000ok;Al?nbdO000_nbdO001?l0003o[/k`ojk>l?n^c_04o`0000?oYLKa
1OnR`^l2o`0000GoWkg]00?o0000oijhjonN^>/00onN^>/2o`0000KoW;CX0_l00007oj6gj0;o0000
1onS]^H2o`000003ojJfi?l0003oZ<3[00KoZ<3[1Ol00004ojc1j@;o000000?oY/[co`000?l00000
0ol00007oj_<l@03o`000?nLco[oW<oj00_oW<oj00?o0000ohK8oOn6b?d00_l00007ogo4o@?o0000
0_mm`_d3o`0000?oL[Kj00?o0000ogbhnOml^?T00_ml^?T2o`0000GoR;[f0_l00004oiBllP;o0000
1OnO_Nh2o`000003ojRnjOl0003o000000;oZL3Z00?o0000ok;2i_nb`^H01?nb`^H01?l0003o^<CS
okS4hol00003okS4h`03o`000?nmaN7o_LGQ00Co_LGQ00?o0000oko5gonoaMl01?noaMl01?l0003o
`<KNol36g_o0a]h2o`000003ol?>hol0003ooooo01kooooo00?o0000ooooooooool05Oooool001oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`06ooooo`03o`000?nfdnoo]]?_00;o
]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`000?n^c_3o[/k`00?o
[/k`00?o0000oj[9l?nZbO000ol00005oj;2k`KoWkg]00?o0000oijhjonN^>/00onN^>/00ol0003o
W;CXoibdj005oibdj004o`000?nL/>GoW;3Uo`0000CoXKOX0_l00007oj>fiP;o00001?nV]^@01?l0
003oZ<3[ojS0jonX`>/6o`0000?o[<7Y0ol000000on``^So0000oj_<l@09oj_<l@Co00000onLcoX:
o`0000SoQ/Sm1?l00003ogo4o@;o00000om]]O/5og:fnP;o00000oml^?T3o`0000CoR;[f0_l00004
oiBllP03o`000?nO_NkoWkg^00?oWkg^0_l00005ojW0jP03o`000?nb`^Ko//;V00Co//;V00?o0000
okS4hol000001?nha><00ol0003o_LGQokg5h@04okg5h@03o`000?noaMoo_lGO00Co_lGO00?o0000
ol36g_l000001?o3c^<00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eoooo
o`;o00001_ooool01Ol0003o]]?_okKCkonfdnoo000000Go]M?`00?o0000ok;Al?nbdO000_nbdO00
0ol0003o[/k`ojk>l002ojk>l003o`000?nZbO3oZ/W`00;oZ/W`00Co0000ojG3kol0003o00000_nR
`^l6oinmk@KoW[S[00?o0000oibdj?nL]>P01OnL]>P00ol0003oW;3Uoib`i@02oib`i@04o`000?nQ
]nSoXKOXo`0000KoXkKV0ol00006ojJfi0?o000000Co[<7Yo`000?l0003o00000on/`NT3o`0000Go
/<;X00?o0000oj_<lOn[c?400_n[c?45o`0000?o/<g_00?o0000oj?AmonSdOL02OnSdOL00ol0003o
T<cloi3<o002oi3<o0Co00001On6b?d3o`0000?oKKKk1?m]]O/00ol0003oL[Kjog:fnP02og:fnP;o
00001?ml^?T2o`0000CoR;[f0_l00003oiBllP;o000000?oWkg^o`000?l000000onO_Nh5ojW0jP03
o`000?nb`^Ko//;V00Co//;V00?o0000okS4hol000001?nha><00ol0003o_LGQokg5h@04okg5h@03
o`000?noaMoo_lGO00?o_lGO0_l00005ol?>h`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`03o`00
0?nfdnoo]]?_00;o]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`00
0?n^c_3o[/k`00;o[/k`00?o0000oj[9l?nZbO000_nZbO000ol0003oYL?_ojG3k`02ojG3k`Co0000
0onO_Nd5oijhj`;o00001_nL]>P2o`0000GoW;3U0ol00005oj>fiP;o00001onV]^@2o`000004ojVf
hol0003o0000o`0000Co[<7Y0_l00007ok32j0;o000000?oZlcao`000?n`cNl01on`cNl3o`0000;o
Xm7g2Ol0000:oi3<o0Co00000omd^_`5offfn`04o`000?m]]O_oKKGkoffen`;o00000omb]_X2o`00
00CoO;Si0_l00004ohRjmP;o00000_nD_?82o`0000KoWkg^1OnY`>X00ol0003o//;Vok;2iP04ok;2
iP03o`000?nha>?o000000Co^<CS00?o0000okg5hOnmaN401?nmaN401ol0003o_lGOoko5gonoaMoo
0000ol;=hol000001Oo3c^<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo000N
ooooo`03o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`000003okKCk`03o`000?ne
do3o]M?`00?o]M?`00Go0000ok;Al?nbdO3o/]7`o`000005ojk>l005o`000?nZbO3oZ/W`oj[9l?l0
00001OnU`nl01?l0003oWkg]oinmkOnO_Nd3o`0000GoW[S[1onL]>P00ol0003oW;3Uoib`i@04oib`
i@04o`000?nM[^?oWJkSoif^h`;o00000_nS]^H00ol0003oY[KTojJfi005ojJfi0Go00000_nY]^<0
1Ol0003o[<7Yojc1jOn/`NWo000000Ko/<;X0ol000000onda>Ko0000ok3=k`05ok3=k`Co00000_nf
c^`00ol0003o[=;dojcBm008ojcBm004o`000?nLcoWoW<oioic?n@Go00000on@c?`01?l0003oP;ok
oh2onol00004ogBjo003o`000?m]]__oKKKk00;oKKKk00Go0000offenom]]O_oKKGko`000004og:f
nP;o00001?ml^?T2o`0000;oR;[f00Co0000ohRjm_l0003o00000onB^O46oinmkP03o`000?nY`>[o
ZL3Z00;oZL3Z00?o0000ok;2i_nb`^H01?nb`^H00ol0003o^<CSo`000004okS4h`03o`000?nmaN7o
_LGQ00Co_LGQ00?o0000oko5gol000000oo2cN<00ol0003o`lkSol?>h`03ol?>h`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool04_ooool001?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000001?nfdnl00ol0003o]M?`okGCl002
okGCl003o`000?nbdO3o/]7`00;o/]7`00?o0000ojk>l?n^c_000_n^c_000ol0003oZ/W`oj[9l002
oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd01?l0003oV[K[o`000?l0
0002oijhj`OoW;CX00?o0000oib`iOnL/>D01?nL/>D00ol0003oWJkSoif^h`03oif^h`;o00001onV
]^@4o`0000GoZKKS0_l00006ok32j0?o00001Onda>H01?l0003o/<g_ok3=kon`cNl2o`0000Ko]/k/
00?o0000ojcBm?n/d_@00_n/d_@6o`0000WoW<oi0ol00005oh2on`;o00000omd^_`2o`0000;oKKKk
0_l00002offen`;o00001?mb]_X2o`0000;oO;Si1?l00003ohFdm003o`000?nB^O7oT[Wa00;oT[Wa
00?o0000oinmk_nO_Nh00onO_Nh00ol0003oZL3ZojW0jP02ojW0jP03o`000?nb`^Ko//;V00Co//;V
0_l00005okS4h`03o`000?nmaN7o_LGQ00?o_LGQ0_l00004ol;=h`03o`000?o3c^?o`lkS00?o`lkS
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0>_ooool00ol0003o]]?_okKCk`02okKCk`03o`00
0?nedo3o]M?`00;o]M?`00?o0000ok;Al?nbdO000_nbdO000ol0003o[/k`ojk>l002ojk>l003o`00
0?nZbO3oZ/W`00;oZ/W`00?o0000ojG3konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`00
0?nJ]^_oV[K[00;oV[K[0_l00005oibdj0;o00001_nL/>D00ol0003oWJkSoif^h`03oif^h`04o`00
0?nO[>7oWjcQo`0000CoY[KT0ol00006ojVfh`;o00000_n]]n400ol0003o/<;Xok32j003o`0000Oo
]<CV0ol00008okK>k0?o000000Co[=;do`000?l0003o00001?ndd_000ol0003oZ=3eojS@m@04ojS@
m@Go00000on>a?X00ol0003oP;okoh2on`03oh2on`;o00000omd^_`2o`0000;oKKKk0_l00002offe
n`;o00000_mb]_X4o`0000?oNJoe00?o0000ohFdm?n5]?@00_n5]?@00ol0003oT[Waoi:il@02oi:i
l@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0j_nY`>X00_nY`>X00ol0003o//;Vok;2iP04ok;2
iP;o00001Onha><00ol0003o_LGQo`000002o`000003oko<i?l0003o`/gS00Co`/gS00?o0000ol?>
hoo3c^<00oo3c^<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@
413oooooooooo`03ooooo`004oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0>_ooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o]M?`00?o0000ok;A
l?nbdO000_nbdO001Ol0003o[/k`ojk>l?n^c_3o000000GoZ/W`00?o0000ojG3konU`nl00_nU`nl0
0ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`j?l000000onL]>P0
0ol0003oW;3Uoib`i@04oib`i@;o00001OnM[^<00ol0003oWjcQoin/h@02oin/h@Co00001onY]^<2
o`0000Co[KOQ0ol00007okC4iP?o00000_nhaN@01?l0003o]/k/okK>k?nfc^`5o`0000;o^lkX00?o
0000okCBl?ndd_000_ndd_04o`0000SoZ=3e00Co0000oig8m_nMb?KoWLSf0_l00004ohk4nP;o0000
0on0_o/2o`0000?oM;[l2_l00004ofn[mPCoNJoe00?o0000ohFdm?n5]?@00_n5]?@00ol0003oT[Wa
oi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0j_nY`>X00_nY`>X00ol0003o//;V
ok;2iP04ok;2iP;o00001?nha><2o`0000Go_lcT00?o0000ol;=hoo2cN<00_o2cN<00ol0003o`lkS
ol?>h`03ol?>h`03o`000?oooooooooo01gooooo00?o0000ooooool000002_ooool00ol0003ooooo
ooooo`05ooooo`004oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0000jooooo`03o`00
0?nfdnoo]]?_00;o]]?_00?o0000okGCl?nedo000_nedo000ol0003o/]7`ok;Al002ok;Al003o`00
0?n^c_3o[/k`00;o[/k`00?o0000oj[9l?nZbO000_nZbO000ol0003oYL?_ojG3k`02ojG3k`03o`00
0?nO_NgoWkg]00?oWkg]00?o0000oiZfjonJ]^/00_nJ]^/01Ol0003oUk3XoiN`j?nG/>So000000;o
W;CX1_nL/>D00ol0003oWJkSoif^h`04oif^h`04o`000?nO[>7oWjcQoin/h@Go00001onY]^<00ol0
003o[KOQojfgh@02ojfgh@;o00000_na^Ml00ol0003o]<CVokC4iP03okC4iP;o00001OnhaN@4o`00
00Ko^lkX0_l000000ondd_3o0000o`000004ok_Aj`03o`000?ncd>oo/m3_00;o/m3_1?l00007oig8
mP?o00000on>a?X3o`000003oh2onol0003o000000?oKjcf2?mYZOH5ofn[mPCoNJoe00?o0000ohFd
m?n5]?@00_n5]?@00ol0003oT[Waoi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o0000ojW0
j_nY`>X00_nY`>X00ol0003o//;Vok;2iP04ok;2iP;o00000_nha><00ol0003o^/[Voko<i005oko<
i003o`000?o2cN?o`/gS00?o`/gS00?o0000ol?>hoo3c^<00_o3c^<00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo03[ooooo00?o0000okKCkonfdnl00_nfdnl00ol0
003o]M?`okGCl002okGCl003o`000?nbdO3o/]7`00;o/]7`00Go0000ojk>l?n^c_3o[/k`o`000004
oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd00ol0003oV[K[oiZfj`02
oiZfj`03o`000?nG/>SoUk3X00?oUk3X0_l00005oib`i@03o`000?nM[^?oWJkS00?oWJkS0_l00000
1_nO[>7o0000o`000?l0003oWjcQo`0000?oXZcO00?o0000ojVfhonY]^<00_nY]^<2o`0000Co[KOQ
00?o0000ok6igona^Ml00ona^Ml00ol0003o]<CVokC4iP02o`0000Co^<GT0ol000000onla^;o0000
ok_>j004ok_>j0?o000000?o_lgUo`000?nkdN/01OnkdN/00ol0003o/m3_ok?@k`06ok?@k`03o`00
0?n[bo3o000000;o00001_nMb?H2o`0000;oR;Se00?o0000ogZbm_mj/_H00_mj/_H4ofn/mP03o`00
0?mYZOKoJJWf00GoJJWf00?o0000ofn[m_m_ZoH00_m_ZoH01Ol0003oNJoeogV_mOmi[oGo000000Co
QKCd00?o0000oi:ilOnB^O400_nB^O400ol0003oWkg^oinmkP03oinmkP03o`000?nY`>[oZL3Z00;o
ZL3Z00?o0000ok;2i_nb`^H01?nb`^H00ol0003o^<CSo`000003ok[:iPKo_lcT00?o0000ol;=hoo2
cN<00_o2cN<00ol0003o`lkSol?>h`03ol?>h`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`004oooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool0>Oooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o
]M?`00?o0000ok;Al?nbdO000_nbdO001Ol0003o[/k`ojk>l?n^c_3o000000GoZ/W`00?o0000ojG3
konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`
j?nG/>P00onG/>P00ol0003oU:_Vo`000002o`0000;oW;3U1OnM[^<4o`0000?oWjcQ00?o0000oj:/
gonR[=l00onR[=l01?l0003oZKKSojVfhol00004ojfgh@;o00001_na^Ml2o`0000Go^<GT0_l00005
okc6hP03o`000?nkc^So^lkX00;o00000onocND01?l0003o^m7[ok_AjonkdN/5o`000004ok?@kol0
003o0000o`0000?o/m3_00?o0000oj_;l?n[bo000on[bo02o`000003oig8m_l0003o000000;oV;kb
00Go0000ohRhmOn8^?GoR;Seo`000004ogZbmP05o`000?m_[?KoKjcfofn/m_l000000omYZOH01Ol0
003oJJWfofVYm_mYZOKo000000CoKj_f00Go0000ogV_mOmi[oGoNJoeo`000004ohFdm003o`000?nB
^O7oT[Wa00;oT[Wa00?o0000oinmk_nO_Nh00onO_Nh00ol0003oZL3ZojW0jP02ojW0jP03o`000?nb
`^Ko//;V00?o//;V0_l00004ok[:iP03o`000?noc>Co_lcT00?o_lcT00?o0000ol;=hoo2cN<00oo2
cN<00ol0003o`lkSol?>h`02ol?>h`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0>?ooool00ol0003o]]?_okKCk`02okKCk`03o`000?nedo3o]M?`00;o]M?`00?o
0000ok;Al?nbdO000_nbdO000ol0003o[/k`ojk>l002ojk>l003o`000?nZbO3oZ/W`00;oZ/W`00?o
0000ojG3konU`nl00_nU`nl00ol0003oWkg]oinmk@03oinmk@03o`000?nJ]^_oV[K[00;oV[K[00?o
0000oiN`j?nG/>P00onG/>P00ol0003oU:_VoiB[iP03oiB[iP;o00000onM[^<3o`0000GoWjcQ00?o
0000oj:/gonR[=l01?nR[=l3o`0000Co[KOQ00?o0000ok6igona^Ml01Ona^Ml01?l0003o]K_NokFk
g_l00002okS5i0;o00001_nla^83o`0000Go_lgU1Ol00004ol7?i@03o`000?nlcnWo_<oY00;o_<oY
0ol00008oj_;l003o`000?nH__;oV;kb00?oV;kb00Go0000ohRhmOn8^?GoR;Seo`000004ogZbmP05
o`000?m_[?KoKjcfofn/m_l000001?mYZOH01?l0003oJJWfofVYm_l00004ofn[mP05o`000?mi[oGo
NJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@02oi:il@03o`000?nO_NkoWkg^00?oWkg^00?o
0000ojW0j_nY`>X00_nY`>X00ol0003o//;Vo`000002o`000003ok?7jOnjb^Ko000000Co^/[V00?o
0000oko<i?noc>@00_noc>@00ol0003o`/gSol;=h`03ol;=h`03o`000?o3c^?o`lkS00;o`lkS00?o
0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000C
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Wooooo00?o0000okKCkonfdnl00_nf
dnl00ol0003o]M?`okGCl002okGCl003o`000?nbdO3o/]7`00;o/]7`00Go0000ojk>l?n^c_3o[/k`
o`000005oj[9l003o`000?nU`nooYL?_00;oYL?_00?o0000oinmkOnO_Nd00onO_Nd01Ol0003oV[K[
oiZfjonJ]^_o000000GoUk3X00?o0000oiB[i_nDZnH01?nDZnH00ol0003oTjOSo`000003o`0000Ko
WjcQ00?o0000oj:/gonR[=l01?nR[=l01Ol0003oYJgMojF]gOnU[Mgo000000;o[KOQ1ona^Ml2o`00
00?o]K_N0_l00007okc6hP;o000000?o`<KOo`000?nocND00_nocND3o`000003ol?<hOl0003o`LoU
00Go`LoU00?o0000okc?jOnlcnT01?nlcnT00ol0003o]/_ZokK;jP03o`000003oj_;l?l0003o0000
00?oY/?^00?o0000oiRnl_nH__800_nH__801Ol0003oR;SeohRhmOn8^?Go000000CoN[;f00Go0000
ofn/m_m_[?KoKjcfo`000004ofVYmP04o`000?mYZOKoJJWfo`0000CoKj_f00Go0000ogV_mOmi[oGo
NJoeo`000004ohFdm003o`000?nB^O7oT[Wa00;oT[Wa00?o0000oinmk_nO_Nh00onO_Nh00ol0003o
ZL3ZojW0jP03o`0000Go/lOY00?o^/[Vo`000?njb^H00_njb^H00ol0003o_lcToko<i003oko<i003
o`000?o2cN?o`/gS00;o`/gS00?o0000ol?>hoo3c^<00oo3c^<00ol0003oooooooooo`0Oooooo`;o
00001oooool00ol0003oooooooooo`05ooooo`007Oooool00ol0003oooooooooo`0goooooaOo0000
0_nZbO000ol0003oYL?_ojG3k`02ojG3k`03o`000?nO_NgoWkg]00?oWkg]00?o0000oiZfjonJ]^/0
0_nJ]^/00ol0003oUk3XoiN`j003oiN`j003o`000?nDZnKoU:_V00?oU:_V0ol00002oi>Wh`;o0000
1OnO[>400ol0003oXZcOoj:/g`04oj:/g`03o`000?nU[MgoYJgM00?oYJgM0_l00006ok6ig`03o`00
0?ne^mko]K_N00;o]K_N00Co0000okVmgOni_Mgo00001?nla^82o`0000Co`<KO00?o0000oko=iOl0
00001?o3c>401?l0003o`LoUol7?iOo1cnD4o`000003okc?jOl0003o000000;o_<oY00?o0000okK;
j_nfbnX01?nfbnX00ol0003oY/?^ojK3kP04ojK3kP03o`000?nH__;oV;kb00;oV;kb00Go0000ohRh
mOn8^?GoR;Seo`000004ogZbmP05o`000?m_[?KoKjcfofn/m_l000001?mYZOH01?l0003oJJWfofVY
m_l00004ofn[mP05o`000?mi[oGoNJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@02oi:il@04
o`000?nO_NkoWkg^oinmkPCo00000_nZ`^`00ol0003o/lOYok?7j@03ok?7j@;o00001?njb^H00ol0
003o_lcToko<i002oko<i003o`000?o2cN?o`/gS00?o`/gS00?o0000ol?>hoo3c^<00_o3c^<00ol0
003oooooooooo`0Nooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool001go
oooo00?o0000ooooooooool0=oooool00ol0003o_]?ZokkCjP02okkCjP03o`000?nldn_o_=?[00;o
_=?[00?o0000ok[Ak?njdN`00_njdN`01Ol0003o]Lk]okG>kOnec^go000000?o[l[^2?l00004oinm
k@03o`000?nJ]^_oV[K[00;oV[K[00?o0000oiN`j?nG/>P00onG/>P00ol0003oU:_VoiB[iP02oiB[
iP;o00001OnCYn<00ol0003oU:GQo`000003oin/h@03o`000?nR[=ooXZcO00?oXZcO0_l00006ojF]
g@03o`000?nY[mco000000?o/KWO0_l00004okFkgP03o`000?ni_Mgo^KgM00;o^KgM00Co0000okc6
h_nla^;o00001Oo0a]l2o`0000Go`lcQ1Ol00003olG=h@04o`000?o2cN?o`/gSol;=h`;o00001Onf
bnX01Ol0003o//GXok;5j?nbaNSo000000GoY/?^00?o0000oiRnl_nH__806?l00004ofn[mP05o`00
0?mi[oGoNJoeogV_mOl000001?n5]?@00ol0003oT[Waoi:il@05o`0000;oWkg^1OnZ`^`00ol0003o
/lOYok?7j@03ok?7j@;o00000onjb^H00ol0003o_lcToko<i003oko<i003o`000?o2cN?o`/gS00;o
`/gS00?o0000ol?>hoo3c^<00oo3c^<00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00co
oooo000Looooo`03o`000?oooooooooo03Sooooo00?o0000okkCj_nndnX00_nndnX00ol0003o_=?[
okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/00Go0000okG>kOnec^go]Lk]o`000004ojo:kP03
o`000?nWa>koYlC^00;oYlC^0_nO_Nh3o`000003oinmkOl0003oV[K[00?oV[K[00?o0000oiN`j?nG
/>P00_nG/>P00ol0003oU:_VoiB[iP03o`000003oiB[i_l0003oTjOS00?oTjOS00Oo0000oiBUhOnD
YN7oU:GQo`000?nO[>7o000000GoXZcO00?o0000ojF]gOnU[Md01OnU[Md01Ol0003oZJoLojV_g?nY
[mco000000;o/KWO1?ne^mh2o`0000Go^KgM0_l00005ol36g`;o000000?o`lOMo`000?o3c>400_o3
c>42o`000003olK;g_l0003oaLgQ00CoaLgQ00?o0000ol;=hoo2cN<00oo2cN<01?l0003o_/_Tokk;
i?nnbn@2o`0000Ko//GX00Go0000ojK3k_nV`nko0000ojK3kP02o`0000;oVKG[00Go0000oh^^kOn;
[^goRjk]o`000004ognXkP05o`000?mfXnkoMZ?^ogJSk_l000001?maXNh3og6Qka7o00000_nC]^l6
oinmkPCoZ/;/00?o0000ok?7jOncanT00oncanT00ol0003o^/[Vo`000003ok[:iP03o`000?noc>Co
_lcT00;o_lcT00?o0000ol;=hoo2cN<00oo2cN<00ol0003o`lkSol?>h`02ol?>h`03o`000?oooooo
oooo01oooooo0ol0000=ooooo`007?ooool00ol0003oooooooooo`0hooooo`03o`000?nndn[o_]?Z
00;o_]?Z00?o0000okcCjonldn/00_nldn/00ol0003o^]7/ok[Ak002ok[Ak005o`000?nec^go]Lk]
okG>kOl000001?n_b^h00ol0003oYlC^ojO4kP02ojO4kPGoWkg^0ol00002oiZfj`03o`000?nG/>So
Uk3X00?oUk3X0ol00003oiB[iP03o`000?nCYn?oTjOS00;oTjOS00?o0000oiBUhOnDYN400onDYN42
o`0000CoXZcO00?o0000ojF]gOnU[Md01OnU[Md00ol0003oZJoLojV_g003ojV_g0;o00001?ne^mh6
okVmg@03o`000?nm_m_o000000Co`<KO00?o0000ol?7gOo3amd00_o3amd00ol0003o`lcQo`000003
olK;gP03o`000?o5cN7oaLgQ00?oaLgQ00?o0000ol;=hoo2cN<00_o2cN<01Ol0003o_/_Tokk;i?nn
bnCo000000;o_<OS00?o0000ok;5j?nbaNP01?nbaNP2o`0000;oYK_X00?o0000oiVejonI]N/00_nI
]N/01Ol0003oRjk]oh^^kOn;[^go000000CoOjS^00Go0000ogJSk_mfXnkoMZ?^o`000004og6QkP?o
LJ7_00?o0000ogFTkomeY>l00_meY>l4ogbYl0GoQjo`1OnC]^l5oinmkP03o`000?nZ`^coZ/;/00;o
Z/;/00?o0000ok?7jOncanT00oncanT2o`0000?o^/[V00?o0000oko<i?noc>@00onoc>@00ol0003o
`/gSol;=h`02ol;=h`03o`000?o3c^?o`lkS00;o`lkS00?o0000ooooooooool07?ooool3o`0000;o
oooo00?o0000ooooooooool02oooool001cooooo0_l0000iooooo`03o`000?nndn[o_]?Z00;o_]?Z
00?o0000okcCjonldn/00_nldn/00ol0003o^]7/ok[Ak002ok[Ak005o`000?nec^go]Lk]okG>kOl0
00001?n_b^h00ol0003oYlC^ojO4kP02ojO4kP03o`000?nO_NkoWkg^00;oWkg^0onG]N`8o`0000Go
U:_V00?o0000oi>WhonCYn<00onCYn<00ol0003oU:GQoiBUh@03oiBUh@06o`000?nFY=oo0000o`00
0?nR[=oo00001onU[Md00ol0003oZJoLojV_g003ojV_g004o`000?n^/]_o[[;Ko`0000;o]K_N1Oni
_Md2o`0000?o_KoK00Co0000ol36goo0a]oo00001?o3amd2o`0000Goa/_N00?o0000olG=hOo5cN40
2?l000001?nnbnCo0000okk;i?l00004okc7h`03o`000?nbaNSo000000;o000000?o/KoUo`000?nU
^nP00onU^nP01Ol0003oVKG[oiVejonI]N_o000000CoRjk]00Go0000ognXk_moZ>koOjS^o`000003
ogJSkP03o`000?maXNkoLJ7^00;oLJ7^00Go0000og6QkomaXNooLJ7_o`000004ogFTk`CoO:W`1On7
[o04oi>fk`03o`000?nO_NkoWkg^00?oWkg^00Go0000oj[2k?nZ`^coZ/;/o`000005ok?7j@03o`00
0?njb^Ko000000;o^/[V00?o0000oko<i?noc>@00onoc>@00ol0003o`/gSol;=h`03ol;=h`04o`00
0?o3c^?o`lkSol?>h`;o00006_ooool3o`0000Gooooo00?o0000ooooooooool02oooool001cooooo
00?o0000ooooooooool0>?ooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000ok[Ak?nj
dN`00_njdN`00ol0003o]Lk]okG>k@02okG>k@03o`000?n_b^ko[l[^00;o[l[^00Go0000ojO4k_nW
a>koYlC^o`000005oinmkPCoUkG/00?oSjg[o`000?l000001?l00005oiB[iP03o`000?nCYn?oTjOS
00;oTjOS00?o0000oiBUhOnDYN400onDYN400ol0003oUZCOoiJTg`02oiJTg`;o00001_nU[Md00ol0
003oZJoLojV_g003ojV_g003o`000?n^/]_o[[;K00;o[[;K0_l00003okVmg@;o00001Onm_m/2o`00
00Co`lOM0_l000000oo6b=_o0000olK;gP03olK;gPCo00000_o8bmd01Ol0003oa/cNolK<g_o6c=ko
000000?oaL[N00?o0000okc7honlan<01?nlan<00ol0003o/KoUok6oi@03ok6oi@03o`000?nU^nSo
YK_X00;oYK_X00Go0000oiVejonI]N_oVKG[o`000003oh^^k@03o`000?moZ>koOjS^00;oOjS^00Go
0000ogJSk_mfXnkoMZ?^o`000004og6QkP04o`000?maXNooLJ7_o`0000CoMJC_00Go0000ogbYl?ml
ZO3oO:W`o`000004ohN_l003o`000?nC]^ooTkK_00;oTkK_00?o0000oinmk_nO_Nh00_nO_Nh00ol0
003oZ/;/oj[2k002oj[2k003o`000?ncanWo/lOY00?o/lOY00?o0000ok[:i_l000000_njb^H00ol0
003o_lcToko<i002oko<i003o`000?o2cN?o`/gS00?o`/gS00Ko0000ol?>hol0003o0000ol;Ej?l0
000Gooooo`?o00002?ooool00ol0003oooooooooo`0;ooooo`007?ooool00ol0003oooooooooo`0h
ooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[Ak002ok[Ak003o`000?ne
c^go]Lk]00;o]Lk]00?o0000ojo:k_n_b^h00_n_b^h01Ol0003oYlC^ojO4k_nWa>ko000000GoWkg^
00?o0000oiNek?l000000_l00004ohn]j`;oRZOX0ol000000onDZnKo0000oi>Wh`03oi>Wh`03o`00
0?nDYN7oU:GQ00?oU:GQ00?o0000oiJTgonFY=l00onFY=l01?l0003oVZKNo`000?l00003ojF]g@03
o`000?nY[mcoZJoL00?oZJoL00?o0000ojjbfon^/]/00on^/]/00ol0003o/kKJo`000002okVmg@Ko
_KoK00Co0000ol72f_o1`][o00000_o3amd00ol0003oa/SKolK8f`02olK8f`06o`000?o6bmko0000
o`000?o9b]_o00000oo8bmd01Ol0003oa/cNolK<g_o6c=ko000000?oaL[N00Go0000ol?8g_o3b=ko
0000okc7h`02o`000003ok_3hOl0003o/KoU00Co/KoU00?o0000ojFkj?nU^nP00_nU^nP01Ol0003o
VKG[oiVejonI]N_o000000CoRjk]00?o0000ognXk_moZ>h00_moZ>h01?l0003oMZ?^ogJSk_l00004
og6QkP05o`000?maXNooLJ7_og6Qkol000001?meY>l01Ol0003oO:W`ogbYl?mlZO3o000000CoQjo`
00Go0000oi>fkonC]^ooTkK_o`000005oinmkP03o`000?nZ`^coZ/;/00;oZ/;/00?o0000ok?7jOnc
anT00_ncanT01_l0003o^/[Vok[:i_l0003o^/[Vo`0000Go_lcT00?o0000ol;=hoo2cN<00_o2cN<2
o`0000?o`]GX00?o0000ooooooooool04Oooool4o`0000_ooooo00?o0000ooooooooool02oooool0
01cooooo00?o0000ooooooooool0>?ooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000
ok[Ak?njdN`00_njdN`00ol0003o]Lk]okG>k@02okG>k@03o`000?n_b^ko[l[^00;o[l[^00Go0000
ojO4k_nWa>koYlC^o`000004oinmkP?o00000_nG]N`00ol0003oSjg[ohn]j`02ohn]j`GoRZOX0_l0
0004oi>Wh`03o`000?nDYN7oU:GQ00?oU:GQ00?o0000oiJTgonFY=l00_nFY=l00ol0003oVZKNoiZV
gP02oiZVgP03o`000?nU[Mgo000000GoZJoL00?o0000ojjbfon^/]/00on^/]/01?l0003o/kKJok>f
f_nc]]X2o`0000Go_KoK00?o0000ol72f_o1`]X00_o1`]X00ol0003oa/SKolK8f`03olK8f`;o0000
1?o9b]/00ol0003ob<_Mo`000005o`000004olG:g_l0003oaL[No`0000Co`lSN00?o0000ok_3hOnk
`n400_nk`n400ol0003o/KoUok6oi@02ok6oi@04o`000?nU^nSoYK_XojFkj13o00000omfXnh01Ol0
003oLJ7^og6Qk_maXNko000000CoLJ7_00Go0000ogFTkomeY>ooMJC_o`000003ogbYl003o`000?n7
[o3oQjo`00;oQjo`00?o0000oi>fkonC]^l00_nC]^l00ol0003oWkg^oinmkP02oinmkP03o`000?nZ
`^coZ/;/00;oZ/;/00?o0000ok?7jOncanT00oncanT00ol0003o^/[Vo`000002ok[:iP03o`000?no
c>Co_lcT00;o_lcT00?o0000ol;=hol000000_l000000oo1eNWo0000ol;Ej002ol;Ej003o`000?oo
oooooooo00kooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooo
oooo03Wooooo00Go0000okkCj_nndn[o_]?Zo`000004okcCj`03o`000?njdNco^]7/00;o^]7/00Go
0000okG>kOnec^go]Lk]o`000004ojo:kP03o`000?nWa>koYlC^00;oYlC^00?o0000oinmk_l00000
0ol00004oiNek003o`000?n?[N_oSjg[00;oSjg[00?o0000ohZWj?n:YnP00_n:YnP2ohJRiP;o0000
00?oTjOSo`000?nDYN401?nDYN400ol0003oUZCOoiJTg`03oiJTg`03o`000?nJY]koVZKN00?oVZKN
0_l00004ojV_g003o`000?n^/]_o[[;K00?o[[;K00?o0000ok>ff_nc]]X00_nc]]X00ol0003o^KWJ
o`000003okfof`03o`000?o1`][o`L;J00;o`L;J00?o0000olG4fOl000000oo6b=/00ol0003ob<SI
o`000003olW:f`?o00000_o:b]T01?l0003obL[JolW:f_l00002olW9fP07o`000?o3b=ko`lSNol?8
g_l0003o`/KMo`000005ok_3h@03o`000?na_nGo/KoU00Go00000_nX]N84oij_i0GoTjWU1?n:XnD5
o`0000CoLJ7^00Go0000og6QkomaXNooLJ7_o`000004ogFTk`05o`000?mlZO3oO:W`ogbYl?l00000
1?n7[o001Ol0003oTkK_oi>fkonC]^oo000000CoWkg^00?o0000oj[2k?nZ`^`00onZ`^`00ol0003o
/lOYok?7j@02ok?7j@06o`000?njb^Ko^/[Vo`000?njb^Ko00000onoc>@3o`0000Co`MGY00Go0000
ol;Ej?o2eNSo`]GXo`00000=ooooo`?o00004oooool00ol0003oooooooooo`0:ooooo`006oooool0
0ol0003oooooooooo`0iooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[A
k002ok[Ak005o`000?nec^go]Lk]okG>kOl000001?n_b^h01?l0003oYlC^ojO4k_nWa>h3o`0000?o
Wkg^00?o0000oiNek?nG]N`00_nG]N`01Ol0003oSjg[ohn]jon?[N_o000000GoRZOX1?n6X^H2o`00
00GoU:GQ00?o0000oiJTgonFY=l00_nFY=l00ol0003oVZKNoiZVgP04oiZVgP06o`000?nOZ=go0000
o`000?nY[mco00001On^/]/00ol0003o/kKJok>ffP02ok>ffP07o`000?ni^M[o^KWJokVif_l0003o
_KoKo`000004ol72fP07o`000?o5a=WoaLCIolG4fOl0003oa/SKo`000003olS8f@05o`000?o9b]_o
0000ol_9fOl000000oo:b]T2olW:fP04o`000?o9bM[obLWJolW9fP;o000000?o`lSNo`000?o2a]d0
0_o2a]d01_l0003o^l?Qok_3hOnk`n7o0000ok_3h@;o00000_nb^n000ol0003oZ;GRojRehP02ojRe
hP05o`000?nN[nCoWZoToij_i?l000001?nCZND00ol0003oRZ?UohZSi@02ohZSi@?oPioV1_l00004
og6Qk`05o`000?meY>ooMJC_ogFTkol000001?mlZO001Ol0003oQjo`ohN_l?n7[o3o000000CoTkK_
00?o0000oinmk_nO_Nh00_nO_Nh00ol0003oZ/;/oj[2k002oj[2k003o`000?ncanWo/lOY00?o/lOY
00?o0000ok[:i_njb^H01Ol00002okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go0000ol;Ej?o2eNSo
`]GXo`000009ooooo`Co00005_ooool00ol0003oooooooooo`0:ooooo`006oooool2o`0003Wooooo
00?o0000okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/
00Go0000okG>kOnec^go]Lk]o`000004ojo:kPCo000000?oYlC^o`000?nO_Nh00onO_Nh01Ol0003o
UkG/oiNek?nG]Nco000000CoSjg[00?o0000ohZWj?n:YnP00_n:YnP00ol0003oQZ;VohJRiP02ohJR
iP;oQYoT0ol000000onDYN7o0000oiJTg`03oiJTg`03o`000?nJY]koVZKN00CoVZKN00?o0000oinX
gOnOZ=d00_nOZ=d2o`0000Co[[;K00?o0000ok>ff_nc]]X00_nc]]X00ol0003o^KWJokVifP03okVi
fP;o00000oo1`]X00ol0003oaLCIolG4f@02olG4f@;o00000oo8b=T2o`0000?oblWI00Co0000ol[:
fOo:b]Wo00000_o9b]X01?l0003obLWJolW9f_l00002olS8fP03o`000?o2a]go`/KM00?o`/KM0ol0
0002ok_0g@05o`000?nb^n3o/[_Pok:kh?l000001?nX]N801Ol0003oWZoToij_i?nN[nCo000000Co
TjWU00?o0000ohZSiOn:XnD00_n:XnD01?l0003oPioVoh>Oi_n3WnH4ogjMiPKo00001?meY>l01Ol0
003oO:W`ogbYl?mlZO3o000000?oQjo`00?o0000oi>fkonC]^l00_nC]^l00ol0003oWkg^oinmkP02
oinmkP03o`000?nZ`^coZ/;/00?oZ/;/00?o0000ok?7jOncanT00_ncanT00ol0003o^/[Vo`000003
o`0000Co_M?Z00?o0000ol7EjOo1eNT00_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000000Kooooo0ol0
000Jooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000
okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`03o`000?njdNco^]7/00;o^]7/00Go0000
okG>kOnec^go]Lk]o`000002ojo:kP?o00001?nWa>h00ol0003oWkg^oinmkP02oinmkP05o`000?nG
]NcoUkG/oiNek?l000001?n?[N/00ol0003oRZOXohZWj002ohZWj003o`000?n6X^KoQZ;V00;oQZ;V
1On6Wn@2o`0000CoUZCO00?o0000oiZVg_nJY]h00onJY]h00ol0003oWjSMoinXg@03oinXg@06o`00
0?nU[=co0000o`000?n^/]_o00001?nc]]X00ol0003o^KWJokVifP03okVifP06o`000?nn_MWo_[gI
o`000?o1`][o00001?o5a=T02?l0003oalKHolO6f?l0003ob<SIo`000?o:b=So00000oo;bMT00ol0
003ob/[Io`000004o`000007olW9f_l0003ob<SJolS8f_o7am[o0000ol;6g@03o`000003ol;4fol0
003o^l3M00?o^l3M00?o0000ok:kh?nb^n000_nb^n001Ol0003oZ;GRojReh_nX]N;o000000CoWZoT
00?o0000oi>YiOnCZND00_nCZND01Ol0003oRZ?UohZSiOn:XnGo000000?oPioV00?o0000ogjMi_mn
WNH00_mnWNH4ogfNi`Ko00001?mlZO001Ol0003oQjo`ohN_l?n7[o3o000000CoTkK_00?o0000oinm
k_nO_Nh00_nO_Nh00ol0003oZ/;/oj[2k002oj[2k004o`000?ncanWo/lOYok?7j@?o00000_nhd>/2
o`0000Co_M?Z00?o0000ol7EjOo1eNT00_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000000?ooooo0ol0
000Mooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000
okkCj_nndnX00_nndnX00ol0003o_=?[okcCj`02okcCj`05o`000?njdNco^]7/ok[Ak?l000001?ne
c^d3o`0000;o[l[^00Go0000ojO4k_nWa>koYlC^o`000004oinmkP03o`000?nG]NcoUkG/00;oUkG/
00?o0000ohn]jon?[N/00_n?[N/00ol0003oRZOXohZWj002ohZWj003o`000?n6X^KoQZ;V00;oQZ;V
00?o0000ohJOi?n6Wn@00_n6Wn@2ohROh`04o`000?nFY=ooUZCOo`0000KoVZKN00?o0000oinXgOnO
Z=d00_nOZ=d00ol0003oYJcLojF/g002ojF/g0;o00001?nc]]X00ol0003o^KWJokVifP02okVifP03
o`000?nn_MWo_[gI00;o_[gI0ol00002olG4f@03o`000?o7a]SoalKH00;oalKH00Ko0000ol[8f?o:
b=Sob/SHo`000?o;bMT2o`000009olc9eol0003oblWGol_9eol0003oblWHo`000?o8b=[o000000?o
alOJ00?o0000ol;4foo2a=/00_o2a=/00ol0003o^l3Mok_0g@02ok_0g@03o`000?nb^n3o/[_P00;o
/[_P00Go0000ojReh_nX]N;oZ;GRo`000004oij_i003o`000?nCZNGoTjWU00;oTjWU00Go0000ohZS
iOn:XnGoRZ?Uo`000003oh>OiP03o`000?mnWNKoOYgV00;oOYgV00?o0000ogfNiommW^L00_mmW^L4
ognQj0Ko00000on7[o000ol0003oTkK_oi>fk`02oi>fk`03o`000?nO_NkoWkg^00;oWkg^00Co0000
oj[2k?nZ`^coZ/;/1Ol00002ok7;k@05o`000?nhd>_o^=3[okS@jol000001?nmdnX00ol0003o`MGY
ol7Ej@02ol7Ej@04o`000?o2eNSo`]GXol;Ej0Co00008?ooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0hooooo`03o`000?nndn[o_]?Z00;o_]?Z00Go0000okcCjonldn_o
_=?[o`000004ok[Ak003o`000?nec^go000000?o00001?n_b^h01Ol0003oYlC^ojO4k_nWa>ko0000
00CoWkg^00?o0000oiNek?nG]N`00_nG]N`00ol0003oSjg[ohn]j`02ohn]j`03o`000?n:YnSoRZOX
00;oRZOX00?o0000ohJRi_n6X^H00_n6X^H00ol0003oQYoTohJOi002ohJOi0?oR9oS00?o0000oiJT
gol000001OnJY]h00ol0003oWjSMoinXg@02oinXg@03o`000?nU[=coYJcL00?oYJcL00Ko0000ojba
fol0003o0000ok>ff_l00004okVifP03o`000?nn_MWo_[gI00;o_[gI00Co0000ol;1f?o2`MSo`/7H
0ol00003olO6f0;o00000oo:b=P2o`000004olc9eol0003oc<WGo`0000;oblWG00CoblWHo`000?o;
b=So00000_o7amX00ol0003oalKIo`000004ol;4f`03o`000?nk`=go^l3M00oo000000?oWZoTo`00
0?nCZND00onCZND01Ol0003oRZ?UohZSiOn:XnGo000000?oPioV00?o0000ogjMi_mnWNH00_mnWNH0
0ol0003oOIkWogfNi`02ogfNi`03o`000?moXNSoOj7X00;oOj7X1?n4Y^XBo`0000;oZLC]00?o0000
ok7;kOnabnd00_nabnd01?l0003o^=3[okS@jonhd>/2o`0000?o_M?Z00?o0000ol7EjOo1eNT00_o1
eNT01Ol0003o`]GXol;Ej?o2eNSo000002?ooooo00?o0000ooooooooool02_ooool001[ooooo0ol0
000iooooo`05o`000?nndn[o_]?ZokkCj_l000001?nldn/00ol0003o^]7/ok[Ak002ok[Ak0;o0000
00?o]Lk]o`000?l000004_l000000onG]Nco0000ohn]j`02ohn]j`03o`000?n:YnSoRZOX00?oRZOX
00?o0000ohJRi_n6X^H00_n6X^H01Ol0003oQYoTohJOi?n6WnCo000000CoR9oS0_l00005oiZVgP05
o`000?nOZ=goWjSMoinXgOl000001OnU[=`00ol0003o[;7Kojbaf`02ojbaf`?o00000_ni^MX00ol0
003o_[gIokjmf@02okjmf@03o`000?o2`MSo`/7H00;o`/7H00Ko0000olK4f?o6a=So0000olO6f?l0
0002ol[7e`06o`000?o:b=So0000olc8eol0003oc<WG0_l00002ol_9e`03ol_9f?l0003oblSH00;o
blSG00?o0000olO6fOo7a]T00_o7a]T00ol0003o`/CKo`000004o`0000;o_KkK00?o0000okFig?ne
^M`00_ne^M`01Ol0003o[K?MojfcgOn]/mgo000000?oYJkN2?l00002ohZSi@03o`000?n3WnKoPioV
00;oPioV00Go0000ogjMi_mnWNKoOYgVo`000004ogfNi`03o`000?moXNSoOj7X00;oOj7X00?o0000
ohBVj_n4Y^X00_n4Y^X4ohb]k0GoUKC]1OnO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo
/L_]00;o/L_]00Oo0000okS@jonhd>_o^=3[o`000?nmdn[o000000;o_M?Z00?o0000ol7EjOo1eNT0
0_o1eNT01Ol0003o`]GXol;Ej?o2eNSo000002Cooooo00?o0000ooooooooool02Oooool001[ooooo
00?o0000ooooooooool0>Oooool01Ol0003o_]?ZokkCj_nndn[o000000Co_=?[00?o0000ok[Ak?l0
00001Ol00002okW;j0Go//SZ1?nY`n`5oinmkPCoTkG^1?l000000on?[N_o0000ohZWj003ohZWj003
o`000?n6X^KoQZ;V00;oQZ;V00?o0000ohJOi?n6Wn@00_n6Wn@00ol0003oR9oSohROh`02ohROh`;o
S:7R0ol000000onJY]ko0000oinXg@03oinXg@03o`000?nU[=coYJcL00?oYJcL00?o0000ojbafon/
/M/00_n//M/00ol0003o/kKKok>ff`04o`0000;o_[gI00?o0000ol;1f?o2`MP00_o2`MP00ol0003o
a/CHolK4f002olK4f0;o00000oo:amL01?l0003oc<SGolc8eoo<b=L3o`000004ol_9eoo;bMSo0000
o`0000?oblSG00Go0000olO6fOo7a]Wo0000olO6f@02o`0000;o`l;I00?o0000okfnfonm_]/00_nm
_]/01Ol0003o]KWLokFig?ne^Mco000000Co[K?M00?o0000ojF^g_nU[]h00_nU[]h00ol0003oWJSN
oifXgP02oifXgP05o`000?nFY=ko0000ohZSiOl000001?n3WnH00ol0003oOYgVogjMiP02ogjMiP05
o`000?mmW^OoOIkWogfNiol000001?moXNP00ol0003oQ:KZohBVjP02ohBVjP05o`000?n<[NcoS:g/
ohb]k?l000001?nE]>d00ol0003oWkg^oinmkP02oinmkP03o`000?nYa>goZLC]00;oZLC]00?o0000
ok7;kOnabnd00_nabnd01ol0003o^=3[okS@jonhd>_o0000okgCj_l000000_nmdnX00ol0003o`MGY
ol7Ej@02ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?ooool00ol0003oooooooooo`09ooooo`00
00Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo03Wooooo00Go0000okkCj_nndn[o_]?Zo`000002okcCj`Go00000_nncNH6
okW;j0Co//SZ00?o0000ojW3k?nY`n`00_nY`n`5oinmkPCoTkG^0on8[Nh5o`000003ohZWj?l0003o
QZ;V00?oQZ;V00?o0000ohJOi?n6Wn@00_n6Wn@00ol0003oR9oSohROh`02ohROh`GoS:7R0ol00002
oinXg@03o`000?nU[=coYJcL00?oYJcL00?o0000ojbafon//M/00_n//M/00ol0003o/kKKok>ff`02
ok>ff`03o`000?ni^][o^K[J00Co00000_o2`MP00ol0003oa/CHolK4f003olK4f008o`000?o9a]Oo
0000ol[7eol0003oc<SGo`000?o<b=L8o`0000?oblSG0ol00002olS5f005o`000?o3`]Wo`l;Iol?2
fOl000000onm_]/00ol0003o]KWLokFig002okFig003o`000?n]/mgo[K?M00;o[K?M00Go0000ojF^
g_nU[]koYJkNo`000005oifXgP04o`000?nFY=koUZCNoiJTgPCo000000?oPioVo`000?mnWNH00omn
WNH01Ol0003oOIkWogfNiommW^Oo000000CoOj7X00?o0000ohBVj_n4Y^X00_n4Y^X01Ol0003oS:g/
ohb]k?n<[Nco000000CoUKC]00?o0000oinmk_nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03
o`000?nabngo/L_]00;o/L_]00Go0000okS@jonhd>_o^=3[o`000002okgCjP03o`000?nmdn[o0000
00Co`MGY00Go0000ol;Ej?o2eNSo`]GXo`00000Tooooo`03o`000?oooooooooo00Wooooo00001?nH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03Wooooo00?o0000okkCj_l000001Ol000000oo1c^Go_/gVokk=iP04okk=iPGo^L_X00?o0000
ok;8j_nbb>X00_nbb>X01Ol0003oZL?/ojW3k?nY`nco000000CoWkg^00Go0000oi>ek_nC]NkoTkG^
o`000003ohR]kPCoOZK]0ol00003ohJRiP03o`000?n6WnCoQYoT00;oQYoT00?o0000ohROhon8Wn<0
0_n8Wn<00ol0003oS:7RohbQhP02ohbQhP?oTjCQ0ol00004ojF/g003o`000?n//M_o[;7K00?o[;7K
00Go0000ok>ffonc]]_o/kKKo`000004okVjfP03o`000?no_mWo_koI00Go00000_o6a=P01?l0003o
bLKGolW6eoo9a]L3o`000003olc8eol0003oc<SF00?o000000?oc<SFo`000?l000000_o;b=L00ol0
003oblOGo`000003olS5f003o`000?o3`]Wo`l;I00;o`l;I00Go0000okfnfonm_]_o_KkKo`000004
okFig005o`000?n]/mgo[K?MojfcgOl000001?nU[]h00ol0003oWJSNoifXgP02oifXgP03o`000?nF
Y=koUZCN00;oUZCN00Co0000oi2Pgon@X=ooT:3O0ol00003ogjMiP03o`000?mmW^OoOIkW00;oOIkW
00Go0000ognQj?moXNSoOj7Xo`000004ohBVjP05o`000?n<[NcoS:g/ohb]k?l000001?nE]>d00ol0
003oWkg^oinmkP02oinmkP03o`000?nYa>goZLC]00;oZLC]00?o0000ok7;kOnabnd00_nabnd01Ol0
003o^=3[okS@jonhd>_o000000?o_M?Z0_l00004ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?oo
ool00ol0003oooooooooo`09ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>Oooool5o`0000Go`LkU1OnncNH00ol0003o^L_XokW;j002
okW;j003o`000?nbb>[o//SZ00;o//SZ00Go0000ojW3k?nY`ncoZL?/o`000004oinmkP03o`000?nC
]NkoTkG^00;oTkG^00Co0000ohR]k_n8[Nko00001?mnY^d2ogRQk0Co00001?n6Wn@00ol0003oR9oS
ohROh`02ohROh`03o`000?n<XN;oS:7R00;oS:7R00Co0000oi>ThOnCY>7oTjCQ0_nKZN03o`000003
ojF/g?l0003o[;7K00?o[;7K00?o0000ok>ffonc]]/00_nc]]/01Ol0003o^K[JokVjf_ni^][o0000
00Co_koI00Co0000olC3f?o4`mSoa<?H1?l00002olW6e`03o`000?o;b=OoblSG00Wo00001?o;amLE
o`000003ojfcgOl0003oYJkN00?oYJkN00?o0000oifXg_nMZ=h00_nMZ=h00ol0003oUZCNoiJTgP02
oiJTgP03o`000?n@X=ooT:3O00;oT:3O00Ko0000ohbOh?l0003o0000ogjMi_l00004ogfNi`05o`00
0?moXNSoOj7XognQj?l000001?n4Y^X01Ol0003oS:g/ohb]k?n<[Nco000000CoUKC]00?o0000oinm
k_nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo/L_]00;o/L_]00Go0000okS@
jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go0000ol;Ej?o2eNSo`]GXo`00
000Tooooo`03o`000?oooooooooo00Wooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0hooooo`?o00000oo2c^@00ol0003o`LkUol7>i@02
ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?nibnP00onibnP01Ol0003o//SZok;8j_nb
b>[o000000CoZL?/00?o0000oinmk_nO_Nh00_nO_Nh01Ol0003oTkG^oi>ek_nC]Nko000000?oR:g^
00Go0000ogjVkOmnY^goOZK]o`000004ogRQk0?o000000?oQYoTo`000?n8Wn<00on8Wn<00ol0003o
S:7RohbQhP02ohbQhP03o`000?nCY>7oTjCQ00;oTjCQ00?o0000oi^Yh?nKZN000_nKZN04o`0000;o
[;7K00Go0000ok>ffonc]]_o/kKKo`000004okVjfP03o`000?no_mWo_koI00;o_koI00?o0000olC3
f?o4`mP00_o4`mP00ol0003ob<KGolS6e`0@o`0000;oblOG00Go0000olS5eoo8aMOob<GGo`000004
olC2f005o`000?no_]Wo_kkIoknnfOl000000oni^]T01?l0003o/kGJok>ef_nc]MX4o`000003ojF^
g_l0003oWJSN00CoWJSN00Go0000oiJTg_nFY=koUZCNo`000004oi2Pg`03o`000?n<Wn3oS9oP00?o
S9oP0_l00003ogfNi`05o`000?moXNSoOj7XognQj?l000001?n4Y^X00ol0003oS:g/ohb]k002ohb]
k005o`000?nE]>goUKC]oiFdkOl000001?nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo
/L_]00;o/L_]00Go0000okS@jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo`MGY00;o`MGY00Go
0000ol;Ej?o2eNSo`]GXo`00000Tooooo`03o`000?oooooooooo00Wooooo0003ooooo`03o`000?oo
oooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`?o0000=_ooool3o`0000;ooooo
00Go0000ol;>i?o2c^Co`/kTo`000004ol7>i@03o`000?nncNKo_/gV00?o_/gV00?o0000okW;j?ni
bnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l000001?nO_Nh01Ol0
003oTkG^oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01?l0003oN:7/ogRQk?mh
XN`3ogFMjP?o00000on8Wn<00ol0003oS:7RohbQhP02ohbQhP03o`000?nCY>7oTjCQ00;oTjCQ00?o
0000oi^Yh?nKZN000_nKZN04ojB^g`Co00000_nc]]/00ol0003o^K[JokVjfP02okVjfP05o`000?no
_mWo_koIoknofOl000001?o4`mP00ol0003ob<KGolS6e`02olS6e`ko00000_o;amL01Ol0003ob<GG
olS5eoo8aMOo000000Coa<;H00Go0000oknnfOno_]Wo_kkIo`000003okVjf@03o`000?nc]M[o/kGJ
00?o/kGJ00?o0000ojf`f_n]/=X00ol00004oifXgP05o`000?nFY=koUZCNoiJTg_l000001?n@X=l0
0ol0003oS9oPohbOh003ohbOh006o`000?n;Wn;o0000o`000?mmW^Oo00000omoXNP00ol0003oQ:KZ
ohBVjP02ohBVjP03o`000?n<[NcoS:g/00;oS:g/00?o0000oiFdkOnE]>d00_nE]>d01Ol0003oWkg^
oinmk_nO_Nko000000CoZLC]00?o0000ok7;kOnabnd00_nabnd01Ol0003o^=3[okS@jonhd>_o0000
00Co_M?Z0_l00003ol7Ej@05o`000?o2eNSo`]GXol;Ej?l000009?ooool00ol0003oooooooooo`09
ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0<oooool3o`0000Gooooo00Go0000ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo
_/gV00;o_/gV00?o0000okW;j?nibnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`nco
ZL?/ojW3k?l000001?nO_Nh00ol0003oTkG^oi>ekP02oi>ekP04o`000?n8[NkoR:g^o`0000CoOZK]
00Go0000ogRQk?mhXNcoN:7/o`000003ogFMjP;oMigY1?l00004ohbQhP03o`000?nCY>7oTjCQ00;o
TjCQ00?o0000oi^Yh?nKZN000_nKZN000ol0003oY:kOojB^g`02ojB^g`03o`000?n]]=ko[KCN00Go
000000?o^K[Jo`000?no_mT00ono_mT00ol0003oa<?Ho`000008o`000003ol_7eol0003o000000Ko
000000?oc<SFo`000?o;b=L00_o;b=L8o`0000;oa<;H00Co0000oknnfOno_]Wo00001?ni^]T00ol0
003o/kGJok>efP02ok>efP03o`000?n]/=[o[K3J00;o[K3J00Ko0000ojJ[fol0003o0000oifXg_l0
0004oiJTgP03o`000?n@X=ooT:3O00;oT:3O00?o0000ohbOh?n<Wn000_n<Wn000ol0003oRioRoh^O
hP03oh^OhP?o000000?oOj7Xo`000?n4Y^X00on4Y^X00ol0003oS:g/ohb]k002ohb]k003o`000?nE
]>goUKC]00;oUKC]00Go0000oinmk_nO_NkoWkg^o`000004ojW4k@03o`000?nabngo/L_]00;o/L_]
00Go0000okS@jonhd>_o^=3[o`000004okgCjP03o`000?o1eNWo000000;o`MGY00?o0000ol;Ej?o2
eNP00_l0000Uooooo`03o`000?oooooooooo00Sooooo00001?nHV9SooooooiRHV?mgMgL<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<?ooool3o`0000Sooooo00?o0000ol;>i?o2
c^@00_o2c^@00ol0003o`LkUol7>i@02ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?ni
bnP00onibnP01Ol0003o//SZok;8j_nbb>[o000000CoZL?/00?o0000oinmk_nO_Nh00_nO_Nh01Ol0
003oTkG^oi>ek_nC]Nko000000?oR:g^00Go0000ogjVkOmnY^goOZK]o`000004ogRQk004o`000?me
WN[oMIgZo`0000CoMigY0_l00003ohbQhP05o`000?nCY>7oTjCQoi>ThOl000001OnKZN000ol0003o
Y:kOojB^g`02ojB^g`05o`000?n]]=ko[KCNojfdg_l000000one^]d8o`0000;o`l?J00?o0000olS6
f?o8a]P00_o8a]P5o`000003olc8e_l0003o000000Co00000_o<b=L2ol_8e`05o`000?o9a]OobLKG
olW6eol000000oo6a=P4o`000003oknnfOl0003o^K[I00;o^K[I00?o0000ok>ef_nc]MX00onc]MX0
1Ol0003o[K3Jojf`f_n]/=[o000000GoYZ_K0_l00003oiJTgP05o`000?n@X=ooT:3Ooi2Pgol00000
1On<Wn000ol0003oRioRoh^OhP03oh^OhP03o`000?n;X^?oRj;S00Go000000?oQ:KZo`000?n<[N`0
0on<[N`00ol0003oUKC]oiFdk@02oiFdk@05o`000?nO_NkoWkg^oinmk_l000001?nYa>d00ol0003o
/L_]ok7;k@02ok7;k@05o`000?nhd>_o^=3[okS@jol000001?nmdnX01Ol0003o`MGYol7EjOl0003o
`MGY00?o000000?o_=W^o`000?ooool09?ooool00ol0003oooooooooo`08ooooo`0000Co<S8bo`00
0?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0;Oooool3o`0000cooooo00Go0000
ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o0000okW;j?nibnP00_ni
bnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l000001?nO_Nh01Ol0003oTkG^
oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01Ol0003oN:7/ogRQk?mhXNco0000
00?oMIgZ00Co0000ogNMjOmgWNWoMigY0_mlWnT3o`0000CoTjCQ00?o0000oi^Yh?nKZN000_nKZN00
0ol0003oY:kOojB^g`03ojB^g`05o`000?n]]=ko[KCNojfdg_l000001?ne^]d00ol0003o_KkKokfn
f`02okfnf`05o`000?o3`m[o`l?Jol?3f_l000000_o8a]P2o`0000;oblSG00?o0000ol_8eoo;b=L0
1ol00003olc8e`?o000000?obLKGo`000?o6a=P00oo6a=P01?l0003o`/3Hol;0f?o2`=P3o`0000;o
^K[I00?o0000ok>ef_nc]MX00_nc]MX00ol0003o[K3Jojf`fP02ojf`fP03o`000?nVZm_oYZ_K00?o
YZ_K00?o0000oj6Wfol000000_l00004oi2Pg`03o`000?n<Wn3oS9oP00?oS9oP00?o0000oh^Oh_n;
Wn800_n;Wn800ol0003oRj;Soh^Rh`02oh^Rh`04o`000?n>Y^KoSZKVohjViPGo000000?oS:g/o`00
0?nE]>d00onE]>d01Ol0003oWkg^oinmk_nO_Nko000000CoZLC]00?o0000ok7;kOnabnd00_nabnd0
1Ol0003o^=3[okS@jonhd>_o000000Co_M?Z00?o0000ol7EjOo1eNT00ol00002okcIkP03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool0:_ooool3
o`0000oooooo00Go0000ol;>i?o2c^Co`/kTo`000005ol7>i@03o`000?nncNKo_/gV00;o_/gV00?o
0000okW;j?nibnP00_nibnP00ol0003o//SZok;8jP02ok;8jP05o`000?nY`ncoZL?/ojW3k?l00000
1?nO_Nh01Ol0003oTkG^oi>ek_nC]Nko000000?oR:g^00?o0000ogjVkOmnY^d00_mnY^d01Ol0003o
N:7/ogRQk?mhXNco000000?oMIgZ00Go0000ogNMjOmgWNWoMigYo`000003ogbOj@Co000000?oTjCQ
o`000?nKZN000onKZN000ol0003oY:kOojB^g`02ojB^g`03o`000?n]]=ko[KCN00;o[KCN00?o0000
okFjgOne^]d00_ne^]d00ol0003o_KkKokfnf`02okfnf`04o`000?o3`m[o`l?Jol?3fP?o000000Co
alKIo`000?o;b=Oo00000_o;b=L00oo;b=So0000o`000004o`000004olc8eol0003oc<SGo`0000?o
b/OG0_l00003olK4f003o`000?o2`=So`/3H00;o`/3H00?o0000okfmfOnm_MT00ol00003ok>efP03
o`000?n]/=[o[K3J00;o[K3J00?o0000ojJ[fonVZm/00onVZm/00ol0003oXJOKoj6Wf`02oj6Wf`;o
00000on@X=l00ol0003oS9oPohbOh002ohbOh003o`000?n;Wn;oRioR00?oRioR00?o0000oh^Rhon;
X^<00_n;X^<00ol0003oSZKVohjViP02ohjViP04o`000?nB[NSoTZgXoi:]j0Go000000?oUKC]o`00
0?nO_Nh00_nO_Nh00ol0003oZLC]ojW4k@02ojW4k@03o`000?nabngo/L_]00;o/L_]00?o0000okS@
jol000002Ol000000onkfNoo0000o`000002okcIkP03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02?ooool001Wooooo0_l0000Xooooo`?o00004_ooool00ol0003o`/kTol;>i002ol;>i003
o`000?o1c^Go`LkU00;o`LkU00?o0000okk=i_nncNH00_nncNH00ol0003o^L_XokW;j003okW;j005
o`000?nbb>[o//SZok;8j_l000001?nY`n`00ol0003oWkg^oinmkP02oinmkP05o`000?nC]NkoTkG^
oi>ek_l000000on8[Nh01Ol0003oOZK]ogjVkOmnY^go000000?oN:7/00Go0000ogFMj_meWN[oMIgZ
o`000004ogNMj@03o`000?mlWnWoO9oY00CoQJCX1Ol000000onKZN3o0000ojB^g`03ojB^g`05o`00
0?n]]=ko[KCNojfdg_l000001?ne^]d00ol0003o_KkKokfnf`02okfnf`03o`000?o3`m[o`l?J00?o
00000oo7a]T3o`0000;oblSH00Oo0000ol_9f?l0003o0000olc9eol0003oc<WG00?o00000oo:amL0
1_l0003oalKHolO6f?l0003oa/CHo`0000Co`/3H00?o0000okfmfOnm_MT00_nm_MT01_l0003o^KWI
o`000?l0003o/kGJo`0000?o[K3J00?o0000ojJ[fonVZm/00onVZm/00ol0003oXJOKoj6Wf`03oj6W
f`03o`000?nLYMco000000;o00001On<Wn000ol0003oRioRoh^OhP02oh^OhP03o`000?n;X^?oRj;S
00;oRj;S00?o0000ohjVi_n>Y^H00_n>Y^H00ol0003oTZgXoi:]j003oi:]j004o`000?nH]>_oV;C[
oiRdja7o00000_ncd_000ol0003o^=O`okSGl002okSGl004o`000?nkfNoo^mW_ok_Ik`;o000000?o
_=W^o`000?ooool09_ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0T
ooooo`?o00005_ooool01Ol0003o`/kTol;>i?o2c^Co000000Go`LkU00?o0000okk=i_nncNH00_nn
cNH00ol0003o^L_XokW;j002okW;j003o`000?nbb>[o//SZ00;o//SZ00?o0000ojW3k?l000004_l0
00001OmnY^go0000ogRQk?mhXNco000000?oMIgZ00?o0000ogNMjOmgWNT00_mgWNT01?l0003oO9oY
ogbOjOl00004ohFTj0CoT:WW1Ol000000onT[]oo0000ojfdgP02ojfdgP03o`000?ne^]go]K[M00[o
00000_o2a=/4o`000009olO7f_l0003o0000ol_8f?l0003oblWHo`000?o;bMOo000000;oc<WG0_l0
0002ol[8f003o`000?o:amOo000000CoalKH0_l00003ol;0f003o`000?nm_MWo_KgI00;o_KgI00?o
0000okVifOni^MT00_ni^MT3o`0000;o[K3J00?o0000ojJ[fonVZm/00_nVZm/00ol0003oXJOKoj6W
f`03oj6Wf`03o`000?nLYMcoW:GL00;oW:GL0_l00004ohbOh003o`000?n;Wn;oRioR00;oRioR00?o
0000oh^Rhon;X^<00_n;X^<00ol0003oSZKVohjViP02ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o
0000oiRdjonH]>/00onH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?00
0_n]c?001?l0003o/m;`ok?Bl?l00004okSGl003o`000?nkfNoo^mW_00;o^mW_00Co0000okcIk_l0
003o00009oooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`0Rooooo`?o
00006Oooool00ol0003o`/kTol;>i002ol;>i003o`000?o1c^Go`LkU00;o`LkU00?o0000okk=i_nn
cNH00_nncNH00ol0003o^L_XokW;j002okW;j003o`000?nbb>[o//SZ00Co00000_n[`NX00ol0003o
Wkg^oinmkP02oinmkP05o`000?nA]o7oTKOaoi6glOl000000on2/?801?l0003oM:SbogBXl_mdZ?84
o`000005ogRQk?l0003oMIgZogFMj_l000001?mgWNT01Ol0003oO9oYogbOjOmlWnWo000000?oQJCX
00?o0000oi2Yion@ZNL00_n@ZNL01?l0003oW;3Voib`i_nL/>H8o`0000;o/[cQ00?o0000ok_0g_nk
`=h00_nk`=h01?l0003o`/CKol;4foo2a=/2o`0000?oalOJ00?o0000olS8f_o8b=X00_l000001?o;
bMSo0000o`000?o<bML2o`000004ol_9fOl0003ob/SHol[8f0?o00000oo7a]P00ol0003oaLCIolG4
f@02o`000003ol;0f?l0003o_KgI00;o_KgI00?o0000okVifOni^MT00_ni^MT01?l0003o];GJokBe
f_nd]MX3o`0000CoYZ_K00?o0000oj6WfonQYm/00_nQYm/00ol0003oW:GLoibUg003oibUg003o`00
0?nIY=go000000?o00001On;Wn800ol0003oRj;Soh^Rh`02oh^Rh`03o`000?n>Y^KoSZKV00;oSZKV
00?o0000oi:]j?nB[NP00_nB[NP00ol0003oV;C[oiRdj`02oiRdj`05o`000?nO_NgoWkg]oinmkOl0
00001?nVaNl00ol0003o[Lc`ojg<l002ojg<l005o`000?ncd_3o/m;`ok?Bl?l000001?nheo001Ol0
003o^mW_ok_IkonkfNoo000000;o_=W^00?o0000ooooooooool09_ooool00ol0003oooooooooo`08
ooooo`006?ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool00ol0003o`/kTol;>i002ol;>
i003o`000?o1c^Go`LkU00?o`LkU00Go0000okk=i_nncNKo_/gVo`000003okW;j0Co00000_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6glOnA]o7oTKOao`00
0003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo84o`000003ogFMj_l0003oMigY00;oMigY
00Go0000ogbOjOmlWnWoO9oYo`000004ohFTj005o`000?n@ZNOoT:WWoi2Yiol000001?nL/>H01Ol0
003oYkKTojNfi?nW]^Co000000Co/[cQ00?o0000ok_0g_nk`=h00_nk`=h4o`000005ol;6gOl0003o
alOJolO7f_l000000oo8b=X00ol0003obLWJo`000002o`000003ol[:fOl0003oblWI00;oblWI0_l0
0003olS8f@03o`000?o7a]So000000CoaLCI1?l000000onm_MWo0000okVif@03okVif@03o`000?nd
]M[o];GJ00;o];GJ00?o0000ojnaf_n_/MX00_l000000onVZm_o0000oj6Wf`03oj6Wf`03o`000?nL
YMcoW:GL00?oW:GL00?o0000oiVTgOnIY=d00onIY=d2o`0000?oRioR00?o0000oh^Rhon;X^<00_n;
X^<00ol0003oSZKVohjViP02ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o0000oiRdjonH]>/00onH
]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001?l0003o/m;`
ok?Bl?l00004okSGl003o`000?nkfNoo^mW_00;o^mW_00?o0000okcIk_nlfNh00_l0000Xooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Oooooo`05o`00
0?o2c^Co`/kTol;>i?l000001Oo1c^D01?l0003o_/gVokk=i_nncNH4o`0000;o^/KS00?o0000okC4
ionda>L00_nda>L00ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6g
lOnA]o7oTKOao`000003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo800ol0003oI9oaofBO
l@05o`000005ogNMjOl0003oO9oYogbOjOl000001?n5Y>P01Ol0003oT:WWoi2Yion@ZNOo000000Co
W;3V00Go0000ojNfi?nW]^CoYkKTo`000005ok:lh@03o`000?nk`=ko^l3N00;o00001Oo2a]d2o`00
00?ob<SJ00So0000olW9f_o9bM[o0000olW:f_l0003ob/[Io`0000;oblWI0_l00004olS8f@;o0000
1?o5a=T01?l0003o`L;Jol72f_o1`]X3o`0000?o^KWI00?o0000okBef_nd]MX00_nd]MX00ol0003o
[k7JojnafP03ojnafP;o00001?nQYm/00ol0003oW:GLoibUg002oibUg003o`000?nIY=goVJCM00Co
VJCM00Ko0000oiNTg_l0003o0000oh^Oh_l00004oh^Rh`03o`000?n>Y^KoSZKV00;oSZKV00?o0000
oi:]j?nB[NP00_nB[NP00ol0003oV;C[oiRdj`02oiRdj`03o`000?nO_NgoWkg]00;oWkg]00Go0000
ojK5konVaNooY/G_o`000004ojg<l005o`000?ncd_3o/m;`ok?Bl?l000001?nheo001Ol0003o^mW_
ok_IkonkfNoo000000;o_=W^00Co0000oooooooooooo00009oooool00ol0003oooooooooo`07oooo
o`006?ooool2o`0001_ooooo0ol0000Rooooo`03o`000?o2c^Co`/kT00;o`/kT00?o0000ol7>iOo1
c^D00_o1c^D01_l0003o_/gVo`000?l0003o_lOQo`0000Go^/KS00?o0000okC4ionda>L00_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP03o`000?nO_NkoWkg^00;oWkg^00Go0000oi6glOnA]o7oTKOao`00
0003oh:`lP05o`000?mdZ?;oM:SbogBXl_l000000_mZXo801?l0003oI9oaofBOlOl00003ofFOl@Co
000000?oO9oYo`000?n5Y>P00_n5Y>P00ol0003oT:WWoi2Yi`02oi2Yi`03o`000?nL/>KoW;3V00;o
W;3V00Go0000ojNfi?nW]^CoYkKTo`000004ok:lh@?o000000?o^lCQo`000?o2a]d01?o2a]d3o`00
0005olS8f_l0003obLWJolW9f_l000000_o9b]X00ol0003ob/[Io`000002o`000004olW:fol0003o
b<SIolS8f@;o000000?oa/SKo`000?o5a=T00_o5a=T01Ol0003o`L;Jol72f_o1`][o000000?o_KoK
00?o0000okVifOl000001?nd]MX00ol0003o[k7JojnafP03ojnafP03o`000?nZ[m_oZZoK00;o0000
00?oXJOKo`000?nLYM`00onLYM`00ol0003oVJCMoiVTg@04oiVTg@03o`000?nGY=koUjCN00;oUjCN
0_l00004oh^Rh`05o`000?n>Y^KoSZKVohjVi_l000001?nB[NP00ol0003oV;C[oiRdj`03oiRdj`05
o`000?nO_NgoWkg]oinmkOl000001?nVaNl00ol0003o[Lc`ojg<l002ojg<l005o`000?ncd_3o/m;`
ok?Bl?l000000onheo000ol0003o^mW_ok_Ik`02ok_Ik`04o`000?nlfNko_=W^o`0000;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0G
ooooo`?o00009Oooool00ol0003o`/kTol;>i002ol;>i003o`000?o1c^Go`LkU00;o`LkU0_l00004
oko7h@03o`000?nja^?o^/KS00?o^/KS00?o0000okC4ionda>L00_nda>L00ol0003oZl7Zoj_1jP02
oj_1jP05o`000?nO_NkoWkg^oinmk_l000001?nA]o401Ol0003oP[3boh:`l_n2/?;o000000?oM:Sb
00Co0000ofZSl_mZXo;o00000_mTWo401Ol0003oIIoaofFOlOmUWo7o000000;oK:;a1Ol000000on5
Y>So0000oi2Yi`02oi2Yi`03o`000?nL/>KoW;3V00;oW;3V00Go0000ojNfi?nW]^CoYkKTo`000002
ok:lh@?o00001?nka>401?l0003o`/KMo`000?l00004ol?8gP;o000000KobLWJo`000?o9b][obL[J
o`000?o:b]T2o`0000CobL[K0_l00004olK8f`03o`000?o5a=Wo000000?o`L;J00?o0000okfofonm
_m/00_nm_m/3o`0000?o];GJ00?o0000ojnaf_n_/MX00on_/MX00ol0003oZZoKojZ_f`02ojZ_f`?o
00001?nLYM`00ol0003oVJCMoiVTg@03oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o0000oiJVhOl0
00000ol00004ohjViP03o`000?nB[NSoTZgX00;oTZgX00?o0000oiRdjonH]>/00_nH]>/00ol0003o
Wkg]oinmk@02oinmk@05o`000?nVaNooY/G_ojK5kol000001?n]c?001Ol0003o/m;`ok?Bl?ncd_3o
000000Co^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP05o`000?ooooooooooooooool00000
9_ooool00ol0003oooooooooo`07ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o0000:Ooo
ool01_l0003o`/kTol;>i?o2c^Co0000ol7>i@?o000000?o`/SOo`000?noan401?noan400ol0003o
^/KSok[6h`03ok[6h`03o`000?nda>Oo]<CW00;o]<CW00?o0000oj_1j_n[`NX00_n[`NX01Ol0003o
Wkg^oinmk_nO_Nko000000?oTKOa00Go0000oh:`l_n2/?;oP[3bo`000004ogBXlP04o`000?mZXo;o
JZ?bo`0000;oI9oa00Go0000ofFOlOmUWo7oIIoao`000002ofbRl@04o`000?mhZ?7oN:SaogRXlA7o
00000_na`>H00ol0003o^lCQok_4h@03ok_4h@03o`000?o3b=ko`lSN00;o`lSN00Co0000olG;goo5
bmooaL_O1_l000000oo8c=go0000olW:f`02olW:f`;o00001Oo6b=/2o`0000?o`L;J00?o0000okfo
fonm_m/00_nm_m/01ol0003o^KgLokVmg?ni_Mco0000okBef_l000001On_/MX00ol0003oZZoKojZ_
f`02ojZ_f`04o`000?nV[McoYZgLojJ]g0;o000000?oW:GLo`000?nIY=d01?nIY=d00ol0003oUjCN
oiNTgP03oiNTgP03o`000?nFY^7oUZKQ00?oUZKQ0ol00002ohjViP03o`000?nB[NSoTZgX00;oTZgX
00?o0000oiRdjonH]>/00_nH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]
c?000_n]c?001Ol0003o/m;`ok?Bl?ncd_3o000000?o^=O`00Go0000ok_IkonkfNoo^mW_o`000003
okcIkP03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`005oooool00ol0003oooooooooo`0Booooo`?o0000;?ooool01?l0003o`/kTol;>i?o2c^@2
o`0000Go`/SO00?o0000oko7hOnoan400onoan400ol0003o^/KSok[6h`02ok[6h`03o`000?nda>Oo
]<CW00?o]<CW00Go0000oj_1j_n[`N[oZl7Zo`000004oinmkP05o`000?nA]o7oTKOaoi6glOl00000
0on2/?801Ol0003oM:SbogBXl_mdZ?;o000000?oJZ?b00Co0000ofBOlOmTWo7o00000omUWo401?l0
003oK:;aofbRlOl00003ogRXl@05o`000?n6[o3oQZo`ohJ_l?l000001?nF]^h01Ol0003oY;cZojBl
j_nT_>[o000000Go/L3V00Co0000ok_4hOl0003o00000onlb><00ol0003o`lSNo`000004olG;g`05
o`000?o6c=koa/cNolK<g_l000000_o8c=d01_l0003obL[Ko`000?l0003oa/_No`0000?oa/SK0_l0
0002ol?7g@03o`000?o1`][o000000?o_KoK0_l00004okVmg0;o00001On_/MX00ol0003oZZoKojZ_
f`02ojZ_f`03o`000?nV[McoYZgL00?oYZgL0_l00005oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o
0000oiJVhOnFY^400onFY^401?l0003oUj[ToiNZi?nGZ^@3o`0000?oTZgX00?o0000oiRdjonH]>/0
0onH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001?l0003o
/m;`ok?Bl?l00004okSGl005o`000?nkfNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo00?o0000oooo
ooooool03oooool3o`0002oooooo00Ko0000ol;>i?l0003o0000ol;8g_l00006ol;8g`03o`000?no
an7o_lOQ00?o_lOQ00?o0000ok[6honja^<00_nja^<00ol0003o]<CWokC4i`02okC4i`03o`000?n[
`N[oZl7Z00;oZl7Z00Go0000oinmk_nO_NkoWkg^o`000004oi6gl@05o`000?n2/?;oP[3boh:`l_l0
00000omdZ?801?l0003oJZ?bofZSl_l00002ofBOl@05o`000?mUWo7oIIoaofFOlOl000000om/X_40
1Ol0003oN:SaogRXlOmhZ?7o000000?oQZo`00?o0000oiJfk_nF]^h00_nF]^h01Ol0003oY;cZojBl
j_nT_>[o000000Go/L3V00?o0000okc8honlb><01?nlb><00ol0003oaL_Oo`000002olG;g`06o`00
0?o6c=koa/cNolK<g_l0003ob<cM0ol00005olK;gP?o00001?o3amd2o`0000?o_KoK00?o0000okVm
g?ni_M`00oni_M`01?l0003o]K[MokFjgOl00003ojnafP03o`000?nZ[m_oZZoK00;oZZoK00?o0000
ojJ]g?nV[M`00onV[M`01?l0003oXjcMoj>/gOl00003oiVTg@03o`000?nGY=koUjCN00?oUjCN00?o
0000oiJVhOnFY^400onFY^400ol0003oUj[ToiNZi003oiNZi006o`000?nH[nOo0000o`000?nB[NSo
00001?nH]>/01Ol0003oWkg]oinmkOnO_Ngo000000CoY/G_00?o0000ojg<l?n]c?000_n]c?001Ol0
003o/m;`ok?Bl?ncd_3o000000?o^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2
o`0000gooooo0ol0000cooooo`03o`000?o2b=ko`/SN00;o`/SN00?o0000ol;8goo2b=l01?o2b=l0
0ol0003o_lOQoko7h@02oko7h@03o`000?nja^?o^/KS00?o^/KS00?o0000okC4ionda>L00_nda>L0
0ol0003oZl7Zoj_1jP02oj_1jP05o`000?nO_NkoWkg^oinmk_l000001?nA]o401Ol0003oP[3boh:`
l_n2/?;o000000?oM:Sb00Co0000ofZSl_mZXo;o00000_mTWo401Ol0003oIIoaofFOlOmUWo7o0000
00?oK:;a00Go0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00;oU[K^00Ko0000
ojBlj_nT_>[oY;cZo`000?na`>H2o`0000?o//KY00Go0000okc8honlb>?o_<SSo`000003okk<i0So
00000_o5c^400ol0003oa/_NolK;gP02olK;gP;o00001?o3amd2o`0000;o`<KO00?o0000okfofol0
00001Oni_M`00ol0003o]K[MokFjg@02okFjg@03o`000?n_/M[o000000CoZZoK00?o0000ojJ]g?nV
[M`00onV[M`00ol0003oXjcMoj>/g@02oj>/g@03o`000?nIY=go000000GoUjCN00?o0000oiJVhOnF
Y^400onFY^400ol0003oUj[ToiNZi003oiNZi003o`000?nH[nOoV:oW00;oV:oW1?l00002oiRdj`05
o`000?nO_NgoWkg]oinmkOl000001?nVaNl00ol0003o[Lc`ojg<l002ojg<l004o`000?ncd_3o/m;`
o`0000Co^=O`00Go0000ok_IkonkfNoo^mW_o`000003okcIkP03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`09
ooooo`?o0000=_ooool00ol0003o`/SNol;8gP03ol;8gP03o`000?o2b=oo`/SO00Co`/SO00?o0000
oko7hOnoan400_noan400ol0003o^/KSok[6h`03ok[6h`03o`000?nda>Oo]<CW00;o]<CW00?o0000
oj_1j_n[`NX00_n[`NX01Ol0003oWkg^oinmk_nO_Nko000000;oTKOa3_l00002ofBOl@04o`000?mU
Wo7oIIoao`0000?oK:;a00Go0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00;o
U[K^00?o0000ojBlj_nT_>X00ol00006ok;6j@03o`000?nlb>?o000000Go_/cT00Go0000ol;>hoo2
c^?o`/kSo`000004olG>h@03o`000?o6bmko000000;o000000?o`lcQo`000?o3amd00_o3amd00ol0
003o`<KOol36g`02ol36g`;o00001?ni_M`2o`0000Go]K[M0ol00003ojZ_f`03o`000?nV[McoYZgL
00;oYZgL0_l00005oj>/g@?o00001?nGY=h00ol0003oUZKQoiJVh@03oiJVh@03o`000?nGZ^CoUj[T
00?oUj[T00?o0000oiR_ionH[nL00_nH[nL00ol0003oVkKZoi^fjP02oi^fjPCo00000_nO_Nd01Ol0
003oY/G_ojK5konVaNoo000000Co[Lc`00Go0000ok?Bl?ncd_3o/m;`o`000003okSGl005o`000?nk
fNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003[ooooo00?o
0000ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ00?o
0000ok[6honja^<00onja^<00ol0003o]<CWokC4i`02okC4i`03o`000?n[`N[oZl7Z00;oZl7Z00?o
0000oinmk_nO_Nh00ol00004oi2jl`CoP;Cf1?m`[oL00omRZOOo0000o`000006o`0000?oK:;a00Go
0000ogRXlOmhZ?7oN:Sao`000003ohJ_l003o`000?nF]^koU[K^00Co00001?nUa>l00ol0003o//KY
ok;6j@03ok;6j@04o`000?nnc>Co0000o`0000;o_/cT00Go0000ol;>hoo2c^?o`/kSo`000002olG>
h@Go00001Oo3c>43o`0000?o`<KO0_l000000onla^;o0000okVmg002okVmg003o`000?ne^]go]K[M
00?o]K[M0_l00003ok6hgP03o`000?nZ[m_o000000CoYZgL00?o0000oj>/gOnS[=d01?nS[=d01?l0
003oX:cOoj2/gonP[=l2o`000003oiNTg_l0003oUZKQ00CoUZKQ00?o0000oiNZi?nGZ^@00onGZ^@0
0ol0003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00Co0000oinmkOnO_NgoWkg]1?l0
0002ojK5k`03o`000?n]c?3o[Lc`00;o[Lc`00Go0000ok?Bl?ncd_3o/m;`o`000003okSGl005o`00
0?nkfNoo^mW_ok_Ikol000000onlfNh00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool01_ooool001Oooooo00?o0000ooooooooool00oooool3o`0003kooooo
00?o0000ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ
00?o0000ok[6honja^<00_nja^<00ol0003o]<CWokC4i`03okC4i`03o`000?n[`N[oZl7Z00Co0000
0onO_Nh5oi2jl`05o`000?n0]?KoP;Cfoh2dm_l000000om`[oL3of:Ym`CoFZKg3ol00004oiFom003
o`000?nUa>ooYLC_00;oYLC_00Co0000ok;6jOl0003o00001Onfc>/9o`0000?o`M3V00?o0000ol?<
hOo3c>400_o3c>43o`0000?o`<KO0_l00004okc6hP03o`000?ni_Mco000000Co]K[M0_l00005ok6h
gP?o00000onV[M`00ol0003oXjcMoj>/g@03oj>/g@;o00001OnP[=l3o`0000CoUZKQ00?o0000oiNZ
i?nGZ^@00onGZ^@00ol0003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000oinm
kOnO_Nd00_nO_Nd01?l0003oY<C`ojC4l?nTa?0Go`0000cooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo00?o0000
ol;8g_o2b=h00oo2b=h00ol0003o`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00;o_lOQ00?o0000
ok[6honja^<00onja^<00ol0003o]<CWokC4i`02okC4i`?o00001?nZ_nT4oinmkP03o`000?n@^_?o
T;[c00;oT;[c0_l00002oh2dmP05o`000?m`[oOoL:ogog2_mol000000_mRZOL01?l0003oFZKgoeZV
mol00002oeZVm`CoHZ_h1?m`/OT4oh:in003o`000?nE_oCoUKod00;oUKod00?o0000ojG4konUa>l0
0_nUa>l00ol0003o]/c[okK<j`05okK<j`03o`000?nkd>Wo^m3Y00?o^m3Y00?o0000ol7@i_o1d>H0
0oo1d>H00ol0003o`lcQo`000002o`0000;o_lgU00Co0000ol36gol0003o00001_nla^82o`0000Co
]K[M00?o0000ok6hg_na^=h00ona^=h2o`0000?o[KOP00?o0000ojJ]g?l000001OnS[=d00ol0003o
X:cOoj2/g`04oj2/g`04o`000?nN[N7oWZgQoij]h@;o000000?oUZKQo`000?nGZ^@01?nGZ^@00ol0
003oV:oWoiR_i`02oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000oinmkOnO_Nd00_nO_Nd00ol0
003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l000000on/dO<01Ol0003o/=Kdok3Fm?n`
e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000=ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`03o`000?o2b=ko`/SN00?o`/SN00?o
0000ol;8goo2b=l00oo2b=l00ol0003o_lOQoko7h@02oko7h@03o`000?nja^?o^/KS00?o^/KS00Co
0000okC4iol0003o00000onc`>@5ojZoj@03o`000?nO_NkoWkg^00;oWkg^00?o0000oi2jlon@^_<0
0_n@^_<01Ol0003oP;Cfoh2dm_n0]?Ko000000;oL:og0_l000001OmRZOOo0000oeZVmomJY_Oo0000
00;oFZKg00Go0000of:[n?mRZoSoHZ_ho`000003og2an@;o00000_n2^OP2o`0000?oUKod00?o0000
ojG4kol000001?nZc?83o`000003okK<jol0003o^m3Y00Co^m3Y00Co0000ol7@i_o1d>Ko`M3V1Ol0
0005oko=i@;o00001_nla^82o`0000;o^<GT00Co0000okFjgOl0003o00001?na^=h2o`0000Go[KOP
0ol00003oj>/g@;o00001OnP[=l2o`0000GoWZgQ0ol00004oiNZi003o`000?nH[nOoV:oW00;oV:oW
00?o0000oi^fj_nK]^X00onK]^X00ol0003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`
00Go0000ojS;l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0
003o]=ScokCHlondf??o000000oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06
ooooo`005_ooool2o`0004Wooooo00?o0000ol;8g_o2b=h00_o2b=h00ol0003o`/SOol;8g`03ol;8
g`03o`000?noan7o_lOQ00?o_lOQ00?o0000ok[6honja^<00_nja^<2o`0000Ko/l3T00?o0000ojZo
jOnZ_nT00onZ_nT01?l0003oWkg^oinmk_nO_Nh2o`0000?oT;[c00Co0000oh2dm_n0]?KoP;Cf0_l0
0002og2_m`04o`000?mRZOOoHZWgo`0000;oFZKg00Co0000oeZVmol0003o00000omRZoP2o`0000;o
L;7i00Go0000oh:in?n2^OSoP[Who`000002oiFom0;o00002?nZc?8;o`0000?o^m;[00Co0000oko=
iOnocNGo_lgU0ol000000onkc^Wo0000okc6hP02okc6hP?o00001?nhaN@2o`0000Co/KSN0_l00005
ojfgh0;o00000onZ]^800ol0003oXjcMo`000006oj2/g`03o`000?nN[N7oWZgQ00CoWZgQ00Co0000
oif_i?nM[nCoWJoT0_l000000onGZ^Co0000oiR_i`03oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o
0000oinmkOnO_Nd00_nO_Nd00ol0003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l00000
0on/dO<01Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Aoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool000cooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00?o0000ol;8g_o2b=h00_o2b=h00ol0003o
`/SOol;8g`03ol;8g`03o`000?noan7o_lOQ00?o_lOQ00Co0000ok[6hol0003o00000oni`N07ok?0
i003o`000?nZ_nWoZ[oY00;oZ[oY0_l00003oinmkP04o`000?n@^_?oT;[coi2jl`;o00000on0]?H0
1?l0003oL:ogog2_mol00002of:Ym`04o`000?mJY_OoFZKgo`0000;oFZKg00?o0000of:[n?mRZoP0
0_mRZoP01?l0003oL;7iog2anOl00002oh:in0?o00001?nKb_P3o`0000;oZ/cb00?o0000ok;Al?nb
dO001OnbdO000ol0003o^m;[ok_Bj`04ok_Bj`04o`000?nocNGo0000o`0000Go^lkY0ol00004okS5
i0?o00000_nda>H01?l0003o/KSNo`000?l00004ojfgh0?o00001OnZ]^82o`0000KoX:cO00?o0000
oij]hOnN[N400onN[N42o`0000GoWJoT0ol00003oiR_i`03o`000?nK]^[oVkKZ00?oVkKZ00?o0000
oinmkOnO_Nd00_nO_Nd00ol0003oY<C`ojC4l003ojC4l005o`000?nXbo;oZ<_bojS;l_l000000on/
dO<01Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`17ooooo`03o`000?o2b=ko`/SN00;o`/SN00?o0000ol;8goo2b=l0
0oo2b=l00ol0003o_lOQoko7h@02oko7h@;o00001_ni`N000ol0003o/l3Tok?0i004ok?0i003o`00
0?nZ_nWoZ[oY00?oZ[oY00Go0000oinmk_nO_NkoWkg^o`000004oi2jl`05o`000?n0]?KoP;Cfoh2d
m_l000000_m`[oL01?l0003oHZWgof:Ymol00002oeZVm`04o`000?mJY_OoFZKgo`0000;oHZ_h1ol0
0003ohW6o0?o00001?nKb_P2o`000004ok;Al?l0003o0000o`0000?o/]7`00Co0000ok_Bjonkd^_o
^m;[1Ol00006ok_>j@?o00001?nhaN@2o`0000Go]<CV0_l00004ojfgh0;o00001_nZ]^82o`0000;o
Y[GS00Co0000oj2/gonP[=ooX:cO0_l00004oij]h@;o00001OnM[n@2o`0000?oWK?W00?o0000oiR_
iol000001OnK]^X00ol0003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;
l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCH
londf??o000001Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`003_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo00?o0000ol;8g_o2b=h00oo2
b=h00ol0003o`/SOol;8g`03ol;8g`04o`000?noan7o0000o`0000?o_L7M1oni`N000ol0003o/l3T
ok?0i003ok?0i0;o00001?nZ_nT01?l0003oWkg^oinmk_nO_Nh2o`0000?oT;[c00?o0000oh2dm_n0
]?H03ol00004ofNio@03o`000?mf_ogoM[om00;o00001?n9a_`3o`000003oi_:n?l0003oYm;f00Co
Ym;f1ol00004ok?Cl@03o`000?nkc^Wo000000Co00000_nec^d00ol0003o^<GTo`000002o`0000Co
]<CV0ol00002ok32j004o`000?n]]n3o0000o`0000KoZ[KR0_l00005ojJeh`03o`000?nP[=oo0000
00GoWZgQ00?o0000oif_i?nM[n@01?nM[n@00ol0003oWK?Woifci`03oifci`?o00001?nK]^X00ol0
003oWkg]oinmk@02oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;l_nXbo;oZ<_bo`000003
ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCHlondf??o000001Kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooooooo
o`0:ooooo`;o0000Aoooool00ol0003o`/SNol;8gP03ol;8gP03o`000?o2b=oo`/SO00;o`/SO0_l0
0006okg1g@;o00001Oni`N02o`0000Go/l3T00?o0000ojZojOnZ_nT00_nZ_nT2o`0000?oWkg^00?o
0000oi2jlon@^_<00ol00003oh>kn0?oLkSk00Co0000ofJdnomV]?_o00000omN/o/2oejdo003o`00
0?mW^OgoIkWm00?oIkWm0ol000001?mf_ogo0000o`000?l00003ohW6o003o`000?nWd_KoYm;f00Ko
Ym;f00Co0000ok?ClOncdo7o/m?a1ol00006okG>k@?o00001?nda>H3o`0000Go/<;X0_l00006ojZf
hP;o00001onV]N<3o`0000?oWZgQ0_l00005oif_i0;o00001?nM/nL2o`0000?oW[SZ0_l000000onK
]^[o0000oinmk@03oinmk@03o`000?nTa?3oY<C`00?oY<C`00Go0000ojS;l_nXbo;oZ<_bo`000003
ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<01Ol0003o]=ScokCHlondf??o000001Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`003_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo04Gooooo00?o0000ol;8g_o2b=h00oo2b=h01?l0003o`/SOo`00
0?l00003oko1f`Oo_L7M00?o0000okW1h?ni`N001?ni`N000ol0003o/l3Tok?0i003ok?0i0;o0000
1?nZ_nT00ol0003oWkg^oinmkP03o`0000?oT[cd1On3^oP00ol0003oLkSkog>hn`02o`0000;oI[Ck
0_l00002oejcn`;oG[Cl0ol00003ofNio@;o00000_mf_od2o`0000KoVM3k1?l000001?ncdo7o0000
o`000?l00005oj[DmP03o`000?nec^go]Lk]00Go00000_n`c_000ol0003o]<CVo`000002o`0000Go
/<;X0ol000000on/`NWo0000ojZfhP03ojZfhP;o00001_nV]N<3o`0000?oY;KU00?o0000oij]hOl0
00001OnM[n@2o`0000GoWK?W00?o0000oijhj_nN^>X01?nN^>X4o`0000;oWkg]00?o0000ojC4l?nT
a?000onTa?001Ol0003oZ<_bojS;l_nXbo;o000000?o[=7c00Go0000ok3Fm?n`e_Co/=Kdo`000004
ok;Hl`05o`000?ndf??o]=ScokCHlol000006Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0AOooool0
0ol0003o`/SNol;8gP03ol;8gP03o`000?no`M_o_l7K00Co_l7K00?o0000okg1gOnm`Md01?nm`Md2
o`0000Go^L7P0_l00005ok?0i004o`000?nZ_nWoZ[oYojZoj@?o00000onO_Nh00ol0003oT[cdoi:l
m002oi:lm003o`000?n3^oSoPk_h00;oPk_h0_l000001Omc^?_o0000o`000?l0003oI[Ck00;o0000
0omN/o/00ol0003oG[Clo`000002o`0000;oIkWm00?o0000oh[=o_n:cOh01On:cOh5o`0000;oZ]Cf
2ol00005ok3>l0Co00001On``^P3o`0000Go[<7Y00Co0000ojZfh_l0003o00001OnV]N<3o`0000Ko
Y;KU0ol00004oif_i003o`000?nM/nOoWK?W00?oWK?W0_l00005oijhjP;o00001?nO_Nd3o`0000Co
Y<C`00Go0000ojS;l_nXbo;oZ<_bo`000003ojcAl`05o`000?n`e_Co/=Kdok3Fm?l000001?nbf?<0
1Ol0003o]=ScokCHlondf??o000001_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`05ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00Go0000
ol;8g_o2b=ko`/SNo`000009oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000okW1h?ni`N001?ni
`N000ol0003o/l3Tok?0i003ok?0i003o`000?nZ_nWo000000?oZKgX00?o0000oinmk_nO_Nh00_nO
_Nh2o`0000?oT[cd0_l00003oh>kn0;o00000_mc^?/2o`000004ofJdnol0003o0000o`0000?oG[?k
00?o0000oejdo?l000001Ommb?l5o`0000?oR/gn00?o0000oj7CnOnQdoT02?nQdoT00ol0003o/<k`
o`000005o`0000?oZ/gb00?o0000ok32j?n``^P00ol00007ojc1j@?o00001OnV]N<2o`0000KoY;KU
0ol00003oj:gi`04o`000?nM[nCo0000o`0000CoWK?W0_l00005oijhjP;o00001?nO_Nd2o`0000?o
X/;`0_l000000onTa?3o0000ojS;lP02ojS;lP05o`000?n/dO?o[=7cojcAlol000000on`e_@00ol0
003o/]Scok;Hl`02ok;Hl`05o`000?ndf??o]=ScokCHlol000007Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Gooooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00016oooo
o`03o`000?o2b=ko000000Co_l7K00?o0000oko1fono`M/01?no`M/00ol0003o_L7Mokg1g@04okg1
g@03o`000?ni`N3o^L7P00Co^L7P0_l00003ok?0i0;o00001_nY_NP2o`0000CoWkg^0_l00003oi:l
m0;o00000_n3^oP2o`0000;oLkSk0_l000001?mV]?_o0000o`000?l00004og?2oP;o000000?oMLCo
o`000?l000000_l00003ogg8o`?o00000_nQdoT;o`0000OoZ/gb1Ol00005ojc1j@Go00000onX`>/0
0ol0003oY[GSo`000002o`0000GoY;KU0ol00006oj:gi`?o00001?nM/nL00ol0003oW[SZoijhjP03
oijhjP;o00001OnO_Nd00ol0003oX/;`oj;2l004oj;2l0Co000000?oZ<_bo`000?n/dO<00_n/dO<0
1Ol0003o/=Kdok3Fm?n`e_Co000000Co/]Sc00Go0000okCHlondf??o]=Sco`00000Oooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002;ooooo00?o0000ooooooooool0A?oo
ool00ol0003o_l7Koko1f`05oko1f`03o`000?no`M_o_l7K00?o_l7K0_l00005okg1g@;o00001_ni
`N000ol0003o/l3To`000003ok2lh`03o`000?nY_NSoZKgX00CoZKgX0_l00004oinmkP;o00000onB
_?@2o`0000;oPk_h0_l000000omc^?_o0000o`000004ogS1o@;o00001Omc`_h4o`000004ogG4ool0
003o0000o`0000GoV=7k00?o0000oiSAnonHdO/00onHdO/00ol0003oZ/gboj[=lP07o`0000?oYL_d
00?o0000ojc1jOn/`NT01?l00007ojS0j`?o00001OnT]^D3o`0000KoX[OW0ol00003oj6hj@04o`00
0?nM/nOo0000o`0000GoW[SZ00?o0000oinmkOnO_Nd00onO_Nd2o`0000GoX/;`0_l00003ojC7lPSo
000000?o/=Kdo`000?nbf?<00onbf?<01Ol0003o]=ScokCHlondf??o0000023ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`008oooool00ol0003oooooooooo`15ooooo`Oo
_l7K0_l00005oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000okW1h?ni`N001?ni`N000ol0003o
/;cSok2lh`04ok2lh`;o00001OnY_NP3o`0000?oWkg^0ol00002oi:lm0;o000000?oPk_ho`000?l0
00001?n1`O`2o`0000GoN<7m1?l00002og?2oP;o00002?nAc_`8o`0000CoYL_d2Ol00006ojS0j`Go
00000onU_n`00ol0003oY;KUo`000002o`0000KoX[OW0ol00005oj6hj@Co00001?nN^>X2o`0000Co
Wkg]0_l00005oj;2l0;o00000onTao82o`0000;oY/cd0_l00003ojS?m0Co00000_nbf?<01Ol0003o
]=ScokCHlondf??o000002;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04oooo
o`009?ooool2o`0004Kooooo0_l00006oko1f`03o`000?no`M_o_l7K00?o_l7K0_l00005okg1g@;o
00000oni`N001?l0003o]KcOokFlgol00006ok2lh`;o00001_nY_NP2o`0000CoWkg^0_l000000onB
_?Co0000o`000004oh_0n003o`000?n1`OcoPL7l00?oPL7l0ol00005ogS1o@;o00002?n>bo`=o`00
00OoXLWe00?o0000ojS0jonX`>/01Ol00007ojFok0?o00001_nR]nL3o`0000GoXKSY0ol00004oj2j
k004o`000?nN^>[o0000o`0000CoWkg]0_l00005oj;2l0;o00001?nTao801Ol0003oY/cdojK<m?nV
c?Co000000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@4o`000003okCHlol0003ooooo02?ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15
ooooo`03o`000?no`M_o_l7K00Co_l7K0_l00005oko1f`03o`000?nm`Mgo_L7M00Co_L7M00?o0000
okW1h?l000001One_=l2o`0000Go/;cS0ol00005ojVmj0;o00001?nO_Nh00ol0003oU[odoiJom002
oiJom003o`000?n;`?SoRl3h00?oRl3h0ol00002oh71o0Co00000_mh`Od00ol0003oS/Skohk8n`02
ohk8n`Oo00000on>bo`00ol0003oXLWeoj79m@05oj79m@Wo00001onU_n`5o`0000?oX[k]00?o0000
oj:gionR]nL00ol00005oj6hj@?o00001_nP^^`4o`0000CoWkg]00?o0000oj;2l?nR`_000onR`_02
o`0000CoY<Ob0_l00002ojK<m0;o00000onXco@2o`0000CoZ]7d00Co0000ojcBm?n/d_Co[=;d0_l0
000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002Oooooo00?o0000
ooooooooool0AOooool2o`0000Ko_l7K00?o0000oko1fono`M/00ono`M/00ol0003o_L7Mokg1g@04
okg1g@03o`000?ne_=oo]KcO00Ko]KcO0_l00006ok2lh`;o00001OnY_NP2o`000003oinmk_l0003o
Wkg^00;oWkg^1OnF_o@4o`0000?oRl3h1?l000000on1`Oco0000o`00000<ohk8n`_o00001onNa_@0
1?l0003oYKo/ojFok?nU_n`5o`0000KoX[k]1Ol00005oj6hj@?o00001_nP^^`3o`0000CoX;g]00Co
0000oinmkOl0003o00001?nR`_02o`0000CoY<Ob0_l00002ojK<m0;o00001?nXco@00ol0003oZ]7d
oj[Am002oj[Am0;o00000_n/d_@2o`0002Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`04ooooo`00:?ooool00ol0003oooooooooo`16ooooo`03o`000?no`M_o_l7K00Co_l7K0_l0
0004oko1f`;o00000onm`Md01?l0003o^;_LokRkg?l00008okFlg`;o00001_n`_><2o`0000GoZKgX
00?o0000oinmk_nO_Nh01OnO_Nh2o`0000CoU[od0ol00004oh_0n0;o00002On@aOTJo`0000KoX[k]
1Ol00004oj6mk@03o`000?nQ^>WoXKSY00?o00001OnP^^`4o`0000OoX;g]0_l00004oj;2l0;o0000
1?nTao82o`0000?oY/cd00?o0000ojS?m?nXco@00_nXco@2o`0000?oZ]7d0_l00003ojcBm003o`00
0?oooooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00:Ooo
ool2o`0004Oooooo0_l00006oko1f`03o`000?no`M_o_l7K00?o_l7K00?o0000okg1gOl000001_nh
^m`00ol0003o]KcOokFlg`05okFlg`;o00001_n`_><2o`000003ojVmj?l0003oY[cX00?oY[cX00?o
0000oinmk_nO_Nh01_nO_Nh3o`0000;oU[od0ol00002oh_0n003o`000?nE`oKoUL?f00;oUL?f2Ol0
0003oi35n@03o`000?nMa?CoWLCd00goWLCd00Co0000oj:nkOnR_^goX[k]1Ol00007oj6mk@Go0000
1OnP^^`3o`0000SoX;g]0ol00002oj30k`04o`000?nR`_3o0000o`0000CoY<Ob0_l00003ojK<m0;o
00000onXco@2o`0000CoZ]7d00Co0000ojcBm?n/d_Co[=;d0_l0000]ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0A_ooool00ol0003o
_l7Koko1f`04oko1f`;o00000ono`M/2o`0000Wo^;_L0_l00006okFlg`;o00001_n`_><00ol0003o
Y[cXojJlj006ojJlj0?o00001onO_Nh3o`000003oiJom?l0003o000000koUL?f5ol00006oj6mk@Ko
00001?nP_Nh00ol0003oX;[/oj2jk003o`0000SoX;g]0ol00005oj30k`?o00001?nTao801?l0003o
Y/cdojK<m?nVc?@2o`0000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@2o`0000;o[=;d0_l0000_oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool002cooooo00?o0000oooooooo
ool0A_ooool2o`0000Ko_l7K00?o0000oko1fol000000onj^mX00ol0003o^;_LokRkg007okRkg0?o
00001One_=l2o`0000Co/;cS00Co0000ojbjhon/^^?o00002?nV_>P3o`0000OoWkg^0_l00006oi[0
lPWo00000onE`oH00ol0003oWL;boig2lP0>oig2lP04o`000?nQ_NgoXKg]oj6mk@Go00002?nP_Nh5
o`0000SoX;g]0ol00005oj30k`?o00000onQ`o001?l0003oY<Obo`000?l00003ojK<m003o`000?nX
coCoZ<od00;oZ<od0_l00003oj[Am0;o00000_n/d_@2o`0003;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`03ooooo`00;Oooool00ol0003oooooooooo`17ooooo`03o`000?no`M_o
_l7K00Co_l7K00?o0000okZkf_nj^mX01Onj^mX2o`0000So^;_L0_l00005okFlg`;o000000?o/;cS
o`000?n/^^<01On/^^<3o`0000KoY[cX0ol00005oinmkP04o`000?nO_NkoWkg^oinmkPOo00001OnJ
`?8Ho`0000OoX;g^1_l00003oj2mkP03o`000?nP_NgoX;g]00CoX;g]0ol00005oj30k`?o00001OnQ
`o05o`000003ojK<m?l0003o000000CoZ<od00?o0000oj[Am?nZdO@00_nZdO@01Ol0003o[=;dojcB
m?n/d_Co000003Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00;_oo
ool2o`0004Sooooo0_l00003oko1f`04o`000?nk^mWo^k_Io`0000Oo^[_J0ol00007okRkg0;o0000
1One_=l00ol0003o[;[Sojbjh`08ojbjh`Co00001OnV_>P3o`000003oinmk_l0003oWkg^00[oWkg^
1_l00002oi[0lP03o`000?nN_o3oW[o`00ooW[o`00Co0000oj2mk_nP_NkoX;g^1_l0000:oj2mkP03
o`000?nP_NgoX;g]00?o00001OnP`>l3o`0000GoXL?`0ol00004oj;5l@?o00000onXco@2o`0000?o
Z]7d0_l00002ojcBm0;o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000oko1fol000001_nk^mT2o`0000Ko^[_J
0_l00007okRkg0?o000000?o]KcOo`000?n`^Ml00_n`^Ml2o`0000[o[;[S0ol00005ojJlj003o`00
0?nO_NkoWkg^013oWkg^6?l0000<oj2mkPOo00001OnP`>l3o`0000GoXL?`0ol00004oj;5l@?o0000
0onTao800ol0003oZ<odo`000003oj[Am0;o00000_n/d_@2o`0003Wooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`17ooooo`03o`000?nk
^mWo^k_I00Oo^k_I0_l00006okZkfP?o00001onh^m`00ol0003o/;WOok2ig`06ok2ig`Go00001_n/
^^<3o`0000;oY[cX00?o0000ojBkjOnT^nT00onT^nT;o`0000CoWkg^00?o0000oinmk_nO_Nh04?nO
_Nh00ol0003oX;g^oj2mkP03oj2mkPWo00001_nP_Nd00ol0003oX<3_oj30k`03o`0000GoXL?`0ol0
0004oj;5l@?o00001_nTao84o`000003oj[Am?l0003o[=;d00;o[=;d00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000booooo`03o`000?oooooo
oooo04Sooooo00?o0000ok^kfOnk^mT01onk^mT3o`0000Ko^[_J0_l00005okRkg003o`000?nc^=go
/kSM00;o00002On`^Ml4o`0000Go[;[S0_l0000AojBkjAgo00003OnP_Nd5o`0000GoXL?`0ol00004
oj;5l@?o00001_nTao83o`0000?oY/Sb0ol000000on/d_Co0000o`00000nooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00oooool003?ooooo0_l0001;ooooo`;o00002?nk^mT2o`00
00Ko^[_J0ol000000onh^mco0000ok>hg@06ok>hg@?o00002?n`^Ml4o`0000;o[;[S00?o0000ojRi
i_nX^NH00_nX^NH7o`0000[oY;_Y00?o0000oj:ljonR_>/04OnR_>/00ol0003oX;g]oj2mk@08oj2m
k@Oo00001?nQ_^d00ol0003oXL?`oj73l003o`0000CoX/Ga0ol00006ojC7lP?o00000onVb?83o`00
00;oYlWa0_l00011ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003Go
oooo00?o0000ooooooooool0B_ooool3o`0000Oo^k_I0_l00007okZkfP03o`000?nc^=go/kSM00Wo
/kSM1?l00008ok2ig`;o00003?nX^NH7o`0000;oY;_Y00?o0000oj:ljonR_>/04onR_>/00ol0003o
X;g]oj2mk@07o`0000WoXKk]1Ol00004oj;5l@?o00001_nTao83o`0000?oY/Sb0ol00002ojO9l@?o
0000@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`00
0?oooooooooo04cooooo0_l00007ok^kf@?o00001?nj^mX00ol0003o]KOKokFgf`02o`0000_o/kSM
1?l00005ok2ig`03o`000?n[^>;oZkSR00;oZkSR1ol00008ojRiiQ_o00002OnQ_^d7o`0000CoXkk]
00?o0000oj;5lOl000000_l00006ojC7lP?o00000onVb?83o`0000?oYlWa0_l00017ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Oooooo0_l0001>ooooo`;o00002?nk
^mT2o`000003okZkf_l0003o]KOK00Ko]KOK1?l00009ok>hg@?o000000?o/;WOo`000?n[^>802on[
^>87o`0000?oZ;WV00?o0000ojBjjOnT^^T04onT^^T00ol0003oXKk]oj6nk@02oj6nk@Oo00002OnS
_^d4o`0000KoY<Ob0ol00004ojK8lP;o00000onWbO43o`0004[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`?o00001onk^mT0
0ol0003o]KOKokFgf`0:okFgf`?o00002Onc^=d2o`0001?oZkSR7_l0000;oj>nk@Go00001?nT_n`0
0ol0003oY<ObojC7lP03o`0000CoY/Sb0ol00003ojO9l@;o0000C_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oooooooooo04oooooo0_l00005ok^k
f@03o`000?nf^=_o][SK00;o00002one]m/4o`0000Ko/kSM00?o0000ojfgh?n]]n000_n]]n08o`00
00[oZkSR00?o0000ojJjionV^^L05?nV^^L00ol0003oXkk]oj>nk@06oj>nk@Ko00001onT_n`5o`00
00CoY/Sb0ol00004ojO9l@;o0000D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo000kooooo`03o`000?oooooooooo053ooooo0ol000000onk^mWo0000okJhf`06okJhf`Co
00002One]m/4o`000003ok>hgOl0003o[KOP00co[KOP1ol00003oj^hhP03o`000?nV^^OoY[[W01Go
Y[[W00?o0000oj>nkOnS_^d01Ol00007ojBok0Ko00001?nV_n`00ol0003oY/Sbo`000002o`0000Co
YlWa0ol0001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003cooooo
0_l0001Cooooo`03o`000?nf^=_o][SK00[o][SK1?l00009okFgf`;o00005?n]]n0No`0000OoY;o/
1Ol00009ojJok0?o00001OnWbO42o`0005Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`00?_ooool00ol0003oooooooooo`1Cooooo`;o00003?nf^=/4o`0000Ko]KOK00?o
0000ojnggon_]ml00_n_]ml8o`0000_o[KOP00?o0000ojRii_nX^NH05OnX^NH01?l0003oY;o/ojBo
k?nT_n`6o`0000WoY[o/1Ol00003ojO0j`03o`000?nWbO7o000000;o0000F_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo05Kooooo1?l0
000:okJhf`Co000000?o]KOKo`000?n_]ml03?n_]ml8o`0000?o[KOP00?o0000ojRii_nX^NH02_nX
^NH?o`0000[oY[o/1Ol00006ojO0j`Co0000GOooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo007ooooo0010ooooo`03o`000?oooooooooo05Wooooo1Ol00009okJhf`;o00005On_]ml@
o`0000coZKWU00?o0000ojJok?nV_n`01OnV_n`5o`0000KoYl3[1Ol0001Rooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00Oooool0047ooooo0_l0001Kooooo`03o`000?oooooooooo
00Co00001_nf^=/00ol0003o/;ONok2ggP02ok2ggPWo00002on_]ml00ol0003oZKWUojVii@0FojVi
i@03o`000?nV_ncoY[o/00Go00001_nW`>/5o`0006Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Co
oooo1?l000000onf^=_o0000ok2ggP0=ok2ggPSo00000on_]ml00ol0003oZKWUojVii@0:ojVii@oo
00001_nW`>/5o`0006kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
A?ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Sooooo0_l0000Fok2ggQ3o0000
3?n[^^@01?l0003oYl3[ojO0jonW`>/5o`0007?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`00AOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo
2Ol0000<ok2ggP03o`000?n[^^CoZk[T017oZk[T2Ol0001iooooo`03o`000?oooooooooo00Sooooo
0Ol00001ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Gooooo`Wo00000on`
]mh00ol0003oZk[Toj^ji004oj^ji0go0000Poooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool1ooooo`00B?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo2_l0002A
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool004_ooooo0_l0001Aooooo`03o`000?oooooooooo0;gooooo
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001>
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`04
ooooo`7o00000Oooool004oooooo0_l0001=ooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ooooool00oooool1o`00007ooooo001Aooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0`?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005;ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Dooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0<7ooooo00Go0000oooooooooooooooo
o`000001ooooo`00E?ooool2o`0004Sooooo00?o0000ooooooooool0`_ooool01?l0003ooooooooo
ool00001ooooo`00E_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0<?ooooo00?o
0000ooooool000000Oooool005Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`33
ooooo`03o`000?oooooooooo007o0000001Hooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0a?ooool1o`00007ooooo0Ol0000005Wooooo0_l00013ooooo`03o`000?oooooooooo0<Go
oooo0_l0000005_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o0000
001Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0`?ooool4o`0000?ooooo001M
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool4o`0000Oooooo001Noooo
o`;o0000?_ooool00ol0003oooooooooo`2hooooo`Co00002oooool0063ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2dooooo`Co00003oooool0067ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`2aooooo`?o00004oooool006;ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`2]ooooo`Co00005_ooool006?ooooo0_l0000iooooo`03o`000?oooooo
oooo0:Wooooo1?l0000Jooooo`00IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
0:Gooooo1?l0000Nooooo`00I_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;o
oooo1?l0000Rooooo`00Ioooool2o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0002Kooooo
001Yooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0V_ooool4o`0002[ooooo001Z
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0U_ooool4o`0002kooooo001[oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0T_ooool4o`0003;ooooo001/ooooo`;o
0000;oooool00ol0003oooooooooo`2>ooooo`Co0000=_ooool006kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2:ooooo`Co0000>_ooool006oooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`27ooooo`?o0000?_ooool0073ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`23ooooo`Co0000@Oooool0077ooooo0_l0000Zooooo`03o`000?oooooooooo
07oooooo1?l00015ooooo`00Loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07_o
oooo1?l00019ooooo`00M?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo
1?l0001=ooooo`00MOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07?ooooo1?l0
001Aooooo`00M_ooool2o`0002Gooooo00?o0000ooooooooool0Koooool4o`0005Gooooo001hoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Wooooo001iooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005gooooo001jooooo`;o0000
8Oooool00ol0003oooooooooo`1Sooooo`Co0000HOooool007cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Pooooo`?o0000IOooool007gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Looooo`Co0000J?ooool007kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Hooooo`Co0000K?ooool007oooooo0_l0000Looooo`03o`000?oooooooooo05Co
oooo1?l0001`ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo053ooooo
1?l0001dooooo`00P_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l0
001hooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001l
ooooo`00Q?ooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`00083ooooo0026ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008Cooooo0027ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008Sooooo0028ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0>Oooool3o`0008cooooo0029ooooo`;o00004_ooool0
0ol0003oooooooooo`0eooooo`Co0000Soooool008_ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0booooo`Co0000Toooool008cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0^ooooo`Co0000Uoooool008gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Zooooo`Co0000Voooool008kooooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo1?l0
002Oooooo`00T?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002S
ooooo`00TOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Woooo
o`00T_ooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:_ooooo002Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:oooooo002Eooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;?ooooo002Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool3o`000;Oooooo002Gooooo`;o00000oooool00ol0
003oooooooooo`0;ooooo`Co0000^_ooool009Wooooo00Co0000oooooooooooo00002Oooool4o`00
0;kooooo002Jooooo`03o`000?oooooo000000Gooooo1?l00032ooooo`00Voooool2o`000003oooo
ool0003o000000;o0000a_ooool009cooooo0_l0003:ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51724 .65343 m .51694 .65827 L .43899 .65168 L p .588 .786 .974 r
F P
0 g
s
.51694 .65827 m .51724 .65343 L .59265 .64836 L p .636 .778 .949 r
F P
0 g
s
.59265 .64836 m .59527 .65394 L .51694 .65827 L p .636 .778 .949 r
F P
0 g
s
.59527 .65394 m .59265 .64836 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44218 .64783 m .43899 .65168 L .36521 .63435 L p .523 .769 .987 r
F P
0 g
s
.43899 .65168 m .44218 .64783 L .51724 .65343 L p .588 .786 .974 r
F P
0 g
s
.51755 .64847 m .51724 .65343 L .44218 .64783 L p .597 .789 .973 r
F P
0 g
s
.51724 .65343 m .51755 .64847 L .59 .64269 L p .642 .78 .947 r
F P
0 g
s
.59 .64269 m .59265 .64836 L .51724 .65343 L p .642 .78 .947 r
F P
0 g
s
.59265 .64836 m .59 .64269 L .65915 .62672 L p .661 .753 .918 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59265 .64836 L p .661 .753 .918 r
F P
0 g
s
.36521 .63435 m .37116 .6317 L .44218 .64783 L p .523 .769 .987 r
F P
0 g
s
.4454 .64384 m .44218 .64783 L .37116 .6317 L p .534 .773 .986 r
F P
0 g
s
.44218 .64783 m .4454 .64384 L .51755 .64847 L p .597 .789 .973 r
F P
0 g
s
.51786 .64323 m .51755 .64847 L .4454 .64384 L p .612 .79 .967 r
F P
0 g
s
.51755 .64847 m .51786 .64323 L .58732 .63685 L p .651 .78 .942 r
F P
0 g
s
.58732 .63685 m .59 .64269 L .51755 .64847 L p .651 .78 .942 r
F P
0 g
s
.59 .64269 m .58732 .63685 L .65355 .62061 L p .667 .755 .916 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59 .64269 L p .667 .755 .916 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72971 .60722 L p .653 .72 .897 r
F P
0 g
s
.72971 .60722 m .73799 .61332 L .67023 .63881 L p .653 .72 .897 r
F P
0 g
s
.37116 .6317 m .37718 .62889 L .4454 .64384 L p .534 .773 .986 r
F P
0 g
s
.44866 .63948 m .4454 .64384 L .37718 .62889 L p .559 .777 .98 r
F P
0 g
s
.4454 .64384 m .44866 .63948 L .51786 .64323 L p .612 .79 .967 r
F P
0 g
s
.51817 .63758 m .51786 .64323 L .44866 .63948 L p .632 .787 .956 r
F P
0 g
s
.51786 .64323 m .51817 .63758 L .58462 .63077 L p .66 .778 .936 r
F P
0 g
s
.58462 .63077 m .58732 .63685 L .51786 .64323 L p .66 .778 .936 r
F P
0 g
s
.37116 .6317 m .36521 .63435 L .29943 .6068 L p .469 .734 .985 r
F P
0 g
s
.58732 .63685 m .58462 .63077 L .6479 .61445 L p .673 .757 .914 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58732 .63685 L p .673 .757 .914 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72139 .60113 L p .658 .721 .895 r
F P
0 g
s
.72139 .60113 m .72971 .60722 L .66471 .63279 L p .658 .721 .895 r
F P
0 g
s
.37718 .62889 m .38326 .62566 L .44866 .63948 L p .559 .777 .98 r
F P
0 g
s
.45196 .63457 m .44866 .63948 L .38326 .62566 L p .593 .779 .969 r
F P
0 g
s
.44866 .63948 m .45196 .63457 L .51817 .63758 L p .632 .787 .956 r
F P
0 g
s
.51849 .6314 m .51817 .63758 L .45196 .63457 L p .652 .78 .942 r
F P
0 g
s
.51817 .63758 m .51849 .6314 L .58189 .62439 L p .67 .773 .927 r
F P
0 g
s
.58189 .62439 m .58462 .63077 L .51817 .63758 L p .67 .773 .927 r
F P
0 g
s
.29943 .6068 m .30795 .60551 L .37116 .6317 L p .469 .734 .985 r
F P
0 g
s
.37718 .62889 m .37116 .6317 L .30795 .60551 L p .481 .739 .984 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71302 .59512 L p .664 .726 .895 r
F P
0 g
s
.71302 .59512 m .72139 .60113 L .65915 .62672 L p .664 .726 .895 r
F P
0 g
s
.58462 .63077 m .58189 .62439 L .64221 .60824 L p .677 .758 .912 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58462 .63077 L p .677 .758 .912 r
F P
0 g
s
.38326 .62566 m .38943 .62176 L .45196 .63457 L p .593 .779 .969 r
F P
0 g
s
.4553 .62893 m .45196 .63457 L .38943 .62176 L p .628 .776 .952 r
F P
0 g
s
.45196 .63457 m .4553 .62893 L .51849 .6314 L p .652 .78 .942 r
F P
0 g
s
.51881 .6246 m .51849 .6314 L .4553 .62893 L p .669 .77 .926 r
F P
0 g
s
.51849 .6314 m .51881 .6246 L .57913 .61766 L p .677 .767 .918 r
F P
0 g
s
.57913 .61766 m .58189 .62439 L .51849 .6314 L p .677 .767 .918 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70461 .58926 L p .669 .732 .897 r
F P
0 g
s
.70461 .58926 m .71302 .59512 L .65355 .62061 L p .669 .732 .897 r
F P
0 g
s
.30795 .60551 m .31654 .60408 L .37718 .62889 L p .481 .739 .984 r
F P
0 g
s
.38326 .62566 m .37718 .62889 L .31654 .60408 L p .513 .748 .98 r
F P
0 g
s
.58189 .62439 m .57913 .61766 L .63648 .60198 L p .681 .759 .911 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58189 .62439 L p .681 .759 .911 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69617 .58362 L p .675 .74 .9 r
F P
0 g
s
.69617 .58362 m .70461 .58926 L .6479 .61445 L p .675 .74 .9 r
F P
0 g
s
.38943 .62176 m .39568 .61699 L .4553 .62893 L p .628 .776 .952 r
F P
0 g
s
.4587 .62244 m .4553 .62893 L .39568 .61699 L p .659 .769 .931 r
F P
0 g
s
.4553 .62893 m .4587 .62244 L .51881 .6246 L p .669 .77 .926 r
F P
0 g
s
.51913 .61712 m .51881 .6246 L .4587 .62244 L p .683 .759 .909 r
F P
0 g
s
.51881 .6246 m .51913 .61712 L .57635 .61056 L p .683 .759 .909 r
F P
0 g
s
.57635 .61056 m .57913 .61766 L .51881 .6246 L p .683 .759 .909 r
F P
0 g
s
.73799 .61332 m .72971 .60722 L .78387 .57256 L p .636 .691 .884 r
F P
0 g
s
.78387 .57256 m .79464 .57831 L .73799 .61332 L p .636 .691 .884 r
F P
0 g
s
.31654 .60408 m .32523 .60218 L .38326 .62566 L p .513 .748 .98 r
F P
0 g
s
.38943 .62176 m .38326 .62566 L .32523 .60218 L p .558 .757 .971 r
F P
0 g
s
.57913 .61766 m .57635 .61056 L .6307 .59568 L p .683 .76 .91 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57913 .61766 L p .683 .76 .91 r
F P
0 g
s
.72971 .60722 m .72139 .60113 L .77307 .56688 L p .641 .693 .883 r
F P
0 g
s
.77307 .56688 m .78387 .57256 L .72971 .60722 L p .641 .693 .883 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68769 .57824 L p .679 .75 .904 r
F P
0 g
s
.68769 .57824 m .69617 .58362 L .64221 .60824 L p .679 .75 .904 r
F P
0 g
s
.39568 .61699 m .40202 .6112 L .4587 .62244 L p .659 .769 .931 r
F P
0 g
s
.46213 .61503 m .4587 .62244 L .40202 .6112 L p .684 .759 .908 r
F P
0 g
s
.4587 .62244 m .46213 .61503 L .51913 .61712 L p .683 .759 .909 r
F P
0 g
s
.51946 .60898 m .51913 .61712 L .46213 .61503 L p .693 .747 .892 r
F P
0 g
s
.51913 .61712 m .51946 .60898 L .57353 .60309 L p .686 .751 .901 r
F P
0 g
s
.57353 .60309 m .57635 .61056 L .51913 .61712 L p .686 .751 .901 r
F P
0 g
s
.30795 .60551 m .29943 .6068 L .24558 .56996 L p .451 .697 .972 r
F P
0 g
s
.57635 .61056 m .57353 .60309 L .62488 .58932 L p .682 .76 .91 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57635 .61056 L p .682 .76 .91 r
F P
0 g
s
.32523 .60218 m .33404 .59956 L .38943 .62176 L p .558 .757 .971 r
F P
0 g
s
.39568 .61699 m .38943 .62176 L .33404 .59956 L p .606 .762 .954 r
F P
0 g
s
.72139 .60113 m .71302 .59512 L .76224 .5614 L p .647 .699 .884 r
F P
0 g
s
.76224 .5614 m .77307 .56688 L .72139 .60113 L p .647 .699 .884 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67916 .57313 L p .683 .761 .91 r
F P
0 g
s
.67916 .57313 m .68769 .57824 L .63648 .60198 L p .683 .761 .91 r
F P
0 g
s
.40202 .6112 m .40844 .6043 L .46213 .61503 L p .684 .759 .908 r
F P
0 g
s
.46561 .6067 m .46213 .61503 L .40844 .6043 L p .702 .748 .887 r
F P
0 g
s
.46213 .61503 m .46561 .6067 L .51946 .60898 L p .693 .747 .892 r
F P
0 g
s
.51979 .60022 m .51946 .60898 L .46561 .6067 L p .699 .735 .878 r
F P
0 g
s
.51946 .60898 m .51979 .60022 L .57069 .59527 L p .686 .742 .894 r
F P
0 g
s
.57069 .59527 m .57353 .60309 L .51946 .60898 L p .686 .742 .894 r
F P
0 g
s
.24558 .56996 m .25635 .5702 L .30795 .60551 L p .451 .697 .972 r
F P
0 g
s
.31654 .60408 m .30795 .60551 L .25635 .5702 L p .462 .702 .971 r
F P
0 g
s
.71302 .59512 m .70461 .58926 L .7514 .55627 L p .655 .709 .887 r
F P
0 g
s
.7514 .55627 m .76224 .5614 L .71302 .59512 L p .655 .709 .887 r
F P
0 g
s
.57353 .60309 m .57069 .59527 L .61901 .58292 L p .68 .759 .911 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57353 .60309 L p .68 .759 .911 r
F P
0 g
s
.33404 .59956 m .34296 .59597 L .39568 .61699 L p .606 .762 .954 r
F P
0 g
s
.40202 .6112 m .39568 .61699 L .34296 .59597 L p .65 .763 .932 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .6706 .56831 L p .684 .771 .917 r
F P
0 g
s
.6706 .56831 m .67916 .57313 L .6307 .59568 L p .684 .771 .917 r
F P
0 g
s
.40844 .6043 m .41495 .59629 L .46561 .6067 L p .702 .748 .887 r
F P
0 g
s
.46913 .59753 m .46561 .6067 L .41495 .59629 L p .715 .736 .868 r
F P
0 g
s
.46561 .6067 m .46913 .59753 L .51979 .60022 L p .699 .735 .878 r
F P
0 g
s
.70461 .58926 m .69617 .58362 L .74054 .55161 L p .665 .724 .893 r
F P
0 g
s
.74054 .55161 m .7514 .55627 L .70461 .58926 L p .665 .724 .893 r
F P
0 g
s
.52013 .59092 m .51979 .60022 L .46913 .59753 L p .701 .724 .867 r
F P
0 g
s
.51979 .60022 m .52013 .59092 L .56782 .58714 L p .684 .734 .888 r
F P
0 g
s
.56782 .58714 m .57069 .59527 L .51979 .60022 L p .684 .734 .888 r
F P
0 g
s
.25635 .5702 m .2672 .57029 L .31654 .60408 L p .462 .702 .971 r
F P
0 g
s
.32523 .60218 m .31654 .60408 L .2672 .57029 L p .495 .714 .969 r
F P
0 g
s
.34296 .59597 m .352 .59125 L .40202 .6112 L p .65 .763 .932 r
F P
0 g
s
.40844 .6043 m .40202 .6112 L .352 .59125 L p .685 .759 .908 r
F P
0 g
s
.57069 .59527 m .56782 .58714 L .61309 .57646 L p .675 .757 .913 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57069 .59527 L p .675 .757 .913 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66198 .56374 L p .682 .781 .925 r
F P
0 g
s
.66198 .56374 m .6706 .56831 L .62488 .58932 L p .682 .781 .925 r
F P
0 g
s
.69617 .58362 m .68769 .57824 L .72968 .54749 L p .674 .741 .901 r
F P
0 g
s
.72968 .54749 m .74054 .55161 L .69617 .58362 L p .674 .741 .901 r
F P
0 g
s
.41495 .59629 m .42153 .58726 L .46913 .59753 L p .715 .736 .868 r
F P
0 g
s
.47269 .58763 m .46913 .59753 L .42153 .58726 L p .722 .726 .854 r
F P
0 g
s
.46913 .59753 m .47269 .58763 L .52013 .59092 L p .701 .724 .867 r
F P
0 g
s
.52047 .58123 m .52013 .59092 L .47269 .58763 L p .7 .714 .86 r
F P
0 g
s
.52013 .59092 m .52047 .58123 L .56493 .57878 L p .679 .726 .885 r
F P
0 g
s
.56493 .57878 m .56782 .58714 L .52013 .59092 L p .679 .726 .885 r
F P
0 g
s
.2672 .57029 m .27816 .56991 L .32523 .60218 L p .495 .714 .969 r
F P
0 g
s
.33404 .59956 m .32523 .60218 L .27816 .56991 L p .542 .73 .961 r
F P
0 g
s
.352 .59125 m .36115 .5853 L .40844 .6043 L p .685 .759 .908 r
F P
0 g
s
.41495 .59629 m .40844 .6043 L .36115 .5853 L p .711 .753 .885 r
F P
0 g
s
.56782 .58714 m .56493 .57878 L .60713 .56996 L p .666 .755 .916 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56782 .58714 L p .666 .755 .916 r
F P
0 g
s
.68769 .57824 m .67916 .57313 L .7188 .54397 L p .683 .761 .911 r
F P
0 g
s
.7188 .54397 m .72968 .54749 L .68769 .57824 L p .683 .761 .911 r
F P
0 g
s
.42153 .58726 m .42817 .57738 L .47269 .58763 L p .722 .726 .854 r
F P
0 g
s
.47627 .57719 m .47269 .58763 L .42817 .57738 L p .724 .717 .844 r
F P
0 g
s
.47269 .58763 m .47627 .57719 L .52047 .58123 L p .7 .714 .86 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65332 .55939 L p .677 .79 .934 r
F P
0 g
s
.65332 .55939 m .66198 .56374 L .61901 .58292 L p .677 .79 .934 r
F P
0 g
s
.52081 .57128 m .52047 .58123 L .47627 .57719 L p .695 .706 .856 r
F P
0 g
s
.52047 .58123 m .52081 .57128 L .56201 .57026 L p .671 .719 .885 r
F P
0 g
s
.56201 .57026 m .56493 .57878 L .52047 .58123 L p .671 .719 .885 r
F P
0 g
s
.36115 .5853 m .37041 .57814 L .41495 .59629 L p .711 .753 .885 r
F P
0 g
s
.42153 .58726 m .41495 .59629 L .37041 .57814 L p .73 .746 .865 r
F P
0 g
s
.27816 .56991 m .28923 .56879 L .33404 .59956 L p .542 .73 .961 r
F P
0 g
s
.34296 .59597 m .33404 .59956 L .28923 .56879 L p .595 .744 .948 r
F P
0 g
s
.56493 .57878 m .56201 .57026 L .60112 .5634 L p .654 .751 .921 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57878 L p .654 .751 .921 r
F P
0 g
s
.67916 .57313 m .6706 .56831 L .7079 .54104 L p .691 .782 .921 r
F P
0 g
s
.7079 .54104 m .7188 .54397 L .67916 .57313 L p .691 .782 .921 r
F P
0 g
s
.79464 .57831 m .78387 .57256 L .82343 .53023 L p .609 .669 .882 r
F P
0 g
s
.82343 .53023 m .83625 .53514 L .79464 .57831 L p .609 .669 .882 r
F P
0 g
s
.42817 .57738 m .43486 .56686 L .47627 .57719 L p .724 .717 .844 r
F P
0 g
s
.47989 .56644 m .47627 .57719 L .43486 .56686 L p .723 .71 .838 r
F P
0 g
s
.47627 .57719 m .47989 .56644 L .52081 .57128 L p .695 .706 .856 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .6446 .55517 L p .668 .796 .943 r
F P
0 g
s
.6446 .55517 m .65332 .55939 L .61309 .57646 L p .668 .796 .943 r
F P
0 g
s
.37041 .57814 m .37977 .56985 L .42153 .58726 L p .73 .746 .865 r
F P
0 g
s
.42817 .57738 m .42153 .58726 L .37977 .56985 L p .742 .739 .849 r
F P
0 g
s
.52115 .56127 m .52081 .57128 L .47989 .56644 L p .687 .699 .856 r
F P
0 g
s
.52081 .57128 m .52115 .56127 L .55907 .56168 L p .659 .712 .887 r
F P
0 g
s
.55907 .56168 m .56201 .57026 L .52081 .57128 L p .659 .712 .887 r
F P
0 g
s
.78387 .57256 m .77307 .56688 L .81061 .52543 L p .614 .671 .881 r
F P
0 g
s
.81061 .52543 m .82343 .53023 L .78387 .57256 L p .614 .671 .881 r
F P
0 g
s
.28923 .56879 m .30044 .56667 L .34296 .59597 L p .595 .744 .948 r
F P
0 g
s
.352 .59125 m .34296 .59597 L .30044 .56667 L p .644 .754 .929 r
F P
0 g
s
.6706 .56831 m .66198 .56374 L .69697 .53866 L p .695 .803 .932 r
F P
0 g
s
.69697 .53866 m .7079 .54104 L .6706 .56831 L p .695 .803 .932 r
F P
0 g
s
.43486 .56686 m .4416 .55599 L .47989 .56644 L p .723 .71 .838 r
F P
0 g
s
.48352 .55564 m .47989 .56644 L .4416 .55599 L p .718 .705 .837 r
F P
0 g
s
.47989 .56644 m .48352 .55564 L .52115 .56127 L p .687 .699 .856 r
F P
0 g
s
.56201 .57026 m .55907 .56168 L .59506 .55679 L p .639 .746 .926 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56201 .57026 L p .639 .746 .926 r
F P
0 g
s
.77307 .56688 m .76224 .5614 L .7978 .52094 L p .623 .679 .883 r
F P
0 g
s
.7978 .52094 m .81061 .52543 L .77307 .56688 L p .623 .679 .883 r
F P
0 g
s
.37977 .56985 m .3892 .56062 L .42817 .57738 L p .742 .739 .849 r
F P
0 g
s
.43486 .56686 m .42817 .57738 L .3892 .56062 L p .748 .734 .839 r
F P
0 g
s
.25635 .5702 m .24558 .56996 L .20758 .52532 L p .47 .671 .951 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63582 .55101 L p .654 .798 .951 r
F P
0 g
s
.63582 .55101 m .6446 .55517 L .60713 .56996 L p .654 .798 .951 r
F P
0 g
s
.30044 .56667 m .31179 .56338 L .352 .59125 L p .644 .754 .929 r
F P
0 g
s
.36115 .5853 m .352 .59125 L .31179 .56338 L p .685 .76 .908 r
F P
0 g
s
.5215 .55138 m .52115 .56127 L .48352 .55564 L p .675 .694 .86 r
F P
0 g
s
.52115 .56127 m .5215 .55138 L .55611 .55313 L p .644 .706 .892 r
F P
0 g
s
.55611 .55313 m .55907 .56168 L .52115 .56127 L p .644 .706 .892 r
F P
0 g
s
.76224 .5614 m .7514 .55627 L .78502 .51698 L p .635 .693 .887 r
F P
0 g
s
.78502 .51698 m .7978 .52094 L .76224 .5614 L p .635 .693 .887 r
F P
0 g
s
.3892 .56062 m .39869 .55071 L .43486 .56686 L p .748 .734 .839 r
F P
0 g
s
.4416 .55599 m .43486 .56686 L .39869 .55071 L p .75 .729 .833 r
F P
0 g
s
.4416 .55599 m .44837 .54507 L .48352 .55564 L p .718 .705 .837 r
F P
0 g
s
.48718 .54503 m .48352 .55564 L .44837 .54507 L p .708 .701 .841 r
F P
0 g
s
.48352 .55564 m .48718 .54503 L .5215 .55138 L p .675 .694 .86 r
F P
0 g
s
.66198 .56374 m .65332 .55939 L .686 .53674 L p .695 .822 .943 r
F P
0 g
s
.686 .53674 m .69697 .53866 L .66198 .56374 L p .695 .822 .943 r
F P
0 g
s
.7514 .55627 m .74054 .55161 L .77227 .51371 L p .649 .712 .893 r
F P
0 g
s
.77227 .51371 m .78502 .51698 L .7514 .55627 L p .649 .712 .893 r
F P
0 g
s
.55907 .56168 m .55611 .55313 L .58896 .55013 L p .619 .739 .932 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55907 .56168 L p .619 .739 .932 r
F P
0 g
s
.31179 .56338 m .32325 .55883 L .36115 .5853 L p .685 .76 .908 r
F P
0 g
s
.37041 .57814 m .36115 .5853 L .32325 .55883 L p .718 .762 .887 r
F P
0 g
s
.20758 .52532 m .22014 .5272 L .25635 .5702 L p .47 .671 .951 r
F P
0 g
s
.2672 .57029 m .25635 .5702 L .22014 .5272 L p .48 .675 .951 r
F P
0 g
s
.39869 .55071 m .40823 .54043 L .4416 .55599 L p .75 .729 .833 r
F P
0 g
s
.44837 .54507 m .4416 .55599 L .40823 .54043 L p .747 .725 .832 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62697 .54682 L p .636 .796 .959 r
F P
0 g
s
.62697 .54682 m .63582 .55101 L .60112 .5634 L p .636 .796 .959 r
F P
0 g
s
.52185 .54178 m .5215 .55138 L .48718 .54503 L p .659 .69 .867 r
F P
0 g
s
.5215 .55138 m .52185 .54178 L .55312 .54469 L p .624 .699 .899 r
F P
0 g
s
.55312 .54469 m .55611 .55313 L .5215 .55138 L p .624 .699 .899 r
F P
0 g
s
.74054 .55161 m .72968 .54749 L .75955 .51124 L p .666 .735 .901 r
F P
0 g
s
.75955 .51124 m .77227 .51371 L .74054 .55161 L p .666 .735 .901 r
F P
0 g
s
.44837 .54507 m .45516 .53443 L .48718 .54503 L p .708 .701 .841 r
F P
0 g
s
.49085 .53487 m .48718 .54503 L .45516 .53443 L p .694 .698 .849 r
F P
0 g
s
.48718 .54503 m .49085 .53487 L .52185 .54178 L p .659 .69 .867 r
F P
0 g
s
.32325 .55883 m .33484 .55303 L .37041 .57814 L p .718 .762 .887 r
F P
0 g
s
.37977 .56985 m .37041 .57814 L .33484 .55303 L p .742 .762 .869 r
F P
0 g
s
.65332 .55939 m .6446 .55517 L .67497 .53514 L p .69 .837 .953 r
F P
0 g
s
.67497 .53514 m .686 .53674 L .65332 .55939 L p .69 .837 .953 r
F P
0 g
s
.40823 .54043 m .4178 .53014 L .44837 .54507 L p .747 .725 .832 r
F P
0 g
s
.45516 .53443 m .44837 .54507 L .4178 .53014 L p .739 .722 .835 r
F P
0 g
s
.55611 .55313 m .55312 .54469 L .5828 .54342 L p .595 .73 .938 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55611 .55313 L p .595 .73 .938 r
F P
0 g
s
.22014 .5272 m .23277 .52894 L .2672 .57029 L p .48 .675 .951 r
F P
0 g
s
.27816 .56991 m .2672 .57029 L .23277 .52894 L p .508 .688 .949 r
F P
0 g
s
.72968 .54749 m .7188 .54397 L .74687 .50964 L p .684 .762 .911 r
F P
0 g
s
.74687 .50964 m .75955 .51124 L .72968 .54749 L p .684 .762 .911 r
F P
0 g
s
.33484 .55303 m .34652 .54607 L .37977 .56985 L p .742 .762 .869 r
F P
0 g
s
.3892 .56062 m .37977 .56985 L .34652 .54607 L p .759 .761 .854 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61805 .5425 L p .612 .789 .966 r
F P
0 g
s
.61805 .5425 m .62697 .54682 L .59506 .55679 L p .612 .789 .966 r
F P
0 g
s
.5222 .53262 m .52185 .54178 L .49085 .53487 L p .638 .686 .878 r
F P
0 g
s
.52185 .54178 m .5222 .53262 L .55011 .53646 L p .6 .693 .908 r
F P
0 g
s
.55011 .53646 m .55312 .54469 L .52185 .54178 L p .6 .693 .908 r
F P
0 g
s
.45516 .53443 m .46198 .52437 L .49085 .53487 L p .694 .698 .849 r
F P
0 g
s
.49455 .52537 m .49085 .53487 L .46198 .52437 L p .675 .695 .861 r
F P
0 g
s
.49085 .53487 m .49455 .52537 L .5222 .53262 L p .638 .686 .878 r
F P
0 g
s
.6446 .55517 m .63582 .55101 L .66389 .5337 L p .679 .846 .963 r
F P
0 g
s
.66389 .5337 m .67497 .53514 L .6446 .55517 L p .679 .846 .963 r
F P
0 g
s
.4178 .53014 m .42739 .52018 L .45516 .53443 L p .739 .722 .835 r
F P
0 g
s
.46198 .52437 m .45516 .53443 L .42739 .52018 L p .727 .72 .844 r
F P
0 g
s
.7188 .54397 m .7079 .54104 L .73419 .5089 L p .7 .79 .92 r
F P
0 g
s
.73419 .5089 m .74687 .50964 L .7188 .54397 L p .7 .79 .92 r
F P
0 g
s
.34652 .54607 m .35827 .53816 L .3892 .56062 L p .759 .761 .854 r
F P
0 g
s
.39869 .55071 m .3892 .56062 L .35827 .53816 L p .769 .759 .844 r
F P
0 g
s
.23277 .52894 m .24549 .53024 L .27816 .56991 L p .508 .688 .949 r
F P
0 g
s
.28923 .56879 m .27816 .56991 L .24549 .53024 L p .549 .707 .944 r
F P
0 g
s
.55312 .54469 m .55011 .53646 L .5766 .53665 L p .567 .719 .944 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55312 .54469 L p .567 .719 .944 r
F P
0 g
s
.35827 .53816 m .37008 .52955 L .39869 .55071 L p .769 .759 .844 r
F P
0 g
s
.40823 .54043 m .39869 .55071 L .37008 .52955 L p .773 .758 .839 r
F P
0 g
s
.42739 .52018 m .43699 .51089 L .46198 .52437 L p .727 .72 .844 r
F P
0 g
s
.46882 .51516 m .46198 .52437 L .43699 .51089 L p .707 .718 .857 r
F P
0 g
s
.46198 .52437 m .46882 .51516 L .49455 .52537 L p .675 .695 .861 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60906 .53795 L p .584 .778 .972 r
F P
0 g
s
.60906 .53795 m .61805 .5425 L .58896 .55013 L p .584 .778 .972 r
F P
0 g
s
.7079 .54104 m .69697 .53866 L .72152 .50896 L p .714 .817 .929 r
F P
0 g
s
.72152 .50896 m .73419 .5089 L .7079 .54104 L p .714 .817 .929 r
F P
0 g
s
.52255 .52403 m .5222 .53262 L .49455 .52537 L p .611 .681 .892 r
F P
0 g
s
.5222 .53262 m .52255 .52403 L .54708 .5285 L p .571 .685 .918 r
F P
0 g
s
.54708 .5285 m .55011 .53646 L .5222 .53262 L p .571 .685 .918 r
F P
0 g
s
.49826 .51671 m .49455 .52537 L .46882 .51516 L p .648 .692 .877 r
F P
0 g
s
.49455 .52537 m .49826 .51671 L .52255 .52403 L p .611 .681 .892 r
F P
0 g
s
.24549 .53024 m .25833 .5308 L .28923 .56879 L p .549 .707 .944 r
F P
0 g
s
.30044 .56667 m .28923 .56879 L .25833 .5308 L p .596 .727 .935 r
F P
0 g
s
.37008 .52955 m .38192 .52059 L .40823 .54043 L p .773 .758 .839 r
F P
0 g
s
.4178 .53014 m .40823 .54043 L .38192 .52059 L p .772 .756 .839 r
F P
0 g
s
.63582 .55101 m .62697 .54682 L .65273 .53225 L p .661 .849 .972 r
F P
0 g
s
.65273 .53225 m .66389 .5337 L .63582 .55101 L p .661 .849 .972 r
F P
0 g
s
.38192 .52059 m .39377 .51163 L .4178 .53014 L p .772 .756 .839 r
F P
0 g
s
.42739 .52018 m .4178 .53014 L .39377 .51163 L p .766 .755 .843 r
F P
0 g
s
.55011 .53646 m .54708 .5285 L .57035 .52982 L p .535 .705 .949 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55011 .53646 L p .535 .705 .949 r
F P
0 g
s
.43699 .51089 m .4466 .50257 L .46882 .51516 L p .707 .718 .857 r
F P
0 g
s
.47569 .50699 m .46882 .51516 L .4466 .50257 L p .68 .714 .874 r
F P
0 g
s
.46882 .51516 m .47569 .50699 L .49826 .51671 L p .648 .692 .877 r
F P
0 g
s
.69697 .53866 m .686 .53674 L .70884 .50969 L p .724 .842 .937 r
F P
0 g
s
.70884 .50969 m .72152 .50896 L .69697 .53866 L p .724 .842 .937 r
F P
0 g
s
.25833 .5308 m .27128 .53041 L .30044 .56667 L p .596 .727 .935 r
F P
0 g
s
.31179 .56338 m .30044 .56667 L .27128 .53041 L p .643 .745 .923 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .6 .5331 L p .552 .761 .975 r
F P
0 g
s
.6 .5331 m .60906 .53795 L .5828 .54342 L p .552 .761 .975 r
F P
0 g
s
.39377 .51163 m .40563 .50305 L .42739 .52018 L p .766 .755 .843 r
F P
0 g
s
.43699 .51089 m .42739 .52018 L .40563 .50305 L p .753 .753 .852 r
F P
0 g
s
.502 .509 m .49826 .51671 L .47569 .50699 L p .614 .687 .895 r
F P
0 g
s
.49826 .51671 m .502 .509 L .52291 .51609 L p .577 .675 .907 r
F P
0 g
s
.52291 .51609 m .52255 .52403 L .49826 .51671 L p .577 .675 .907 r
F P
0 g
s
.52255 .52403 m .52291 .51609 L .54403 .52084 L p .536 .676 .928 r
F P
0 g
s
.54403 .52084 m .54708 .5285 L .52255 .52403 L p .536 .676 .928 r
F P
0 g
s
.62697 .54682 m .61805 .5425 L .6415 .53059 L p .637 .844 .98 r
F P
0 g
s
.6415 .53059 m .65273 .53225 L .62697 .54682 L p .637 .844 .98 r
F P
0 g
s
.27128 .53041 m .28436 .52888 L .31179 .56338 L p .643 .745 .923 r
F P
0 g
s
.32325 .55883 m .31179 .56338 L .28436 .52888 L p .686 .761 .909 r
F P
0 g
s
.686 .53674 m .67497 .53514 L .69612 .5109 L p .727 .862 .945 r
F P
0 g
s
.69612 .5109 m .70884 .50969 L .686 .53674 L p .727 .862 .945 r
F P
0 g
s
.40563 .50305 m .41748 .49518 L .43699 .51089 L p .753 .753 .852 r
F P
0 g
s
.4466 .50257 m .43699 .51089 L .41748 .49518 L p .733 .75 .866 r
F P
0 g
s
.4466 .50257 m .45623 .49545 L .47569 .50699 L p .68 .714 .874 r
F P
0 g
s
.48259 .50001 m .47569 .50699 L .45623 .49545 L p .644 .708 .894 r
F P
0 g
s
.47569 .50699 m .48259 .50001 L .502 .509 L p .614 .687 .895 r
F P
0 g
s
.54708 .5285 m .54403 .52084 L .56404 .52294 L p .501 .69 .952 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54708 .5285 L p .501 .69 .952 r
F P
0 g
s
.28436 .52888 m .29755 .52614 L .32325 .55883 L p .686 .761 .909 r
F P
0 g
s
.33484 .55303 m .32325 .55883 L .29755 .52614 L p .721 .773 .893 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59087 .52787 L p .518 .741 .975 r
F P
0 g
s
.59087 .52787 m .6 .5331 L .5766 .53665 L p .518 .741 .975 r
F P
0 g
s
.61805 .5425 m .60906 .53795 L .63018 .52855 L p .607 .831 .985 r
F P
0 g
s
.63018 .52855 m .6415 .53059 L .61805 .5425 L p .607 .831 .985 r
F P
0 g
s
.41748 .49518 m .42931 .48835 L .4466 .50257 L p .733 .75 .866 r
F P
0 g
s
.45623 .49545 m .4466 .50257 L .42931 .48835 L p .703 .745 .884 r
F P
0 g
s
.50576 .50228 m .502 .509 L .48259 .50001 L p .569 .679 .914 r
F P
0 g
s
.502 .509 m .50576 .50228 L .52327 .50883 L p .535 .667 .922 r
F P
0 g
s
.52327 .50883 m .52291 .51609 L .502 .509 L p .535 .667 .922 r
F P
0 g
s
.83625 .53514 m .82343 .53023 L .84485 .48226 L p .577 .657 .891 r
F P
0 g
s
.84485 .48226 m .85906 .48583 L .83625 .53514 L p .577 .657 .891 r
F P
0 g
s
.29755 .52614 m .31084 .52219 L .33484 .55303 L p .721 .773 .893 r
F P
0 g
s
.34652 .54607 m .33484 .55303 L .31084 .52219 L p .749 .781 .879 r
F P
0 g
s
.52291 .51609 m .52327 .50883 L .54095 .5135 L p .497 .665 .937 r
F P
0 g
s
.54095 .5135 m .54403 .52084 L .52291 .51609 L p .497 .665 .937 r
F P
0 g
s
.67497 .53514 m .66389 .5337 L .68336 .51237 L p .723 .876 .952 r
F P
0 g
s
.68336 .51237 m .69612 .5109 L .67497 .53514 L p .723 .876 .952 r
F P
0 g
s
.82343 .53023 m .81061 .52543 L .83069 .47883 L p .582 .659 .89 r
F P
0 g
s
.83069 .47883 m .84485 .48226 L .82343 .53023 L p .582 .659 .89 r
F P
0 g
s
.81061 .52543 m .7978 .52094 L .81659 .47581 L p .594 .669 .892 r
F P
0 g
s
.81659 .47581 m .83069 .47883 L .81061 .52543 L p .594 .669 .892 r
F P
0 g
s
.31084 .52219 m .32421 .51713 L .34652 .54607 L p .749 .781 .879 r
F P
0 g
s
.35827 .53816 m .34652 .54607 L .32421 .51713 L p .769 .787 .868 r
F P
0 g
s
.45623 .49545 m .46589 .48968 L .48259 .50001 L p .644 .708 .894 r
F P
0 g
s
.48953 .49428 m .48259 .50001 L .46589 .48968 L p .596 .698 .915 r
F P
0 g
s
.48259 .50001 m .48953 .49428 L .50576 .50228 L p .569 .679 .914 r
F P
0 g
s
.7978 .52094 m .78502 .51698 L .80256 .47345 L p .611 .685 .895 r
F P
0 g
s
.80256 .47345 m .81659 .47581 L .7978 .52094 L p .611 .685 .895 r
F P
0 g
s
.42931 .48835 m .44115 .48278 L .45623 .49545 L p .703 .745 .884 r
F P
0 g
s
.46589 .48968 m .45623 .49545 L .44115 .48278 L p .663 .737 .904 r
F P
0 g
s
.32421 .51713 m .33764 .51115 L .35827 .53816 L p .769 .787 .868 r
F P
0 g
s
.37008 .52955 m .35827 .53816 L .33764 .51115 L p .782 .791 .86 r
F P
0 g
s
.78502 .51698 m .77227 .51371 L .78862 .47194 L p .633 .707 .9 r
F P
0 g
s
.78862 .47194 m .80256 .47345 L .78502 .51698 L p .633 .707 .9 r
F P
0 g
s
.54403 .52084 m .54095 .5135 L .55769 .51601 L p .464 .673 .954 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54403 .52084 L p .464 .673 .954 r
F P
0 g
s
.33764 .51115 m .35109 .50452 L .37008 .52955 L p .782 .791 .86 r
F P
0 g
s
.38192 .52059 m .37008 .52955 L .35109 .50452 L p .789 .794 .857 r
F P
0 g
s
.60906 .53795 m .6 .5331 L .61878 .52596 L p .573 .811 .989 r
F P
0 g
s
.61878 .52596 m .63018 .52855 L .60906 .53795 L p .573 .811 .989 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58167 .52223 L p .482 .717 .974 r
F P
0 g
s
.58167 .52223 m .59087 .52787 L .57035 .52982 L p .482 .717 .974 r
F P
0 g
s
.35109 .50452 m .36456 .49755 L .38192 .52059 L p .789 .794 .857 r
F P
0 g
s
.39377 .51163 m .38192 .52059 L .36456 .49755 L p .789 .796 .858 r
F P
0 g
s
.77227 .51371 m .75955 .51124 L .77476 .47144 L p .658 .733 .905 r
F P
0 g
s
.77476 .47144 m .78862 .47194 L .77227 .51371 L p .658 .733 .905 r
F P
0 g
s
.66389 .5337 m .65273 .53225 L .67053 .51383 L p .711 .883 .96 r
F P
0 g
s
.67053 .51383 m .68336 .51237 L .66389 .5337 L p .711 .883 .96 r
F P
0 g
s
.36456 .49755 m .37801 .49061 L .39377 .51163 L p .789 .796 .858 r
F P
0 g
s
.40563 .50305 m .39377 .51163 L .37801 .49061 L p .783 .796 .863 r
F P
0 g
s
.50955 .49654 m .50576 .50228 L .48953 .49428 L p .516 .667 .931 r
F P
0 g
s
.50576 .50228 m .50955 .49654 L .52363 .50223 L p .487 .656 .935 r
F P
0 g
s
.52363 .50223 m .52327 .50883 L .50576 .50228 L p .487 .656 .935 r
F P
0 g
s
.75955 .51124 m .74687 .50964 L .76098 .47202 L p .685 .762 .91 r
F P
0 g
s
.76098 .47202 m .77476 .47144 L .75955 .51124 L p .685 .762 .91 r
F P
0 g
s
.37801 .49061 m .39143 .48404 L .40563 .50305 L p .783 .796 .863 r
F P
0 g
s
.41748 .49518 m .40563 .50305 L .39143 .48404 L p .769 .794 .874 r
F P
0 g
s
.52327 .50883 m .52363 .50223 L .53784 .50648 L p .455 .651 .944 r
F P
0 g
s
.53784 .50648 m .54095 .5135 L .52327 .50883 L p .455 .651 .944 r
F P
0 g
s
.44115 .48278 m .45299 .47864 L .46589 .48968 L p .663 .737 .904 r
F P
0 g
s
.47559 .48533 m .46589 .48968 L .45299 .47864 L p .611 .722 .924 r
F P
0 g
s
.46589 .48968 m .47559 .48533 L .48953 .49428 L p .596 .698 .915 r
F P
0 g
s
.49651 .48977 m .48953 .49428 L .47559 .48533 L p .537 .683 .932 r
F P
0 g
s
.48953 .49428 m .49651 .48977 L .50955 .49654 L p .516 .667 .931 r
F P
0 g
s
.39143 .48404 m .40481 .47819 L .41748 .49518 L p .769 .794 .874 r
F P
0 g
s
.42931 .48835 m .41748 .49518 L .40481 .47819 L p .746 .79 .888 r
F P
0 g
s
.22014 .5272 m .20758 .52532 L .18911 .47507 L p .51 .66 .928 r
F P
0 g
s
.74687 .50964 m .73419 .5089 L .74726 .47368 L p .711 .791 .914 r
F P
0 g
s
.74726 .47368 m .76098 .47202 L .74687 .50964 L p .711 .791 .914 r
F P
0 g
s
.6 .5331 m .59087 .52787 L .60729 .5227 L p .535 .785 .99 r
F P
0 g
s
.60729 .5227 m .61878 .52596 L .6 .5331 L p .535 .785 .99 r
F P
0 g
s
.65273 .53225 m .6415 .53059 L .65763 .51502 L p .692 .881 .969 r
F P
0 g
s
.65763 .51502 m .67053 .51383 L .65273 .53225 L p .692 .881 .969 r
F P
0 g
s
.40481 .47819 m .41816 .47336 L .42931 .48835 L p .746 .79 .888 r
F P
0 g
s
.44115 .48278 m .42931 .48835 L .41816 .47336 L p .713 .781 .906 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .5724 .51615 L p .447 .692 .97 r
F P
0 g
s
.5724 .51615 m .58167 .52223 L .56404 .52294 L p .447 .692 .97 r
F P
0 g
s
.54095 .5135 m .53784 .50648 L .55128 .50901 L p .428 .655 .954 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54095 .5135 L p .428 .655 .954 r
F P
0 g
s
.73419 .5089 m .72152 .50896 L .73359 .47632 L p .734 .819 .918 r
F P
0 g
s
.73359 .47632 m .74726 .47368 L .73419 .5089 L p .734 .819 .918 r
F P
0 g
s
.18911 .47507 m .20281 .47866 L .22014 .5272 L p .51 .66 .928 r
F P
0 g
s
.23277 .52894 m .22014 .5272 L .20281 .47866 L p .518 .663 .927 r
F P
0 g
s
.41816 .47336 m .43148 .46977 L .44115 .48278 L p .713 .781 .906 r
F P
0 g
s
.45299 .47864 m .44115 .48278 L .43148 .46977 L p .668 .767 .924 r
F P
0 g
s
.45299 .47864 m .46486 .47598 L .47559 .48533 L p .611 .722 .924 r
F P
0 g
s
.48534 .48236 m .47559 .48533 L .46486 .47598 L p .548 .701 .94 r
F P
0 g
s
.47559 .48533 m .48534 .48236 L .49651 .48977 L p .537 .683 .932 r
F P
0 g
s
.51338 .49167 m .50955 .49654 L .49651 .48977 L p .457 .65 .942 r
F P
0 g
s
.50955 .49654 m .51338 .49167 L .52399 .49623 L p .436 .641 .943 r
F P
0 g
s
.52399 .49623 m .52363 .50223 L .50955 .49654 L p .436 .641 .943 r
F P
0 g
s
.6415 .53059 m .63018 .52855 L .64464 .51569 L p .664 .871 .977 r
F P
0 g
s
.64464 .51569 m .65763 .51502 L .6415 .53059 L p .664 .871 .977 r
F P
0 g
s
.52363 .50223 m .52399 .49623 L .53471 .49974 L p .413 .637 .947 r
F P
0 g
s
.53471 .49974 m .53784 .50648 L .52363 .50223 L p .413 .637 .947 r
F P
0 g
s
.72152 .50896 m .70884 .50969 L .71994 .47979 L p .752 .844 .92 r
F P
0 g
s
.71994 .47979 m .73359 .47632 L .72152 .50896 L p .752 .844 .92 r
F P
0 g
s
.59087 .52787 m .58167 .52223 L .59573 .51868 L p .496 .753 .987 r
F P
0 g
s
.59573 .51868 m .60729 .5227 L .59087 .52787 L p .496 .753 .987 r
F P
0 g
s
.20281 .47866 m .21656 .48212 L .23277 .52894 L p .518 .663 .927 r
F P
0 g
s
.24549 .53024 m .23277 .52894 L .21656 .48212 L p .539 .675 .926 r
F P
0 g
s
.50355 .48636 m .49651 .48977 L .48534 .48236 L p .472 .661 .944 r
F P
0 g
s
.49651 .48977 m .50355 .48636 L .51338 .49167 L p .457 .65 .942 r
F P
0 g
s
.43148 .46977 m .44477 .46758 L .45299 .47864 L p .668 .767 .924 r
F P
0 g
s
.46486 .47598 m .45299 .47864 L .44477 .46758 L p .61 .746 .941 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56306 .50964 L p .414 .667 .965 r
F P
0 g
s
.56306 .50964 m .5724 .51615 L .55769 .51601 L p .414 .667 .965 r
F P
0 g
s
.53784 .50648 m .53471 .49974 L .54482 .50197 L p .394 .637 .953 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53784 .50648 L p .394 .637 .953 r
F P
0 g
s
.21656 .48212 m .23037 .48517 L .24549 .53024 L p .539 .675 .926 r
F P
0 g
s
.25833 .5308 m .24549 .53024 L .23037 .48517 L p .571 .693 .924 r
F P
0 g
s
.70884 .50969 m .69612 .5109 L .70628 .48386 L p .763 .863 .923 r
F P
0 g
s
.70628 .48386 m .71994 .47979 L .70884 .50969 L p .763 .863 .923 r
F P
0 g
s
.46486 .47598 m .47676 .47478 L .48534 .48236 L p .548 .701 .94 r
F P
0 g
s
.49515 .48064 m .48534 .48236 L .47676 .47478 L p .478 .673 .95 r
F P
0 g
s
.48534 .48236 m .49515 .48064 L .50355 .48636 L p .472 .661 .944 r
F P
0 g
s
.63018 .52855 m .61878 .52596 L .63157 .5156 L p .629 .851 .984 r
F P
0 g
s
.63157 .5156 m .64464 .51569 L .63018 .52855 L p .629 .851 .984 r
F P
0 g
s
.44477 .46758 m .45807 .46684 L .46486 .47598 L p .61 .746 .941 r
F P
0 g
s
.47676 .47478 m .46486 .47598 L .45807 .46684 L p .543 .716 .953 r
F P
0 g
s
.58167 .52223 m .5724 .51615 L .58409 .51388 L p .457 .72 .981 r
F P
0 g
s
.58409 .51388 m .59573 .51868 L .58167 .52223 L p .457 .72 .981 r
F P
0 g
s
.23037 .48517 m .24425 .48757 L .25833 .5308 L p .571 .693 .924 r
F P
0 g
s
.27128 .53041 m .25833 .5308 L .24425 .48757 L p .608 .715 .921 r
F P
0 g
s
.69612 .5109 m .68336 .51237 L .6926 .48825 L p .767 .877 .927 r
F P
0 g
s
.6926 .48825 m .70628 .48386 L .69612 .5109 L p .767 .877 .927 r
F P
0 g
s
.51725 .48752 m .51338 .49167 L .50355 .48636 L p .4 .631 .947 r
F P
0 g
s
.51338 .49167 m .51725 .48752 L .52436 .49071 L p .388 .625 .947 r
F P
0 g
s
.52436 .49071 m .52399 .49623 L .51338 .49167 L p .388 .625 .947 r
F P
0 g
s
.52399 .49623 m .52436 .49071 L .53154 .49321 L p .375 .622 .948 r
F P
0 g
s
.53154 .49321 m .53471 .49974 L .52399 .49623 L p .375 .622 .948 r
F P
0 g
s
.51066 .48386 m .50355 .48636 L .49515 .48064 L p .408 .637 .949 r
F P
0 g
s
.50355 .48636 m .51066 .48386 L .51725 .48752 L p .4 .631 .947 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55366 .50275 L p .384 .644 .959 r
F P
0 g
s
.55366 .50275 m .56306 .50964 L .55128 .50901 L p .384 .644 .959 r
F P
0 g
s
.24425 .48757 m .25822 .48909 L .27128 .53041 L p .608 .715 .921 r
F P
0 g
s
.28436 .52888 m .27128 .53041 L .25822 .48909 L p .647 .739 .916 r
F P
0 g
s
.61878 .52596 m .60729 .5227 L .61843 .51457 L p .587 .823 .989 r
F P
0 g
s
.61843 .51457 m .63157 .5156 L .61878 .52596 L p .587 .823 .989 r
F P
0 g
s
.38596 .46433 m .40003 .46098 L .40481 .47819 L p .765 .835 .906 r
F P
0 g
s
.40481 .47819 m .39143 .48404 L .38596 .46433 L p .765 .835 .906 r
F P
0 g
s
.41816 .47336 m .40481 .47819 L .40003 .46098 L p .738 .828 .92 r
F P
0 g
s
.37183 .46833 m .38596 .46433 L .39143 .48404 L p .782 .837 .894 r
F P
0 g
s
.39143 .48404 m .37801 .49061 L .37183 .46833 L p .782 .837 .894 r
F P
0 g
s
.40003 .46098 m .41403 .45855 L .41816 .47336 L p .738 .828 .92 r
F P
0 g
s
.43148 .46977 m .41816 .47336 L .41403 .45855 L p .7 .814 .936 r
F P
0 g
s
.45807 .46684 m .47137 .46751 L .47676 .47478 L p .543 .716 .953 r
F P
0 g
s
.48872 .47489 m .47676 .47478 L .47137 .46751 L p .472 .681 .957 r
F P
0 g
s
.47676 .47478 m .48872 .47489 L .49515 .48064 L p .478 .673 .95 r
F P
0 g
s
.35763 .47268 m .37183 .46833 L .37801 .49061 L p .79 .836 .887 r
F P
0 g
s
.37801 .49061 m .36456 .49755 L .35763 .47268 L p .79 .836 .887 r
F P
0 g
s
.25822 .48909 m .27228 .4896 L .28436 .52888 L p .647 .739 .916 r
F P
0 g
s
.29755 .52614 m .28436 .52888 L .27228 .4896 L p .685 .761 .909 r
F P
0 g
s
.5724 .51615 m .56306 .50964 L .57239 .50831 L p .42 .686 .973 r
F P
0 g
s
.57239 .50831 m .58409 .51388 L .5724 .51615 L p .42 .686 .973 r
F P
0 g
s
.53471 .49974 m .53154 .49321 L .5383 .49486 L p .365 .622 .951 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53471 .49974 L p .365 .622 .951 r
F P
0 g
s
.41403 .45855 m .42798 .45726 L .43148 .46977 L p .7 .814 .936 r
F P
0 g
s
.44477 .46758 m .43148 .46977 L .42798 .45726 L p .65 .792 .95 r
F P
0 g
s
.34339 .47706 m .35763 .47268 L .36456 .49755 L p .79 .831 .884 r
F P
0 g
s
.36456 .49755 m .35109 .50452 L .34339 .47706 L p .79 .831 .884 r
F P
0 g
s
.50504 .47996 m .49515 .48064 L .48872 .47489 L p .41 .643 .952 r
F P
0 g
s
.49515 .48064 m .50504 .47996 L .51066 .48386 L p .408 .637 .949 r
F P
0 g
s
.68336 .51237 m .67053 .51383 L .67888 .49264 L p .763 .885 .932 r
F P
0 g
s
.67888 .49264 m .6926 .48825 L .68336 .51237 L p .763 .885 .932 r
F P
0 g
s
.27228 .4896 m .28642 .48901 L .29755 .52614 L p .685 .761 .909 r
F P
0 g
s
.31084 .52219 m .29755 .52614 L .28642 .48901 L p .719 .781 .902 r
F P
0 g
s
.32913 .48114 m .34339 .47706 L .35109 .50452 L p .782 .823 .884 r
F P
0 g
s
.35109 .50452 m .33764 .51115 L .32913 .48114 L p .782 .823 .884 r
F P
0 g
s
.42798 .45726 m .44187 .45722 L .44477 .46758 L p .65 .792 .95 r
F P
0 g
s
.45807 .46684 m .44477 .46758 L .44187 .45722 L p .59 .762 .961 r
F P
0 g
s
.31486 .48465 m .32913 .48114 L .33764 .51115 L p .768 .812 .888 r
F P
0 g
s
.33764 .51115 m .32421 .51713 L .31486 .48465 L p .768 .812 .888 r
F P
0 g
s
.28642 .48901 m .30062 .48733 L .31084 .52219 L p .719 .781 .902 r
F P
0 g
s
.32421 .51713 m .31084 .52219 L .30062 .48733 L p .747 .799 .894 r
F P
0 g
s
.30062 .48733 m .31486 .48465 L .32421 .51713 L p .747 .799 .894 r
F P
0 g
s
.60729 .5227 m .59573 .51868 L .60521 .51249 L p .541 .788 .989 r
F P
0 g
s
.60521 .51249 m .61843 .51457 L .60729 .5227 L p .541 .788 .989 r
F P
0 g
s
.44187 .45722 m .45573 .4585 L .45807 .46684 L p .59 .762 .961 r
F P
0 g
s
.47137 .46751 m .45807 .46684 L .45573 .4585 L p .523 .725 .965 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .5442 .49554 L p .359 .625 .953 r
F P
0 g
s
.5442 .49554 m .55366 .50275 L .54482 .50197 L p .359 .625 .953 r
F P
0 g
s
.67053 .51383 m .65763 .51502 L .66511 .4967 L p .75 .885 .941 r
F P
0 g
s
.66511 .4967 m .67888 .49264 L .67053 .51383 L p .75 .885 .941 r
F P
0 g
s
.47137 .46751 m .48472 .46947 L .48872 .47489 L p .472 .681 .957 r
F P
0 g
s
.50076 .47608 m .48872 .47489 L .48472 .46947 L p .406 .646 .955 r
F P
0 g
s
.48872 .47489 m .50076 .47608 L .50504 .47996 L p .41 .643 .952 r
F P
0 g
s
.56306 .50964 m .55366 .50275 L .56064 .50204 L p .388 .656 .964 r
F P
0 g
s
.56064 .50204 m .57239 .50831 L .56306 .50964 L p .388 .656 .964 r
F P
0 g
s
.52116 .48387 m .51725 .48752 L .51066 .48386 L p .354 .613 .948 r
F P
0 g
s
.51725 .48752 m .52116 .48387 L .52474 .48551 L p .35 .611 .948 r
F P
0 g
s
.52474 .48551 m .52436 .49071 L .51725 .48752 L p .35 .611 .948 r
F P
0 g
s
.52436 .49071 m .52474 .48551 L .52834 .48682 L p .345 .61 .948 r
F P
0 g
s
.52834 .48682 m .53154 .49321 L .52436 .49071 L p .345 .61 .948 r
F P
0 g
s
.51785 .482 m .51066 .48386 L .50504 .47996 L p .356 .615 .948 r
F P
0 g
s
.51066 .48386 m .51785 .482 L .52116 .48387 L p .354 .613 .948 r
F P
0 g
s
.59573 .51868 m .58409 .51388 L .59193 .50931 L p .493 .748 .985 r
F P
0 g
s
.59193 .50931 m .60521 .51249 L .59573 .51868 L p .493 .748 .985 r
F P
0 g
s
.45573 .4585 m .46958 .46105 L .47137 .46751 L p .523 .725 .965 r
F P
0 g
s
.48472 .46947 m .47137 .46751 L .46958 .46105 L p .456 .684 .964 r
F P
0 g
s
.53154 .49321 m .52834 .48682 L .53174 .48769 L p .342 .609 .948 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53154 .49321 L p .342 .609 .948 r
F P
0 g
s
.51503 .48002 m .50504 .47996 L .50076 .47608 L p .357 .617 .949 r
F P
0 g
s
.50504 .47996 m .51503 .48002 L .51785 .482 L p .356 .615 .948 r
F P
0 g
s
.65763 .51502 m .64464 .51569 L .65126 .50012 L p .727 .878 .951 r
F P
0 g
s
.65126 .50012 m .66511 .4967 L .65763 .51502 L p .727 .878 .951 r
F P
0 g
s
.55366 .50275 m .5442 .49554 L .54884 .4952 L p .361 .63 .956 r
F P
0 g
s
.54884 .4952 m .56064 .50204 L .55366 .50275 L p .361 .63 .956 r
F P
0 g
s
.58409 .51388 m .57239 .50831 L .57861 .50506 L p .447 .707 .978 r
F P
0 g
s
.57861 .50506 m .59193 .50931 L .58409 .51388 L p .447 .707 .978 r
F P
0 g
s
.46958 .46105 m .48342 .46476 L .48472 .46947 L p .456 .684 .964 r
F P
0 g
s
.49811 .47249 m .48472 .46947 L .48342 .46476 L p .396 .647 .958 r
F P
0 g
s
.48472 .46947 m .49811 .47249 L .50076 .47608 L p .406 .646 .955 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53469 .48808 L p .34 .61 .949 r
F P
0 g
s
.53469 .48808 m .5442 .49554 L .5383 .49486 L p .34 .61 .949 r
F P
0 g
s
.51289 .47806 m .50076 .47608 L .49811 .47249 L p .355 .617 .95 r
F P
0 g
s
.50076 .47608 m .51289 .47806 L .51503 .48002 L p .357 .617 .949 r
F P
0 g
s
.64464 .51569 m .63157 .5156 L .63735 .5026 L p .694 .863 .962 r
F P
0 g
s
.63735 .5026 m .65126 .50012 L .64464 .51569 L p .694 .863 .962 r
F P
0 g
s
.57239 .50831 m .56064 .50204 L .56525 .49985 L p .405 .669 .968 r
F P
0 g
s
.56525 .49985 m .57861 .50506 L .57239 .50831 L p .405 .669 .968 r
F P
0 g
s
.80256 .47345 m .78862 .47194 L .78745 .42885 L p .617 .71 .911 r
F P
0 g
s
.78862 .47194 m .77476 .47144 L .77335 .43054 L p .651 .735 .911 r
F P
0 g
s
.77335 .43054 m .78745 .42885 L .78862 .47194 L p .651 .735 .911 r
F P
0 g
s
.77476 .47144 m .76098 .47202 L .75936 .43345 L p .685 .762 .91 r
F P
0 g
s
.75936 .43345 m .77335 .43054 L .77476 .47144 L p .685 .762 .91 r
F P
0 g
s
.81659 .47581 m .80256 .47345 L .8017 .42828 L p .588 .687 .91 r
F P
0 g
s
.78745 .42885 m .8017 .42828 L .80256 .47345 L p .617 .71 .911 r
F P
0 g
s
.43106 .44609 m .44461 .44828 L .44187 .45722 L p .609 .8 .973 r
F P
0 g
s
.44187 .45722 m .42798 .45726 L .43106 .44609 L p .609 .8 .973 r
F P
0 g
s
.45573 .4585 m .44187 .45722 L .44461 .44828 L p .551 .764 .977 r
F P
0 g
s
.76098 .47202 m .74726 .47368 L .74548 .43755 L p .718 .787 .906 r
F P
0 g
s
.74548 .43755 m .75936 .43345 L .76098 .47202 L p .718 .787 .906 r
F P
0 g
s
.52511 .48046 m .52116 .48387 L .51785 .482 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52474 .48551 L .52116 .48387 L closepath p .328 .601 .946 r
F P
0 g
s
.5442 .49554 m .53469 .48808 L .53699 .48794 L p .341 .612 .95 r
F P
0 g
s
.53699 .48794 m .54884 .4952 L .5442 .49554 L p .341 .612 .95 r
F P
0 g
s
.48342 .46476 m .49728 .46942 L .49811 .47249 L p .396 .647 .958 r
F P
0 g
s
.51157 .47627 m .49811 .47249 L .49728 .46942 L p .352 .617 .951 r
F P
0 g
s
.49811 .47249 m .51157 .47627 L .51289 .47806 L p .355 .617 .95 r
F P
0 g
s
.44461 .44828 m .4581 .45154 L .45573 .4585 L p .551 .764 .977 r
F P
0 g
s
.46958 .46105 m .45573 .4585 L .4581 .45154 L p .49 .722 .974 r
F P
0 g
s
.41743 .44493 m .43106 .44609 L .42798 .45726 L p .66 .83 .965 r
F P
0 g
s
.42798 .45726 m .41403 .45855 L .41743 .44493 L p .66 .83 .965 r
F P
0 g
s
.52511 .48046 m .51785 .482 L .51503 .48002 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52834 .48682 L .52474 .48551 L closepath p .328 .601 .946 r
F P
0 g
s
.63157 .5156 m .61843 .51457 L .62338 .50394 L p .651 .838 .972 r
F P
0 g
s
.62338 .50394 m .63735 .5026 L .63157 .5156 L p .651 .838 .972 r
F P
0 g
s
.83069 .47883 m .81659 .47581 L .81607 .42867 L p .565 .67 .909 r
F P
0 g
s
.8017 .42828 m .81607 .42867 L .81659 .47581 L p .588 .687 .91 r
F P
0 g
s
.74726 .47368 m .73359 .47632 L .73168 .44277 L p .746 .809 .902 r
F P
0 g
s
.73168 .44277 m .74548 .43755 L .74726 .47368 L p .746 .809 .902 r
F P
0 g
s
.4581 .45154 m .47154 .45584 L .46958 .46105 L p .49 .722 .974 r
F P
0 g
s
.48342 .46476 m .46958 .46105 L .47154 .45584 L p .432 .68 .968 r
F P
0 g
s
.40373 .44469 m .41743 .44493 L .41403 .45855 L p .702 .85 .953 r
F P
0 g
s
.41403 .45855 m .40003 .46098 L .40373 .44469 L p .702 .85 .953 r
F P
0 g
s
.52511 .48046 m .51503 .48002 L .51289 .47806 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48682 L closepath p .328 .601 .946 r
F P
0 g
s
.84485 .48226 m .83069 .47883 L .83057 .42981 L p .55 .66 .909 r
F P
0 g
s
.81607 .42867 m .83057 .42981 L .83069 .47883 L p .565 .67 .909 r
F P
0 g
s
.56064 .50204 m .54884 .4952 L .55188 .49385 L p .369 .637 .958 r
F P
0 g
s
.55188 .49385 m .56525 .49985 L .56064 .50204 L p .369 .637 .958 r
F P
0 g
s
.47154 .45584 m .48495 .46107 L .48342 .46476 L p .432 .68 .968 r
F P
0 g
s
.49728 .46942 m .48342 .46476 L .48495 .46107 L p .383 .643 .959 r
F P
0 g
s
.73359 .47632 m .71994 .47979 L .71795 .4489 L p .769 .827 .898 r
F P
0 g
s
.71795 .4489 m .73168 .44277 L .73359 .47632 L p .769 .827 .898 r
F P
0 g
s
.38993 .44521 m .40373 .44469 L .40003 .46098 L p .734 .862 .941 r
F P
0 g
s
.40003 .46098 m .38596 .46433 L .38993 .44521 L p .734 .862 .941 r
F P
0 g
s
.52511 .48046 m .51289 .47806 L .51157 .47627 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53469 .48808 L .53174 .48769 L closepath p .328 .601 .946 r
F P
0 g
s
.85906 .48583 m .84485 .48226 L .84517 .43141 L p .544 .657 .909 r
F P
0 g
s
.83057 .42981 m .84517 .43141 L .84485 .48226 L p .55 .66 .909 r
F P
0 g
s
.61843 .51457 m .60521 .51249 L .60936 .50399 L p .599 .805 .979 r
F P
0 g
s
.60936 .50399 m .62338 .50394 L .61843 .51457 L p .599 .805 .979 r
F P
0 g
s
.84517 .43141 m .85986 .43317 L .85906 .48583 L p .544 .657 .909 r
F P
0 g
s
.54884 .4952 m .53699 .48794 L .5385 .4873 L p .343 .614 .951 r
F P
0 g
s
.5385 .4873 m .55188 .49385 L .54884 .4952 L p .343 .614 .951 r
F P
0 g
s
.48495 .46107 m .49835 .46708 L .49728 .46942 L p .383 .643 .959 r
F P
0 g
s
.51118 .47476 m .49728 .46942 L .49835 .46708 L p .348 .616 .951 r
F P
0 g
s
.49728 .46942 m .51118 .47476 L .51157 .47627 L p .352 .617 .951 r
F P
0 g
s
.37605 .44626 m .38993 .44521 L .38596 .46433 L p .755 .866 .93 r
F P
0 g
s
.38596 .46433 m .37183 .46833 L .37605 .44626 L p .755 .866 .93 r
F P
0 g
s
.52511 .48046 m .51157 .47627 L .51118 .47476 L closepath p .328 .601 .946 r
F P
0 g
s
.71994 .47979 m .70628 .48386 L .70424 .45571 L p .784 .841 .895 r
F P
0 g
s
.70424 .45571 m .71795 .4489 L .71994 .47979 L p .784 .841 .895 r
F P
0 g
s
.52511 .48046 m .53699 .48794 L .53469 .48808 L closepath p .328 .601 .946 r
F P
0 g
s
.60521 .51249 m .59193 .50931 L .59531 .50269 L p .542 .766 .98 r
F P
0 g
s
.59531 .50269 m .60936 .50399 L .60521 .51249 L p .542 .766 .98 r
F P
0 g
s
.36209 .4476 m .37605 .44626 L .37183 .46833 L p .767 .864 .921 r
F P
0 g
s
.37183 .46833 m .35763 .47268 L .36209 .4476 L p .767 .864 .921 r
F P
0 g
s
.49835 .46708 m .51173 .47363 L .51118 .47476 L p .348 .616 .951 r
F P
0 g
s
.52511 .48046 m .51118 .47476 L .51173 .47363 L closepath p .328 .601 .946 r
F P
0 g
s
.70628 .48386 m .6926 .48825 L .69054 .46286 L p .792 .851 .895 r
F P
0 g
s
.69054 .46286 m .70424 .45571 L .70628 .48386 L p .792 .851 .895 r
F P
0 g
s
.52511 .48046 m .5385 .4873 L .53699 .48794 L closepath p .328 .601 .946 r
F P
0 g
s
.59193 .50931 m .57861 .50506 L .58124 .50008 L p .484 .722 .976 r
F P
0 g
s
.58124 .50008 m .59531 .50269 L .59193 .50931 L p .484 .722 .976 r
F P
0 g
s
.57861 .50506 m .56525 .49985 L .56716 .49631 L p .429 .68 .968 r
F P
0 g
s
.56716 .49631 m .58124 .50008 L .57861 .50506 L p .429 .68 .968 r
F P
0 g
s
.56525 .49985 m .55188 .49385 L .55311 .49158 L p .382 .643 .959 r
F P
0 g
s
.55311 .49158 m .56716 .49631 L .56525 .49985 L p .382 .643 .959 r
F P
0 g
s
.50125 .46564 m .5132 .47296 L .51173 .47363 L p .344 .614 .951 r
F P
0 g
s
.51173 .47363 m .49835 .46708 L .50125 .46564 L p .344 .614 .951 r
F P
0 g
s
.52511 .48046 m .51173 .47363 L .5132 .47296 L closepath p .328 .601 .946 r
F P
0 g
s
.34805 .44895 m .36209 .4476 L .35763 .47268 L p .77 .857 .915 r
F P
0 g
s
.35763 .47268 m .34339 .47706 L .34805 .44895 L p .77 .857 .915 r
F P
0 g
s
.55188 .49385 m .5385 .4873 L .53909 .48619 L p .347 .616 .951 r
F P
0 g
s
.53909 .48619 m .55311 .49158 L .55188 .49385 L p .347 .616 .951 r
F P
0 g
s
.52511 .48046 m .5353 .48092 L .53744 .48289 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53246 .47891 L .5353 .48092 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52912 .47702 L .53246 .47891 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .5255 .47536 L .52912 .47702 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .52185 .47405 L .5255 .47536 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47405 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .51549 .47281 L .51844 .47318 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .5132 .47296 L .51549 .47281 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53909 .48619 L .5385 .4873 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53873 .48468 L .53909 .48619 L closepath p .328 .601 .946 r
F P
0 g
s
.52511 .48046 m .53744 .48289 L .53873 .48468 L closepath p .328 .601 .946 r
F P
0 g
s
.48925 .45869 m .50125 .46564 L .49835 .46708 L p .371 .638 .958 r
F P
0 g
s
.49835 .46708 m .48495 .46107 L .48925 .45869 L p .371 .638 .958 r
F P
0 g
s
.6926 .48825 m .67888 .49264 L .67683 .47001 L p .792 .856 .898 r
F P
0 g
s
.67683 .47001 m .69054 .46286 L .6926 .48825 L p .792 .856 .898 r
F P
0 g
s
.47721 .45225 m .48925 .45869 L .48495 .46107 L p .408 .67 .968 r
F P
0 g
s
.48495 .46107 m .47154 .45584 L .47721 .45225 L p .408 .67 .968 r
F P
0 g
s
.46511 .44647 m .47721 .45225 L .47154 .45584 L p .452 .707 .977 r
F P
0 g
s
.47154 .45584 m .4581 .45154 L .46511 .44647 L p .452 .707 .977 r
F P
0 g
s
.45294 .4414 m .46511 .44647 L .4581 .45154 L p .502 .747 .983 r
F P
0 g
s
.4581 .45154 m .44461 .44828 L .45294 .4414 L p .502 .747 .983 r
F P
0 g
s
.5058 .46521 m .51549 .47281 L .5132 .47296 L p .341 .612 .95 r
F P
0 g
s
.5132 .47296 m .50125 .46564 L .5058 .46521 L p .341 .612 .95 r
F P
0 g
s
.33396 .45005 m .34805 .44895 L .34339 .47706 L p .765 .845 .912 r
F P
0 g
s
.34339 .47706 m .32913 .48114 L .33396 .45005 L p .765 .845 .912 r
F P
0 g
s
.55311 .49158 m .53909 .48619 L .53873 .48468 L p .352 .617 .951 r
F P
0 g
s
.67888 .49264 m .66511 .4967 L .66309 .47677 L p .783 .857 .906 r
F P
0 g
s
.66309 .47677 m .67683 .47001 L .67888 .49264 L p .783 .857 .906 r
F P
0 g
s
.4407 .43708 m .45294 .4414 L .44461 .44828 L p .552 .785 .985 r
F P
0 g
s
.44461 .44828 m .43106 .44609 L .4407 .43708 L p .552 .785 .985 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51549 .47281 L p .34 .61 .949 r
F P
0 g
s
.51549 .47281 m .5058 .46521 L .5117 .46583 L p .34 .61 .949 r
F P
0 g
s
.31982 .45068 m .33396 .45005 L .32913 .48114 L p .754 .829 .91 r
F P
0 g
s
.32913 .48114 m .31486 .48465 L .31982 .45068 L p .754 .829 .91 r
F P
0 g
s
.53873 .48468 m .55243 .48853 L .55311 .49158 L p .352 .617 .951 r
F P
0 g
s
.55243 .48853 m .53873 .48468 L .53744 .48289 L p .355 .617 .95 r
F P
0 g
s
.66511 .4967 m .65126 .50012 L .64931 .48281 L p .764 .852 .917 r
F P
0 g
s
.64931 .48281 m .66309 .47677 L .66511 .4967 L p .764 .852 .917 r
F P
0 g
s
.56716 .49631 m .55311 .49158 L .55243 .48853 L p .395 .646 .958 r
F P
0 g
s
.49605 .45777 m .5058 .46521 L .50125 .46564 L p .362 .631 .956 r
F P
0 g
s
.50125 .46564 m .48925 .45869 L .49605 .45777 L p .362 .631 .956 r
F P
0 g
s
.20281 .47866 m .18911 .47507 L .19318 .42214 L p .555 .662 .908 r
F P
0 g
s
.42837 .43347 m .4407 .43708 L .43106 .44609 L p .6 .818 .983 r
F P
0 g
s
.43106 .44609 m .41743 .44493 L .42837 .43347 L p .6 .818 .983 r
F P
0 g
s
.19318 .42214 m .20717 .42743 L .20281 .47866 L p .555 .662 .908 r
F P
0 g
s
.21656 .48212 m .20281 .47866 L .20717 .42743 L p .562 .664 .906 r
F P
0 g
s
.51856 .46746 m .52185 .47405 L .51844 .47318 L p .342 .609 .948 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51856 .46746 L p .342 .609 .948 r
F P
0 g
s
.53744 .48289 m .54987 .48492 L .55243 .48853 L p .355 .617 .95 r
F P
0 g
s
.54987 .48492 m .53744 .48289 L .5353 .48092 L p .357 .616 .949 r
F P
0 g
s
.65126 .50012 m .63735 .5026 L .63549 .4878 L p .735 .842 .93 r
F P
0 g
s
.63549 .4878 m .64931 .48281 L .65126 .50012 L p .735 .842 .93 r
F P
0 g
s
.30567 .45062 m .31982 .45068 L .31486 .48465 L p .735 .809 .91 r
F P
0 g
s
.31486 .48465 m .30062 .48733 L .30567 .45062 L p .735 .809 .91 r
F P
0 g
s
.58124 .50008 m .56716 .49631 L .5662 .49165 L p .453 .684 .965 r
F P
0 g
s
.55243 .48853 m .5662 .49165 L .56716 .49631 L p .395 .646 .958 r
F P
0 g
s
.48624 .45057 m .49605 .45777 L .48925 .45869 L p .39 .656 .964 r
F P
0 g
s
.48925 .45869 m .47721 .45225 L .48624 .45057 L p .39 .656 .964 r
F P
0 g
s
.20717 .42743 m .22116 .4326 L .21656 .48212 L p .562 .664 .906 r
F P
0 g
s
.23037 .48517 m .21656 .48212 L .22116 .4326 L p .577 .674 .906 r
F P
0 g
s
.52588 .46999 m .5255 .47536 L .52185 .47405 L p .345 .61 .948 r
F P
0 g
s
.52185 .47405 m .51856 .46746 L .52588 .46999 L p .345 .61 .948 r
F P
0 g
s
.5353 .48092 m .5456 .48098 L .54987 .48492 L p .357 .616 .949 r
F P
0 g
s
.5456 .48098 m .5353 .48092 L .53246 .47891 L p .356 .615 .948 r
F P
0 g
s
.63735 .5026 m .62338 .50394 L .62164 .49149 L p .695 .824 .944 r
F P
0 g
s
.62164 .49149 m .63549 .4878 L .63735 .5026 L p .695 .824 .944 r
F P
0 g
s
.59531 .50269 m .58124 .50008 L .58003 .4937 L p .518 .726 .968 r
F P
0 g
s
.5662 .49165 m .58003 .4937 L .58124 .50008 L p .453 .684 .965 r
F P
0 g
s
.29152 .44973 m .30567 .45062 L .30062 .48733 L p .712 .786 .91 r
F P
0 g
s
.30062 .48733 m .28642 .48901 L .29152 .44973 L p .712 .786 .91 r
F P
0 g
s
.22116 .4326 m .23517 .43742 L .23037 .48517 L p .577 .674 .906 r
F P
0 g
s
.24425 .48757 m .23037 .48517 L .23517 .43742 L p .599 .691 .907 r
F P
0 g
s
.41594 .4305 m .42837 .43347 L .41743 .44493 L p .642 .843 .977 r
F P
0 g
s
.41743 .44493 m .40373 .44469 L .41594 .4305 L p .642 .843 .977 r
F P
0 g
s
.53317 .47324 m .52912 .47702 L .5255 .47536 L p .35 .611 .948 r
F P
0 g
s
.5255 .47536 m .52588 .46999 L .53317 .47324 L p .35 .611 .948 r
F P
0 g
s
.53246 .47891 m .5399 .47699 L .5456 .48098 L p .356 .615 .948 r
F P
0 g
s
.5399 .47699 m .53246 .47891 L .52912 .47702 L p .353 .613 .948 r
F P
0 g
s
.62338 .50394 m .60936 .50399 L .60776 .49372 L p .644 .798 .957 r
F P
0 g
s
.60776 .49372 m .62164 .49149 L .62338 .50394 L p .644 .798 .957 r
F P
0 g
s
.60936 .50399 m .59531 .50269 L .59389 .49444 L p .584 .765 .965 r
F P
0 g
s
.58003 .4937 m .59389 .49444 L .59531 .50269 L p .518 .726 .968 r
F P
0 g
s
.5662 .49165 m .55243 .48853 L .54987 .48492 L p .405 .646 .955 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .5058 .46521 L p .36 .625 .953 r
F P
0 g
s
.5058 .46521 m .49605 .45777 L .50491 .45842 L p .36 .625 .953 r
F P
0 g
s
.52912 .47702 m .53317 .47324 L .5399 .47699 L p .353 .613 .948 r
F P
0 g
s
.27739 .44794 m .29152 .44973 L .28642 .48901 L p .685 .762 .91 r
F P
0 g
s
.28642 .48901 m .27228 .4896 L .27739 .44794 L p .685 .762 .91 r
F P
0 g
s
.59389 .49444 m .60776 .49372 L .60936 .50399 L p .584 .765 .965 r
F P
0 g
s
.23517 .43742 m .24921 .4417 L .24425 .48757 L p .599 .691 .907 r
F P
0 g
s
.25822 .48909 m .24425 .48757 L .24921 .4417 L p .626 .712 .908 r
F P
0 g
s
.26328 .44525 m .27739 .44794 L .27228 .4896 L p .655 .736 .909 r
F P
0 g
s
.27228 .4896 m .25822 .48909 L .26328 .44525 L p .655 .736 .909 r
F P
0 g
s
.24921 .4417 m .26328 .44525 L .25822 .48909 L p .626 .712 .908 r
F P
0 g
s
.47637 .44368 m .48624 .45057 L .47721 .45225 L p .425 .687 .973 r
F P
0 g
s
.47721 .45225 m .46511 .44647 L .47637 .44368 L p .425 .687 .973 r
F P
0 g
s
.40343 .42806 m .41594 .4305 L .40373 .44469 L p .677 .859 .969 r
F P
0 g
s
.40373 .44469 m .38993 .44521 L .40343 .42806 L p .677 .859 .969 r
F P
0 g
s
.54987 .48492 m .5624 .48618 L .5662 .49165 L p .405 .646 .955 r
F P
0 g
s
.5624 .48618 m .54987 .48492 L .5456 .48098 L p .409 .642 .952 r
F P
0 g
s
.51523 .4606 m .51856 .46746 L .5117 .46583 L p .365 .622 .951 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51523 .4606 L p .365 .622 .951 r
F P
0 g
s
.58003 .4937 m .5662 .49165 L .5624 .48618 L p .469 .681 .958 r
F P
0 g
s
.46642 .43712 m .47637 .44368 L .46511 .44647 L p .464 .72 .98 r
F P
0 g
s
.46511 .44647 m .45294 .4414 L .46642 .43712 L p .464 .72 .98 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49605 .45777 L p .386 .644 .959 r
F P
0 g
s
.49605 .45777 m .48624 .45057 L .49806 .45095 L p .386 .644 .959 r
F P
0 g
s
.39082 .42597 m .40343 .42806 L .38993 .44521 L p .703 .867 .959 r
F P
0 g
s
.38993 .44521 m .37605 .44626 L .39082 .42597 L p .703 .867 .959 r
F P
0 g
s
.5456 .48098 m .55599 .48028 L .5624 .48618 L p .409 .642 .952 r
F P
0 g
s
.55599 .48028 m .5456 .48098 L .5399 .47699 L p .407 .637 .949 r
F P
0 g
s
.52627 .46416 m .52588 .46999 L .51856 .46746 L p .375 .622 .948 r
F P
0 g
s
.51856 .46746 m .51523 .4606 L .52627 .46416 L p .375 .622 .948 r
F P
0 g
s
.59389 .49444 m .58003 .4937 L .575 .48633 L p .539 .717 .955 r
F P
0 g
s
.5624 .48618 m .575 .48633 L .58003 .4937 L p .469 .681 .958 r
F P
0 g
s
.45639 .43092 m .46642 .43712 L .45294 .4414 L p .505 .753 .985 r
F P
0 g
s
.45294 .4414 m .4407 .43708 L .45639 .43092 L p .505 .753 .985 r
F P
0 g
s
.5399 .47699 m .54741 .47437 L .55599 .48028 L p .407 .637 .949 r
F P
0 g
s
.54741 .47437 m .5399 .47699 L .53317 .47324 L p .399 .63 .948 r
F P
0 g
s
.53726 .46886 m .53317 .47324 L .52588 .46999 L p .387 .625 .947 r
F P
0 g
s
.52588 .46999 m .52627 .46416 L .53726 .46886 L p .387 .625 .947 r
F P
0 g
s
.53317 .47324 m .53726 .46886 L .54741 .47437 L p .399 .63 .948 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48624 .45057 L p .416 .667 .964 r
F P
0 g
s
.48624 .45057 m .47637 .44368 L .49116 .44341 L p .416 .667 .964 r
F P
0 g
s
.575 .48633 m .5624 .48618 L .55599 .48028 L p .475 .673 .951 r
F P
0 g
s
.37811 .42407 m .39082 .42597 L .37605 .44626 L p .721 .867 .95 r
F P
0 g
s
.37605 .44626 m .36209 .4476 L .37811 .42407 L p .721 .867 .95 r
F P
0 g
s
.51186 .45338 m .51523 .4606 L .50491 .45842 L p .394 .637 .953 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51186 .45338 L p .394 .637 .953 r
F P
0 g
s
.60776 .49372 m .59389 .49444 L .58767 .48512 L p .605 .749 .946 r
F P
0 g
s
.575 .48633 m .58767 .48512 L .59389 .49444 L p .539 .717 .955 r
F P
0 g
s
.44629 .42507 m .45639 .43092 L .4407 .43708 L p .546 .782 .986 r
F P
0 g
s
.4407 .43708 m .42837 .43347 L .44629 .42507 L p .546 .782 .986 r
F P
0 g
s
.74548 .43755 m .73168 .44277 L .71518 .41064 L p .749 .791 .887 r
F P
0 g
s
.73168 .44277 m .71795 .4489 L .70234 .41918 L p .771 .801 .877 r
F P
0 g
s
.70234 .41918 m .71518 .41064 L .73168 .44277 L p .771 .801 .877 r
F P
0 g
s
.75936 .43345 m .74548 .43755 L .72811 .40305 L p .72 .778 .898 r
F P
0 g
s
.71518 .41064 m .72811 .40305 L .74548 .43755 L p .749 .791 .887 r
F P
0 g
s
.71795 .4489 m .70424 .45571 L .68956 .42839 L p .785 .807 .87 r
F P
0 g
s
.68956 .42839 m .70234 .41918 L .71795 .4489 L p .785 .807 .87 r
F P
0 g
s
.62164 .49149 m .60776 .49372 L .60038 .48237 L p .663 .773 .931 r
F P
0 g
s
.58767 .48512 m .60038 .48237 L .60776 .49372 L p .605 .749 .946 r
F P
0 g
s
.70424 .45571 m .69054 .46286 L .67681 .43795 L p .793 .811 .867 r
F P
0 g
s
.67681 .43795 m .68956 .42839 L .70424 .45571 L p .793 .811 .867 r
F P
0 g
s
.77335 .43054 m .75936 .43345 L .74115 .39659 L p .685 .761 .909 r
F P
0 g
s
.72811 .40305 m .74115 .39659 L .75936 .43345 L p .72 .778 .898 r
F P
0 g
s
.36532 .42217 m .37811 .42407 L .36209 .4476 L p .73 .86 .942 r
F P
0 g
s
.36209 .4476 m .34805 .44895 L .36532 .42217 L p .73 .86 .942 r
F P
0 g
s
.55599 .48028 m .56647 .47849 L .575 .48633 L p .475 .673 .951 r
F P
0 g
s
.56647 .47849 m .55599 .48028 L .54741 .47437 L p .469 .661 .945 r
F P
0 g
s
.69054 .46286 m .67683 .47001 L .66408 .44748 L p .793 .813 .868 r
F P
0 g
s
.66408 .44748 m .67681 .43795 L .69054 .46286 L p .793 .813 .868 r
F P
0 g
s
.63549 .4878 m .62164 .49149 L .61312 .47803 L p .71 .791 .914 r
F P
0 g
s
.60038 .48237 m .61312 .47803 L .62164 .49149 L p .663 .773 .931 r
F P
0 g
s
.52667 .45771 m .52627 .46416 L .51523 .4606 L p .412 .636 .948 r
F P
0 g
s
.51523 .4606 m .51186 .45338 L .52667 .45771 L p .412 .636 .948 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47637 .44368 L p .451 .692 .969 r
F P
0 g
s
.47637 .44368 m .46642 .43712 L .48419 .43581 L p .451 .692 .969 r
F P
0 g
s
.78745 .42885 m .77335 .43054 L .75433 .39138 L p .647 .742 .918 r
F P
0 g
s
.74115 .39659 m .75433 .39138 L .77335 .43054 L p .685 .761 .909 r
F P
0 g
s
.67683 .47001 m .66309 .47677 L .65135 .4566 L p .786 .812 .874 r
F P
0 g
s
.65135 .4566 m .66408 .44748 L .67683 .47001 L p .786 .812 .874 r
F P
0 g
s
.58767 .48512 m .575 .48633 L .56647 .47849 L p .543 .701 .943 r
F P
0 g
s
.64931 .48281 m .63549 .4878 L .62587 .47217 L p .745 .802 .898 r
F P
0 g
s
.61312 .47803 m .62587 .47217 L .63549 .4878 L p .71 .791 .914 r
F P
0 g
s
.66309 .47677 m .64931 .48281 L .63862 .46494 L p .77 .809 .884 r
F P
0 g
s
.63862 .46494 m .65135 .4566 L .66309 .47677 L p .77 .809 .884 r
F P
0 g
s
.62587 .47217 m .63862 .46494 L .64931 .48281 L p .745 .802 .898 r
F P
0 g
s
.4361 .41951 m .44629 .42507 L .42837 .43347 L p .585 .807 .984 r
F P
0 g
s
.42837 .43347 m .41594 .4305 L .4361 .41951 L p .585 .807 .984 r
F P
0 g
s
.8017 .42828 m .78745 .42885 L .76765 .3874 L p .608 .721 .925 r
F P
0 g
s
.75433 .39138 m .76765 .3874 L .78745 .42885 L p .647 .742 .918 r
F P
0 g
s
.50847 .44573 m .51186 .45338 L .49806 .45095 L p .428 .655 .954 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50847 .44573 L p .428 .655 .954 r
F P
0 g
s
.54741 .47437 m .555 .47074 L .56647 .47849 L p .469 .661 .945 r
F P
0 g
s
.555 .47074 m .54741 .47437 L .53726 .46886 L p .455 .65 .943 r
F P
0 g
s
.5414 .46364 m .53726 .46886 L .52627 .46416 L p .434 .641 .944 r
F P
0 g
s
.52627 .46416 m .52667 .45771 L .5414 .46364 L p .434 .641 .944 r
F P
0 g
s
.53726 .46886 m .5414 .46364 L .555 .47074 L p .455 .65 .943 r
F P
0 g
s
.35245 .42007 m .36532 .42217 L .34805 .44895 L p .732 .848 .935 r
F P
0 g
s
.34805 .44895 m .33396 .45005 L .35245 .42007 L p .732 .848 .935 r
F P
0 g
s
.81607 .42867 m .8017 .42828 L .78114 .3846 L p .571 .7 .929 r
F P
0 g
s
.76765 .3874 m .78114 .3846 L .8017 .42828 L p .608 .721 .925 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46642 .43712 L p .487 .717 .972 r
F P
0 g
s
.46642 .43712 m .45639 .43092 L .47717 .42815 L p .487 .717 .972 r
F P
0 g
s
.60038 .48237 m .58767 .48512 L .57702 .47536 L p .607 .725 .928 r
F P
0 g
s
.56647 .47849 m .57702 .47536 L .58767 .48512 L p .543 .701 .943 r
F P
0 g
s
.42582 .41419 m .4361 .41951 L .41594 .4305 L p .62 .825 .979 r
F P
0 g
s
.41594 .4305 m .40343 .42806 L .42582 .41419 L p .62 .825 .979 r
F P
0 g
s
.57702 .47536 m .56647 .47849 L .555 .47074 L p .534 .683 .935 r
F P
0 g
s
.33951 .41761 m .35245 .42007 L .33396 .45005 L p .728 .83 .928 r
F P
0 g
s
.33396 .45005 m .31982 .45068 L .33951 .41761 L p .728 .83 .928 r
F P
0 g
s
.83057 .42981 m .81607 .42867 L .79479 .38279 L p .542 .684 .931 r
F P
0 g
s
.78114 .3846 m .79479 .38279 L .81607 .42867 L p .571 .7 .929 r
F P
0 g
s
.52706 .45051 m .52667 .45771 L .51186 .45338 L p .454 .651 .944 r
F P
0 g
s
.51186 .45338 m .50847 .44573 L .52706 .45051 L p .454 .651 .944 r
F P
0 g
s
.50504 .43762 m .50847 .44573 L .49116 .44341 L p .464 .673 .954 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50504 .43762 L p .464 .673 .954 r
F P
0 g
s
.61312 .47803 m .60038 .48237 L .58763 .47073 L p .66 .741 .91 r
F P
0 g
s
.57702 .47536 m .58763 .47073 L .60038 .48237 L p .607 .725 .928 r
F P
0 g
s
.555 .47074 m .56265 .46589 L .57702 .47536 L p .534 .683 .935 r
F P
0 g
s
.56265 .46589 m .555 .47074 L .5414 .46364 L p .513 .667 .932 r
F P
0 g
s
.84517 .43141 m .83057 .42981 L .80859 .38174 L p .524 .673 .932 r
F P
0 g
s
.79479 .38279 m .80859 .38174 L .83057 .42981 L p .542 .684 .931 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45639 .43092 L p .524 .74 .973 r
F P
0 g
s
.45639 .43092 m .44629 .42507 L .47008 .42042 L p .524 .74 .973 r
F P
0 g
s
.32652 .41464 m .33951 .41761 L .31982 .45068 L p .717 .809 .922 r
F P
0 g
s
.31982 .45068 m .30567 .45062 L .32652 .41464 L p .717 .809 .922 r
F P
0 g
s
.54558 .45739 m .5414 .46364 L .52667 .45771 L p .484 .656 .936 r
F P
0 g
s
.52667 .45771 m .52706 .45051 L .54558 .45739 L p .484 .656 .936 r
F P
0 g
s
.41546 .40902 m .42582 .41419 L .40343 .42806 L p .648 .836 .972 r
F P
0 g
s
.40343 .42806 m .39082 .42597 L .41546 .40902 L p .648 .836 .972 r
F P
0 g
s
.5414 .46364 m .54558 .45739 L .56265 .46589 L p .513 .667 .932 r
F P
0 g
s
.58763 .47073 m .57702 .47536 L .56265 .46589 L p .592 .7 .918 r
F P
0 g
s
.62587 .47217 m .61312 .47803 L .59829 .46454 L p .701 .753 .892 r
F P
0 g
s
.58763 .47073 m .59829 .46454 L .61312 .47803 L p .66 .741 .91 r
F P
0 g
s
.85986 .43317 m .84517 .43141 L .82254 .38116 L p .517 .67 .932 r
F P
0 g
s
.80859 .38174 m .82254 .38116 L .84517 .43141 L p .524 .673 .932 r
F P
0 g
s
.31349 .41107 m .32652 .41464 L .30567 .45062 L p .702 .786 .916 r
F P
0 g
s
.30567 .45062 m .29152 .44973 L .31349 .41107 L p .702 .786 .916 r
F P
0 g
s
.52747 .44246 m .52706 .45051 L .50847 .44573 L p .495 .665 .938 r
F P
0 g
s
.50847 .44573 m .50504 .43762 L .52747 .44246 L p .495 .665 .938 r
F P
0 g
s
.50159 .42903 m .50504 .43762 L .48419 .43581 L p .501 .69 .952 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50159 .42903 L p .501 .69 .952 r
F P
0 g
s
.63862 .46494 m .62587 .47217 L .60898 .45685 L p .733 .76 .875 r
F P
0 g
s
.59829 .46454 m .60898 .45685 L .62587 .47217 L p .701 .753 .892 r
F P
0 g
s
.40501 .40392 m .41546 .40902 L .39082 .42597 L p .671 .839 .964 r
F P
0 g
s
.39082 .42597 m .37811 .42407 L .40501 .40392 L p .671 .839 .964 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44629 .42507 L p .558 .76 .972 r
F P
0 g
s
.44629 .42507 m .4361 .41951 L .46294 .41262 L p .558 .76 .972 r
F P
0 g
s
.30042 .40684 m .31349 .41107 L .29152 .44973 L p .684 .762 .91 r
F P
0 g
s
.29152 .44973 m .27739 .44794 L .30042 .40684 L p .684 .762 .91 r
F P
0 g
s
.82254 .38116 m .8366 .38074 L .85986 .43317 L p .517 .67 .932 r
F P
0 g
s
.65135 .4566 m .63862 .46494 L .61969 .44781 L p .754 .764 .861 r
F P
0 g
s
.60898 .45685 m .61969 .44781 L .63862 .46494 L p .733 .76 .875 r
F P
0 g
s
.56265 .46589 m .57036 .45967 L .58763 .47073 L p .592 .7 .918 r
F P
0 g
s
.57036 .45967 m .56265 .46589 L .54558 .45739 L p .565 .68 .917 r
F P
0 g
s
.59829 .46454 m .58763 .47073 L .57036 .45967 L p .64 .712 .899 r
F P
0 g
s
.5498 .45 m .54558 .45739 L .52706 .45051 L p .531 .668 .924 r
F P
0 g
s
.52706 .45051 m .52747 .44246 L .5498 .45 L p .531 .668 .924 r
F P
0 g
s
.66408 .44748 m .65135 .4566 L .63042 .43767 L p .768 .767 .852 r
F P
0 g
s
.61969 .44781 m .63042 .43767 L .65135 .4566 L p .754 .764 .861 r
F P
0 g
s
.28734 .40194 m .30042 .40684 L .27739 .44794 L p .665 .738 .905 r
F P
0 g
s
.27739 .44794 m .26328 .44525 L .28734 .40194 L p .665 .738 .905 r
F P
0 g
s
.54558 .45739 m .5498 .45 L .57036 .45967 L p .565 .68 .917 r
F P
0 g
s
.67681 .43795 m .66408 .44748 L .64116 .42675 L p .776 .77 .847 r
F P
0 g
s
.63042 .43767 m .64116 .42675 L .66408 .44748 L p .768 .767 .852 r
F P
0 g
s
.39448 .39878 m .40501 .40392 L .37811 .42407 L p .687 .836 .955 r
F P
0 g
s
.37811 .42407 m .36532 .42217 L .39448 .39878 L p .687 .836 .955 r
F P
0 g
s
.27423 .39642 m .28734 .40194 L .26328 .44525 L p .645 .716 .9 r
F P
0 g
s
.26328 .44525 m .24921 .4417 L .27423 .39642 L p .645 .716 .9 r
F P
0 g
s
.68956 .42839 m .67681 .43795 L .65194 .4154 L p .777 .771 .848 r
F P
0 g
s
.64116 .42675 m .65194 .4154 L .67681 .43795 L p .776 .77 .847 r
F P
0 g
s
.4981 .41996 m .50159 .42903 L .47717 .42815 L p .535 .705 .949 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .4981 .41996 L p .535 .705 .949 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .4361 .41951 L p .59 .775 .968 r
F P
0 g
s
.4361 .41951 m .42582 .41419 L .45573 .40475 L p .59 .775 .968 r
F P
0 g
s
.70234 .41918 m .68956 .42839 L .66274 .40399 L p .772 .772 .853 r
F P
0 g
s
.65194 .4154 m .66274 .40399 L .68956 .42839 L p .777 .771 .848 r
F P
0 g
s
.52787 .43355 m .52747 .44246 L .50504 .43762 L p .534 .676 .929 r
F P
0 g
s
.50504 .43762 m .50159 .42903 L .52787 .43355 L p .534 .676 .929 r
F P
0 g
s
.2611 .39035 m .27423 .39642 L .24921 .4417 L p .627 .698 .896 r
F P
0 g
s
.24921 .4417 m .23517 .43742 L .2611 .39035 L p .627 .698 .896 r
F P
0 g
s
.71518 .41064 m .70234 .41918 L .67361 .39289 L p .76 .772 .863 r
F P
0 g
s
.66274 .40399 m .67361 .39289 L .70234 .41918 L p .772 .772 .853 r
F P
0 g
s
.60898 .45685 m .59829 .46454 L .57811 .45202 L p .678 .719 .88 r
F P
0 g
s
.57036 .45967 m .57811 .45202 L .59829 .46454 L p .64 .712 .899 r
F P
0 g
s
.24795 .38387 m .2611 .39035 L .23517 .43742 L p .613 .685 .894 r
F P
0 g
s
.23517 .43742 m .22116 .4326 L .24795 .38387 L p .613 .685 .894 r
F P
0 g
s
.57811 .45202 m .57036 .45967 L .5498 .45 L p .61 .689 .899 r
F P
0 g
s
.72811 .40305 m .71518 .41064 L .68454 .38242 L p .742 .771 .876 r
F P
0 g
s
.67361 .39289 m .68454 .38242 L .71518 .41064 L p .76 .772 .863 r
F P
0 g
s
.23477 .37712 m .24795 .38387 L .22116 .4326 L p .602 .677 .894 r
F P
0 g
s
.22116 .4326 m .20717 .42743 L .23477 .37712 L p .602 .677 .894 r
F P
0 g
s
.22154 .37026 m .23477 .37712 L .20717 .42743 L p .596 .675 .895 r
F P
0 g
s
.20717 .42743 m .19318 .42214 L .22154 .37026 L p .596 .675 .895 r
F P
0 g
s
.38386 .39351 m .39448 .39878 L .36532 .42217 L p .696 .827 .946 r
F P
0 g
s
.36532 .42217 m .35245 .42007 L .38386 .39351 L p .696 .827 .946 r
F P
0 g
s
.55404 .44142 m .5498 .45 L .52747 .44246 L p .573 .676 .91 r
F P
0 g
s
.52747 .44246 m .52787 .43355 L .55404 .44142 L p .573 .676 .91 r
F P
0 g
s
.74115 .39659 m .72811 .40305 L .69557 .37284 L p .717 .767 .892 r
F P
0 g
s
.68454 .38242 m .69557 .37284 L .72811 .40305 L p .742 .771 .876 r
F P
0 g
s
.5498 .45 m .55404 .44142 L .57811 .45202 L p .61 .689 .899 r
F P
0 g
s
.61969 .44781 m .60898 .45685 L .58591 .443 L p .706 .724 .864 r
F P
0 g
s
.57811 .45202 m .58591 .443 L .60898 .45685 L p .678 .719 .88 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42582 .41419 L p .618 .786 .962 r
F P
0 g
s
.42582 .41419 m .41546 .40902 L .44846 .39682 L p .618 .786 .962 r
F P
0 g
s
.49459 .41046 m .4981 .41996 L .47008 .42042 L p .567 .719 .944 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49459 .41046 L p .567 .719 .944 r
F P
0 g
s
.75433 .39138 m .74115 .39659 L .70673 .36434 L p .685 .76 .909 r
F P
0 g
s
.69557 .37284 m .70673 .36434 L .74115 .39659 L p .717 .767 .892 r
F P
0 g
s
.52828 .4238 m .52787 .43355 L .50159 .42903 L p .568 .686 .92 r
F P
0 g
s
.50159 .42903 m .4981 .41996 L .52828 .4238 L p .568 .686 .92 r
F P
0 g
s
.58591 .443 m .57811 .45202 L .55404 .44142 L p .645 .695 .882 r
F P
0 g
s
.63042 .43767 m .61969 .44781 L .59374 .43274 L p .727 .728 .851 r
F P
0 g
s
.58591 .443 m .59374 .43274 L .61969 .44781 L p .706 .724 .864 r
F P
0 g
s
.37317 .38801 m .38386 .39351 L .35245 .42007 L p .699 .814 .936 r
F P
0 g
s
.35245 .42007 m .33951 .41761 L .37317 .38801 L p .699 .814 .936 r
F P
0 g
s
.76765 .3874 m .75433 .39138 L .71801 .35702 L p .648 .75 .924 r
F P
0 g
s
.70673 .36434 m .71801 .35702 L .75433 .39138 L p .685 .76 .909 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41546 .40902 L p .641 .792 .955 r
F P
0 g
s
.41546 .40902 m .40501 .40392 L .44112 .38881 L p .641 .792 .955 r
F P
0 g
s
.55832 .43168 m .55404 .44142 L .52787 .43355 L p .607 .683 .896 r
F P
0 g
s
.52787 .43355 m .52828 .4238 L .55832 .43168 L p .607 .683 .896 r
F P
0 g
s
.55404 .44142 m .55832 .43168 L .58591 .443 L p .645 .695 .882 r
F P
0 g
s
.64116 .42675 m .63042 .43767 L .6016 .42146 L p .74 .731 .843 r
F P
0 g
s
.59374 .43274 m .6016 .42146 L .63042 .43767 L p .727 .728 .851 r
F P
0 g
s
.49104 .40059 m .49459 .41046 L .46294 .41262 L p .595 .73 .938 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49104 .40059 L p .595 .73 .938 r
F P
0 g
s
.78114 .3846 m .76765 .3874 L .72945 .35089 L p .607 .737 .937 r
F P
0 g
s
.71801 .35702 m .72945 .35089 L .76765 .3874 L p .648 .75 .924 r
F P
0 g
s
.3624 .38222 m .37317 .38801 L .33951 .41761 L p .697 .798 .927 r
F P
0 g
s
.33951 .41761 m .32652 .41464 L .3624 .38222 L p .697 .798 .927 r
F P
0 g
s
.59374 .43274 m .58591 .443 L .55832 .43168 L p .672 .699 .867 r
F P
0 g
s
.52869 .41328 m .52828 .4238 L .4981 .41996 L p .597 .694 .91 r
F P
0 g
s
.4981 .41996 m .49459 .41046 L .52869 .41328 L p .597 .694 .91 r
F P
0 g
s
.65194 .4154 m .64116 .42675 L .60948 .40944 L p .749 .735 .839 r
F P
0 g
s
.6016 .42146 m .60948 .40944 L .64116 .42675 L p .74 .731 .843 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40501 .40392 L p .658 .794 .947 r
F P
0 g
s
.40501 .40392 m .39448 .39878 L .43372 .38074 L p .658 .794 .947 r
F P
0 g
s
.66274 .40399 m .65194 .4154 L .61741 .397 L p .752 .739 .84 r
F P
0 g
s
.60948 .40944 m .61741 .397 L .65194 .4154 L p .749 .735 .839 r
F P
0 g
s
.79479 .38279 m .78114 .3846 L .74105 .34587 L p .568 .723 .946 r
F P
0 g
s
.72945 .35089 m .74105 .34587 L .78114 .3846 L p .607 .737 .937 r
F P
0 g
s
.55832 .43168 m .56262 .42091 L .59374 .43274 L p .672 .699 .867 r
F P
0 g
s
.56262 .42091 m .55832 .43168 L .52828 .4238 L p .635 .688 .883 r
F P
0 g
s
.52828 .4238 m .52869 .41328 L .56262 .42091 L p .635 .688 .883 r
F P
0 g
s
.35157 .37607 m .3624 .38222 L .32652 .41464 L p .692 .78 .918 r
F P
0 g
s
.32652 .41464 m .31349 .41107 L .35157 .37607 L p .692 .78 .918 r
F P
0 g
s
.48747 .39043 m .49104 .40059 L .45573 .40475 L p .619 .739 .932 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48747 .39043 L p .619 .739 .932 r
F P
0 g
s
.6016 .42146 m .59374 .43274 L .56262 .42091 L p .693 .703 .855 r
F P
0 g
s
.67361 .39289 m .66274 .40399 L .62538 .38449 L p .75 .743 .846 r
F P
0 g
s
.61741 .397 m .62538 .38449 L .66274 .40399 L p .752 .739 .84 r
F P
0 g
s
.52911 .40212 m .52869 .41328 L .49459 .41046 L p .622 .701 .902 r
F P
0 g
s
.49459 .41046 m .49104 .40059 L .52911 .40212 L p .622 .701 .902 r
F P
0 g
s
.80859 .38174 m .79479 .38279 L .75282 .3418 L p .535 .709 .952 r
F P
0 g
s
.74105 .34587 m .75282 .3418 L .79479 .38279 L p .568 .723 .946 r
F P
0 g
s
.68454 .38242 m .67361 .39289 L .6334 .37222 L p .742 .748 .857 r
F P
0 g
s
.62538 .38449 m .6334 .37222 L .67361 .39289 L p .75 .743 .846 r
F P
0 g
s
.34067 .36954 m .35157 .37607 L .31349 .41107 L p .683 .761 .91 r
F P
0 g
s
.31349 .41107 m .30042 .40684 L .34067 .36954 L p .683 .761 .91 r
F P
0 g
s
.60948 .40944 m .6016 .42146 L .56695 .40927 L p .707 .707 .847 r
F P
0 g
s
.56262 .42091 m .56695 .40927 L .6016 .42146 L p .693 .703 .855 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39448 .39878 L p .671 .791 .939 r
F P
0 g
s
.39448 .39878 m .38386 .39351 L .42626 .3726 L p .671 .791 .939 r
F P
0 g
s
.56695 .40927 m .56262 .42091 L .52869 .41328 L p .657 .693 .872 r
F P
0 g
s
.52869 .41328 m .52911 .40212 L .56695 .40927 L p .657 .693 .872 r
F P
0 g
s
.48387 .38008 m .48747 .39043 L .44846 .39682 L p .639 .746 .926 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48387 .38008 L p .639 .746 .926 r
F P
0 g
s
.69557 .37284 m .68454 .38242 L .64149 .36048 L p .73 .753 .871 r
F P
0 g
s
.6334 .37222 m .64149 .36048 L .68454 .38242 L p .742 .748 .857 r
F P
0 g
s
.32972 .36263 m .34067 .36954 L .30042 .40684 L p .673 .743 .903 r
F P
0 g
s
.30042 .40684 m .28734 .40194 L .32972 .36263 L p .673 .743 .903 r
F P
0 g
s
.82254 .38116 m .80859 .38174 L .76474 .33845 L p .514 .7 .954 r
F P
0 g
s
.75282 .3418 m .76474 .33845 L .80859 .38174 L p .535 .709 .952 r
F P
0 g
s
.52952 .39048 m .52911 .40212 L .49104 .40059 L p .641 .708 .895 r
F P
0 g
s
.49104 .40059 m .48747 .39043 L .52952 .39048 L p .641 .708 .895 r
F P
0 g
s
.61741 .397 m .60948 .40944 L .5713 .397 L p .717 .712 .844 r
F P
0 g
s
.56695 .40927 m .5713 .397 L .60948 .40944 L p .707 .707 .847 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38386 .39351 L p .68 .786 .93 r
F P
0 g
s
.38386 .39351 m .37317 .38801 L .41873 .36438 L p .68 .786 .93 r
F P
0 g
s
.70673 .36434 m .69557 .37284 L .64966 .34951 L p .71 .757 .889 r
F P
0 g
s
.64149 .36048 m .64966 .34951 L .69557 .37284 L p .73 .753 .871 r
F P
0 g
s
.5713 .397 m .56695 .40927 L .52911 .40212 L p .673 .698 .865 r
F P
0 g
s
.3187 .35535 m .32972 .36263 L .28734 .40194 L p .662 .727 .898 r
F P
0 g
s
.28734 .40194 m .27423 .39642 L .3187 .35535 L p .662 .727 .898 r
F P
0 g
s
.52911 .40212 m .52952 .39048 L .5713 .397 L p .673 .698 .865 r
F P
0 g
s
.48023 .36963 m .48387 .38008 L .44112 .38881 L p .654 .751 .921 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48023 .36963 L p .654 .751 .921 r
F P
0 g
s
.62538 .38449 m .61741 .397 L .57568 .38435 L p .723 .717 .845 r
F P
0 g
s
.5713 .397 m .57568 .38435 L .61741 .397 L p .717 .712 .844 r
F P
0 g
s
.8366 .38074 m .82254 .38116 L .77681 .33553 L p .506 .696 .954 r
F P
0 g
s
.76474 .33845 m .77681 .33553 L .82254 .38116 L p .514 .7 .954 r
F P
0 g
s
.71801 .35702 m .70673 .36434 L .65793 .33949 L p .685 .76 .908 r
F P
0 g
s
.64966 .34951 m .65793 .33949 L .70673 .36434 L p .71 .757 .889 r
F P
0 g
s
.52995 .37854 m .52952 .39048 L .48747 .39043 L p .657 .715 .891 r
F P
0 g
s
.48747 .39043 m .48387 .38008 L .52995 .37854 L p .657 .715 .891 r
F P
0 g
s
.30762 .34776 m .3187 .35535 L .27423 .39642 L p .651 .714 .894 r
F P
0 g
s
.27423 .39642 m .2611 .39035 L .30762 .34776 L p .651 .714 .894 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37317 .38801 L p .684 .779 .923 r
F P
0 g
s
.37317 .38801 m .3624 .38222 L .41113 .35609 L p .684 .779 .923 r
F P
0 g
s
.57568 .38435 m .5713 .397 L .52952 .39048 L p .685 .704 .862 r
F P
0 g
s
.6334 .37222 m .62538 .38449 L .58009 .3716 L p .724 .725 .85 r
F P
0 g
s
.57568 .38435 m .58009 .3716 L .62538 .38449 L p .723 .717 .845 r
F P
0 g
s
.29648 .33991 m .30762 .34776 L .2611 .39035 L p .642 .704 .892 r
F P
0 g
s
.2611 .39035 m .24795 .38387 L .29648 .33991 L p .642 .704 .892 r
F P
0 g
s
.52952 .39048 m .52995 .37854 L .57568 .38435 L p .685 .704 .862 r
F P
0 g
s
.72945 .35089 m .71801 .35702 L .66632 .3305 L p .653 .759 .928 r
F P
0 g
s
.65793 .33949 m .66632 .3305 L .71801 .35702 L p .685 .76 .908 r
F P
0 g
s
.47656 .35919 m .48023 .36963 L .43372 .38074 L p .666 .755 .916 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47656 .35919 L p .666 .755 .916 r
F P
0 g
s
.77681 .33553 m .78901 .33274 L .8366 .38074 L p .506 .696 .954 r
F P
0 g
s
.64149 .36048 m .6334 .37222 L .58453 .35901 L p .721 .733 .86 r
F P
0 g
s
.58009 .3716 m .58453 .35901 L .6334 .37222 L p .724 .725 .85 r
F P
0 g
s
.28528 .33187 m .29648 .33991 L .24795 .38387 L p .634 .698 .892 r
F P
0 g
s
.24795 .38387 m .23477 .37712 L .28528 .33187 L p .634 .698 .892 r
F P
0 g
s
.53037 .36649 m .52995 .37854 L .48387 .38008 L p .669 .722 .889 r
F P
0 g
s
.48387 .38008 m .48023 .36963 L .53037 .36649 L p .669 .722 .889 r
F P
0 g
s
.58009 .3716 m .57568 .38435 L .52995 .37854 L p .694 .711 .862 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .3624 .38222 L p .685 .77 .916 r
F P
0 g
s
.3624 .38222 m .35157 .37607 L .40346 .34772 L p .685 .77 .916 r
F P
0 g
s
.74105 .34587 m .72945 .35089 L .67482 .32255 L p .617 .756 .944 r
F P
0 g
s
.66632 .3305 m .67482 .32255 L .72945 .35089 L p .653 .759 .928 r
F P
0 g
s
.27399 .32374 m .28528 .33187 L .23477 .37712 L p .629 .696 .894 r
F P
0 g
s
.23477 .37712 m .22154 .37026 L .27399 .32374 L p .629 .696 .894 r
F P
0 g
s
.52995 .37854 m .53037 .36649 L .58009 .3716 L p .694 .711 .862 r
F P
0 g
s
.64966 .34951 m .64149 .36048 L .58902 .34683 L p .714 .742 .873 r
F P
0 g
s
.58453 .35901 m .58902 .34683 L .64149 .36048 L p .721 .733 .86 r
F P
0 g
s
.47286 .34883 m .47656 .35919 L .42626 .3726 L p .675 .757 .913 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47286 .34883 L p .675 .757 .913 r
F P
0 g
s
.58453 .35901 m .58009 .3716 L .53037 .36649 L p .699 .719 .865 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35157 .37607 L p .683 .761 .91 r
F P
0 g
s
.35157 .37607 m .34067 .36954 L .39573 .33928 L p .683 .761 .91 r
F P
0 g
s
.5308 .35452 m .53037 .36649 L .48023 .36963 L p .677 .729 .889 r
F P
0 g
s
.48023 .36963 m .47656 .35919 L .5308 .35452 L p .677 .729 .889 r
F P
0 g
s
.75282 .3418 m .74105 .34587 L .68346 .31557 L p .581 .749 .957 r
F P
0 g
s
.67482 .32255 m .68346 .31557 L .74105 .34587 L p .617 .756 .944 r
F P
0 g
s
.65793 .33949 m .64966 .34951 L .59356 .33524 L p .702 .751 .89 r
F P
0 g
s
.58902 .34683 m .59356 .33524 L .64966 .34951 L p .714 .742 .873 r
F P
0 g
s
.53037 .36649 m .5308 .35452 L .58453 .35901 L p .699 .719 .865 r
F P
0 g
s
.46911 .33863 m .47286 .34883 L .41873 .36438 L p .68 .759 .911 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46911 .33863 L p .68 .759 .911 r
F P
0 g
s
.58902 .34683 m .58453 .35901 L .5308 .35452 L p .7 .728 .872 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34067 .36954 L p .679 .751 .906 r
F P
0 g
s
.34067 .36954 m .32972 .36263 L .38792 .33076 L p .679 .751 .906 r
F P
0 g
s
.53123 .3428 m .5308 .35452 L .47656 .35919 L p .683 .737 .891 r
F P
0 g
s
.47656 .35919 m .47286 .34883 L .53123 .3428 L p .683 .737 .891 r
F P
0 g
s
.66632 .3305 m .65793 .33949 L .59816 .3244 L p .684 .759 .908 r
F P
0 g
s
.59356 .33524 m .59816 .3244 L .65793 .33949 L p .702 .751 .89 r
F P
0 g
s
.76474 .33845 m .75282 .3418 L .69223 .30942 L p .55 .741 .965 r
F P
0 g
s
.68346 .31557 m .69223 .30942 L .75282 .3418 L p .581 .749 .957 r
F P
0 g
s
.5308 .35452 m .53123 .3428 L .58902 .34683 L p .7 .728 .872 r
F P
0 g
s
.59356 .33524 m .58902 .34683 L .53123 .3428 L p .698 .738 .882 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32972 .36263 L p .674 .742 .902 r
F P
0 g
s
.32972 .36263 m .3187 .35535 L .38005 .32217 L p .674 .742 .902 r
F P
0 g
s
.46533 .32864 m .46911 .33863 L .41113 .35609 L p .682 .76 .91 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46533 .32864 L p .682 .76 .91 r
F P
0 g
s
.53167 .33147 m .53123 .3428 L .47286 .34883 L p .686 .744 .896 r
F P
0 g
s
.47286 .34883 m .46911 .33863 L .53167 .33147 L p .686 .744 .896 r
F P
0 g
s
.67482 .32255 m .66632 .3305 L .60282 .31436 L p .662 .766 .927 r
F P
0 g
s
.59816 .3244 m .60282 .31436 L .66632 .3305 L p .684 .759 .908 r
F P
0 g
s
.77681 .33553 m .76474 .33845 L .70112 .30388 L p .528 .734 .969 r
F P
0 g
s
.69223 .30942 m .70112 .30388 L .76474 .33845 L p .55 .741 .965 r
F P
0 g
s
.53123 .3428 m .53167 .33147 L .59356 .33524 L p .698 .738 .882 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .3187 .35535 L p .668 .735 .9 r
F P
0 g
s
.3187 .35535 m .30762 .34776 L .3721 .3135 L p .668 .735 .9 r
F P
0 g
s
.59816 .3244 m .59356 .33524 L .53167 .33147 L p .692 .749 .895 r
F P
0 g
s
.4615 .31889 m .46533 .32864 L .40346 .34772 L p .683 .76 .91 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .4615 .31889 L p .683 .76 .91 r
F P
0 g
s
.68346 .31557 m .67482 .32255 L .60755 .30515 L p .636 .77 .944 r
F P
0 g
s
.60282 .31436 m .60755 .30515 L .67482 .32255 L p .662 .766 .927 r
F P
0 g
s
.53211 .32062 m .53167 .33147 L .46911 .33863 L p .685 .752 .902 r
F P
0 g
s
.46911 .33863 m .46533 .32864 L .53211 .32062 L p .685 .752 .902 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30762 .34776 L p .661 .729 .9 r
F P
0 g
s
.30762 .34776 m .29648 .33991 L .36408 .30475 L p .661 .729 .9 r
F P
0 g
s
.78901 .33274 m .77681 .33553 L .71014 .29871 L p .521 .73 .969 r
F P
0 g
s
.70112 .30388 m .71014 .29871 L .77681 .33553 L p .528 .734 .969 r
F P
0 g
s
.53167 .33147 m .53211 .32062 L .59816 .3244 L p .692 .749 .895 r
F P
0 g
s
.60282 .31436 m .59816 .3244 L .53211 .32062 L p .683 .759 .909 r
F P
0 g
s
.45762 .30938 m .4615 .31889 L .39573 .33928 L p .681 .759 .911 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45762 .30938 L p .681 .759 .911 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29648 .33991 L p .655 .725 .9 r
F P
0 g
s
.29648 .33991 m .28528 .33187 L .35599 .29592 L p .655 .725 .9 r
F P
0 g
s
.69223 .30942 m .68346 .31557 L .61235 .2967 L p .608 .771 .958 r
F P
0 g
s
.60755 .30515 m .61235 .2967 L .68346 .31557 L p .636 .77 .944 r
F P
0 g
s
.53256 .31032 m .53211 .32062 L .46533 .32864 L p .683 .759 .909 r
F P
0 g
s
.46533 .32864 m .4615 .31889 L .53256 .31032 L p .683 .759 .909 r
F P
0 g
s
.71014 .29871 m .71927 .29362 L .78901 .33274 L p .521 .73 .969 r
F P
0 g
s
.53211 .32062 m .53256 .31032 L .60282 .31436 L p .683 .759 .909 r
F P
0 g
s
.60755 .30515 m .60282 .31436 L .53256 .31032 L p .671 .768 .923 r
F P
0 g
s
.4537 .30008 m .45762 .30938 L .38792 .33076 L p .677 .758 .912 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .4537 .30008 L p .677 .758 .912 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28528 .33187 L p .65 .723 .902 r
F P
0 g
s
.28528 .33187 m .27399 .32374 L .34782 .287 L p .65 .723 .902 r
F P
0 g
s
.53301 .30056 m .53256 .31032 L .4615 .31889 L p .678 .766 .917 r
F P
0 g
s
.4615 .31889 m .45762 .30938 L .53301 .30056 L p .678 .766 .917 r
F P
0 g
s
.70112 .30388 m .69223 .30942 L .61722 .28889 L p .584 .769 .967 r
F P
0 g
s
.61235 .2967 m .61722 .28889 L .69223 .30942 L p .608 .771 .958 r
F P
0 g
s
.53256 .31032 m .53301 .30056 L .60755 .30515 L p .671 .768 .923 r
F P
0 g
s
.61235 .2967 m .60755 .30515 L .53301 .30056 L p .656 .775 .937 r
F P
0 g
s
.44973 .29096 m .4537 .30008 L .38005 .32217 L p .673 .757 .914 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44973 .29096 L p .673 .757 .914 r
F P
0 g
s
.53348 .29131 m .53301 .30056 L .45762 .30938 L p .671 .771 .925 r
F P
0 g
s
.45762 .30938 m .4537 .30008 L .53348 .29131 L p .671 .771 .925 r
F P
0 g
s
.71014 .29871 m .70112 .30388 L .62217 .28156 L p .567 .765 .972 r
F P
0 g
s
.61722 .28889 m .62217 .28156 L .70112 .30388 L p .584 .769 .967 r
F P
0 g
s
.44572 .28195 m .44973 .29096 L .3721 .3135 L p .667 .755 .916 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44572 .28195 L p .667 .755 .916 r
F P
0 g
s
.53301 .30056 m .53348 .29131 L .61235 .2967 L p .656 .775 .937 r
F P
0 g
s
.61722 .28889 m .61235 .2967 L .53348 .29131 L p .64 .78 .948 r
F P
0 g
s
.53394 .28248 m .53348 .29131 L .4537 .30008 L p .663 .774 .932 r
F P
0 g
s
.4537 .30008 m .44973 .29096 L .53394 .28248 L p .663 .774 .932 r
F P
0 g
s
.44165 .27296 m .44572 .28195 L .36408 .30475 L p .661 .753 .918 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44165 .27296 L p .661 .753 .918 r
F P
0 g
s
.71927 .29362 m .71014 .29871 L .62718 .27448 L p .559 .762 .973 r
F P
0 g
s
.62217 .28156 m .62718 .27448 L .71014 .29871 L p .567 .765 .972 r
F P
0 g
s
.53348 .29131 m .53394 .28248 L .61722 .28889 L p .64 .78 .948 r
F P
0 g
s
.62217 .28156 m .61722 .28889 L .53394 .28248 L p .625 .781 .956 r
F P
0 g
s
.43754 .26392 m .44165 .27296 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53442 .27394 m .53394 .28248 L .44973 .29096 L p .655 .775 .937 r
F P
0 g
s
.44973 .29096 m .44572 .28195 L .53442 .27394 L p .655 .775 .937 r
F P
0 g
s
.62718 .27448 m .63227 .26744 L .71927 .29362 L p .559 .762 .973 r
F P
0 g
s
.53394 .28248 m .53442 .27394 L .62217 .28156 L p .625 .781 .956 r
F P
0 g
s
.62718 .27448 m .62217 .28156 L .53442 .27394 L p .613 .781 .961 r
F P
0 g
s
.5349 .26555 m .53442 .27394 L .44572 .28195 L p .648 .775 .941 r
F P
0 g
s
.44572 .28195 m .44165 .27296 L .5349 .26555 L p .648 .775 .941 r
F P
0 g
s
.53442 .27394 m .5349 .26555 L .62718 .27448 L p .613 .781 .961 r
F P
0 g
s
.63227 .26744 m .62718 .27448 L .5349 .26555 L p .606 .778 .963 r
F P
0 g
s
.53539 .25714 m .5349 .26555 L .44165 .27296 L p .641 .773 .943 r
F P
0 g
s
.44165 .27296 m .43754 .26392 L .53539 .25714 L p .641 .773 .943 r
F P
0 g
s
.5349 .26555 m .53539 .25714 L .63227 .26744 L p .606 .778 .963 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00002?nTaO400ol0003oVlOfoi_7mP04oi_7mP_o00009_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02oooooo000Booooo`Ko00001Oooool00ol0003o
ooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`1iooooo`[o00005?nTaO46o`00017o
VlOf2ol0000Kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;oooool001gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Cooooo
1?l00002ojO0j`03o`000?nTaO7oY<Ga00koY<Ga2ol00005ojG6l003o`000?nLaoKoW<Of00?oW<Of
2ol0000<oi_7mPOo00005?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02kooooo
000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1`ooooo`?o00001onW`>/00ol0003oY<GaojC5l@07ojC5l@Ko00004?nUa_000ol0003oW<Ofoic7
mP0>oic7mP[o00001OnKaoH01?l0003oSl?ioho3nOn?`oT3o`00017ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Joooool4o`0000WoYl3[0ol00002ojC5l@;o00005OnU
a_06o`0001[oW<Of1Ol00007oho3n@?o00003_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02gooooo000Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Vooooo`Co00002_nW`>/3o`0000;oZL3[00?o0000ojG6l?nUa_003OnUa_0:
o`0000GoYlK_00?o0000oio7m?nOao@00onOao@:o`0000ooW<Of00?o0000oi73n?nA`oP02?n?`oT3
o`0000_ooooo00?o0000ooooooooool0<oooool2o`0002kooooo000Kooooo`03oeEEEOmVIVKo0000
00Kooooo0_l0000:ooooo`03o`000?oooooooooo067ooooo1?l0000:ojO0j`Co00001_nY`>/00ol0
003oYLK`ojG6l005ojG6l0Oo00003onWa^l00ol0003oWlOdoio7m00=oio7m0Wo00001OnLaoH00ol0
003oTL?hoi73n004oi73n0;o00001_n?`oT4o`0000Sooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0/ooooo`009?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05go
oooo0ol0000:ojO0j`Co00002?nY`>/3o`0000;oYLK`0_l0000DojO6k`Ko00006?nOao@5o`0000[o
TL?h0ol00006oho3n@?o00001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_o
oooo000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool4o`0000[oYl3[
0ol00009ojW0j`?o00000_nZ`NX00ol0003oYlK_ojO6k`0<ojO6k`[o00001OnYa^h00ol0003oXlOb
oj?7lP05oj?7lPko00001onOao@01?l0003oULCgoiG4mol0000:oi73n0?o00001_n?`oT3o`0000;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo05Cooooo0ol0000:ojO0j`Co00002OnY`>/3o`0000KoZ/7Z
00?o0000ojO6konWa^l01?nWa^l7o`0000ooZLK^00?o0000oj?7l_nSao804onSao87o`0000OoULCg
0_l00008oi73n0?o00001_n?`oT3o`0003Oooooo00?o0000ooooooooool0:_ooool002Cooooo0_l0
000>ooooo`03o`000?oooooooooo057ooooo0_l00002ojJiiP03o`000?nW`>_oYl3[00GoYl3[0ol0
0009ojW0j`Co00001onZ`NX3o`000004ojO6kol0003o0000o`0001CoZLK^1Ol0000Koj?7lP04o`00
0?nKaOGoVlGeo`0000SoULCg0ol00006oi73n0?o00001On?`oT4o`0003Gooooo00?o0000oooooooo
ool0:Oooool002?ooooo0_l0000@ooooo`03o`000?oooooooooo04kooooo0_l00005ojJiiP03o`00
0?nW`>_oYl3[00;oYl3[00?o0000ojW0jonY`>/02?nY`>/3o`0000SoZ/7Z0ol00002ojc1j@03o`00
0?nYa^koZLK^00goZLK^2Ol00004oj_5k003o`000?nWa^ooYlK_00GoYlK_3Ol00006oj?7lP03o`00
0?nKaOGoVlGe00CoVlGe0ol00007oiG4m`?o00001OnA`oP3o`0000;oSl?i00Co0000oho3nOn?`oWo
Sl?i0ol0000cooooo`03o`000?oooooooooo02Sooooo000Tooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Boooool2o`0000OoY[WV0ol00009ojW0j`Co00002?nZ`NX3o`0000Ko[<7Y
00?o0000ojW6k_nYa^h01OnYa^h7o`0000coZlG/00?o0000ojO6konWa^l04onWa^l6o`0000_oVlGe
1?l00005oiG4m`Co00001?nA`oP3o`0000;oSl?i00Co0000ohFjn?n5^_SoQK[h0_l0000`ooooo`;o
0000:_ooool002?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`18ooooo`;o0000
1onV^NH2o`0000;oYkWV00?o0000ojW0jonY`>/01OnY`>/2o`0000WoZ/7Z0ol00008ojc1j@?o0000
00CoZLK^o`000?l0003o00004On[aN`5o`0001[oYlK_00Co0000oj;5lOnRaO7o00003?nKaOD3o`00
00KoULCg1?l00002oi73n0?o00001_n5^_P2o`00033ooooo00?o0000ooooooooool09oooool002?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001onV^NH2o`0000Go
YkWV00?o0000ojW0jonY`>/00_nY`>/00ol0003oZ/7Zoj[1jP06oj[1jPCo00002?n/`NT3o`0000;o
[L;Y00?o0000oj_5k?n[aN`02_n[aN`9o`0000Co[LCZ00?o0000oj_4k?n[a>`01?n[a>`=o`0000Ko
YlK_00?o0000oj;5lOnRaO401OnRaO44o`0000SoVlGe1?l00006oiG4m`?o00000on7^oP7ohFjn003
o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool002?ooooo0_l0000Dooooo`03o`00
0?oooooooooo047ooooo0ol00007ojJiiP;o00001onW^NH3o`0000SoZ/7Z0ol00008ojc1j@Co0000
1_n]`^T00ol0003oZlG/oj_5k003oj_5k0Ko00003On]a>X00ol0003oZlC/oj_4k00Aoj_4k0Ko0000
3?nRaO44o`0000SoVlGe0ol000001_nEa?Oo0000o`000?l0003oS;ggo`0000GoQk_h00?o0000ohFj
n?n5^_P00on5^_P2o`0002kooooo00?o0000ooooooooool09_ooool002?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0nooooo`;o00002?nV^NH2o`0000OoYkWV0_l000000onY^^Ko
0000oj[1jP06oj[1jP;o00001on/`NT4o`0000So[L;Y0ol000000on[aNco0000o`00000Aojg4jPGo
00006?n[a>`00ol0003oZLC]ojW4k@02o`0000coX/Ga1?l00005oi_5m@Co00001?n<_OL00ol0003o
S;ggohNkn004ohNkn003o`000?n5^_SoQK[h00?oQK[h0_l0000]ooooo`03o`000?oooooooooo02Go
oooo000Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>oooool2o`0000SoY[WV
0_l00007ojNiiP;o00001?nY^^H01?l0003oZ/7Zoj[1j_nZ`NX2o`0000Oo[<7Y0ol00009ojg2j@?o
00000_n^`^T00ol0003o[LCZojg4jP0:ojg4jPSo00001?n^`^P00ol0003o[/;Xojk2j004ojk2j0co
00001On[a>`00ol0003oZLC]ojW4k@05ojW4k@Co00002_nRaO45o`000003oi_5mOl0003oU;od00;o
U;od1?n<_OL01?l0003oS;ggo`000?l00003ohNkn0;o00001On5^_P2o`0002_ooooo00?o0000oooo
ooooool09Oooool002?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0hooooo`;o
00002?nV^NH2o`0000OoYkWV0_l00006ojVjiP?o00001on/`NT3o`0000Wo[L;Y0ol00006ojk2j@03
o`000?n]a>[o[LCZ00?o[LCZ1_l0000<ojk2j003o`000?n^`^So[/;X013o[/;X1_l0000;ojW4k@?o
00001_nRaO43o`0000;oX/Ga0_l00006oiBom004o`000?n<_OOoS;ggo`0000;oS;gg0_l00003ohNk
n0;o00001On5^_P2o`0002Wooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`008_ooool3o`0001Sooooo00?o0000
ooooooooool0=Oooool2o`0000SoY[WV0_l00007ojNiiP;o00001_nY^^H2o`0000?oZkcV00Co0000
ojc1jOn/`NWo[<7Y0_l00009ojg2j@Co00001on^`^T3o`000003ojg4j_l0003o000001Co[/;X00?o
0000ojk2j?n^`^P05On^`^P00ol0003o[l;Xojo2j002o`0000[oZLC]1_l00005oj;5l@03o`000?nM
`O7oWL7a00OoU;od0_l00004ohbmm`;o00000on7^oP2o`0000GoQK[h0_l0000Yooooo`03o`000?oo
oooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`07ooooo`008_ooool00ol0003oooooooooo`0Iooooo`;o0000<oooool2o`0000SoY[WV0_l0
0006ojNiiP?o00001_nY^^H2o`0000GoZkcV0ol00009ojg2j@?o00002?n^`^T3o`0000;o[/;X00?o
0000ojk2j?n^`^P04On^`^P5o`0000Go[/;X1_l0000;ojk2j003o`000?n_`^So[l;X00Go[l;X1Ol0
0003ojW4k@?o000000?oZLC]o`000?l000000_l00002oj;5l@03o`000?nM`O7oWL7a00?oWL7a00?o
0000oiBom?nD_o@00onD_o@2o`0000GoS;gg00?o0000ohNkn?n7^oP00_n7^oP2o`0000GoQK[h0_l0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;_oo
ool3o`0000OoY[WV0_l00006ojNiiP;o00001onY^^H2o`0000GoZkcV0_l00002ojbmiP03o`000?n]
`^Wo[L;Y00Co[L;Y0ol00008ojk2j@?o00001_n^`^P00ol0003o[/;Xojk2j009ojk2j0Oo00001?n_
`>H00ol0003o/KoUok6oi@09ok6oi@_o00003On_`^P4o`0000OoZLC]0_l00008oig1l@03o`000?nD
_oCoU;od00?oU;od0_l00004ohbmm`;o00001?n7^oP2o`0000GoQK[h00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`07ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02co
oooo00Go0000oj6bi?nQ/^CoXK;To`000004ojJiiP;o00001_nW^NH2o`0000OoZK[V0_l00006oj^l
iP03o`000?n/_NKo[;gV00?o[;gV00Co0000ojg2jOn]`^Wo[L;Y0_l00008ojk2j@?o00002On^`^P0
0ol0003o[/;Xojk2j003ojk2j0Ko00002on_`>H00ol0003o/KoUok6oi@0Cok6oi@03o`000?nc`>?o
/l3S00Co00001?n_`^P3o`0000Co[l;X1?l00002ojW4k@05o`000?nW`^goYl;]ojO2kOl000002?nM
`O42o`0000?oU;od0ol00004ohbmm`;o00001?n7^oP00ol0003oQK[hohFjn003ohFjn0;o00009_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02[o
oooo00?o0000oj6bi?nQ/^@00onQ/^@01?l0003oY[WVojJii_l00006ojNiiP;o00001onY^^H2o`00
00KoZkcV0_l00006ojbmiP?o00002?n^`^T3o`0000_o[/;X0ol000000on^`^So0000o`00000Bojo0
iP03o`000?na_nGo/KoU01?o/KoU00?o0000ok?0honc`><01?nc`><4o`0000_o[l;X0_l00006ojO2
k@;o00001onM`O401?l0003oU;odoiBom?l00002oiBom0;o00001?n<_OL2o`0000?oQk_h0_l00005
ohFjn0;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0:ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:?oo
ool00ol0003oXK;Toj6bi004oj6bi0?o00001_nW^NH00ol0003oZK[VojVjiP06ojVjiP03o`000?n[
_>KoZkcV00CoZkcV0_l00006ojbmiP;o000000?o[L3Wo`000?n^`^T01On^`^T3o`0000_o[/;X0ol0
0002ojk2j003o`000?n_`>Ko[l3V00ko[l3V1_l00003ok6oi@So00002Ona_nD00ol0003o/l3Sok?0
h`03ok?0h`?o00000onc`><4o`0000Oo[l;X00Co0000ojo2j?n_`^So00001_nW`^d2o`0000KoWL7a
0_l000000onD_oCo0000oiBom002oiBom003o`000?n<_OOoS;gg00?oS;gg00?o0000ohNkn?n7^oP0
0_n7^oP2o`0000?oQK[h0ol0000Rooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool02_ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00?ooooo0_l0000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oj6bi?nQ
/^@01?nQ/^@01?l0003oX[;Toj:bi?nR/^@2o`0000;oYkWV00?o0000ojVji_nY^^H01_nY^^H2o`00
00GoZkcV0_l00006ojbmiP;o00001?n]`>L01?l0003o[/;Yojk2jOn^`^T2o`0000[o[/;X1?l00006
ojk2j003o`000?n_`>Ko[l3V00;o[l3V2ol00005ojnni@03o`000?nb_>7o/[cQ00Wo/[cQ2_l00002
ok?0h`?o00002_nc`><4o`0000;o[l;X00?o0000ojo2j?n_`^P00on_`^P2o`0000GoYl;]0_l00006
oig1l@?o00000onD_o@2o`0000CoS;gg0_l00002ohNkn0Go00000on1/_@00ol0003oooooooooo`0R
ooooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00009ooooo`00
1oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool09?ooool00ol0003oXK;Toj6bi004oj6b
i003o`000?nR/^CoX[;T00?oX[;T0ol00007ojVjiP;o00001_n[_>H00ol0003o[;gVojbmiP05ojbm
iP03o`000?n]`>Oo[L3W00Co[L3W0ol0000:ojk2j0?o00002?n^`^P3o`000004ojo0i_l0003o0000
o`00013o[kkU00?o0000ok:lhOnb_>404_nb_>47o`0000go/l3S0_l00008ojo2j0;o00001OnW`^d2
o`0000KoWL7a0_l00004oiBom0;o00000_n<_OL4o`0000CoPk?d1On1/_@00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01oooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08_ooool0
0ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00Go0000ojBdi?nT]>CoY;CTo`00
0004ojVjiP;o00001_n[_>H2o`0000Ko[;gV0_l00005ojg0i`;o00000_n^`^P00ol0003o[/;Xojk2
j004ojk2j0Co00002?n^`^P3o`0000;o[/;Y00?o0000ojnniOn__^D03On__^D6o`0000Co/[cQ00?o
0000ok:lhOnb_>402_nb_>43o`0000Oo][gO1?l0000:ok?0h`03o`000?ne`N?o000000So[l;X0_l0
0005ojO2k@;o00001OnM`O43o`0000;oU;od1?l00004ohRel`GoPk?d1On1/_@00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01kooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08?oo
ool00ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBdi?nT]>@00onT
]>@01?l0003oZK[VojVji_l00006oj^liP;o00001_n/_NH2o`0000Go[L3W0_l00005ojk2j004o`00
0?n^`^So[/;Xojk2j0;o00002On^`^P3o`0000Ko[/;Y00?o0000ojnniOn__^D00on__^D9o`0000Go
[[cT00?o0000ok>jgonc^]l00onc^]l9o`000003ok:lhOl0003o000000;o/[cQ00?o0000okJmgonf
_Ml02Onf_Ml3o`0000Ko/l3S00?o0000okG1hone`N<00_ne`N<2o`0000Oo[l;X0_l00005ojO2k@;o
00001?nM`O401?l0003oWL7ao`000?l00003oi6ilP03o`000?n8]O?oR;Gc00?oR;Gc1On3/o@00ol0
003oPK;doh6bm002oh6bm003o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool2o`0002Gooooo00?o0000oooo
ooooool07_ooool00ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBd
i?nT]>@01?nT]>@2o`0000KoZkcV0_l00006ojbmiP;o00001_n]`>L00ol0003o[/;Xojk2j005ojk2
j0?o00002?n^`^P4o`0000So[/;Y0_l000001?n__^Go0000o`000?l0000?ojjli003o`000?nc^]oo
/k[O00[o/k[O1ol0000?okJmg`Co00000_nc`><00ol0003o]L7SokG1h`04okG1h`;o00001on_`^P2
o`0000GoYl;]0_l000001?nM`O7o0000o`000?l00002oi^lk`CoTKWb00?o0000ohRelon8]O<00on8
]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Mooooo`008?ooool2o`0002Oooooo00?o0000ooooooooool07?ooool0
0ol0003oXK;Toj6bi004oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBdi?nT]>@01?nT]>@0
1?l0003oY[KTojJfi?l00004oj^liP03o`000?n/_NKo[;gV00Co[;gV0_l00006ojg0i`;o00001_n^
`^P2o`000003ojo5j_l0003o[/;X00Go[/;X0ol00009ojk2j@?o000000?o[<7Yo`000?n^_>@04_n^
_>@00ol0003o/k[Ook>jg`07ok>jg`?o00001_nc^]l00ol0003o^;_LokRkg005o`0000co][gO0_l0
0009okG1h`;o00001on_`^P2o`0000CoYl;]0_l00002oi^lk`04o`000?nK_>ooVkc_oi^lk`CoTKWb
00?o0000ohRelon8]O<00on8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d
00?o0000ooooooooool07oooool2o`0001kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool06_ooool00ol0003oXK;Toj6bi003oj6bi0;o00001OnR/^@00ol0003oY;CTojBd
i004ojBdi003o`000?nV]^CoY[KT00;oY[KT00Co0000oj^li_n[_>Ko00001_n/_NH00ol0003o[L3W
ojg0i`04ojg0i`;o00001_n^`^P2o`0000Co[lGZ00Co0000ojk2j?n^`^So[/;X0_l00009ojk2j@?o
00001?n/`NT00ol0003o[[cTojjli00<ojjli0Ko00001?nc^]l00ol0003o/k[Oo`000002o`0000Wo
/k[O00?o0000okRkg?nh^m`01Onh^m`4o`0000So][gO00Co0000ok[0g_nj`=ko00002One`N<00ol0
003o[l;Xojo2j006ojo2j0;o000000?oYl;]o`000?nU_n`00_nU_n`2oi^lk`04o`000?nK_>ooVkc_
oi^lk`CoTKWb00?o0000ohRelon8]O<00on8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_Co
PK;d00;oPK;d00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`008?ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo01Sooooo00?o0000oj6bi?nQ/^@00onQ/^@00ol0
003oX[;Toj:bi004oj:bi003o`000?nT]>CoY;CT00CoY;CT00?o0000ojJfi?nV]^@00onV]^@3o`00
00Go[;gV0_l00005ojg0i`;o00001on^`^P00ol0003o[lGZojo5jP04ojo5jP?o00002On^`^T3o`00
00So[<7Y00?o0000ojjli?n^_>@00_n^_>@9o`0000Go[K[S00Co0000ok:hgOnb^=go/[SM2ol00003
ok>jg`03o`000?nh^mco^;_L00[o^;_L1Ol00002okJmg`03o`000?nj`=ko^/3N00?o^/3N0_l00007
okG1h`;o00002?n_`^P00ol0003oYKo/ojFok003ojFok0;oVkc_00Go0000oi^lkonK_>ooVkc_o`00
0003oi6ilP03o`000?n8]O?oR;Gc00?oR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6b
m002oh6bm003o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool0023ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?nQ/^CoXK;T00?oXK;T00?o0000
oj:bi?nR/^@00onR/^@2o`0000KoY;CT00?o0000ojJfi?nV]^@00onV]^@01?l0003oZK[UojVjiOnY
^^D2o`0000;o[;gV00?o0000ojg0ion]`>L00on]`>L2o`0000Oo[/;X0_l00005ojo5jP;o00000_n_
an`00ol0003o[/;Yojk2j@04ojk2j@?o00002On/`NT3o`000004ojjli?l0003o0000o`0000ko[K[S
1?l0000;ok:hg@Co00004Onh^m`2o`0000So^/3N0ol00006okG1h`;o00001?n_`^P01?l0003o[l;X
ojo2j?l00005ojFok003o`000?nK_>oo000000?oVkc_00Go0000oi6il_nA^O;oTKWbo`000005ohRe
l`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01[ooooo000Pooooo`;o0000:oooool00ol0003oooooooooo`0Dooooo`03
o`000?nQ/^CoXK;T00?oXK;T00?o0000oj:bi?nR/^@00onR/^@00ol0003oY;CTojBdi005ojBdi003
o`000?nV]^CoY[KT00?oY[KT00?o0000ojVjiOnY^^D00onY^^D3o`0000Go[L3W00?o0000ojk2j?n^
`^P01On^`^P2o`0000Ko[lGZ00?o0000ojo7k?n_an`00on_an`01?l0003o[/;Yojk2jOn^`^T2o`00
00So[<7Y1?l00002oj[1jP03o`000?n]^^?o[K[S00ko[K[S0ol0000Aok:hg@03o`000?ni^MWo^KWI
00Co00003?nh^m`00ol0003o_KoKo`000009ok[0gP;o00001_ne`N<2o`000003ojo2j?l0003o[l;X
00?o[l;X00?o0000ojFok?nU_n`00onU_n`2o`0000CoVkc_00Go0000oi6il_nA^O;oTKWbo`000005
ohRel`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01[ooooo000Pooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool04_ooool00ol0003oXK;Toj6bi003oj6bi003o`000?nR/^CoX[;T00?oX[;T00?o0000ojBd
i?nT]>@01OnT]>@00ol0003oY[KTojJfi003ojJfi003o`000?nY^^GoZK[U00?oZK[U00Co0000ojbn
ion/_^Oo[;kW0_l00002ojg0i`03o`000?n^`^So[/;X00Co[/;X0_l00006ojo5jP;o00001_n_an`3
o`0000Ko[<7Y1Ol00007oj[1jP03o`000?n]^^?o[K[S00Ko[K[S2Ol0000Aok:hg@03o`000?ni^MWo
^KWI00Go^KWI1?l00007okRkg003o`000?nm_m_o_KoK00;o_KoK00?o0000ok[0g_nj`=h01onj`=h2
o`0000Ko]L7S00?o0000ojo2j?n_`^P01?n_`^P00ol0003oYKo/ojFok003ojFok0;o00001?nK_>l0
1Ol0003oTKWboi6il_nA^O;o000000GoR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6b
m002oh6bm003o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool0023ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`03o`000?nQ/^CoXK;T00?oXK;T00?o0000
oj:bi?nR/^@00onR/^@00ol0003oY;CTojBdi004ojBdi0;o00001OnV]^@00ol0003oZK[UojVji@03
ojVji@03o`000?n/_^Oo[;kW00?o[;kW0_l00006ojk2j0;o00001_n_aNX2o`0000Ko[lO/0_l00002
ojk9kP04o`000?n/`NWo[<7Yojc1j@?o00002onZ`NX3o`000003ojfjhol0003o000000Co000000Co
ZkSSo`000?l0003o00001?n[^><00ol0003o/KKLok6fg002ok6fg0Wo00001?nb^=d00ol0003o^KWI
okVif@09okVif@Co00000_nh^m`00ol0003o_KoKokfof`04okfof`;o00002Onj`=h2o`000003okG1
hol0003o000000?o]lCT1_n_`^P00ol0003oYKo/ojFok003ojFok0;o00001?nK_>l01Ol0003oTKWb
oi6il_nA^O;o000000GoR;Gc00?o0000oh>cm?n3/o@00_n3/o@00ol0003oPK;doh6bm002oh6bm003
o`000?oooooooooo01gooooo0_l0000Jooooo`008?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00kooooo0_l00005oj6bi0GoX[;T00?o0000ojBdi?nT]>@01?nT]>@00ol0003oY[KT
ojJfi004ojJfi003o`000?nY^^GoZK[U00?oZK[U00?o0000ojbnion/_^L00on/_^L01?l0003o[/;X
ojk2j?l00004ojk2j003o`000?n_aN[o[lGZ00Co[lGZ0_l00006ojo7k0;o00001?n^bNh3o`0000_o
Z/7Z1?l00002ojO0j`03o`000?n[^>?oZkSS00?oZkSS0ol00007oj^hh`03o`000?na]]co/KKL00_o
/KKL1?l0000@okVif@;o00002Onm_m/2o`0000Wo^/3N00?o0000okO4i?nga>@01?nga>@00ol0003o
[l;Xojo2j003ojo2j003o`000?nU_ncoYKo/00?oYKo/0_l00004oi^lk`05o`000?nA^O;oTKWboi6i
l_l000001On8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;oPK;d00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Hooooo`007oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo00gooooo00Co0000oiR/iOl0003o00000_nQ/^@5oj:bi003o`000?nT]>CoY;CT
00CoY;CT00?o0000ojJfi?nV]^@00onV]^@2o`0000GoZK[U00?o0000ojbnion/_^L00on/_^L00ol0
003o[/;Xojk2j002ojk2j004o`000?n^`^So[/;Xo`0000Go[lGZ0_l00006ojo7k0;o00001?n^bNh2
o`0000;oZl[`00?o0000oj[1j_nZ`NX01OnZ`NX4o`0000KoYl3[00?o0000oj^hhon[^><00ol0000:
oj^hh`03o`000?na]]co/KKL00ko/KKL00?o0000okVgf?ni]mP01?l0000;okVif@03o`000?no_]So
000000Wo_KoK0_l00006ok[0gP03o`000?nmaN3o000000Ko]lCT00?o0000ojo2j?n_`^P00on_`^P0
0ol0003oYKo/ojFok003ojFok003o`000?nK_>ooVkc_00?oVkc_00Go0000oi6il_nA^O;oTKWbo`00
0005ohRel`03o`000?n3/oCoPk?d00;oPk?d00?o0000oh6bm?n1/_@00_n1/_@00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Oooooo000Oooooo`;o0000<Oooool00ol0003oooooooooo`0;
ooooo`03o`000?nH[>GoV:cU00;oV:cU0_l00005oj:bi0KoY;CT00?o0000ojJfi?nV]^@00onV]^@0
0ol0003oZK[UojVji@04ojVji@03o`000?n/_^Oo[;kW00?o[;kW00?o0000ojk2j?n^`^P00on^`^P3
o`0000Go[lGZ00?o0000ojo7k?n_an`01On_an`00ol0003o[/W^ojk9kP02ojk9kP;o00001On[b_00
1?l0003oZ/7Zoj[1j_nZ`NX3o`0000[oYl3[0ol00006oj^hh`So00000ona]]`00ol0003o/KKLok6f
g00:ok6fg003o`000?ni]mSo^KOH00Co^KOH0ol00007okVif@03o`000?no_]So_kkH00;o_kkH0_l0
0008okfof`03o`000?nj`=ko^/3N00;o^/3N00Go0000okg5h?nmaN3o_LGPo`000006okO4i003o`00
0?n_`^So[l;X00?o[l;X00?o0000ojFok?nU_n`00onU_n`00ol0003oVkc_oi^lk`03oi^lk`05o`00
0?nA^O;oTKWboi6il_l000001On8]O<00ol0003oPk?doh>cm002oh>cm003o`000?n1/_CoPK;d00;o
PK;d00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`007oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00[ooooo00?o0000oiR/iOnH[>D00_nH[>D01?l0003oVZgT
o`000?l00002oj:bi0KoY;CT00?o0000ojJfi?nV]^@00onV]^@00ol0003oZK[UojVji@04ojVji@03
o`000?n/_^Oo[;kW00?o[;kW00?o0000ojk2j?n^`^P00on^`^P01?l0003o/LO[ok77jonaan/2o`00
00;o[lGZ00?o0000ojo7k?n_an`01?n_an`2o`0000?o[/W^0_l00007oj_:l0?o00002onW`>/5o`00
0003oj^hhol0003o000000Co00001onX]n@00ol0003o[kCLojndg002ojndg0So00000ona]]`00ol0
003o^KOHokVgf008okVgf0Co00000_ni^MT00ol0003o_kkHoknnf005oknnf0;o00001onm_m/2o`00
0003ok[0g_l0003o_LGP00Co_LGP00?o0000okO4i?nga>@01?nga>@00ol0003o[l;Xojo2j003ojo2
j003o`000?nU_ncoYKo/00?oYKo/00?o0000oi^lkonK_>l00onK_>l01Ol0003oTKWboi6il_nA^O;o
000000?oR;Gc3Ol0000Nooooo`03o`000?oooooooooo01Kooooo000Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool02?ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT
00;oVZgT0_l00005ojBdi003o`000?nV]^CoY[KT00?oY[KT00?o0000ojVjiOnY^^D01?nY^^D00ol0
003o[;kWojbni`03ojbni`03o`000?n^`^So[/;X00?o[/;X00?o0000ok77jonaan/00onaan/3o`00
00Go[lO/0_l00003ojk9kP;o00001on[b_02o`000003ojS;l_l0003oYl3[00SoYl3[1Ol00002oj>n
k@03o`000?nX]nCoZ;OT00coZ;OT00?o0000ojndg?n_]=`02_n_]=`4o`0000ko^KOH0_l0000:oknn
f0;o00001onm_m/00ol0003o_LGPokg5h005okg5h003o`000?nga>Co]lCT00Co]lCT00?o0000ojo2
j?n_`^P00on_`^P00ol0003oYKo/ojFok003ojFok004o`000?nK_>ooVkc_oi^lk`Wo00000_n:[nh5
ohJ/kPGoQ:_^00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`007oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo00?o0000oiR/iOnH[>D00onH[>D00ol0
003oVZgToiZ]i002oiZ]i003o`000?nL[nCo000000;o00000_nT]>@5ojJfi003o`000?nY^^GoZK[U
00CoZK[U00?o0000ojbnion/_^L00on/_^L00ol0003o[/;Xojk2j003ojk2j003o`000?naan_o/LO[
00?o/LO[00Co0000ok;<kOnbc>go//c]0_l00002ojo7k004o`000?n^bNko[/W^ojk9kP;o00001on[
b_02o`0000CoZ<_b00Co0000ojO0jonW`>_oYl3[1_l00007oj>nk@03o`000?nX]nCoZ;OT00_oZ;OT
00?o0000ojndg?n_]=`03On_]=`00ol0003o]kKHo`000002o`0000_o^KOH00Co0000ol2meol0003o
00002Ono_]P2o`0000Co_KoK00?o0000ol;5g?o2aM`01onmaN000ol0003o]lCTokO4i004okO4i003
o`000?n_`^So[l;X00?o[l;X00?o0000ojFok?nU_n`00_nU_n`4o`0000;oVkS/1?nB/nd6ohZ_kPGo
QZc^1On4Znh00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eooooo`;o0000
1_ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT00;oVZgT00?o0000oib_i?nL[n@0
0onL[n@2o`0000GoY[KT1_nY^^D00ol0003o[;kWojbni`03ojbni`03o`000?n^`^So[/;X00?o[/;X
00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<k@Co00000_n^bNh00ol0003oZl[`
oj_:l004oj_:l0?o00001_nXbo87o`0000SoXkk]0ol000000onX]nCo0000o`00000;o`0000ko[kCL
00?o0000okNff?ng]]P00ong]]P3o`0000Oo^KOH00?o0000ol2meoo0_ML00_o0_ML2o`0000Wo_kkH
0_l000000onm_m_o0000ol;5g003ol;5g003o`000?nmaN3o_LGP00Co_LGP00?o0000okO4i?nga>@0
1?nga>@00ol0003o[l;Xojo2j003ojo2j006o`000?nU_nco0000o`000?nU_N_o00001OnK^>`4oi:c
k@GoRZo^00?o0000ohJ/k_n6[>h00_n6[>h00ol0003oQ:_^ohB[kP02ohB[kP03o`000?oooooooooo
01gooooo00?o0000ooooooooool05?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`02ooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000oiZ]i?nJ[N@00_nJ[N@00ol0003o
W:oToib_i003oib_i004o`000?nP/^Go0000o`0000;oY[KT1_nY^^D00ol0003o[;kWojbni`03ojbn
i`03o`000?n^`^So[/;X00?o[/;X00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<
k@04o`000?nbd>oo/]3_ok;@k`?o00001On[b_02o`0000KoZ<_b0ol000001?nTb_Co0000o`000?l0
0006oj>nk@Go00000_nN_Nh00ol0003oY;GUojBei@0;ojBei@03o`000?n//]go[;;M00Go00001on_
]=`00ol0003o]kKHokNff006okNff0?o00001?ni]mP00ol0003o`;gGol2me`04ol2me`;o00002Ono
_]P00ol0003o`/GLol;5g004ol;5g003o`000?nmaN3o_LGP00Co_LGP00?o0000okO4i?nga>@01?ng
a>@01?l0003o[l;Xojo2j?n_`^P3o`0000CoYKg[00?o0000oi^hk?nK^>`00_nK^>`01Ol0003oT[?]
oi:ckOnB/ngo000000CoRZo^00?o0000ohJ/k_n6[>h00_n6[>h00ol0003oQ:_^ohB[kP02ohB[kP03
o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool001kooooo00?o0000ooooooooool0
>?ooool01Ol0003ooooooooooooooooo000000CoV:cU00?o0000oiZ]i?nJ[N@00_nJ[N@00ol0003o
W:oToib_i003oib_i003o`000?nP/^GoX;;U00;oX;;U0_l00005ojVji@03o`000?n/_^Oo[;kW00?o
[;kW00?o0000ojk2j?n^`^P00on^`^P00ol0003o/LO[ok77j`03ok77j`03o`000?nbc>go//c]00?o
//c]00Go0000ok;@konbd>oo/]3_o`000003ok;ClP;o00000_n[b_000ol0003oZ<_bojS;lP04ojS;
lP;o000000CoY<[do`000?l0003o00000_nTb_@01?l0003oXkk]oj>nkOnS_^d3o`0000OoW[g^00?o
0000ojBeiOnT]ND02onT]ND00ol0003o[;;Mojbbg@05ojbbg@Go00000_n_]=`00ol0003o]kKHokNf
f009okNff0?o000000?o^KOHo`000?o0_ML01oo0_ML00ol0003o_kkHoknnf005oknnf003o`000?o5
aM[o000000Ko`/GL0_l00005okg5h003o`000?nga>Co]lCT00?o]lCT1?l00002ojo2j0GoYKg[0_l0
0004oi^hk005o`000?nB/ngoT[?]oi:ckOl000001?n:[nh00ol0003oQZc^ohJ/kP02ohJ/kP03o`00
0?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
o`000005oiR/i@03o`000?nJ[NCoVZgT00;oVZgT00?o0000oib_i?nL[n@00onL[n@00ol0003oX;;U
oj2bi@02oj2bi@03o`000?nU]nKo000000;o00000_nY^^D5ojbni`03o`000?n^`^So[/;X00?o[/;X
00?o0000ok77jonaan/00onaan/00ol0003o//c]ok;<k@03ok;<k@05o`000?nbd>oo/]3_ok;@kol0
00001Onbdo83o`0000GoZ<_b1Ol00005ojC:m0?o00003?nN_Nh00ol0003oY;GUojBei@0:ojBei@03
o`000?n//]go[;;M00[o[;;M0_l0000?okNff003o`000?o0_MOo`;gG00So`;gG0_l00004oknnf005
o`000?o5aM[oaLGJolG5f_l000001oo2aM`00ol0003o_LGPokg5h003okg5h006o`000?nga>Co]lCT
okO4i?l0003o^<OU1_n_`^P5ojFmj`03o`000?nK^>coVkS/00;oVkS/00Go0000oi:ckOnB/ngoT[?]
o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01;ooooo000Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`0jooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000oiZ]i?nJ[N@0
0_nJ[N@00ol0003oW:oToib_i003oib_i003o`000?nP/^GoX;;U00;oX;;U00?o0000ojFgi_nU]nH0
0onU]nH2o`0000Co[;kW00?o0000ojk2j?n^`^P00on^`^P00ol0003o/LO[ok77j`03ok77j`03o`00
0?nbc>go//c]00?o//c]00Go0000ok;@konbd>oo/]3_o`000005ok;ClP05o`000?n_e_Co[mKdojoF
m?l000000_nXbo84o`0000GoY<[d0ol00002oik9mP03o`000?nN_NkoW[g^00CoW[g^1ol000000onT
]NGo0000o`00000:o`0000go[;;M00?o0000okBdf?nd]=P00ol0000:okNff004o`000?no_=Ko0000
o`0000Wo`;gG0_l000000ono_]So0000olG5fP04olG5fP03o`000?o2aMco`/GL00Go`/GL00?o0000
okg5h?nmaN000onmaN000ol0003o]lCTo`000003okS7i@Go[l;X00?o0000ojFmjonU_N/00_nU_N/2
o`0000CoVkS/00Go0000oi:ckOnB/ngoT[?]o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00?o
0000ohB[k_n4Znh00_n4Znh00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l0
00000ol@413oooooooooo`03ooooo`004oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0>_ooool00ol0003oV:cUoiR/i@02oiR/i@03o`000?nJ[NCoVZgT00?oVZgT00?o
0000oib_i?nL[n@00_nL[n@00ol0003oX;;Uoj2bi@03oj2bi@03o`000?nU]nKoYKOV00?oYKOV00Co
0000ojZliol0003o00000_n/_^L5ojk2j003o`000?naan_o/LO[00?o/LO[00?o0000ok;<kOnbc>d0
0_nbc>d2o`0000?o/]3_00?o0000ok;Cl_nbdo800onbdo800ol0003o[mKdojoFm002ojoFm0Co0000
1OnTb_@3o`0000CoW/Wf2?l00006oiRjl003o`000?nO/nKoWk?V00[oWk?V00?o0000ojRagonX/Ml0
1Ol00006ojbbg@03o`000?nd]=So];CH00?o];CH0ol00006okNff003o`000?no_=Ko_kcF00;o_kcF
0_l00009ol2me`03o`000?o5aM[oaLGJ00GoaLGJ00?o0000ol;5g?o2aM`01Oo2aM`00ol0003o_LGP
okg5h002okg5h0;o00001?nhanD00ol0003o[l;Xojo2j003ojo2j003o`000?nU_N_oYKg[00;oYKg[
0_l00003oi^hk005o`000?nB/ngoT[?]oi:ckOl000001?n:[nh00ol0003oQZc^ohJ/kP02ohJ/kP03
o`000?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07Oooool00ol0003oooooo`00000:ooooo`03
o`000?oooooooooo00Gooooo000Cooooo`05o`000?ooooooooooooooool000001Oooool3o`0003[o
oooo00?o0000oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?o
W:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;o
Z[cW1?l00003ojk2j0Go/LO[00?o0000ok;<kOnbc>d00_nbc>d00ol0003o/]3_ok;@k`02ok;@k`03
o`000?nbdo;o/]?b00?o/]?b00Co0000ojoFm?n_e_Co[mKd0ol00002oj_FmP;o00000_nTb_@2o`00
00CoW/Wf0ol00003oiO6m`03o`000?nH^_3oV;[`00WoV;[`00?o0000oinci_nO/nH02OnO/nH00ol0
003oZ;7OojRag`05ojRag`Co000000?o[;;Mo`000?nd]=P02?nd]=P3o`0000;o]kKH00?o0000oknl
e_no_=H01Ono_=H00ol0003o`;gGol2me`05ol2me`03o`000?o6aMWoa/GI00OoaLGJ00?o0000ol;5
g?o2aM`01Oo2aM`01_l0003o_LGPo`000?l0003o_l[So`0000Go^<OU00?o0000ojo2j?n_`^P00_n_
`^P00ol0003oYKg[ojFmj`02ojFmj`03o`000?nK^>co000000?oVkS/00Go0000oi:ckOnB/ngoT[?]
o`000004ohZ_kP03o`000?n6[>koQZc^00;oQZc^00Go0000ohB[k_n4ZnkoQ:_^o`00000Qooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03[ooooo00?o0000oiR/iOnH[>D00_nH[>D00ol0003o
VZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000oj2biOnP/^D00onP/^D00ol0003o
YKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;oZ[cW00Co0000ojo3j?n_`nSo[l?X0ol00004ok77
j`03o`000?nbc>go//c]00;o//c]00?o0000ok;@konbd>l00_nbd>l00ol0003o/]?bok;ClP02ok;C
lP;o000000?o[mKdo`000?l000000_l00005oj_FmPCo00000_nNbOH3o`0000OoUlKg00?o0000oiRj
l?nH^_000onH^_06o`000003oinci_l0003o000000?o00001OnO/nH00ol0003oZ;7OojRag`09ojRa
g`;o00003?nd]=P2o`0000Wo_kcF0_l00004ol2me`03o`000?o6aMWoa/GI00;oa/GI00?o0000olG5
f_o5aMX01?o5aMX00ol0003o`/GLol;5g004ol;5g0;o00001?nob^<00ol0003o^<OUokS7i@02okS7
i@03o`000?n_`^So[l;X00?o[l;X00?o0000ojFmjonU_N/00_nU_N/2o`0000?oVkS/00?o0000oi:c
kOnB/nd00_nB/nd01Ol0003oRZo^ohZ_k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
01?ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Wooooo00?o0000
oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000
oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW00;oZ[cW00?o0000
ojo3j?n_`nP00on_`nP01?l0003o/lWZo`000?l00002ok77j`Co//c]00?o0000ok;@konbd>l00_nb
d>l00ol0003o/]?bok;ClP02ok;ClPCo000000?o[mKdo`000?l000001On[e_H01?l0003oYMKhojGF
n?nUe_P3o`0000WoUlKg1ol00005oi6hl@03o`000?nH/NSoV;7X00CoV;7X1_l0000<ojRag`03o`00
0?na/m[o000000;o00002Ond]=P01?l0003o_K_Go`000?l00008oknleP;o000000?o`;gGo`000?o6
aMT01Oo6aMT00ol0003oaLGJolG5fP04olG5fP04o`000?o2aMco`/GLol;5g0;o000000?oaLgPo`00
0?nob^<00onob^<00ol0003o^<OUokS7i@03okS7i@03o`000?n_`^So[l;X00;o[l;X00?o0000ojFm
jonU_N/00_nU_N/00ol0003oVkS/o`000002oi^hk003o`000?nB/ngoT[?]00;oT[?]00Go0000ohZ_
k_n:[nkoRZo^o`000004ohJ/kP03o`000?n4ZnkoQ:_^00;oQ:_^00?o0000ooooooooool07oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`03o`000?nH[>GoV:cU00?oV:cU00?o0000
oiZ]i?nJ[N@00_nJ[N@00ol0003oW:oToib_i003oib_i003o`000?nP/^GoX;;U00?oX;;U00?o0000
ojFgi_nU]nH00onU]nH00ol0003oZ[cWojZli`02ojZli`03o`000?n_`nSo[l?X00;o[l?X00?o0000
ok?9j_ncbNX00_ncbNX3o`0000?o//c]1Onbd>l3ok;ClP?o00000on_e_@00ol0003oZmKfoj_FmP03
oj_FmP;o00000onUe_P01?l0003oW]?joikCn_nNdoX2o`0000;oUlKg1Ol00003ohk2n003o`000?nA
^?7oTKSa00OoTKSa00?o0000oiRaj?nH/NP02?nH/NP00ol0003oX[3Roj:`hP04o`0000GoZ;7O00?o
0000ok6cf_na/mX00ona/mX3o`0000Go];CH00?o0000okfkeonm^mL00_nm^mL2o`0000So_kcF00?o
0000olK5fOo6aMT01_o6aMT00ol0003oaLGJolG5fP04olG5fP03o`000?o2aMco000000CoaLgP00?o
0000oko:honob^<00_nob^<00ol0003o^<OUokS7i@03okS7i@05o`000?n_`^So[l;Xojo2j?l00000
1OnU_N/00ol0003oVkS/o`000002oi^hk003o`000?nB/ngoT[?]00;oT[?]00Go0000ohZ_k_n:[nko
RZo^o`000004ohJ/kP05o`000?n4ZnkoQ:_^ohB[k_l000008_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo000Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`00
03Wooooo00?o0000oiR/iOnH[>D00onH[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT
00?oW:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW
00;oZ[cW00?o0000ojo3j?n_`nP00_n_`nP00ol0003o/lWZok?9jP03ok?9jP03o`000?ngcnco]lo/
00co00001?n_e_@00ol0003oZmKfoj_FmP02oj_FmP;o00000onUe_P2o`0000GoW]?j0ol00007ohk2
n0go00000_nH/NP00ol0003oV;7XoiRaj004oiRaj003o`000?nR/>;oX[3R00CoX[3R0ol00002ojRa
g`03o`000?na/m[o/K?J00Ko/K?J0ol000000ond]=So0000okfke`06okfke`03o`000?no_=Ko_kcF
00Go_kcF00?o0000olK5f?l000001oo6aMT00ol0003oaLGJolG5fP03olG5fP;o00001Oo5cN000ol0
003o_l[Soko:h`02oko:h`03o`000?nhanGo^<OU00?o^<OU00?o0000ojo2j?n_`^P00_n_`^P00ol0
003oYKg[ojFmj`02ojFmj`06o`000?nK^>coVkS/o`000?nK^>co00001?nB/nd01Ol0003oRZo^ohZ_
k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0003oooooooooo`0Oooooo`;o0000
1oooool00ol0003oooooooooo`05ooooo`007Oooool00ol0003oooooooooo`0gooooo`;o00001?nH
[>D00ol0003oVZgToiZ]i002oiZ]i003o`000?nL[nCoW:oT00?oW:oT00?o0000oj2biOnP/^D00onP
/^D00ol0003oYKOVojFgiP03ojFgiP05o`000?nZ_>OoZ[cWojZliol000001On_`nP00ol0003o/lWZ
ok?9jP02ok?9jP03o`000?ngcnco]lo/00;o]lo/00Co0000ok[DkOnje>go^]C]0ol000000onkfNoo
0000o`000002o`0000?o[mKd1?n[e_H00ol0003oYMKhojGFn002ojGFn003o`000?nNdo[oW]?j00?o
W]?j0_l00003oiG>n`03o`000?n>`_SoS/;h00Co00000on6_OT00ol0003oR;CbohRdlP06ohRdlP04
o`000?nA[n_oTJo[oi6_j`Go000000?oV;7Xo`000?nR/>802?nR/>82o`0000co/K?J00?o0000okfk
eonm^mL01onm^mL2o`0000Co_kcF00Go0000olK5f?o6aMSoa/GHo`000007olK5f@07o`000?o5aM[o
aLGJolG5f_l0003ob<kNo`000006olG=h003o`000?nob^?o_l[S00;o_l[S00?o0000okS7iOnhanD0
0onhanD01Ol0003o[l;Xojo2j?n_`^So000000GoYKg[00?o0000oi^hk?l000000_nK^>`00ol0003o
T[?]oi:ck@02oi:ck@05o`000?n:[nkoRZo^ohZ_k_l000001?n6[>h01Ol0003oQ:_^ohB[k_n4Znko
0000023ooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`000007ooooo`007Oooool00ol0
003oooooooooo`0gooooo`;oSZWX0ol000000onH[>Go0000oiZ]i003oiZ]i003o`000?nL[nCoW:oT
00?oW:oT00?o0000oj2biOnP/^D00_nP/^D00ol0003oYKOVojFgiP03ojFgiP03o`000?nZ_>OoZ[cW
00;oZ[cW00?o0000ojo3j?n_`nP00_n_`nP00ol0003o/lWZok?9jP03ok?9jP05o`000?ngcnco]lo/
okO?k?l000000_nje>d3o`0000Co^mW_00?o0000ok[LlOnjg?402Ol00003ojGFn0GoW]?j00?o0000
oiG>nonEc_/00onEc_/3o`0000SoQ[gi00?o0000ohRdl_n8]?801_n8]?800ol0003oTJo[oi6_j`05
oi6_j`;o00002_nR/>800ol0003o[;;Mo`000002o`0000So/K?J00Co0000okZjfOl0003o00002?nm
^mL2o`000003oknle_l0003oa/GH00Coa/GH0_l00006olK5f@03o`000?o5aM[o000000?ob<kN00?o
0000olG=h?o5cN000oo5cN000ol0003o_l[Soko:h`03oko:h`03o`000?nhanGo^<OU00;o^<OU00?o
0000ojo2j?n_`^P00_n_`^P00ol0003oYKg[ojFmj`02ojFmj`06o`000?nK^>coVkS/o`000?nK^>co
00001?nB/nd01Ol0003oRZo^ohZ_k_n:[nko000000CoQZc^00?o0000ohB[k_n4Znh00_n4Znh00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo000Looooo`03o`000?oooooooooo03So
oooo1On>ZNP2o`0000?oVZgT00?o0000oib_i?nL[n@00onL[n@00ol0003oX;;Uoj2bi@03oj2bi@03
o`000?nU]nKoYKOV00;oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3j003ojo3j003
o`000?ncbN[o/lWZ00;o/lWZ00?o0000okO?k?ngcn`00_ngcn`3o`000003ok[DkOl0003o^mW_00?o
^mW_00?o0000ok[LlOnjg?400_njg?400ol0003o^=gcokSMl`02okSMl`03o`000?ncgOGo/mge00Co
00000_nNdoX2o`0000CoULkk0_l00003oh_8o0;o00001?n6_OT<o`0000SoTJo[00Co0000oi^^iOnK
[^GoVjkU1Ol000000onR/>;o0000ojbbg@04ojbbg@?o00001?na/mX00ol0003o^[[IokZjf@02okZj
f@;o00002?nm^mL00ol0003oa/GHolK5f006olK5f003o`000?o6aMWoa/GI00Coa/GI00?o0000olS>
g_o8c]h00oo8c]h00ol0003oaLgPolG=h003olG=h003o`000?nob^?o_l[S00;o_l[S00?o0000okS7
iOnhanD00onhanD01Ol0003o[l;Xojo2j?n_`^So000000?oYKg[4?l00004ohJ/kP03o`000?n4Znko
Q:_^00;oQ:_^00?o0000ooooooooool07oooool3o`0000gooooo000Looooo`03o`000?oooooooooo
03Sooooo1On>ZNP2ohnYi`;o000000?oVZgTo`000?nL[n@00onL[n@00ol0003oX;;Uoj2bi@03oj2b
i@03o`000?nU]nKoYKOV00?oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3j002ojo3
j003o`000?ncbN[o/lWZ00;o/lWZ00?o0000okO?k?ngcn`00ol00004ok[Dk@05o`000?nkfNoo^mW_
ok_Ikol000001?njg?400ol0003o^=gcokSMl`02okSMl`03o`000?ncgOGo/mge00;o/mge00?o0000
ojgKn?n]foP01?l00002oiG>n`;o00001_n;b?`5o`0000?oO;Oh00?o0000oh2`lon0/?<01On0/?<0
0ol0003oR:g]ohR]k@05o`000003oi6_jol0003oVjkU00OoVjkU0_l00008ojbbg@?o000000?o/K?J
o`000?nj^]T01Onj^]T2o`0000Co_K_G00Co0000olC4f_o4a=[o00002?o6aMP01ol0003oa/GIolK5
fOo6aMWo0000ol_?gOl000001Oo8c]h00ol0003oaLgPolG=h003olG=h003o`000?nob^?o_l[S00?o
_l[S00?o0000okS7iOnhanD00_nhanD00ol0003o[l;Xojo2j005o`0000;oY[cY0onM]NT00ol0003o
WKGYoiJ_j004oiJ_j0?oT:_X2ol0000Nooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`00
7?ooool2o`0003Wooooo00?o0000ohjYj?n>ZNP00_n>ZNP4ohnYi`Co00000_nL[n@00ol0003oX;;U
oj2bi@03oj2bi@03o`000?nU]nKoYKOV00;oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?X
ojo3j002ojo3j003o`000?ncbN[o/lWZ00?o/lWZ0ol00002okO?k005o`000?nje>go^]C]ok[DkOl0
00001?nkfNl01Ol0003o^]caok[LlOnjg?7o000000Co^=gc00?o0000ok?MmOncgOD00_ncgOD00ol0
003o[M_hojgKn002ojgKn003o`000?nTeo[oY=Oj00Co00000on;b?`3o`0000?oPL3l00?o0000ogbg
n?ml]oP00oml]oP00ol0003oP;3coh2`l`05oh2`l`03o`000?n8[NgoR:g]00CoR:g]0_l00009oi^^
i@04o`000?nU/N7o0000o`0000So[;;M00?o0000okZjfOnj^]T01onj^]T2o`000003okfkeol0003o
a<CJ00?oa<CJ00?o0000olK5f?o6aMP01_o6aMP00ol0003oa/GIo`000003ol_?g@03o`000?o8c]ko
b<kN00?ob<kN00?o0000olG=h?o5cN000_o5cN000ol0003o_l[Soko:h`03oko:h`04o`000?nhanGo
^<OUokS7i@Co00000_n_`nP00ol0003oY[cYojJlj@02ojJlj@05o`000?nM]NWoWKGYoifejOl00000
1OnF[nP4oi2[j0GoS:SX1?n;Z>P2o`0001[ooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo
000Looooo`03o`000?oooooooooo03Sooooo00?o0000ohjYj?n>ZNP00_n>ZNP4ohnYi`CoTjcW0ol0
0004oj2bi@03o`000?nU]nKoYKOV00?oYKOV00?o0000ojZlionZ_>L00_nZ_>L00ol0003o[l?Xojo3
j002ojo3j003o`000?ncbN[o/lWZ00?o00001?ngcn`01Ol0003o^]C]ok[DkOnje>go000000Co^mW_
00?o0000ok[LlOnjg?400_njg?401Ol0003o^=gcokSMlonhgO?o000000Co/mge00?o0000ojgKn?n]
foP00_n]foP01Ol0003oY=OjojCGn_nTeo[o000000?oVM7k0ol00006oh70o0oo00001on8[Nd00ol0
003oTZgXo`000002o`0000CoVjkU00?o0000ojFahOnU/N400_nU/N43o`0000Co[;;M00?o0000okBi
gOnd^Md00_l00008okZjf@03o`000?o4a=[oa<CJ00Coa<CJ00?o0000olK5f?o6aMP01_o6aMP00ol0
003obloMol_?g@02ol_?g@03o`000?o8c]kob<kN00?ob<kN00?o0000olG=h?o5cN000oo5cN000ol0
003o_l[Soko:h`02oko:h`Co00000_ngbNL01Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000
oifejOnM]NT00_nM]NT00ol0003oUZoXoiJ_j002oiJ_j004o`000?n@ZnSoT:_Xoi2[j0GoS:SX1On;
Z>P00ol0003oooooooooo`0Eooooo`?o00002?ooool00ol0003oooooooooo`0;ooooo`007?ooool0
0ol0003oooooooooo`0hooooo`03o`000?n>ZNSoSZWX00;oSZWX00Co0000ohnYion?ZNOoSjWW1OnC
[>L2oiV`j0?o000000?oX;;Uo`000?nU]nH00onU]nH00ol0003oZ[cWojZli`02ojZli`03o`000?n_
`nSo[l?X00;o[l?X1?l00002ok?9jP05o`000?ngcnco]lo/okO?k?l000000onje>d00ol0003o^mW_
ok_Ik`02ok_Ik`03o`000?njg?7o^]ca00;o^]ca00?o0000okSMlonhgO<00_nhgO<01Ol0003o/mge
ok?MmOncgOGo000000Co[M_h00Go0000ojCGn_nTeo[oY=Ojo`000004oiWAn`03o`000?n=b?coSLSl
00;o000000CoPL3lo`000?l0003o00000omf^?X00ol0003oLk7hog>an002og>an003o`000?mf[?Co
MZcd00?oMZcd00?o0000ogjZl?mnZ_001?l000000on8[Ngo0000oi:]j003oi:]j0?o000000?oVjkU
o`000?nU/N401_nU/N42o`000003ojbbgOl0003o];WM00Co];WM0_l00006okZjf@;o00001_o4a=X0
0ol0003oa/GHolK5f003olK5f003o`000?o;d=ko000000GobloM00?o0000olS>g_o8c]h00oo8c]h0
0ol0003oaLgPolG=h002olG=h003o`000?nob^?o000000;o000000?o_/oVo`000?ngbNL00ongbNL0
1Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT00_nM]NT2o`0000?oUZoX00Go
0000oi2[j?n@ZnSoT:_Xo`000004ohbXj003o`000?n;Z>SoRjSX00;oRjSX00?o0000ooooooooool0
4Oooool4o`0000_ooooo00?o0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?oo
ool01Ol0003oSZWXohjYj?n>ZNSo000000CoSjWW00?o0000oi>/ionC[>L00_nC[>L5oiV`j0Co0000
0_nU]nH01Ol0003oZ[cWojZlionZ_>Oo000000?o[l?X0ol00004ok?9jP03o`000?ngcnco]lo/00;o
]lo/00Go0000ok[DkOnje>go^]C]o`000004ok_Ik`03o`000?njg?7o^]ca00;o^]ca00Go0000okSM
lonhgO?o^=gco`000003ok?Mm@03o`000?n]foSo[M_h00;o[M_h00Go0000ojCGn_nTeo[oY=Ojo`00
0004oiWAn`03o`000?n=b?coSLSl00?oSLSl1?l00003ogJhnP[o00000_mf[?@00ol0003oOZ[`ogjZ
l003ogjZl0;o00001onB[NP00ol0003oYK7QojFah@08ojFah@03o`000?nd^Mgo];WM00Ko];WM00?o
0000okZjfOnj^]T00_nj^]T01?l0003o`L?Lol73g?l00006olC4fP05o`000?o6aMSoa/GHolK5f?l0
00000oo;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00?ob<kN00Co0000olG=h?o5
cN3oaLgP0_l00004okk?iP03o`000?ngbNOo]lWW00;o]lWW00Go0000ojo3j?n_`nSo[l?Xo`000004
ojJlj@03o`000?nM]NWoWKGY00;oWKGY0_l00003oiJ_j005o`000?n@ZnSoT:_Xoi2[j?l000001?n<
Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oo
oooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000ohjYj?n>ZNSoSZWXo`00
0004ohnYi`03o`000?nC[>OoTjcW00;oTjcW1OnI/>P4oj2fj0Co00000_nZ_>L4o`000003ojo3j?l0
003o/lWZ00?o/lWZ00?o0000okO?k?ngcn`00_ngcn`01Ol0003o^]C]ok[DkOnje>go000000Co^mW_
00?o0000ok[LlOnjg?400_njg?400ol0003o^=gco`00000Go`0000;oSLSl00?o0000oh2onon0_o/0
0_n0_o/3o`0000?oK:oi00Go0000ofZZm_mZZ_KoJZ[fo`000002offWm0?o00001_mnZ_000ol0003o
Qj_/ohN[k003o`0000;oTZgX00?o0000oib`i_nL/>H00ol00005ojFah@03o`000?n]^>7o000000Oo
];WM0_l000000onj^]Wo0000ol73g003ol73g003o`000?o4a=[oa<CJ00Coa<CJ00?o0000olK5f?l0
00001?o;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00?ob<kN00Ko0000olG=h?l0
003o0000olCCiOl00004okk?iP03o`000?ngbNOo]lWW00;o]lWW00Go0000ojo3j?n_`nSo[l?Xo`00
0004ojJlj@03o`000?nM]NWoWKGY00;oWKGY00?o0000oiJ_j?l000000_nF[nP01Ol0003oT:_Xoi2[
j?n@ZnSo000000CoS:SX00?o0000oh^Xj?n;Z>P00_n;Z>P00ol0003oooooooooo`0;ooooo`?o0000
4oooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0iooooo`05o`000?n>
ZNSoSZWXohjYj?l000001?n?ZNL00ol0003oTjcWoi>/i`02oi>/i`03o`000?nI/>SoVK3X00;oVK3X
1OnP]^P00ol0003oYkcXojNlj00:o`0000;o/lWZ00?o0000okO?k?ngcn`00_ngcn`@o`0000;oa=g[
00Go0000ol7Mk_o1gNko`Mg^o`000004ok_Ll005o`000?ncfO?o/mWcok?Ilol000001?nXe?L01?l0
003oVlcioi_<nOnKc?T4o`0000;oP;ok00Co0000og>dn_mc]?[oLkCj0_l00002ofb_n@05o`000?mZ
Z_KoJZ[fofZZm_l000000om]Yo@00ol0003oM:KaogBVl@04o`0000KoQj_/0_l00006oib`iP?o0000
00?oYK7Qo`000?n]^>400_n]^>42o`0000Oo];WM00?o0000ol73g?o1`m`01?o1`m`00ol0003oa<CJ
olC4fP03olC4fP;o00001_o;d=h00ol0003obloMol_?g@03ol_?g@03o`000?o8c]kob<kN00;ob<kN
0_l00003olCCi@03o`000?nncnKo_/oV00;o_/oV00?o0000okO9iongbNL00_ngbNL01Ol0003o[l?X
ojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT00_nM]NT01_l0003oUZoXoiJ_j?l0003oUZoX
o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooo
oooo00Oooooo1?l0000Fooooo`03o`000?oooooooooo00[ooooo000Kooooo`;o0000>Oooool00ol0
003oSZWXohjYj002ohjYj003o`000?n?ZNOoSjWW00;oSjWW00?o0000oi>/ionC[>L00_nC[>L00ol0
003oVK3XoiV`j002oiV`j0GoX;KX0ol000000onW_>So0000ojo3j003ojo3j004o`000?nfbNSo]/WX
okK9j0So00000_o1e>P00ol0003o`mSYol?Hj@02ol?Hj@03o`000?o5fn[oaM_Z00;oaM_Z00?o0000
olCMjoo4gN/00_o4gN/01Ol0003o`Mg^ol7Mk_o1gNko000000Co^mc`00Go0000ok?IloncfO?o/mWc
o`000004ojSDm`03o`000?nKc?WoVlci00;oVlci00?o0000ohg3n_n=`oX01Ol00002og>dnP_o0000
00?oKJOdo`000?mdY_400omdY_400ol0003oQj_/ohN[k005ohN[k004o`000?n@[^[o0000o`0000Ko
W;3V00?o0000ojfhhOn]^>401?n]^>42o`0000?o];WM00Go0000ok_2gonk`]oo^l;Oo`000005ol73
g007o`000?o4a=[oa<CJolC4f_l0003obLoOo`000006ol_@gP03o`000?o;cmgobloM00?obloM00?o
0000olS>g_l000000_l000000oo8enGo0000olCCi@02olCCi@03o`000?nncnKo_/oV00;o_/oV00?o
0000okO9iongbNL00_ngbNL01Ol0003o[l?Xojo3j?n_`nSo000000CoY[cY00?o0000oifejOnM]NT0
0_nM]NT01?l0003oUZoXoiJ_j?nF[nP2o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003o
RjSXoh^Xj002oh^Xj003o`000?oooooooooo00Cooooo0ol0000Jooooo`03o`000?oooooooooo00[o
oooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000ohjYj?n>ZNP00_n>ZNP00ol0003oSjWW
ohnYi`02ohnYi`03o`000?nC[>OoTjcW00;oTjcW00?o0000oiV`j?nI/>P00_nI/>P00ol0003oX;KX
o`000003o`0000?oYkcX00?o0000ojo3j?n_`nP00_n_`nP00ol0003o]/WXokK9j002okK9j003o`00
0?nlcnSo_<oX00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?Hj@03o`000?o5fn[oaM_Z00;o
aM_Z00Go0000olCMjoo4gN_oa=g[o`000004ol7MkP05o`000?nkg?3o^mc`ok_Ll?l000000oncfO<0
0ol0003oZ=CgojSDm`02ojSDm`03o`000?nKc?WoVlci00;oVlci00?o0000ohg3n_n=`oX00_n=`oX0
1?l0003oOKSiogfhnOmm^?T3o`0000;oJ:_g0_l000001_mSYoKo0000of:TmOmRY?Go0000ofBSl`;o
00000_mdY_400ol0003oM:Kao`000002og^Wk`?o000000?oQj_/o`000?n@[^X00on@[^X00ol0003o
W;3Voib`iP02oib`iP04o`000?nS]^KoXkKVo`0000Ko[KSQ00?o0000okBigOl000001Onk`]l00ol0
003o`L?Lol73g003ol73g003o`000?o4a=[o000000?obLoO00?o0000ol_@g_o;d=h00oo;d=h00ol0
003obloMol_?g@03ol_?g@;o00001?o8enD01Ol0003oa=?UolCCiOo4dnGo000000Co_/oV00?o0000
okO9iongbNL00_ngbNL00ol0003o[l?Xojo3j002ojo3j005o`000?nV_>WoY[cYojJljOl000001?nM
]NT01?l0003oUZoXoiJ_j?nF[nP2o`0000?oT:_X00?o0000ohbXj?n<Z>P00_n<Z>P00ol0003oRjSX
oh^Xj002oh^Xj004o`000?ooooooooooooooo`?o00007Oooool00ol0003oooooooooo`0:ooooo`00
6oooool00ol0003oooooooooo`0hooooo`03o`000?n>ZNSoSZWX00;oSZWX00?o0000ohnYion?ZNL0
0_n?ZNL00ol0003oTjcWoi>/i`02oi>/i`04o`000?nI/>SoVK3XoiV`j0?o00000onP]^P01Ol0003o
YkcXojNlj?nW_>So000000Co[l?X00?o0000okK9j?nfbNP00_nfbNP00ol0003o_<oXokc?j002okc?
j005o`000?o1e>So`MCXol7Dj?l000001?o3f>T01Ol0003oaM_ZolGKj_o5fn[o000000Coa=g[00Go
0000ol7Mk_o1gNko`Mg^o`000004ok_Ll003o`000?ncfO?o000001?o00000_mm^?T01Ol0003oKZkg
o`000?l0003oJ:_g00Wo00000omYX_82o`0000GoNjO_0_l00005oi2^jP;o000000?oW;3Vo`000?nS
]^H00onS]^H2o`0000Go[KSQ00?o0000ok_2gonk`]l01Onk`]l00ol0003o`L?Lol73g003ol73g003
o`000?o9cmoobLoO00?obLoO00?o0000ol_@g_o;d=h00oo;d=h00ol0003obloMol_?g@02o`000003
ol[IiOl0003ob=OU00?ob=OU00Go0000olCCiOo4dnGoa=?Uo`000004okk?iP03o`000?ngbNOo]lWW
00;o]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000
oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xoi2[j002oi2[j005o`000?n<Z>SoS:SXohbXj?l000001?n;
Z>P4o`00023ooooo00?o0000ooooooooool02_ooool001_ooooo00?o0000ooooooooool0>?ooool0
0ol0003oSZWXohjYj002ohjYj005o`000?n?ZNOoSjWWohnYiol000001OnC[>L5o`0000CoX;KX00?o
0000ojNlj?nW_>P00_nW_>P01Ol0003o[l?Xojo3j?n_`nSo000000Go]/WX00?o0000okc?j?nlcnP0
0_nlcnP01Ol0003o`MCXol7Dj?o1e>So000000Co`mSY00Go0000olGKj_o5fn[oaM_Zo`000004olCM
j`05o`000?o1gNko`Mg^ol7Mk_l000000_nkg?04o`0000;o_=?[00?o0000ok?@koncd>l00_ncd>l0
0ol0003oY/[cojK:l`02ojK:l`05o`000?nG`oKoUl?foiO3m_l000000on5^OL5o`000003ofj^mol0
003o000000;oGZ?e0_l000002_mLWo?o0000oefOlomMWo?o0000ofVRl_l0003oJJ;bo`000?m_Y?43
o`000004og^Wkol0003oPj[^oh>ZkP;o00001?n@[^X00ol0003oXkKVoj>fiP05oj>fiP04o`000?n]
^>7o0000o`0000?o/l3T00?o0000ok_2gonk`]l01?nk`]l01_l0003o`L?Lo`000?l0003oaLoRo`00
00KobLoO00?o0000ol_@g_o;d=h00_o;d=h00ol0003obloMo`000003ol[Ii@03o`000?o8enGob=OU
00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo000000Co]lWW00?o0000
ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000oiJ_j?nF[nP00_nF
[nP2o`0000?oT:_X00Go0000ohbXj?n<Z>SoS:SXo`000004oh^Xj003o`000?oooooooooo027ooooo
00?o0000ooooooooool02_ooool001[ooooo0ol0000iooooo`03o`000?n>ZNSoSZWX00;oSZWX00Go
0000ohnYion?ZNOoSjWWo`000004oi>/i`;o00000onI/>P00ol0003oX;KXoj2fj002oj2fj003o`00
0?nW_>SoYkcX00;oYkcX00Go0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX00;o
_<oX00?o0000ol7Dj?o1e>P00_o1e>P00ol0003o`mSYol?Hj@02ol?Hj@05o`000?o5fn[oaM_ZolGK
j_l000001?o4gN/00ol0003o`Mg^ol7MkP04o`0000;o`mGW00?o0000okcCjonldn/00_nldn/01Ol0
003o/m3_ok?@koncd>oo000000GoY/[c00Go0000oiO3m_nG`oKoUl?fo`000003ohFim`04o`000?md
[oKoM:ofogB_mPSo000000KoG9oco`000?mMWo?oGIoco`000?mOWo82o`0000CoKjCa00?o0000oh>Z
k_n3Z^h00on3Z^h00ol0003oT:kZo`000003oiNcj`;o00001OnS]^H00ol0003o/l3Tok?0i004ok?0
i003o`000?nk`]oo^l;O00Co^l;O00?o0000olG?h_o5cn800_o5cn800ol0003obLoOolW?g`03olW?
g`03o`000?o;d=kobm3N00;obm3N0_l00004ol[Ii@03o`000?o8enGob=OU00;ob=OU00?o0000olCC
iOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP0
1Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o0000oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xo`00
0002oi2[j005o`000?n<Z>SoS:SXohbXj?l000001?n;Z>P00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo03Wooooo00?o0000ohjYj?n>ZNP00_n>
ZNP01_l0003oSjWWohnYion?ZNOo0000oi>/i`Co00001?nI/>P00ol0003oX;KXoj2fj002oj2fj003
o`000?nW_>SoYkcX00;oYkcX00Go0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX
00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?Hj@03o`000?o5fn[oaM_Z00;oaM_Z00Co0000
olCMjoo4gN_oa=g[1?l000000oo8e^Co0000ol?Ei`03ol?Ei`03o`000?nldn_o_=?[00;o_=?[00?o
0000ok?@koncd>l00_ncd>l00ol0003oY/[cojK:l`0>o`000004ogB_m_l0003oIJGeo`0000;oHZCe
2_l000001_mSWo;o0000o`000?m_Y?7o0000ogBVl@?o00000_n3Z^h00ol0003oUk?[oiNcj`04oiNc
j`;o000000GoXkKVo`000?nX_NSoZ;gXo`000006ok?0i007o`000?nk`]oo^l;Ook_2gol0003o_/gU
o`000005olG?hP03o`000?o9cmoobLoO00?obLoO00Ko0000ol_@g_l0003o0000ol[KiOl00004ol[I
i@03o`000?o8enGob=OU00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nncnKo
000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY00?o
0000oiJ_j?nF[nP00_nF[nP00ol0003oT:_Xo`000002oi2[j005o`000?n<Z>SoS:SXohbXj?l00000
1?n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00001?lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0>Oooool01Ol0003oSZWXohjYj?n>ZNSo000000?oSjWW0ol00003oi>/i`03o`000?nI/>SoVK3X
00;oVK3X00?o0000oj2fj?nP]^P00_nP]^P00ol0003oYkcXojNlj002ojNlj005o`000?n_`nSo[l?X
ojo3j?l000001?nfbNP00ol0003o_<oXokc?j002okc?j005o`000?o1e>So`MCXol7Dj?l000001?o3
f>T01Ol0003oaM_ZolGKj_o5fn[o000000;oa=g[0ol00004olSFi003o`000?o3eNOo`mGW00;o`mGW
00?o0000okcCjonldn/00_nldn/00ol0003o/m3_ok?@k`05o`0000;oZlC/00Go0000oibnl?nL__3o
W;k`o`000004oh^gl`03o`000?mh[_CoN:kd00Oo000000?oFIgco`000?l000000_l000001?mGVo;o
0000oeRLl_l00002of>OlP;o00001OmdY_401?l0003oR:k_ohR^kon8[^l2o`0000GoUk?[00?o0000
ojRmj?nX_NP00_nX_NP00ol0003o/l3Tok?0i004ok?0i003o`000?nk`]oo000000?o_/gU00?o0000
olG?h_o5cn800_o5cn800ol0003obLoOolW?g`03olW?g`;o00000oo:fnD00ol0003ob]WUol[Ii@02
ol[Ii@03o`000?o8enGob=OU00;ob=OU00?o0000olCCiOo4dnD00_o4dnD01Ol0003o_/oVokk?i_nn
cnKo000000Co]lWW00?o0000ojo3j?n_`nP00_n_`nP01Ol0003oY[cYojJljOnV_>Wo000000CoWKGY
00?o0000oiJ_j?nF[nP00_nF[nP01_l0003oT:_Xoi2[j?l0003oT:_Xo`0000?oS:SX00?o0000oh^X
j?n;Z>P00_n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Wooooo00Co0000ohjYj?n>ZNSoSZWX1?l000000on?ZNOo0000oi>/i`03oi>/i`03o`000?nI/>So
VK3X00;oVK3X00?o0000oj2fj?nP]^P00_nP]^P01Ol0003oYkcXojNlj?nW_>So000000Co[l?X00?o
0000okK9j?nfbNP00_nfbNP00ol0003o_<oXokc?j002okc?j005o`000?o1e>So`MCXol7Dj?l00000
1?o3f>T00ol0003oaM_ZolGKjP04o`0000;ob]KS00?o0000olSFi?o8e^@00oo8e^@00ol0003o`mGW
ol?Ei`02ol?Ei`04o`000?nldn_o_=?[okcCj`?o00000_nfanL00ol0003oZlC/oj_4k003oj_4k005
o`000?nL__3oW;k`oibnl?l000001?n;]o<01?l0003oN:kdogR^m?l00003ofNUm0Co000000?oFIgc
o`000?l000001?l000000omIW?;o0000ofJQlP02ofJQlP03o`000?mdY_7o000000?oN:Wa00Ko0000
ohR^kon8[^ooR:k_o`000?nG/n/2o`0000;oVkW]00?o0000ojRmj?nX_NP00_nX_NP00ol0003o/l3T
ok?0i004ok?0i003o`000?nncNGo_/gU00;o_/gU00?o0000olG?h_o5cn800oo5cn800ol0003obLoO
o`000002o`000003olSKiol0003ob]_U00;ob]_U00?o0000ol[IiOo:fND00oo:fND01Ol0003ob=OU
olSGiOo8enGo000000Coa=?U00?o0000okk?i_l000006?l000000onF[nSo0000oi2[j002oi2[j0;o
00000on<Z>P00ol0003oRjSXoh^Xj002oh^Xj003o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02Oooool000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03Wooooo1Ol00004ohnYi`03o`000?nC[>OoTjcW00;oTjcW00?o0000oiV`j?nI/>P0
0_nI/>P00ol0003oX;KXoj2fj002oj2fj005o`000?nW_>SoYkcXojNlj?l000001?n_`nP00ol0003o
]/WXokK9j002okK9j003o`000?nlcnSo_<oX00;o_<oX00Go0000ol7Dj?o1e>So`MCXo`000004ol?H
j@?o000000?ob]CRo`000?o:e^<00oo:e^<00ol0003ob=KTolSFi003olSFi003o`000?o3eNOo`mGW
00;o`mGW1?l000000onnb^?o0000okK7i`03okK7i`03o`000?n[a>coZlC/00;oZlC/00?o0000oibn
l?nL__004?l000000omJWO?o0000o`000005o`000004oeVLl_l0003oFYcbo`0000;oIZ7b00?o0000
ogRYlOmhZO400omhZO401Ol0003oR:k_ohR^kon8[^oo000000GoVkW]00?o0000ojRmj?nX_NP00_nX
_NP00ol0003o/l3To`000002o`000003okG:jOl0003o_/gU00Co_/gU00?o0000olG?h_o5cn800_o5
cn82o`0000Cob=_W00Go0000ol[KiOo:fnGob]_Uo`000005ol[Ii@05o`000?o8enGob=OUolSGiOl0
00000_o4dnD4o`0000;o^m7[00?o0000okK:jOnfb^T00_nfb^T00ol0003o[l?Xojo3j002ojo3j005
o`000?nX^nOoZ;_WojRkiol000001?nR]>H01?l0003oW:oUoib_iOnL[nD5o`000003oi2[j?l0003o
S:SX00;oS:SX00?o0000oh^Xj?n;Z>P00_n;Z>P00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Wooooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0hooooo`?o000000?oPZS]o`000?l000000ol000000on?ZNOo0000oi>/i`03oi>/
i`05o`000?nI/>SoVK3XoiV`j?l000001OnP]^P01Ol0003oYkcXojNlj?nW_>So000000Co[l?X00?o
0000okK9j?nfbNP00_nfbNP01Ol0003o_<oXokc?j?nlcnSo000000Co`MCX00?o0000ol?HjOo3f>T0
0ol00004ol[DhP03o`000?o:e^?ob]KS00;ob]KS00?o0000olSFi?o8e^@00_o8e^@01?l0003o`mGW
ol?Eioo3eNL2o`0000Go_/[S00?o0000okK7ionfanL00_nfanL00ol0003oZlC/oj_4k004o`0000Co
W;S/00Go0000ohbcl?n</o3oS;?`o`000003ogZ/l`04o`000?mXY??oJ:Cco`0000;oFigb1ol00003
oeZLlP05o`000?mXXo;oJ:?bofRSl_l000001?mhZO42o`0000?oRk?a00?o0000oi^ikOnK^Nd00_nK
^Nd00ol0003oZ;gXojRmj003o`0000Go]L[Y00?o0000okk=iOnncND00_nncND00ol0003oaLoRo`00
0002o`000003ol?Jj_l0003ob=_W00?ob=_W00?o0000ol[KiOo:fnD00_o:fnD00ol0003ob]WUol[I
i@02ol[Ii@03o`000?o8enGob=OU00Co00000_o0f>/01?l0003o^m7[ok_Ajol00004okK:j@03o`00
0?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00?o
W:oU00Co0000oiR[i?nHZnCoV:_T1?l000000on<Z>So0000oh^Xj003oh^Xj003o`000?oooooooooo
02;ooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool3oh:Xk@CoQ:W]1Ol000000onC
[>Oo0000oiV`j002oiV`j003o`000?nP]^SoX;KX00;oX;KX00?o0000ojNlj?nW_>P00_nW_>P01Ol0
003o[l?Xojo3j?n_`nSo000000Co]/WX00?o0000okc?j?nlcnP00_nlcnP00ol0003o`MCXol7Dj005
o`0000;ob=;R00?o0000ol[Dh_o:e>800_o:e>800ol0003ob]KSol[Fh`02ol[Fh`03o`000?o8e^Co
b=KT00?ob=KT0ol000000oo4bmoo0000okk:h`05okk:h`04o`000?nfanOo]/OWokK7i`?o00001?nY
_>L00ol0003oW;S/oibhk002oibhk004o`000?n</o3oS;?`ohbcl0?o000000?oNZcco`000?l00000
3_l000001?mKWO;o0000o`000?mXXo82o`0000;oNJcc00?o0000oh^clOn;/o400on;/o401Ol0003o
VkW]oi^ikOl0003oVkW]00;o00000_nYaNh00ol0003o]L[YokG:j@04okG:j@04o`000?nncNGo_/gU
okk=i@;o00001?o3f^X00ol0003ob=_WolSKi`02olSKi`03o`000?o:fnGob]_U00;ob]_U00?o0000
ol[IiOo:fND00_o:fND3o`000003ol?Lk?l0003o`=S[00;o`=S[00Go0000ok_AjonkdN_o^m7[o`00
0004okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`00
0?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@2o`000003oiBXhol0003o000000?o0000
00?oRjSXo`000?ooool08oooool00ol0003oooooooooo`09ooooo`000oooool00ol@413ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<oooool3o`0000Gooooo1?n2
Z>d4ohBYk@CoRJc]1?l000000onI/>So0000oj2fj003oj2fj003o`000?nW_>SoYkcX00;oYkcX00Go
0000ojo3j?n_`nSo[l?Xo`000004okK9j003o`000?nlcnSo_<oX00Go00000_o4cn<00ol0003ob=;R
olSBhP02olSBhP03o`000?o:e>;ob]CR00;ob]CR00?o0000ol[Fhoo:e^<00_o:e^<00ol0003ob=KT
olSFi002olSFi0;o00001?o4bml00ol0003o_/[Sokk:h`03okk:h`04o`000?nfanOo0000o`0000?o
/kkR00?o0000ojVlionY_>L00_nY_>L00ol0003oW;S/oibhk002oibhk0;o00000on9[^h01?l0003o
N:WaogRYlOl00003ofRSlP03o`000?mJW?;oFYcb00Wo000000GoFigbo`000?mXY??oJ:Cco`000003
ogV/l`06o`000?n;/o7oRk?aoh^clOl0003oRk?a0_l00002oiZolP03o`000?nYaNkoZLG^00;oZLG^
00?o0000okG:jOneb^T00oneb^T01_l0003o_/gUo`000?l0003o_=O^o`0000Co`m[Z00?o0000olSK
ioo8fnL00_o8fnL00ol0003ob]_Uol[Ki@02ol[Ki@03o`000?o:fNGob]WU00?o00000oo3g>`01Ol0
003o`=S[ol3Hjoo0f>_o000000?o^m7[00?o0000okK:jOnfb^T00_nfb^T00ol0003o[l?Xojo3j002
ojo3j005o`000?nX^nOoZ;_WojRkiol000001?nR]>H00ol0003oW:oUoib_i@02oib_i@03o`000?nH
ZnCoV:_T00;oV:_T00Ko0000oiBXhonDZ>?o0000oiBXhol00003oi>Xi0;o00009Oooool00ol0003o
ooooooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo033ooooo0ol00008ooooo`04o`000?n2Z>goPZS]oh:Xk@CoQ:W]00?o0000ohV/
kOn9[>d00_n9[>d3oi:ak0Go000000?oX;KXo`000?nW_>P00onW_>P01Ol0003o[l?Xojo3j?n_`nSo
000000;o]/WX1Ol00002oko<i003o`000?o4cn?oa<oS00;oa<oS00?o0000olSBh_o8d^800oo8d^80
0ol0003ob]CRol[DhP02ol[DhP03o`000?o:e^?ob]KS00;ob]KS1?l000000oo8bmco0000olC;g`04
olC;g`03o`000?nnb^?o_/[S00;o_/[S0_l00006ok>nhP03o`000?nY_>OoZKcW00;oZKcW00?o0000
oibhk?l000000onH/^X01_l0003oRJk^ohV^k_n9[^ko0000ogRYl@?o00000omVXO82o`000003oeVL
l_l0003o000000Co00000omJWO<:o`0000;oRKOd00?o0000oiZol_nJ_o800_nJ_o800ol0003oZLG^
ojW5kP02ojW5kP04o`000?neb^Wo]L[YokG:j@?o00000onlenh00ol0003o`m[Zol?JjP03ol?JjP05
o`000?o8fnOob=_WolSKiol000000oo:fnD4o`0000;oa>3]00Co0000ol?Lk?o3g>co00001?o0f>/0
1?l0003o^m7[ok_Ajol00004okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_W
o`000004oj:diP03o`000?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@01Ol0003oU:SS
oiBXhonDZ>?o000000GoTjST00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`00
00Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0;Oooool3o`0000co
oooo00Co0000oh:XkOn2Z>go00001?n4ZNd00ol0003oRJc]ohV/k@02ohV/k@?oT[7/1?nK]n/=o`00
00;o^<OV1Onoc>@00ol0003oa<oSolC?h`03olC?h`03o`000?o8d^;ob=;R00;ob=;R00?o0000ol[D
h_o:e>800_o:e>801?l0003ob]KSol[Fhoo:e^<2o`0000Gob<_L00?o0000olC;goo4bml00_o4bml0
1Ol0003o_/[Sokk:honnb^?o000000?o^koM00?o0000ok>nh_nc_^800onc_^801?l0003oZKcWojVl
ionY_>L2o`0000KoV;;Z00Co0000ohV^k_n9[^ko00001?mdY_43o`000003of>Ol_l0003o000000;o
000000?oEicboeNLlomGW?<00_mHWO<3o`0000;oIJGe0_l00002ogR^m@03o`000?n9]oCoRKOd00;o
RKOd00?o0000oiZol_nJ_o800_nJ_o800ol0003oZLG^ojW5kP05o`0000;o/M;a00Go0000okcGk_nl
enko_=O^o`000005ol?JjP04o`000?o8fnOob=_WolSKi`Co000000?o`n;^o`000?o4h>d00_o4h>d0
1Ol0003o`mc/ol?Lk?o3g>co000000?o`=S[00Go0000ok_AjonkdN_o^m7[o`000004okK:j@03o`00
0?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00;o
W:oU00?o0000oiR[i?nHZn@00_nHZn@00ol0003oU:SSoiBXh`02oiBXh`03o`000?nCZ>CoTjST00;o
TjST00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003ooooo
ooooo`0Zooooo`?o00003oooool01Ol0003oPZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/kOn9
[>d00_n9[>d4oi:ak0CoVkO[1OnU_NX4ojo2j0Ko^<OV1Onoc>@00ol0003oa<oSolC?h`02olC?h`03
o`000?o8d^;ob=;R00;ob=;R00?o0000ol[Dh_o:e>800_o:e>801_l0003ob]KSo`000?l0003obL_K
o`0000Kob<_L00?o0000olC;goo4bml00_o4bml00ol0003o_/[So`000005ok^og@03o`000?nc_^;o
/kkR00?o/kkR00?o0000ojVliol000000onT]N@2o`0000CoV;;Z00Co0000ohBZk_n4Z^koQ:[^0_l0
00001?mdY_7o0000ofnTlOm_Y?42o`0000;oGiob0_l000000omGW?;oEiccoeNLl`02oeNMl`Co0000
00CoIJGeo`000?mc[oOoLjog1Ol000000on9]oCo0000o`000005o`0000;oY<cd00?o0000ok7BlOna
d_400_nad_400ol0003o_=O^okcGkP02okcGkP03o`000?o3f^[o`m[Z00;o`m[Z00?o0000olSKiol0
00000_l00003ol?RkP03o`000?o4h>goa>3]00;oa>3]00Go0000ol?Lk?o3g>co`mc/o`000003ol3H
j`05o`000?nkdN_o^m7[ok_Ajol000000onfb^T00ol0003o[l?Xojo3j002ojo3j003o`000?nX^nOo
Z;_W00;oZ;_W00Go0000oj:di_nR]>KoX[CVo`000004oib_i@03o`000?nHZnCoV:_T00?oV:_T00Oo
0000oiBXhonDZ>?oU:SSo`000?nCZ>Co000000?oTjST00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`08ooooo`006Oooool2o`0002Sooooo0ol0000Booooo`05o`000?n2Z>goPZS]oh:XkOl0
00000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`000?nB/NcoT[7/oi:ak?l000000onK]n/00ol0
003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o[l;X1OnhanH00ol0003o_lcToko<i002oko<
i003o`000?o4cn?oa<oS00;oa<oS00?o0000olSBh_o8d^800_o8d^800ol0003ob]CRol[DhP02ol[D
hP;o00001?o9bm/00ol0003ob<_LolS;g004olS;g004o`000?o4bmooa<_OolC;g`;o00001onk_md0
0ol0003o/kkRok>nhP03ok>nhP03o`000?nT]NCoY;GT00CoY;GT00?o0000oiRbj_l000000onA[NT2
o`0000;oQ:[^0_l00003ofnTl@Co000000?oGIoco`000?l000001?l000001?mNXoGo0000of6TmOmQ
Y?D5o`0000CoQ;Wg00?o0000oiG3monE`oL00_nE`oL01Ol0003oY<cdojC<m?nTc?Co000000Co/M;a
00?o0000okcGk_nlenh00_nlenh00ol0003o`m[Zol?JjP04o`0000;o_n;`00Go0000ol?Rk_o3h^ko
`n;^o`000003olCPk@05o`000?o3g>co`mc/ol?Lk?l000001?o0f>/01?l0003o^m7[ok_Ajol00004
okK:j@03o`000?n_`nSo[l?X00;o[l?X00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL
[nGoW:oU00;oW:oU00?o0000oiR[i?nHZn@00onHZn@01Ol0003oU:SSoiBXhonDZ>?o000000;oTjST
00?o0000oi>Xi?l000009oooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003ooooooooo
o`0Tooooo`?o00005_ooool01?l0003oPZS]oh:XkOl00004ohBYk@03o`000?n9[>goRJc]00;oRJc]
00Co0000oi:ak?nB/Nco00001?nK]n/00ol0003oYKgZojFmjP02ojFmjP05o`000?n_`^So[l;Xojo2
j?l000001?nhanH00ol0003o_lcToko<i002oko<i003o`000?o4cn?oa<oS00?oa<oS00Go0000olSB
h_o8d^;ob=;Ro`000002ol[DhP;o000000?obL_Ko`000?o9bm/01?o9bm/00ol0003ob<_LolS;g004
olS;g003o`000?o4bmoo000000?o`<3J00?o0000ok^ogOnk_md01?nk_md01?l0003o/kkRo`000?l0
0003ojjfg`03o`000?nT]NCoY;GT00?oY;GT00?o0000oi6]jOnA[NT01?nA[NT01?l0003oQ:[^o`00
0?mlYnl4o`0000;oJJ?b1?l00002oe^Ol`;oG:7d00?o0000oejSmOmNXoD00_l00003off^m`Co0000
00?oQ;Wgo`000?nE`oL00onE`oL00ol0003oY<cdojC<m002ojC<m005o`000?nad_7o/M;aok7BlOl0
00000_nlenh5o`0000;o^^3c00Go0000okoRl?noh_3o_n;`o`000003ol?RkP05o`000?o4h>goa>3]
olCPkOl000000oo3g>`01Ol0003o`=S[ol3Hjoo0f>_o000000?o^m7[00?o0000okK:jOnfb^T00_nf
b^T00ol0003o[l?Xojo3j002ojo3j005o`000?nX^nOoZ;_WojRkiol000001?nR]>H01Ol0003oW:oU
oib_iOnL[nGo000000GoV:_T00?o0000oiBXhonDZ><00_nDZ><01?l0003oTjSToi>Xi?nCZ>@2o`00
02Oooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000ooooooooool08_ooool3o`0001Wo
oooo00Go0000oh:XkOn2Z>goPZS]o`000003ohBYk@03o`000?n9[>goRJc]00;oRJc]00Go0000oi:a
k?nB/NcoT[7/o`000003oi^gj`03o`000?nU_N[oYKgZ00;oYKgZ00Go0000ojo2j?n_`^So[l;Xo`00
0005okS7iP03o`000?noc>Co_lcT00;o_lcT00?o0000olC?hoo4cn<00_o4cn<00ol0003ob=;RolSB
hP02olSBhP;o00001?o9bm/00ol0003obL_KolW;f`03olW;f`03o`000?o8bmcob<_L00?ob<_L0_l0
0005ol30fP;o00001Onk_md00ol0003o[[KOojjfg`04ojjfg`;o00000onT]N@00ol0003oWJoUo`00
0002o`0000?oTJgY0ol00003ogbWk`Go00000_mTXo<8o`000003ofN[mol0003o000000;oKJkg00?o
0000og^hnOmk^?T01Ol000000onE`oOo0000ojC<m003ojC<m003o`000?nad_7o000000Co00000_na
g?H01Ol0003o^^3cok[Plonjh??o000000?o_n;`00Go0000ol?Rk_o3h^ko`n;^o`000004olCPk@05
o`000?o3g>co`mc/ol?Lk?l000000oo0f>/01Ol0003o^m7[ok_AjonkdN_o000000?o]/[Y00?o0000
ojo3j?n_`nP00_n_`nP00ol0003oZ;_WojRki`02ojRki`05o`000?nR]>KoX[CVoj:di_l000001?nL
[nD00ol0003oV:_ToiR[i003oiR[i005o`000?nDZ>?oU:SSoiBXhol000001?nCZ>@00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo023ooooo0_l0
000Looooo`05o`000?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`00
0?nB/NcoT[7/oi:ak?l000000onK]n/00ol0003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o
[l;X00?o0000okS7i_nhanH00_nhanH00ol0003o_lcToko<i002oko<i003o`000?o4cn?oa<oS00;o
a<oS00Co0000olSBh_o8d^;ob=;R0_l00006olW;f`03o`000?o9bm_obL_K00?obL_K00Go0000olS;
g?o8bmcob<_Lo`000003olC1e`03o`000?o0`=[o`<3J00?o`<3J00Go0000ok^ogOnk_mgo^koMo`00
0002okBgf`;o00001On^]]l00ol0003oY;GTo`000005oif_i@;o000000CoTJgYo`000?n8Z^coR:[/
1?l00003ogBVl@Ko000000?oHZCeo`000?mSYoH00_mSYoH00ol0003oIj_gofN[m`04o`0000;oNkSi
00Co0000oh[4n_n:a?[oR/Cj2?l00002ojKFn005o`000?nag?Ko/Mcfok7Lm_l000001?njh?<01Ol0
003o_n;`okoRl?noh_3o000000?o`n;^00Go0000olCPkOo4h>goa>3]o`000004ol?Lk005o`000?o0
f>_o`=S[ol3Hjol000000_nkdN/00ol0003o]/[YokK:j@02okK:j@03o`000?n_`nSo[l?X00;o[l?X
00Go0000ojRkionX^nOoZ;_Wo`000004oj:diP03o`000?nL[nGoW:oU00;oW:oU00?o0000oiR[i?nH
Zn@00_nHZn@00ol0003oU:SSoiBXh`02oiBXh`03o`000?nCZ>CoTjST00;oTjST0_l0000Xooooo`03
o`000?oooooooooo00Oooooo000Hooooo`03o`000?oooooooooo01gooooo0ol0000Oooooo`05o`00
0?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@04o`000?nB/NcoT[7/o`00
00CoVkO[00?o0000ojFmj_nU_NX00_nU_NX01Ol0003o[l;Xojo2j?n_`^So000000Co^<OV00?o0000
oko<i?noc>@00_noc>@00ol0003oa<oSolC?h`03olC?h`?o000000?ob<[Lo`000?o9bm/01_o9bm/0
0ol0003obL_KolW;f`03olW;f`03o`000?o8bmco000000Goa<7G00?o0000ol30f_o0`=X00oo0`=X0
0ol0003o^koMo`000005okBgf`;o00001?n^]]l00ol0003oWJoUoif_i@06oif_i@;o00001On8Z^`3
o`0000;oM:Ka00Co0000offWm?m]YoCoKJOd1?l00002of>WmPCo00000omb]?X5o`0000;oR/Cj00?o
0000oiW>n_nIc_X00_nIc_X01Ol0003oY]KhojKFn?nVe_So000000?o/Mcf00Go0000ok[Plonjh??o
^^3co`000004okoRl005o`000?o3h^ko`n;^ol?Rk_l000000oo4h>d01_l0003o`mc/ol?Lk?o3g>co
0000ol3Hj`Wo00000_nfb^T00ol0003o[l?Xojo3j002ojo3j005o`000?nX^nOoZ;_WojRkiol00000
0onR]>H00ol0003oW:oUoib_i@02oib_i@03o`000?nHZnCoV:_T00?oV:_T00Go0000oiBXhonDZ>?o
U:SSo`000004oi>Xi004o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01oooool001So
oooo0_l0000Kooooo`?o00008_ooool01Ol0003oPZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/
kOn9[>d00_n9[>d01Ol0003oT[7/oi:ak?nB/Nco000000?oVkO[00?o0000ojFmj_nU_NX00_nU_NX0
1Ol0003o[l;Xojo2j?n_`^So000000Go^<OV00Go0000oko<i?noc>Co_lcTo`000004olC?h`;o0000
1?o8b]`00ol0003obL_KolW;f`04olW;f`03o`000?o9bm_obL_K00?obL_K0_l00007olC1e`03o`00
0?o0`=[o`<3J00?o`<3J00?o0000okBgfond]m/01_nd]m/2o`000004ojjfgol0003oYK7PojFah0?o
00001?nM[nD00ol0003oTjcXo`000002o`0000;oR:[/00?o0000ognZkomoZ^l01?l00003offWm003
o`000?mYZ_OoJJ[g00;o00001?m[[oT01?l0003oL[Cjog:dn_l00004ogjoo0Co00000_nIc_X01Ol0
003oY]KhojKFn?nVe_So000000Co/Mcf00Go0000ok[Plonjh??o^^3co`000003okoRl003o`000?o3
h^ko000000co00000_nienl01Ol0003o]]7]okKAkOnfdNgo000000;o/l[[2Ol00002ojRki`05o`00
0?nR]>KoX[CVoj:di_l000001?nL[nD00ol0003oV:_ToiR[i002oiR[i003o`000?nDZ>?oU:SS00;o
U:SS00?o0000oi>Xi?nCZ>@00_nCZ>@01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
00Oooooo000Hooooo`03o`000?oooooooooo01Oooooo0ol0000Uooooo`05o`000?n2Z>goPZS]oh:X
kOl000000on4ZNd00ol0003oRJc]ohV/k@02ohV/k@05o`000?nB/NcoT[7/oi:ak?l000000onK]n/0
0ol0003oYKgZojFmjP02ojFmjP03o`000?n_`^So[l;X00;o[l;X00?o0000okS7i_nhanH00_nhanH0
0ol0003o_lcToko<i002oko<i0Co000000?oa<WNo`000?o8b]`01?o8b]`00ol0003obL_KolW;f`04
olW;f`05o`000?o9bm_obL_KolW;fol000000oo5`MH00ol0003oa<7GolC1e`04olC1e`05o`000?o0
`=[o`<3Jol30f_l000000_nj^=P2o`0000Oo];OK00?o0000ojFah?nU/N001?nU/N04o`0000GoTjcX
0ol00005ognZk`Co000000?oKJOdo`000?mYZ_L00_mYZ_L2o`0000;oJjoi1?l00003ogjoo003o`00
0?n:bOgoR/Wm00;oR/Wm1Ol000000onVe_So0000ok7LmP02ok7LmP03o`000?njh??o000000So0000
0_nfh_D01Ol0003o^N3cokWPlonih??o000000Co^]ca00Co0000okWGkonienoo00000onfdNd00ol0
003o/l[[ok?:j`02ok?:j`03o`000?n_`nWo[l?Y00;o[l?Y00?o0000ojZli_nZ_>H01?l00002oj:d
iP05o`000?nL[nGoW:oUoib_iOl000001OnHZn@01Ol0003oU:SSoiBXhonDZ>?o000000GoTjST00Go
0000ooooooooooooooooo`00000Vooooo`03o`000?oooooooooo00Oooooo000Hooooo`03o`000?oo
oooooooo01Cooooo0ol0000Yooooo`05o`000?n2Z>goPZS]oh:XkOl000000on4ZNd00ol0003oRJc]
ohV/k@02ohV/k@04o`000?nB/NcoT[7/o`0000CoVkO[00?o0000ojFmj_nU_NX00_nU_NX01Ol0003o
[l;Xojo2j?n_`^So000000Co^<OV00Co0000oko<i?noc>Co_lcT0_l00005olC9gP03o`000?o8b]co
b<[L00?ob<[L00?o0000olW;foo9bm/01?o9bm/00ol0003obL_Ko`000005olG1eP03o`000?o4`MOo
a<7G00Coa<7G00?o0000ol30f_l000001Onj^=P2o`0000Co];OK00?o0000ojbag?n//M`00_l00006
ojFah0?o00001OnC[>P5o`000003ognZkol0003oMZcd00;oMZcd2Ol00004ogBhn`03o`000?mn_oco
000000CoR/Wm00?o0000oiKBoOnFd_d00onFd_d7o`0000;oZMkj00Go0000ok7Qn?nahOSo/N7ho`00
0003okKRm@05o`000?nih??o^N3cokWPlol000001?njg?401?l0003o^MO_okWGkol00003okKAk@03
o`000?ncb^_o/l[[00;o/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP03
o`000?nV]^CoY[KT00Co00000_nL[nD00ol0003oV:_ToiR[i003oiR[i005o`000?nDZ>?oU:SSoiBX
hol000001?nCZ>@00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool001Oooooo00?o0000ooooooooool04_ooool3o`0002cooooo00Go0000oh:XkOn2
Z>goPZS]o`000003ohBYk@03o`000?n9[>goRJc]00;oRJc]00Go0000oi:ak?nB/NcoT[7/o`000003
oi^gj`03o`000?nU_N[oYKgZ00;oYKgZ00Go0000ojo2j?n_`^So[l;Xo`000005okS7iP?o000000?o
_lOQo`000?o4bMh01Oo4bMh00ol0003ob<[LolS:g003olS:g003o`000?o9bm_obL_K00?obL_K0_l0
0007olG1eP;o00001Oo4`ML00ol0003o^[SHokZhf006okZhf0;o000000?o];OKo`000?n//M`01?n/
/M`2o`0000CoYK7P00?o0000oib^i?nL[^@01?l000000onC[>So0000ohV]k@03ohV]k@Oo000000?o
MZcdo`000?mb/OP01?mb/OP00ol0003oM;SkogBhn`05o`0000;oR/Wm00?o0000oiKBoOnFd_d00_nF
d_d2o`0000?oXMWk00?o0000ojWNn_nYg_X00_nYg_X01Ol0003o/N7hok7Qn?nahOSo000000?o]^;e
00Go0000okWPlonih??o^N3co`000004ok[Ll@04o`000?nienoo^MO_o`0000?o]]7]00?o0000ok?:
joncb^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000ojJf
i?nV]^@00_nV]^@00ol0003oX[7Soj:ah`03o`0000CoV:_T00?o0000oiBXhonDZ><00_nDZ><00ol0
003oTjSToi>Xi002oi>Xi003o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`07ooooo`005oooool00ol0003oooooooooo`0?ooooo`?o0000;oooool01Ol0003o
PZS]oh:XkOn2Z>go000000?oQ:W]00?o0000ohV/kOn9[>d00_n9[>d01Ol0003oT[7/oi:ak?nB/Nco
000000?oVkO[00?o0000ojFmj_nU_NX00_nU_NX00ol0003o[l;Xojo2j002ojo2j003o`000?nhanKo
^<OV00?o00001?noan400ol0003oa<WNolC9gP04olC9gP03o`000?o8b]cob<[L00?ob<[L00Go0000
olW;foo9bm_obL_Ko`000003olG2eP03o`000?o5`MKoaL7F00GoaL7F00Go0000olC1eoo4`MOoa<7G
o`000002okfhe@;o00001onj^=P00ol0003o[;7Lojbag006ojbag0;o000000?oYK7Po`000?nL[^@0
1_nL[^@4o`0000CoRJg]00?o0000oh2`lon0/?<00_n0/?<:o`0000GoO/3l1?l00002oiKBo@03o`00
0?nQfO_oXMWk00;oXMWk00?o0000ojWNn_nYg_X00_nYg_X01Ol0003o/N7hok7Qn?nahOSo000000?o
]^;e00Go0000okWPlonih??o^N3co`000004ok[Ll@04o`000?nienoo^MO_o`0000?o]]7]00?o0000
ok?:joncb^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000
ojJfi?nV]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;o000000;o000000?oV:_T
o`000?nDZ><00_nDZ><00ol0003oTjSToi>Xi002oi>Xi003o`000?oooooooooo00Gooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`07ooooo`005oooool2o`0000gooooo0ol0000coooo
o`Oo000000?oQ:W]o`000?n9[>d00on9[>d01?l0003oT[7/oi:ak?l00004oi^gj`03o`000?nU_N[o
YKgZ00;oYKgZ00?o0000ojo2j?l000001?l00002okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000
olC9g_o4bMh01?o4bMh00ol0003ob<[LolS:g003olS:g003o`000?o9bm_o000000GoaL;F00?o0000
olG1e_o5`MH01Oo5`MH00ol0003oa<7Go`000005okfhe@;o00001Onj^=P00ol0003o/K;Io`000002
o`0000Ko[;7L00?o0000oib^i?nL[^@01onL[^@00ol0003oTZo[oi:_j`04o`000003ohV]kOl0003o
P;3c00GoP;3c00?o0000og^gnOmk]oT01?mk]oT00ol0003oO/3lo`000002o`0000CoR<Sm1?l00002
oj7In`03o`000?nYg_[oZMkj00;oZMkj00Go0000ok7Qn?nahOSo/N7ho`000003okKRm@05o`000?ni
h??o^N3cokWPlol000001?njg?401Ol0003o^MO_okWGkonienoo000000;o]]7]00?o0000ok?:jonc
b^/00_ncb^/00ol0003o[l?Yojo3j@02ojo3j@03o`000?nZ_>KoZ[cV00;oZ[cV00?o0000ojJfi?nV
]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;oWjgR00?oWjgR0ol00002oiBXh`03
o`000?nCZ>CoTjST00;oTjST00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000fooooo`05o`00
0?mhZo?oN:_cogR[lol000000_mj[?<9o`000003oi:ak?l0003oVkO[00Wo00000_n_`^P00ol0003o
^<GTokS5i003okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000olC9g_o4bMh00oo4bMh00ol0003o
b<[LolS:g003olS:g0;o00001oo5`]H00ol0003oaL7FolG1eP05olG1eP03o`000?nm^=Go_KSE00Ko
_KSE00Go0000okZhf?nj^=So^[SHo`000005ok6bf@;o00001?n//M`01?l0003oXjoPoj>_h?nS[n05
o`000003oib^i?l0003oTZo[00GoTZo[4ol00002ohS8o@?o00001?nBcod4o`0000;oZMkj00Go0000
ok7Qn?nahOSo/N7ho`000003okKRm@05o`000?nih??o^N3cokWPlol000001?njg?401Ol0003o^MO_
okWGkonienoo000000?o]]7]00Go0000ok?:joncb^_o/l[[o`000004ojo3j@03o`000?nZ_>KoZ[cV
00;oZ[cV00?o0000ojJfi?nV]^@00_nV]^@00ol0003oX[7Soj:ah`02oj:ah`03o`000?nO[N;oWjgR
00CoWjgR00?o0000oif[hOnMZn400ol00003oi>Xi003o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`06ooooo`005oooool00ol0003oooooooooo`06ooooo`?o
0000>_ooool01Ol0003oN:_cogR[lomhZo?o000000;oNZcc00?o0000oh:`l_n2/?800_n2/?800ol0
003oS;Caohbdl@03o`0000;oV;[_00?o0000ojBnk?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2
j003o`000?nhaNCo^<GT00?o^<GT00?o0000oko7hOnoan400onoan400ol0003oa<WNolC9gP03olC9
gP05o`000?o8b]cob<[LolS:g?l000000oo4`]P00ol0003oaL;FolG2eP04olG2eP03o`000?o5`MKo
aL7F00?oaL7F00?o0000oknie?no^M@00_l00006okfhe@;o000000?o^[SHo`000?na/]T01_na/]T4
o`0000WoXjoP1?l00005oi:_j`03o`000?n8]?;oR;Cb00GoR;Cb00?o0000ohBmnOn4_OT01On4_OT4
o`0000CoT/om0ol00004oi_Do0So000000?o]^;eo`000?nih?<00_nih?<00ol0003o^]caok[Ll@02
ok[Ll@05o`000?nienoo^MO_okWGkol000000onfdNd00ol0003o/l[[ok?:j`02ok?:j`03o`000?n_
`nWo[l?Y00;o[l?Y00Go0000ojZli_nZ_>KoZ[cVo`000004ojJfi003o`000?nR/N?oX[7S00;oX[7S
00?o0000oin]h_nO[N801?nO[N800ol0003oWJ_Qoif[h@02oif[h@06o`000?nKZn7o0000o`000?nC
Z>Co00002oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03
o`000?oooooooooo00?ooooo0ol0000nooooo`05o`000?mhZo?oN:_cogR[lol000000_mj[?<00ol0
003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o0000ojBnk?nT_^`00_nT_^`0
0ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00?o0000oko7hOnoan400_noan40
0ol0003oa<WNolC9gP04olC9gP03o`000?o8b]co000000Goa<;H00?o0000olG2e_o5`]H01?o5`]H0
1Ol0003oaL7FolG1e_o5`MKo000000Go_kWD0_l00006okfhe@03o`000?na/]Wo/K;I00Wo/K;I00?o
0000oj>_h?nS[n002?nS[n000ol0003oVK7XoiVaj005o`000003oi:_jol0003oR;Cb00KoR;Cb00?o
0000ohBmnOn4_OT01?l00004ohg2n@04o`000?nBcogo0000o`0000GoVmCl0_l00002oj?HnP;o0000
0onYfOP8o`0000;o^]ca00Go0000okWGkonienoo^MO_o`000003okKAk@03o`000?ncb^_o/l[[00;o
/l[[00?o0000ojo3jOn_`nT00_n_`nT01Ol0003oZ[cVojZli_nZ_>Ko000000CoY[KT00?o0000oj:a
honR/N<00_nR/N<00ol0003oWjgRoin]hP04oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[
hOnKZn400_nKZn400ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01_ooool001Kooooo00Co0000oooooooooooooooo0ol00012ooooo`05o`000?mhZo?oN:_c
ogR[lol000000_mj[?<00ol0003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o
0000ojBnk?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00?o
0000oko7hOnoan400_noan400ol0003oa<WNolC9gP03olC9gP;o00001oo4`]P2o`0000GoaL;F00?o
0000olG1e_l000002?no^M@2o`0000Co_KSE00?o0000okFceone/mL01?l00005ok6bf@04o`000?nX
/=goZ;3MojR`g@Go00000_nS[n000ol0003oVK7XoiVaj005oiVaj0co00001on=`_T4o`0000CoVmCl
0_l00002oj?HnP;o00000onYfOP2o`0000?o[MSf00?o0000ok3Flon`e_<00_n`e_<8o`000003okKA
kOl0003o/l[[00?o/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP05o`00
0?nV]^CoY[KTojJfi?l000001?nR/N<00ol0003oWjgRoin]hP04oin]hP03o`000?nMZn7oWJ_Q00;o
WJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`05o`000?mhZo?oN:_cogR[lol0
00000_mj[?<00ol0003oP[3boh:`lP02oh:`lP04o`000?n<]?7oS;Cao`0000CoV;[_00?o0000ojBn
k?nT_^`00_nT_^`00ol0003o[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00;o^<GT00?o0000oko7
hOnoan400onoan401Ol0003oa<WNolC9g_o4bMko000000?o`/;J00?o0000olC2f?o4`]P01Oo4`]P0
0ol0003oaL;FolG2eP03olG2eP03o`000?no^MCo_kWD00Wo_kWD0_l000000onm^=Go0000okFce`06
okFce`?o000000?o/K;Io`000?nX/=d02?nX/=d8o`0000?oVK7X00?o0000oi6hlOnA^?401onA^?40
0ol0003oSL;iohg2n@05o`0000CoULOh00Co0000oi_Do?l0003o00000onSf?X01?l0003oZMWhojWI
n?nYfOP2o`0000?o[MSf0_l00004ok3Fl`05o`000?nad_7o/M;aok7BlOl000000onacNh4o`0000;o
/l[[00?o0000ojo3jOn_`nT00_n_`nT00ol0003oZ[cVojZliP02ojZliP03o`000?nV]^CoY[KT00;o
Y[KT00Go0000oj:ahonR/N?oX[7So`000006oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[
hOnKZn400onKZn400ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01_ooool001Kooooo0_l00019ooooo`04o`000?mhZo?oN:_co`0000?oNZcc00?o0000oh:`
l_n2/?800_n2/?801?l0003oS;CaohbdlOl00003oiRjk`03o`000?nT_^coY;k/00;oY;k/00?o0000
ojo2j?n_`^P00on_`^P00ol0003o^<GTokS5i002okS5i003o`000?noan7o_lOQ00?o_lOQ00?o0000
olC9g_l000001Oo2`]X00ol0003oa<;HolC2f005olC2f005o`000?o5`]KoaL;FolG2e_l000000_no
^]D3o`0000Wo_kWD00?o0000okFceone/mL02One/mL2o`0000_oZ;3M00?o0000oinbi_nO/^H00onO
/^H@o`0000SoULOh1Ol000000onSf?[o0000o`000003ojWIn003o`000?n]f?Ko[MSf00;o[MSf00?o
0000ok3Flon`e_<00_n`e_<2o`0000?o/M;a00Go0000ok7=k_nacNko/Lg^o`000004ok38j`Co0000
0_n_`nT00ol0003oZ[cVojZliP02ojZliP03o`000?nV]^CoY[KT00;oY[KT00?o0000oj:ahonR/N<0
0_nR/N<00ol0003oWjgRoin]hP03oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[hOnKZn40
0onKZn400ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool000cooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo00Co
0000ogR[lomhZo?o00000omj[?<01Ol0003oP[3boh:`l_n2/?;o000000?oS;Ca00Go0000oiRjkonH
^^ooV;[_o`000004ojBnk003o`000?n_`^So[l;X00;o[l;X00?o0000okS5i?nhaN@00onhaN@00ol0
003o_lOQoko7h@02oko7h@;o00001oo2`]X00ol0003oa<;HolC2f005olC2f003o`000?o5`]Ko0000
00Ko_k[E0_l00007oknie003o`000?ng]=Ko]kCF00?o00001one/mL00ol0003o[;7Lojbag004o`00
00GoZ;3M00?o0000oinbi_nO/^H01onO/^H00ol0003oV;[`oiRjl008oiRjl004o`000?nEaoSoULOh
oiG7n0Go00000onLbOL5o`000003ojWIn?l0003o000000Co[MSf00Co0000ok3Flon`e_?o/=Kc0_l0
0003ok7Bl@;o00000onacNh00ol0003o/<S[ok38j`02ok38j`03o`000?n^`^Wo[/;Y00;o[/;Y0ol0
0003ojZliP03o`000?nV]^CoY[KT00;oY[KT00?o0000oj:ahonR/N<00_nR/N<00ol0003oWjgRoin]
hP03oin]hP03o`000?nMZn7oWJ_Q00;oWJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool000kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`17ooooo`04o`000?mhZo?oN:_co`0000?oNZcc00Go
0000oh:`l_n2/?;oP[3bo`000003ohbdl@05o`000?nH^^ooV;[_oiRjkol000001?nT_^`00ol0003o
[l;Xojo2j002ojo2j003o`000?nhaNCo^<GT00?o^<GT00Co0000oko7hOl0003o00000onm`mh7ol;2
fP;o00001_o4`]P00ol0003o_k[Eoknje@07oknje@;o00001?no^M@00ol0003o]kCFokNdeP04okNd
eP?o00001?ne/mL00ol0003o[;7Lojbag004ojbag0?o000000?oZ;3Mo`000?nO/^H02_nO/^H00ol0
003oV;[`oiRjl003oiRjl0So00001?nLbOL4o`0000CoX/_e0ol00003ojgHmP;o00000on`e_<00ol0
003o/M;aok7Bl@02ok7Bl@04o`000?nacNko/Lg^ok7=kP;o00001?n`b>/00ol0003o[/;Yojk2j@02
ojk2j@07o`000?n/_NKo[;gVojbmi_l0003oZ[cVo`000004ojJfi003o`000?nR/N?oX[7S00;oX[7S
00?o0000oin]h_nO[N800onO[N800ol0003oWJ_Qoif[h@02oif[h@03o`000?nKZn7oVj_Q00?oVj_Q
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
000>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool01Ol0003oN:_cogR[
lomhZo?o000000;oNZcc00?o0000oh:`l_n2/?800_n2/?801?l0003oS;CaohbdlOl00004oiRjk`03
o`000?nT_^coY;k/00;oY;k/00?o0000ojo2j?n_`^P00_n_`^P00ol0003o^<GTokS5i002okS5i0;o
00001_nm`mh00ol0003o`/;Jol;2fP05ol;2fP03o`000?o4`]Soa<;H00?oa<;H00Co0000oknke_l0
003o00002?no^]D3o`000003oknie?l0003o]kCF00So]kCF1?l0000:ojbag1?o00001_nN_Nh00ol0
003oW<Wgoic9m`03o`0000GoX/_e0ol00003ojO<l`03o`000?n]f?Ko000000?o/=Kc0_l00004ok7B
l@05o`000?nacNko/Lg^ok7=k_l000001?n`b>/2o`0000Co[/;Y00?o0000ojbmi_n/_NH00_n/_NH4
o`0000;oY[KT00?o0000oj:ahonR/N<00_nR/N<00ol0003oWjgRoin]hP03oin]hP03o`000?nMZn7o
WJ_Q00;oWJ_Q00?o0000oi^[hOnKZn400onKZn400ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01Oooool000kooooo00?o0000ooooooooool02_ooool2o`00
04Oooooo00Go0000ogR[lomhZo?oN:_co`000002ogZ/l`03o`000?n2/?;oP[3b00;oP[3b00Co0000
ohbdlOn<]?7o00001?nH^^l01Ol0003oY;k/ojBnk?nT_^co000000Go[l;X00Co0000okS5i?l0003o
00000ong`n<6okg3gP;o00001_o2`]X01Ol0003oa<;HolC2f?o4`]So000000Co_k_F0_l00009oknj
e@03o`000?ng]=Ko]kCF00_o]kCF00?o0000ojbag?n//M`02On//M`00ol0003oY;CTojBdi009ojBd
i003o`000?nN_NkoW[g^00OoW[g^1Ol00006oj;;m@;o00001_nWc?<4o`000003ok3Flol0003o/M;a
00?o/M;a0_l00003ok7=kP03o`000?n`b>_o/<S[00;o/<S[00?o0000ojk2jOn^`^T00_n^`^T2o`00
00Co[;gV00?o0000ojZii?nZ^N@00_nZ^N@3o`0000?oX[7S00?o0000oin]h_nO[N800onO[N800ol0
003oWJ_Qoif[h@03oif[h@03o`000?nKZn7oVj_Q00;oVj_Q00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0AOooool01?l0003oN:_cogR[lol00003ogZ/l`05o`000?n2/?;oP[3b
oh:`l_l000000on<]?401Ol0003oV;[_oiRjkonH^^oo000000CoY;k/00?o0000ojo2j?n_`^P00_n_
`^P2o`0000Ko]l?S00?o0000okg3g_nm`mh01?nm`mh00ol0003o`/;Jol;2fP04ol;2fP03o`000?o4
`]So000000Oo_k_F0_l00007oknje@03o`000?ni]MKo^KGF00?o00002?ng]=H01?l0003o[k;Kojnb
fon_/]/6o`0000;o[;7L00?o0000ojBdi?nT]>@02_nT]>@00ol0003oW[g^oijmkP06o`0000?oXkk]
00?o0000oj;;mOnRboD00onRboD2o`0000GoYlcc0ol00003oj_;l@?o00000onad_401?l0003o/Lg^
ok7=k_nacNh2o`0000Co/<S[00?o0000ojk2jOn^`^T00_n^`^T00ol0003o[;gVojbmiP02ojbmiP;o
00001?nZ^N@01ol0003oYkGSojNehonW]N?o0000oj:ahol000001OnO[N800ol0003oWJ_Qoif[h@03
oif[h@03o`000?nKZn7oVj_Q00;oVj_Q00?o0000ooooooooool05oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0AOooool01?l0003oN:_cogR[lol00003ogZ/l`05o`000?n2/?;oP[3boh:`l_l000000on<
]?401Ol0003oV;[_oiRjkonH^^oo000000CoY;k/00Co0000ojo2j?l0003o00000on_`^P6okO3h`;o
00001Onm`mh2o`0000Go`/;J00?o0000oknke_no^mH02?no^mH2o`0000Co_k[E00?o0000okVee_ni
]MH01?ni]MH3o`0000Co]kCF00?o0000ojnbfon_/]/02?n_/]/Bo`0000[oXkk]00?o0000oj;;mOl0
00000_l00004ojO<l`?o00000on[bo43o`0000?o[L[_00?o0000ok7BlOl000000onacNh00ol0003o
/<S[ok38j`03ok38j`04o`000?n^`^Wo[/;Yojk2j@;o00001?n/_NH00ol0003oZ[WTojZii002ojZi
i0;o00001?nW]N<3o`0000CoWjgR00?o0000oif[hOnMZn400onMZn400ol0003oVj_Qoi^[h@02oi^[
h@03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05oooo
o`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Gooooo00Co0000ogR[lomh
Zo?o00000omj[?<01Ol0003oP[3boh:`l_n2/?;o000000?oS;Ca00Go0000oiRjkonH^^ooV;[_o`00
0002ojBnk0?o00001_n_`^P00ol0003o]l?SokO3h`04okO3h`03o`000?nm`mko_L?N00Co_L?N00Go
0000ol;2f_o2`][o`/;Jo`000002okfmf@?o00002?no^mH2o`000003oknjeOl0003o^KGF00Wo^KGF
0ol000000ong]=Ko0000ojnbf`0;ojnbf`03o`000?nX]^?oZ;KS00[oZ;KS00?o0000oj>nkOnS_^d0
2?nS_^d4o`0000GoYlcc0_l00004oj_;l@;o00001_n]b^l4o`000003ok7=k_l0003o/<S[00?o/<S[
0_l00003ojk2j@03o`000?n/_NKo[;gV00;o[;gV0_l00004ojZii003o`000?nW]N?oYkGS00?oYkGS
00Co0000ojFbh_nU/^;oYK;R0_l000000onO[N;o0000oif[h@04oif[h@03o`000?nKZn7oVj_Q00;o
Vj_Q00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Go
oooo000<ooooo`03oeEEEOmVIVKo0000017ooooo0_l00016ooooo`04o`000?mhZo?oN:_co`0000?o
NZcc00Go0000oh:`l_n2/?;oP[3bo`000002ohbdl@Oo00001?nT`Nd7ojo2j003o`000?ng`n?o]l?S
00?o]l?S00?o0000okg3g_nm`mh01?nm`mh00ol0003o`/;Jo`000006okfmf@?o00001ono^mH00ol0
003o^KGFokVeeP0<okVeeP04o`000?n_/]_o[k;Kojnbf`Co00001_n_/]/00ol0003oZ;KSojRfh`0;
ojRfh`03o`000?nS_^goXkk]00Oo00001?nW`>/00ol0003oYlcco`000002o`0000CoZl_a0_l00005
ojg:k`?o00000on^an`3o`0000?o/<S[00?o0000ojk2jOn^`^T00_n^`^T00ol0003o[;gVojbmiP02
ojbmiP03o`000?nZ^NCoZ[WT00;oZ[WT0_l00004ojNeh`;o00001OnU/^83o`0000CoWJ_Q00?o0000
oi^[hOnKZn400_nKZn400ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01?ooool002;ooooo00?o0000ooooooooool0A?ooool=o`0000?oR[[f1?nH__85ojC1
k@;o00001On_`^P2o`0000Co]l?S0_l00005okg3gP03o`000?nm_MWo_KgI00So_KgI0_l00005oknk
eP03o`000?ni]mSo^KOH00Go00001oni]MH00ol0003o/KCKok6df`05ok6dfaOo00002_nW`>/3o`00
00CoZl_a0ol00005ojg:k`;o00001?n^an`2o`0000?o[lGZ00?o0000ok38jol000000on^`^T2o`00
00?o[;gV0_l00004ojZii003o`000?nW]N?oYkGS00?oYkGS00?o0000ojFbh_nU/^801?nU/^801?l0
003oY;7RojBah_nT/N82o`000003oif[hOl0003oVj_Q00?oVj_Q00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Sooooo`03o`000?oooooooooo
04Gooooo0omc/_P4ogJcn0CoO[Kh1?n:^_H01Ol0003oV;kboiRnl_nH__;o000000GoY<7]00?o0000
ojo2j?n_`^P01?n_`^P00ol0003o]l?SokO3h`03okO3h`05o`000?nm`mko_L?Nokg3g_l000000_nj
_]d3o`0000So_KgI0ol000000ono^mKo0000okVgf007okVgf0Go000000?o^KGFo`000?na]=/03Ona
]=/00ol0003oZkSRoj^hhP0;oj^hhP03o`000?nW`>_oYl3[00GoYl3[1Ol00003oj[1jP04o`000?n[
bo7o0000o`0000Go[L[_0ol00003ojk7k0?o00001On_aNX2o`0000?o[/;Y00?o0000ojbmi_n/_NH0
0_n/_NH00ol0003oZ[WTojZii003ojZii003o`000?nW]N?oYkGS00;oYkGS0_l00005ojFbhP;o0000
1OnT/N83o`0000?oVj_Q00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo000Tooooo`;o0000A_ooool01?l0003oLk;hog>bn?l00003ogJcn005o`00
0?mn]_SoO[Khogjfn?l000000on:^_H2o`0000?oV;kb00?o0000ojC1kOnT`Nd00_nT`Nd2o`0000Go
[l;X00?o0000okO3hong`n<00ong`n<00ol0003o_L?No`000006okZng@;o00002Onm_MT00ol0003o
^KOHokVgf00<okVgf0;o00000ona]=/00ol0003o/KCKok6df`08ok6df`03o`000?n[^>;oZkSR00co
ZkSR00?o0000ojO0jol000001?l00007oj[1jP?o00001On]b^l2o`0000Co[/O/0_l00005ojo5jP?o
00000_n^`^P00ol0003o[/;Yo`000003ojbmiP;o00001?nZ^N@2o`0000CoYkGS00?o0000ojFbh_nU
/^801?nU/^800ol0003oY;7RojBahP04ojBahP07o`000?nR/>;oX[3Roj:`h_l0003oVj_Qo`00000T
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002Kooooo00?o0000oooo
ooooool0AOooool3og>bn004o`000?mf/oSoM[?hogJcn0?oO[Kh0_l00003ohZjmP05o`000?nH__;o
V;kboiRnl_l000001OnT`Nd00ol0003o[l;Xojo2j003ojo2j0;o00000ong`n<2o`0000Wo^[kM0_l0
0007okfmf@03o`000?nh^M[o^;WJ00Co00002Oni]mP00ol0003o/kKLok>fg002ok>fg0Oo00000ona
]=/00ol0003oZkSRoj^hhP05oj^hhPWo00002?nZ`NX4o`0000?o[<7Y00?o0000ojg:kol000000_l0
0004ojk7k0;o00001On_aNX2o`0000Go[/;X1?l000000on/_NKo0000ojZii004ojZii003o`000?nW
]N?oYkGS00?oYkGS00?o0000ojFbh_nU/^800onU/^82o`0000GoY;7R0_l00004oj:`hP;o00009_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo000Wooooo`03o`000?oooooo
oooo04Gooooo00?o0000og>bn?mc/_P00_l00002ogJcn005o`000?mn]_SoO[Khogjfn?l000000on:
^_H2o`0000;oV;kb0_l00004ojC1k@03o`000?n_`^So[l;X00Co[l;X00?o0000okO3hol000000onf
`>82o`0000So^[kM0ol00003okfmf@03o`000?nh^M[o^;WJ00Go^;WJ0ol00006okVgf003o`000?nc
]]co/kKL00Wo/kKL2ol00007ojfihP03o`000?nZ`N[oZ/7Z00CoZ/7Z0ol00006ojc1j@?o00001?n^
an`3o`0000Co[lGZ0ol00005ojk2j0;o00000on]_nL3o`0000?oZ[WT0_l00004ojNeh`;o00001?nU
/^82o`0000GoY;7R0_l00004oj:`hP;o0000:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo000Xooooo`03o`000?oooooooooo04Kooooo00Co0000og>bn?mc/_So00000omf
/oP00ol0003oO[Khogjfn002o`0000?oR[[f00Go0000oiRnl_nH__;oV;kbo`000004ojC1k@;o0000
1?n_`^P2o`0000Oo]/3R0_l00008okZng@;o000000?o_KgIo`000?nh^MX02Onh^MX4o`000003okVg
f?l0003o/kKL00ko/kKL00?o0000ojfih_n]^N803On]^N800ol0003oZ/7Zo`000003o`0000Go[<7Y
1?l00003ojk2j@04o`000?n^anco0000o`0000Go[lGZ0_l00006ojk2j0;o00000on]_nL2o`0000?o
[;gV00?o0000ojZii?l000001OnW]N<00ol0003oYK;RojFbhP03ojFbhP03o`000?nT/N;oY;7R00Co
Y;7R00?o0000oj:`h_nR/>800onR/>800ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool002Wooooo0_l00017ooooo`;o000000?oLk;ho`000?l00000
0omf/oP01?l0003oO[Khogjfn?l00003ohZjmP04o`000?nH__;oV;kboiRnlP;o00001?nT`Nd01?l0
003o[l;Xo`000?l00003ojo2j003o`000?nf`>;o]/3R00Go]/3R0ol00007okZng@03o`000?nh^M[o
^;WJ00go^;WJ0_l00003ok>fg0Go00001onc]]`00ol0003o[KWRojfihP05ojfihP[o00001On/`NT4
o`0000Ko[/;Y0ol00005ojo5jP;o00001_n^`^P2o`0000?o[KoW0_l00005ojbmiP?o00000onW]N<2
o`0000CoYK;R0_l00005ojBahP;o00001?nR/>82o`0002gooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`00:oooool00ol0003oooooooooo`16ooooo`04o`000?mc/_SoLk;h
o`0000?oM[?h00Co0000ogjfn?mn]_So00000on:^_H2o`0000?oV;kb00Co0000ojC1kOnT`NgoY<7]
0_l00008ojo2j0;o00001_nf`>82o`0000Go^[kM00Co0000okNlg_ng_=ko]kcN1Ol00008okRifP03
o`000?nc^Mgo/kWM00Ko/kWM3ol00008ojnkh`03o`000?n/`NWo[<7Y00Co00001on^`^T3o`0000?o
[/;X00?o0000ojo5j_l000000_l00005ojk2j0?o00000on]_nL2o`0000Go[;gV0_l00003oj^ki@03
o`000?nW]N?o000000GoYK;R00?o0000ojBah_nT/N800onT/N82o`0000CoX[3R0_l0000_ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0
A_ooool2o`000003og>bn?l0003o000000?oM[?h00Co0000ogjfn?l0003o00000on:^_H01ol0003o
V;kboiRnl_nH__;o0000ojC1kOl000000onV`nh00ol0003o[l;Xojo2j006ojo2j0?o00001Onf`>83
o`000003okZngOl0003o]kcN00So]kcN1Ol00002okRifP03o`000?nc^Mgo/kWM00ko/kWM00?o0000
ojnkhon_^n<02_n_^n<6o`0000Oo[/;Y1?l00005ojk2j0?o00001_n^`^P2o`0000Co[KoW0_l00005
ojbmiP;o00001On[^nD3o`0000?oYK;R0_l00005ojBahP03o`000?nR/>;oX[3R00;oX[3R0_l0000b
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002gooooo00?o0000oooo
ooooool0Aoooool01?l0003oLk;hog>bn?l00003ogJcn0;o000000?oO[Kho`000?n:^_H00_n:^_H0
0ol0003oV;kboiRnlP02o`0000OoY/?^0_l00007ojo2j0;o00001_nf`>800ol0003o]kcNokNlgP0=
okNlgP?o00000onc^Md6o`0000Oo/kWM00Co0000ojnkhon_^n?o[k_S2Ol00004ojnmi003o`000?n^
`^Wo[/;Y00?o[/;Y0ol00006ojk2j0?o00000_n^`^P00ol0003o[/;Xojk2j002ojk2j0;o00001?n]
_nL2o`0000Go[;gV0_l00005oj^ki@;o00000onY^ND00ol0003oYK;Ro`000005ojBahP;o00001?nR
/>800ol0003oooooooooo`0cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool002kooooo0_l00018ooooo`;o000000?oLk;ho`000?l000000omf/oP00ol0003oO[Kho`000002
ohZjmP?o00000onK`o@00ol0003oY/?^ojK3kP05ojK3kP?o00001_n_`^P3o`000003okK0h_l0003o
/koS00Co/koS1_l00008okNlgP03o`000?nb_>3o/[cP00Oo/[cP2ol0000>ojnmi003o`000?n^`^Wo
000000;o00001On^`^P4o`0000Ko[/;X00Co0000ojk2j?l0003o00001?n]_nL2o`0000Co[;gV0ol0
0004oj^ki@?o00001OnY^ND3o`0000?oY;7R0_l00004oj:`hP;o0000=oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo00Co0000
og>bn?mc/_So00000_mf/oP5o`0000?oS/7h00?o0000oi_3m?nK`o@00onK`o@2o`0000KoY/?^0_l0
0007ojo2j003o`000?nc_n?o/koS00[o/koS1Ol00002okNlgP03o`000?nb_>3o/[cP00oo/[cP00?o
0000ojnmi?n__N@02on__N@6o`0000Co[/;X1?l00009ojk2j0?o00001?n]_nL2o`0000Co[;gV0_l0
0005oj^ki@;o00001OnY^ND3o`0000?oZ;SU00?o0000ojBah_l000001?nR/>82o`0003Wooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`17
ooooo`Go00000omk_O/2oh>onP03o`000?n>`OSoS/7h00?oS/7h00?o0000oi_3m?nK`o@00_nK`o@3
o`0000GoY/?^0_l00005ojo2j003o`000?n_`^So[l;X00Go00002_nc_n<3o`0000Co/[cP1Ol00008
ok:lh003o`000?n__NCo[kgT00;o[kgT2Ol00004ojo0iP03o`000?n^`^So[/;X00?o00002On^`^P4
o`0000?o[/;Y00Co0000ojfoiol0003o00001?n/_NH2o`0000GoZk_U0_l00005ojVii@;o00001_nX
^>D2o`0000CoX[3R00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00?ooooo000booooo`03o`000?oooooooooo04Sooooo0omh^o`5og^mn`03o`000?n3_o[o
Pkoj00;o00001?n>`OP2o`0000?oVl?d0ol00004ojK3kP?o000000?o[l;Xo`000?n_`^P01on_`^P5
o`0000Oo/koS00?o0000ok6oi?na_n@01ona_n@=o`0000_o[l3V1Ol00008ojk2j0Co00001_n^`^T3
o`0000Co[;gV0_l00005oj^ki@;o00001OnY^ND2o`0000GoZ;SU0ol00002ojNhi@04o`000?nR/>;o
0000o`0003kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<oooool2
o`0004_ooooo0omh^o`5og^mn`03o`000?n3_o[o000000;o00001?n>`OP2o`0000?oVl?d0_l00005
ojK3kP03o`000?n_`^So[l;X00co[l;X1Ol000000onc_n?o0000ok6oi00Aok6oi003o`000?n_`>Ko
[l3V00Ko[l3V1ol00003ojk2j003o`000?n^`^So[/;X00Co[/;X0ol00006ojk2j@Co00000on]`^T0
1?l0003o[;gVo`000?l00005oj^ki@;o00001?nY^ND3o`0000GoZ;SU0_l00005ojNhi@;o0000@Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooo
oooo04[ooooo00Co0000ogRko?mh^oco00001?mk_O/2o`000003oh>on_l0003o000000CoS/7h0ol0
0002oi_3m0?o000000?oY/?^o`000?nXa>h00onXa>h7o`0000Wo[l;X0_l00004ok6oi0Ko00002?na
_n@00ol0003o[l3Vojo0iP06o`0000_o[/;X00?o0000ojk2j?l000000ol00005ojk2j@Co00001_n]
`^T3o`0000CoZk_U0ol00004ojVii@;o00001OnX^>D3o`0000CoYkSU0ol00013ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0C?ooool2
ogRko0;o00000omk_O/2o`000004oh>on_l0003o0000o`0000CoS/7h0ol00002oi_3m003o`000?nX
a>koZ<C^00[oZ<C^1_l00003ojo2j003o`000?n^`^So[/;X00Wo[/;X2ol0000<ojk2j0Oo00001On^
`^T4o`0000Ko[L;Y1?l00003ojc1j@04o`000?n[^nGo0000o`0000GoZKWU0_l00005ojRhi@;o0000
1OnW^>D2o`0004Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=ooo
ool2o`0004kooooo00?o0000ogRko?mh^o`00_l00002og^mn`;o00000_n3_oX2o`0000GoS/7h00?o
0000oj36lonPa_<00onPa_<5o`0000[oZ<C^0ol0000:ojk2j003o`000?n^`^So[/;X00Oo[/;X00?o
0000ojk2j?n^`^P00_n^`^P:o`0000Go[LC[00?o0000ojk2jOn^`^T01?l00005ojg2j@Go00001_n/
`NT3o`0000CoZKWU0ol00005ojRhi@;o00001?nW^>D3o`0004[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`;o000000?oN;_l
o`000?l000000_mk_O/3o`000006oh>on_l0003o0000o`000?n>`OSo00000onGaoP2o`0000KoX<Kc
1Ol00007ojS4kP03o`000?n[aNgoZlG]00WoZlG]3_l0000;ojg4j`Oo00001On]`^T4o`0000Ko[<7Y
1Ol00003oj[1jP04o`000?nY^NGo0000o`0000GoZ;SU0ol00004ojNhi@;o0000C_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oooooooooo04oooooo
00?o0000ogRko?l000000_l00002og^mn`;o000000?oPkojo`000?l000002?nGaoP5o`0000CoX<Kc
1Ol000000onXa>ko0000oj_5k@0Doj_5k@03o`000?n]a>_o[LC[00;o[LC[2ol00005oj_5k@03o`00
0?n]`^Wo[L;Y00Co00001_n/`NT4o`0000OoZ/7Z0ol00005ojRhi@;o00001OnW^>D2o`00053ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003ooooooooo
o`1@ooooo`;o000000CoN;_lo`000?l0003oNkgk0_l00005oho6nP03o`000?nGaoSoUlOh00OoUlOh
1?l00005oj36l`;o00001On[aNdEo`0000goZlG]1_l00006ojc1j@Co00001_nZ`NX5o`0000?oZL3[
00?o0000ojRhiOl000000_l00004ojNhi@?o0000Doooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo000looooo`;o0000Doooool3o`0000CoR<Gl0_l00006oho6nPCo00001OnG
aoP4o`0000;oX<Kc00?o0000ojK7lOnVao404_nVao400ol0003oZlG]oj_5k@08oj_5k@So00001?nX
anl00ol0003o[<7Yojc1j@05o`0000GoZ/7Z1Ol00007ojW0j`?o00001OnW^>D2o`0005Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00?_ooool00ol0003oooooooooo`1C
ooooo`03o`000?n5a?co000000KoR<Gl1Ol00004oho6nPGo00000_nGaoP2o`0000GoY/Oa1_l0000:
ojK7l@04o`000?n[aNgoZlG]oj_5k@Oo00001onXanl8o`0000KoZ/7Z1?l00007ojW0j`Go00000onW
`>/00ol0003oYkSUo`000002o`0005[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`01ooooo`00?oooool00ol0003oooooooooo`1Fooooo`;o000000?oQLClo`000?l000001On8aO`4
o`0000GoSlKj0ol0000<oj79m0ko00000_nXanl<o`0000KoY/Oa00?o0000oj[1j_nZ`NX01Ol00006
ojW0j`Go00001_nW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01
ooooo`00@?ooool00ol0003oooooooooo`1Iooooo`?o000000?oQLClo`000?l000000_l00002ohS5
o0Go00000_n?a_X00ol0003oW<[goic:m`0:oic:ma3o00003OnVao48o`0000KoZL3[1Ol00006ojO0
j`Go0000H_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o
0000Foooool00ol0003oooooooooo`03o`000003ohG4o?l0003o000000?o000000?oR<Glo`000?l0
00002onLb_L00ol0003oW<[goic:m`09oic:m`03o`000?nVao7oY/Oa00?oY/Oa3Ol00006ojC7lP03
o`000?nY`>_oZL3[00Go00001_nW`>/5o`0006Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Cooooo
1?l000000on5a?co0000o`00000=oiS9nA7o00003OnTao89o`0000KoYl3[1Ol0001^ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`08ooooo`;o00001onFbOT=o`0000GoV<Wi00?o0000ojC7l_nTao800onT
ao8=o`0000KoX/Ob00Co0000ojO0jonW`>_oYl3[1Ol0001cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00Oooool004Gooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`0>ooooo`Wo00001onFbOT;o`0000koX/Ob2Ol0001iooooo`03o`000?oooooooooo00Sooooo0Ol0
0001ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Gooooo`Wo00000onFbOT0
0ol0003oX/Oboj;7lP04oj;7lPgo0000Poooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00B?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo023ooooo2_l0002Aoooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00
B_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool0
1Oooool1o`00007ooooo0Oooool004_ooooo0_l0001Aooooo`03o`000?oooooooooo0;gooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`2mooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001>oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`04oooo
o`7o00000Oooool004oooooo0_l0001=ooooo`03o`000?oooooooooo0;oooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001Aooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
`?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005;ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Doooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo0<7ooooo00Go0000ooooooooooooooooo`00
0001ooooo`00E?ooool2o`0004Sooooo00?o0000ooooooooool0`_ooool01?l0003oooooooooool0
0001ooooo`00E_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0<?ooooo00?o0000
ooooool000000Oooool005Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`33oooo
o`03o`000?oooooooooo007o0000001Hooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0a?ooool1o`00007ooooo0Ol0000005Wooooo0_l00013ooooo`03o`000?oooooooooo0<Gooooo
0_l0000005_ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`34ooooo`?o0000001L
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0`?ooool4o`0000?ooooo001Moooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool0_?ooool4o`0000Oooooo001Nooooo`;o
0000?_ooool00ol0003oooooooooo`2hooooo`Co00002oooool0063ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2dooooo`Co00003oooool0067ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`2aooooo`?o00004oooool006;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`2]ooooo`Co00005_ooool006?ooooo0_l0000iooooo`03o`000?oooooooooo
0:Wooooo1?l0000Jooooo`00IOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Go
oooo1?l0000Nooooo`00I_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:;ooooo
1?l0000Rooooo`00Ioooool2o`0003Cooooo00?o0000ooooooooool0W_ooool4o`0002Kooooo001Y
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0V_ooool4o`0002[ooooo001Zoooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0U_ooool4o`0002kooooo001[ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0T_ooool4o`0003;ooooo001/ooooo`;o0000
;oooool00ol0003oooooooooo`2>ooooo`Co0000=_ooool006kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`2:ooooo`Co0000>_ooool006oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`27ooooo`?o0000?_ooool0073ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`23ooooo`Co0000@Oooool0077ooooo0_l0000Zooooo`03o`000?oooooooooo07oo
oooo1?l00015ooooo`00Loooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07_ooooo
1?l00019ooooo`00M?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0
001=ooooo`00MOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07?ooooo1?l0001A
ooooo`00M_ooool2o`0002Gooooo00?o0000ooooooooool0Koooool4o`0005Gooooo001hooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Wooooo001iooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005gooooo001jooooo`;o00008Ooo
ool00ol0003oooooooooo`1Sooooo`Co0000HOooool007cooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Pooooo`?o0000IOooool007gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Looooo`Co0000J?ooool007kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1Hooooo`Co0000K?ooool007oooooo0_l0000Looooo`03o`000?oooooooooo05Cooooo
1?l0001`ooooo`00POooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo053ooooo1?l0
001dooooo`00P_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l0001h
ooooo`00Poooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001loooo
o`00Q?ooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`00083ooooo0026ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008Cooooo0027ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008Sooooo0028ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0>Oooool3o`0008cooooo0029ooooo`;o00004_ooool00ol0
003oooooooooo`0eooooo`Co0000Soooool008_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0booooo`Co0000Toooool008cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0^ooooo`Co0000Uoooool008gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Zooooo`Co0000Voooool008kooooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo1?l0002O
ooooo`00T?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Soooo
o`00TOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Wooooo`00
T_ooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:_ooooo002Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:oooooo002Eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04_ooool4o`000;?ooooo002Fooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool3o`000;Oooooo002Gooooo`;o00000oooool00ol0003o
ooooooooo`0;ooooo`Co0000^_ooool009Wooooo00Co0000oooooooooooo00002Oooool4o`000;ko
oooo002Jooooo`03o`000?oooooo000000Gooooo1?l00032ooooo`00Voooool2o`000003ooooool0
003o000000;o0000a_ooool009cooooo0_l0003:ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03386 .2586 -12 -2.71522 ]
[.03386 .2586 0 6.28478 ]
[.02307 .32624 -24 -2.77285 ]
[.02307 .32624 0 6.22715 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[-4e-05 .47105 -18 -2.89707 ]
[-4e-05 .47105 0 6.10293 ]
[-0.01242 .54867 -6 -2.96413 ]
[-0.01242 .54867 0 6.03587 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04606 .25376 m
.05216 .25134 L
s
[(-1)] .03386 .2586 1 -0.39662 Mshowa
.03532 .32154 m
.04145 .31918 L
s
[(-0.5)] .02307 .32624 1 -0.38381 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01233 .46664 m
.01851 .46444 L
s
[(0.5)] -4e-05 .47105 1 -0.35621 Mshowa
0 .54443 m
.00621 .54231 L
s
[(1)] -0.01242 .54867 1 -0.3413 Mshowa
.125 Mabswid
.04395 .26707 m
.04762 .26563 L
s
.04182 .28051 m
.04549 .27907 L
s
.03968 .29406 m
.04335 .29264 L
s
.03751 .30774 m
.04118 .30632 L
s
.03312 .33546 m
.0368 .33406 L
s
.03089 .34951 m
.03457 .34811 L
s
.02864 .36368 m
.03233 .3623 L
s
.02638 .37799 m
.03007 .37661 L
s
.02178 .40699 m
.02548 .40564 L
s
.01945 .4217 m
.02315 .42035 L
s
.0171 .43654 m
.0208 .4352 L
s
.01472 .45152 m
.01843 .45019 L
s
.00991 .4819 m
.01362 .48059 L
s
.00747 .49731 m
.01118 .49601 L
s
.005 .51287 m
.00872 .51158 L
s
.00251 .52857 m
.00624 .52729 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65641 m .51694 .65827 L .43899 .65168 L p .286 .744 .953 r
F P
0 g
s
.51694 .65827 m .51723 .65641 L .59268 .64991 L p .575 .818 .99 r
F P
0 g
s
.59268 .64991 m .59527 .65394 L .51694 .65827 L p .575 .818 .99 r
F P
0 g
s
.59527 .65394 m .59268 .64991 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.43899 .65168 m .44208 .65206 L .51723 .65641 L p .286 .744 .953 r
F P
0 g
s
.44208 .65206 m .43899 .65168 L .36521 .63435 L p 0 .48 .744 r
F P
0 g
s
.51753 .65434 m .51723 .65641 L .44208 .65206 L p .333 .771 .966 r
F P
0 g
s
.51723 .65641 m .51753 .65434 L .59005 .64573 L p .6 .826 .986 r
F P
0 g
s
.59005 .64573 m .59268 .64991 L .51723 .65641 L p .6 .826 .986 r
F P
0 g
s
.59268 .64991 m .59005 .64573 L .65915 .62672 L p .67 .756 .915 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59268 .64991 L p .67 .756 .915 r
F P
0 g
s
.36521 .63435 m .37093 .63691 L .44208 .65206 L p 0 .48 .744 r
F P
0 g
s
.44208 .65206 m .4452 .65217 L .51753 .65434 L p .333 .771 .966 r
F P
0 g
s
.4452 .65217 m .44208 .65206 L .37093 .63691 L p 0 .524 .78 r
F P
0 g
s
.51784 .65165 m .51753 .65434 L .4452 .65217 L p .431 .811 .991 r
F P
0 g
s
.51753 .65434 m .51784 .65165 L .5874 .6412 L p .633 .829 .976 r
F P
0 g
s
.5874 .6412 m .59005 .64573 L .51753 .65434 L p .633 .829 .976 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72962 .60566 L p .647 .675 .863 r
F P
0 g
s
.72962 .60566 m .73799 .61332 L .67023 .63881 L p .647 .675 .863 r
F P
0 g
s
.59005 .64573 m .5874 .6412 L .65355 .62061 L p .684 .76 .909 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59005 .64573 L p .684 .76 .909 r
F P
0 g
s
.30757 .61138 m .31583 .61564 L .366 .63502 L p 0 .331 .668 r
F P
0 g
s
.37093 .63691 m .36521 .63435 L .3116 .61189 L p .298 0 0 r
F P
0 g
s
.37093 .63691 m .3116 .61189 L .31897 .61503 L .298 0 0 r
F
.37093 .63691 m .37673 .63916 L .4452 .65217 L p 0 .524 .78 r
F P
0 g
s
.29943 .6068 m .30757 .61138 L .37093 .63691 L p .298 0 0 r
F P
0 g
s
.37673 .63916 m .37093 .63691 L .34385 .626 L p 0 .331 .668 r
F P
0 g
s
.34385 .626 m .30757 .61138 L p .34559 .62665 L 0 .331 .668 r
F P
0 g
s
.37673 .63916 m .34385 .626 L .34559 .62665 L 0 .331 .668 r
F
.35895 .63202 m .30757 .61138 L .366 .63502 L F
.366 .63502 m .37673 .63916 L p .35895 .63202 L F P
0 g
s
.44839 .65143 m .4452 .65217 L .37673 .63916 L p .114 .636 .882 r
F P
0 g
s
.37673 .63916 m .38264 .64039 L .44839 .65143 L p .114 .636 .882 r
F P
0 g
s
.37673 .63916 m .31583 .61564 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.38264 .64039 m .37719 .63925 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.37719 .63925 m .37673 .63916 L p .3627 .633 L 0 .464 .796 r
F P
0 g
s
.33288 .62004 m .3887 .63996 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.31583 .61564 m .32425 .61877 L .35028 .62841 L p 0 .464 .796 r
F P
0 g
s
.34861 .62779 m .31583 .61564 L .35028 .62841 L 0 .464 .796 r
F
.32425 .61877 m .33252 .61999 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.33252 .61999 m .33288 .62004 L p .34717 .62631 L .188 .64 .942 r
F P
0 g
s
.35028 .62841 m .38264 .64039 L p .34861 .62779 L 0 .464 .796 r
F P
0 g
s
.3116 .61189 m .29943 .6068 L p .31897 .61503 L .298 0 0 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72121 .59807 L p .658 .68 .859 r
F P
0 g
s
.72121 .59807 m .72962 .60566 L .66471 .63279 L p .658 .68 .859 r
F P
0 g
s
.4452 .65217 m .44839 .65143 L .51784 .65165 L p .431 .811 .991 r
F P
0 g
s
.51815 .64796 m .51784 .65165 L .44839 .65143 L p .544 .835 .999 r
F P
0 g
s
.51784 .65165 m .51815 .64796 L .58471 .63614 L p .665 .823 .959 r
F P
0 g
s
.58471 .63614 m .5874 .6412 L .51784 .65165 L p .665 .823 .959 r
F P
0 g
s
.5874 .6412 m .58471 .63614 L .6479 .61445 L p .697 .764 .903 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .5874 .6412 L p .697 .764 .903 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71278 .59074 L p .671 .689 .859 r
F P
0 g
s
.71278 .59074 m .72121 .59807 L .65915 .62672 L p .671 .689 .859 r
F P
0 g
s
.58199 .63037 m .58471 .63614 L .51815 .64796 L p .692 .809 .938 r
F P
0 g
s
.58471 .63614 m .58199 .63037 L .64221 .60824 L p .708 .767 .898 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58471 .63614 L p .708 .767 .898 r
F P
0 g
s
.44839 .65143 m .45164 .64932 L .51815 .64796 L p .544 .835 .999 r
F P
0 g
s
.51846 .64298 m .51815 .64796 L .45164 .64932 L p .635 .829 .975 r
F P
0 g
s
.51815 .64796 m .51846 .64298 L .58199 .63037 L p .692 .809 .938 r
F P
0 g
s
.45164 .64932 m .44839 .65143 L .38264 .64039 L p .342 .755 .979 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70433 .58388 L p .684 .704 .862 r
F P
0 g
s
.70433 .58388 m .71278 .59074 L .65355 .62061 L p .684 .704 .862 r
F P
0 g
s
.57923 .62378 m .58199 .63037 L .51846 .64298 L p .71 .79 .914 r
F P
0 g
s
.58199 .63037 m .57923 .62378 L .63648 .60198 L p .716 .769 .894 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58199 .63037 L p .716 .769 .894 r
F P
0 g
s
.45164 .64932 m .45497 .64538 L .51846 .64298 L p .635 .829 .975 r
F P
0 g
s
.51879 .63645 m .51846 .64298 L .45497 .64538 L p .692 .802 .933 r
F P
0 g
s
.51846 .64298 m .51879 .63645 L .57923 .62378 L p .71 .79 .914 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69586 .57763 L p .697 .723 .869 r
F P
0 g
s
.69586 .57763 m .70433 .58388 L .6479 .61445 L p .697 .723 .869 r
F P
0 g
s
.38264 .64039 m .3887 .63996 L .45164 .64932 L p .342 .755 .979 r
F P
0 g
s
.45497 .64538 m .45164 .64932 L .3887 .63996 L p .543 .809 .995 r
F P
0 g
s
.73799 .61332 m .72962 .60566 L .78364 .56952 L p .606 .614 .833 r
F P
0 g
s
.78364 .56952 m .79464 .57831 L .73799 .61332 L p .606 .614 .833 r
F P
0 g
s
.72962 .60566 m .72121 .59807 L .77262 .56091 L p .617 .619 .831 r
F P
0 g
s
.77262 .56091 m .78364 .56952 L .72962 .60566 L p .617 .619 .831 r
F P
0 g
s
.57643 .61632 m .57923 .62378 L .51879 .63645 L p .72 .768 .891 r
F P
0 g
s
.57923 .62378 m .57643 .61632 L .6307 .59568 L p .72 .77 .892 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57923 .62378 L p .72 .77 .892 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68739 .5721 L p .71 .746 .88 r
F P
0 g
s
.68739 .5721 m .69586 .57763 L .64221 .60824 L p .71 .746 .88 r
F P
0 g
s
.45497 .64538 m .45837 .63929 L .51879 .63645 L p .692 .802 .933 r
F P
0 g
s
.51911 .62827 m .51879 .63645 L .45837 .63929 L p .722 .767 .889 r
F P
0 g
s
.51879 .63645 m .51911 .62827 L .57643 .61632 L p .72 .768 .891 r
F P
0 g
s
.30757 .61138 m .29943 .6068 L .24558 .56996 L p 0 .252 .686 r
F P
0 g
s
.3887 .63996 m .3949 .63729 L .45497 .64538 L p .543 .809 .995 r
F P
0 g
s
.45837 .63929 m .45497 .64538 L .3949 .63729 L p .664 .799 .947 r
F P
0 g
s
.72121 .59807 m .71278 .59074 L .76164 .55289 L p .631 .633 .834 r
F P
0 g
s
.76164 .55289 m .77262 .56091 L .72121 .59807 L p .631 .633 .834 r
F P
0 g
s
.3887 .63996 m .38264 .64039 L .32425 .61877 L p .188 .64 .942 r
F P
0 g
s
.5736 .60797 m .57643 .61632 L .51911 .62827 L p .723 .747 .87 r
F P
0 g
s
.57643 .61632 m .5736 .60797 L .62488 .58932 L p .72 .77 .892 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57643 .61632 L p .72 .77 .892 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .6789 .56737 L p .721 .772 .893 r
F P
0 g
s
.6789 .56737 m .68739 .5721 L .63648 .60198 L p .721 .772 .893 r
F P
0 g
s
.45837 .63929 m .46184 .63087 L .51911 .62827 L p .722 .767 .889 r
F P
0 g
s
.51945 .61843 m .51911 .62827 L .46184 .63087 L p .735 .735 .851 r
F P
0 g
s
.51911 .62827 m .51945 .61843 L .5736 .60797 L p .723 .747 .87 r
F P
0 g
s
.71278 .59074 m .70433 .58388 L .75069 .54581 L p .65 .655 .842 r
F P
0 g
s
.75069 .54581 m .76164 .55289 L .71278 .59074 L p .65 .655 .842 r
F P
0 g
s
.3949 .63729 m .40126 .63198 L .45837 .63929 L p .664 .799 .947 r
F P
0 g
s
.46184 .63087 m .45837 .63929 L .40126 .63198 L p .723 .767 .888 r
F P
0 g
s
.24558 .56996 m .25585 .57634 L .30757 .61138 L p 0 .252 .686 r
F P
0 g
s
.31583 .61564 m .30757 .61138 L .25585 .57634 L p 0 .292 .722 r
F P
0 g
s
.70433 .58388 m .69586 .57763 L .73979 .53997 L p .672 .685 .855 r
F P
0 g
s
.73979 .53997 m .75069 .54581 L .70433 .58388 L p .672 .685 .855 r
F P
0 g
s
.3949 .63729 m .3887 .63996 L .33288 .62004 L p .462 .756 .993 r
F P
0 g
s
.57074 .5988 m .5736 .60797 L .51945 .61843 L p .721 .726 .855 r
F P
0 g
s
.5736 .60797 m .57074 .5988 L .61901 .58292 L p .714 .769 .895 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .5736 .60797 L p .714 .769 .895 r
F P
0 g
s
.46184 .63087 m .46538 .62011 L .51945 .61843 L p .735 .735 .851 r
F P
0 g
s
.51978 .60705 m .51945 .61843 L .46538 .62011 L p .738 .708 .822 r
F P
0 g
s
.51945 .61843 m .51978 .60705 L .57074 .5988 L p .721 .726 .855 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67038 .56342 L p .726 .8 .91 r
F P
0 g
s
.67038 .56342 m .6789 .56737 L .6307 .59568 L p .726 .8 .91 r
F P
0 g
s
.40126 .63198 m .40777 .62382 L .46184 .63087 L p .723 .767 .888 r
F P
0 g
s
.46538 .62011 m .46184 .63087 L .40777 .62382 L p .751 .736 .839 r
F P
0 g
s
.69586 .57763 m .68739 .5721 L .72895 .53559 L p .696 .725 .872 r
F P
0 g
s
.72895 .53559 m .73979 .53997 L .69586 .57763 L p .696 .725 .872 r
F P
0 g
s
.46538 .62011 m .46897 .60722 L .51978 .60705 L p .738 .708 .822 r
F P
0 g
s
.52012 .59439 m .51978 .60705 L .46897 .60722 L p .736 .686 .802 r
F P
0 g
s
.51978 .60705 m .52012 .59439 L .56784 .58893 L p .713 .708 .844 r
F P
0 g
s
.56784 .58893 m .57074 .5988 L .51978 .60705 L p .713 .708 .844 r
F P
0 g
s
.57074 .5988 m .56784 .58893 L .61309 .57646 L p .702 .765 .901 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57074 .5988 L p .702 .765 .901 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66184 .5602 L p .725 .829 .929 r
F P
0 g
s
.66184 .5602 m .67038 .56342 L .62488 .58932 L p .725 .829 .929 r
F P
0 g
s
.33288 .62004 m .34172 .61881 L .3949 .63729 L p .462 .756 .993 r
F P
0 g
s
.40126 .63198 m .3949 .63729 L .34172 .61881 L p .637 .783 .951 r
F P
0 g
s
.40777 .62382 m .41441 .61281 L .46538 .62011 L p .751 .736 .839 r
F P
0 g
s
.46897 .60722 m .46538 .62011 L .41441 .61281 L p .762 .71 .803 r
F P
0 g
s
.25585 .57634 m .26627 .58239 L .31583 .61564 L p 0 .292 .722 r
F P
0 g
s
.32425 .61877 m .31583 .61564 L .26627 .58239 L p 0 .412 .825 r
F P
0 g
s
.68739 .5721 m .6789 .56737 L .71815 .53279 L p .722 .774 .894 r
F P
0 g
s
.71815 .53279 m .72895 .53559 L .68739 .5721 L p .722 .774 .894 r
F P
0 g
s
.46897 .60722 m .47261 .59254 L .52012 .59439 L p .736 .686 .802 r
F P
0 g
s
.52047 .58078 m .52012 .59439 L .47261 .59254 L p .729 .668 .789 r
F P
0 g
s
.52012 .59439 m .52047 .58078 L .56493 .57855 L p .7 .691 .838 r
F P
0 g
s
.56493 .57855 m .56784 .58893 L .52012 .59439 L p .7 .691 .838 r
F P
0 g
s
.56784 .58893 m .56493 .57855 L .60713 .56996 L p .682 .76 .91 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56784 .58893 L p .682 .76 .91 r
F P
0 g
s
.41441 .61281 m .42116 .5992 L .46897 .60722 L p .762 .71 .803 r
F P
0 g
s
.47261 .59254 m .46897 .60722 L .42116 .5992 L p .766 .69 .778 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65325 .55758 L p .711 .854 .95 r
F P
0 g
s
.65325 .55758 m .66184 .5602 L .61901 .58292 L p .711 .854 .95 r
F P
0 g
s
.34172 .61881 m .35079 .61463 L .40126 .63198 L p .637 .783 .951 r
F P
0 g
s
.40777 .62382 m .40126 .63198 L .35079 .61463 L p .725 .768 .888 r
F P
0 g
s
.47261 .59254 m .47628 .57657 L .52047 .58078 L p .729 .668 .789 r
F P
0 g
s
.52082 .56666 m .52047 .58078 L .47628 .57657 L p .719 .653 .783 r
F P
0 g
s
.52047 .58078 m .52082 .56666 L .56198 .56786 L p .682 .675 .837 r
F P
0 g
s
.56198 .56786 m .56493 .57855 L .52047 .58078 L p .682 .675 .837 r
F P
0 g
s
.6789 .56737 m .67038 .56342 L .70737 .53156 L p .744 .829 .917 r
F P
0 g
s
.70737 .53156 m .71815 .53279 L .6789 .56737 L p .744 .829 .917 r
F P
0 g
s
.42116 .5992 m .428 .58342 L .47261 .59254 L p .766 .69 .778 r
F P
0 g
s
.47628 .57657 m .47261 .59254 L .428 .58342 L p .764 .674 .763 r
F P
0 g
s
.56493 .57855 m .56198 .56786 L .60112 .5634 L p .652 .75 .922 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56493 .57855 L p .652 .75 .922 r
F P
0 g
s
.26627 .58239 m .27687 .58727 L .32425 .61877 L p 0 .412 .825 r
F P
0 g
s
.33288 .62004 m .32425 .61877 L .27687 .58727 L p .177 .575 .937 r
F P
0 g
s
.79464 .57831 m .78364 .56952 L .82304 .52587 L p .547 .566 .826 r
F P
0 g
s
.82304 .52587 m .83625 .53514 L .79464 .57831 L p .547 .566 .826 r
F P
0 g
s
.428 .58342 m .43488 .56609 L .47628 .57657 L p .764 .674 .763 r
F P
0 g
s
.47997 .55991 m .47628 .57657 L .43488 .56609 L p .759 .662 .755 r
F P
0 g
s
.47628 .57657 m .47997 .55991 L .52082 .56666 L p .719 .653 .783 r
F P
0 g
s
.52116 .55249 m .52082 .56666 L .47997 .55991 L p .704 .641 .783 r
F P
0 g
s
.52082 .56666 m .52116 .55249 L .55902 .55712 L p .657 .66 .841 r
F P
0 g
s
.55902 .55712 m .56198 .56786 L .52082 .56666 L p .657 .66 .841 r
F P
0 g
s
.35079 .61463 m .36008 .60725 L .40777 .62382 L p .725 .768 .888 r
F P
0 g
s
.41441 .61281 m .40777 .62382 L .36008 .60725 L p .768 .747 .834 r
F P
0 g
s
.78364 .56952 m .77262 .56091 L .80987 .51691 L p .558 .572 .824 r
F P
0 g
s
.80987 .51691 m .82304 .52587 L .78364 .56952 L p .558 .572 .824 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64461 .5554 L p .681 .871 .971 r
F P
0 g
s
.64461 .5554 m .65325 .55758 L .61309 .57646 L p .681 .871 .971 r
F P
0 g
s
.43488 .56609 m .4418 .54797 L .47997 .55991 L p .759 .662 .755 r
F P
0 g
s
.48368 .54324 m .47997 .55991 L .4418 .54797 L p .75 .653 .754 r
F P
0 g
s
.47997 .55991 m .48368 .54324 L .52116 .55249 L p .704 .641 .783 r
F P
0 g
s
.77262 .56091 m .76164 .55289 L .7968 .5088 L p .577 .589 .829 r
F P
0 g
s
.7968 .5088 m .80987 .51691 L .77262 .56091 L p .577 .589 .829 r
F P
0 g
s
.67038 .56342 m .66184 .5602 L .69661 .53178 L p .755 .885 .937 r
F P
0 g
s
.69661 .53178 m .70737 .53156 L .67038 .56342 L p .755 .885 .937 r
F P
0 g
s
.52151 .53875 m .52116 .55249 L .48368 .54324 L p .683 .629 .79 r
F P
0 g
s
.52116 .55249 m .52151 .53875 L .55605 .54656 L p .624 .644 .85 r
F P
0 g
s
.55605 .54656 m .55902 .55712 L .52116 .55249 L p .624 .644 .85 r
F P
0 g
s
.56198 .56786 m .55902 .55712 L .59506 .55679 L p .609 .735 .935 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56198 .56786 L p .609 .735 .935 r
F P
0 g
s
.76164 .55289 m .75069 .54581 L .78384 .50207 L p .603 .618 .839 r
F P
0 g
s
.78384 .50207 m .7968 .5088 L .76164 .55289 L p .603 .618 .839 r
F P
0 g
s
.4418 .54797 m .44872 .52988 L .48368 .54324 L p .75 .653 .754 r
F P
0 g
s
.48738 .52721 m .48368 .54324 L .44872 .52988 L p .735 .646 .76 r
F P
0 g
s
.48368 .54324 m .48738 .52721 L .52151 .53875 L p .683 .629 .79 r
F P
0 g
s
.36008 .60725 m .36955 .5967 L .41441 .61281 L p .768 .747 .834 r
F P
0 g
s
.42116 .5992 m .41441 .61281 L .36955 .5967 L p .789 .728 .795 r
F P
0 g
s
.75069 .54581 m .73979 .53997 L .77102 .49714 L p .637 .659 .854 r
F P
0 g
s
.77102 .49714 m .78384 .50207 L .75069 .54581 L p .637 .659 .854 r
F P
0 g
s
.27687 .58727 m .28772 .59021 L .33288 .62004 L p .177 .575 .937 r
F P
0 g
s
.34172 .61881 m .33288 .62004 L .28772 .59021 L p .438 .702 .977 r
F P
0 g
s
.44872 .52988 m .45562 .51262 L .48738 .52721 L p .735 .646 .76 r
F P
0 g
s
.49109 .51247 m .48738 .52721 L .45562 .51262 L p .714 .639 .772 r
F P
0 g
s
.48738 .52721 m .49109 .51247 L .52186 .52588 L p .653 .618 .802 r
F P
0 g
s
.52186 .52588 m .52151 .53875 L .48738 .52721 L p .653 .618 .802 r
F P
0 g
s
.36955 .5967 m .37918 .58325 L .42116 .5992 L p .789 .728 .795 r
F P
0 g
s
.428 .58342 m .42116 .5992 L .37918 .58325 L p .799 .713 .769 r
F P
0 g
s
.25585 .57634 m .24558 .56996 L .20758 .52532 L p 0 .326 .805 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .6359 .55343 L p .628 .875 .988 r
F P
0 g
s
.6359 .55343 m .64461 .5554 L .60713 .56996 L p .628 .875 .988 r
F P
0 g
s
.52151 .53875 m .52186 .52588 L .55305 .53642 L p .577 .625 .863 r
F P
0 g
s
.55305 .53642 m .55605 .54656 L .52151 .53875 L p .577 .625 .863 r
F P
0 g
s
.37918 .58325 m .38892 .5674 L .428 .58342 L p .799 .713 .769 r
F P
0 g
s
.43488 .56609 m .428 .58342 L .38892 .5674 L p .802 .701 .753 r
F P
0 g
s
.66184 .5602 m .65325 .55758 L .68583 .53324 L p .747 .933 .949 r
F P
0 g
s
.68583 .53324 m .69661 .53178 L .66184 .5602 L p .747 .933 .949 r
F P
0 g
s
.73979 .53997 m .72895 .53559 L .75834 .49431 L p .678 .711 .873 r
F P
0 g
s
.75834 .49431 m .77102 .49714 L .73979 .53997 L p .678 .711 .873 r
F P
0 g
s
.55902 .55712 m .55605 .54656 L .58896 .55013 L p .548 .711 .947 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55902 .55712 L p .548 .711 .947 r
F P
0 g
s
.38892 .5674 m .39873 .54985 L .43488 .56609 L p .802 .701 .753 r
F P
0 g
s
.4418 .54797 m .43488 .56609 L .39873 .54985 L p .801 .693 .745 r
F P
0 g
s
.39873 .54985 m .40855 .53146 L .4418 .54797 L p .801 .693 .745 r
F P
0 g
s
.44872 .52988 m .4418 .54797 L .40855 .53146 L p .796 .687 .744 r
F P
0 g
s
.45562 .51262 m .46251 .49698 L .49109 .51247 L p .714 .639 .772 r
F P
0 g
s
.49479 .49956 m .49109 .51247 L .46251 .49698 L p .682 .631 .791 r
F P
0 g
s
.49109 .51247 m .49479 .49956 L .52222 .51428 L p .61 .605 .821 r
F P
0 g
s
.52222 .51428 m .52186 .52588 L .49109 .51247 L p .61 .605 .821 r
F P
0 g
s
.40855 .53146 m .41835 .51314 L .44872 .52988 L p .796 .687 .744 r
F P
0 g
s
.45562 .51262 m .44872 .52988 L .41835 .51314 L p .786 .682 .75 r
F P
0 g
s
.41835 .51314 m .42811 .4958 L .45562 .51262 L p .786 .682 .75 r
F P
0 g
s
.46251 .49698 m .45562 .51262 L .42811 .4958 L p .769 .679 .763 r
F P
0 g
s
.52186 .52588 m .52222 .51428 L .55004 .52691 L p .512 .599 .878 r
F P
0 g
s
.55004 .52691 m .55305 .53642 L .52186 .52588 L p .512 .599 .878 r
F P
0 g
s
.72895 .53559 m .71815 .53279 L .74579 .49373 L p .723 .775 .894 r
F P
0 g
s
.74579 .49373 m .75834 .49431 L .72895 .53559 L p .723 .775 .894 r
F P
0 g
s
.42811 .4958 m .43781 .4803 L .46251 .49698 L p .769 .679 .763 r
F P
0 g
s
.46936 .48361 m .46251 .49698 L .43781 .4803 L p .742 .674 .785 r
F P
0 g
s
.46251 .49698 m .46936 .48361 L .49479 .49956 L p .682 .631 .791 r
F P
0 g
s
.28772 .59021 m .29884 .59055 L .34172 .61881 L p .438 .702 .977 r
F P
0 g
s
.35079 .61463 m .34172 .61881 L .29884 .59055 L p .621 .758 .944 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62711 .55144 L p .548 .857 .997 r
F P
0 g
s
.62711 .55144 m .6359 .55343 L .60112 .5634 L p .548 .857 .997 r
F P
0 g
s
.49849 .48891 m .49479 .49956 L .46936 .48361 L p .632 .619 .819 r
F P
0 g
s
.49479 .49956 m .49849 .48891 L .52257 .50427 L p .547 .585 .844 r
F P
0 g
s
.52257 .50427 m .52222 .51428 L .49479 .49956 L p .547 .585 .844 r
F P
0 g
s
.55605 .54656 m .55305 .53642 L .5828 .54342 L p .466 .673 .954 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55605 .54656 L p .466 .673 .954 r
F P
0 g
s
.65325 .55758 m .64461 .5554 L .67499 .53558 L p .708 .96 .945 r
F P
0 g
s
.67499 .53558 m .68583 .53324 L .65325 .55758 L p .708 .96 .945 r
F P
0 g
s
.20758 .52532 m .21958 .53321 L .25585 .57634 L p 0 .326 .805 r
F P
0 g
s
.26627 .58239 m .25585 .57634 L .21958 .53321 L p 0 .358 .827 r
F P
0 g
s
.43781 .4803 m .44745 .46737 L .46936 .48361 L p .742 .674 .785 r
F P
0 g
s
.4762 .47303 m .46936 .48361 L .44745 .46737 L p .698 .667 .816 r
F P
0 g
s
.46936 .48361 m .4762 .47303 L .49849 .48891 L p .632 .619 .819 r
F P
0 g
s
.71815 .53279 m .70737 .53156 L .73333 .49541 L p .767 .845 .91 r
F P
0 g
s
.73333 .49541 m .74579 .49373 L .71815 .53279 L p .767 .845 .91 r
F P
0 g
s
.52222 .51428 m .52257 .50427 L .54702 .5182 L p .422 .562 .89 r
F P
0 g
s
.54702 .5182 m .55004 .52691 L .52222 .51428 L p .422 .562 .89 r
F P
0 g
s
.29884 .59055 m .31022 .58781 L .35079 .61463 L p .621 .758 .944 r
F P
0 g
s
.36008 .60725 m .35079 .61463 L .31022 .58781 L p .726 .77 .888 r
F P
0 g
s
.5022 .4808 m .49849 .48891 L .4762 .47303 L p .552 .597 .852 r
F P
0 g
s
.49849 .48891 m .5022 .4808 L .52292 .49605 L p .45 .551 .867 r
F P
0 g
s
.52292 .49605 m .52257 .50427 L .49849 .48891 L p .45 .551 .867 r
F P
0 g
s
.44745 .46737 m .45703 .45758 L .4762 .47303 L p .698 .667 .816 r
F P
0 g
s
.48304 .46559 m .4762 .47303 L .45703 .45758 L p .624 .649 .855 r
F P
0 g
s
.4762 .47303 m .48304 .46559 L .5022 .4808 L p .552 .597 .852 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61824 .54916 L p .438 .812 .993 r
F P
0 g
s
.61824 .54916 m .62711 .55144 L .59506 .55679 L p .438 .812 .993 r
F P
0 g
s
.55305 .53642 m .55004 .52691 L .5766 .53665 L p .359 .619 .95 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55305 .53642 L p .359 .619 .95 r
F P
0 g
s
.39448 .49396 m .40655 .47771 L .42811 .4958 L p .835 .737 .756 r
F P
0 g
s
.42811 .4958 m .41835 .51314 L .39448 .49396 L p .835 .737 .756 r
F P
0 g
s
.43781 .4803 m .42811 .4958 L .40655 .47771 L p .82 .737 .772 r
F P
0 g
s
.40655 .47771 m .41852 .46341 L .43781 .4803 L p .82 .737 .772 r
F P
0 g
s
.44745 .46737 m .43781 .4803 L .41852 .46341 L p .795 .736 .798 r
F P
0 g
s
.64461 .5554 m .6359 .55343 L .66409 .53841 L p .632 .957 .924 r
F P
0 g
s
.66409 .53841 m .67499 .53558 L .64461 .5554 L p .632 .957 .924 r
F P
0 g
s
.38233 .51126 m .39448 .49396 L .41835 .51314 L p .842 .738 .749 r
F P
0 g
s
.41835 .51314 m .40855 .53146 L .38233 .51126 L p .842 .738 .749 r
F P
0 g
s
.70737 .53156 m .69661 .53178 L .72094 .49918 L p .8 .913 .917 r
F P
0 g
s
.72094 .49918 m .73333 .49541 L .70737 .53156 L p .8 .913 .917 r
F P
0 g
s
.31022 .58781 m .32186 .58176 L .36008 .60725 L p .726 .77 .888 r
F P
0 g
s
.36955 .5967 m .36008 .60725 L .32186 .58176 L p .783 .766 .838 r
F P
0 g
s
.41852 .46341 m .43039 .45181 L .44745 .46737 L p .795 .736 .798 r
F P
0 g
s
.45703 .45758 m .44745 .46737 L .43039 .45181 L p .751 .731 .834 r
F P
0 g
s
.37012 .52866 m .38233 .51126 L .40855 .53146 L p .844 .74 .749 r
F P
0 g
s
.40855 .53146 m .39873 .54985 L .37012 .52866 L p .844 .74 .749 r
F P
0 g
s
.21958 .53321 m .23172 .54077 L .26627 .58239 L p 0 .358 .827 r
F P
0 g
s
.27687 .58727 m .26627 .58239 L .23172 .54077 L p .094 .445 .88 r
F P
0 g
s
.52257 .50427 m .52292 .49605 L .54397 .51039 L p .297 .506 .89 r
F P
0 g
s
.54397 .51039 m .54702 .5182 L .52257 .50427 L p .297 .506 .89 r
F P
0 g
s
.35792 .54522 m .37012 .52866 L .39873 .54985 L p .841 .744 .757 r
F P
0 g
s
.39873 .54985 m .38892 .5674 L .35792 .54522 L p .841 .744 .757 r
F P
0 g
s
.32186 .58176 m .33373 .57241 L .36955 .5967 L p .783 .766 .838 r
F P
0 g
s
.37918 .58325 m .36955 .5967 L .33373 .57241 L p .814 .758 .8 r
F P
0 g
s
.43039 .45181 m .44216 .44349 L .45703 .45758 L p .751 .731 .834 r
F P
0 g
s
.46659 .45131 m .45703 .45758 L .44216 .44349 L p .672 .715 .88 r
F P
0 g
s
.45703 .45758 m .46659 .45131 L .48304 .46559 L p .624 .649 .855 r
F P
0 g
s
.34576 .56005 m .35792 .54522 L .38892 .5674 L p .832 .75 .774 r
F P
0 g
s
.38892 .5674 m .37918 .58325 L .34576 .56005 L p .832 .75 .774 r
F P
0 g
s
.33373 .57241 m .34576 .56005 L .37918 .58325 L p .814 .758 .8 r
F P
0 g
s
.48988 .46142 m .48304 .46559 L .46659 .45131 L p .496 .608 .893 r
F P
0 g
s
.48304 .46559 m .48988 .46142 L .50592 .47537 L p .422 .551 .88 r
F P
0 g
s
.50592 .47537 m .5022 .4808 L .48304 .46559 L p .422 .551 .88 r
F P
0 g
s
.5022 .4808 m .50592 .47537 L .52328 .4897 L p .305 .492 .877 r
F P
0 g
s
.52328 .4897 m .52292 .49605 L .5022 .4808 L p .305 .492 .877 r
F P
0 g
s
.55004 .52691 m .54702 .5182 L .57035 .52982 L p .228 .544 .928 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55004 .52691 L p .228 .544 .928 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60928 .54636 L p .303 .735 .969 r
F P
0 g
s
.60928 .54636 m .61824 .54916 L .58896 .55013 L p .303 .735 .969 r
F P
0 g
s
.69661 .53178 m .68583 .53324 L .70856 .50471 L p .81 .966 .906 r
F P
0 g
s
.70856 .50471 m .72094 .49918 L .69661 .53178 L p .81 .966 .906 r
F P
0 g
s
.6359 .55343 m .62711 .55144 L .65308 .54124 L p .523 .918 .889 r
F P
0 g
s
.65308 .54124 m .66409 .53841 L .6359 .55343 L p .523 .918 .889 r
F P
0 g
s
.44216 .44349 m .45388 .43884 L .46659 .45131 L p .672 .715 .88 r
F P
0 g
s
.47615 .44871 m .46659 .45131 L .45388 .43884 L p .532 .668 .924 r
F P
0 g
s
.46659 .45131 m .47615 .44871 L .48988 .46142 L p .496 .608 .893 r
F P
0 g
s
.52292 .49605 m .52328 .4897 L .5409 .50354 L p .137 .424 .866 r
F P
0 g
s
.5409 .50354 m .54397 .51039 L .52292 .49605 L p .137 .424 .866 r
F P
0 g
s
.23172 .54077 m .24406 .54719 L .27687 .58727 L p .094 .445 .88 r
F P
0 g
s
.28772 .59021 m .27687 .58727 L .24406 .54719 L p .277 .56 .931 r
F P
0 g
s
.54702 .5182 m .54397 .51039 L .56404 .52294 L p .081 .45 .882 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54702 .5182 L p .081 .45 .882 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .60022 .54282 L p .154 .632 .925 r
F P
0 g
s
.60022 .54282 m .60928 .54636 L .5828 .54342 L p .154 .632 .925 r
F P
0 g
s
.49677 .46047 m .48988 .46142 L .47615 .44871 L p .289 .517 .901 r
F P
0 g
s
.48988 .46142 m .49677 .46047 L .50967 .47255 L p .222 .462 .877 r
F P
0 g
s
.50967 .47255 m .50592 .47537 L .48988 .46142 L p .222 .462 .877 r
F P
0 g
s
.40595 .44734 m .41933 .43789 L .43039 .45181 L p .837 .819 .832 r
F P
0 g
s
.43039 .45181 m .41852 .46341 L .40595 .44734 L p .837 .819 .832 r
F P
0 g
s
.44216 .44349 m .43039 .45181 L .41933 .43789 L p .784 .815 .877 r
F P
0 g
s
.39244 .45943 m .40595 .44734 L .41852 .46341 L p .865 .816 .799 r
F P
0 g
s
.41852 .46341 m .40655 .47771 L .39244 .45943 L p .865 .816 .799 r
F P
0 g
s
.50592 .47537 m .50967 .47255 L .52364 .48519 L p .108 .396 .85 r
F P
0 g
s
.52364 .48519 m .52328 .4897 L .50592 .47537 L p .108 .396 .85 r
F P
0 g
s
.68583 .53324 m .67499 .53558 L .69616 .51154 L p .789 .993 .878 r
F P
0 g
s
.69616 .51154 m .70856 .50471 L .68583 .53324 L p .789 .993 .878 r
F P
0 g
s
.41933 .43789 m .43258 .43165 L .44216 .44349 L p .784 .815 .877 r
F P
0 g
s
.45388 .43884 m .44216 .44349 L .43258 .43165 L p .686 .792 .93 r
F P
0 g
s
.37878 .47342 m .39244 .45943 L .40655 .47771 L p .879 .812 .778 r
F P
0 g
s
.40655 .47771 m .39448 .49396 L .37878 .47342 L p .879 .812 .778 r
F P
0 g
s
.62711 .55144 m .61824 .54916 L .64196 .54358 L p .39 .85 .85 r
F P
0 g
s
.64196 .54358 m .65308 .54124 L .62711 .55144 L p .39 .85 .85 r
F P
0 g
s
.45388 .43884 m .46556 .43802 L .47615 .44871 L p .532 .668 .924 r
F P
0 g
s
.48574 .44971 m .47615 .44871 L .46556 .43802 L p .302 .56 .927 r
F P
0 g
s
.47615 .44871 m .48574 .44971 L .49677 .46047 L p .289 .517 .901 r
F P
0 g
s
.7968 .5088 m .78384 .50207 L .80098 .45503 L p .547 .594 .852 r
F P
0 g
s
.78384 .50207 m .77102 .49714 L .78695 .45149 L p .598 .644 .867 r
F P
0 g
s
.78695 .45149 m .80098 .45503 L .78384 .50207 L p .598 .644 .867 r
F P
0 g
s
.80987 .51691 m .7968 .5088 L .81524 .46079 L p .508 .557 .841 r
F P
0 g
s
.80098 .45503 m .81524 .46079 L .7968 .5088 L p .547 .594 .852 r
F P
0 g
s
.24406 .54719 m .25664 .55172 L .28772 .59021 L p .277 .56 .931 r
F P
0 g
s
.29884 .59055 m .28772 .59021 L .25664 .55172 L p .468 .665 .948 r
F P
0 g
s
.77102 .49714 m .75834 .49431 L .77315 .45055 L p .659 .706 .882 r
F P
0 g
s
.77315 .45055 m .78695 .45149 L .77102 .49714 L p .659 .706 .882 r
F P
0 g
s
.43258 .43165 m .44573 .42898 L .45388 .43884 L p .686 .792 .93 r
F P
0 g
s
.46556 .43802 m .45388 .43884 L .44573 .42898 L p .512 .723 .968 r
F P
0 g
s
.82304 .52587 m .80987 .51691 L .8297 .46828 L p .482 .536 .835 r
F P
0 g
s
.81524 .46079 m .8297 .46828 L .80987 .51691 L p .508 .557 .841 r
F P
0 g
s
.365 .48847 m .37878 .47342 L .39448 .49396 L p .885 .808 .768 r
F P
0 g
s
.39448 .49396 m .38233 .51126 L .365 .48847 L p .885 .808 .768 r
F P
0 g
s
.52328 .4897 m .52364 .48519 L .53781 .49761 L p 0 .319 .807 r
F P
0 g
s
.53781 .49761 m .5409 .50354 L .52328 .4897 L p 0 .319 .807 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59108 .53835 L p .007 .513 .864 r
F P
0 g
s
.59108 .53835 m .60022 .54282 L .5766 .53665 L p .007 .513 .864 r
F P
0 g
s
.83625 .53514 m .82304 .52587 L .84432 .47686 L p .469 .528 .836 r
F P
0 g
s
.8297 .46828 m .84432 .47686 L .82304 .52587 L p .482 .536 .835 r
F P
0 g
s
.54397 .51039 m .5409 .50354 L .55769 .51601 L p 0 .346 .815 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54397 .51039 L p 0 .346 .815 r
F P
0 g
s
.75834 .49431 m .74579 .49373 L .75955 .4524 L p .725 .775 .893 r
F P
0 g
s
.75955 .4524 m .77315 .45055 L .75834 .49431 L p .725 .775 .893 r
F P
0 g
s
.84432 .47686 m .85906 .48583 L .83625 .53514 L p .469 .528 .836 r
F P
0 g
s
.67499 .53558 m .66409 .53841 L .68368 .51908 L p .736 .992 .839 r
F P
0 g
s
.68368 .51908 m .69616 .51154 L .67499 .53558 L p .736 .992 .839 r
F P
0 g
s
.35114 .50365 m .365 .48847 L .38233 .51126 L p .884 .805 .767 r
F P
0 g
s
.38233 .51126 m .37012 .52866 L .35114 .50365 L p .884 .805 .767 r
F P
0 g
s
.50371 .46246 m .49677 .46047 L .48574 .44971 L p .013 .364 .835 r
F P
0 g
s
.49677 .46047 m .50371 .46246 L .51345 .47211 L p 0 .323 .81 r
F P
0 g
s
.51345 .47211 m .50967 .47255 L .49677 .46047 L p 0 .323 .81 r
F P
0 g
s
.74579 .49373 m .73333 .49541 L .74612 .45704 L p .788 .844 .894 r
F P
0 g
s
.74612 .45704 m .75955 .4524 L .74579 .49373 L p .788 .844 .894 r
F P
0 g
s
.61824 .54916 m .60928 .54636 L .6307 .54495 L p .243 .759 .813 r
F P
0 g
s
.6307 .54495 m .64196 .54358 L .61824 .54916 L p .243 .759 .813 r
F P
0 g
s
.25664 .55172 m .26949 .55371 L .29884 .59055 L p .468 .665 .948 r
F P
0 g
s
.31022 .58781 m .29884 .59055 L .26949 .55371 L p .621 .735 .928 r
F P
0 g
s
.44573 .42898 m .45883 .43004 L .46556 .43802 L p .512 .723 .968 r
F P
0 g
s
.47727 .44094 m .46556 .43802 L .45883 .43004 L p .246 .576 .942 r
F P
0 g
s
.46556 .43802 m .47727 .44094 L .48574 .44971 L p .302 .56 .927 r
F P
0 g
s
.50967 .47255 m .51345 .47211 L .524 .48235 L p 0 .268 .772 r
F P
0 g
s
.524 .48235 m .52364 .48519 L .50967 .47255 L p 0 .268 .772 r
F P
0 g
s
.49539 .45401 m .48574 .44971 L .47727 .44094 L p .008 .383 .844 r
F P
0 g
s
.48574 .44971 m .49539 .45401 L .50371 .46246 L p .013 .364 .835 r
F P
0 g
s
.33724 .51802 m .35114 .50365 L .37012 .52866 L p .876 .803 .774 r
F P
0 g
s
.37012 .52866 m .35792 .54522 L .33724 .51802 L p .876 .803 .774 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58185 .53286 L p 0 .394 .794 r
F P
0 g
s
.58185 .53286 m .59108 .53835 L .57035 .52982 L p 0 .394 .794 r
F P
0 g
s
.73333 .49541 m .72094 .49918 L .73281 .46425 L p .838 .905 .884 r
F P
0 g
s
.73281 .46425 m .74612 .45704 L .73333 .49541 L p .838 .905 .884 r
F P
0 g
s
.26949 .55371 m .28262 .55271 L .31022 .58781 L p .621 .735 .928 r
F P
0 g
s
.32186 .58176 m .31022 .58781 L .28262 .55271 L p .726 .772 .889 r
F P
0 g
s
.5409 .50354 m .53781 .49761 L .55128 .50901 L p 0 .243 .738 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .5409 .50354 L p 0 .243 .738 r
F P
0 g
s
.32338 .53073 m .33724 .51802 L .35792 .54522 L p .861 .8 .79 r
F P
0 g
s
.35792 .54522 m .34576 .56005 L .32338 .53073 L p .861 .8 .79 r
F P
0 g
s
.52364 .48519 m .524 .48235 L .53469 .49252 L p 0 .207 .72 r
F P
0 g
s
.53469 .49252 m .53781 .49761 L .52364 .48519 L p 0 .207 .72 r
F P
0 g
s
.66409 .53841 m .65308 .54124 L .6711 .52665 L p .657 .967 .801 r
F P
0 g
s
.6711 .52665 m .68368 .51908 L .66409 .53841 L p .657 .967 .801 r
F P
0 g
s
.41514 .42653 m .42901 .42285 L .43258 .43165 L p .763 .907 .939 r
F P
0 g
s
.43258 .43165 m .41933 .43789 L .41514 .42653 L p .763 .907 .939 r
F P
0 g
s
.44573 .42898 m .43258 .43165 L .42901 .42285 L p .621 .857 .988 r
F P
0 g
s
.40111 .43312 m .41514 .42653 L .41933 .43789 L p .842 .918 .885 r
F P
0 g
s
.41933 .43789 m .40595 .44734 L .40111 .43312 L p .842 .918 .885 r
F P
0 g
s
.28262 .55271 m .29601 .54849 L .32186 .58176 L p .726 .772 .889 r
F P
0 g
s
.33373 .57241 m .32186 .58176 L .29601 .54849 L p .793 .789 .849 r
F P
0 g
s
.30961 .54107 m .32338 .53073 L .34576 .56005 L p .835 .797 .815 r
F P
0 g
s
.34576 .56005 m .33373 .57241 L .30961 .54107 L p .835 .797 .815 r
F P
0 g
s
.60928 .54636 m .60022 .54282 L .61932 .54492 L p .093 .65 .78 r
F P
0 g
s
.61932 .54492 m .6307 .54495 L .60928 .54636 L p .093 .65 .78 r
F P
0 g
s
.42901 .42285 m .44277 .42241 L .44573 .42898 L p .621 .857 .988 r
F P
0 g
s
.45883 .43004 m .44573 .42898 L .44277 .42241 L p .391 .734 .991 r
F P
0 g
s
.21958 .53321 m .20758 .52532 L .18911 .47507 L p .181 .422 .857 r
F P
0 g
s
.29601 .54849 m .30961 .54107 L .33373 .57241 L p .793 .789 .849 r
F P
0 g
s
.45883 .43004 m .47192 .43474 L .47727 .44094 L p .246 .576 .942 r
F P
0 g
s
.48903 .44729 m .47727 .44094 L .47192 .43474 L p 0 .371 .829 r
F P
0 g
s
.47727 .44094 m .48903 .44729 L .49539 .45401 L p .008 .383 .844 r
F P
0 g
s
.38692 .4421 m .40111 .43312 L .40595 .44734 L p .882 .913 .843 r
F P
0 g
s
.40595 .44734 m .39244 .45943 L .38692 .4421 L p .882 .913 .843 r
F P
0 g
s
.72094 .49918 m .70856 .50471 L .71957 .47364 L p .87 .949 .862 r
F P
0 g
s
.71957 .47364 m .73281 .46425 L .72094 .49918 L p .87 .949 .862 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57254 .52628 L p 0 .285 .726 r
F P
0 g
s
.57254 .52628 m .58185 .53286 L .56404 .52294 L p 0 .285 .726 r
F P
0 g
s
.44277 .42241 m .45644 .42533 L .45883 .43004 L p .391 .734 .991 r
F P
0 g
s
.47192 .43474 m .45883 .43004 L .45644 .42533 L p .105 .535 .912 r
F P
0 g
s
.51074 .46691 m .50371 .46246 L .49539 .45401 L p 0 .192 .704 r
F P
0 g
s
.50371 .46246 m .51074 .46691 L .51728 .47366 L p 0 .172 .69 r
F P
0 g
s
.51728 .47366 m .51345 .47211 L .50371 .46246 L p 0 .172 .69 r
F P
0 g
s
.51345 .47211 m .51728 .47366 L .52437 .48088 L p 0 .143 .664 r
F P
0 g
s
.52437 .48088 m .524 .48235 L .51345 .47211 L p 0 .143 .664 r
F P
0 g
s
.37256 .45281 m .38692 .4421 L .39244 .45943 L p .902 .904 .815 r
F P
0 g
s
.39244 .45943 m .37878 .47342 L .37256 .45281 L p .902 .904 .815 r
F P
0 g
s
.50516 .46107 m .49539 .45401 L .48903 .44729 L p 0 .197 .703 r
F P
0 g
s
.49539 .45401 m .50516 .46107 L .51074 .46691 L p 0 .192 .704 r
F P
0 g
s
.53781 .49761 m .53469 .49252 L .54482 .50197 L p 0 .153 .661 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53781 .49761 L p 0 .153 .661 r
F P
0 g
s
.65308 .54124 m .64196 .54358 L .65837 .53356 L p .558 .926 .776 r
F P
0 g
s
.65837 .53356 m .6711 .52665 L .65308 .54124 L p .558 .926 .776 r
F P
0 g
s
.60022 .54282 m .59108 .53835 L .6078 .54316 L p 0 .53 .747 r
F P
0 g
s
.6078 .54316 m .61932 .54492 L .60022 .54282 L p 0 .53 .747 r
F P
0 g
s
.18911 .47507 m .20227 .48411 L .21958 .53321 L p .181 .422 .857 r
F P
0 g
s
.23172 .54077 m .21958 .53321 L .20227 .48411 L p .216 .442 .864 r
F P
0 g
s
.70856 .50471 m .69616 .51154 L .70633 .48464 L p .88 .977 .835 r
F P
0 g
s
.70633 .48464 m .71957 .47364 L .70856 .50471 L p .88 .977 .835 r
F P
0 g
s
.524 .48235 m .52437 .48088 L .53153 .48811 L p 0 .11 .63 r
F P
0 g
s
.53153 .48811 m .53469 .49252 L .524 .48235 L p 0 .11 .63 r
F P
0 g
s
.45644 .42533 m .47008 .43153 L .47192 .43474 L p .105 .535 .912 r
F P
0 g
s
.48505 .44276 m .47192 .43474 L .47008 .43153 L p 0 .321 .778 r
F P
0 g
s
.47192 .43474 m .48505 .44276 L .48903 .44729 L p 0 .371 .829 r
F P
0 g
s
.50091 .45652 m .48903 .44729 L .48505 .44276 L p 0 .184 .684 r
F P
0 g
s
.48903 .44729 m .50091 .45652 L .50516 .46107 L p 0 .197 .703 r
F P
0 g
s
.35806 .46448 m .37256 .45281 L .37878 .47342 L p .91 .893 .801 r
F P
0 g
s
.37878 .47342 m .365 .48847 L .35806 .46448 L p .91 .893 .801 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56317 .51865 L p 0 .194 .664 r
F P
0 g
s
.56317 .51865 m .57254 .52628 L .55769 .51601 L p 0 .194 .664 r
F P
0 g
s
.59108 .53835 m .58185 .53286 L .59617 .53942 L p 0 .408 .711 r
F P
0 g
s
.59617 .53942 m .6078 .54316 L .59108 .53835 L p 0 .408 .711 r
F P
0 g
s
.20227 .48411 m .21554 .49285 L .23172 .54077 L p .216 .442 .864 r
F P
0 g
s
.24406 .54719 m .23172 .54077 L .21554 .49285 L p .294 .495 .883 r
F P
0 g
s
.64196 .54358 m .6307 .54495 L .64549 .53911 L p .441 .87 .768 r
F P
0 g
s
.64549 .53911 m .65837 .53356 L .64196 .54358 L p .441 .87 .768 r
F P
0 g
s
.34344 .47627 m .35806 .46448 L .365 .48847 L p .908 .883 .798 r
F P
0 g
s
.365 .48847 m .35114 .50365 L .34344 .47627 L p .908 .883 .798 r
F P
0 g
s
.53469 .49252 m .53153 .48811 L .5383 .49486 L p 0 .082 .596 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53469 .49252 L p 0 .082 .596 r
F P
0 g
s
.69616 .51154 m .68368 .51908 L .69303 .49653 L p .871 .992 .812 r
F P
0 g
s
.69303 .49653 m .70633 .48464 L .69616 .51154 L p .871 .992 .812 r
F P
0 g
s
.43189 .41777 m .44533 .41964 L .44277 .42241 L p .395 .814 .972 r
F P
0 g
s
.44277 .42241 m .42901 .42285 L .43189 .41777 L p .395 .814 .972 r
F P
0 g
s
.45644 .42533 m .44277 .42241 L .44533 .41964 L p .146 .632 .919 r
F P
0 g
s
.47008 .43153 m .48373 .44072 L .48505 .44276 L p 0 .321 .778 r
F P
0 g
s
.49827 .45357 m .48505 .44276 L .48373 .44072 L p 0 .156 .651 r
F P
0 g
s
.48505 .44276 m .49827 .45357 L .50091 .45652 L p 0 .184 .684 r
F P
0 g
s
.41832 .41856 m .43189 .41777 L .42901 .42285 L p .596 .927 .964 r
F P
0 g
s
.42901 .42285 m .41514 .42653 L .41832 .41856 L p .596 .927 .964 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55373 .51006 L p 0 .122 .612 r
F P
0 g
s
.55373 .51006 m .56317 .51865 L .55128 .50901 L p 0 .122 .612 r
F P
0 g
s
.51787 .47318 m .51074 .46691 L .50516 .46107 L p 0 .065 .583 r
F P
0 g
s
.51074 .46691 m .51787 .47318 L .52117 .47667 L p 0 .059 .579 r
F P
0 g
s
.52117 .47667 m .51728 .47366 L .51074 .46691 L p 0 .059 .579 r
F P
0 g
s
.44533 .41964 m .45867 .42427 L .45644 .42533 L p .146 .632 .919 r
F P
0 g
s
.47008 .43153 m .45644 .42533 L .45867 .42427 L p 0 .424 .815 r
F P
0 g
s
.51728 .47366 m .52117 .47667 L .52474 .48041 L p 0 .051 .57 r
F P
0 g
s
.52474 .48041 m .52437 .48088 L .51728 .47366 L p 0 .051 .57 r
F P
0 g
s
.51506 .47019 m .50516 .46107 L .50091 .45652 L p 0 .065 .581 r
F P
0 g
s
.50516 .46107 m .51506 .47019 L .51787 .47318 L p 0 .065 .583 r
F P
0 g
s
.58185 .53286 m .57254 .52628 L .58445 .53362 L p 0 .295 .671 r
F P
0 g
s
.58445 .53362 m .59617 .53942 L .58185 .53286 L p 0 .295 .671 r
F P
0 g
s
.40459 .42175 m .41832 .41856 L .41514 .42653 L p .73 .975 .925 r
F P
0 g
s
.41514 .42653 m .40111 .43312 L .40459 .42175 L p .73 .975 .925 r
F P
0 g
s
.32876 .48735 m .34344 .47627 L .35114 .50365 L p .897 .871 .804 r
F P
0 g
s
.35114 .50365 m .33724 .51802 L .32876 .48735 L p .897 .871 .804 r
F P
0 g
s
.21554 .49285 m .22897 .50054 L .24406 .54719 L p .294 .495 .883 r
F P
0 g
s
.25664 .55172 m .24406 .54719 L .22897 .50054 L p .402 .569 .903 r
F P
0 g
s
.45867 .42427 m .47195 .43159 L .47008 .43153 L p 0 .424 .815 r
F P
0 g
s
.48373 .44072 m .47008 .43153 L .47195 .43159 L p 0 .247 .702 r
F P
0 g
s
.52437 .48088 m .52474 .48041 L .52834 .48417 L p 0 .041 .558 r
F P
0 g
s
.52834 .48417 m .53153 .48811 L .52437 .48088 L p 0 .041 .558 r
F P
0 g
s
.51293 .46789 m .50091 .45652 L .49827 .45357 L p 0 .061 .574 r
F P
0 g
s
.50091 .45652 m .51293 .46789 L .51506 .47019 L p 0 .065 .581 r
F P
0 g
s
.6307 .54495 m .61932 .54492 L .63245 .54268 L p .302 .794 .772 r
F P
0 g
s
.63245 .54268 m .64549 .53911 L .6307 .54495 L p .302 .794 .772 r
F P
0 g
s
.3907 .42691 m .40459 .42175 L .40111 .43312 L p .809 .987 .885 r
F P
0 g
s
.40111 .43312 m .38692 .4421 L .3907 .42691 L p .809 .987 .885 r
F P
0 g
s
.78695 .45149 m .77315 .45055 L .77152 .40705 L p .643 .711 .897 r
F P
0 g
s
.77315 .45055 m .75955 .4524 L .75775 .41139 L p .726 .775 .891 r
F P
0 g
s
.75775 .41139 m .77152 .40705 L .77315 .45055 L p .726 .775 .891 r
F P
0 g
s
.68368 .51908 m .6711 .52665 L .67963 .50847 L p .846 .999 .801 r
F P
0 g
s
.67963 .50847 m .69303 .49653 L .68368 .51908 L p .846 .999 .801 r
F P
0 g
s
.80098 .45503 m .78695 .45149 L .78557 .40583 L p .558 .645 .892 r
F P
0 g
s
.77152 .40705 m .78557 .40583 L .78695 .45149 L p .643 .711 .897 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54423 .50068 L p 0 .067 .571 r
F P
0 g
s
.54423 .50068 m .55373 .51006 L .54482 .50197 L p 0 .067 .571 r
F P
0 g
s
.57254 .52628 m .56317 .51865 L .57265 .52583 L p 0 .199 .631 r
F P
0 g
s
.57265 .52583 m .58445 .53362 L .57254 .52628 L p 0 .199 .631 r
F P
0 g
s
.75955 .4524 m .74612 .45704 L .7442 .41886 L p .798 .828 .875 r
F P
0 g
s
.7442 .41886 m .75775 .41139 L .75955 .4524 L p .798 .828 .875 r
F P
0 g
s
.31407 .49694 m .32876 .48735 L .33724 .51802 L p .876 .858 .819 r
F P
0 g
s
.33724 .51802 m .32338 .53073 L .31407 .49694 L p .876 .858 .819 r
F P
0 g
s
.81524 .46079 m .80098 .45503 L .7999 .40754 L p .482 .585 .881 r
F P
0 g
s
.78557 .40583 m .7999 .40754 L .80098 .45503 L p .558 .645 .892 r
F P
0 g
s
.47195 .43159 m .4852 .44136 L .48373 .44072 L p 0 .247 .702 r
F P
0 g
s
.49743 .45241 m .48373 .44072 L .4852 .44136 L p 0 .121 .612 r
F P
0 g
s
.48373 .44072 m .49743 .45241 L .49827 .45357 L p 0 .156 .651 r
F P
0 g
s
.53153 .48811 m .52834 .48417 L .53174 .48769 L p 0 .032 .547 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53153 .48811 L p 0 .032 .547 r
F P
0 g
s
.51162 .46643 m .49827 .45357 L .49743 .45241 L p 0 .052 .563 r
F P
0 g
s
.49827 .45357 m .51162 .46643 L .51293 .46789 L p 0 .061 .574 r
F P
0 g
s
.22897 .50054 m .24262 .50651 L .25664 .55172 L p .402 .569 .903 r
F P
0 g
s
.26949 .55371 m .25664 .55172 L .24262 .50651 L p .522 .648 .914 r
F P
0 g
s
.74612 .45704 m .73281 .46425 L .73081 .42921 L p .854 .868 .85 r
F P
0 g
s
.73081 .42921 m .7442 .41886 L .74612 .45704 L p .854 .868 .85 r
F P
0 g
s
.61932 .54492 m .6078 .54316 L .61926 .54378 L p .143 .688 .775 r
F P
0 g
s
.61926 .54378 m .63245 .54268 L .61932 .54492 L p .143 .688 .775 r
F P
0 g
s
.8297 .46828 m .81524 .46079 L .81453 .41175 L p .423 .538 .869 r
F P
0 g
s
.7999 .40754 m .81453 .41175 L .81524 .46079 L p .482 .585 .881 r
F P
0 g
s
.37664 .43349 m .3907 .42691 L .38692 .4421 L p .855 .983 .856 r
F P
0 g
s
.38692 .4421 m .37256 .45281 L .37664 .43349 L p .855 .983 .856 r
F P
0 g
s
.29944 .50439 m .31407 .49694 L .32338 .53073 L p .844 .839 .841 r
F P
0 g
s
.32338 .53073 m .30961 .54107 L .29944 .50439 L p .844 .839 .841 r
F P
0 g
s
.24262 .50651 m .25649 .51019 L .26949 .55371 L p .522 .648 .914 r
F P
0 g
s
.28262 .55271 m .26949 .55371 L .25649 .51019 L p .634 .719 .909 r
F P
0 g
s
.56317 .51865 m .55373 .51006 L .56079 .51623 L p 0 .124 .594 r
F P
0 g
s
.56079 .51623 m .57265 .52583 L .56317 .51865 L p 0 .124 .594 r
F P
0 g
s
.52511 .48046 m .51787 .47318 L .51506 .47019 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52117 .47667 L .51787 .47318 L closepath p 0 .003 .518 r
F P
0 g
s
.6711 .52665 m .65837 .53356 L .66609 .5196 L p .805 .999 .807 r
F P
0 g
s
.66609 .5196 m .67963 .50847 L .6711 .52665 L p .805 .999 .807 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53469 .49073 L p 0 .028 .54 r
F P
0 g
s
.53469 .49073 m .54423 .50068 L .5383 .49486 L p 0 .028 .54 r
F P
0 g
s
.4852 .44136 m .49846 .45315 L .49743 .45241 L p 0 .121 .612 r
F P
0 g
s
.51122 .46593 m .49743 .45241 L .49846 .45315 L p 0 .042 .551 r
F P
0 g
s
.49743 .45241 m .51122 .46593 L .51162 .46643 L p 0 .052 .563 r
F P
0 g
s
.28494 .50921 m .29944 .50439 L .30961 .54107 L p .795 .813 .866 r
F P
0 g
s
.30961 .54107 m .29601 .54849 L .28494 .50921 L p .795 .813 .866 r
F P
0 g
s
.52511 .48046 m .51506 .47019 L .51293 .46789 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52474 .48041 L .52117 .47667 L closepath p 0 .003 .518 r
F P
0 g
s
.84432 .47686 m .8297 .46828 L .82943 .41791 L p .384 .509 .861 r
F P
0 g
s
.81453 .41175 m .82943 .41791 L .8297 .46828 L p .423 .538 .869 r
F P
0 g
s
.25649 .51019 m .27061 .51116 L .28262 .55271 L p .634 .719 .909 r
F P
0 g
s
.29601 .54849 m .28262 .55271 L .27061 .51116 L p .726 .774 .891 r
F P
0 g
s
.73281 .46425 m .71957 .47364 L .71753 .442 L p .892 .896 .825 r
F P
0 g
s
.71753 .442 m .73081 .42921 L .73281 .46425 L p .892 .896 .825 r
F P
0 g
s
.27061 .51116 m .28494 .50921 L .29601 .54849 L p .726 .774 .891 r
F P
0 g
s
.52511 .48046 m .51293 .46789 L .51162 .46643 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52834 .48417 L .52474 .48041 L closepath p 0 .003 .518 r
F P
0 g
s
.6078 .54316 m .59617 .53942 L .60593 .54208 L p 0 .553 .762 r
F P
0 g
s
.60593 .54208 m .61926 .54378 L .6078 .54316 L p 0 .553 .762 r
F P
0 g
s
.4534 .42097 m .46547 .42703 L .45867 .42427 L p 0 .454 .781 r
F P
0 g
s
.45867 .42427 m .44533 .41964 L .4534 .42097 L p 0 .454 .781 r
F P
0 g
s
.47195 .43159 m .45867 .42427 L .46547 .42703 L p 0 .298 .705 r
F P
0 g
s
.46547 .42703 m .47746 .43499 L .47195 .43159 L p 0 .298 .705 r
F P
0 g
s
.4852 .44136 m .47195 .43159 L .47746 .43499 L p 0 .176 .635 r
F P
0 g
s
.55373 .51006 m .54423 .50068 L .54891 .50518 L p 0 .067 .563 r
F P
0 g
s
.54891 .50518 m .56079 .51623 L .55373 .51006 L p 0 .067 .563 r
F P
0 g
s
.44123 .41686 m .4534 .42097 L .44533 .41964 L p .08 .623 .846 r
F P
0 g
s
.44533 .41964 m .43189 .41777 L .44123 .41686 L p .08 .623 .846 r
F P
0 g
s
.36243 .44085 m .37664 .43349 L .37256 .45281 L p .879 .972 .842 r
F P
0 g
s
.37256 .45281 m .35806 .46448 L .36243 .44085 L p .879 .972 .842 r
F P
0 g
s
.52511 .48046 m .51162 .46643 L .51122 .46593 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48417 L closepath p 0 .003 .518 r
F P
0 g
s
.47746 .43499 m .48941 .44467 L .4852 .44136 L p 0 .176 .635 r
F P
0 g
s
.49846 .45315 m .4852 .44136 L .48941 .44467 L p 0 .089 .58 r
F P
0 g
s
.85906 .48583 m .84432 .47686 L .84456 .42531 L p .367 .5 .86 r
F P
0 g
s
.82943 .41791 m .84456 .42531 L .84432 .47686 L p .384 .509 .861 r
F P
0 g
s
.42893 .41465 m .44123 .41686 L .43189 .41777 L p .276 .774 .883 r
F P
0 g
s
.43189 .41777 m .41832 .41856 L .42893 .41465 L p .276 .774 .883 r
F P
0 g
s
.71957 .47364 m .70633 .48464 L .70429 .45659 L p .915 .914 .803 r
F P
0 g
s
.70429 .45659 m .71753 .442 L .71957 .47364 L p .915 .914 .803 r
F P
0 g
s
.59617 .53942 m .58445 .53362 L .59251 .53746 L p 0 .406 .725 r
F P
0 g
s
.59251 .53746 m .60593 .54208 L .59617 .53942 L p 0 .406 .725 r
F P
0 g
s
.54423 .50068 m .53469 .49073 L .53701 .49308 L p 0 .028 .537 r
F P
0 g
s
.53701 .49308 m .54891 .50518 L .54423 .50068 L p 0 .028 .537 r
F P
0 g
s
.65837 .53356 m .64549 .53911 L .65238 .52906 L p .744 .993 .833 r
F P
0 g
s
.65238 .52906 m .66609 .5196 L .65837 .53356 L p .744 .993 .833 r
F P
0 g
s
.48941 .44467 m .50132 .45575 L .49846 .45315 L p 0 .089 .58 r
F P
0 g
s
.51176 .46641 m .49846 .45315 L .50132 .45575 L p 0 .034 .542 r
F P
0 g
s
.49846 .45315 m .51176 .46641 L .51122 .46593 L p 0 .042 .551 r
F P
0 g
s
.52511 .48046 m .51122 .46593 L .51176 .46641 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53469 .49073 L .53174 .48769 L closepath p 0 .003 .518 r
F P
0 g
s
.84456 .42531 m .85986 .43317 L .85906 .48583 L p .367 .5 .86 r
F P
0 g
s
.58445 .53362 m .57265 .52583 L .57902 .53001 L p 0 .271 .673 r
F P
0 g
s
.57902 .53001 m .59251 .53746 L .58445 .53362 L p 0 .271 .673 r
F P
0 g
s
.34808 .4483 m .36243 .44085 L .35806 .46448 L p .888 .956 .84 r
F P
0 g
s
.35806 .46448 m .34344 .47627 L .34808 .4483 L p .888 .956 .84 r
F P
0 g
s
.4165 .41413 m .42893 .41465 L .41832 .41856 L p .452 .882 .892 r
F P
0 g
s
.41832 .41856 m .40459 .42175 L .4165 .41413 L p .452 .882 .892 r
F P
0 g
s
.50132 .45575 m .51322 .46785 L .51176 .46641 L p 0 .034 .542 r
F P
0 g
s
.52511 .48046 m .51176 .46641 L .51322 .46785 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53701 .49308 L .53469 .49073 L closepath p 0 .003 .518 r
F P
0 g
s
.70633 .48464 m .69303 .49653 L .69102 .47217 L p .925 .928 .791 r
F P
0 g
s
.69102 .47217 m .70429 .45659 L .70633 .48464 L p .925 .928 .791 r
F P
0 g
s
.57265 .52583 m .56079 .51623 L .5655 .52003 L p 0 .163 .62 r
F P
0 g
s
.5655 .52003 m .57902 .53001 L .57265 .52583 L p 0 .163 .62 r
F P
0 g
s
.64549 .53911 m .63245 .54268 L .6385 .53607 L p .649 .969 .875 r
F P
0 g
s
.6385 .53607 m .65238 .52906 L .64549 .53911 L p .649 .969 .875 r
F P
0 g
s
.56079 .51623 m .54891 .50518 L .552 .50802 L p 0 .085 .575 r
F P
0 g
s
.552 .50802 m .5655 .52003 L .56079 .51623 L p 0 .085 .575 r
F P
0 g
s
.50583 .46007 m .51549 .47015 L .51322 .46785 L p 0 .028 .538 r
F P
0 g
s
.51322 .46785 m .50132 .45575 L .50583 .46007 L p 0 .028 .538 r
F P
0 g
s
.52511 .48046 m .51322 .46785 L .51549 .47015 L closepath p 0 .003 .518 r
F P
0 g
s
.54891 .50518 m .53701 .49308 L .53853 .49459 L p 0 .033 .541 r
F P
0 g
s
.53853 .49459 m .552 .50802 L .54891 .50518 L p 0 .033 .541 r
F P
0 g
s
.52511 .48046 m .53534 .49091 L .53748 .49323 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53248 .48787 L .53534 .49091 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52913 .48432 L .53248 .48787 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .5255 .48052 L .52913 .48432 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .52185 .47671 L .5255 .48052 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47671 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .51549 .47015 L .51844 .47318 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53853 .49459 L .53701 .49308 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53913 .49513 L .53853 .49459 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53878 .49467 L .53913 .49513 L closepath p 0 .003 .518 r
F P
0 g
s
.52511 .48046 m .53748 .49323 L .53878 .49467 L closepath p 0 .003 .518 r
F P
0 g
s
.49612 .45047 m .50583 .46007 L .50132 .45575 L p 0 .071 .566 r
F P
0 g
s
.50132 .45575 m .48941 .44467 L .49612 .45047 L p 0 .071 .566 r
F P
0 g
s
.48635 .44157 m .49612 .45047 L .48941 .44467 L p 0 .133 .605 r
F P
0 g
s
.48941 .44467 m .47746 .43499 L .48635 .44157 L p 0 .133 .605 r
F P
0 g
s
.40392 .415 m .4165 .41413 L .40459 .42175 L p .59 .947 .888 r
F P
0 g
s
.40459 .42175 m .3907 .42691 L .40392 .415 L p .59 .947 .888 r
F P
0 g
s
.47652 .43353 m .48635 .44157 L .47746 .43499 L p 0 .218 .653 r
F P
0 g
s
.47746 .43499 m .46547 .42703 L .47652 .43353 L p 0 .218 .653 r
F P
0 g
s
.33365 .45516 m .34808 .4483 L .34344 .47627 L p .884 .936 .847 r
F P
0 g
s
.34344 .47627 m .32876 .48735 L .33365 .45516 L p .884 .936 .847 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51549 .47015 L p 0 .028 .54 r
F P
0 g
s
.51549 .47015 m .50583 .46007 L .5117 .46583 L p 0 .028 .54 r
F P
0 g
s
.552 .50802 m .53853 .49459 L .53913 .49513 L p 0 .041 .55 r
F P
0 g
s
.63245 .54268 m .61926 .54378 L .62447 .54003 L p .503 .905 .916 r
F P
0 g
s
.62447 .54003 m .6385 .53607 L .63245 .54268 L p .503 .905 .916 r
F P
0 g
s
.69303 .49653 m .67963 .50847 L .67766 .4878 L p .925 .939 .792 r
F P
0 g
s
.67766 .4878 m .69102 .47217 L .69303 .49653 L p .925 .939 .792 r
F P
0 g
s
.46661 .42644 m .47652 .43353 L .46547 .42703 L p 0 .329 .711 r
F P
0 g
s
.46547 .42703 m .4534 .42097 L .46661 .42644 L p 0 .329 .711 r
F P
0 g
s
.20227 .48411 m .18911 .47507 L .19318 .42214 L p .376 .496 .853 r
F P
0 g
s
.51855 .47264 m .52185 .47671 L .51844 .47318 L p 0 .032 .547 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51855 .47264 L p 0 .032 .547 r
F P
0 g
s
.53913 .49513 m .55326 .50899 L .552 .50802 L p 0 .041 .55 r
F P
0 g
s
.55326 .50899 m .53913 .49513 L .53878 .49467 L p 0 .051 .561 r
F P
0 g
s
.5655 .52003 m .552 .50802 L .55326 .50899 L p 0 .115 .606 r
F P
0 g
s
.3912 .41687 m .40392 .415 L .3907 .42691 L p .69 .98 .883 r
F P
0 g
s
.3907 .42691 m .37664 .43349 L .3912 .41687 L p .69 .98 .883 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50583 .46007 L p 0 .068 .573 r
F P
0 g
s
.50583 .46007 m .49612 .45047 L .50491 .45842 L p 0 .068 .573 r
F P
0 g
s
.45662 .42036 m .46661 .42644 L .4534 .42097 L p 0 .46 .773 r
F P
0 g
s
.4534 .42097 m .44123 .41686 L .45662 .42036 L p 0 .46 .773 r
F P
0 g
s
.31918 .46079 m .33365 .45516 L .32876 .48735 L p .866 .909 .859 r
F P
0 g
s
.32876 .48735 m .31407 .49694 L .31918 .46079 L p .866 .909 .859 r
F P
0 g
s
.61926 .54378 m .60593 .54208 L .6103 .54053 L p .3 .777 .924 r
F P
0 g
s
.6103 .54053 m .62447 .54003 L .61926 .54378 L p .3 .777 .924 r
F P
0 g
s
.19318 .42214 m .20672 .43194 L .20227 .48411 L p .376 .496 .853 r
F P
0 g
s
.21554 .49285 m .20227 .48411 L .20672 .43194 L p .399 .508 .854 r
F P
0 g
s
.57902 .53001 m .5655 .52003 L .56748 .52115 L p 0 .231 .686 r
F P
0 g
s
.55326 .50899 m .56748 .52115 L .5655 .52003 L p 0 .115 .606 r
F P
0 g
s
.52588 .48003 m .5255 .48052 L .52185 .47671 L p 0 .04 .558 r
F P
0 g
s
.52185 .47671 m .51855 .47264 L .52588 .48003 L p 0 .04 .558 r
F P
0 g
s
.53878 .49467 m .5526 .508 L .55326 .50899 L p 0 .051 .561 r
F P
0 g
s
.5526 .508 m .53878 .49467 L .53748 .49323 L p 0 .06 .572 r
F P
0 g
s
.67963 .50847 m .66609 .5196 L .66418 .50252 L p .914 .949 .808 r
F P
0 g
s
.66418 .50252 m .67766 .4878 L .67963 .50847 L p .914 .949 .808 r
F P
0 g
s
.60593 .54208 m .59251 .53746 L .59605 .53742 L p .069 .591 .875 r
F P
0 g
s
.59605 .53742 m .6103 .54053 L .60593 .54208 L p .069 .591 .875 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49612 .45047 L p 0 .126 .617 r
F P
0 g
s
.49612 .45047 m .48635 .44157 L .49806 .45095 L p 0 .126 .617 r
F P
0 g
s
.59251 .53746 m .57902 .53001 L .58176 .53083 L p 0 .394 .783 r
F P
0 g
s
.56748 .52115 m .58176 .53083 L .57902 .53001 L p 0 .231 .686 r
F P
0 g
s
.58176 .53083 m .59605 .53742 L .59251 .53746 L p 0 .394 .783 r
F P
0 g
s
.44653 .41523 m .45662 .42036 L .44123 .41686 L p .05 .6 .831 r
F P
0 g
s
.44123 .41686 m .42893 .41465 L .44653 .41523 L p .05 .6 .831 r
F P
0 g
s
.5332 .48749 m .52913 .48432 L .5255 .48052 L p 0 .05 .569 r
F P
0 g
s
.5255 .48052 m .52588 .48003 L .5332 .48749 L p 0 .05 .569 r
F P
0 g
s
.53748 .49323 m .55003 .5051 L .5526 .508 L p 0 .06 .572 r
F P
0 g
s
.55003 .5051 m .53748 .49323 L .53534 .49091 L p 0 .064 .58 r
F P
0 g
s
.77152 .40705 m .75775 .41139 L .73958 .37358 L p .726 .773 .89 r
F P
0 g
s
.75775 .41139 m .7442 .41886 L .72686 .38354 L p .797 .804 .857 r
F P
0 g
s
.72686 .38354 m .73958 .37358 L .75775 .41139 L p .797 .804 .857 r
F P
0 g
s
.30472 .46465 m .31918 .46079 L .31407 .49694 L p .834 .874 .873 r
F P
0 g
s
.31407 .49694 m .29944 .50439 L .30472 .46465 L p .834 .874 .873 r
F P
0 g
s
.78557 .40583 m .77152 .40705 L .75255 .36685 L p .633 .726 .915 r
F P
0 g
s
.73958 .37358 m .75255 .36685 L .77152 .40705 L p .726 .773 .89 r
F P
0 g
s
.20672 .43194 m .22032 .44146 L .21554 .49285 L p .399 .508 .854 r
F P
0 g
s
.22897 .50054 m .21554 .49285 L .22032 .44146 L p .444 .541 .861 r
F P
0 g
s
.53998 .49447 m .53248 .48787 L .52913 .48432 L p 0 .059 .578 r
F P
0 g
s
.52913 .48432 m .5332 .48749 L .53998 .49447 L p 0 .059 .578 r
F P
0 g
s
.53534 .49091 m .54572 .50049 L .55003 .5051 L p 0 .064 .58 r
F P
0 g
s
.54572 .50049 m .53534 .49091 L .53248 .48787 L p 0 .064 .582 r
F P
0 g
s
.7442 .41886 m .73081 .42921 L .71434 .3965 L p .846 .821 .824 r
F P
0 g
s
.71434 .3965 m .72686 .38354 L .7442 .41886 L p .846 .821 .824 r
F P
0 g
s
.56748 .52115 m .55326 .50899 L .5526 .508 L p 0 .15 .644 r
F P
0 g
s
.5152 .46798 m .51855 .47264 L .5117 .46583 L p 0 .082 .596 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .5152 .46798 L p 0 .082 .596 r
F P
0 g
s
.37833 .41927 m .3912 .41687 L .37664 .43349 L p .759 .991 .884 r
F P
0 g
s
.37664 .43349 m .36243 .44085 L .37833 .41927 L p .759 .991 .884 r
F P
0 g
s
.53248 .48787 m .53998 .49447 L .54572 .50049 L p 0 .064 .582 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48635 .44157 L p 0 .203 .674 r
F P
0 g
s
.48635 .44157 m .47652 .43353 L .49116 .44341 L p 0 .203 .674 r
F P
0 g
s
.7999 .40754 m .78557 .40583 L .7658 .36337 L p .523 .664 .925 r
F P
0 g
s
.75255 .36685 m .7658 .36337 L .78557 .40583 L p .633 .726 .915 r
F P
0 g
s
.73081 .42921 m .71753 .442 L .70194 .41198 L p .878 .83 .796 r
F P
0 g
s
.70194 .41198 m .71434 .3965 L .73081 .42921 L p .878 .83 .796 r
F P
0 g
s
.66609 .5196 m .65238 .52906 L .65055 .51534 L p .888 .957 .84 r
F P
0 g
s
.65055 .51534 m .66418 .50252 L .66609 .5196 L p .888 .957 .84 r
F P
0 g
s
.22032 .44146 m .23403 .4501 L .22897 .50054 L p .444 .541 .861 r
F P
0 g
s
.24262 .50651 m .22897 .50054 L .23403 .4501 L p .505 .59 .873 r
F P
0 g
s
.43634 .41095 m .44653 .41523 L .42893 .41465 L p .216 .73 .879 r
F P
0 g
s
.42893 .41465 m .4165 .41413 L .43634 .41095 L p .216 .73 .879 r
F P
0 g
s
.29032 .46635 m .30472 .46465 L .29944 .50439 L p .786 .829 .885 r
F P
0 g
s
.29944 .50439 m .28494 .50921 L .29032 .46635 L p .786 .829 .885 r
F P
0 g
s
.81453 .41175 m .7999 .40754 L .77938 .36292 L p .414 .596 .92 r
F P
0 g
s
.7658 .36337 m .77938 .36292 L .7999 .40754 L p .523 .664 .925 r
F P
0 g
s
.5526 .508 m .56655 .51946 L .56748 .52115 L p 0 .15 .644 r
F P
0 g
s
.56655 .51946 m .5526 .508 L .55003 .5051 L p 0 .178 .678 r
F P
0 g
s
.52628 .4785 m .52588 .48003 L .51855 .47264 L p 0 .109 .628 r
F P
0 g
s
.51855 .47264 m .5152 .46798 L .52628 .4785 L p 0 .109 .628 r
F P
0 g
s
.58176 .53083 m .56748 .52115 L .56655 .51946 L p 0 .306 .763 r
F P
0 g
s
.23403 .4501 m .24787 .45731 L .24262 .50651 L p .505 .59 .873 r
F P
0 g
s
.25649 .51019 m .24262 .50651 L .24787 .45731 L p .578 .649 .884 r
F P
0 g
s
.71753 .442 m .70429 .45659 L .68961 .42931 L p .897 .836 .777 r
F P
0 g
s
.68961 .42931 m .70194 .41198 L .71753 .442 L p .897 .836 .777 r
F P
0 g
s
.27602 .46568 m .29032 .46635 L .28494 .50921 L p .725 .775 .892 r
F P
0 g
s
.28494 .50921 m .27061 .51116 L .27602 .46568 L p .725 .775 .892 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47652 .43353 L p 0 .301 .742 r
F P
0 g
s
.47652 .43353 m .46661 .42644 L .48419 .43581 L p 0 .301 .742 r
F P
0 g
s
.51183 .46252 m .5152 .46798 L .50491 .45842 L p 0 .153 .661 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51183 .46252 L p 0 .153 .661 r
F P
0 g
s
.24787 .45731 m .26187 .46261 L .25649 .51019 L p .578 .649 .884 r
F P
0 g
s
.27061 .51116 m .25649 .51019 L .26187 .46261 L p .654 .713 .891 r
F P
0 g
s
.36534 .42171 m .37833 .41927 L .36243 .44085 L p .802 .986 .89 r
F P
0 g
s
.36243 .44085 m .34808 .4483 L .36534 .42171 L p .802 .986 .89 r
F P
0 g
s
.26187 .46261 m .27602 .46568 L .27061 .51116 L p .654 .713 .891 r
F P
0 g
s
.65238 .52906 m .6385 .53607 L .63676 .5254 L p .838 .958 .889 r
F P
0 g
s
.63676 .5254 m .65055 .51534 L .65238 .52906 L p .838 .958 .889 r
F P
0 g
s
.42604 .40737 m .43634 .41095 L .4165 .41413 L p .376 .834 .913 r
F P
0 g
s
.4165 .41413 m .40392 .415 L .42604 .40737 L p .376 .834 .913 r
F P
0 g
s
.55003 .5051 m .56273 .51504 L .56655 .51946 L p 0 .178 .678 r
F P
0 g
s
.56273 .51504 m .55003 .5051 L .54572 .50049 L p 0 .191 .698 r
F P
0 g
s
.53734 .48922 m .5332 .48749 L .52588 .48003 L p 0 .14 .661 r
F P
0 g
s
.52588 .48003 m .52628 .4785 L .53734 .48922 L p 0 .14 .661 r
F P
0 g
s
.59605 .53742 m .58176 .53083 L .58061 .52816 L p .059 .513 .894 r
F P
0 g
s
.56655 .51946 m .58061 .52816 L .58176 .53083 L p 0 .306 .763 r
F P
0 g
s
.82943 .41791 m .81453 .41175 L .79327 .36509 L p .323 .536 .905 r
F P
0 g
s
.77938 .36292 m .79327 .36509 L .81453 .41175 L p .414 .596 .92 r
F P
0 g
s
.70429 .45659 m .69102 .47217 L .67727 .44765 L p .906 .839 .768 r
F P
0 g
s
.67727 .44765 m .68961 .42931 L .70429 .45659 L p .906 .839 .768 r
F P
0 g
s
.6385 .53607 m .62447 .54003 L .62284 .53202 L p .744 .939 .949 r
F P
0 g
s
.62284 .53202 m .63676 .5254 L .6385 .53607 L p .744 .939 .949 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46661 .42644 L p 0 .416 .817 r
F P
0 g
s
.46661 .42644 m .45662 .42036 L .47717 .42815 L p 0 .416 .817 r
F P
0 g
s
.54572 .50049 m .55625 .50818 L .56273 .51504 L p 0 .191 .698 r
F P
0 g
s
.55625 .50818 m .54572 .50049 L .53998 .49447 L p 0 .187 .7 r
F P
0 g
s
.54758 .49936 m .53998 .49447 L .5332 .48749 L p 0 .168 .686 r
F P
0 g
s
.5332 .48749 m .53734 .48922 L .54758 .49936 L p 0 .168 .686 r
F P
0 g
s
.6103 .54053 m .59605 .53742 L .59471 .5334 L p .337 .723 .984 r
F P
0 g
s
.58061 .52816 m .59471 .5334 L .59605 .53742 L p .059 .513 .894 r
F P
0 g
s
.53998 .49447 m .54758 .49936 L .55625 .50818 L p 0 .187 .7 r
F P
0 g
s
.50842 .45606 m .51183 .46252 L .49806 .45095 L p 0 .243 .738 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50842 .45606 L p 0 .243 .738 r
F P
0 g
s
.62447 .54003 m .6103 .54053 L .6088 .53474 L p .581 .87 .995 r
F P
0 g
s
.6088 .53474 m .62284 .53202 L .62447 .54003 L p .581 .87 .995 r
F P
0 g
s
.58061 .52816 m .56655 .51946 L .56273 .51504 L p 0 .358 .818 r
F P
0 g
s
.59471 .5334 m .6088 .53474 L .6103 .54053 L p .337 .723 .984 r
F P
0 g
s
.35225 .4237 m .36534 .42171 L .34808 .4483 L p .823 .966 .898 r
F P
0 g
s
.34808 .4483 m .33365 .45516 L .35225 .4237 L p .823 .966 .898 r
F P
0 g
s
.52667 .47547 m .52628 .4785 L .5152 .46798 L p 0 .204 .717 r
F P
0 g
s
.5152 .46798 m .51183 .46252 L .52667 .47547 L p 0 .204 .717 r
F P
0 g
s
.69102 .47217 m .67766 .4878 L .66488 .46603 L p .908 .843 .769 r
F P
0 g
s
.66488 .46603 m .67727 .44765 L .69102 .47217 L p .908 .843 .769 r
F P
0 g
s
.41562 .40427 m .42604 .40737 L .40392 .415 L p .515 .906 .935 r
F P
0 g
s
.40392 .415 m .3912 .41687 L .41562 .40427 L p .515 .906 .935 r
F P
0 g
s
.84456 .42531 m .82943 .41791 L .80747 .36928 L p .264 .496 .892 r
F P
0 g
s
.79327 .36509 m .80747 .36928 L .82943 .41791 L p .323 .536 .905 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45662 .42036 L p .055 .539 .89 r
F P
0 g
s
.45662 .42036 m .44653 .41523 L .47008 .42042 L p .055 .539 .89 r
F P
0 g
s
.50498 .4485 m .50842 .45606 L .49116 .44341 L p 0 .346 .815 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50498 .4485 L p 0 .346 .815 r
F P
0 g
s
.67766 .4878 m .66418 .50252 L .6524 .48342 L p .901 .847 .781 r
F P
0 g
s
.6524 .48342 m .66488 .46603 L .67766 .4878 L p .901 .847 .781 r
F P
0 g
s
.56273 .51504 m .57555 .52212 L .58061 .52816 L p 0 .358 .818 r
F P
0 g
s
.57555 .52212 m .56273 .51504 L .55625 .50818 L p 0 .372 .837 r
F P
0 g
s
.59471 .5334 m .58061 .52816 L .57555 .52212 L p .211 .563 .937 r
F P
0 g
s
.54153 .48888 m .53734 .48922 L .52628 .4785 L p 0 .262 .767 r
F P
0 g
s
.52628 .4785 m .52667 .47547 L .54153 .48888 L p 0 .262 .767 r
F P
0 g
s
.33909 .4248 m .35225 .4237 L .33365 .45516 L p .821 .932 .904 r
F P
0 g
s
.33365 .45516 m .31918 .46079 L .33909 .4248 L p .821 .932 .904 r
F P
0 g
s
.85986 .43317 m .84456 .42531 L .82194 .37477 L p .242 .483 .888 r
F P
0 g
s
.80747 .36928 m .82194 .37477 L .84456 .42531 L p .264 .496 .892 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44653 .41523 L p .209 .657 .949 r
F P
0 g
s
.44653 .41523 m .43634 .41095 L .46294 .41262 L p .209 .657 .949 r
F P
0 g
s
.4051 .40142 m .41562 .40427 L .3912 .41687 L p .622 .944 .947 r
F P
0 g
s
.3912 .41687 m .37833 .41927 L .4051 .40142 L p .622 .944 .947 r
F P
0 g
s
.52708 .47059 m .52667 .47547 L .51183 .46252 L p 0 .313 .802 r
F P
0 g
s
.51183 .46252 m .50842 .45606 L .52708 .47059 L p 0 .313 .802 r
F P
0 g
s
.55625 .50818 m .56691 .5131 L .57555 .52212 L p 0 .372 .837 r
F P
0 g
s
.56691 .5131 m .55625 .50818 L .54758 .49936 L p 0 .355 .829 r
F P
0 g
s
.66418 .50252 m .65055 .51534 L .6398 .49881 L p .883 .85 .806 r
F P
0 g
s
.6398 .49881 m .6524 .48342 L .66418 .50252 L p .883 .85 .806 r
F P
0 g
s
.55528 .50174 m .54758 .49936 L .53734 .48922 L p 0 .315 .804 r
F P
0 g
s
.53734 .48922 m .54153 .48888 L .55528 .50174 L p 0 .315 .804 r
F P
0 g
s
.54758 .49936 m .55528 .50174 L .56691 .5131 L p 0 .355 .829 r
F P
0 g
s
.6088 .53474 m .59471 .5334 L .58845 .5256 L p .483 .725 .978 r
F P
0 g
s
.57555 .52212 m .58845 .5256 L .59471 .5334 L p .211 .563 .937 r
F P
0 g
s
.50151 .43979 m .50498 .4485 L .48419 .43581 L p .081 .45 .882 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50151 .43979 L p .081 .45 .882 r
F P
0 g
s
.3259 .42462 m .33909 .4248 L .31918 .46079 L p .802 .886 .906 r
F P
0 g
s
.31918 .46079 m .30472 .46465 L .3259 .42462 L p .802 .886 .906 r
F P
0 g
s
.65055 .51534 m .63676 .5254 L .62709 .51131 L p .85 .851 .844 r
F P
0 g
s
.62709 .51131 m .6398 .49881 L .65055 .51534 L p .85 .851 .844 r
F P
0 g
s
.58845 .5256 m .57555 .52212 L .56691 .5131 L p .275 .551 .926 r
F P
0 g
s
.73958 .37358 m .72686 .38354 L .69455 .35386 L p .786 .778 .845 r
F P
0 g
s
.72686 .38354 m .71434 .3965 L .68385 .36866 L p .824 .776 .808 r
F P
0 g
s
.68385 .36866 m .69455 .35386 L .72686 .38354 L p .824 .776 .808 r
F P
0 g
s
.82194 .37477 m .8366 .38074 L .85986 .43317 L p .242 .483 .888 r
F P
0 g
s
.62284 .53202 m .6088 .53474 L .60137 .52502 L p .675 .811 .948 r
F P
0 g
s
.58845 .5256 m .60137 .52502 L .6088 .53474 L p .483 .725 .978 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43634 .41095 L p .358 .752 .986 r
F P
0 g
s
.43634 .41095 m .42604 .40737 L .45573 .40475 L p .358 .752 .986 r
F P
0 g
s
.71434 .3965 m .70194 .41198 L .67328 .38589 L p .846 .772 .779 r
F P
0 g
s
.67328 .38589 m .68385 .36866 L .71434 .3965 L p .846 .772 .779 r
F P
0 g
s
.75255 .36685 m .73958 .37358 L .70543 .34194 L p .726 .771 .889 r
F P
0 g
s
.69455 .35386 m .70543 .34194 L .73958 .37358 L p .786 .778 .845 r
F P
0 g
s
.63676 .5254 m .62284 .53202 L .61426 .5202 L p .787 .843 .894 r
F P
0 g
s
.61426 .5202 m .62709 .51131 L .63676 .5254 L p .787 .843 .894 r
F P
0 g
s
.60137 .52502 m .61426 .5202 L .62284 .53202 L p .675 .811 .948 r
F P
0 g
s
.39449 .39854 m .4051 .40142 L .37833 .41927 L p .697 .954 .952 r
F P
0 g
s
.37833 .41927 m .36534 .42171 L .39449 .39854 L p .697 .954 .952 r
F P
0 g
s
.54576 .48595 m .54153 .48888 L .52667 .47547 L p .091 .387 .846 r
F P
0 g
s
.52667 .47547 m .52708 .47059 L .54576 .48595 L p .091 .387 .846 r
F P
0 g
s
.70194 .41198 m .68961 .42931 L .66278 .40488 L p .858 .767 .761 r
F P
0 g
s
.66278 .40488 m .67328 .38589 L .70194 .41198 L p .858 .767 .761 r
F P
0 g
s
.52748 .46363 m .52708 .47059 L .50842 .45606 L p .122 .417 .863 r
F P
0 g
s
.50842 .45606 m .50498 .4485 L .52748 .46363 L p .122 .417 .863 r
F P
0 g
s
.7658 .36337 m .75255 .36685 L .71654 .33314 L p .634 .748 .931 r
F P
0 g
s
.70543 .34194 m .71654 .33314 L .75255 .36685 L p .726 .771 .889 r
F P
0 g
s
.3127 .42289 m .3259 .42462 L .30472 .46465 L p .767 .832 .902 r
F P
0 g
s
.30472 .46465 m .29032 .46635 L .3127 .42289 L p .767 .832 .902 r
F P
0 g
s
.49802 .42998 m .50151 .43979 L .47717 .42815 L p .228 .544 .928 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49802 .42998 L p .228 .544 .928 r
F P
0 g
s
.68961 .42931 m .67727 .44765 L .65231 .42481 L p .862 .763 .752 r
F P
0 g
s
.65231 .42481 m .66278 .40488 L .68961 .42931 L p .862 .763 .752 r
F P
0 g
s
.56691 .5131 m .57765 .51453 L .58845 .5256 L p .275 .551 .926 r
F P
0 g
s
.57765 .51453 m .56691 .5131 L .55528 .50174 L p .266 .509 .901 r
F P
0 g
s
.56306 .50097 m .55528 .50174 L .54153 .48888 L p .202 .453 .875 r
F P
0 g
s
.54153 .48888 m .54576 .48595 L .56306 .50097 L p .202 .453 .875 r
F P
0 g
s
.60137 .52502 m .58845 .5256 L .57765 .51453 L p .513 .669 .934 r
F P
0 g
s
.77938 .36292 m .7658 .36337 L .72792 .32748 L p .509 .702 .957 r
F P
0 g
s
.71654 .33314 m .72792 .32748 L .7658 .36337 L p .634 .748 .931 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42604 .40737 L p .484 .817 .999 r
F P
0 g
s
.42604 .40737 m .41562 .40427 L .44846 .39682 L p .484 .817 .999 r
F P
0 g
s
.29953 .41946 m .3127 .42289 L .29032 .46635 L p .724 .774 .893 r
F P
0 g
s
.29032 .46635 m .27602 .46568 L .29953 .41946 L p .724 .774 .893 r
F P
0 g
s
.55528 .50174 m .56306 .50097 L .57765 .51453 L p .266 .509 .901 r
F P
0 g
s
.67727 .44765 m .66488 .46603 L .64182 .44474 L p .86 .76 .752 r
F P
0 g
s
.64182 .44474 m .65231 .42481 L .67727 .44765 L p .86 .76 .752 r
F P
0 g
s
.38378 .3954 m .39449 .39854 L .36534 .42171 L p .742 .94 .949 r
F P
0 g
s
.36534 .42171 m .35225 .4237 L .38378 .3954 L p .742 .94 .949 r
F P
0 g
s
.20672 .43194 m .19318 .42214 L .22154 .37026 L p .503 .557 .844 r
F P
0 g
s
.28641 .4143 m .29953 .41946 L .27602 .46568 L p .675 .717 .881 r
F P
0 g
s
.27602 .46568 m .26187 .46261 L .28641 .4143 L p .675 .717 .881 r
F P
0 g
s
.52789 .45451 m .52748 .46363 L .50498 .4485 L p .281 .5 .891 r
F P
0 g
s
.50498 .4485 m .50151 .43979 L .52789 .45451 L p .281 .5 .891 r
F P
0 g
s
.22154 .37026 m .23447 .38035 L .20672 .43194 L p .503 .557 .844 r
F P
0 g
s
.22032 .44146 m .20672 .43194 L .23447 .38035 L p .519 .565 .842 r
F P
0 g
s
.4945 .41916 m .49802 .42998 L .47008 .42042 L p .359 .619 .95 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .4945 .41916 L p .359 .619 .95 r
F P
0 g
s
.55003 .4801 m .54576 .48595 L .52708 .47059 L p .286 .484 .877 r
F P
0 g
s
.52708 .47059 m .52748 .46363 L .55003 .4801 L p .286 .484 .877 r
F P
0 g
s
.66488 .46603 m .6524 .48342 L .63127 .46368 L p .851 .759 .76 r
F P
0 g
s
.63127 .46368 m .64182 .44474 L .66488 .46603 L p .851 .759 .76 r
F P
0 g
s
.23447 .38035 m .24739 .3902 L .22032 .44146 L p .519 .565 .842 r
F P
0 g
s
.23403 .4501 m .22032 .44146 L .24739 .3902 L p .547 .587 .846 r
F P
0 g
s
.61426 .5202 m .60137 .52502 L .58843 .51201 L p .665 .725 .894 r
F P
0 g
s
.57765 .51453 m .58843 .51201 L .60137 .52502 L p .513 .669 .934 r
F P
0 g
s
.27335 .40753 m .28641 .4143 L .26187 .46261 L p .627 .665 .867 r
F P
0 g
s
.26187 .46261 m .24787 .45731 L .27335 .40753 L p .627 .665 .867 r
F P
0 g
s
.79327 .36509 m .77938 .36292 L .73959 .32475 L p .366 .634 .957 r
F P
0 g
s
.72792 .32748 m .73959 .32475 L .77938 .36292 L p .509 .702 .957 r
F P
0 g
s
.24739 .3902 m .26035 .39939 L .23403 .4501 L p .547 .587 .846 r
F P
0 g
s
.24787 .45731 m .23403 .4501 L .26035 .39939 L p .583 .621 .855 r
F P
0 g
s
.26035 .39939 m .27335 .40753 L .24787 .45731 L p .583 .621 .855 r
F P
0 g
s
.58843 .51201 m .57765 .51453 L .56306 .50097 L p .479 .606 .9 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41562 .40427 L p .581 .852 .995 r
F P
0 g
s
.41562 .40427 m .4051 .40142 L .44112 .38881 L p .581 .852 .995 r
F P
0 g
s
.6524 .48342 m .6398 .49881 L .62065 .48065 L p .834 .757 .779 r
F P
0 g
s
.62065 .48065 m .63127 .46368 L .6524 .48342 L p .834 .757 .779 r
F P
0 g
s
.62709 .51131 m .61426 .5202 L .59921 .50537 L p .753 .747 .847 r
F P
0 g
s
.58843 .51201 m .59921 .50537 L .61426 .5202 L p .665 .725 .894 r
F P
0 g
s
.37299 .39175 m .38378 .3954 L .35225 .4237 L p .761 .909 .941 r
F P
0 g
s
.35225 .4237 m .33909 .4248 L .37299 .39175 L p .761 .909 .941 r
F P
0 g
s
.57088 .49665 m .56306 .50097 L .54576 .48595 L p .403 .546 .884 r
F P
0 g
s
.54576 .48595 m .55003 .4801 L .57088 .49665 L p .403 .546 .884 r
F P
0 g
s
.6398 .49881 m .62709 .51131 L .60996 .49477 L p .804 .755 .807 r
F P
0 g
s
.60996 .49477 m .62065 .48065 L .6398 .49881 L p .804 .755 .807 r
F P
0 g
s
.59921 .50537 m .60996 .49477 L .62709 .51131 L p .753 .747 .847 r
F P
0 g
s
.56306 .50097 m .57088 .49665 L .58843 .51201 L p .479 .606 .9 r
F P
0 g
s
.49097 .40751 m .4945 .41916 L .46294 .41262 L p .466 .673 .954 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49097 .40751 L p .466 .673 .954 r
F P
0 g
s
.5283 .44329 m .52789 .45451 L .50151 .43979 L p .407 .559 .893 r
F P
0 g
s
.50151 .43979 m .49802 .42998 L .5283 .44329 L p .407 .559 .893 r
F P
0 g
s
.80747 .36928 m .79327 .36509 L .75156 .32455 L p .238 .561 .936 r
F P
0 g
s
.73959 .32475 m .75156 .32455 L .79327 .36509 L p .366 .634 .957 r
F P
0 g
s
.55431 .47121 m .55003 .4801 L .52748 .46363 L p .433 .547 .871 r
F P
0 g
s
.52748 .46363 m .52789 .45451 L .55431 .47121 L p .433 .547 .871 r
F P
0 g
s
.59921 .50537 m .58843 .51201 L .57088 .49665 L p .615 .654 .865 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .4051 .40142 L p .649 .864 .981 r
F P
0 g
s
.4051 .40142 m .39449 .39854 L .43372 .38074 L p .649 .864 .981 r
F P
0 g
s
.36214 .3874 m .37299 .39175 L .33909 .4248 L p .76 .867 .927 r
F P
0 g
s
.33909 .4248 m .3259 .42462 L .36214 .3874 L p .76 .867 .927 r
F P
0 g
s
.48741 .39524 m .49097 .40751 L .45573 .40475 L p .548 .711 .947 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48741 .39524 L p .548 .711 .947 r
F P
0 g
s
.52871 .4302 m .5283 .44329 L .49802 .42998 L p .501 .598 .883 r
F P
0 g
s
.49802 .42998 m .4945 .41916 L .52871 .4302 L p .501 .598 .883 r
F P
0 g
s
.57872 .48861 m .57088 .49665 L .55003 .4801 L p .539 .596 .859 r
F P
0 g
s
.55003 .4801 m .55431 .47121 L .57872 .48861 L p .539 .596 .859 r
F P
0 g
s
.57088 .49665 m .57872 .48861 L .59921 .50537 L p .615 .654 .865 r
F P
0 g
s
.69455 .35386 m .68385 .36866 L .64103 .34807 L p .795 .741 .803 r
F P
0 g
s
.68385 .36866 m .67328 .38589 L .63318 .36591 L p .808 .728 .775 r
F P
0 g
s
.63318 .36591 m .64103 .34807 L .68385 .36866 L p .808 .728 .775 r
F P
0 g
s
.67328 .38589 m .66278 .40488 L .6254 .38529 L p .813 .716 .758 r
F P
0 g
s
.6254 .38529 m .63318 .36591 L .67328 .38589 L p .813 .716 .758 r
F P
0 g
s
.60996 .49477 m .59921 .50537 L .57872 .48861 L p .696 .675 .825 r
F P
0 g
s
.70543 .34194 m .69455 .35386 L .64898 .33238 L p .77 .756 .841 r
F P
0 g
s
.64103 .34807 m .64898 .33238 L .69455 .35386 L p .795 .741 .803 r
F P
0 g
s
.66278 .40488 m .65231 .42481 L .61766 .40548 L p .813 .707 .749 r
F P
0 g
s
.61766 .40548 m .6254 .38529 L .66278 .40488 L p .813 .707 .749 r
F P
0 g
s
.55861 .45938 m .55431 .47121 L .52789 .45451 L p .534 .583 .85 r
F P
0 g
s
.52789 .45451 m .5283 .44329 L .55861 .45938 L p .534 .583 .85 r
F P
0 g
s
.82194 .37477 m .80747 .36928 L .76381 .3263 L p .154 .509 .912 r
F P
0 g
s
.75156 .32455 m .76381 .3263 L .80747 .36928 L p .238 .561 .936 r
F P
0 g
s
.65231 .42481 m .64182 .44474 L .60991 .42562 L p .806 .7 .748 r
F P
0 g
s
.60991 .42562 m .61766 .40548 L .65231 .42481 L p .806 .7 .748 r
F P
0 g
s
.62065 .48065 m .60996 .49477 L .58655 .477 L p .745 .684 .792 r
F P
0 g
s
.57872 .48861 m .58655 .477 L .60996 .49477 L p .696 .675 .825 r
F P
0 g
s
.71654 .33314 m .70543 .34194 L .65707 .31926 L p .725 .769 .888 r
F P
0 g
s
.64898 .33238 m .65707 .31926 L .70543 .34194 L p .77 .756 .841 r
F P
0 g
s
.35123 .3822 m .36214 .3874 L .3259 .42462 L p .745 .82 .911 r
F P
0 g
s
.3259 .42462 m .3127 .42289 L .35123 .3822 L p .745 .82 .911 r
F P
0 g
s
.64182 .44474 m .63127 .46368 L .60216 .44481 L p .795 .695 .754 r
F P
0 g
s
.60216 .44481 m .60991 .42562 L .64182 .44474 L p .795 .695 .754 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39449 .39854 L p .692 .858 .961 r
F P
0 g
s
.39449 .39854 m .38378 .3954 L .42626 .3726 L p .692 .858 .961 r
F P
0 g
s
.63127 .46368 m .62065 .48065 L .59437 .4622 L p .776 .69 .769 r
F P
0 g
s
.58655 .477 m .59437 .4622 L .62065 .48065 L p .745 .684 .792 r
F P
0 g
s
.59437 .4622 m .60216 .44481 L .63127 .46368 L p .776 .69 .769 r
F P
0 g
s
.52912 .41556 m .52871 .4302 L .4945 .41916 L p .569 .626 .869 r
F P
0 g
s
.4945 .41916 m .49097 .40751 L .52912 .41556 L p .569 .626 .869 r
F P
0 g
s
.48383 .38261 m .48741 .39524 L .44846 .39682 L p .609 .735 .935 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48383 .38261 L p .609 .735 .935 r
F P
0 g
s
.58655 .477 m .57872 .48861 L .55431 .47121 L p .625 .621 .827 r
F P
0 g
s
.55431 .47121 m .55861 .45938 L .58655 .477 L p .625 .621 .827 r
F P
0 g
s
.72792 .32748 m .71654 .33314 L .66533 .30892 L p .648 .772 .939 r
F P
0 g
s
.65707 .31926 m .66533 .30892 L .71654 .33314 L p .725 .769 .888 r
F P
0 g
s
.5629 .44492 m .55861 .45938 L .5283 .44329 L p .602 .606 .827 r
F P
0 g
s
.5283 .44329 m .52871 .4302 L .5629 .44492 L p .602 .606 .827 r
F P
0 g
s
.34029 .37609 m .35123 .3822 L .3127 .42289 L p .722 .773 .893 r
F P
0 g
s
.3127 .42289 m .29953 .41946 L .34029 .37609 L p .722 .773 .893 r
F P
0 g
s
.59437 .4622 m .58655 .477 L .55861 .45938 L p .679 .635 .799 r
F P
0 g
s
.8366 .38074 m .82194 .37477 L .77631 .3293 L p .127 .49 .903 r
F P
0 g
s
.76381 .3263 m .77631 .3293 L .82194 .37477 L p .154 .509 .912 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38378 .3954 L p .717 .842 .942 r
F P
0 g
s
.38378 .3954 m .37299 .39175 L .41873 .36438 L p .717 .842 .942 r
F P
0 g
s
.52954 .39981 m .52912 .41556 L .49097 .40751 L p .618 .647 .856 r
F P
0 g
s
.49097 .40751 m .48741 .39524 L .52954 .39981 L p .618 .647 .856 r
F P
0 g
s
.55861 .45938 m .5629 .44492 L .59437 .4622 L p .679 .635 .799 r
F P
0 g
s
.48023 .36987 m .48383 .38261 L .44112 .38881 L p .652 .75 .922 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48023 .36987 L p .652 .75 .922 r
F P
0 g
s
.73959 .32475 m .72792 .32748 L .6738 .30139 L p .53 .752 .977 r
F P
0 g
s
.66533 .30892 m .6738 .30139 L .72792 .32748 L p .648 .772 .939 r
F P
0 g
s
.60216 .44481 m .59437 .4622 L .5629 .44492 L p .715 .645 .778 r
F P
0 g
s
.32932 .36905 m .34029 .37609 L .29953 .41946 L p .695 .73 .877 r
F P
0 g
s
.29953 .41946 m .28641 .4143 L .32932 .36905 L p .695 .73 .877 r
F P
0 g
s
.5672 .42833 m .5629 .44492 L .52871 .4302 L p .648 .621 .809 r
F P
0 g
s
.52871 .4302 m .52912 .41556 L .5672 .42833 L p .648 .621 .809 r
F P
0 g
s
.60991 .42562 m .60216 .44481 L .5672 .42833 L p .738 .653 .765 r
F P
0 g
s
.5629 .44492 m .5672 .42833 L .60216 .44481 L p .715 .645 .778 r
F P
0 g
s
.61766 .40548 m .60991 .42562 L .57149 .41021 L p .754 .661 .759 r
F P
0 g
s
.5672 .42833 m .57149 .41021 L .60991 .42562 L p .738 .653 .765 r
F P
0 g
s
.6254 .38529 m .61766 .40548 L .57579 .39128 L p .764 .672 .76 r
F P
0 g
s
.57149 .41021 m .57579 .39128 L .61766 .40548 L p .754 .661 .759 r
F P
0 g
s
.63318 .36591 m .6254 .38529 L .5801 .37226 L p .77 .684 .768 r
F P
0 g
s
.57579 .39128 m .5801 .37226 L .6254 .38529 L p .764 .672 .76 r
F P
0 g
s
.52995 .38343 m .52954 .39981 L .48741 .39524 L p .653 .664 .848 r
F P
0 g
s
.48741 .39524 m .48383 .38261 L .52995 .38343 L p .653 .664 .848 r
F P
0 g
s
.31832 .36113 m .32932 .36905 L .28641 .4143 L p .667 .692 .864 r
F P
0 g
s
.28641 .4143 m .27335 .40753 L .31832 .36113 L p .667 .692 .864 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37299 .39175 L p .727 .821 .923 r
F P
0 g
s
.37299 .39175 m .36214 .3874 L .41113 .35609 L p .727 .821 .923 r
F P
0 g
s
.64103 .34807 m .63318 .36591 L .58443 .35384 L p .771 .7 .785 r
F P
0 g
s
.5801 .37226 m .58443 .35384 L .63318 .36591 L p .77 .684 .768 r
F P
0 g
s
.57149 .41021 m .5672 .42833 L .52912 .41556 L p .68 .634 .796 r
F P
0 g
s
.52912 .41556 m .52954 .39981 L .57149 .41021 L p .68 .634 .796 r
F P
0 g
s
.47659 .35729 m .48023 .36987 L .43372 .38074 L p .682 .76 .91 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47659 .35729 L p .682 .76 .91 r
F P
0 g
s
.77631 .3293 m .78901 .33274 L .8366 .38074 L p .127 .49 .903 r
F P
0 g
s
.64898 .33238 m .64103 .34807 L .58881 .33665 L p .766 .72 .81 r
F P
0 g
s
.58443 .35384 m .58881 .33665 L .64103 .34807 L p .771 .7 .785 r
F P
0 g
s
.75156 .32455 m .73959 .32475 L .68248 .29648 L p .379 .7 .983 r
F P
0 g
s
.6738 .30139 m .68248 .29648 L .73959 .32475 L p .53 .752 .977 r
F P
0 g
s
.30729 .35246 m .31832 .36113 L .27335 .40753 L p .641 .661 .854 r
F P
0 g
s
.27335 .40753 m .26035 .39939 L .30729 .35246 L p .641 .661 .854 r
F P
0 g
s
.65707 .31926 m .64898 .33238 L .59325 .32118 L p .752 .743 .844 r
F P
0 g
s
.58881 .33665 m .59325 .32118 L .64898 .33238 L p .766 .72 .81 r
F P
0 g
s
.57579 .39128 m .57149 .41021 L .52954 .39981 L p .703 .646 .79 r
F P
0 g
s
.29624 .3432 m .30729 .35246 L .26035 .39939 L p .619 .638 .847 r
F P
0 g
s
.26035 .39939 m .24739 .3902 L .29624 .3432 L p .619 .638 .847 r
F P
0 g
s
.53037 .36695 m .52995 .38343 L .48383 .38261 L p .68 .68 .843 r
F P
0 g
s
.48383 .38261 m .48023 .36987 L .53037 .36695 L p .68 .68 .843 r
F P
0 g
s
.52954 .39981 m .52995 .38343 L .57579 .39128 L p .703 .646 .79 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36214 .3874 L p .727 .796 .907 r
F P
0 g
s
.36214 .3874 m .35123 .3822 L .40346 .34772 L p .727 .796 .907 r
F P
0 g
s
.28514 .33356 m .29624 .3432 L .24739 .3902 L p .6 .623 .846 r
F P
0 g
s
.24739 .3902 m .23447 .38035 L .28514 .33356 L p .6 .623 .846 r
F P
0 g
s
.5801 .37226 m .57579 .39128 L .52995 .38343 L p .719 .659 .789 r
F P
0 g
s
.47292 .34508 m .47659 .35729 L .42626 .3726 L p .702 .765 .901 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47292 .34508 L p .702 .765 .901 r
F P
0 g
s
.27399 .32374 m .28514 .33356 L .23447 .38035 L p .587 .617 .849 r
F P
0 g
s
.23447 .38035 m .22154 .37026 L .27399 .32374 L p .587 .617 .849 r
F P
0 g
s
.66533 .30892 m .65707 .31926 L .59777 .30778 L p .723 .768 .889 r
F P
0 g
s
.59325 .32118 m .59777 .30778 L .65707 .31926 L p .752 .743 .844 r
F P
0 g
s
.52995 .38343 m .53037 .36695 L .5801 .37226 L p .719 .659 .789 r
F P
0 g
s
.58443 .35384 m .5801 .37226 L .53037 .36695 L p .731 .675 .796 r
F P
0 g
s
.76381 .3263 m .75156 .32455 L .69138 .29382 L p .233 .629 .957 r
F P
0 g
s
.68248 .29648 m .69138 .29382 L .75156 .32455 L p .379 .7 .983 r
F P
0 g
s
.53079 .35085 m .53037 .36695 L .48023 .36987 L p .699 .696 .844 r
F P
0 g
s
.48023 .36987 m .47659 .35729 L .53079 .35085 L p .699 .696 .844 r
F P
0 g
s
.58881 .33665 m .58443 .35384 L .53079 .35085 L p .738 .693 .809 r
F P
0 g
s
.53037 .36695 m .53079 .35085 L .58443 .35384 L p .731 .675 .796 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35123 .3822 L p .721 .772 .893 r
F P
0 g
s
.35123 .3822 m .34029 .37609 L .39573 .33928 L p .721 .772 .893 r
F P
0 g
s
.6738 .30139 m .66533 .30892 L .60237 .29663 L p .671 .79 .938 r
F P
0 g
s
.59777 .30778 m .60237 .29663 L .66533 .30892 L p .723 .768 .889 r
F P
0 g
s
.4692 .33344 m .47292 .34508 L .41873 .36438 L p .714 .769 .895 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .4692 .33344 L p .714 .769 .895 r
F P
0 g
s
.59325 .32118 m .58881 .33665 L .53122 .33558 L p .739 .715 .829 r
F P
0 g
s
.53079 .35085 m .53122 .33558 L .58881 .33665 L p .738 .693 .809 r
F P
0 g
s
.53122 .33558 m .53079 .35085 L .47659 .35729 L p .712 .713 .849 r
F P
0 g
s
.47659 .35729 m .47292 .34508 L .53122 .33558 L p .712 .713 .849 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .34029 .37609 L p .71 .749 .882 r
F P
0 g
s
.34029 .37609 m .32932 .36905 L .38792 .33076 L p .71 .749 .882 r
F P
0 g
s
.77631 .3293 m .76381 .3263 L .70049 .2929 L p .133 .57 .925 r
F P
0 g
s
.69138 .29382 m .70049 .2929 L .76381 .3263 L p .233 .629 .957 r
F P
0 g
s
.59777 .30778 m .59325 .32118 L .53165 .32148 L p .735 .74 .856 r
F P
0 g
s
.53122 .33558 m .53165 .32148 L .59325 .32118 L p .739 .715 .829 r
F P
0 g
s
.68248 .29648 m .6738 .30139 L .60708 .28776 L p .587 .797 .98 r
F P
0 g
s
.60237 .29663 m .60708 .28776 L .6738 .30139 L p .671 .79 .938 r
F P
0 g
s
.46544 .3225 m .4692 .33344 L .41113 .35609 L p .72 .77 .892 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46544 .3225 L p .72 .77 .892 r
F P
0 g
s
.53165 .32148 m .53122 .33558 L .47292 .34508 L p .72 .731 .859 r
F P
0 g
s
.47292 .34508 m .4692 .33344 L .53165 .32148 L p .72 .731 .859 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32932 .36905 L p .696 .728 .875 r
F P
0 g
s
.32932 .36905 m .31832 .36113 L .38005 .32217 L p .696 .728 .875 r
F P
0 g
s
.60237 .29663 m .59777 .30778 L .53208 .30881 L p .721 .768 .889 r
F P
0 g
s
.53165 .32148 m .53208 .30881 L .59777 .30778 L p .735 .74 .856 r
F P
0 g
s
.46163 .31234 m .46544 .3225 L .40346 .34772 L p .72 .77 .892 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46163 .31234 L p .72 .77 .892 r
F P
0 g
s
.53208 .30881 m .53165 .32148 L .4692 .33344 L p .723 .75 .873 r
F P
0 g
s
.4692 .33344 m .46544 .3225 L .53208 .30881 L p .723 .75 .873 r
F P
0 g
s
.69138 .29382 m .68248 .29648 L .6119 .28101 L p .472 .778 .997 r
F P
0 g
s
.60708 .28776 m .6119 .28101 L .68248 .29648 L p .587 .797 .98 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31832 .36113 L p .681 .71 .87 r
F P
0 g
s
.31832 .36113 m .30729 .35246 L .3721 .3135 L p .681 .71 .87 r
F P
0 g
s
.78901 .33274 m .77631 .3293 L .7098 .29308 L p .101 .548 .912 r
F P
0 g
s
.70049 .2929 m .7098 .29308 L .77631 .3293 L p .133 .57 .925 r
F P
0 g
s
.60708 .28776 m .60237 .29663 L .53253 .29771 L p .695 .795 .927 r
F P
0 g
s
.53208 .30881 m .53253 .29771 L .60237 .29663 L p .721 .768 .889 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30729 .35246 L p .666 .696 .868 r
F P
0 g
s
.30729 .35246 m .29624 .3432 L .36408 .30475 L p .666 .696 .868 r
F P
0 g
s
.53253 .29771 m .53208 .30881 L .46544 .3225 L p .72 .769 .891 r
F P
0 g
s
.45776 .30295 m .46163 .31234 L .39573 .33928 L p .716 .769 .894 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45776 .30295 L p .716 .769 .894 r
F P
0 g
s
.46544 .3225 m .46163 .31234 L .53253 .29771 L p .72 .769 .891 r
F P
0 g
s
.70049 .2929 m .69138 .29382 L .61684 .27608 L p .351 .735 .986 r
F P
0 g
s
.6119 .28101 m .61684 .27608 L .69138 .29382 L p .472 .778 .997 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29624 .3432 L p .652 .686 .869 r
F P
0 g
s
.29624 .3432 m .28514 .33356 L .35599 .29592 L p .652 .686 .869 r
F P
0 g
s
.6119 .28101 m .60708 .28776 L .53298 .2882 L p .652 .815 .962 r
F P
0 g
s
.53253 .29771 m .53298 .2882 L .60708 .28776 L p .695 .795 .927 r
F P
0 g
s
.7098 .29308 m .71927 .29362 L .78901 .33274 L p .101 .548 .912 r
F P
0 g
s
.53298 .2882 m .53253 .29771 L .46163 .31234 L p .711 .786 .91 r
F P
0 g
s
.45384 .29429 m .45776 .30295 L .38792 .33076 L p .708 .767 .898 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45384 .29429 L p .708 .767 .898 r
F P
0 g
s
.46163 .31234 m .45776 .30295 L .53298 .2882 L p .711 .786 .91 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28514 .33356 L p .64 .682 .874 r
F P
0 g
s
.28514 .33356 m .27399 .32374 L .34782 .287 L p .64 .682 .874 r
F P
0 g
s
.61684 .27608 m .6119 .28101 L .53345 .28016 L p .594 .823 .987 r
F P
0 g
s
.53298 .2882 m .53345 .28016 L .6119 .28101 L p .652 .815 .962 r
F P
0 g
s
.44985 .28624 m .45384 .29429 L .38005 .32217 L p .697 .764 .903 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44985 .28624 L p .697 .764 .903 r
F P
0 g
s
.7098 .29308 m .70049 .2929 L .62188 .27254 L p .261 .691 .964 r
F P
0 g
s
.61684 .27608 m .62188 .27254 L .70049 .2929 L p .351 .735 .986 r
F P
0 g
s
.53345 .28016 m .53298 .2882 L .45776 .30295 L p .696 .801 .93 r
F P
0 g
s
.45776 .30295 m .45384 .29429 L .53345 .28016 L p .696 .801 .93 r
F P
0 g
s
.4458 .27863 m .44985 .28624 L .3721 .3135 L p .684 .76 .909 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .4458 .27863 L p .684 .76 .909 r
F P
0 g
s
.62188 .27254 m .61684 .27608 L .53392 .27338 L p .529 .817 .998 r
F P
0 g
s
.53345 .28016 m .53392 .27338 L .61684 .27608 L p .594 .823 .987 r
F P
0 g
s
.53392 .27338 m .53345 .28016 L .45384 .29429 L p .675 .811 .948 r
F P
0 g
s
.45384 .29429 m .44985 .28624 L .53392 .27338 L p .675 .811 .948 r
F P
0 g
s
.71927 .29362 m .7098 .29308 L .62703 .26986 L p .226 .669 .954 r
F P
0 g
s
.62188 .27254 m .62703 .26986 L .7098 .29308 L p .261 .691 .964 r
F P
0 g
s
.4417 .27127 m .4458 .27863 L .36408 .30475 L p .67 .756 .915 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .4417 .27127 L p .67 .756 .915 r
F P
0 g
s
.5344 .26754 m .53392 .27338 L .44985 .28624 L p .65 .815 .963 r
F P
0 g
s
.44985 .28624 m .4458 .27863 L .5344 .26754 L p .65 .815 .963 r
F P
0 g
s
.53392 .27338 m .5344 .26754 L .62188 .27254 L p .529 .817 .998 r
F P
0 g
s
.62703 .26986 m .62188 .27254 L .5344 .26754 L p .474 .802 1 r
F P
0 g
s
.43754 .26392 m .4417 .27127 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.62703 .26986 m .63227 .26744 L .71927 .29362 L p .226 .669 .954 r
F P
0 g
s
.53489 .26227 m .5344 .26754 L .4458 .27863 L p .625 .813 .972 r
F P
0 g
s
.4458 .27863 m .4417 .27127 L .53489 .26227 L p .625 .813 .972 r
F P
0 g
s
.5344 .26754 m .53489 .26227 L .62703 .26986 L p .474 .802 1 r
F P
0 g
s
.63227 .26744 m .62703 .26986 L .53489 .26227 L p .445 .787 .998 r
F P
0 g
s
.53539 .25714 m .53489 .26227 L .4417 .27127 L p .605 .806 .977 r
F P
0 g
s
.4417 .27127 m .43754 .26392 L .53539 .25714 L p .605 .806 .977 r
F P
0 g
s
.53489 .26227 m .53539 .25714 L .63227 .26744 L p .445 .787 .998 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00l?ooool4o`000003oa0@4?oooooooooo077ooooo003booooo`03o`000?oooooooooo07?o
oooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003b
ooooo`03o`000?oooooooooo07?ooooo003booooo`03o`000?oooooooooo07?ooooo003booooo`03
o`000?oooooooooo07?ooooo003`ooooo`03oeEEEOmVIVKo000007Gooooo003oooooo`oooooo1?l0
00000ol@413oooooooooo`1Cooooo`00oooooolAooooo`03o`000?oooooooooo05Gooooo003loooo
o`;o00001oooool6o`0000Gooooo00?o0000ooooooooool0EOooool00?Wooooo0ol000000ooooooo
0000ooooo`0Aooooo`03o`000?oooooooooo05Gooooo003gooooo`;o00001?ooool2o`00017ooooo
00?o0000ooooooooool0EOooool00?Cooooo1?l00005ooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool0EOooool00?;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00Co0000
ooooool0003o00003oooool00ol0003oooooooooo`1Eooooo`00koooool3o`0000_ooooo0_l00000
0ooooooo0000ooooo`0<ooooo`03oeEEEOmVIVKo000005Oooooo003]ooooo`;o00003_ooool01Ol0
003ooooooooooooooooo000006Kooooo003Zooooo`?o00004?ooool01Ol0003ooooooooooooooooo
000006Kooooo003Wooooo`?o00000_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Hoooool00>Gooooo0_l0000Gooooo`05o`000?oooooooooooooo
ool00000IOooool00>;ooooo0ol0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00>3ooooo0_l0000Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
HOooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM01kooooo0ol000000ooooooo0000ooooo`0Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00008Oooool00ol0003oooooooooo`03ooooo`;o
0000H_ooool00:Wooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Oo
oooo0ol0000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Kooooo0_l0000Vooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Goooool00:Wooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool3o`0002Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Nooooo`00ZOooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05?ooool2o`0000?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo002Yooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0Aooooo`?o0000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05gooooo002Yooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo0_l0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool00<Wo
oooo0ol0000booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Oooooo
0_l00002ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool2o`0005gooooo
0034ooooo`?o0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo0032
ooooo`;o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002ooooo
o`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Wooooo002looooo`?o
000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05So
oooo002jooooo`;o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0F?ooool00;Oooooo0ol00015ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Eoooool00;Gooooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0E_ooool00;;ooooo0ol0001:ooooo`03o`000?oooooooooo00cooooo0_l0001Hoooo
o`00/?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05Gooooo002]ooooo`?o0000Coooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Cooooo002[ooooo`;o0000D_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0021ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Cooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1Cooooo`00POooool01OmgMgOoV9RHoooooonH
V9SoMgMg023ooooo0_l00003ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Booooo`00POooool01Ol@413ooooooooooooooooo410@01gooooo0ol0
001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool0087ooooo00Go0000
ooooooooooooooooo`00000Kooooo`;o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo057ooooo0021ooooo`05o`000?ooooooooooooooool000006?ooool3o`0005kooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00000@ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0/ooooo`00POooool01Ol@413ooooo
oooooooooooo410@01Kooooo0_l00002ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool0:oooool0087ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`?o0000Hoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Zooooo`00POooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^017ooooo0_l0001Vooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0:ooo
ool009Cooooo0ol0001Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00/ooooo`00TOoo
ool3o`0000;ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02kooooo
002?ooooo`;o0000Koooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02kooooo002<ooooo`?o0000LOoo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000]ooooo`00R_ooool2o`0007Cooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0001=ooooo`00Qoooool3o`000003ooooool0003ooooo07?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1;ooooo`00QOooool2o`0000Gooooo00?o0000ooooooooool0LOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04[ooooo0022ooooo`?o0000Noooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo0020ooooo`;o0000O_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Wooooo001mooooo`?o000000?oooooo`000?ooool0
OOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Sooooo001kooooo`;o0000Pooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo001hooooo`?o0000QOooool0
0ol0003oooooooooo`0Jooooo`;o0000BOooool0043ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM023ooooo0_l00028ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0A_ooool0043ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`?o000000?oooooo`000?ooool0Qooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Gooooo000hooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool2o`0008gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`15ooooo`00@?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool05oooool3o`0008oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`14ooooo`00@?ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Fooooo`;o0000T_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Cooooo0010ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0Eooooo`?o000000?oooooo`000?ooool0TOooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo04?ooooo0010ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0Booooo`?o0000Uoooool00ol0003oooooooooo`0Nooooo`?o0000A?ooool0043ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003oooool2o`0009_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`12ooooo`00HOooool3o`0009gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`11ooooo`00Goooool2o`0000?ooooo00?o0000ooooooooool0V_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Looooo`?o0000X_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo043ooooo001Jooooo`;o0000YOooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03oooooo001Gooooo`?o0000Yoooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03kooooo001Eooooo`;o00000oooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo02;ooooo0_l00010ooooo`00D_ooool3o`0000Kooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03gooooo001@oooo
o`;o0000[oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001=ooooo`?o
0000/Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo001;ooooo`;o0000
0oooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>oooool004Sooooo0ol0002fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0>_oo
ool0027ooooo1?l000000ol@413oooooooooo`0Nooooo`;o0000^Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo01gooooo1Ol0002ioooo
o`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;_ooool0
01Sooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l0002nooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo000Soooo
o`03o`000?oooooooooo01Sooooo0ol00030ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@02kooooo000Sooooo`03o`000?oooooooooo
01Gooooo0ol00033ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000002kooooo000Sooooo`03o`000?oooooooooo01?ooooo0_l00002oooo
o`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000;_ooool002?ooooo00?o0000ooooooooool04?ooool3o`00
0<Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooo
ooooool@4100;_ooool0027ooooo00?oEEEEofIVI_l000004?ooool2o`000<cooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;_ooool0
037ooooo0ol0003>ooooo`03o`000?oooooooooo02Wooooo0ol00004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0;_ooool002oooooo0_l00003ooooo`03o`000?oooooooooo0<_ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0dooooo`00;?ooool3o`000=?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0cooooo`00:_ooool2o`000=Kooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0cooooo`009oooool5o`000=Kooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0booooo`009_ooool3o`0000?ooooo00?o0000ooooooooool0doooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo037ooooo000Vooooo`03o`000?oooooo0000
0=Wooooo00?o0000ooooooooool0;oooool2o`0003;ooooo000Kooooo`Co000000?o410@oooooooo
ool01?ooool01?l0003oooooooooool0002Hooooo`oo0000<Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo000003;ooooo000Mooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000026oooooa7o00001?nJc_X5o`0000KoLLWo2ol0000Vooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0;oooool001;ooooo1_l00005ooooo`03o`000?oooooooooo00Go
oooo0_l00004ooooo`03o`000?oooooooooo07Wooooo2_l0000=oi[>nPOo00001OnOd?P00ol0003o
NLgoogW=o`03ogW=o`?o00002OmabOl;o`0001_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0_ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0M?ooool4o`0000?oYl3[00?o0000oi[>n_nJc_X02_nJc_X3o`0000coWm3h
1Ol0000@ogW=o`Wo00000omabOl7o`0001Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0^ooooo`007Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0L?ooool3o`0000KoYl3[0ol00003oi[>nP03o`000?nOd?SoWm3h00goWm3h1ol0
0004ojK@mP03o`000?n7dOooQm7o00GoQm7o2Ol0000:ogW=o`Go00001?liZo@3o`00017ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0^ooooo`007Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Joooool4o`0000KoYl3[0ol00002
oj_1jP03o`000?nOd?SoWm3h00_oWm3h1_l00007ojK@mPGo00005_n7dOl7o`0000Co@[3f1OliZo@3
o`0000kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0]ooooo`007Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0I_ooool4o`00
00OoYl3[0ol00006oj_1jP03o`000?nOd?SoWm3h00GoWm3h0ol00008ojK@mPOo00001?n/co800ol0
003oV=;loiSBo00<oiSBo0ko00000omI_?`5od:`mP03o`000?liZoCo>J_d00;o>J_d0ol0000;oooo
o`03o`000?oooooooooo03?ooooo0_l0000^ooooo`006oooool00omEEEGoIVIVo`000006ooooo`;o
00002_ooool00ol0003oooooooooo`1Qooooo`Co00002?nW`>/3o`0000SoZl7Z0_l00002oio@n003
o`000?nVd?KoY]3f00OoY]3f1_l00008ojc?lPCo00006_nHd_`01?l0003oN<OoogS7oomhaol5oeVl
o0Go@[3f00Co0000ocV[m?liZoCo>J_d1?l00008ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0;?ooool002Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Moooo
o`?o00002?nW`>/4o`0000SoZl7Z0ol000000on_`^So0000ojK@mP06ojK@mPCo00002_n/co85o`00
00?o//g^00?o0000ojK@m_nVd?H02onVd?H=o`0000SoN<Oo00?o0000oeVlo?mI_?`00_mI_?`01?l0
003o@[3fod:`m_m2/?H2o`0000?o>J_d0ol00005ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0:oooool002Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hoooo
o`Co00002?nW`>/3o`0000WoZl7Z0ol00004ojo2j0;o000000?oY]3fo`000?l000002on/co86o`00
00Oo//g^00?o0000ojK@m_nVd?H05onVd?H01Ol0003oU/cjoiK<n_nFc?[o000000WoN<Oo0_l00003
oeVlo005o`000?m2/?Ko@[3fod:`m_l000000oliZo@3o`0000;ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo05Cooooo0ol0000:ojO0j`;o00002On[`NX3o`0000Co[l;X0ol000000onb`nOo0000ojc?lP0:
ojc?lP?o00002onbcNh3o`0000KoY]3f4ol00009oiK<nP?o00001omhaol00ol0003oFKcloeVlo002
o`0000;o@[3f0_l00002ocV[m0?o0000=oooool00ol0003oooooooooo`0Zooooo`009?ooool2o`00
00kooooo00?o0000ooooooooool0DOooool2o`0000;oXjkO00?o0000ojO0jonW`>/01OnW`>/2o`00
00WoZl7Z0ol00004ojo2j0?o00001Onb`nL00ol0003o[<obojc?lP04ojc?lP;o00002onbcNh5o`00
00;o]/WX00?o0000ok7;kOnabnd05_nabnd01Ol0003oZl[`oj_:l?n[b_3o000000[oU/cj1Ol00004
ogS7o`;o000000GoFKclo`000?l0003o0000od:`mP06o`0003Gooooo00?o0000ooooooooool0:Ooo
ool002?ooooo0_l0000@ooooo`03o`000?oooooooooo04kooooo0_l00005oj>^g`03o`000?nW`>_o
Yl3[00;oYl3[00?o0000oj_1j_n[`NX01on[`NX3o`0000Go[l;X0_l00008ok;3i`;o000000?o[<ob
o`000?nbcNh02_nbcNh5o`0000Oo]/WX00?o0000ok7;kOnabnd05Onabnd00ol0003oZl[`oj_:l008
oj_:l0Co00001_nFc?X5o`0000?oN<Oo3?l0000cooooo`03o`000?oooooooooo02Sooooo000Toooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Boooool2o`0000OoXjkO0ol00009oj_1
jP?o00001On_`^P3o`0000Oo//?W0ol000000onea>Go0000ok;=kP07ok;=kPGo00002_nfbNP3o`00
00?o/L_]5Ol0000?oj_:l0Ko00001?nFc?X3o`0000?oHK?k0_lkXO@01?l0003o8Y7/ob:Ak?lRTN`3
oaV<j@;o0000<?ooool2o`0002[ooooo000Sooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0B?ooool2o`0000OoXjkO0_l00002ojJ_gP03o`000?n[`N[oZl7Z00CoZl7Z0ol00006ojo2
j0;o00001onb`nL3o`0000Go]LCU00?o0000ok;=k_nbcNh00_nbcNh3o`0000[o]/WX1Ol00002okS4
i003o`000?nha>?o^<CS01Go^<CS00Co0000okW4honia>?o^LCS1Ol0000=oj_:l0Co00000on7`?X5
of6cn`03o`000?lkXOCo>j7d00?o8Y7/0olIS>T2o`00033ooooo00?o0000ooooooooool09oooool0
02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`;o00001onS[]l2o`00
00GoYZoN00Co0000oj_1j_n[`N[oZl7Z0_l00006ojo2j0?o00001_nb`nL3o`0000Oo]LCU0_l00000
0onbcNko0000okK9j009okK9j0Go00001onha>@00ol0003o^<CSokS4h`0DokS4h`03o`000?nia>?o
^LCS00Oo^LCS1Ol00009oj_:l003o`000?nUaO3oYLG`00GoQl3j00Go0000of6cnol0003o0000of6c
n`03oc^Qm0?o8Y7/0olIS>T00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Kooooo000S
ooooo`;o00005?ooool00ol0003oooooooooo`11ooooo`?o00001onS[]l2o`0000OoYZoN0ol00007
ojo2j0;o00001_nb`nL3o`0000Oo]LCU0ol000000onga>Co0000okK9j007okK9j0Co00003?nha>@0
0ol0003o^<CSokS4h`0DokS4h`03o`000?nia>?o^LCS00co^LCS1Ol00003oj_:l003o`000?nUaO3o
YLG`00?oYLG`00?o0000ohO0n_l000001?l00003of6cn`03o`000?lkXOCo>j7d00;o8Y7/00?o0000
oaV<jOlIS>T00_l0000^ooooo`03o`000?oooooooooo02Kooooo000Sooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0?_ooool2o`0000SoXjkO0_l00007ojJ_gP;o000000?oZ[;No`00
0?n_`^P01On_`^P00ol0003o//?Wok;3i`05ok;3i`;o00002?nea>D2o`0000Go]lCT00?o0000okK9
j?nfbNP00_nfbNP2o`0000oo^<CT0ol00002okS4haCo00005?nia><3o`0000GoYLG`1Ol00003ohO0
nP;o00000omQ/o/00ol0003o>j7doc^Qm002ob:Ak003o`000?lIS>Wo6HcY00;o0000;Oooool00ol0
003oooooooooo`0Uooooo`008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03_o
oooo0_l00008oj>^g`;o00002?nV[mh00ol0003oZ[;NojZbgP02ojZbgP05o`000?n_`^So[l;Xojo2
j?l000001_nb`nL3o`0000Oo]LCU0ol00006okO4i0;o000000?o]/WXokS4i?nha>@03Onha>@5o`00
00;o^KoO00?o0000okbmfonl_M/04onl_M/01?l0003o`;kHol2nf?o0_]P7o`0000_o^LCS00?o0000
okW4honia><01?l00005ojG5l0;o00000_n7`?X01?l0003oQl3jo`000?l00002of6cn`03o`000?lk
XOCo>j7d00;o8Y7/00?o0000oaV<jOlIS>T00_l0000[ooooo`03o`000?oooooooooo02Gooooo000S
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0>?ooool2o`0000SoXjkO0_l00008
ojJ_gP;o00001OnZ/]h3o`0000Ko//?W0_l00007okG4i@?o00001_nga>@3o`000003okS5i?l0003o
^<CT00_o^<CT1?l00007okVog`03o`000?nl_M_o_;gK01?o_;gK00?o0000ol2nf?o0_]P02?o0_]P7
o`0000?o^LCS00?o0000okW4hol000000_l000000onia>?o0000o`000007ojG5l0;o000000CoQl3j
o`000?n7`?[oQl3j0_l00002of6cn`05o`000?lkXOCo0000o`000?lRTN`00_l000000olIS>Wo0000
o`00000Yooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd02?ooool002;ooooo0ol0000Hooooo`03o`000?oooooooooo03Go
oooo0_l00008oj>^g`;o00002?nV[mh2o`0000GoZ[;N0_l00003ojjegP05o`000?nb`nOo//?Wok;3
iol000002?nea>D2o`0000Oo]lCT0_l00005okS5i003o`000?nha>Co^<CT00Go^<CT1?l0000;okVo
g`03o`000?nl_M_o_;gK01;o_;gK00?o0000ol2nf?o0_]P04?o0_]P5o`0000Ko^LCS0_l00007ojG5
l0;o00001?n7`?X2o`0000;oHK?k00Go0000oc^Qm?l0003o0000ob:Ak002o`000003oaV<jOl0003o
000002Wooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Oooooo000Rooooo`03o`000?oooooooooo01Wooooo0_l0000c
ooooo`;o00002?nS[]l2o`0000SoYZoN0_l00006ojZbgP03o`000?n^]Mko[[GN00?o[[GN0_l00008
okG4i@?o00001_nga>@3o`0000Oo^<GT00?o0000okS4i?nha>@00_nha>@3o`0000co^KoO1?l00002
okbmfa?o00004Oo0_]P4o`000003olG1eol0003o^LCS00Oo^LCS0ol00006ojG5l0;o00001?n7`?X2
o`0000;oHK?k1?l000001?lRTNco0000oaV<jOlIS>T2o`0002Oooooo00?o0000ooooooooool01Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01_ooool002;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0^ooooo`?o00001onS[]l2o`0000SoYZoN0_l0
0006ojZbgP;o00001On^]Mh01?l0003o/[[Ook:jgol00006okG4i@03o`000?nga>Co]lCT00Go]lCT
0_l0000:okS5i0?o00003?ni_ml5o`0000?o^;_K00?o0000okfge?nm]m@04_nm]m@00ol0003oa;S?
olBhc`05o`0000Oo`;kH0ol00002ol2nf003o`000?o5`MOoaL7G00;oaL7G0_l00008okW4h`;o0000
1OnUaO03o`0000;oQl3j3?l00002oaV<j@03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0/ooooo`05o`000?nFWMWoUYgI
oiJMfOl000001?nS[]l2o`0000WoYZoN00?o0000ojZbg_nZ/]h01?nZ/]h2o`0000Go[[GN0_l00004
ok:jg`05o`000?nea>Go]LCUokG4iOl000001onga>@2o`0000Wo^<GT0ol000000onhaNCo0000okVo
g`07okVog`Go00002?nh^m/00ol0003o_KODokfge00Aokfge003o`000?o4^<ooa;S?00Koa;S?1ol0
0004ol2nf003o`000?o5`MOoaL7G00GoaL7G0_l00008okW4h`;o00001?nUaO001?l0003oYLG`o`00
0?l00003oh:cm006o`000?mMX_CoGJ;doefRm?l0003o?8o_1Ol000000olIS>Wo0000o`00000Voooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:_oo
ool00ol0003oUYgIoiJMf@03oiJMf@04o`000?nS[]ooXjkOo`0000WoYZoN0_l00006ojZbgP03o`00
0?n^]Mko[[GN00Co[[GN00?o0000ok:jgonb^]l01?nb^]l2o`0000Oo]lCT0ol00008okS5i0?o0000
1OnhaN@01?l0003o^KoOokVogoni_ml4o`0000go^;_K00?o0000okfge?nm]m@04Onm]m@00ol0003o
a;S?olBhc`07olBhc`So00000_o0_]P00ol0003oaL7GolG1e`07olG1e`;o00002?nia><2o`000003
ojG5l?l0003o000000?oX[o^1?n2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_00?o9h;Yo`00
0?l000001?l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00[ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0X
ooooo`03o`000?nFWMWoUYgI00CoUYgI0_l00009ojJ_gP;o00001_nZ/]h2o`0000Go[[GN0_l00006
ok:jg`03o`000?ne_n7o000000Go]lCT0_l00009okS5i0;o00001onhaN@4o`0001;o^;_K00?o0000
okfge?nm]m@04Onm]m@00ol0003oa;S?olBhc`04olBhc`?o00002?o4^<l2o`0000coaL7G0_l00008
okW4h`04o`000?nR_nkoX[o^o`0000?oX[o^1?n2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_
0olWP^T2ob1mi`;o00008_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00[ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`03ooooo`;o00008Oooool00ol0003oooooooooo`0Vooooo`03o`000?nFWMWoUYgI00Co
UYgI00Co0000oiVOf?nIWmSo00001_nV[mh2o`0000KoZ[;N0_l00006ojjegP03o`000?nb^]oo/[[O
00Co/[[O0_l00003okFoh@05o`000?nga>Co]lCTokO4i?l000002?nhaN@3o`0000Ko^<GT0ol00000
0onfa>Go0000okRkf`0@okRkf`Co000000?o_KODo`000?l000004?l00004olBhc`?o00003?o4^<l0
1?l0003obkg=o`000?l0000;olG1e`;o00001?nia><01?l0003o^LGSokW5honiaN<2oj:okP05o`00
0?nR_nkoX[o^oj:ok_l000000on2/o@01Ol0003oGJ;doefRm?mMX_Co000000?o?8o_0olWP^T3ob1m
i`03o`000?oooooooooo02;ooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Wooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Tooooo`03
o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP00_nIWmP00ol0003oYZoNojJ_gP02ojJ_gP03
o`000?nZ/]koZ[;N00GoZ[;N00?o0000ojjeg_n^]Mh01?n^]Mh2o`0000Ko/[[O00?o0000okFohOne
_n400one_n42o`0000Wo^<GT0_l00007okS5i0;o00001?nfa>D00ol0003o^;_KokRkf`08okRkf`Oo
00000onf]]T00ol0003o_;7?okbac`0@okbac`03o`000?o5/lSo000000Go00002oo4^<l00ol0003o
bkg=ol^mc@02ol^mc@?o00002_o5`ML2o`000003okW4hol0003o^LGS00Co^LGS00?o0000oj:ok_l0
00000onR_nh01Ol0003oP[?doh:cm?n2/oCo000000?oGJ;d00Co0000ocb?kollSnoo?8o_0olWP^T3
ob1mi`03o`000?oooooooooo027ooooo00?o0000ooooooooool07oooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP01?nIWmP0
1?l0003oYZoNojJ_g_l00006ojZbgP;o00001_n^]Mh00ol0003o/[[Ook:jg`04ok:jg`;o00001One
_n401?l0003o^<GTokS5i?l00005okS5i0?o00001_nhaN@3o`0000Oo]/CU00Co0000okRkfonh^m_o
^;_K1_l0000:okJff@03o`000?nl/Loo_;7?00oo_;7?0ol00006olFcb0Co00001oo4^<l00ol0003o
bkg=ol^mc@05ol^mc@;o00002_o5`ML00ol0003o^LGSokW5h`05okW5h`;o00001?nR_nh01Ol0003o
P[?doh:cm?n2/oCo000000?oGJ;d00Go0000ocb?kollSnoo?8o_o`000002obN2j@?o87gW00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo023ooooo00?o0000oiJMfOnFWMT01?nFWMT00ol0003oVIoHoiVOf005oiVOf0;o00001_nZ/]h2
o`0000Ko[[GN0_l00006ok:jg`03o`000?ne_n7o]KoQ00Co]KoQ00?o0000okS5i?nhaN@00_nhaN@0
0ol0003o^<GTokS5i002o`0000Oo^<GT0_l00009okK4i@Co00004Onf]]T00ol0003o_;7?okbac`0=
okbac`;o000000?o_;7?o`000?o5/lP02_o5/lP5o`0000;oa;S?00?o0000ol^mcOo;_Ld01oo;_Ld2
o`0000SoaL7G00?o0000olW7f?niaN<01_niaN<2o`0000CoX[o^00Go0000oh:cm?n2/oCoP[?do`00
0003oefRm005o`000?llSnoo?8o_ocb?kol000000_lWP^T01?l0003o87gWob1miol0000Sooooo`03
o`000?oooooooooo01gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo0_l0000Uooooo`03o`000?oooooooooo01kooooo00?o0000oiJMfOnFWMT01?nFWMT00ol0003o
VIoHoiVOf005oiVOf004o`000?nNXmSoWZ?Ho`0000CoZ[;N00?o0000ojjeg_n^]Mh01On^]Mh00ol0
003o/[[Ook:jg`04ok:jg`;o00001One_n42o`0000Go^<GT0_l00007okS5i0?o00002?nfa>D3o`00
0003ok?3i_l0003o][KI01;o][KI00?o0000okbaconl/Ll02_nl/Ll3o`0000;o_;7?00?o0000olFc
b?o5/lP03oo5/lP2o`0000cobkg=0ol00004olG1e`05o`000?o9amSobLOHolW7f?l000001_niaN<2
o`0000CoX[o^00Go0000oh:cm?n2/oCoP[?do`000003oefRm005o`000?llSnoo?8o_ocb?kol00000
0_lWP^T01?l0003o87gWob1miol0000Rooooo`03o`000?oooooooooo01gooooo000Pooooo`;o0000
9oooool00ol0003oooooooooo`0Looooo`03o`000?nFWMWoUYgI00CoUYgI00?o0000oiVOf?nIWmP0
1OnIWmP00ol0003oWZ?HoijSf002oijSf004o`000?nZ/]koZ[;No`0000Ko[[GN0_l00005ok:jg`;o
00001_ne_n400ol0003o^<GTokS5i004okS5i003o`000?njbnSo000000Go^<GT0_l00009okK4i@;o
00001?nc`nH00ol0003o][KIokJff@0<okJff@Ko000000?o_;7?o`000?l000002Ol00005okbac`03
o`000?o5/lSoaK?8013oaK?800Co0000oljja_l0003o00003?o;_Ld2o`000003olG1eol0003obLOH
00CobLOH00?o0000okW5honiaN<01?niaN<00ol0003oX[o^oj:okP03oj:okP05o`000?n2/oCoP[?d
oh:cm?l000000omMX_@01Ol0003o?8o_ocb?kollSnoo000000;o9h;Y00Co0000ob1miolPONOo0000
8Oooool2o`0001kooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06_oo
ool00ol0003oUYgIoiJMf@04oiJMf@03o`000?nIWmSoVIoH00GoVIoH00?o0000oijSf?nNXmP01?nN
XmP2o`0000Ko[[GN00?o0000ok:jgonb^]l01?nb^]l00ol0003o]KoQokFoh@04okFoh@;o00001Onh
aN@2o`0000?o^/_X00Go0000okS5i?nhaNCo^<GTo`000008okK4i@?o00001onc`nH00ol0003o][KI
okJff@02okJff@Wo00001Onb/]P00ol0003o^jc;ok^/b`04ok^/b`co00004Oo5/lP00ol0003oc[[6
oljjaP02oljjaP;o00003?o;_Ld00ol0003obLOHolW7f005olW7f003o`000?niaN?o^LGS00Co^LGS
00?o0000oj:ok_nR_nh00onR_nh01Ol0003oP[?doh:cm?n2/oCo000000?oGJ;d00Go0000ocb?koll
Snoo?8o_o`000002obN2j@04o`000?lPONOo87gWo`0002;ooooo00?o0000ooooooooool06oooool0
023ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?nFWMWoUYgI
00CoUYgI00?o0000oiVOf?nIWmP01OnIWmP00ol0003oWZ?HoijSf004oijSf004o`000?nTZM[oY:WJ
o`0000Co[[GN00?o0000ok:jgonb^]l00onb^]l2o`0000Ko]KoQ00?o0000okS5i?nhaN@01?nhaN@0
0ol0003o^/_Xok[;j003ok[;j0;o00002?nfa>D3o`0000So/l?V1ol0000>ok:bf004o`000?nk[<_o
^jc;ok^/b`?o00002onk[</00ol0003oaJo4olF_a004o`0000_oaK?800?o0000oljja_o>^/H01?o>
^/H2o`0000[obkg=00?o0000om;6c_o9amP01_o9amP00ol0003o^LGSokW5h`04okW5h`03o`000?nR
_nkoX[o^00?oX[o^00Go0000oh:cm?n2/oCoP[?do`000003oefRm005o`000?llSnoo?8o_ocb?kol0
00000_lWP^T01?l0003o87gWob1miol0000Qooooo`03o`000?oooooooooo01_ooooo000Pooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003oUYgIoiJMf@04oiJMf@03
o`000?nIWmSoVIoH00GoVIoH00?o0000oijSf?nNXmP01?nNXmP00ol0003oY:WJojBYfP02ojBYfP03
o`000?n^]Mko[[GN00Ko/[[O00?o0000okFohOne_n401One_n400ol0003o^<GTokS5i003okS5i0;o
00001OnjbnP01?l0003o^];/ok[Bk?l00005okK4i@;o00002?nc`nH3o`0000;o[/;X00?o0000ok:b
f?nb/]P03onb/]P00ol0003o^jc;o`000002o`0000go^jc;00?o0000olF_a?o5[l@01Oo5[l@4o`00
00KoaK?800?o0000oljja_o>^/H01oo>^/H2o`0000Oobkg=00Go0000om;6c_oBa/kod/K>o`000006
olW7f003o`000?niaN?o^LGS00Co^LGS00?o0000oj:ok_nR_nh00onR_nh01Ol0003oP[?doh:cm?n2
/oCo000000?oGJ;d00Go0000ocb?kollSnoo?8o_o`000002obN2j@04o`000?lPONOo87gWo`00027o
oooo00?o0000ooooooooool06_ooool0023ooooo0_l0000[ooooo`03o`000?oooooooooo01Cooooo
00?o0000oiJMfOnFWMT01?nFWMT00ol0003oVIoHoiVOf005oiVOf003o`000?nNXmSoWZ?H00CoWZ?H
00?o0000ojBYf_nTZMX01?nTZMX2o`0000Go/[[O00?o0000okFohOne_n401?ne_n42o`0000Go^<GT
00?o0000ok[;j?njbnP00onjbnP2o`0000Co^];/00?o0000okK4iOnfa>D00_l00006ok?3iPCo0000
1_n^`^P00ol0003o/[;Hok:bf00=ok:bf0?o00004?nk[</00ol0003oaJo4olF_a009olF_a0Co0000
0_o5/lP00ol0003oc[[6oljjaP09oljjaP;o00001?o;_Ld00ol0003od/K>om;6cP03om;6cP03o`00
0?o9amSobLOH00CobLOH00?o0000okW5honiaN<00oniaN<2o`0000?oX[o^2ol00003ocb?k`04o`00
0?lWP^Wo9h;Yo`0000;o87gW00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`00
8?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01;ooooo00?o0000oiJMfOnFWMT0
1?nFWMT00ol0003oVIoHoiVOf004oiVOf0;o00001_nNXmP00ol0003oY:WJojBYfP04ojBYfP03o`00
0?nZ/MgoZ[7M00;o00000_nb^]l7okFoh@03o`000?nhaNCo^<GT00?o^<GT0_l00004ok[;j0;o0000
1_njd^`2o`0000Ko/l?V0ol0000:ojk2j003o`000?nb/]So/[;H00Ko/[;H2Ol000001?nk[<_o0000
o`000?l0000=ok^/b`03o`000?o5[lCoaJo400goaJo40ol0000=oljjaP;o000000?obkg=o`000?oB
a/h01_oBa/h00ol0003obLOHolW7f004olW7f003o`000?niaN?o^LGS00?o^LGS1?l00002oj:ijPCo
QJW/1?mYV>/6o`0000;o9h;Y00Co0000ob1miolPONOo00008?ooool00ol0003oooooooooo`0Ioooo
o`008?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo013ooooo00?o0000oiJMfOnF
WMT01?nFWMT00ol0003oVIoHoiVOf004oiVOf003o`000?nNXmSoWZ?H00GoWZ?H00?o0000ojBYf_nT
ZMX01?nTZMX00ol0003oZ[7MojZag@03ojZag@;o00001_ne_n400ol0003o^<GTokS5i003okS5i003
o`000?njbnSo^/_X00?o^/_X00?o0000ok[Bk?njd^`01?njd^`2o`0000;o]mOa00Co0000ok?3i_nc
`nKo/l?V0_l0000<ojk2j0[o000000Co[ZkGo`000?l0003o00001?n^[]L00ol0003o^:S9okRXb@02
okRXb@Wo00000onk[</00ol0003oaJo4olF_a00?olF_a004o`000?o@]l;o0000o`0000goc[[60_l0
0008om;6cP03o`000?o9amSobLOH00CobLOH00Oo0000okW5honiaN?o^LGSo`000?niaN?o000000Go
X[WZ1?n5ZN`4ofVHj`CoDXWW0ol000001OlWP^Wo0000ob1miolPONOo000001oooooo0_l0000Joooo
o`008?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00kooooo0_l00005oiJMf@03
o`000?nIWmSoVIoH00CoVIoH00?o0000oijSf?nNXmP01OnNXmP00ol0003oY:WJojBYfP04ojBYfP03
o`000?nZ/MgoZ[7M00?oZ[7M00Co0000ok6jh?na^^3o00001?ne_n45okS5i0;o00001?njbnP2o`00
00Ko^];/00?o0000okOGlOngeo400_ngeo43o`0000_o[/;X1?l00002ojJok003o`000?n^[]Oo[ZkG
00?o[ZkG0ol00007ojj^e`03o`000?nhZ<Wo^:S900_o^:S91?l0000@olF_a003o`000?o@]l;od;O2
00;od;O20_l0000;oljjaP03o`000?oHaLOo000000Sod/K>00?o0000olW7f?o9amP01?o9amP00ol0
003o^LGSo`000003okW5h`03o`000?nR^N[oX[WZ00;oX[WZ00Go0000ohFYk?n5ZNcoQJW/o`000004
ofVHj`CoDXWW0_m3O^@3o`0000;o87gW00?o0000ooooooooool07Oooool00ol0003oooooooooo`0H
ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo0_n0S]P01Ol0
003oUYgIoiJMfOnFWMWo000000KoVIoH00?o0000oijSf?nNXmP01OnNXmP00ol0003oY:WJojBYfP04
ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6jh?na^^000_na^^000ol0003o]KoQokFoh@05
okS5i003o`000?njbnSo^/_X00?o^/_X00?o0000ok[Bk?njd^`01?njd^`2o`0000?o]mOa0_l00002
ok7KmP03o`000?n^`^So[/;X00Go[/;X1?l00006ojJok003o`000?n^[]Oo[ZkG00?o00002_n^[]L0
0ol0003o^:S9okRXb@0>okRXb@03o`000?o3[<;o`jc200?o00002oo5[l@00ol0003od;O2om2g`P04
om2g`P;o00002?o>^/H01Ol0003of<G7omS5aooHaLOo000000Sod/K>00?o0000olW7f?o9amP00oo9
amP2o`0000Co^LGS00?o0000oj:ij_nR^NX00_nR^NX00ol0003oQJW/ohFYk002ohFYk0CoJIS[00?o
0000oe:9iomBRNL00_mBRNL4od=ni0;o000000?o87gWo`000?ooool07_ooool00ol0003ooooooooo
o`0Gooooo`007oooool2o`00037ooooo00?o0000ooooooooool02oooool01Ol0003oP8kHoh2>f?n0
S]So000000;oUYgI1_nIWmP00ol0003oWZ?HoijSf005oijSf003o`000?nTZM[oY:WJ00CoY:WJ00?o
0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh0;o00001?nhaN@00ol0003o^/_Xok[;
j002ok[;j0;o00001Onjd^`2o`0000Co]mOa00?o0000ok7Km_nafoH00onafoH01?l0003o[/;Xojk2
j?n^`^P3o`0000[oY[o/0ol0000=ojj^e`03o`000?nhZ<Wo^:S900ko^:S900?o0000ol>/`_o3[<80
0oo3[<83o`0000OoaJo400?o0000om2g`_o@]l801oo@]l82o`0000Koc[[600?o0000omS5aooHaLL0
0_oHaLL00ol0003od/K>om;6cP06om;6cP07o`000?o9amSobLOHolW7f?l0003oc<gKo`000005okW5
h`03o`000?nR^N[oX[WZ00;oX[WZ00Go0000ohFYk?n5ZNcoQJW/o`000004ofVHj`CoDXWW00Co0000
od=ni?m3O^Co@gkT0_lmNn<3o`0001oooooo00?o0000ooooooooool05_ooool001oooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`03o`000?n0S]SoP8kH00;oP8kH0_l00005
oiVOf003o`000?nNXmSoWZ?H00GoWZ?H00?o0000ojBYf_nTZMX01?nTZMX00ol0003oZ[7MojZag@03
ojZag@03o`000?na^^3o/K[P00Co/K[P00Co0000okS5i?nhaNCo00000_nhaN@5ok[;j003o`000?nj
d^co^];/00Co^];/00?o0000okOGlOngeo400_ngeo42o`0000Ko/M_f0ol0000;ojJok0?o000000?o
Y[o/o`000?n^[]L03On^[]L00ol0003o^:S9okRXb@0>okRXb@03o`000?o3[<;o`jc200Ko`jc20ol0
0004olF_a003o`000?o@]l;od;O200Wod;O20_l00003oljjaP03o`000?oHaLOof<G700Cof<G700?o
0000om;6c_oBa/h01_oBa/h00ol0003obLOHo`000003olc=f`03o`000?niaN?o^LGS00;o^LGS0_l0
0003oj:ijP03o`000?n5ZNcoQJW/00;oQJW/00Go0000ofVHjomYV>_oJIS[o`000003oe:9i`03o`00
0?m3O^Co@gkT00;o@gkT1?lmNn<00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo
000Oooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02?ooool00ol0003oP8kHoh2>
f003oh2>f0;oQ93G00Go0000oiVOf?nIWmSoVIoHo`000007oijSf003o`000?nTZM[oY:WJ00CoY:WJ
00?o0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT
0ol00003ok[;j0Ko^];/0_l00003okOGl@;o00001_nafoH2o`000003ojKMnol0003oY[o/00WoY[o/
5_l000000onhZ<Wo0000o`00000<okRXb@03o`000?o3[<;o`jc200[o`jc20ol000000oo5[lCo0000
om2g`P0<om2g`P;o000000?oc[[6o`000?oHaLL01_oHaLL00ol0003od/K>om;6cP05om;6cP;o0000
1?o<cM/00ol0003o^LGSokW5h`03okW5h`;o00000onR^NX01Ol0003oQJW/ohFYk?n5ZNco000000?o
JIS[00?o0000oe:9iomBRNL00_mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Eooooo`007oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Kooooo00?o0000oh2>f?n0S]P00on0S]P01Ol0003oQ93GohB@eon4T=Oo0000
00;oVIoH1onNXmP00ol0003oY:WJojBYfP04ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6j
h?na^^001?na^^000ol0003o^<GTokS5i002okS5i004o`000?nndNWo_]7YokkAj@?o00001Onjd^`0
1?l0003o]mOaokOGlOngeo42o`0000Ko/M_f0_l00004ojKMn`03o`000?nV_ncoY[o/00;oY[o/1ol0
0004oi^lk`03o`000?nWZMWoYjWI00coYjWI00Co0000ok>Ub_ncYL[o/jG:1Ol00007okRXb@03o`00
0?o3[<;o`jc200go`jc20_l0000?om2g`P03o`000?oHaLOof<G700Oof<G700?o0000om;6c_oBa/h0
0ooBa/h00ol0003of=;Bo`000005olc=f`03o`000?niaN?o^LGS00;o^LGS0_l00003oj:ijP03o`00
0?n5ZNcoQJW/00;oQJW/00Go0000ofVHjomYV>_oJIS[o`000003oe:9i`05o`000?m3O^Co@gkTod=n
i?l000001?lmNn<00ol0003oooooooooo`0Kooooo`?o00005_ooool001oooooo0_l0000eooooo`;o
00001_ooool00ol0003oP8kHoh2>f003oh2>f003o`000?n4T=OoQ93G00;oQ93G0_l00006oijSf003
o`000?nTZM[oY:WJ00CoY:WJ00?o0000ojZagOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003
o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01?l0003o`]g]o`000?l00002ok[B
k0Co]mOa00?o0000ok7Km_nafoH00onafoH3o`0000KoY]gk1ol00009oi^lk`03o`000?nWZMWoYjWI
00coYjWI00?o0000ok>Ub_ncYLX01_ncYLX5o`0000;o^:S900?o0000ol>/`_o3[<803Oo3[<801?l0
003od;Boo`000?l0000=om2g`P;o00002OoHaLL01Ol0003od/K>om;6c_oBa/ko000000?of=;B00?o
0000olc=foo<cM/00_o<cM/00ol0003o^LGSokW5h`03okW5h`;o00000_nR^NX00ol0003oQJW/ohFY
k002ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o
?G_S00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`007_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00;ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93G
ohB@e`03ohB@e`;oS9KH0_l00003oijSf003o`000?nTZM[oY:WJ00CoY:WJ00?o0000ojZagOnZ/Md0
0onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT0
0onndNT01?l0003o`]g]ol;MkOo2gNd4o`0000;o]mOa00?o0000ok7Km_nafoH00_nafoH2o`0000Ko
Y]gk0ol000001?nDf_ko0000o`000?l0000=oi^lk`03o`000?nWZMWoYjWI00_oYjWI00?o0000ok>U
b_ncYLX02oncYLX3o`0000ko`jc200?o0000om2d_oo@];l00_o@];l2o`0000[od;O200Co0000om_4
`_oKa<;o00002OoHaLL00ol0003od/K>o`000004omSBdP03o`000?o<cM_oc<gK00?oc<gK00?o0000
okW5honiaN<00_niaN<00ol0003oX[WZo`000002oj:ijP05o`000?n5ZNcoQJW/ohFYk?l000001?mY
V>/01Ol0003oDXWWoe:9iomBRNOo000000?o@gkT00Go0000ocekholmNn?o?G_So`00000Pooooo`03
o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo03Sooooo00Go0000oooooooooooo
ooooo`000005oh2>f003o`000?n4T=OoQ93G00;oQ93G00?o0000ohbFf?n<U]P00_n<U]P00ol0003o
WZ?HoijSf006ojBYfP03o`000?nZ/MgoZ[7M00?oZ[7M00?o0000ok6jh?na^^001?na^^000ol0003o
^<GTokS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo`]g]o`000004ol;X
l0?o00000onafoH00ol0003oY]gkojKMn`03ojKMn`?o000000CoU=[no`000?l0003o00000_nDf_h0
0ol0003oVkc_oi^lk`05oi^lk`Oo000000CoYjWIo`000?l0003o00002OnWZMT00ol0003o/jG:ok>U
bP0=ok>UbP03o`000?o1ZL;o`JW200?o00002Oo3[<800ol0003od;Boom2d_`04om2d_`?o00001_o@
]l800ol0003oflC2om_4`P02om_4`P03o`000?oHaLOof<G700Oof<G700?o0000omSBd_oHd]800ooH
d]800ol0003oc<gKolc=f`03olc=f`03o`000?niaN?o^LGS00?o^LGS00Go0000oj:ij_l0003oX[WZ
o`000004ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mBRNL01Ol0003o@gkTod=ni?m3O^Co0000
00?o?G_S00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`004oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooo`000005oh2>
f003o`000?n4T=OoQ93G00?oQ93G00?o0000ohbFf?n<U]P00on<U]P2o`0000GoY:WJ00?o0000ojZa
gOnZ/Md00onZ/Md00ol0003o/K[Pok6jh004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkA
jOnndNT00onndNT01Ol0003o`]g]ol;MkOo2gNgo000000Co`^S`00Co0000okg`l_nml?;o_O3b1?l0
0002ojKMn`?o000000CoU=[no`000?l0003o00000onDf_h:o`0000KoS;Kb00?o0000oijUfonNYM/0
0_nNYM/7o`0000;oYjWI00?o0000ok>Ub_ncYLX03?ncYLX00ol0003o`JW2ol6Y`P04ol6Y`PCo0000
1Oo3[<800ol0003od;Boom2d_`07om2d_`;o00001?o@]l800ol0003oflC2om_4`P03om_4`P03o`00
0?oHaLOof<G700Kof<G700?o0000omSBd_oHd]801?oHd]800ol0003oc<gKolc=f`03olc=f`03o`00
0?niaN?o^LGS00;o^LGS00?o0000oj:ij_l000000_nR^NX01Ol0003oQJW/ohFYk?n5ZNco000000Co
JIS[00Go0000oe:9iomBRNOoDXWWo`000003od=ni005o`000?lmNn?o?G_Socekhol000008?ooool0
0ol0003oooooooooo`0Booooo`004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0>_ooool00ol0003oP8kHoh2>f004oh2>f003o`000?n4T=OoQ93G00;oQ93G00?o0000
ohbFf?n<U]P01?n<U]P2oiFNfP05o`000?nTZM[oY:WJojBYf_l000001OnZ/Md00ol0003o/K[Pok6j
h004ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01Ol0003o`]g]ol;M
kOo2gNgo000000Co`^S`00Go0000okg`l_nml?;o_O3bo`000003ok;dl`Oo000000?oU=[no`000?l0
00000ol00004og_Ao`03o`000?n<]_;oS;Kb00WoS;Kb00?o0000oijUfonNYM/02OnNYM/3o`0000ko
/jG:00?o0000ol6Y`_o1ZL802?o1ZL83o`000003ol>/`_l0003od;Bo00_od;Bo0_l000000oo@]l;o
0000om_4`P06om_4`P03o`000?oHaLOof<G700Cof<G700?o0000on3Dbol000001OoHd]800ol0003o
c<gKolc=f`03olc=f`03o`000?niaN?o^LGS00?o^LGS00Go0000oj:ij_l0003oX[WZo`000004ohFY
k005o`000?mYV>_oJIS[ofVHjol000000omBRNL00ol0003o@gkTod=ni002od=ni005o`000?lmNn?o
?G_Socekhol000008?ooool00ol0003oooooooooo`07ooooo`Co000000?o410@ooooooooool00ooo
ool001?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03[ooooo00?o
0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`000?n<U]SoS9KH00?oS9KH00Go
0000oiFNf_nEW][oUIkJo`000002ojBYfPGoZ[7M00?o0000ok6jh?na^^001?na^^000ol0003o^<GT
okS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo`]g]o`000004ol;Xl005
o`000?nml?;o_O3bokg`l_l000000onbm?<00ol0003oWo7bo`000006o`0000GoNm7o1_l000000on<
]_;o0000o`000003o`0000GoS;Kb00?o0000oijUfonNYM/02_nNYM/00ol0003o[Z;;ojjRb`05o`00
00Oo/jG:00?o0000ol6Y`_o1ZL802oo1ZL83o`0000god;Bo0_l00008om_4`P03o`000?oHaLOof<G7
00;of<G700Co0000on3DbooPe<_o00001_oHd]800ol0003oc<gKolc=f`03olc=f`03o`000?niaN?o
^LGS00;o^LGS00?o0000oj:ij_nR^NX00_l00004ohFYk005o`000?mYV>_oJIS[ofVHjol000001?mB
RNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000ooooooooool07Oooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05o`000?ooooooooooooooool00000
1Oooool3o`0003[ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`00
0?n<U]SoS9KH00CoS9KH00?o0000oiFNf_nEW]X00_nEW]X2o`0000CoZ[7M00?o0000ok6jh?na^^00
1?na^^000ol0003o^<GTokS5i002okS5i003o`000?nndNWo_]7Y00?o_]7Y00Go0000ol;MkOo2gNgo
`]g]o`000004ol;Xl005o`000?nml?;o_O3bokg`l_l000000_nbm?<4o`000003oioal_l0003o0000
00?oPnO_1_l00006oe_0o003o`000?mg[?CoMjcd00?oMjcd1_l0000<oijUf`03o`000?n^X/_o[Z;;
00Go[Z;;1Ol000000oncYL[o0000ol6Y`P0>ol6Y`P04o`000?o>/koo0000o`0000_od;Bo00?o0000
omc3`?l000002?oKa<801Ol0003of<G7omS5aooHaLOo000000?oh=C;00?o0000omSBd_oHd]800ooH
d]800ol0003oc<gKolc=f`03olc=f`04o`000?niaN?o^LGSokW5h`go00000_mYV>/01Ol0003oDXWW
oe:9iomBRNOo000000?o@gkT00Go0000ocekholmNn?o?G_So`00000Qooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool001?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo03[ooooo00?o0000oh2>f?n0S]P00on0S]P00ol0003oQ93GohB@e`03ohB@
e`03o`000?n<U]SoS9KH00?oS9KH00?o0000oiFNf_nEW]X00onEW]X01?l0003oX:[Mo`000?l00002
ojZag@Ko/K[P00?o0000okS5i?nhaN@00_nhaN@00ol0003o_]7YokkAj@03okkAj@05o`000?o2gNgo
`]g]ol;MkOl000001?o2j?000ol0003o_O3bokg`lP02o`000004ok;dlol0003o0000o`0000;oWo7b
0_l00002oh?Wk`?o00000_mPeNT4o`000003oe_0o?l0003o000000;o00000_mK`?`00ol0003oMjcd
ogN/m007ogN/m003o`000?nAX=koTJ3N00Go00001OnNYM/00ol0003o[Z;;ojjRb`0:ojjRb`;o0000
3_o1ZL800ol0003oc[>ooljc_`02oljc_`03o`000?o@];ood;Bo00Ood;Bo00Go0000omc3`?oL`l3o
g<?0o`000008om_4`P03o`000?oHaLOo000000Coh=C;00?o0000omSBd_oHd]801?oHd]800ol0003o
c<gKolc=f`02olc=f`Co00000_nia^@3ojBfi@03o`000?n>YNCoSZGT00?oSZGT0_mkUN43o`0000Co
DXWW00Go0000od=ni?m3O^Co@gkTo`000003ocekh`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`004oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0>Oooool00ol0003oP8kHoh2>f003oh2>f003o`000?n4T=OoQ93G
00?oQ93G00?o0000ohbFf?n<U]P01?n<U]P00ol0003oUIkJoiFNfP02oiFNfP03o`000?nPZ]goX:[M
00;oX:[M0_l00005ok6jh003o`000?nhaNCo^<GT00;o^<GT00?o0000okkAjOnndNT00onndNT01Ol0
003o`]g]ol;MkOo2gNgo000000Co`^S`00?o0000okg`l_nml?801Ol00003oioalP04o`000?n3inoo
PnO_oh?Wk`Ko00001Olg^^401?l0003o=JSbocFXl_leZ?84o`000003ogN/m?l0003o000000GoMjcd
00?o0000oi6Pg_nAX=h01OnAX=h4o`000003oijUfol0003o[Z;;00co[Z;;00?o0000okbW`ol00000
0_l0000:ol6Y`P03o`000?o>/kooc[>o00?oc[>o0_l00007om2d_`03o`000?oL`l3og<?000;og<?0
00?o0000om_4`_oKa<801_oKa<800ol0003oh=C;on3Db`04on3Db`03o`000?oHd];of=;B00?of=;B
00?o0000olc=foo<cM/00_l000000oo<dmoo0000okW6i003okW6i005o`000?nT]^GoY;KUojBfiOl0
00001?n>YN@5og^Eh@;o00000_mBRNL01Ol0003o@gkTod=ni?m3O^Co000000?o?G_S00?o0000oooo
ooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`03o`000?n0S]SoP8kH
00CoP8kH00?o0000ohB@eon4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ
00?oUIkJ00?o0000oj2ZgOnPZ]d00_nPZ]d00ol0003o[;OQo`000002o`000003ok6jh?l0003o^<GT
00?o^<GT00?o0000okkAjOnndNT00onndNT01Ol0003o`]g]ol;MkOo2gNgo000000Co`^S`00?o0000
okg`l_l000000_l00002ok;dl`03oioal_l0003o000000Oo00001?mchN@8o`0000;o=JSb0_l00002
ocFXlP03o`000?mKW_?oFikc00Go000000?oMjcdo`000?nAX=h02OnAX=h2o`0000go[Z;;00?o0000
okbW`onlYl<00_nlYl<3o`0000Ko`JW200?o0000oljc_oo>/kl01_o>/kl2o`0000Cod;Bo00?o0000
omc3`?oL`l001?oL`l000ol0003oflC2om_4`P05om_4`P03o`000?oPe<_oh=C;00Goh=C;00?o0000
omSBd_oHd]800_oHd]800ol0003oc<gKo`000003olcCg`03o`000?nia^Co^LKT00;o^LKT00Co0000
ojBfiOnT]^GoY;KU0_l00003ohjUi003o`000?mkUN7oNiGQ00;oNiGQ0_m/RMh3o`0000Co@gkT00Co
0000ocekholmNn?o00008_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
000Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Wooooo00?o0000oh2>f?n0S]P0
0on0S]P00ol0003oQ93GohB@e`03ohB@e`03o`000?n<U]SoS9KH00CoS9KH00?o0000oiFNf_nEW]X0
0_nEW]X00ol0003oX:[Moj2Zg@02oj2Zg@03o`000?n/]n7o[;OQ00?o[;OQ0ol00003okS5i0Go_]7Y
00Go0000ol;MkOo2gNgo`]g]o`000004ol;Xl0?o000000?o_O3bo`000?l000000ol00002ol;mhP03
o`000?n`n^;o000000;oUo;S00?o0000og?Qi?l000004ol00006oe^Nl`;o00002onAX=h00ol0003o
YIk?ojFNc`03o`0000So[Z;;00?o0000okbW`onlYl<01OnlYl<2o`0000Co`JW200?o0000oljc_oo>
/kl02?o>/kl01Ol0003od;Boom2d_oo@];oo000000Oog<?000?o0000om_4`_oKa<800ooKa<800ol0
003oiMK6o`000006on3Db`03o`000?oHd];of=;B00;of=;B0_l00004olcCg`03o`000?nia^Co^LKT
00;o^LKT00Oo0000ojBfiOnT]^GoY;KUo`000?n>YNCo000000;oSZGT00?o0000og^EhOmkUN400_mk
UN45ofb9gP;o00000_m3O^@01Ol0003o?G_SocekholmNn?o0000027ooooo0_l00007ooooo`03o`00
0?oooooooooo00Gooooo000Mooooo`03o`000?oooooooooo03Oooooo0_l00005oh2>f003o`000?n4
T=OoQ93G00?oQ93G00?o0000ohbFf?n<U]P00on<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nP
Z]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i005o`0000;o_]7Y00?o
0000ol;MkOo2gNd00_o2gNd2ol;Xl0Oo00000_o=o><02?l0003o`_gRol;mh_o2oN;o0000ok3jh_l0
003oUo;S1?l00002ok[ik003o`000?nHkOKo000001?o00000omKW_<00ol0003oP9WRoh2IhP03o`00
00KoTJ3N00?o0000ojFNconUW/l00onUW/l3o`0000Co[Z;;00?o0000okbW`onlYl<02?nlYl<3o`00
0003ol6Y`_l0003oc[>o00[oc[>o0_l000000oo@];oo0000omc3`007omc3`005o`000?oKa<;oflC2
om_4`_l000000_oUe/H00ol0003oh=C;on3Db`05on3Db`06o`000?oHd];of=;Bo`000?oJg]Wo0000
1?o<dml00ol0003o^LKTokW6i002okW6i007o`000?nT]^GoY;KUojBfiOl0003oSZGTo`000002ohjU
i003o`000?mkUN7oNiGQ00;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh2of:2g0?o00000olmNn<00ol0
003oooooooooo`0Nooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool001go
oooo00?o0000ooooooooool0=oooool2of1nfP;o00000_n0S]P00ol0003oQ93GohB@e`03ohB@e`03
o`000?n<U]SoS9KH00?oS9KH00?o0000oiFNf_nEW]X00onEW]X00ol0003oX:[Moj2Zg@02oj2Zg@03
o`000?n/]n7o[;OQ00?o[;OQ00?o0000okW6i?nia^@00_nia^@01?l0003oa=CVolCDi_o4e>H<o`00
00;od_OU00Co0000olglhoo=o>?o00000oo2oN800ol0003o/?[Ro`000002o`000003ololh_l0003o
^_W/00;o^_W/0ol000000oo3j?3o0000oikKo003oikKo004o`000?mT^ogoI;_mofBko@Co00000_l0
J]42o`0000;o>X_]0_l00002oe^Nl`03o`000?n0VN;oP9WR00;oP9WR0ol00003oi6PgP03o`000?nU
W/ooYIk?00KoYIk?0ol000000on^X/_o0000okbW``0<okbW``;o00003Oo>/kl00ol0003og<?0omc3
`008omc3`003o`000?oKa<;o000000CoiMK600?o0000on3DbooPe</01?oPe</00ol0003of=;Bo`00
0002om[Nf@03o`000?o<dmooc=?O00;oc=?O00?o0000okW6i?nia^@00_nia^@01Ol0003oY;KUojBf
iOnT]^Go000000;oSZGT00?o0000ohjUi?l000001?mkUN400ol0003oK8WNofb9gP02ofb9gPGoHX;L
0_l00002ocekh`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool001cooooo00?o
0000ooooooooool0>?ooool4of1nfP03o`000?n0S]So000000GoQ93G00?o0000ohbFf?n<U]P00on<
U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nPZ]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/
]n401Ol0003o^LKTokW6i?nia^Co000000Goa=CV00?o0000olgRioo=h^L00ol00003om;^i`04o`00
0?oBmnGod_OUo`0000;ocOcS00Co0000ol;mh_o2oN;o`_gR0ol00004ololhP03o`000?njnNco^_W/
00;o00001?o3j?000ol0003oW]_loikKo005o`000003ofBkoOl0003o6XSY00;o00000ol0J]401?l0
003o>X_]ocZ;kOljRnd3o`0000OoP9WR1?l0000;ojFNc`;o00003OnlYl<00ol0003obk71o`00000<
oljc_`;o00002_oL`l000ol0003oiMK6onGFaP03onGFaP03o`000?oPe<_oh=C;00Goh=C;00Go0000
om[NfOoJg]Wof]kIo`000004olcCg`03o`000?nia^Co^LKT00;o^LKT00Go0000ojBfiOnT]^GoY;KU
o`000003ohjUi0;o00001?mkUN400ol0003oK8WNofb9gP02ofb9gP03o`000?mRP]coHX;L00;oHX;L
0_mMOm`3o`00027ooooo0ol0000=ooooo`007?ooool00ol0003oooooooooo`0hooooo`GoH7kJ00?o
0000ohB@eon4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ00?oUIkJ00?o
0000oj2ZgOnPZ]d00_nPZ]d00ol0003o[;OQojbgh@03ojbgh@03o`000?nia^Co^LKT00;o^LKT00?o
0000olCDi_o4e>H00_o4e>H5o`0000Cod^kW00Co0000om;giOoBmnGo00000_o=o><01?l0003o`_gR
ol;mh_o2oN82o`000003om[kfol0003ococR00;ococR1?l000000ooGjn;o0000ol?Xl003ol?Xl0?o
00000_n_b^h00ol0003oPkWgoh>im`09o`000003oaAchOl0003o000000?o>X_]00?o0000oh2Ih_n0
VN801on0VN800ol0003oYIk?ojFNc`0:ojFNc`04o`000?ngYLOo0000o`0000[o_:O300?o0000ol^a
`Oo;/L400_l00009oljc_`04o`000?oL`/3og<;0o`0000Wog<?000?o0000onGFa_oUe/H01?oUe/H0
0ol0003oh=C;on3Db`03on3Db`;o00000ooJg]T00ol0003oc=?OolcCg`02olcCg`03o`000?nia^Co
^LKT00;o^LKT00?o0000ojBfiOnT]^D00_nT]^D00ol0003oSZGTohjUi002o`0000CoNiGQ00?o0000
ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2g002of:2g0CoGGoL00?o0000ooooooooool07?ooool3
o`0000;ooooo00?o0000ooooooooool02oooool001cooooo0_l0000iooooo`03o`000?mPO][oH7kJ
00;oH7kJ00?oIX;Jo`000?n4T=L00on4T=L00ol0003oS9KHohbFf003ohbFf003o`000?nEW][oUIkJ
00;oUIkJ00?o0000oj2ZgOnPZ]d00onPZ]d00ol0003o[;OQojbgh@03ojbgh@05o`000?nia^Co^LKT
okW6i?l000000oo4e>H3o`0000?ocN;W00Go0000om;^iooBk^Ood^kWo`000003om;gi@05o`000?o=
o>?ocOcSo`000?o2oN800_l00003om[kf`03o`000?o?o>;ococR00;o00001OoGjn84o`000003olS@
h?l0003o[l[^00?o[l[^00?o0000oh>imon3^OL00_n3^OL2ocjCl@Go00000_lDLn42o`000003ocZ;
kOl0003oJ8oT00?o00001On0VN801?l0003oVY_Co`000?l00008ojFNc`03o`000?ngYLOo]jG700;o
]jG70_l00007okbW``03o`000?o;/L7obk7100?obk710_l00007oljc_`05o`000?oL`/3og<;0omc2
`?l000001ooL`l000ol0003oimK4o`000005onGFaP03o`000?oPe<_oh=C;00;oh=C;00?o0000onCU
dol000000ooJg]T00ol0003oc=?OolcCg`03olcCg`05o`000?nia^Co^LKTokW6i?l000001?nT]^D0
1?l0003oSZGTohjUi?n>YN@2o`0000?oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2
g002of:2g003o`000?mMOmcoGGoL00;oGGoL00?o0000ooooooooool06?ooool3o`0000Gooooo00?o
0000ooooooooool02oooool001cooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02
of1nfP;oIX;J00Co0000ohB@eon4T=Oo00001On<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nP
Z]goX:[M00;oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i002okW6i0Co000000?o
a=CVo`000?o=h^L00_o=h^L00ol0003od^kWom;^i`02om;^i`04o`000?oBmnGod_OUo`0000;ocOcS
0ol000001_oQn=Oo0000om[kfooJnm_o0000ololhP;o000000?ohNWGo`000?oGjn801?oGjn800ol0
003ob=3PolS@h003olS@h003o`000?n_b^ko[l[^00;o[l[^00?o0000oh>imon3^OL01?l000000oln
To7o0000o`0]XP02o`0000?o57?Q0ol00003ofR?i0;o00000on0VN801?l0003oVY_CoiZKdonJVm<3
o`0000GoYIk?00?o0000okNUaongYLL01?ngYLL2o`0000Go_:O300?o0000ol^a`Oo;/L401Oo;/L40
0ol0003oc[>ooljc_`03oljc_`03o`000?oL`/3og<;000?og<;000?o0000omc3`?oL`l001?oL`l00
0ol0003oimK4o`000006onGFaP04o`000?oPe<_oh=C;o`0000;oi>GC00Go0000om[NfOoJg]Wof]kI
o`000005olcCg`05o`000?nia^Co^LKTokW6i?l000001?nT]^D00ol0003oSZGTohjUi002ohjUi005
o`000?mkUN7oNiGQog^EhOl000001?m/RMh00ol0003oHX;Lof:2g002of:2g003o`000?mMOmcoGGoL
00;oGGoL00?o0000ooooooooool05Oooool3o`0000Sooooo00?o0000ooooooooool02oooool001co
oooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP?oIX;J00?o0000ohB@eol0
00001On<U]P00ol0003oUIkJoiFNfP02oiFNfP03o`000?nPZ]goX:[M00?oX:[M00?o0000ojbghOn/
]n400on/]n400ol0003o^LKTokW6i003o`0000Coa=CV00Co0000olgRioo=h^Oo00001?oBk^L01Ol0
003od_OUom;giOl0003ocOcS00;o00000ooQn=L01?l0003of__Kom[kfooJnm/2o`0000CohNWG00Co
0000omO[h_oGjn;oen_R0_l00006olS@h003o`000?n_b^ko[l[^00Co00000_n8Zn`00ol0003oCHo]
odf?k@02o`000003o`0]X_l0003o000000;o00000_lDLn400ol0003oJ8oTofR?i003ofR?i0Co0000
1_nJVm<2o`0000?oYIk?00?o0000okNUaongYLL01_ngYLL2o`0000?o_:O300?o0000ol^a`Oo;/L40
1_o;/L42o`0000;oc[>o00?o0000omc2`?oL`/001OoL`/000ol0003og<?0omc3`002omc3`005o`00
0?oWe/CoimK4onOFa?l000001OoUe/H00ol0003oh=C;o`000003onCUd`03o`000?oJg]Wof]kI00;o
f]kI00?o0000olcCgoo<dml00_o<dml01Ol0003o^LKTokW6i?nia^Co000000CoY;KU00?o0000ohjU
i?n>YN@00_n>YN@2o`0000;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0003oHX;Lof:2g002of:2
g003o`000?mMOmcoGGoL00;oGGoL00?o0000ooooooooool04Oooool4o`0000_ooooo00?o0000oooo
ooooool02oooool001cooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP04
o`000?mVP][oIX;JofJ2fP;o00001?n<U]P00ol0003oUIkJoiFNfP03oiFNfP03o`000?nPZ]goX:[M
00?oX:[M00?o0000ojbghOn/]n400_n/]n44o`000003okW6i?l0003oa=CV00?oa=CV00Go0000olgR
ioo=h^OocN;Wo`000003om;^i`04o`000?oBmnGod_OUom;gi@;o000000?ohoCGo`000?oQn=L00_oQ
n=L00ol0003of__Kom[kf`02o`0000GohNWG00Co0000omO[h_oGjn;o00000_oFdM@00ol0003ob=3P
olS@h004olS@h0;o00000on/]n401Ol0003oR:_/ohR[k?n8Znco000000;oCHo]00?o0000o`9Rf?l0
00000_l000001Ol0F=3o0000oaAchOl0003oAgoT00;o00001OmXSn@00ol0003oVY_CoiZKd`06oiZK
d`?o00002ongYLL3o`0000_obk7100?o0000oljc_ol000002?oL`/001?l0003og<?0omc3`?l00004
onOFa003o`000?oUe/KoiMK600CoiMK600?o0000onCUdooTiM<00_oTiM<00ol0003of]kIom[Nf@02
om[Nf@03o`000?o<dmooc=?O00;oc=?O00Go0000okW6i?nia^Co^LKTo`000004ojBfi@03o`000?n>
YNCoSZGT00;oSZGT0_l00002og^Eh@03o`000?m/RMkoK8WN00;oK8WN00?o0000of:2g?mRP]`00_mR
P]`00ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00kooooo0ol0000@ooooo`03o`000?oo
oooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Wooooo00Go0000of1nf_mPO][oH7kJo`00
0004ofJ2fP;oLH[L0ol000000on<U]So0000oiFNfP03oiFNfP03o`000?nPZ]goX:[M00?oX:[M00Co
0000ojbghOn/]n7o[;OQ0ol00003okW6i003o`000?o4e>Koa=CV00;oa=CV00Go0000olgRioo=h^Oo
cN;Wo`000003om;^i`05o`000?oBmnGod_OUom;giOl000000ooSm=L01?l0003ohOSGon7heooQn=L3
o`000003onKWd?l0003ohNWG00CohNWG00?o0000omO[h_l000001?oFdM@01Ol0003ob=3PolS@h?o8
d>3o000000;o`;_E00?o0000ojbghOn/]n400_n/]n401Ol0003oR:_/ohR[k?n8Znco000000;oCHo]
00?o0000o`9Rf?l000000_l000001?l0F=3o0000o`000?l00002odMoi0;o00000omXSn@01?l0003o
R9GIo`000?l00007oiZKd`03o`000?ngYLOo]jG700_o]jG70_l0000;ol^a`@;o00002OoL`/000ol0
003og<?0o`000005onOFa003o`000?oUe/KoiMK600?oiMK600?o0000onCUdooTiM<00_oTiM<00ol0
003of]kIom[Nf@02om[Nf@03o`000?o<dmooc=?O00;oc=?O00Go0000okW6i?nia^Co^LKTo`000004
ojBfi@03o`000?n>YNCoSZGT00;oSZGT00Go0000og^EhOl0003oNiGQo`000004ofb9gP03o`000?mR
P]coHX;L00;oHX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0;ooooo`?o00004ooo
ool00ol0003oooooooooo`0:ooooo`006oooool00ol0003oooooooooo`0iooooo`05o`000?mPO][o
H7kJof1nf_l000001?mVP]X5og6:g0;o00001?nEW]X00ol0003oX:[Moj2Zg@03oj2Zg@Co000000?o
[;OQo`000?nia^@00onia^@00ol0003oa=CVolCDiP02olCDiP05o`000?o=h^OocN;WolgRiol00000
0ooBk^L01?l0003od_OUo`000?l00003on?de`04o`000?oQn=OohOSGon7he`;o00001?oVim000ol0
003ohNWGon7Ye`02on7Ye`;o00001_oFdM@00ol0003ob=3Po`000004ol2ke@03o`000?n/]n7o[;OQ
00;o[;OQ00?o0000ohR[k?n8Zn`03?l00004odMoi004o`000?mXSnCoJ8oTo`0000?oR9GI00?o0000
oiZKdonJVm<01?nJVm<01?l0003o[J;<o`000?l0000:okNUa`03o`000?o6/<Co000000[obk7100?o
0000omW2`_l000002OoL`/000ol0003oimK4onOFa004onOFa003o`000?oUe/KoiMK600;oiMK60_l0
0005onCUd`05o`000?oJg]Wof]kIom[NfOl000001?o<dml01Ol0003o^LKTokW6i?nia^Co000000Co
Y;KU00?o0000ohjUi?n>YN@00_n>YN@00ol0003oNiGQog^Eh@02o`0000CoK8WN00?o0000of:2g?mR
P]`00_mRP]`00ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00Oooooo1?l0000Fooooo`03
o`000?oooooooooo00[ooooo000Kooooo`;o0000>Oooool00ol0003oH7kJof1nfP02of1nfP03o`00
0?mVP][oIX;J00;oIX;J1OmaR]`2oh6Gg`04o`000?nEW][oUIkJo`0000CoX:[M0ol00004ojbgh@03
o`000?nia^Co^LKT00;o^LKT00Go0000olCDi_o4e>Koa=CVo`000003olgRi`04o`000?oBk^Ood^kW
om;^i`?o000000?oh^oHo`000?oSm=L00_oSm=L00ol0003ohOSGon7he`02o`0000Goi^O@00Oo0000
on7YeooQjMOohNWGo`000?oMd<co000000Ooe]7D00?o0000ol2keOo0^mD01?o0^mD01?l0003o[;OQ
ojbghOn/]n43o`0000?oOY_T0_m9Q>H5o`000004o`0n_?l0003o7f[Lo`0000?oAgoT0ol00004ohRE
f@;o00001?nJVm<01?l0003o[J;<ojfRc?n]X/`2o`0000Oo]jG700Co0000olJ`a?o6/<Coa[340_l0
0007ol^a`@05o`000?oI`/;ofL;2omW2`_l000002?oL`/000ol0003oimK4onOFa005onOFa006o`00
0?oUe/KoiMK6o`000?oZjLgo00001OoTiM<01Ol0003of]kIom[NfOoJg]Wo000000?oc=?O3_l00000
0on>YNCo0000og^Eh@02og^Eh@03o`000?m/RMkoK8WN00;oK8WN00?o0000of:2g?mRP]`00_mRP]`0
0ol0003oGGoLoeeog002oeeog003o`000?oooooooooo00Cooooo0ol0000Jooooo`03o`000?oooooo
oooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000of1nf_mPO]X00_mPO]X00ol0
003oIX;JofJ2fP02ofJ2fP03o`000?maR]coLH[L00;oLH[L0on1Uml01?l0003oUIkJo`000?nPZ]d3
o`000003oj2ZgOl0003o[;OQ00?o[;OQ00?o0000okW6i?nia^@00_nia^@00ol0003oa=CVolCDiP02
olCDiP04o`000?o=h^OocN;Wo`0000;od^kW0_l00004on;_f009o`000?oSm=OohoCGon?deol0003o
hOSGo`000?oXi<go000000Goi^O@00Co0000on7YeooQjMOo00000ooMd<`00ol0003oe]7DomKAe003
omKAe004o`000?o;_<cobkc<o`0000Go`;_E00?o0000ojbghOl000000onOY]X4ogjKi004o`000?m9
Q>Ko0000o`=Me@?o000000?o03jlo`000?lOJ]`00_l00003odMoi003o`000?n8UMWoR9GI00CoR9GI
0_l000000onJVm?o0000ojfRc005ojfRc003o`000?ngYLOo]jG700Co]jG700?o0000olJ`a?o6/<@0
0oo6/<@00ol0003obk71ol^a`@03ol^a`@03o`000?oI`/;ofL;200?ofL;200?o0000omc2`?oL`/00
1?oL`/000ol0003oj=O4o`000006onOFa003o`000?oUe/Ko000000;oj^W=00?o0000onCUdooTiM<0
0ooTiM<01?l0003of]kIom[NfOoJg]T4o`000003olWHi?l0003o^LKT00;o^LKT00?o0000ojRdhOnX
]>400_nX]>401?l0003oVJCMoiVTgOnIY=d3o`0000;oNiGQ00?o0000ofb9g_m/RMh00_m/RMh00ol0
003oHX;Lof:2g002of:2g003o`000?mMOmcoGGoL00;oGGoL00Co0000oooooooooooooooo0ol0000M
ooooo`03o`000?oooooooooo00[ooooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000of1n
f_mPO]X00_mPO]X00ol0003oIX;JofJ2fP02ofJ2fP03o`000?maR]coLH[L00;oLH[L1?n1Uml3o`00
00?oX:[M00?o0000ojbghOn/]n400on/]n400ol0003o^LKTokW6i002okW6i005o`000?o4e>Koa=CV
olCDi_l000000oo=h^L3o`000003omgXfol0003oh^oH00?oh^oH00Co0000on?deooSm=OohoCG0_l0
0002onSTc@03o`000?oVim3oi^O@00Coi^O@0_l00005omg@c005o`000?oFdMCoe]7DomKAe?l00000
1?o;_<`00ol0003o`;_Eol2ke@03ol2ke@03o`000?nOY][oWjKJ00?oWjKJ00So0000ogjKi?mnVnCo
OY_To`000?m9Q>Ko0000o`=Me@Co000000?o053=oamZg?lOJ]`00_l000001?m7OnCo0000ofj<g_l0
0006ohREf@;o00001on]X/`2o`0000?o]jG700?o0000olJ`a?o6/<@01Oo6/<@2o`0000?obk7100?o
0000omW2`_oI`/801?oI`/800ol0003og<;0omc2`002omc2`005o`000?oXelCoj=O4onSGa?l00000
1_oWe/@01Ol0003oj^W=on[YcOoZjLgo000000Goi>GC00?o0000om[NfOoJg]T00_l00003olWHi005
o`000?nia^Co^LKTokW6i?l000001?nX]>400ol0003oVJCMoiVTg@03oiVTg@;oS9SJ1?l00003ofb9
gP03o`000?mRP]coHX;L00;oHX;L00?o0000oeeog?mMOm`00_mMOm`4o`00023ooooo00?o0000oooo
ooooool02_ooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003oH7kJof1nfP02of1nfP03
o`000?mVP][oIX;J00;oIX;J00?o0000og6:g?maR]`00_maR]`4o`0000;oTjKR0ol000000onPZ]go
0000ojbgh@03ojbgh@03o`000?nia^Co^LKT00;o^LKT00?o0000olCDi_o4e>H00_o4e>H4o`0000Co
gNSK00?o0000on;_f?oRkmP00_oRkmP00ol0003ohoCGon?de`02o`0000Coj>C=00?o0000onKWd?oV
im000_oVim02o`0000OogM3<00?o0000omKAe?l000001_o;_<`01Ol0003o`;_Eol2keOo0^mGo0000
00;o/Z[@00?o0000oinVf_nOY]X00_nOY]X01?l0003oOY_TogjKi?mnVn@8o`000004o`1@cOl0003o
7f[LoamZg0;o00000_m^S=h2o`0000GoR9GI00?o0000ojfRc?n]X/`01on]X/`2o`000003okNUaol0
003oa[3400Soa[3400?o0000ol^a`Ol000002?oI`/801Ol0003og<;0omc2`?oL`/3o000000?oj=O4
00?o0000onOFa?oWe/@01?oWe/@00ol0003oj^W=on[Yc@02on[Yc@03o`000?oTiM?oi>GC00;oi>GC
0ol000000ooFin;o0000olWHi002olWHi005o`000?nia^Co^LKTokW6i?l000001?nX]>400ol0003o
VJCMoiVTg@02oiVTg@03o`000?n<V=[oS9SJ00;oS9SJ0ol00002ofb9gP03o`000?mRP]coHX;L00;o
HX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[o
oooo000Jooooo`?o0000>Oooool00ol0003oH7kJof1nfP02of1nfP03o`000?mVP][oIX;J00;oIX;J
00Co0000og6:g?maR]coLH[L0_l00003oh6Gg`GoTjKR1?l00002ojbgh@03o`000?nia^Co^LKT00;o
^LKT00?o0000olCDi_l000000ol00002omGOg`03o`000?oMj=_ogNSK00;ogNSK00Go0000on;_f?oR
kmSoh^oHo`000003on?de`03o`000?oXi<goj>C=00?oj>C=00Oo0000onKWd?oVim3oi^O@o`000?oQ
clOo000000SogM3<00?o0000ol^lc?o;_<`01_o;_<`00ol0003o`;_Eo`000004ok:Zd003o`000?nO
Y][oWjKJ00;oWjKJ00Go0000ogjKi?l0003oK8gQo`000002ocQfh0Co00000_l0D<d01?l0003o7f[L
oamZg?l00004ofj<gP03o`000?n8UMWoR9GI00;oR9GI00?o0000oinNdol000002On]X/`00ol0003o
a[34olJ`a009olJ`a0;o00002OoI`/800ol0003og<;0o`000005onSGa003o`000?oWe/CoimK400;o
imK40_l00004on[Yc@04o`000?oTiM?oi>GConCUd`;o00000ooFin801Ol0003obMSTolWHi?o9f>Co
000000?o^LKT00?o0000ojRdhOnX]>400_nX]>400ol0003oVJCMoiVTg@02oiVTg@03o`000?n<V=[o
S9SJ00;oS9SJ0_n2S]L2o`000003ofb9g_l0003oHX;L00?oHX;L00?o0000oeeog?mMOm`00_mMOm`0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo
03Wooooo00?o0000of1nf_mPO]X00_mPO]X00ol0003oIX;JofJ2fP02ofJ2fPGo00001?n1Uml5oi>V
hPCoYkKT2Ol00002olWDhP05o`000?oEgmooeMoOomGOgol000001?oMj=/01Ol0003oh^oHon;_f?oR
kmSo000000;ohoCG0_l00005onSTc@04o`000?oVim3oi^O@o`0000?ohLo700?o0000omg@c?oMd<`0
1OoMd<`2o`0000Sobkc<00?o0000ok:Zd?nbZ]001?nbZ]001?l0003oWjKJoinVf_nOY]X3o`0000;o
K8gQ00?o0000ocQfh?lhM^001?l00002o`1@c@05o`000?lOJ]co0000odUkh?l000000om^S=h2o`00
00;oR9GI00?o0000oinNdonOW]<00_l00007ojfRc003o`000?nn[l[o000000Woa[3400?o0000omG1
aol000002OoI`/800ol0003oj=O4onSGa004onSGa007o`000?oWe/CoimK4onOFa?l0003ok>g:o`00
0004on[Yc@06o`000?oTiM?o0000o`000?oNl]co00000_oFin801Ol0003obMSTolWHi?o9f>Co0000
00?o^LKT00?o0000ojRdhOnX]>400_nX]>400ol0003oVJCMoiVTg@03oiVTg@05o`000?n<V=[oS9SJ
ohbHf_l000000on2S]L3o`0000CoHX;L00?o0000oeeog?mMOm`00_mMOm`00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Wooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0>Oooool00ol0003oH7kJof1n
fP02of1nfP03o`000?mVP][oIX;J00?o00000omaR]`00ol0003oPIOOoh6Gg`02oh6Gg`03o`000?nC
Y^;oTjKR00;oTjKR1OnW]^@00ol0003o^LKTokW6i002okW6i003o`000?o9e>;obMCR00;obMCR00Go
0000omGOgooEgmooeMoOo`000004omgXf`07o`000?oRkmSoh^oHon;_f?l0003ohoCGo`000002onSR
c003o`000?oXi<goj>C=00?oj>C=0_l00005on7?a`03o`000?oMd<cogM3<00?ogM3<00Co0000om6l
aOoA_<Go00001oo;_<`00ol0003o_Jc8o`000005ok:Zd003o`000?nOY][o000000?oSISJ00Co0000
ofb=hOm/SN7o00000_lhM^05o`000003o`1@cOl0003oBG_P00;oBG_P00?o0000ofj<g_m^S=h00_m^
S=h2o`0000GoWikC00?o0000ojfRc?n]X/`00on]X/`01?l0003o_Zo:okj_b_nn[lX2o`0000Koa[34
00Go0000omG1aooE`LOoeL77o`000008omW2`P03o`000?oXelCoj=O400Goj=O400?o0000onOFa?l0
00000_o/kLX00ol0003oj^W=on[Yc@02on[Yc@;o00000_oNl]`01Ol0003oe^ORomKWh_oFin;o0000
00?obMST00Go0000okW6i?nia^Co^LKTo`000004ojRdh@03o`000?nIY=goVJCM00;oVJCM00?o0000
ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`02oh:>e`?o00000omRP]`00ol0003oGGoLoeeog002
oeeog003o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00004oiRHV?ooooooV9RH
ogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>Oooool0
1?l0003oH7kJof1nf_mPO]X4o`000003ofJ2f_l0003oLH[L00?oLH[L00?o0000oh6Ggon1Uml00_n1
Uml00ol0003oTjKRoi>VhP02oi>VhPGoYkKT00?o0000okW6i?nia^@00_nia^@00ol0003obMCRolWD
hP02olWDhP05o`000?oEgmooeMoOomGOgol000000ooMj=/00ol0003oh^oHon;_f002on;_f0;o0000
0ooXh/`00ol0003oj>C=onSTc@03onSTc@03o`000?oQclOohLo700GohLo700Go0000omg@c?oMd<co
gM3<o`000004om6la@03o`000?o;_<cobkc<00?obkc<00Go0000okf/b?nm[<So_Jc8o`000005ok:Z
d003o`000?n=V=[oSISJ00?oSISJ00Go0000ofb=hOm/SN7o0000ocQfh007o`000005oaMSf?m9Nn3o
BG_PodUkh?l000001?m^S=h00ol0003oWikCoinNd`04oinNd`;o00000_n]X/`00ol0003o_Zo:okj_
bP04okj_bP03o`000?o6/<Coa[3400?oa[3400?o0000omG1aooE`LL00_oE`LL00ol0003ofL;2omW2
`P04omW2`P03o`000?oVf<Oo000000Ooj=O400?o0000onc]b_o/kLX00_o/kLX01Ol0003oj^W=on[Y
cOoZjLgo000000?og_;L00Go0000omKWh_oFin;oe^ORo`000003olWHi005o`000?nia^Co^LKTokW6
i?l000000onX]>400ol0003oVJCMoiVTg@03oiVTg@03o`000?n<V=[oS9SJ00;oS9SJ00?o0000oh:>
eon2S]L00on2S]L00ol0003oNhWEo`000003o`0000CoGGoL00?o0000ooooooooool08_ooool00ol0
003oooooooooo`09ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0>Oooool5o`0000CoIX;J00?o0000og6:g?maR]`00_maR]`00ol0003o
PIOOoh6Gg`02oh6Gg`03o`000?nCY^;oTjKR00;oTjKR00?o0000ojNfi?nW]^@00_nW]^@00ol0003o
^LKTokW6i002okW6i005o`000?o9e>;obMCRolWDh_l000001?oEgml01Ol0003ogNSKomgXfooMj=_o
000000?oh^oH0_l00004onSRc003o`000?oXi<goj>C=00?oj>C=00?o0000on7?aooQclL01_oQclL0
0ol0003ogM3<o`000006om6la@05o`000?o;_<cobkc<ol^lc?l000001Onm[<P00ol0003o/Z[@ok:Z
d002ok:Zd003o`000?nQW]7o000000CoSISJ00?o0000ofb=hOm/SN400_l000000olKIMWo0000o`00
0003o`0000;o5f?H00Co0000odUkh?m9Nn3o00000om^S=h00ol0003oRISKo`000006oinNd`03o`00
0?n]X/co000000Oo_Zo:0_l00002olJ`a003o`000?oE`LOoeL7700CoeL7700?o0000omW2`_oI`/80
0_oI`/801?l0003oi]S7onKHaol00006onSGa0;o00001?o/kLX00ol0003oj^W=on[Yc@02o`0000?o
g_;L00Co0000omKWh_oFin;o00000oo9f>@01Ol0003o^LKTokW6i?nia^Co000000CoZ;CQ00?o0000
oiVTgOnIY=d00onIY=d01Ol0003oS9SJohbHf_n<V=[o000000GoPXkG00?o0000og^9eOl000000omk
RMD2o`0000?oGGoL00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`000oooool0
0ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0>?ooool4
o`000003of1nf_l0003oIX;J00?oIX;J00?o0000og6:g?maR]`00_maR]`00ol0003oPIOOoh6Gg`02
oh6Gg`05o`000?nCY^;oTjKRoi>Vh_l000001OnW]^@01Ol0003o^LKTokW6i?nia^Co000000CobMCR
00?o0000omGOgooEgml00_oEgml01Ol0003ogNSKomgXfooMj=_o000000;oh^oH00?o0000onGNcOl0
00001OoXh/`01ol0003oj>C=onSTcOoXi<go0000on;>a?l000002?oQclL00ol0003odKc5om6la@06
om6la@03o`000?o;_<co000000Oo_Jc800Co0000ok:Zd?nbZ]3o00000onQW]400ol0003oSISJohfH
fP02ohfHfP06o`000?m/SN7o0000odimh?l0003o6fGI1Ol00002oaMSf006o`000?m9Nn3oBG_Po`00
0?m^S=ko00000on9V=/2o`0000GoWikC00?o0000okj_b_nn[lX02?nn[lX00ol0003oa[34o`000007
omG1a`05o`000?oI`/;ofL;2omW2`_l000000ooVf<L00ol0003oj=O4onSGa002onSGa003o`000?o/
l<[o000000Cok>g:00Co0000on[YcOl0003o00000ooNl]`01Ol0003oe^ORomKWh_oFin;o000000?o
bMST00Go0000okW6i?nia^Co^LKTo`000004ojRdh@03o`000?nIY=goVJCM00;oVJCM00?o0000ohbH
f_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mkRMGo000000?oNhWE0_mhQmH2o`00
0003oeeog?l0003ooooo02?ooooo00?o0000ooooooooool02Oooool000?ooooo00?o0000oooooooo
ool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo0ol0000fooooo`?o00000_ooool2obi/
f`;o00001?mVP]X00ol0003oLH[Log6:g002og6:g003o`000?n1UmooPIOO00;oPIOO00Go0000oi>V
h_nCY^;oTjKRo`000004ojNfi003o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>80
1Ol0003oeMoOomGOgooEgmoo000000CogNSK00?o0000on;_f?l000000_oUg/d00ol0003oj>;<onSR
c003onSRc004o`000?oXi<goj>C=o`0000?oh/k400?o0000on7?aooQclL01OoQclL00ol0003oeKc1
o`000007om6la@03o`000?nm[<So_Jc800Oo_Jc800?o0000ok:Zd?l000001?nQW]42o`0000?oSISJ
0_l00002odimh003o`000?lKIMWo000000Co00000_lGHmP01?l0003oBG_PodUkh?l00006ohVHf`;o
00000onOW]<00ol0003o/ZcCo`000009okj_bP03o`000?oE`LOoeL7700OoeL7700?o0000omW2`_l0
00001OoVf<L01?l0003oj=O4onSGa?l00002onc`bP03o`000?o/kL[ok>g:00;ok>g:0_l000000ooQ
n]Go0000omkbg002omkbg005o`000?oFin;oe^ORomKWh_l000000oo9f>@01Ol0003o^LKTokW6i?ni
a^Co000000?oZ;CQ00?o0000oiVTgOnIY=d00onIY=d00ol0003oS9SJohbHfP02ohbHfP03o`000?n2
S]OoPXkG00?oPXkG00Ko0000og^9eOmkRMGo0000og^9eOl00004ogR7eP;o00009?ooool00ol0003o
ooooooooo`09ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<oooool3o`0000Gooooo0ol^K=/2o`0000?oIX;J00?o0000og6:g?maR]`0
0_maR]`01Ol0003oPIOOoh6Ggon1Umoo000000CoTjKR00?o0000ojNfi?nW]^@00_nW]^@00ol0003o
^LKTokW6i002okW6i003o`000?o9e>;obMCR00;obMCR00Go0000omGOgooEgmooeMoOo`000004omgX
f`;o00001?oUg/d00ol0003oj>;<onSRc002onSRc003o`000?oXi<go000000Goh/k400?o0000on7?
aooQclL00ooQclL01Ol0003oeKc1omFl`OoE_<7o000000KodKc500Co0000olB]`ol0003o00001onm
[<P00ol0003oXIkAoj6Nd@05oj6Nd@06o`000?n=V=[oSISJo`000?mcSMgo00000_m>ON000ol0003o
6fGIo`000004o`0000;o5f?H00Go0000odUkh?l0003oIh_Ro`000006ohVHf`03o`000?nOW]?o0000
00?o/ZcC00?o0000okj_b_nn[lX01_nn[lX2o`0000WoeL7700?o0000onKHaooVf<L01?oVf<L00ol0
003oj=O4o`000003onc`bP04o`000?o/kL[ok>g:onc]bP;o00000_oQn]D01Ol0003og_;Lomkbg?oN
l]co000000;oe^OR00Go0000olWHi?o9f>CobMSTo`000003okW6i003o`000?nX]>7oZ;CQ00;oZ;CQ
00?o0000oiVTgOnIY=d00_nIY=d00ol0003oS9SJohbHfP02ohbHfP03o`000?n2S]OoPXkG00?oPXkG
00?o0000og^9eOmkRMD00_mkRMD2o`0000GoN8OF00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`08ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo033ooooo0ol00008ooooo`03o`000?l^K=_o;VcK00;o=g7M0_l000000omVP][o0000
og6:g003og6:g005o`000?n1UmooPIOOoh6Ggol000001?nCY^800ol0003oYkKTojNfi002ojNfi003
o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>801Ol0003oeMoOomGOgooEgmoo0000
00?ogNSK0_l00005onGNc@03o`000?oXh/coj>;<00?oj>;<00?o0000on;>a?oRc/@01OoRc/@01Ol0
003ohLo7on7?aooQclOo000000GoeKc100?o0000om6laOoA_<D00_oA_<D00ol0003oa:g3olB]``02
olB]``;o00001Onm[<P01?l0003o[Z7:o`000?l00005oj6Nd@;o00000omcSMd2o`000004odimh?l0
003o0000o`1AcPCo000000?o5f?Ho`000?l000000omWRn82o`0000GoRISK00?o0000ok:/donb[=<0
0onb[=<2o`0000Go_Zo:00Co0000olg1c_o=`Lko00001ooE`LL2o`0000Ooi]S700?o0000onc`b_o/
l<X00_o/l<X02?l0003ok>g:onc]b_l0003og_g?o`000?oQn]Go00000ooNl]`01Ol0003oe^ORomKW
h_oFin;o000000?obMST00Go0000okW6i?nia^Co^LKTo`000003ojRdh@03o`000?nIY=goVJCM00?o
VJCM00?o0000ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mkRMGoNhWE00?o
NhWE00?o0000ogR7e_mhQmH00omhQmH00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00So
oooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0]ooooo`?o
00003?ooool3obi/f`?o=g7M0_l00003og6:g003o`000?n1UmooPIOO00;oPIOO00?o0000oi>Vh_nC
Y^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co^LKT00;o^LKT00?o0000olWDh_o9
e>800_o9e>801_l0003oeMoOomGOgooEgmoo0000omgXf`;o000000?oh=_Ao`000?oUg/d01?oUg/d0
0ol0003oj>;<onSRc002onSRc0;o00002?oRc/@00ol0003ohLo7o`000007omFl`@04o`000?oA_<Go
dKc5o`0000Ooa:g300Go0000okf/b?nm[<So_Jc8o`000004ojjQbP;o00001?nQW]42o`0000CoLhgM
00Go0000odimh?l0003o0000o`1AcP04o`0000;o<g?O00?o0000ofN;h_mWRn800_mWRn801Ol0003o
RISKohVHfon9V=_o000000;oWJOM00?o0000ok:/donb[=<00onb[=<01Ol0003o_Zo:okj_b_nn[l[o
000000CocL7>00?o0000omG1aooE`LL00ooE`LL01?l0003oh]W>on;Ic_l00006onKHa`03o`000?o/
l<[ok?3:00;ok?3:00Go0000onc]b_l0003og_g?o`000002on7je@05o`000?oNl]cog_;Lomkbg?l0
00000ooFin801Ol0003obMSTolWHi?o9f>Co000000?o^LKT00Go0000ojRdhOnX]>7oZ;CQo`000005
oiVTg@05o`000?n<V=[oS9SJohbHf_l000001_n2S]L00ol0003oNhWEog^9e@02og^9e@;o00001?mh
QmH00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooo
oooo02[ooooo0ol0000?ooooo`03o`000?l^K=_o;VcK00Co=g7M0_l00002og6:g003o`000?n1Umoo
PIOO00;oPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co
^LKT00;o^LKT00?o0000olWDh_o9e>800_o9e>801?l0003oeMoOomGOgooEgml2o`0000?oh=_A00?o
0000onGNcOoUg/d00ooUg/d01Ol0003oj>;<onSRc?oXh/co000000;oh/k400?o0000on;>a?oRc/@0
1_oRc/@2o`0000SoeKc100?o0000om6laOl000002?o4[L<2o`000003okf/b?l0003o[Z7:00Go[Z7:
00Oo0000oj6NdOnQW]7oXIkAo`000?n<UMSo000000CoLhgM0_l000001olSK=go0000o`1Ac_l0003o
012Do`000?l0D<d00_lcLml00ol0003oIh_RofN;hP02ofN;hP03o`000?n9V=_o000000CoWJOM00?o
0000ok:/donb[=<00onb[=<00ol0003o_Zo:o`000006olg1cP05o`000?oE`LOoeL77omG1aol00000
1?oRfLh00ol0003oi]S7onKHa`02onKHa`;o00001?o/l<X2o`0000;og_g?00Co0000on7jeOoQn]Go
00000ooNl]`01Ol0003oe^ORomKWh_l0003obMST00Wo00000_nX]>400ol0003oVJCMoiVTg@02oiVT
g@03o`000?n<V=[oS9SJ00;oS9SJ00?o0000oh:>eon2S]L00on2S]L00ol0003oNhWEog^9e@03og^9
e@03o`000?mhQmKo000000?oN8OF00?o0000ooooooooool09?ooool00ol0003oooooooooo`08oooo
o`006Oooool2o`0002Sooooo0ol0000Booooo`04o`000?l^K=_o;VcKo`0000?o=g7M0_m;O^83o`00
00CoPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003oYkKTojNfi002ojNfi003o`000?nia^Co^LKT
00;o^LKT00Go0000olWDh_o9e>;obMCRo`000003omGOg`;o00001OoPfm400ol0003oiMk=onGNc@02
onGNc@04o`000?oXh/coj>;<o`0000Coh/k400?o0000on;>a?oRc/@01OoRc/@00ol0003oekboo`00
0008omFl`@03o`000?o4[L?oa:g300Woa:g300?o0000ojjQb_n^XLX01_n^XLX3o`0000?oS9GH0_l0
0003og>=g@;o000000[o8fcMo`000?l0003o0000o`0@U?l0003o053=o`000?lcLmoo00000omWRn82
o`0000KoWJOM00?o0000ok:/donb[=<00onb[=<2o`0000OocL7>00?o0000omG1aol000001OoRfLh0
1ol0003oi]S7onKHaooVf<Oo0000onWbc_l000001?o/l<X01?l0003og_g?omkmcol00002on7je@06
o`000?oNl]cog_;Lomkbg?l0003oe^OR1?l00002olCHj005o`000?nia^Co^LKTokW6i?l000000_n]
]]l3o`0000CoVJCM00?o0000ohbHf_n<V=X00_n<V=X00ol0003oPXkGoh:>e`03oh:>e`03o`000?mk
RMGoNhWE00;oNhWE00Oo0000ogR7e_mhQmKoN8OFo`000?mhQmKo000002Oooooo00?o0000oooooooo
ool02?ooool001Wooooo00?o0000ooooooooool09?ooool3o`0001Kooooo00?o0000obi/fol^K=/0
0olgLMd01?l0003oBgkRod]nh_m;O^82o`0000?oPIOO00?o0000oi>Vh_nCY^800_nCY^800ol0003o
YkKTojNfi002ojNfi005o`000?nia^Co^LKTokW6i?l000001?o9e>801_l0003oeMoOo`000?l0003o
f=KGo`0000Goh=_A00?o0000onGNcOoUg/d00ooUg/d2o`0000Koh/k400?o0000on;>a?oRc/@00ooR
c/@01Ol0003oekboomNl_ooG_;oo000000OoeKc100?o0000olV^_ol000002Oo4[L<01?l0003o]Z?5
o`000?l00007ojjQbP;o00001?n<UMP2o`000004og>=gOl0003oC87So`0000;o8fcM0_l000002?l0
49Co0000o`000?l0003o<g?Oo`000?mWRn;o00000omjVnH00ol0003oWJOMoifWg@03oifWg@05o`00
0?nb[=?o/ZcCok:/dol000000_o0_mP00ol0003ocL7>olg1cP05olg1cP03o`000?oRfLkoh]W>00Go
h]W>00?o0000onKHaol000000ooYl/h00ol0003ok?3:onc`bP02o`0000;og_g?00Co0000on7jeOoQ
n]Go00000_oNl]`3o`0000;oc>WZ00Co0000olCHj?o4f>So00000onia^@00ol0003o[KKOojffg`02
ojffg`03o`000?nSZ=[o000000;o000000?oVJCMo`000?n<V=X00_n<V=X00ol0003oPXkGoh:>e`03
oh:>e`03o`000?mkRMGoNhWE00?oNhWE00?o0000ogR7e_mhQmH00_mhQmH2o`0002Oooooo00?o0000
ooooooooool02?ooool001Sooooo00?o0000ooooooooool08_ooool3o`0001Wooooo00Co0000obi/
fol^K=_o00000olgLMd3od]nhP;oIY7W1?l00003oi>VhP03o`000?nW]^CoYkKT00;oYkKT00?o0000
okW6i?nia^@00_nia^@00ol0003obMCRolWDhP02olWDhP;o00000ooHe]L00ol0003oh=_Aon3Kd@03
on3Kd@03o`000?oUg/goiMk=00?oiMk=00?o0000on;>a?oRc/@01OoRc/@00ol0003oh/k4on;>a002
on;>a003o`000?oG_;ooekbo00?oekbo00?o0000omFl`OoE_<400ooE_<401?l0003obJjoolV^_oo9
[[l2o`0000Koa:g300?o0000okJSaOnfXlD00_nfXlD2o`0000Go[Z7:00Co0000oibJd_l0003o0000
1?n<UMP2o`0000;oC87S0_l000000olSK=go0000o`000002o`000004o`1Je?l0003o0000o`0000Go
NY_V00?o0000oifWgOnMYmd00onMYmd00ol0003o/ZcCo`000004ol2of003o`000?o=`LkocL7>00?o
cL7>0_l00008on;IcP03o`000?oYl/kojO;>00;ojO;>00Co0000onc`b_l0003o00000ooNoLl00ol0
003ohO[Eon7je@03o`000005ologiol0003oc>WZolcYj_l000000_o4f>P01Ol0003o^LKTokW6i?ni
a^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X2o`0000?oS9SJ00?o0000oh:>eon2S]L00on2
S]L00ol0003oNhWEog^9e@02og^9e@03o`000?mhQmKoN8OF00?oN8OF00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`0Pooooo`;o00007?ooool0
1?l0003o;VcKobi/fol00003ocMag@04o`000?m;O^;oBgkRo`0000CoIY7W0_l00002oi>VhP03o`00
0?nW]^CoYkKT00;oYkKT00?o0000okW6i?nia^@00_nia^@00ol0003obMCRolWDhP03o`0000Gof=KG
00?o0000on3KdOoPfm400_oPfm400ol0003oiMk=onGNc@02onGNc@;o00002?oRc/@01Ol0003oh/k4
on;>a?oRc/Co000000Koekbo00?o0000omFl`OoE_<400_oE_<400ol0003obJjoolV^_`03olV^_`03
o`000?o4[L?oa:g300?oa:g300?o0000okJSaOnfXlD01?nfXlD01Ol0003o[Z7:ojjQb_n^XL[o0000
00CoW9[B0_l00003ohbEf0;o00000om<PN<2o`000006o`1Hd?l0003o0000o`000?l0F]Co00000_m4
P^H00ol0003oNY_VogZKiP02ogZKiP03o`000?nMYmgoWJOM00?oWJOM00?o0000ol2of?o0_mP01?o0
_mP01Ol0003ocL7>olg1c_o=`Lko000000;ofMWH00?o0000on;Ic_oRfLh00ooRfLh00ol0003ohoCG
o`000004onWbcP;o000000Kof?o=o`000?oNoLoog_g?o`000?oQn]D2o`0000?ocoOW00Co0000olcY
j_o<jN[o00000oo4f>P01?l0003o^LKTokW6i?l00004ojffg`03o`000?nSZ=[oXjSJ00CoXjSJ00Ko
0000oiZNe_l0003o0000ohbHf_l00005oh:>e`03o`000?mkRMGoNhWE00;oNhWE00?o0000ogR7e_mh
QmH00omhQmH2o`0002Sooooo00?o0000ooooooooool01oooool001Sooooo00?o0000ooooooooool0
7Oooool3o`0001oooooo00Co0000obi/fol^K=_o00000_lgLMd01?l0003oBgkRod]nh_m;O^84ofJA
i`;oQJGY0ol00004ojNfi003o`000?nia^Co^LKT00Go00000_o;d=d00ol0003of=KGomSFe`03omSF
e`03o`000?oPfm7oh=_A00;oh=_A00Go0000onGNcOoUg/goiMk=o`000002on3=aP03o`000?oRc/Co
h/k400Koh/k400?o0000on;>a?l000002?oG_;l01?l0003oeKc1omFl`Ol00007olV^_`;o00000_o4
[L<00ol0003o]Z?5okJSa@06okJSa@;o000000?o[Z7:o`000?nLV]801OnLV]801Ol0003oS9GHohbE
f?l0003oK8oS00;o00000_m<PN<2o`000003o`1Hd?l04I3o000000?o00000_m4P^H00ol0003oNY_V
ogZKiP02ogZKiP04o`000?nMYmgo0000o`0000;oZ[WT00?o0000ol2of?o0_mP01?o0_mP00ol0003o
cL7>o`000004omWIf005o`000?oRfLkoh]W>on;Ic_l000000_oSm=L01?l0003ojO;>onWbc_oYl/h2
o`0000;of?o=00?o0000omkmcooNoLl00_l000001Oo9o^3o0000ologioo?mnOo000000;oc>WZ00Go
0000olCHj?o4f>Soa=SXo`000003okW6i003o`000?n]]]oo[KKO00;o[KKO00?o0000oj>Xf_nSZ=X0
0onSZ=X00ol0003oVYkFoiZNeP02oiZNeP;o00001?n2S]L00ol0003oNhWEog^9e@03og^9e@03o`00
0?mhQmKoN8OF00;oN8OF00Co0000oooooooooooo00009oooool00ol0003oooooooooo`07ooooo`00
6?ooool2o`0001_ooooo0ol0000Rooooo`04o`000?l^K=_o;VcKo`0000?o=g7M00Co0000od]nh_m;
O^;o00000omVTNL01?l0003oQJGYohFUjOn5YNT8o`0000;o^LKT00?o0000ol_@gOo;d=d00_o;d=d0
0ol0003of=KGomSFe`03omSFe`03o`000?oPfm7oh=_A00?oh=_A00?o0000onGNcOl000001?oPcLH0
0ol0003oh/k4on;>a006on;>a0;o00002OoG_;l00ol0003oeKc1o`000009olV^_`03o`000?o4[L?o
000000[o]Z?50_l00007oibJdP?o00000om/Sn<2o`000006odb1hol0003o0000o`1Hd?l0003o01fK
0ol00002odB2iP03o`000?mjVnKoNY_V00?o00001OnZ^N@00ol0003o`;oHol2of004ol2of003o`00
0?oIfMSofMWH00CofMWH00?o0000on;Ic_l000000ooSm=L02Ol0003ojO;>onWbc_l0003oc_o>o`00
0?oHolgo0000omkmc`02o`0000;obOkP00Co0000ologioo?mnOo00000oo<jNX01?l0003oa=SXolCH
j?l00003okW6i003o`000?n]]]oo[KKO00;o[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0003oVYkF
oiZNeP03oiZNeP04o`000?nCU]Co0000o`0000;oPXkG00?o0000og^9eOmkRMD00_mkRMD00ol0003o
N8OFogR7eP03ogR7eP04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool01oooool001So
oooo00?o0000ooooooooool05oooool3o`0002Gooooo00Go0000obi/fol^K=_o;VcKo`000002ocMa
g@04o`000?m;O^;oBgkRo`0000CoIY7W0on5YNT5oj:hj0Go^LKT00?o0000ol_@gOo;d=d00oo;d=d0
0ol0003of=KGomSFe`02omSFe`03o`000?oPfm7oh=_A00?oh=_A0_l00006on3=aP03o`000?oRc/Co
h/k400Goh/k400?o0000omRm_ol000002OoG_;l00ol0003obJjoolV^_`09olV^_`03o`000?nfXlGo
]Z?500Wo]Z?500Co0000ojNNcOl0003o00001onLV]82o`0000CoK8oS0_l000001olDLn7o0000o`00
0?l0003o01fKo`000?l0GmH01Ol00002oh>[k`03o`000?nZ^NCoZ[WT00CoZ[WT00Oo0000ol2of?o0
_mSo`;oHo`000?o9enCo000000OofMWH00?o0000on?deooSm=L00_oSm=L01Ol0003ojO;>o`000?o>
olko000000;of?o=0_l000001?nloMKo0000olWnh?l00002ologi`05o`000?o<jN[oc>WZolcYj_l0
00000_o4f>P01Ol0003o^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0
003oVYkFoiZNeP03oiZNeP03o`000?nCU]CoTiKD00;oTiKD00?o0000oh:>eol000001?mkRMD00ol0
003oN8OFogR7eP03ogR7eP05o`000?ooooooooooooooool000009_ooool00ol0003oooooooooo`07
ooooo`006?ooool00ol0003oooooooooo`0Dooooo`?o0000:Oooool01?l0003o;VcKobi/fol00002
ocMag@05o`000?m;O^;oBgkRod]nh_l000000omVTNL01?l0003oQJGYohFUjOn5YNT4oj:hj003o`00
0?nia^Co^LKT00?o^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`03omSFe`03o`00
0?oPfm7oh=_A00;oh=_A00?o0000on3=a_oPcLH01_oPcLH00ol0003oh/k4on;>a003on;>a005o`00
0?oH_Koof;foomRm_ol000002?oG_;l01?l0003objnno`000?l00008olV^_`03o`000?nlYL;o0000
00;o00001onfXlD01?l0003oYik=ojNNcOnWW/d3o`0000CoW9[B00Co0000oh>Ih?l0003o00001?m/
Sn<2o`000004oaAchOl0003o0000o`0MV`?o00000_m6SNd01Ol0003oPj__oh>[kon3Znoo000000Ko
Z[WT00?o0000ol2of?l000000oo9en@00ol0003ofMWHomWIf002omWIf003o`000?oFmN?o000000Co
hoCG0_l00002olkocP08o`000?oHolgof?o=o`000?nloMKo0000olWnh?l00002ologi`05o`000?o<
jN[oc>WZolcYj_l000000oo4f>P01Ol0003o^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nS
Z=X00onSZ=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD0_l00003og^9e@03
o`000?mhQmKoN8OF00?oN8OF00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo000Gooooo`03o`000?oooooooooo01;ooooo0ol0000/ooooo`04o`00
0?l^K=_o;VcKo`0000?o=g7M00Co0000od]nh_m;O^;o00000omVTNL01Ol0003oQJGYohFUjOn5YNWo
000000CoX[SX00?o0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oo
f=KG00?of=KG00?o0000on3KdOoPfm400_oPfm400ol0003oh<g6on3=aP06on3=aP03o`000?oRc/Co
h/k400;oh/k400?o0000omRm_ooH_Kl00ooH_Kl00ol0003oekboomNl_`04omNl_`03o`000?o;[kko
bjnn00;objnn0_l00005olV^_`03o`000?nlYL;o_:G200?o_:G20ol00003okJSa@03o`000?nWW/go
Yik=00GoYik=0_l00002oibJdP04o`000?n3VN3oPiWPoh>Ih0?o000000?oK8oSo`000?ljRnd01_l0
00001Ol0Fm7o0000odJ=kOm6SNgo000000?oPj__00?o0000ojZii?nZ^N@00onZ^N@2o`0000GobMOT
00Co0000omWIf?oIfMSo00000_oFmN<01?l0003ohoCGon?deooSm=L2o`0000;oc_o>00So0000omSo
cOl0003o0000okcme_l0003obOkPo`0000?ocoOW00Co0000olcYj_o<jN[o00000oo4f>P01Ol0003o
^LKTokW6i?nia^Co000000Co[KKO00?o0000oj>Xf_nSZ=X00onSZ=X00ol0003oVYkFoiZNeP02oiZN
eP03o`000?nCU]CoTiKD00GoTiKD00?o0000ohjBd_l000000_mkRMD00ol0003oN8OFogR7eP03ogR7
eP03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`005oooool00ol0003oooooooooo`0?ooooo`?o0000;oooool01Ol0003o;VcKobi/fol^K=_o0000
00;o=g7M00Co0000od]nh_m;O^;o00000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000CoX[SX00?o
0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oof=KG00?of=KG00Oo
0000on3KdOoPfm7oh=_Ao`000?oLc<[o000000Soh<g600Go0000on;>a?oRc/Coh/k4o`000006omRm
_`03o`000?oG_;ooekbo00;oekbo00?o0000ol^___o;[kh01Oo;[kh2o`0000?obJjo00?o0000okbU
`_nlYL801_nlYL84o`0000WoYik=0ol00006oh>Ih0?o00000_ljRnd5o`000005o`1KdOl0003o0000
odJ=kOl000000on3Znl00ol0003oZ[WTo`000002o`000003ojc?l_l0003obMOT00CobMOT00?o0000
omWIf?l000001?oFmN<01Ol0003ohoCGo`000?nno]Go000000;oc_o>0_l00002okcmeP04o`000?o9
o^3obOkPo`0000;ocoOW00Go0000olcYj_o<jN[oc>WZo`000002olCHj005o`000?nia^Co^LKTokW6
i?l000001?n]]]l00ol0003oXjSJoj>XfP03oj>XfP03o`000?nJW]KoVYkF00;oVYkF00?o0000oi>F
e?nCU]@01OnCU]@01ol0003oSY;BohjBd_n>T];o0000og^9eOl000001?mhQmH00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001Oooooo0_l0000=
ooooo`?o0000<oooool2o`000005obi/fol0003o=g7MocMagOl000000om;O^801Ol0003oIY7WofJA
iomVTNOo000000?oQJGY00Go0000oj:hj?nR^>SoX[SXo`000005okW6i003o`000?o;d=gobm3M00;o
bm3M00?o0000omSFeooHe]L00_oHe]L01?l0003oh=_Aon3KdOl00003omc<bP03o`000?oPcLKoh<g6
00Koh<g600?o0000on;>a?l000002?oH_Kl01Ol0003oekboomNl_ooG_;oo000000Wobjnn0_l00000
0oo9[[oo0000okbU`P0:okbU`P;o00002_nWW/d2o`0000OoPiWP0_l00003ocZ;k@Go00000_lfT>l6
o`0000Go[<ob00?o0000olWGi?o9en@00oo9en@00ol0003oe_GSomKeh`03omKeh`;o000000?o__kE
o`000?o>olh00ol00002okcmeP04o`000?o9o^3obOkPo`0000;ocoOW00Go0000olcYj_o<jN[oc>WZ
o`000003olCHj004o`000?nia^Co^LKTo`0000Go[KKO00?o0000oj>Xf_nSZ=X00_nSZ=X00ol0003o
VYkFoiZNeP03oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]800on>T]82o`0000Co
N8OF00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Ko
oooo000Gooooo`03o`000?oooooooooo00Wooooo0ol0000fooooo`;o05?>0_l00003ocMag@04o`00
0?m;O^;oBgkRo`0000?oIY7W00Go0000ohFUjOn5YNWoQJGYo`000004oj:hj003o`000?nia^Co^LKT
00;o^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`03omSFe`;o00001OoLc<X00ol0
003oh<g6on3=aP06on3=aP;o00002OoH_Kl00ol0003oekboo`00000<ol^__P03o`000?nlYL;o_:G2
00[o_:G200?o0000ojjQb_l000000_l00007ojNNc@03o`000?nCWmco000000;o00001?n3VN001?l0
003oFikco`000?l00003ocZ;k@Go000000?o=Y3_o`000?mk^OX00omk^OX00ol0003o[<obojc?lP03
ojc?lP06o`000?o9enCo0000o`000?nnl?;o00001OoFmN<00ol0003o__kEokkne@02o`000005ojSg
cOl0003o_?gFokcme_l000000_o9o^001?l0003ocoOWologiol00003olcYjP05o`000?o4f>Soa=SX
olCHj?l000000onia^@00ol0003o[KKOojffg`02ojffg`03o`000?nSZ=[oXjSJ00?oXjSJ00?o0000
oiZNe_nJW]H00_nJW]H00ol0003oTiKDoi>Fe004oi>Fe003o`000?n>T];oSY;B00CoSY;B00?o0000
ohb@dol000000_mhQmH00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01_ooool001Oooooo00?o0000ooooooooool01_ooool3o`0003[ooooo0ol0Dlh2o`00
0005ocMagOl0003oBgkRod]nh_l000000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000CoX[SX00?o
0000okW6i?nia^@00_nia^@00ol0003obm3Mol_@g@02ol_@g@03o`000?oHe]Oof=KG00;of=KG0_l0
0007omc<bP03o`000?oPcLKoh<g600Coh<g600Co0000omNn`OoG_/7o00002OoH_Kl00ol0003objnn
ol^__P0;ol^__P03o`000?noYl7o000000;o00002?nlYL800ol0003o[Z7:ojjQbP02ojjQbP?o0000
1?nWW/d00ol0003oTioLoi>Og002oi>Og0;o00000_n3VN001?l0003oFikcoe^NlomKW_<4o`000003
o`63gOl0003o000000Co00001?mk^OX01ol0003o[<obojc?l_n/co;o0000ojc?l_l000001?nnl?85
o`0000?o__kE00?o0000ojSgcOl000000_nloMHAo`000003okW6i?l0003o[KKO00?o[KKO00?o0000
oj>Xf_nSZ=X00onSZ=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000
ohjBd_n>T]801?n>T]801ol0003oS93Cohb@don<T=?o0000ogR7e_l000002oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo000Gooooo`03o`000?oooooooooo00?ooooo0ol0
000nooooo`;o05?>0_l0Fm<2o`0000?oBgkR00Co0000ofJAiomVTNOo00001?n5YNT01Ol0003oX[SX
oj:hj?nR^>So000000Co^LKT00?o0000ol_@gOo;d=d00_o;d=d00ol0003of=KGomSFe`02o`000003
omG<d?l0003og<c:00Kog<c:00?o0000on3=a_oPcLH00ooPcLH00ol0003oekk1omNn`@02omNn`@03
o`000?oH_Koof;fo00Kof;fo00?o0000olfa__l000000_l00008ol^__P03o`000?noYl7o_jO100?o
_jO10_l00006okbU`P03o`000?n^XL[o[Z7:00Go[Z7:1?l00007oi>Og0Co00001OmKW_<2o`0000?o
0H?M0_l000000ol?PnCo0000o`000006o`0000;oU=kn00?o0000okk`l_nnl?800_nnl?801Ol0003o
Y_SOojKhgol0003o__kE00?o000000?oZ?O=o`000?l000001?l00002oko^lP05o`000?o1h^oo`N;_
ol7Rkol000000onne>X01?l0003o^<KTokS6i?nha^@3o`0000Co[KKO00?o0000oj>Xf_nSZ=X00_nS
Z=X00ol0003oVYkFoiZNeP02oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]801?n>
T]800ol0003oS93Cohb@d`03ohb@d`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`06ooooo`005_ooool01?l0003oooooooooooooool3o`0004;ooooo0_l0
Dlh2o`1Kd`05ocMagOl0003oBgkRod]nh_l000000omVTNL01Ol0003oQJGYohFUjOn5YNWo000000?o
X[SX00?o0000okW6i?nia^@00onia^@00ol0003obm3Mol_@g@02ol_@g@;o00001?oEc=000ol0003o
g<c:omc<bP05omc<bP05o`000?oPcLKoh<g6on3=a_l000001_oG_/42o`0000Gof;fo00?o0000olfa
__o=/Kh00oo=/Kh2o`0000Kobjnn00?o0000oknW`OnoYl401OnoYl42o`0000?o_:G200?o0000ojjQ
b_n^XLX02On^XLX3o`0000SoTioL1?l00004oe^Nl`?o00000_l1Pmd3o`0000?oE[Wk00?o0000oiCN
o_nDg_h00_nDg_h4o`000003oh3Wj_l0003o000000Wo00000_nemO401?l0003o_nkboko^l_l00003
ol7Rk`05o`000?nne>[o_]CZokkDj_l000000onha^@01?l0003o/[WOok:igonb^Ml2o`000003ojff
gol0003oXjSJ00CoXjSJ00Go0000oiZNe_nJW]KoVYkFo`000006oi>Fe003o`000?n>T];oSY;B00Co
SY;B00?o0000ohb@don<T=<01?n<T=<00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool001Kooooo1?l00016ooooo`;o05?>0_l0Fm<2o`000003od]n
h_l0003oIY7W00;oIY7W00Go0000ohFUjOn5YNWoQJGYo`000004oj:hj003o`000?nia^Co^LKT00;o
^LKT00Co0000ol_@gOo;d=gobm3M0_l00006omG<d003o`000?oLc<[og<c:00Gog<c:00?o0000on3=
a_l000002OoG_/400ol0003of;foomRm_`02omRm_`03o`000?o=/KkocK6n00GocK6n0_l00004ol^_
_P03o`000?noYl7o_jO100Oo_jO11?l0000;ojjQbP03o`000?nOY=WoWjCI00Co00001?nCWm`01?l0
003oMjcdogN/m?mg[?@6o`000003obNQk?l0003o000000co00000on0inX2o`000003og3Na?l0003o
000000?o000000?oXOC/o`000?l000000_nemO401?l0003o_nkboko^l_l00003ol7Rk`05o`000?nn
e>[o_]CZokkDj_l000000onha^@00ol0003o/[WOok:ig`03ok:ig`?o00001?nSZ=X00ol0003oVYkF
oiZNeP02oiZNeP03o`000?nCU]CoTiKD00?oTiKD00?o0000ohjBd_n>T]801?n>T]800ol0003oS93C
ohb@d`04ohb@d`03o`000?oooooooooo00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`005_ooool2o`0004Wooooo0_l0Dlh01_l0Fm?o677QoaQahOl0003oBgkRo`0000;o
IY7W00?o0000ohFUjOn5YNT00_n5YNT01Ol0003oX[SXoj:hj?nR^>So000000Co^LKT00Ko0000ol_@
gOo;d=go0000ol_9fOl00007omG<d003o`000?oLc<[og<c:00Gog<c:0_l0000:omNn`@04o`000?oH
_Koof;foo`0000[ocK6n1?l0000=oknW`@03o`000?n^XL[o[Z7:00Wo[Z7:00?o0000oinTfOnOY=T0
1?nOY=T4o`000003oi>Og?l0003oMjcd00KoMjcd6Ol00002oj7dk003o`000?nemO7o]OGa00;o0000
0_nok_801Ol0003o`N;_ol7Rkoo1h^oo000000?o_]CZ00Go0000okS6i?nha^Co^<KTo`000005ok:i
g`04o`000?n/[m[o[:oJojb_fP;o000000?oXjSJo`000?nJW]H00onJW]H00ol0003oTiKDoi>Fe004
oi>Fe003o`000?n>T];oSY;B00?oSY;B00?o0000ohb@don<T=<01?n<T=<00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool000cooooo1?l000000ol@
413oooooooooo`05ooooo`03o`000?oooooooooo04Oooooo0_l0Dlh01?l0Fm?o677QoaQahOlHLN42
o`000003ofJAiol0003oQJGY00?oQJGY00Go0000oj:hj?nR^>SoX[SXo`000005okW6i0;o00000oo;
bMT00ol0003oeLc@omG<d005omG<d003o`000?oLc<[og<c:00Cog<c:00?o0000omBoa_l000002_oG
_/400ol0003of;foo`00000=olfa_P03o`000?noYl7o_jO100_o_jO100?o0000okBTb?ndY<P01?l0
0005ojjQbP03o`000?nOY=WoWjCI00SoWjCI2?l00003ogN/m003o`000?m=_?SoCKch00;oCKch1ol0
00000oln`]3o0000o`000006o`0000?oXOC/00Co0000okGelOnemO7o00000onok_801Ol0003o`N;_
ol7Rkoo1h^oo000000?o_]CZ00Go0000okS6i?nha^Co^<KTo`000005ok:ig`03o`000?n/[m[o[:oJ
00?o[:oJ0ol00003oiZNeP03o`000?nCU]CoTiKD00CoTiKD00?o0000ohjBd_n>T]800on>T]800ol0
003oS93Cohb@d`04ohb@d`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Oo
oooo00?o05?>o`000?l0Fm<00_lHLN401Ol0003oAXo^o`000?mVTNOo000000?oQJGY00?o0000oj:h
j?nR^>P00_nR^>P00ol0003o^LKTokW6i003o`0000GoblWI00?o0000omG<d?oEc=001?oEc=000ol0
003og<c:omc<bP03omc<bP05o`000?oD_lKoe;o6omBoa_l000002_oG_/400ol0003ocK6nolfa_P0<
olfa_P03o`000?o2ZL7o`ZW100?o00002?noYl400ol0003o]:C8okBTb004okBTb0Co000000?o[Z7:
o`000?nOY=T02_nOY=T00ol0003oS;KbohbflP04ohbflQ7o000000CoHmWIo`000?l0003oQN_S0_l0
0002oj7dk0;o00000_nemO401Ol0003o_nkboko^l_nok_;o000000?o`N;_00?o0000okkDj_nne>X0
0_l00003okS6i003o`000?nb^Moo/[WO00?o/[WO00?o0000ojb_f_n/[mX00on/[mX01ol0003oYZOG
ojJWeonVYmOo0000oiZNe_l000001_nCU]@00ol0003oSY;BohjBdP03ohjBdP03o`000?n<T=?oS93C
00CoS93C00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo000>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0A_ooool01?l0003o
05?>o`000?l0Fm<2oaQah@03o`000?m6SnkoAXo^00co00000_niaN<00ol0003oblWIol_9f@04ol_9
f@03o`000?oEc=3oeLc@00CoeLc@00Go0000omc<b_oLc<[og<c:o`000005omBoaP;o00002?oG_/40
1?l0003ocK?0o`000?l0000:olfa_P03o`000?o2ZL7o`ZW100Co`ZW10ol00004oknW`@03o`000?nd
Y<So]:C800Wo]:C82Ol00005oinTf@03o`000?n<]_;oS;Kb00SoS;Kb00?o0000og3?o_m`coh01?m`
coh;o`000003oj7dk?l0003o]OGa00;o]OGa00Go0000oko^l_nok_;o_nkbo`000003ol7Rk`04o`00
0?nne>[o_]CZo`0000Co^<KT00?o0000ok:igonb^Ml00_nb^Ml2o`0000Go[:oJ00?o0000ojJWeonV
YmL00_nVYmL3o`0000GoTiKD00?o0000ohjBd_n>T]801?n>T]800ol0003oS93Cohb@d`03ohb@d`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00
3_ooool00ol0003oooooooooo`0:ooooo`;o0000Aoooool01?l0003o05?>o`000?l0Fm<2oaQah@03
o`000?m6Snko000000CoMj[b00Go0000oijlkOnN_>goW[c]o`000005okW5h`03o`000?o;bMWoblWI
00?oblWI00?o0000omG<d?oEc=001OoEc=000ol0003og<c:o`000008omBoaP03o`000?oG_/7oekk1
00Coekk100?o0000olfc`?o=/l000_o=/l02o`0000SocK6n00?o0000ol:Y`Oo2ZL401oo2ZL43o`00
0003oknW`Ol0003o]:C800_o]:C800?o0000ojRXeonXZ=L01OnXZ=LGo`0000CoS=_o0ol00003oj3O
o0Co000000?o]OGao`000?nok_800_nok_801Ol0003o`N;_ol7Rkoo1h^oo000000;o_]CZ00?o0000
okS6i?nha^@00_nha^@00ol0003o/[WOok:ig`02ok:ig`03o`000?n/[m[o[:oJ00?o[:oJ0_l00004
ojJWe`05o`000?nQX]GoXJ;Eoj6ReOl000000onCU]@00ol0003oSY;BohjBdP04ohjBdP03o`000?n<
T=?oS93C00?oS93C00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Gooooo000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0AOooool0
1?l0003o05?>o`000?l0Fm<2oaQah@03o`000?m6Snko000000CoMj[b00Go0000oijlkOnN_>goW[c]
o`000005okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=001OoEc=02o`0000Woe;o6
0_l00004omNn`@03o`000?o=/l3ocK?000CocK?00_l00005olfa_P03o`000?o2ZL7o`ZW100_o`ZW1
0_l0000<okBTb003o`000?nXZ=OoZ:SG00[oZ:SG00?o0000oi^lkonK_>l02OnK_>l00ol0003oS=_o
ohcKo`04ohcKo`?o00000onPgo`3o`0000?o[]kh1?l000000onok_;o0000ol7Rk`02ol7Rk`04o`00
0?nne>[o_]CZo`0000Co^<KT00?o0000ok:igonb^Ml00_nb^Ml00ol0003o[:oJojb_fP03ojb_fP03
o`000?nVYmOoYZOG00?oYZOG00?o0000oj6ReOnQX]D00onQX]D00ol0003oTiKDo`000006ohjBdP03
o`000?n<T=?oS93C00?oS93C00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
AOooool01?l0003o05?>o`000?l0Fm<2oaQah@03o`000?m6Snko000000CoMj[b00Go0000oijlkOnN
_>goW[c]o`000005okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=001?oEc=000ol0
003od<;<o`00000:omBoaP04o`000?oG_/7oekk1o`0000WocK?00_l00003olfa_P03o`000?o2ZL7o
`ZW100co`ZW100?o0000okRWb?nhYlP01Ol00005okBTb003o`000?nXZ=OoZ:SG00[oZ:SG00?o0000
oi^lkonK_>l02_nK_>l00ol0003oS=_oohcKo`03o`0000?oX=ol0ol00003ojkNn0?o00000onff_<4
o`000005ol7Rkol0003o_]CZokkDj_l000001?nha^@00ol0003o/[WOok:ig`02ok:ig`03o`000?n/
[m[o[:oJ00?o[:oJ00?o0000ojJWeonVYmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@?o00001On>
T]800ol0003oS93Cohb@d`03ohb@d`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`05ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04Gooooo0_l000001?l0Fm?o0000oaQahOl00002odJ?kP03o`000?mgZ_;oMj[b00;oMj[b00Go
0000oijlkOnN_>goW[c]o`000004okW5h`03o`000?o;bMWoblWI00?oblWI00?o0000omG<d?oEc=00
0ooEc=001?l0003od<;<om32c?o@`/`2o`0000Woe;o600?o0000omNn`Ol000002oo=/l02o`000003
olfa__l0003o`ZW100co`ZW100?o0000okRWb?nhYlP01_nhYlP4o`000003okBTb?l0003oZ:SG00co
Z:SG00?o0000oi^lkonK_>l01?nK_>l8o`0000CoX=ol0_l00004ojkNn0;o00001?nff_<2o`0000?o
^MC]0ol000000onne>[o0000okS6i003okS6i004o`000?nb^Moo/[WOok:ig`;o00001?n/[mX2o`00
00CoYZOG0_l00006oj6Re@05o`000?nMW]CoWIkDoifNe?l000000on>T]800ol0003oS93Cohb@d`03
ohb@d`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05
ooooo`003?ooool00omEEEGoIVIVo`00000Aooooo`;o0000A_ooool2o`000004o`1Kdol0003o677Q
o`0000;oAXo^00Go0000ogNZl_mgZ_;oMj[bo`000003oijlk@03o`000?niaN?o^LGS00?o^LGS00?o
0000ol_9fOo;bMT00oo;bMT01Ol0003oeLc@omG<d?oEc=3o000000Kod<;<00?o0000omBoa_oD_lH0
1ooD_lH00ol0003ocK?0olfc`00<olfc`003o`000?o2ZL7o`ZW100co`ZW100?o0000okRWb?nhYlP0
2_nhYlPFo`0000OoY[o/00?o0000oj3Oo?l000000_l00004ojkNn0;o00001?nff_<2o`0000?o^MC]
0_l00002okW<j0?o00000onha^@01Ol0003o/[WOok:igonb^Moo000000Go[:oJ00?o0000ojJWeonV
YmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@;o00001OnMW]@00ol0003oSY;Bo`000005ohb@d`03
o`000?oooooooooo01gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
8_ooool00ol0003oooooooooo`14ooooo`;o000000Co05_Co`000?lHLN7o00000_m6Snh01Ol0003o
Mj[bogNZl_mgZ_;o000000?oW[c]00?o0000okW5honiaN<00oniaN<00ol0003oblWIol_9f@03ol_9
f@03o`000?oEc=3o000000Sod<;<0_l00007omBoaP03o`000?o<]/Co000000;o00002_o=/l000ol0
003o`jc3ol>/``05o`0000Oo`ZW100?o0000okRWb?nhYlP02onhYlP00ol0003o[ZcFojj/eP0;ojj/
eP03o`000?nV_ncoY[o/00[oY[o/0ol00004ojkNn0?o00000onff_<3o`0000?o^MC]0_l00002okW<
j0;o00000onhaN@00ol0003o^<KTo`000003ok:ig`03o`000?n/[m[o[:oJ00?o[:oJ00?o0000ojJW
eonVYmL00onVYmL00ol0003oXJ;Eoj6Re@04oj6Re@03o`000?nMW]CoWIkD00GoWIkD0_l00005ohb@
d`03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04oooo
o`008oooool00ol0003oooooooooo`15ooooo`05o`000?l0Fm?o0000oaQahOl000000_m6Snh01Ol0
003oMj[bogNZl_mgZ_;o000000?oW[c]00?o0000okW5honiaN<00_niaN<00ol0003oblWIol_9f@03
ol_9f@;o00002oo@`/`00ol0003oe;o6omBoaP03omBoaP03o`000?o<]/Coc;K400?oc;K40ol00006
olfc`003o`000?o3[<?o`jc300Ko`jc31Ol000000oo2ZL7o0000okRWb00=okRWb003o`000?n^[=Ko
[ZcF00_o[ZcF00?o0000ojJok?nV_n`01OnV_n`5o`0000?o[/;X00Co0000ojkNn?l0003o00001?nf
f_<2o`0000Co^MC]0_l00003okW<j003o`000?nhaNCo^<GT00?o^<GT1?l000000onb^Moo0000ojb_
fP03ojb_fP;o00001OnVYmL00ol0003oXJ;Eoj6Re@04oj6Re@03o`000?nMW]CoWIkD00GoWIkD00Co
0000oi^MeOnKWMGo00000on<T=<00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01?ooool002Cooooo0_l00016ooooo`Co00000_m6Snh00ol0003oMj[bogNZ
lP02ogNZlP05o`000?nN_>goW[c]oijlkOl000001?niaN<01Ol0003oblWIol_9fOo;bMWo000000?o
b<CF00?o0000om32c?o@`/`02?o@`/`2o`0000;oe;o600?o0000olbfa?o<]/@01oo<]/@2o`0000Co
cK?000?o0000ol>/`oo3[<<02oo3[<<2o`0000;o^:O81_l00006okRWb003o`000?n^[=Ko[ZcF00co
[ZcF00?o0000ojJok?l000001?l00007ojk2j0?o00001?nff_<2o`0000Co^MC]0_l00003okW<j0;o
00001?nhaN@2o`0000?o]KkQ0ol00003ojb_fP03o`000?nVYmOoYZOG00CoYZOG00?o0000oj6ReOnQ
X]D00onQX]D2o`0000KoWIkD0_l00004oi^Me@03o`000?n<T=?o000002Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`009_ooool00ol0003oooooooooo`15ooooo`?o0000
0_m6Snh00ol0003oMj[bogNZlP02ogNZlP04o`000?nN_>goW[c]o`0000Go^LGS00?o0000ol_9fOl0
00001Oo8a=H2o`0000[od<;<00?o0000omBoa_l000002oo<]/@3o`000003olfc`?l0003o`jc300go
`jc300?o0000okZ[bOnjZlT01_njZlTGo`0000So[/;X1?l00003ok?3iP04o`000?nff_?o0000o`00
00Co^MC]0_l00003okW<j0;o00001OnhaN@00ol0003o]KkQokFnh@02okFnh@07o`000?nb^Mko/[WN
ok:ig_l0003o[:oJo`000005ojJWe`;o00001OnQX]D00ol0003oWIkDoifNe005oifNe003o`000?nK
WMGoVigE00CoVigE0_l0000Vooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool002Oooooo00?o0000ooooooooool0AOooool00ol0B[So0000o`000002odJ?kP05o`000?mgZ_;o
Mj[bogNZl_l000000onN_>d00ol0003o^LGSokW5h`02okW5h`;o00002?o8a=H00ol0003od<;<om32
c008om32c003o`000?o<]/Coc;K400goc;K400?o0000ol>/`oo3[<<03Oo3[<<00ol0003o^Z_9okZ[
b@0<okZ[b@03o`000?nc/=Ko/k3F00co/k3F00?o0000ojk2j?n^`^P01?n^`^P3o`0000Oo/l?V0_l0
0004okWDk@;o00000onic>P2o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000GoYZOG00?o
0000oj6ReOnQX]D00onQX]D2o`0000KoWIkD0_l00005oi^Me@;o0000:?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Cooooo000Xooooo`03o`000?oooooooooo04Kooooo00Go04Zh
o`000?m6SnkoAXo^o`000003ogNZlP06o`000?nN_>goW[c]oijlkOl0003o^LGS0_l00003okW5h`03
o`000?o8a=Kob<CF00Gob<CF0_l00008om32c003o`000?o9^/_o000000;o00002oo<]/@01?l0003o
a;37olB`aoo4/<L5o`0000Ko`jc300?o0000okZ[bOnjZlT03OnjZlT00ol0003o/k3Fok>`eP0=ok>`
eP03o`000?n^`^So000000?o00001onc`nH3o`0000;o]/CU00Co0000okWDkOl0003o00000onic>P2
o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000;o[kCL00Go0000ojJWeonVYmOoYZOGo`00
0005oj6Re@03o`000?nMW]CoWIkD00GoWIkD00?o0000oi^MeOnKWMD01?nKWMD00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool002Wooooo0_l00017
ooooo`03o`1:^?l0003o000000;o00000omgZ_800ol0003oW[c]oijlk@02o`0000Ko^LGS0_l00007
olS4eP03o`000?o@`/cod<;<00Cod<;<00?o0000olVjboo9^//00oo9^//2o`0000Soc;K400?o0000
olB`aoo4/<L01oo4/<L5o`000003ol>/`ol0003o^Z_900ko^Z_900?o0000ok>`e_nc/=H02Onc/=H6
o`0000So/l?V0ol00005okK4i@;o00001?nic>P00ol0003o^<GTokS5i004okS5i003o`000?ne_^7o
]KkQ00;o]KkQ00?o0000ok:ig_nb^Mh00onb^Mh00ol0003o[kCLojndg003ojndg003o`000?nVYmOo
000000GoXJ;E00?o0000oifNe?nMW]@01?nMW]@2o`0000GoVigE0_l0000]ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0A_ooool00ol0
B[So;I?_o`000006o`0000?oW/;a1oniaN<2o`0000Kob<CF0_l00003om32c003o`000?o9^/_obK[;
00KobK[;0_l00006olbfa003o`000?o4/<Ooa;3700coa;370_l000000onjZlWo0000o`000005o`00
00Oo^Z_900Co0000ok>`e_nc/=Ko/k3F2?l00004okJef003o`000?nc`nKo/l?V00Go/l?V0_l00005
okK4i@?o00000_nhaN@01?l0003o^LcXo`000?l00005okS5i0;o00000one_^42o`0000Co/[WN0_l0
0006ojndg0?o00000onQX]D2o`0000KoWIkD00?o0000oi^MeOnKWMD00onKWMD2o`0002oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`16
ooooo`04o`1:^?l0003o;I?_obfCk`CoL;?j1?nN`_42o`0000Ko^LGS00?o0000olS4e_o8a=H01Oo8
a=H00ol0003od<;<o`00000;olVjb`?o00000oo<]/@00ol0003oa;37olB`a`0=olB`a`03o`000?nl
[lgo_:o=00Ko_:o=2ol0000<okJef003o`000?nc`nKo/l?V00;o/l?V0ol00005okK4i@;o00001Onh
aN@2o`0000Go^<GT0_l00003okFnh@;o00001?nb^Mh2o`0000Ko[kCL0_l00003oj^`f`03o`000?nQ
X]Go000000KoWIkD0_l00004oi^Me@;o0000<_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo000]ooooo`03o`000?oooooooooo04Oooooo00Co04ZhobfCkol]Tnoo00000om`
/oX00ol0003oW/;aoik2l@02oik2l@03o`000?niaN?o^LGS00Co^LGS0_l00006olS4eP03o`000?o9
^/_obK[;00gobK[;0ol0000@olB`a`03o`000?nl[lgo_:o=00go_:o=00?o0000okJef?nf]MP03_nf
]MP4o`0000Go]/CU0ol00004okS5i0?o000000?o^<GTo`000?nhaN@00onhaN@00ol0003o]KkQokFn
h@02okFnh@03o`000?nb^Mko/[WN00;o/[WN0_l00006ojndg0;o00001On[/=/2o`0000KoWIkD00?o
0000oi^MeOnKWMD00onKWMD00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool002kooooo0_l00018ooooo`;o00000_l]Tnl01Ol0003oL;?jog2cn_m`
/o[o000000?oW/;a0_l00006okW5h`;o00000oo8a=H01?l0003oa;oEolBoeOo4_mD3o`0000cobK[;
00?o0000olB`aoo4/<L00_l0000;olB`a`03o`000?nl[lgo_:o=00ko_:o=00?o0000okJef?nf]MP0
2_nf]MP5o`0000Ko]/CU0_l00005okS5i0;o00001OnhaN@01?l0003o^<GTo`000?l00003okFnh@;o
00001?nb^Mh00ol0003o[kCLojndg004ojndg0;o00001On[/=/2o`0000;oZ:kK00Co0000oifNe?nM
W]CoWIkD0_l00004oi^Me@;o0000=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00?ooooo000`ooooo`03o`000?oooooooooo04Oooooo0_l000000ol]Tnoo0000o`000002og2cnP;o
00000onN`_42o`0000Ko^LGS00?o0000olS4e_l000001oo4_mD3o`0000WobK[;00?o0000ol>ecOo3
]Ld00_o3]Ld8o`0000?oa;3700?o0000okb_cOnl[ld03_nl[ld01?l0003o][GHokJef?nf]MP9o`00
00Co^;WJ00?o0000okK4iOnfa>D00_nfa>D2o`0000Co^<GT0ol00007okS5i0;o00000one_^42o`00
00Co/[WN0_l00005ojndg0;o00001On[/=/2o`0000GoZ:kK00?o0000oifNe?l000001?nKWMD2o`00
03Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003o
ooooooooo`17ooooo`?o000000?o;I?_o`000?m`/oX00_m`/oX2o`0000?oW/;a00?o0000okW5honi
aN<01?niaN<00ol0003oa;oEolBoe@09olBoe@?o00001Oo9^//00ol0003o`kG=ol>ec@0;ol>ec@Co
000000?o_:o=o`000?l000004Ol0000>okRifPCo00000onhaN@3o`0000Oo^<GT0ol00002okO4i003
o`000?ne_^7o000000Co/[WN0_l00005ojndg0;o00001On[/=/2o`0000OoZ:kK0_l00004oi^Me@03
o`000?oooooooooo03[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00
<_ooool00ol0003oooooooooo`18ooooo`;o000000?o;I?_o`000?l000000om`/oX01?l0003oW/;a
oik2lOnN`_42o`0000?o^LGS00?o0000okW4honia><00ol0000:olBoe@?o000000?obK[;o`000?o3
]Ld04?o3]Ld00ol0003o_;GBokbedP0>okbedP03o`000?nh^M[o^;WJ00co^;WJ1?l00004okS5i0;o
00001onhaN@3o`0000Go]lCT0_l00004ok:igP03o`000?n_]=co[kCL00?o[kCL0_l00005oj^`f`;o
00001_nX[]/3o`0000;oYJcL00Co0000oi^MeOl0003o0000?_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo000cooooo`;o0000BOooool3o`000003obfCkol0003oL;?j00;o
L;?j0_l00003oik2l@03o`000?niaN?o000000Ko^LCS0ol0000:olBoe@03o`000?o3]Lgo`kG=013o
`kG=00?o0000okbed_nl]M803_nl]M800ol0003o^;WJokRifP06okRifPKo00000oni_mh00ol0003o
^<GTo`000002o`0000Ko^<GT0ol00005okO4i0?o00000_nea>D01?l0003o/[WNo`000?l00004ojnd
g0;o00001?n[/=/3o`0000KoZ:kK0_l00005ojF/g0;o0000@Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo04Sooooo1Ol00003og2cnP03
o`000?nN`_7oW/;a00;o00002_nia><2o`0000Soa;oE00Co0000ol2le_o0_=Ko`;cF1_l00008ol>e
c@03o`000?nl]M;o_;GB00oo_;GB00Co0000okRif_nh^M[o^;WJ1Ol00008okVogP?o00001onhaN@2
o`0000Go]lCT0ol00005okG4i@;o00001?n_]=`2o`0000CoZk3K0_l00006ojR^f`?o00001?nU[=`3
o`0004?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0
003oooooooooo`19ooooo`04o`1fbol0003o;I?_o`0000;oL;?j0ol00003oj?8l`;o00002Onia><3
o`0000Coa;oE00?o0000ol2le_o0_=H02?o0_=H6o`0000;o`kG=00?o0000okbed_nl]M801_nl]M8<
o`0000Wo^KoN1Ol00002okS4i003o`000?nhaNCo^<GT00;o^<GT0ol00004okO4i0?o00001Onea>D3
o`0000;o//?W00Co0000ojndg?l0003o00001?n[/=/2o`0000KoZ:kK0_l00005ojF/g0;o0000Aooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000gooooo`;o0000C?ooool3
o`0000CoM/7n1OnSb?<3o`0000So^LCS0ol000000oo4_mGo0000ol2leP0?ol2leP?o000000?o_;GB
o`000?l000001Ol00009okblf@03o`000?ni_mko^KoN00Go^KoN1?l00008okS4i0Co00001?nga>@3
o`0000Go]LCU0ol00004ok;3i`?o00001?n[/=/2o`0000KoZ:kK0_l00004ojF/g0?o0000B_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo
04_ooooo00?o05B[o`000?mf`Oh01Omf`Oh00ol0003oXlScoj?8l`02oj?8l`?o00002?nia><00ol0
003o`;cFol2leP0Aol2leP03o`000?nl_=Wo_;cI00oo_;cI00?o0000okVog_ni_mh00_ni_mh2o`00
00_o^<CT0ol00004okO4i0?o00001Onea>D3o`0000Co//?W0ol00003ojo2j004o`000?n[/=_o0000
o`0000GoZ:kK0ol00004ojF/g0;o0000C_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00;ooooo000jooooo`03o`000?oooooooooo04gooooo0ol00005ogK1oP;o00000onSb?<3o`00
00Go^LCS00?o0000okW4honia><00onia><9o`0000Co`;cF00?o0000okblfOnl_=T01_nl_=T;o`00
0003okVog_nha>Co^<CT00Wo^<CT1Ol00002okG:j@03o`000?nga>Co000000;o00001Onea>D3o`00
00Co//?W0ol00005ojo2j0?o00001OnX[]/2o`0000GoYJcL0_l0001@ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool003_ooooo00?o0000ooooooooool0C_ooool00ol0E:_o
0000o`000003o`0000?oM/7n0ol00002oj?8l`?o000000?o^LCSo`000?nia><03_nia><4o`0000;o
_;cI1ol0000:okS4h`03o`000?nha>Co^<CT00Go^<CT1Ol00005okG:j@Co00001Onea>D3o`0000Co
//?W0ol00004ojo2j0Co00000on[`NX00ol0003oZ:kKo`000002o`0000CoYJcL0ol0001Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003cooooo0_l0001@ooooo`03o`1D
Zol0003o000000Co00000omf`Oh3o`0000;oXlSc00?o0000okW4honia><04Onia><00ol0003o^<CS
okS4h`0AokS4h`04o`000?nha>Co^<CTokS4i0Co00001Oneb^T5o`0000?o/Lo`00?o0000okG4iOne
a>D00ol00004ok;3i`?o00000on_`^P4o`0000KoZl7Z0ol00005ojF/g0;o0000Eoooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000nooooo`03o`000?oooooooooo053ooooo
0ol000001?l`Xo7o0000o`000?l00003ogK1oP03o`000?nYc?;oZLcb00GoZLcb2Ol00004okW4h`03
o`000?nha>?o^<CS00So^<CS3Ol00005okG:j@Go00001_naco05o`0000Co//?W0ol00003ojo2j0?o
00001_n[`NX4o`0000?oYl3[00?o0000ojF/g?l000000_l0001Jooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00Oooool003oooooo00?o0000ooooooooool0D_ooool3o`000003oc2S
lOl0003o000000GoRlon1ol00006ojW<lPGo00000_nha><8o`0000[o/Lg^00Co0000okG:jOneb^Wo
]L[Y0ol00006ok7?l0Ko00000onZd_D00ol0003o//?Wok;3i`03o`0000;o[l;X1?l00005oj_1jPCo
00001OnW`>/4o`0005gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00
@?ooool00ol0003oooooooooo`1Dooooo`03o`000?mG`O[oEl7j00?oEl7j0ol00006oh_?oPOo0000
0onYc?800ol0003o/Lg^ok7=kP07ok7=kP_o000000?o]L[Yo`000?naco001Onaco05o`0000KoZ];e
1_l000000on_`^So0000o`000002o`0000CoZl7Z1Ol00004ojO0j`Go0000H_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo0011ooooo`;o0000FOooool6oeO1nPGo00001_n;
coh3o`0000?o/Lg^1ol0000:oj;Dn@03o`000?naco3o/Lo`00;o/Lo`1?l00003oj[Bm@So000000?o
X]Cio`000?l000001?l00004oj_1jPCo00001?nW`>/5o`0006Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`01ooooo`00@oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo
oooo00;ooooo00Co0000oeO1n_mG`O[oEl7j1Ol00003oh_?oP03o`000?nRe?WoX]Ci00OoX]Ci3?l0
00000onaco3o0000oj[Bm@0Ao`0000CoVM?l00?o0000oj_1j_l000000ol00003ojO0j`Go0000K_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooo
oooo05Oooooo00?o0000ooooooooool02?ooool2o`000004oeO1n_l0003o0000o`0000?oX]Ci7_l0
0007oiWCo0So00000_nW`>/5o`0007?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`00AOooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00kooooo6Ol00002
oiWCo0go000000?oTm7mo`000?l000001ol0001iooooo`03o`000?oooooooooo00Sooooo0Ol00001
ooooo`7ooooo0016ooooo`;o0000E_ooool00ol0003oooooooooo`0Goooooa;o000000?oTm7mo`00
0?l000002ol00023ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0018ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool08?ooool:o`00097ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00Boooool2o`00057ooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004kooooo00?o0000oooooooo
ool0COooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
Coooool2o`0004gooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool0057ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`30ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00D_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo0<3ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Cooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo0000007ooooo001Doooo
o`;o0000B?ooool00ol0003oooooooooo`32ooooo`04o`000?ooooooooooo`00007ooooo001Foooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0`oooool00ol0003oooooo`000001oooo
o`00Eoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0<?ooooo00?o0000oooooooo
ool00Ol0000005Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`34ooooo`7o0000
0Oooool1o`000000FOooool2o`0004?ooooo00?o0000ooooooooool0aOooool2o`000000Foooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo0ol0000005cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`30ooooo`Co00000oooool005gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`2looooo`Co00001oooool005kooooo0_l0000nooooo`03o`00
0?oooooooooo0;Sooooo1?l0000;ooooo`00H?ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo0;Cooooo1?l0000?ooooo`00HOooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo0;7ooooo0ol0000Cooooo`00H_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
0:gooooo1?l0000Fooooo`00Hoooool2o`0003Wooooo00?o0000ooooooooool0ZOooool4o`0001[o
oooo001Uooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0YOooool4o`0001kooooo
001Vooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0X_ooool4o`0002;ooooo001W
ooooo`;o0000=?ooool00ol0003oooooooooo`2Nooooo`Co00009_ooool006Wooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`2Jooooo`Co0000:_ooool006[ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`2Fooooo`Co0000;_ooool006_ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Booooo`Co0000<_ooool006cooooo0_l0000_ooooo`03o`000?oo
oooooooo08kooooo1?l0000fooooo`00K_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo08[ooooo1?l0000jooooo`00Koooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
08Oooooo0ol0000nooooo`00L?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?o
oooo1?l00011ooooo`00LOooool2o`0002[ooooo00?o0000ooooooooool0Ooooool4o`0004Gooooo
001cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Noooool4o`0004Wooooo001d
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004gooooo001eoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Loooool4o`00057ooooo001fooooo`;o
00009Oooool00ol0003oooooooooo`1_ooooo`Co0000EOooool007Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`1[ooooo`Co0000FOooool007Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Wooooo`Co0000GOooool007[ooooo0_l0000Qooooo`03o`000?oooooo
oooo06?ooooo1?l0001Qooooo`00O?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
063ooooo0ol0001Uooooo`00OOooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05co
oooo1?l0001Xooooo`00O_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Sooooo
1?l0001/ooooo`00Ooooool2o`0001cooooo00?o0000ooooooooool0E?ooool4o`00073ooooo0021
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D?ooool4o`0007Cooooo0022oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool4o`0007Sooooo0023ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007cooooo0024ooooo`;o0000
5oooool00ol0003oooooooooo`14ooooo`Co0000P?ooool008Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`10ooooo`Co0000Q?ooool008Oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0looooo`Co0000R?ooool008Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0iooooo`?o0000S?ooool008Wooooo0_l0000Booooo`03o`000?oooooooooo03Go
oooo1?l0002?ooooo`00Roooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03;ooooo
1?l0002Cooooo`00S?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo1?l0
002Gooooo`00SOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo1?l0002K
ooooo`00S_ooool2o`0000cooooo00?o0000ooooooooool09_ooool4o`0009oooooo002@ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`000:?ooooo002Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:Oooooo002Booooo`;o00002?oo
ool00ol0003oooooooooo`0Jooooo`Co0000Zoooool009Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`Co0000[oooool009Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000/oooool009Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`?o0000]oooool009Oooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo
1?l0002jooooo`00VOooool01?l0003oooooooooool00009ooooo`Co0000__ooool009[ooooo00?o
0000ooooool000001Oooool4o`000<;ooooo002Kooooo`;o000000?oooooo`000?l000000_l00036
ooooo`00W?ooool2o`000<[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0637128, -0.00247541, \
0.00353722, 0.00353722}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The reader is invited to plot some of the other modes in this \
manner, so as to get a feeling for their behavior.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Traveling Waves in \[Theta]", "Section",
  CellTags->{"i:91", "c:38"}],

Cell[TextData[{
  "We have found that the general solution to the 2D wave equation is a sum \
of eigenmodes with oscillatory time-dependence, given by Eq. ",
  ButtonBox["(4.4.17)",
    ButtonData:>"(4.4.17)",
    ButtonStyle->"Hyperlink"],
  ". Each term in the sum has the form"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(A\_\(m\ n\)\) cos\ \(\[Omega]\_\(m\ n\)\) 
              t\  + \ \(B\_\(m\ n\)\) 
              sin\ \ \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)\) 
              t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) \(\(J\
\_m\)(\(j\_\(m, \ n\)\) r/a)\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.20)"],

Cell[TextData[{
  " Let 's consider a specific case, where the complex amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(m\ n\)\)]],
  " equals -",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ A\_\(m\ n\)\)]],
  " for some given ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ". For this mode, Eq. ",
  ButtonBox["(4.4.20)",
    ButtonData:>"(4.4.20)",
    ButtonStyle->"Hyperlink"],
  "  can be written as "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[{
      \(TraditionalForm\`A\_\(m\ n\)\ \((cos\ \(\[Omega]\_\(m\ n\)\) 
                t\  - \ \[ImaginaryI]\ sin\ \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \
\)\)\) t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) \
\(\(J\_m\)(\(j\_\(m, \ n\)\) r/a)\) = 
        A\_\(m\ n\)\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(\[Omega]\_\(m\
\ n\)\) t\)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[Theta]\)\) \(\(J\_m\)(\
\(j\_\(m, \ n\)\) r/a)\)\), "\[IndentingNewLine]", 
      \(TraditionalForm\`\(\(=\)\(A\_\(m\ n\)\ \(\[ExponentialE]\^\(\
\[ImaginaryI](\ m\ \ \[Theta] - \(\[Omega]\_\(m\ n\)\) 
                    t)\)\) \(\(J\_m\)(\(j\_\(m\ , n\)\) r/a)\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "This mode is a ",
  StyleBox["traveling wave",
    FontSlant->"Italic"],
  " in the \[Theta]-direction. The real part of the mode has a \
\[Theta]-variation of the form ",
  Cell[BoxData[
      \(TraditionalForm\`cos(
        m\ \[Theta] - \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)\) 
            t\  + \ \[Phi]\_\(m\ n\)\%A)\)]],
  ", so this wave moves, unlike a standing wave. For example, at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", there is a maximum in the real part of the wave at ",
  Cell[BoxData[
      \(TraditionalForm\`m\ \[Theta] + \[Phi]\_\(m\ n\)\%A = 0\)]],
  "; but as time progresses this maximum moves according to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`m\ \[Theta] - \(\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)\
\) t + \[Phi]\_\(m\ n\)\%A = 0\)]],
  ", or ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \(-\[Phi]\_\(m\ n\)\%A\)/
            m + \((\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)/m)\) t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t The angular velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(\(m\)\(\ \)\(n\)\(\ \)\)/m\)]],
  " is also called the phase velocity ",
  Cell[BoxData[
      \(TraditionalForm\`c\_\[Phi]\)]],
  " of this wave. Since the wave is moving in \[Theta], this phase velocity \
has units of radians per second. In Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  ", we will consider traveling waves moving linearly in ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". There, the phase velocity has units of meters per second. "
}], "Text"],

Cell[TextData[{
  "\t We could also choose ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(m\ n\) = \(+\[ImaginaryI]\)\ A\_\(m\ n\)\)]],
  " in Eq. ",
  ButtonBox["(4.4.20)",
    ButtonData:>"(4.4.20)",
    ButtonStyle->"Hyperlink"],
  ". This results in a traveling wave proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[ExponentialE]\^\(\[ImaginaryI](\ 
            m\ \ \[Theta] + \(\[Omega]\_\(m\ n\)\) t)\)\)\)\)]],
  ". This wave travels in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Theta]\)\)]],
  " direction."
}], "Text"],

Cell[TextData[{
  "\t In Cell ",
  ButtonBox["4.43",
    ButtonData:>"Cell 4.43",
    ButtonStyle->"Hyperlink"],
  " we exhibit an animation of the drumhead traveling wave for  ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, \(\(n\)\(=\)\(1\)\(\ \)\)\)]],
  ", traveling in the positive \[Theta]-direction."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1; \ \[Omega] = j1[\([1]\)];\[IndentingNewLine]\), "\n", 
    \(\(\[Psi][r_, \[Theta]_, t_]\  := \ 
        BesselJ[1, j1[\([1]\)]\ r]\ Cos[m\ \[Theta] - \[Omega]\ t] /; \ 
          r \[LessEqual] \ 1;\)\), "\n", 
    \(\(\(\[Psi][r_, \[Theta]_, t_]\  := \ 
        0\  /; \ r > \ 1;\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[
        ParametricPlot3D[{r\ Cos[\[Theta]], 
            r\ Sin[\[Theta]], \[Psi][r, \[Theta], t]}, {r, 0, 1}, {\[Theta], 
            0, 2\ Pi}, PlotPoints \[Rule] 25, 
          BoxRatios \[Rule] {1, 1, 1/2}], {t, 0, 
          1.9\ Pi/\[Omega], \  .1\ Pi/\[Omega]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.43"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03003 .28261 -24 -2.73565 ]
[.03003 .28261 0 6.26435 ]
[.02107 .33874 -30 -2.78353 ]
[.02107 .33874 0 6.21647 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00213 .45746 -24 -2.88536 ]
[.00213 .45746 0 6.11464 ]
[-0.0079 .5203 -18 -2.93958 ]
[-0.0079 .5203 0 6.06042 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04225 .27781 m
.04836 .27542 L
s
[(-0.5)] .03003 .28261 1 -0.39208 Mshowa
.03334 .33406 m
.03947 .33172 L
s
[(-0.25)] .02107 .33874 1 -0.38144 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01448 .45303 m
.02066 .45081 L
s
[(0.25)] .00213 .45746 1 -0.35881 Mshowa
.00451 .516 m
.01071 .51384 L
s
[(0.5)] -0.0079 .5203 1 -0.34676 Mshowa
.125 Mabswid
.04049 .2889 m
.04416 .28747 L
s
.03872 .30007 m
.0424 .29864 L
s
.03694 .31131 m
.04062 .3099 L
s
.03515 .32265 m
.03882 .32124 L
s
.03151 .34556 m
.0352 .34416 L
s
.02968 .35715 m
.03336 .35576 L
s
.02783 .36882 m
.03152 .36744 L
s
.02597 .38058 m
.02966 .3792 L
s
.0222 .40436 m
.02589 .403 L
s
.02029 .41639 m
.02399 .41504 L
s
.01837 .42851 m
.02207 .42716 L
s
.01643 .44072 m
.02014 .43938 L
s
.01252 .46543 m
.01623 .4641 L
s
.01054 .47792 m
.01425 .47661 L
s
.00854 .49051 m
.01226 .48921 L
s
.00653 .50321 m
.01025 .50191 L
s
.04399 .26681 m
.04766 .26536 L
s
.04573 .25588 m
.04939 .25443 L
s
.00246 .52889 m
.00619 .5276 L
s
.0004 .54188 m
.00413 .5406 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51726 .64438 m .51694 .65827 L .43899 .65168 L p .722 .646 .773 r
F P
0 g
s
.51694 .65827 m .51726 .64438 L .59255 .64367 L p .686 .669 .828 r
F P
0 g
s
.59255 .64367 m .59527 .65394 L .51694 .65827 L p .686 .669 .828 r
F P
0 g
s
.43899 .65168 m .44249 .63501 L .51726 .64438 L p .722 .646 .773 r
F P
0 g
s
.51759 .63028 m .51726 .64438 L .44249 .63501 L p .714 .638 .771 r
F P
0 g
s
.51726 .64438 m .51759 .63028 L .58982 .63325 L p .674 .66 .828 r
F P
0 g
s
.58982 .63325 m .59255 .64367 L .51726 .64438 L p .674 .66 .828 r
F P
0 g
s
.59527 .65394 m .59255 .64367 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44249 .63501 m .43899 .65168 L .36521 .63435 L p .761 .655 .745 r
F P
0 g
s
.44249 .63501 m .446 .61809 L .51759 .63028 L p .714 .638 .771 r
F P
0 g
s
.51791 .61612 m .51759 .63028 L .446 .61809 L p .706 .631 .771 r
F P
0 g
s
.51759 .63028 m .51791 .61612 L .58707 .62277 L p .659 .651 .83 r
F P
0 g
s
.58707 .62277 m .58982 .63325 L .51759 .63028 L p .659 .651 .83 r
F P
0 g
s
.36521 .63435 m .37188 .61591 L .44249 .63501 L p .761 .655 .745 r
F P
0 g
s
.446 .61809 m .44249 .63501 L .37188 .61591 L p .756 .649 .743 r
F P
0 g
s
.59255 .64367 m .58982 .63325 L .65915 .62672 L p .632 .743 .928 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59255 .64367 L p .632 .743 .928 r
F P
0 g
s
.37188 .61591 m .37855 .59722 L .446 .61809 L p .756 .649 .743 r
F P
0 g
s
.44952 .60115 m .446 .61809 L .37855 .59722 L p .751 .644 .742 r
F P
0 g
s
.446 .61809 m .44952 .60115 L .51791 .61612 L p .706 .631 .771 r
F P
0 g
s
.51824 .60207 m .51791 .61612 L .44952 .60115 L p .695 .624 .773 r
F P
0 g
s
.51791 .61612 m .51824 .60207 L .5843 .61231 L p .642 .641 .834 r
F P
0 g
s
.5843 .61231 m .58707 .62277 L .51791 .61612 L p .642 .641 .834 r
F P
0 g
s
.37855 .59722 m .38523 .57854 L .44952 .60115 L p .751 .644 .742 r
F P
0 g
s
.45304 .58439 m .44952 .60115 L .38523 .57854 L p .744 .639 .743 r
F P
0 g
s
.44952 .60115 m .45304 .58439 L .51824 .60207 L p .695 .624 .773 r
F P
0 g
s
.38523 .57854 m .39189 .56015 L .45304 .58439 L p .744 .639 .743 r
F P
0 g
s
.45656 .56804 m .45304 .58439 L .39189 .56015 L p .736 .635 .746 r
F P
0 g
s
.45304 .58439 m .45656 .56804 L .51857 .58827 L p .683 .617 .776 r
F P
0 g
s
.51857 .58827 m .51824 .60207 L .45304 .58439 L p .683 .617 .776 r
F P
0 g
s
.51824 .60207 m .51857 .58827 L .58152 .60195 L p .621 .631 .839 r
F P
0 g
s
.58152 .60195 m .5843 .61231 L .51824 .60207 L p .621 .631 .839 r
F P
0 g
s
.58982 .63325 m .58707 .62277 L .65355 .62061 L p .604 .733 .936 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58982 .63325 L p .604 .733 .936 r
F P
0 g
s
.39189 .56015 m .39853 .54229 L .45656 .56804 L p .736 .635 .746 r
F P
0 g
s
.46007 .55229 m .45656 .56804 L .39853 .54229 L p .726 .631 .751 r
F P
0 g
s
.45656 .56804 m .46007 .55229 L .5189 .57486 L p .668 .611 .782 r
F P
0 g
s
.5189 .57486 m .51857 .58827 L .45656 .56804 L p .668 .611 .782 r
F P
0 g
s
.51857 .58827 m .5189 .57486 L .57872 .59176 L p .596 .62 .846 r
F P
0 g
s
.57872 .59176 m .58152 .60195 L .51857 .58827 L p .596 .62 .846 r
F P
0 g
s
.39853 .54229 m .40515 .52521 L .46007 .55229 L p .726 .631 .751 r
F P
0 g
s
.46358 .53734 m .46007 .55229 L .40515 .52521 L p .714 .626 .758 r
F P
0 g
s
.46007 .55229 m .46358 .53734 L .51923 .562 L p .65 .604 .789 r
F P
0 g
s
.51923 .562 m .5189 .57486 L .46007 .55229 L p .65 .604 .789 r
F P
0 g
s
.58707 .62277 m .5843 .61231 L .6479 .61445 L p .569 .719 .943 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58707 .62277 L p .569 .719 .943 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .73 .61199 L p .615 .89 .989 r
F P
0 g
s
.73 .61199 m .73799 .61332 L .67023 .63881 L p .615 .89 .989 r
F P
0 g
s
.40515 .52521 m .41174 .50914 L .46358 .53734 L p .714 .626 .758 r
F P
0 g
s
.46708 .52336 m .46358 .53734 L .41174 .50914 L p .698 .622 .768 r
F P
0 g
s
.46358 .53734 m .46708 .52336 L .51956 .54979 L p .628 .596 .798 r
F P
0 g
s
.51956 .54979 m .51923 .562 L .46358 .53734 L p .628 .596 .798 r
F P
0 g
s
.5189 .57486 m .51923 .562 L .57591 .58183 L p .566 .607 .853 r
F P
0 g
s
.57591 .58183 m .57872 .59176 L .5189 .57486 L p .566 .607 .853 r
F P
0 g
s
.41174 .50914 m .41829 .49429 L .46708 .52336 L p .698 .622 .768 r
F P
0 g
s
.47058 .5105 m .46708 .52336 L .41829 .49429 L p .678 .617 .779 r
F P
0 g
s
.46708 .52336 m .47058 .5105 L .51989 .53836 L p .601 .587 .809 r
F P
0 g
s
.51989 .53836 m .51956 .54979 L .46708 .52336 L p .601 .587 .809 r
F P
0 g
s
.32837 .54928 m .33796 .53042 L .39189 .56015 L p .792 .674 .733 r
F P
0 g
s
.39189 .56015 m .38523 .57854 L .32837 .54928 L p .792 .674 .733 r
F P
0 g
s
.39853 .54229 m .39189 .56015 L .33796 .53042 L p .787 .671 .737 r
F P
0 g
s
.31874 .56849 m .32837 .54928 L .38523 .57854 L p .797 .677 .732 r
F P
0 g
s
.38523 .57854 m .37855 .59722 L .31874 .56849 L p .797 .677 .732 r
F P
0 g
s
.5843 .61231 m .58152 .60195 L .64221 .60824 L p .528 .702 .95 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .5843 .61231 L p .528 .702 .95 r
F P
0 g
s
.30909 .58776 m .31874 .56849 L .37855 .59722 L p .8 .68 .733 r
F P
0 g
s
.37855 .59722 m .37188 .61591 L .30909 .58776 L p .8 .68 .733 r
F P
0 g
s
.33796 .53042 m .34749 .51221 L .39853 .54229 L p .787 .671 .737 r
F P
0 g
s
.40515 .52521 m .39853 .54229 L .34749 .51221 L p .779 .669 .742 r
F P
0 g
s
.29943 .6068 m .30909 .58776 L .37188 .61591 L p .801 .684 .735 r
F P
0 g
s
.37188 .61591 m .36521 .63435 L .29943 .6068 L p .801 .684 .735 r
F P
0 g
s
.34749 .51221 m .35696 .49491 L .40515 .52521 L p .779 .669 .742 r
F P
0 g
s
.41174 .50914 m .40515 .52521 L .35696 .49491 L p .77 .667 .75 r
F P
0 g
s
.51923 .562 m .51956 .54979 L .57309 .57221 L p .53 .592 .861 r
F P
0 g
s
.57309 .57221 m .57591 .58183 L .51923 .562 L p .53 .592 .861 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72195 .61072 L p .562 .881 .992 r
F P
0 g
s
.72195 .61072 m .73 .61199 L .66471 .63279 L p .562 .881 .992 r
F P
0 g
s
.35696 .49491 m .36636 .47879 L .41174 .50914 L p .77 .667 .75 r
F P
0 g
s
.41829 .49429 m .41174 .50914 L .36636 .47879 L p .757 .665 .76 r
F P
0 g
s
.36636 .47879 m .37568 .46405 L .41829 .49429 L p .757 .665 .76 r
F P
0 g
s
.42481 .48085 m .41829 .49429 L .37568 .46405 L p .741 .662 .772 r
F P
0 g
s
.41829 .49429 m .42481 .48085 L .47058 .5105 L p .678 .617 .779 r
F P
0 g
s
.47407 .4989 m .47058 .5105 L .42481 .48085 L p .653 .61 .793 r
F P
0 g
s
.47058 .5105 m .47407 .4989 L .52022 .52781 L p .566 .575 .821 r
F P
0 g
s
.52022 .52781 m .51989 .53836 L .47058 .5105 L p .566 .575 .821 r
F P
0 g
s
.58152 .60195 m .57872 .59176 L .63648 .60198 L p .478 .679 .954 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58152 .60195 L p .478 .679 .954 r
F P
0 g
s
.51956 .54979 m .51989 .53836 L .57025 .56297 L p .486 .574 .869 r
F P
0 g
s
.57025 .56297 m .57309 .57221 L .51956 .54979 L p .486 .574 .869 r
F P
0 g
s
.37568 .46405 m .38494 .45091 L .42481 .48085 L p .741 .662 .772 r
F P
0 g
s
.43131 .46896 m .42481 .48085 L .38494 .45091 L p .719 .658 .788 r
F P
0 g
s
.42481 .48085 m .43131 .46896 L .47407 .4989 L p .653 .61 .793 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71382 .60945 L p .498 .86 .988 r
F P
0 g
s
.71382 .60945 m .72195 .61072 L .65915 .62672 L p .498 .86 .988 r
F P
0 g
s
.47757 .48866 m .47407 .4989 L .43131 .46896 L p .62 .601 .81 r
F P
0 g
s
.47407 .4989 m .47757 .48866 L .52056 .51821 L p .523 .56 .835 r
F P
0 g
s
.52056 .51821 m .52022 .52781 L .47407 .4989 L p .523 .56 .835 r
F P
0 g
s
.38494 .45091 m .39414 .43953 L .43131 .46896 L p .719 .658 .788 r
F P
0 g
s
.43779 .45876 m .43131 .46896 L .39414 .43953 L p .691 .652 .807 r
F P
0 g
s
.43131 .46896 m .43779 .45876 L .47757 .48866 L p .62 .601 .81 r
F P
0 g
s
.57872 .59176 m .57591 .58183 L .6307 .59568 L p .42 .651 .954 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57872 .59176 L p .42 .651 .954 r
F P
0 g
s
.51989 .53836 m .52022 .52781 L .5674 .55416 L p .433 .551 .875 r
F P
0 g
s
.5674 .55416 m .57025 .56297 L .51989 .53836 L p .433 .551 .875 r
F P
0 g
s
.48106 .47987 m .47757 .48866 L .43779 .45876 L p .576 .588 .828 r
F P
0 g
s
.47757 .48866 m .48106 .47987 L .52089 .50962 L p .467 .539 .847 r
F P
0 g
s
.52089 .50962 m .52056 .51821 L .47757 .48866 L p .467 .539 .847 r
F P
0 g
s
.39414 .43953 m .40329 .43006 L .43779 .45876 L p .691 .652 .807 r
F P
0 g
s
.44425 .45035 m .43779 .45876 L .40329 .43006 L p .652 .643 .829 r
F P
0 g
s
.43779 .45876 m .44425 .45035 L .48106 .47987 L p .576 .588 .828 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70562 .60807 L p .422 .828 .977 r
F P
0 g
s
.70562 .60807 m .71382 .60945 L .65355 .62061 L p .422 .828 .977 r
F P
0 g
s
.57591 .58183 m .57309 .57221 L .62488 .58932 L p .353 .615 .949 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57591 .58183 L p .353 .615 .949 r
F P
0 g
s
.52022 .52781 m .52056 .51821 L .56454 .54583 L p .369 .522 .879 r
F P
0 g
s
.56454 .54583 m .5674 .55416 L .52022 .52781 L p .369 .522 .879 r
F P
0 g
s
.31822 .4629 m .32999 .4478 L .36636 .47879 L p .822 .725 .758 r
F P
0 g
s
.36636 .47879 m .35696 .49491 L .31822 .4629 L p .822 .725 .758 r
F P
0 g
s
.37568 .46405 m .36636 .47879 L .32999 .4478 L p .811 .725 .77 r
F P
0 g
s
.32999 .4478 m .34164 .43418 L .37568 .46405 L p .811 .725 .77 r
F P
0 g
s
.38494 .45091 m .37568 .46405 L .34164 .43418 L p .796 .725 .785 r
F P
0 g
s
.30633 .47924 m .31822 .4629 L .35696 .49491 L p .83 .725 .749 r
F P
0 g
s
.35696 .49491 m .34749 .51221 L .30633 .47924 L p .83 .725 .749 r
F P
0 g
s
.34164 .43418 m .35319 .42225 L .38494 .45091 L p .796 .725 .785 r
F P
0 g
s
.39414 .43953 m .38494 .45091 L .35319 .42225 L p .775 .723 .804 r
F P
0 g
s
.40329 .43006 m .41239 .4226 L .44425 .45035 L p .652 .643 .829 r
F P
0 g
s
.45071 .44379 m .44425 .45035 L .41239 .4226 L p .598 .628 .852 r
F P
0 g
s
.44425 .45035 m .45071 .44379 L .48456 .47259 L p .518 .569 .846 r
F P
0 g
s
.48456 .47259 m .48106 .47987 L .44425 .45035 L p .518 .569 .846 r
F P
0 g
s
.29434 .49658 m .30633 .47924 L .34749 .51221 L p .836 .725 .742 r
F P
0 g
s
.34749 .51221 m .33796 .53042 L .29434 .49658 L p .836 .725 .742 r
F P
0 g
s
.48106 .47987 m .48456 .47259 L .52122 .5021 L p .396 .511 .857 r
F P
0 g
s
.52122 .5021 m .52089 .50962 L .48106 .47987 L p .396 .511 .857 r
F P
0 g
s
.35319 .42225 m .36463 .41217 L .39414 .43953 L p .775 .723 .804 r
F P
0 g
s
.40329 .43006 m .39414 .43953 L .36463 .41217 L p .747 .72 .827 r
F P
0 g
s
.28225 .51462 m .29434 .49658 L .33796 .53042 L p .84 .726 .738 r
F P
0 g
s
.33796 .53042 m .32837 .54928 L .28225 .51462 L p .84 .726 .738 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69734 .60651 L p .336 .782 .958 r
F P
0 g
s
.69734 .60651 m .70562 .60807 L .6479 .61445 L p .336 .782 .958 r
F P
0 g
s
.57309 .57221 m .57025 .56297 L .61901 .58292 L p .277 .572 .938 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57309 .57221 L p .277 .572 .938 r
F P
0 g
s
.73799 .61332 m .73 .61199 L .78459 .58188 L p .568 .939 .859 r
F P
0 g
s
.78459 .58188 m .79464 .57831 L .73799 .61332 L p .568 .939 .859 r
F P
0 g
s
.27008 .53307 m .28225 .51462 L .32837 .54928 L p .842 .727 .736 r
F P
0 g
s
.32837 .54928 m .31874 .56849 L .27008 .53307 L p .842 .727 .736 r
F P
0 g
s
.52056 .51821 m .52089 .50962 L .56165 .53801 L p .292 .486 .877 r
F P
0 g
s
.56165 .53801 m .56454 .54583 L .52056 .51821 L p .292 .486 .877 r
F P
0 g
s
.36463 .41217 m .37598 .4041 L .40329 .43006 L p .747 .72 .827 r
F P
0 g
s
.41239 .4226 m .40329 .43006 L .37598 .4041 L p .707 .713 .853 r
F P
0 g
s
.25784 .55162 m .27008 .53307 L .31874 .56849 L p .843 .728 .736 r
F P
0 g
s
.31874 .56849 m .30909 .58776 L .25784 .55162 L p .843 .728 .736 r
F P
0 g
s
.41239 .4226 m .42147 .41722 L .45071 .44379 L p .598 .628 .852 r
F P
0 g
s
.45718 .43912 m .45071 .44379 L .42147 .41722 L p .525 .604 .875 r
F P
0 g
s
.45071 .44379 m .45718 .43912 L .48807 .46685 L p .44 .54 .862 r
F P
0 g
s
.48807 .46685 m .48456 .47259 L .45071 .44379 L p .44 .54 .862 r
F P
0 g
s
.24558 .56996 m .25784 .55162 L .30909 .58776 L p .843 .73 .739 r
F P
0 g
s
.30909 .58776 m .29943 .6068 L .24558 .56996 L p .843 .73 .739 r
F P
0 g
s
.48456 .47259 m .48807 .46685 L .52156 .49566 L p .306 .472 .861 r
F P
0 g
s
.52156 .49566 m .52122 .5021 L .48456 .47259 L p .306 .472 .861 r
F P
0 g
s
.37598 .4041 m .38725 .39813 L .41239 .4226 L p .707 .713 .853 r
F P
0 g
s
.42147 .41722 m .41239 .4226 L .38725 .39813 L p .65 .698 .881 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68897 .60469 L p .243 .725 .931 r
F P
0 g
s
.68897 .60469 m .69734 .60651 L .64221 .60824 L p .243 .725 .931 r
F P
0 g
s
.57025 .56297 m .5674 .55416 L .61309 .57646 L p .192 .522 .918 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57025 .56297 L p .192 .522 .918 r
F P
0 g
s
.73 .61199 m .72195 .61072 L .77446 .58563 L p .484 .898 .811 r
F P
0 g
s
.77446 .58563 m .78459 .58188 L .73 .61199 L p .484 .898 .811 r
F P
0 g
s
.52089 .50962 m .52122 .5021 L .55876 .53071 L p .202 .44 .866 r
F P
0 g
s
.55876 .53071 m .56165 .53801 L .52089 .50962 L p .202 .44 .866 r
F P
0 g
s
.38725 .39813 m .39847 .39434 L .42147 .41722 L p .65 .698 .881 r
F P
0 g
s
.43054 .41396 m .42147 .41722 L .39847 .39434 L p .569 .672 .908 r
F P
0 g
s
.42147 .41722 m .43054 .41396 L .45718 .43912 L p .525 .604 .875 r
F P
0 g
s
.46367 .43634 m .45718 .43912 L .43054 .41396 L p .424 .564 .891 r
F P
0 g
s
.45718 .43912 m .46367 .43634 L .4916 .46265 L p .338 .498 .87 r
F P
0 g
s
.4916 .46265 m .48807 .46685 L .45718 .43912 L p .338 .498 .87 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .68052 .60253 L p .146 .658 .897 r
F P
0 g
s
.68052 .60253 m .68897 .60469 L .63648 .60198 L p .146 .658 .897 r
F P
0 g
s
.5674 .55416 m .56454 .54583 L .60713 .56996 L p .103 .464 .89 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .5674 .55416 L p .103 .464 .89 r
F P
0 g
s
.48807 .46685 m .4916 .46265 L .5219 .4903 L p .197 .42 .852 r
F P
0 g
s
.5219 .4903 m .52156 .49566 L .48807 .46685 L p .197 .42 .852 r
F P
0 g
s
.72195 .61072 m .71382 .60945 L .76424 .58942 L p .392 .844 .76 r
F P
0 g
s
.76424 .58942 m .77446 .58563 L .72195 .61072 L p .392 .844 .76 r
F P
0 g
s
.52122 .5021 m .52156 .49566 L .55584 .52396 L p .1 .385 .844 r
F P
0 g
s
.55584 .52396 m .55876 .53071 L .52122 .5021 L p .1 .385 .844 r
F P
0 g
s
.39847 .39434 m .40966 .39277 L .43054 .41396 L p .569 .672 .908 r
F P
0 g
s
.43962 .41282 m .43054 .41396 L .40966 .39277 L p .457 .627 .926 r
F P
0 g
s
.43054 .41396 m .43962 .41282 L .46367 .43634 L p .424 .564 .891 r
F P
0 g
s
.31838 .40633 m .33159 .39647 L .35319 .42225 L p .842 .81 .82 r
F P
0 g
s
.35319 .42225 m .34164 .43418 L .31838 .40633 L p .842 .81 .82 r
F P
0 g
s
.36463 .41217 m .35319 .42225 L .33159 .39647 L p .818 .811 .844 r
F P
0 g
s
.33159 .39647 m .34465 .38844 L .36463 .41217 L p .818 .811 .844 r
F P
0 g
s
.37598 .4041 m .36463 .41217 L .34465 .38844 L p .784 .809 .873 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67197 .59994 L p .05 .585 .857 r
F P
0 g
s
.67197 .59994 m .68052 .60253 L .6307 .59568 L p .05 .585 .857 r
F P
0 g
s
.30503 .41785 m .31838 .40633 L .34164 .43418 L p .858 .808 .8 r
F P
0 g
s
.34164 .43418 m .32999 .4478 L .30503 .41785 L p .858 .808 .8 r
F P
0 g
s
.56454 .54583 m .56165 .53801 L .60112 .5634 L p .01 .401 .853 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56454 .54583 L p .01 .401 .853 r
F P
0 g
s
.47019 .43543 m .46367 .43634 L .43962 .41282 L p .291 .503 .89 r
F P
0 g
s
.46367 .43634 m .47019 .43543 L .49515 .45996 L p .21 .437 .862 r
F P
0 g
s
.49515 .45996 m .4916 .46265 L .46367 .43634 L p .21 .437 .862 r
F P
0 g
s
.34465 .38844 m .35759 .38238 L .37598 .4041 L p .784 .809 .873 r
F P
0 g
s
.38725 .39813 m .37598 .4041 L .35759 .38238 L p .734 .8 .905 r
F P
0 g
s
.29152 .43084 m .30503 .41785 L .32999 .4478 L p .87 .805 .784 r
F P
0 g
s
.32999 .4478 m .31822 .4629 L .29152 .43084 L p .87 .805 .784 r
F P
0 g
s
.35759 .38238 m .37041 .37839 L .38725 .39813 L p .734 .8 .905 r
F P
0 g
s
.39847 .39434 m .38725 .39813 L .37041 .37839 L p .661 .78 .937 r
F P
0 g
s
.4916 .46265 m .49515 .45996 L .52224 .48599 L p .07 .354 .826 r
F P
0 g
s
.52224 .48599 m .5219 .4903 L .4916 .46265 L p .07 .354 .826 r
F P
0 g
s
.71382 .60945 m .70562 .60807 L .74847 .59475 L p .297 .782 .709 r
F P
0 g
s
.74847 .59475 m .7539 .59307 L p .75146 .59407 L .297 .782 .709 r
F P
0 g
s
.75146 .59407 m .71382 .60945 L .74847 .59475 L .297 .782 .709 r
F
.74345 .59642 m .7539 .59307 L .70562 .60807 L p 0 0 0 r
F P
0 g
s
.70562 .60807 m .69734 .60651 L .73209 .5989 L p 0 0 0 r
F P
0 g
s
.73406 .59876 m .70562 .60807 L .73209 .5989 L 0 0 0 r
F
.74035 .59737 m .70562 .60807 L .73668 .5979 L F
.73209 .5989 m .73668 .5979 L p .73406 .59876 L F P
0 g
s
.73668 .5979 m .74345 .59642 L p .74035 .59737 L 0 0 0 r
F P
0 g
s
.73287 .5993 m .74345 .59642 L .69917 .60611 L p 0 0 0 r
F P
0 g
s
.73287 .5993 m .69917 .60611 L .6981 .60636 L 0 0 0 r
F
.69917 .60611 m .69734 .60651 L p .6981 .60636 L F P
0 g
s
.69734 .60651 m .68897 .60469 L .71436 .60158 L p 0 0 0 r
F P
0 g
s
.71651 .60174 m .69734 .60651 L .71436 .60158 L 0 0 0 r
F
.72473 .60096 m .69734 .60651 L .71991 .60089 L F
.71991 .60089 m .73287 .5993 L p .72473 .60096 L F P
0 g
s
.72217 .60157 m .73287 .5993 L .71991 .60089 L p 0 0 0 r
F P
0 g
s
.71436 .60158 m .71991 .60089 L p .71651 .60174 L 0 0 0 r
F P
0 g
s
.71991 .60089 m .69156 .60437 L p .71794 .60195 L 0 0 0 r
F P
0 g
s
.72217 .60157 m .71991 .60089 L .71794 .60195 L 0 0 0 r
F
.72217 .60157 m .69156 .60437 L .69006 .60459 L F
.69156 .60437 m .68897 .60469 L p .69006 .60459 L F P
0 g
s
.68897 .60469 m .68052 .60253 L .70198 .60203 L p 0 0 0 r
F P
0 g
s
.70198 .60203 m .72217 .60157 L p .70756 .60294 L 0 0 0 r
F P
0 g
s
.70756 .60294 m .68897 .60469 L .70198 .60203 L 0 0 0 r
F
.71132 .60305 m .72217 .60157 L .70198 .60203 L p .063 0 0 r
F P
0 g
s
.70198 .60203 m .68473 .60243 L p .70129 .60282 L .063 0 0 r
F P
0 g
s
.71132 .60305 m .70198 .60203 L .70129 .60282 L .063 0 0 r
F
.71132 .60305 m .68473 .60243 L .68288 .60257 L F
.68473 .60243 m .68052 .60253 L p .68288 .60257 L F P
0 g
s
.68052 .60253 m .67197 .59994 L .68969 .60134 L p .063 0 0 r
F P
0 g
s
.68969 .60134 m .71132 .60305 L p .69545 .60278 L .063 0 0 r
F P
0 g
s
.69545 .60278 m .68052 .60253 L .68969 .60134 L .063 0 0 r
F
.67785 .60041 m .67718 .60035 L p .67826 .60051 L .142 0 0 r
F P
0 g
s
.70034 .60363 m .67785 .60041 L .67826 .60051 L .142 0 0 r
F
.70034 .60363 m .71132 .60305 L .67785 .60041 L p F P
0 g
s
.70034 .60363 m .67718 .60035 L .67492 .60032 L .142 0 0 r
F
.67718 .60035 m .67197 .59994 L p .67492 .60032 L F P
0 g
s
.67197 .59994 m .66334 .59687 L .70034 .60363 L p .142 0 0 r
F P
0 g
s
.68923 .60318 m .70034 .60363 L .67068 .59821 L p .215 0 0 r
F P
0 g
s
.67068 .59821 m .66334 .59687 L p .66799 .598 L .215 0 0 r
F P
0 g
s
.68923 .60318 m .67068 .59821 L .66799 .598 L .215 0 0 r
F
.66334 .59687 m .65462 .59325 L .67167 .59814 L p F P
0 g
s
.65632 .59374 m .65462 .59325 L p .6572 .59417 L .281 0 0 r
F P
0 g
s
.66004 .59519 m .65632 .59374 L .6572 .59417 L .281 0 0 r
F
.66313 .59569 m .65632 .59374 L p .66004 .59519 L F P
0 g
s
.67754 .60033 m .66334 .59687 L .67167 .59814 L .215 0 0 r
F
.67799 .6016 m .66313 .59569 L .66004 .59519 L .281 0 0 r
F
.65462 .59325 m .64581 .58904 L .67799 .6016 L p F P
0 g
s
.65539 .59277 m .64581 .58904 L p .65194 .59191 L .34 0 0 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66334 .59687 L p 0 .508 .813 r
F P
0 g
s
.66334 .59687 m .67197 .59994 L .62488 .58932 L p 0 .508 .813 r
F P
0 g
s
.65462 .59325 m .66334 .59687 L .61901 .58292 L p 0 .431 .767 r
F P
0 g
s
.66662 .59881 m .65539 .59277 L .65194 .59191 L .34 0 0 r
F
.61901 .58292 m .61309 .57646 L .65462 .59325 L p 0 .431 .767 r
F P
0 g
s
.64581 .58904 m .65462 .59325 L .61309 .57646 L p 0 .357 .722 r
F P
0 g
s
.64581 .58904 m .63692 .58419 L .65415 .59267 L p .34 0 0 r
F P
0 g
s
.65415 .59267 m .66662 .59881 L p .66023 .59581 L .34 0 0 r
F P
0 g
s
.66023 .59581 m .64581 .58904 L .65415 .59267 L .34 0 0 r
F
.63692 .58419 m .64581 .58904 L .6399 .58612 L p 0 .288 .679 r
F P
0 g
s
.6399 .58612 m .60713 .56996 L p .63692 .58419 L 0 .288 .679 r
F P
0 g
s
.63692 .58419 m .62795 .57868 L .63344 .58193 L p .39 0 0 r
F P
0 g
s
.64239 .58722 m .64526 .58829 L .63893 .58518 L .39 0 0 r
F
.61309 .57646 m .60713 .56996 L .64581 .58904 L p 0 .357 .722 r
F P
0 g
s
.65515 .59477 m .64526 .58829 L .64172 .58697 L .39 0 0 r
F
.63344 .58193 m .65515 .59477 L p .63692 .58419 L F P
0 g
s
.60713 .56996 m .60112 .5634 L .63692 .58419 L p 0 .288 .679 r
F P
0 g
s
.62795 .57868 m .63692 .58419 L .63106 .58078 L p 0 .225 .639 r
F P
0 g
s
.63106 .58078 m .60112 .5634 L p .62795 .57868 L 0 .225 .639 r
F P
0 g
s
.61889 .5725 m .62795 .57868 L .62216 .57483 L p 0 .168 .602 r
F P
0 g
s
.62216 .57483 m .59506 .55679 L p .61889 .5725 L 0 .168 .602 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61889 .5725 L p 0 .168 .602 r
F P
0 g
s
.60977 .56565 m .61889 .5725 L .6132 .56825 L p 0 .118 .569 r
F P
0 g
s
.6132 .56825 m .58896 .55013 L p .60977 .56565 L 0 .118 .569 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60977 .56565 L p 0 .118 .569 r
F P
0 g
s
.60977 .56565 m .60057 .55815 L .60577 .56263 L p .494 0 0 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62795 .57868 L p 0 .225 .639 r
F P
0 g
s
.60577 .56263 m .62017 .57505 L p .60977 .56565 L .494 0 0 r
F P
0 g
s
.61889 .5725 m .60977 .56565 L .61509 .56979 L p .467 0 0 r
F P
0 g
s
.61509 .56979 m .63191 .58287 L p .61889 .5725 L .467 0 0 r
F P
0 g
s
.62795 .57868 m .61889 .5725 L .62431 .57622 L p .433 0 0 r
F P
0 g
s
.62431 .57622 m .64357 .58945 L p .62795 .57868 L .433 0 0 r
F P
0 g
s
.64357 .58945 m .65515 .59477 L .63413 .58234 L p .433 0 0 r
F P
0 g
s
.63413 .58234 m .62795 .57868 L p .63064 .58054 L .433 0 0 r
F P
0 g
s
.64357 .58945 m .63413 .58234 L .63064 .58054 L .433 0 0 r
F
.65515 .59477 m .66662 .59881 L .64526 .58829 L p .39 0 0 r
F P
0 g
s
.67167 .59814 m .68923 .60318 L p .67754 .60033 L .215 0 0 r
F P
0 g
s
.66662 .59881 m .67799 .6016 L .65539 .59277 L p .34 0 0 r
F P
0 g
s
.67799 .6016 m .68923 .60318 L .66313 .59569 L p .281 0 0 r
F P
0 g
s
.7539 .59307 m .76424 .58942 L .71382 .60945 L p .297 .782 .709 r
F P
0 g
s
.27785 .44506 m .29152 .43084 L .31822 .4629 L p .877 .802 .772 r
F P
0 g
s
.31822 .4629 m .30633 .47924 L .27785 .44506 L p .877 .802 .772 r
F P
0 g
s
.52156 .49566 m .5219 .4903 L .55289 .51775 L p 0 .322 .809 r
F P
0 g
s
.55289 .51775 m .55584 .52396 L .52156 .49566 L p 0 .322 .809 r
F P
0 g
s
.40966 .39277 m .42083 .39342 L .43962 .41282 L p .457 .627 .926 r
F P
0 g
s
.44873 .41377 m .43962 .41282 L .42083 .39342 L p .309 .555 .922 r
F P
0 g
s
.43962 .41282 m .44873 .41377 L .47019 .43543 L p .291 .503 .89 r
F P
0 g
s
.37041 .37839 m .38315 .37653 L .39847 .39434 L p .661 .78 .937 r
F P
0 g
s
.40966 .39277 m .39847 .39434 L .38315 .37653 L p .558 .742 .962 r
F P
0 g
s
.26403 .46027 m .27785 .44506 L .30633 .47924 L p .882 .799 .763 r
F P
0 g
s
.30633 .47924 m .29434 .49658 L .26403 .46027 L p .882 .799 .763 r
F P
0 g
s
.56165 .53801 m .55876 .53071 L .59506 .55679 L p 0 .335 .808 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56165 .53801 L p 0 .335 .808 r
F P
0 g
s
.47676 .43631 m .47019 .43543 L .44873 .41377 L p .128 .417 .862 r
F P
0 g
s
.47019 .43543 m .47676 .43631 L .49874 .45872 L p .059 .357 .829 r
F P
0 g
s
.49874 .45872 m .49515 .45996 L .47019 .43543 L p .059 .357 .829 r
F P
0 g
s
.25007 .4762 m .26403 .46027 L .29434 .49658 L p .885 .797 .757 r
F P
0 g
s
.29434 .49658 m .28225 .51462 L .25007 .4762 L p .885 .797 .757 r
F P
0 g
s
.38315 .37653 m .39583 .37684 L .40966 .39277 L p .558 .742 .962 r
F P
0 g
s
.42083 .39342 m .40966 .39277 L .39583 .37684 L p .418 .675 .968 r
F P
0 g
s
.49515 .45996 m .49874 .45872 L .52259 .48271 L p 0 .277 .78 r
F P
0 g
s
.52259 .48271 m .52224 .48599 L .49515 .45996 L p 0 .277 .78 r
F P
0 g
s
.5219 .4903 m .52224 .48599 L .54993 .51207 L p 0 .253 .762 r
F P
0 g
s
.54993 .51207 m .55289 .51775 L .5219 .4903 L p 0 .253 .762 r
F P
0 g
s
.42083 .39342 m .43202 .39624 L .44873 .41377 L p .309 .555 .922 r
F P
0 g
s
.4579 .41674 m .44873 .41377 L .43202 .39624 L p .131 .453 .884 r
F P
0 g
s
.44873 .41377 m .4579 .41674 L .47676 .43631 L p .128 .417 .862 r
F P
0 g
s
.236 .49256 m .25007 .4762 L .28225 .51462 L p .886 .795 .754 r
F P
0 g
s
.28225 .51462 m .27008 .53307 L .236 .49256 L p .886 .795 .754 r
F P
0 g
s
.55876 .53071 m .55584 .52396 L .58896 .55013 L p 0 .269 .759 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55876 .53071 L p 0 .269 .759 r
F P
0 g
s
.39583 .37684 m .40847 .37931 L .42083 .39342 L p .418 .675 .968 r
F P
0 g
s
.43202 .39624 m .42083 .39342 L .40847 .37931 L p .243 .575 .942 r
F P
0 g
s
.79464 .57831 m .78459 .58188 L .82464 .54357 L p .664 .958 .741 r
F P
0 g
s
.82464 .54357 m .83625 .53514 L .79464 .57831 L p .664 .958 .741 r
F P
0 g
s
.22182 .50903 m .236 .49256 L .27008 .53307 L p .885 .793 .754 r
F P
0 g
s
.27008 .53307 m .25784 .55162 L .22182 .50903 L p .885 .793 .754 r
F P
0 g
s
.48338 .43889 m .47676 .43631 L .4579 .41674 L p 0 .311 .802 r
F P
0 g
s
.47676 .43631 m .48338 .43889 L .50235 .45886 L p 0 .262 .77 r
F P
0 g
s
.50235 .45886 m .49874 .45872 L .47676 .43631 L p 0 .262 .77 r
F P
0 g
s
.55584 .52396 m .55289 .51775 L .5828 .54342 L p 0 .206 .707 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55584 .52396 L p 0 .206 .707 r
F P
0 g
s
.20758 .52532 m .22182 .50903 L .25784 .55162 L p .882 .792 .755 r
F P
0 g
s
.25784 .55162 m .24558 .56996 L .20758 .52532 L p .882 .792 .755 r
F P
0 g
s
.52224 .48599 m .52259 .48271 L .54694 .5069 L p 0 .183 .706 r
F P
0 g
s
.54694 .5069 m .54993 .51207 L .52224 .48599 L p 0 .183 .706 r
F P
0 g
s
.49874 .45872 m .50235 .45886 L .52293 .48038 L p 0 .193 .717 r
F P
0 g
s
.52293 .48038 m .52259 .48271 L .49874 .45872 L p 0 .193 .717 r
F P
0 g
s
.43202 .39624 m .44326 .40116 L .4579 .41674 L p .131 .453 .884 r
F P
0 g
s
.46713 .42161 m .4579 .41674 L .44326 .40116 L p 0 .332 .811 r
F P
0 g
s
.4579 .41674 m .46713 .42161 L .48338 .43889 L p 0 .311 .802 r
F P
0 g
s
.40847 .37931 m .42111 .38391 L .43202 .39624 L p .243 .575 .942 r
F P
0 g
s
.44326 .40116 m .43202 .39624 L .42111 .38391 L p .05 .447 .877 r
F P
0 g
s
.78459 .58188 m .77446 .58563 L .81294 .5523 L p .597 .921 .689 r
F P
0 g
s
.81294 .5523 m .82464 .54357 L .78459 .58188 L p .597 .921 .689 r
F P
0 g
s
.33584 .36991 m .34959 .36637 L .35759 .38238 L p .762 .909 .94 r
F P
0 g
s
.35759 .38238 m .34465 .38844 L .33584 .36991 L p .762 .909 .94 r
F P
0 g
s
.37041 .37839 m .35759 .38238 L .34959 .36637 L p .684 .888 .973 r
F P
0 g
s
.32193 .37524 m .33584 .36991 L .34465 .38844 L p .815 .916 .906 r
F P
0 g
s
.34465 .38844 m .33159 .39647 L .32193 .37524 L p .815 .916 .906 r
F P
0 g
s
.34959 .36637 m .36321 .36472 L .37041 .37839 L p .684 .888 .973 r
F P
0 g
s
.38315 .37653 m .37041 .37839 L .36321 .36472 L p .573 .843 .996 r
F P
0 g
s
.30786 .38224 m .32193 .37524 L .33159 .39647 L p .852 .916 .875 r
F P
0 g
s
.33159 .39647 m .31838 .40633 L .30786 .38224 L p .852 .916 .875 r
F P
0 g
s
.36321 .36472 m .37672 .36502 L .38315 .37653 L p .573 .843 .996 r
F P
0 g
s
.39583 .37684 m .38315 .37653 L .37672 .36502 L p .427 .767 .996 r
F P
0 g
s
.55289 .51775 m .54993 .51207 L .5766 .53665 L p 0 .147 .655 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55289 .51775 L p 0 .147 .655 r
F P
0 g
s
.29361 .39076 m .30786 .38224 L .31838 .40633 L p .876 .912 .849 r
F P
0 g
s
.31838 .40633 m .30503 .41785 L .29361 .39076 L p .876 .912 .849 r
F P
0 g
s
.49008 .44303 m .48338 .43889 L .46713 .42161 L p 0 .2 .717 r
F P
0 g
s
.48338 .43889 m .49008 .44303 L .50601 .46026 L p 0 .165 .691 r
F P
0 g
s
.50601 .46026 m .50235 .45886 L .48338 .43889 L p 0 .165 .691 r
F P
0 g
s
.37672 .36502 m .39014 .36728 L .39583 .37684 L p .427 .767 .996 r
F P
0 g
s
.40847 .37931 m .39583 .37684 L .39014 .36728 L p .25 .655 .963 r
F P
0 g
s
.52259 .48271 m .52293 .48038 L .54392 .50219 L p 0 .116 .645 r
F P
0 g
s
.54392 .50219 m .54694 .5069 L .52259 .48271 L p 0 .116 .645 r
F P
0 g
s
.42111 .38391 m .43377 .39055 L .44326 .40116 L p .05 .447 .877 r
F P
0 g
s
.45456 .40807 m .44326 .40116 L .43377 .39055 L p 0 .311 .785 r
F P
0 g
s
.44326 .40116 m .45456 .40807 L .46713 .42161 L p 0 .332 .811 r
F P
0 g
s
.77446 .58563 m .76424 .58942 L .80113 .56111 L p .526 .879 .641 r
F P
0 g
s
.80113 .56111 m .81294 .5523 L .77446 .58563 L p .526 .879 .641 r
F P
0 g
s
.47646 .42825 m .46713 .42161 L .45456 .40807 L p 0 .209 .717 r
F P
0 g
s
.46713 .42161 m .47646 .42825 L .49008 .44303 L p 0 .2 .717 r
F P
0 g
s
.27918 .40063 m .29361 .39076 L .30503 .41785 L p .893 .906 .828 r
F P
0 g
s
.30503 .41785 m .29152 .43084 L .27918 .40063 L p .893 .906 .828 r
F P
0 g
s
.50235 .45886 m .50601 .46026 L .52328 .47893 L p 0 .113 .645 r
F P
0 g
s
.52328 .47893 m .52293 .48038 L .50235 .45886 L p 0 .113 .645 r
F P
0 g
s
.39014 .36728 m .40349 .37152 L .40847 .37931 L p .25 .655 .963 r
F P
0 g
s
.42111 .38391 m .40847 .37931 L .40349 .37152 L p .062 .517 .895 r
F P
0 g
s
.26457 .41163 m .27918 .40063 L .29152 .43084 L p .904 .899 .811 r
F P
0 g
s
.29152 .43084 m .27785 .44506 L .26457 .41163 L p .904 .899 .811 r
F P
0 g
s
.54993 .51207 m .54694 .5069 L .57035 .52982 L p 0 .093 .606 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .54993 .51207 L p 0 .093 .606 r
F P
0 g
s
.76424 .58942 m .7539 .59307 L .78265 .57407 L p .453 .834 .601 r
F P
0 g
s
.78265 .57407 m .7892 .56975 L p .78651 .57187 L .453 .834 .601 r
F P
0 g
s
.78651 .57187 m .76424 .58942 L .78265 .57407 L .453 .834 .601 r
F
.77711 .57799 m .7892 .56975 L .7539 .59307 L p 0 0 0 r
F P
0 g
s
.7539 .59307 m .74345 .59642 L .76348 .58545 L p 0 0 0 r
F P
0 g
s
.76638 .58427 m .7539 .59307 L .76348 .58545 L 0 0 0 r
F
.77366 .58023 m .7539 .59307 L .76898 .58244 L F
.76348 .58545 m .76898 .58244 L p .76638 .58427 L F P
0 g
s
.76898 .58244 m .77711 .57799 L p .77366 .58023 L 0 0 0 r
F P
0 g
s
.76487 .58559 m .77711 .57799 L .74646 .59477 L p 0 0 0 r
F P
0 g
s
.76487 .58559 m .74646 .59477 L .74456 .59586 L 0 0 0 r
F
.74646 .59477 m .74345 .59642 L p .74456 .59586 L F P
0 g
s
.74345 .59642 m .73287 .5993 L .74936 .59224 L p 0 0 0 r
F P
0 g
s
.74936 .59224 m .76487 .58559 L p .75561 .59027 L 0 0 0 r
F P
0 g
s
.75561 .59027 m .74345 .59642 L .74936 .59224 L 0 0 0 r
F
.74106 .59579 m .73712 .59749 L p .75246 .59231 L F P
0 g
s
.75246 .59231 m .76487 .58559 L .74106 .59579 L p 0 0 0 r
F P
0 g
s
.73712 .59749 m .73287 .5993 L p .73447 .59873 L 0 0 0 r
F P
0 g
s
.75246 .59231 m .73712 .59749 L .73447 .59873 L 0 0 0 r
F
.73287 .5993 m .72217 .60157 L .75246 .59231 L p F P
0 g
s
.72907 .59946 m .72217 .60157 L p .72563 .60086 L 0 0 0 r
F P
0 g
s
.73987 .59794 m .72907 .59946 L .72563 .60086 L 0 0 0 r
F
.72217 .60157 m .71132 .60305 L .73987 .59794 L p F P
0 g
s
.72711 .60228 m .73987 .59794 L .71983 .60153 L p 0 0 0 r
F P
0 g
s
.71983 .60153 m .71132 .60305 L p .71567 .60284 L 0 0 0 r
F P
0 g
s
.72711 .60228 m .71983 .60153 L .71567 .60284 L 0 0 0 r
F
.73987 .59794 m .75246 .59231 L .72907 .59946 L p F P
0 g
s
.7892 .56975 m .80113 .56111 L .76424 .58942 L p .453 .834 .601 r
F P
0 g
s
.40349 .37152 m .41682 .37767 L .42111 .38391 L p .062 .517 .895 r
F P
0 g
s
.43377 .39055 m .42111 .38391 L .41682 .37767 L p 0 .374 .804 r
F P
0 g
s
.43377 .39055 m .44647 .39913 L .45456 .40807 L p 0 .311 .785 r
F P
0 g
s
.46596 .41683 m .45456 .40807 L .44647 .39913 L p 0 .186 .684 r
F P
0 g
s
.45456 .40807 m .46596 .41683 L .47646 .42825 L p 0 .209 .717 r
F P
0 g
s
.52293 .48038 m .52328 .47893 L .54087 .4979 L p 0 .056 .585 r
F P
0 g
s
.54087 .4979 m .54392 .50219 L .52293 .48038 L p 0 .056 .585 r
F P
0 g
s
.24977 .42353 m .26457 .41163 L .27785 .44506 L p .911 .892 .799 r
F P
0 g
s
.27785 .44506 m .26403 .46027 L .24977 .42353 L p .911 .892 .799 r
F P
0 g
s
.49687 .44858 m .49008 .44303 L .47646 .42825 L p 0 .099 .624 r
F P
0 g
s
.49008 .44303 m .49687 .44858 L .50971 .46279 L p 0 .077 .608 r
F P
0 g
s
.50971 .46279 m .50601 .46026 L .49008 .44303 L p 0 .077 .608 r
F P
0 g
s
.4859 .43648 m .47646 .42825 L .46596 .41683 L p 0 .102 .62 r
F P
0 g
s
.47646 .42825 m .4859 .43648 L .49687 .44858 L p 0 .099 .624 r
F P
0 g
s
.50601 .46026 m .50971 .46279 L .52364 .47824 L p 0 .043 .574 r
F P
0 g
s
.52364 .47824 m .52328 .47893 L .50601 .46026 L p 0 .043 .574 r
F P
0 g
s
.54694 .5069 m .54392 .50219 L .56404 .52294 L p 0 .047 .561 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54694 .5069 L p 0 .047 .561 r
F P
0 g
s
.41682 .37767 m .43013 .38568 L .43377 .39055 L p 0 .374 .804 r
F P
0 g
s
.44647 .39913 m .43377 .39055 L .43013 .38568 L p 0 .243 .708 r
F P
0 g
s
.23481 .4361 m .24977 .42353 L .26403 .46027 L p .914 .886 .791 r
F P
0 g
s
.26403 .46027 m .25007 .4762 L .23481 .4361 L p .914 .886 .791 r
F P
0 g
s
.44647 .39913 m .45925 .40949 L .46596 .41683 L p 0 .186 .684 r
F P
0 g
s
.47747 .42724 m .46596 .41683 L .45925 .40949 L p 0 .085 .593 r
F P
0 g
s
.46596 .41683 m .47747 .42724 L .4859 .43648 L p 0 .102 .62 r
F P
0 g
s
.60057 .55815 m .60977 .56565 L .60419 .56105 L p .456 0 0 r
F P
0 g
s
.60419 .56105 m .5828 .54342 L p .60057 .55815 L .456 0 0 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .60057 .55815 L p .456 0 0 r
F P
0 g
s
.60057 .55815 m .59131 .55002 L .59638 .55478 L p .515 0 0 r
F P
0 g
s
.59638 .55478 m .60837 .56606 L p .60057 .55815 L .515 0 0 r
F P
0 g
s
.2197 .44906 m .23481 .4361 L .25007 .4762 L p .915 .879 .786 r
F P
0 g
s
.25007 .4762 m .236 .49256 L .2197 .44906 L p .915 .879 .786 r
F P
0 g
s
.52328 .47893 m .52364 .47824 L .53779 .49398 L p 0 .006 .531 r
F P
0 g
s
.53779 .49398 m .54087 .4979 L .52328 .47893 L p 0 .006 .531 r
F P
0 g
s
.43013 .38568 m .44347 .39542 L .44647 .39913 L p 0 .243 .708 r
F P
0 g
s
.45925 .40949 m .44647 .39913 L .44347 .39542 L p 0 .135 .621 r
F P
0 g
s
.54392 .50219 m .54087 .4979 L .55769 .51601 L p 0 .007 .522 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54392 .50219 L p 0 .007 .522 r
F P
0 g
s
.50376 .45533 m .49687 .44858 L .4859 .43648 L p 0 .018 .542 r
F P
0 g
s
.49687 .44858 m .50376 .45533 L .51347 .46627 L p 0 .006 .532 r
F P
0 g
s
.51347 .46627 m .50971 .46279 L .49687 .44858 L p 0 .006 .532 r
F P
0 g
s
.36661 .3583 m .38001 .36083 L .37672 .36502 L p .28 .754 .936 r
F P
0 g
s
.37672 .36502 m .36321 .36472 L .36661 .3583 L p .28 .754 .936 r
F P
0 g
s
.39014 .36728 m .37672 .36502 L .38001 .36083 L p .117 .632 .891 r
F P
0 g
s
.35309 .35737 m .36661 .3583 L .36321 .36472 L p .432 .851 .956 r
F P
0 g
s
.36321 .36472 m .34959 .36637 L .35309 .35737 L p .432 .851 .956 r
F P
0 g
s
.38001 .36083 m .39331 .365 L .39014 .36728 L p .117 .632 .891 r
F P
0 g
s
.40349 .37152 m .39014 .36728 L .39331 .365 L p 0 .496 .824 r
F P
0 g
s
.49547 .44607 m .4859 .43648 L .47747 .42724 L p 0 .019 .537 r
F P
0 g
s
.4859 .43648 m .49547 .44607 L .50376 .45533 L p 0 .018 .542 r
F P
0 g
s
.33942 .35802 m .35309 .35737 L .34959 .36637 L p .559 .918 .954 r
F P
0 g
s
.34959 .36637 m .33584 .36991 L .33942 .35802 L p .559 .918 .954 r
F P
0 g
s
.50971 .46279 m .51347 .46627 L .524 .47819 L p 0 0 .512 r
F P
0 g
s
.524 .47819 m .51347 .46627 L p .52295 .47704 L .534 .054 0 r
F P
0 g
s
.524 .47819 m .5238 .47821 L p .52113 .47509 L 0 0 .512 r
F P
0 g
s
.52437 .47865 m .52427 .47853 L p .52295 .47704 L .534 .054 0 r
F P
0 g
s
.52427 .47853 m .524 .47819 L p .52295 .47704 L .534 .054 0 r
F P
0 g
s
.52364 .47824 m .50971 .46279 L p .52113 .47509 L 0 0 .512 r
F P
0 g
s
.52364 .47824 m .524 .47819 L .53468 .49035 L p 0 0 .486 r
F P
0 g
s
.53468 .49035 m .53779 .49398 L .53449 .4903 L p 0 0 .486 r
F P
0 g
s
.53449 .4903 m .52364 .47824 L p .53144 .4868 L 0 0 .486 r
F P
0 g
s
.53468 .49035 m .53449 .4903 L .53144 .4868 L 0 0 .486 r
F
.524 .47819 m .52437 .47865 L .52583 .48035 L p .546 .063 0 r
F P
0 g
s
.52583 .48035 m .53153 .48694 L p .52792 .48274 L .546 .063 0 r
F P
0 g
s
.52792 .48274 m .524 .47819 L .52583 .48035 L .546 .063 0 r
F
.52117 .47532 m .52474 .47946 L p .51919 .4728 L .565 .08 0 r
F P
0 g
s
.51729 .47052 m .52437 .47865 L p .51702 .47029 L .534 .054 0 r
F P
0 g
s
.51729 .47052 m .51854 .47206 L p .51919 .4728 L .565 .08 0 r
F P
0 g
s
.51854 .47206 m .52117 .47532 L p .51919 .4728 L .565 .08 0 r
F P
0 g
s
.51347 .46627 m .51547 .46849 L p .51702 .47029 L .534 .054 0 r
F P
0 g
s
.51547 .46849 m .51729 .47052 L p .51702 .47029 L .534 .054 0 r
F P
0 g
s
.5238 .47821 m .52364 .47824 L p .52113 .47509 L 0 0 .512 r
F P
0 g
s
.20445 .46214 m .2197 .44906 L .236 .49256 L p .913 .873 .784 r
F P
0 g
s
.236 .49256 m .22182 .50903 L .20445 .46214 L p .913 .873 .784 r
F P
0 g
s
.59131 .55002 m .60057 .55815 L .59512 .55326 L p .484 0 0 r
F P
0 g
s
.59512 .55326 m .5766 .53665 L p .59131 .55002 L .484 0 0 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59131 .55002 L p .484 0 0 r
F P
0 g
s
.59131 .55002 m .582 .54131 L .58692 .54628 L p .532 0 0 r
F P
0 g
s
.58692 .54628 m .59653 .55599 L p .59131 .55002 L .532 0 0 r
F P
0 g
s
.39331 .365 m .40652 .37078 L .40349 .37152 L p 0 .496 .824 r
F P
0 g
s
.41682 .37767 m .40349 .37152 L .40652 .37078 L p 0 .364 .747 r
F P
0 g
s
.3256 .36015 m .33942 .35802 L .33584 .36991 L p .658 .959 .937 r
F P
0 g
s
.33584 .36991 m .32193 .37524 L .3256 .36015 L p .658 .959 .937 r
F P
0 g
s
.83625 .53514 m .82464 .54357 L .84648 .49883 L p .847 .994 .747 r
F P
0 g
s
.84648 .49883 m .85906 .48583 L .83625 .53514 L p .847 .994 .747 r
F P
0 g
s
.40652 .37078 m .41967 .37816 L .41682 .37767 L p 0 .364 .747 r
F P
0 g
s
.43013 .38568 m .41682 .37767 L .41967 .37816 L p 0 .247 .671 r
F P
0 g
s
.44347 .39542 m .45684 .40677 L .45925 .40949 L p 0 .135 .621 r
F P
0 g
s
.47214 .42145 m .45925 .40949 L .45684 .40677 L p 0 .052 .549 r
F P
0 g
s
.45925 .40949 m .47214 .42145 L .47747 .42724 L p 0 .085 .593 r
F P
0 g
s
.48913 .43907 m .47747 .42724 L .47214 .42145 L p 0 .008 .52 r
F P
0 g
s
.47747 .42724 m .48913 .43907 L .49547 .44607 L p 0 .019 .537 r
F P
0 g
s
.3116 .36367 m .3256 .36015 L .32193 .37524 L p .732 .98 .915 r
F P
0 g
s
.32193 .37524 m .30786 .38224 L .3116 .36367 L p .732 .98 .915 r
F P
0 g
s
.54087 .4979 m .53779 .49398 L .55128 .50901 L p 0 0 .488 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54087 .4979 L p 0 0 .488 r
F P
0 g
s
.18911 .47507 m .20445 .46214 L .22182 .50903 L p .909 .867 .786 r
F P
0 g
s
.22182 .50903 m .20758 .52532 L .18911 .47507 L p .909 .867 .786 r
F P
0 g
s
.582 .54131 m .59131 .55002 L .57035 .52982 L p .508 0 0 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .582 .54131 L p .508 0 0 r
F P
0 g
s
.41967 .37816 m .43278 .38705 L .43013 .38568 L p 0 .247 .671 r
F P
0 g
s
.44347 .39542 m .43013 .38568 L .43278 .38705 L p 0 .15 .603 r
F P
0 g
s
.29742 .36844 m .3116 .36367 L .30786 .38224 L p .786 .988 .891 r
F P
0 g
s
.30786 .38224 m .29361 .39076 L .29742 .36844 L p .786 .988 .891 r
F P
0 g
s
.82464 .54357 m .81294 .5523 L .83383 .51221 L p .823 .988 .721 r
F P
0 g
s
.83383 .51221 m .84648 .49883 L .82464 .54357 L p .823 .988 .721 r
F P
0 g
s
.51076 .46307 m .50376 .45533 L .49547 .44607 L p 0 0 .478 r
F P
0 g
s
.50376 .45533 m .51076 .46307 L .51729 .47052 L p 0 0 .474 r
F P
0 g
s
.51347 .46627 m .50376 .45533 L p .51613 .46922 L 0 0 .474 r
F P
0 g
s
.51787 .47154 m .52117 .47532 L p .51239 .46499 L .563 .078 0 r
F P
0 g
s
.51076 .46307 m .51203 .46459 L p .51239 .46499 L .563 .078 0 r
F P
0 g
s
.51203 .46459 m .51787 .47154 L p .51239 .46499 L .563 .078 0 r
F P
0 g
s
.51729 .47052 m .5168 .46997 L p .51613 .46922 L 0 0 .474 r
F P
0 g
s
.5168 .46997 m .51347 .46627 L p .51613 .46922 L 0 0 .474 r
F P
0 g
s
.50519 .45679 m .49547 .44607 L .48913 .43907 L p 0 0 .475 r
F P
0 g
s
.49547 .44607 m .50519 .45679 L .51076 .46307 L p 0 0 .478 r
F P
0 g
s
.45684 .40677 m .44347 .39542 L .44588 .39736 L p 0 .072 .547 r
F P
0 g
s
.43278 .38705 m .44588 .39736 L .44347 .39542 L p 0 .15 .603 r
F P
0 g
s
.45684 .40677 m .47029 .41955 L .47214 .42145 L p 0 .052 .549 r
F P
0 g
s
.48515 .4348 m .47214 .42145 L .47029 .41955 L p 0 0 .494 r
F P
0 g
s
.47214 .42145 m .48515 .4348 L .48913 .43907 L p 0 .008 .52 r
F P
0 g
s
.57263 .53207 m .582 .54131 L .56404 .52294 L p .527 .022 0 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57263 .53207 L p .527 .022 0 r
F P
0 g
s
.28306 .37433 m .29742 .36844 L .29361 .39076 L p .825 .989 .871 r
F P
0 g
s
.29361 .39076 m .27918 .40063 L .28306 .37433 L p .825 .989 .871 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53779 .49398 L p .538 .052 0 r
F P
0 g
s
.53779 .49398 m .53468 .49035 L .54482 .50197 L p .538 .052 0 r
F P
0 g
s
.63191 .58287 m .64357 .58945 L .61889 .5725 L p .467 0 0 r
F P
0 g
s
.48913 .43907 m .50094 .45209 L .50519 .45679 L p 0 0 .475 r
F P
0 g
s
.50094 .45209 m .48913 .43907 L .48515 .4348 L p .532 .045 0 r
F P
0 g
s
.81294 .5523 m .80113 .56111 L .82107 .52569 L p .795 .979 .701 r
F P
0 g
s
.82107 .52569 m .83383 .51221 L .81294 .5523 L p .795 .979 .701 r
F P
0 g
s
.53153 .48694 m .53468 .49035 L .524 .47819 L p .546 .063 0 r
F P
0 g
s
.71132 .60305 m .70034 .60363 L .72711 .60228 L p 0 0 0 r
F P
0 g
s
.44588 .39736 m .45898 .40897 L .45684 .40677 L p 0 .072 .547 r
F P
0 g
s
.47029 .41955 m .45684 .40677 L .45898 .40897 L p .498 0 0 r
F P
0 g
s
.2685 .38115 m .28306 .37433 L .27918 .40063 L p .853 .985 .854 r
F P
0 g
s
.27918 .40063 m .26457 .41163 L .2685 .38115 L p .853 .985 .854 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56321 .52236 L p .543 .044 0 r
F P
0 g
s
.56321 .52236 m .57263 .53207 L .55769 .51601 L p .543 .044 0 r
F P
0 g
s
.62017 .57505 m .63191 .58287 L .60977 .56565 L p .494 0 0 r
F P
0 g
s
.47029 .41955 m .48382 .43355 L .48515 .4348 L p 0 0 .494 r
F P
0 g
s
.49831 .44928 m .48515 .4348 L .48382 .43355 L p .545 .053 0 r
F P
0 g
s
.48515 .4348 m .49831 .44928 L .50094 .45209 L p .532 .045 0 r
F P
0 g
s
.70034 .60363 m .68923 .60318 L .71419 .60514 L p .018 0 0 r
F P
0 g
s
.71419 .60514 m .72711 .60228 L .70034 .60363 L p .018 0 0 r
F P
0 g
s
.45898 .40897 m .47211 .42173 L .47029 .41955 L p .498 0 0 r
F P
0 g
s
.48382 .43355 m .47029 .41955 L .47211 .42173 L p .533 .032 0 r
F P
0 g
s
.80113 .56111 m .7892 .56975 L .80817 .53899 L p .763 .97 .688 r
F P
0 g
s
.80817 .53899 m .82107 .52569 L .80113 .56111 L p .763 .97 .688 r
F P
0 g
s
.53468 .49035 m .53153 .48694 L .5383 .49486 L p .558 .072 0 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53468 .49035 L p .558 .072 0 r
F P
0 g
s
.60837 .56606 m .62017 .57505 L .60057 .55815 L p .515 0 0 r
F P
0 g
s
.51787 .47154 m .51076 .46307 L .50519 .45679 L p .562 .077 0 r
F P
0 g
s
.52117 .47532 m .51729 .47052 L .51076 .46307 L p .563 .078 0 r
F P
0 g
s
.25376 .38872 m .2685 .38115 L .26457 .41163 L p .873 .979 .842 r
F P
0 g
s
.26457 .41163 m .24977 .42353 L .25376 .38872 L p .873 .979 .842 r
F P
0 g
s
.51506 .46836 m .50519 .45679 L .50094 .45209 L p .563 .077 0 r
F P
0 g
s
.50519 .45679 m .51506 .46836 L .51787 .47154 L p .562 .077 0 r
F P
0 g
s
.52474 .47946 m .52437 .47865 L .51729 .47052 L p .565 .08 0 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55375 .51226 L p .556 .063 0 r
F P
0 g
s
.55375 .51226 m .56321 .52236 L .55128 .50901 L p .556 .063 0 r
F P
0 g
s
.51293 .46599 m .50094 .45209 L .49831 .44928 L p .565 .078 0 r
F P
0 g
s
.50094 .45209 m .51293 .46599 L .51506 .46836 L p .563 .077 0 r
F P
0 g
s
.40562 .37052 m .41775 .37752 L .40652 .37078 L p .29 0 0 r
F P
0 g
s
.40652 .37078 m .39331 .365 L .40562 .37052 L p .29 0 0 r
F P
0 g
s
.41967 .37816 m .40652 .37078 L .41775 .37752 L p .367 0 0 r
F P
0 g
s
.41775 .37752 m .42981 .38564 L .41967 .37816 L p .367 0 0 r
F P
0 g
s
.43278 .38705 m .41967 .37816 L .42981 .38564 L p .427 0 0 r
F P
0 g
s
.39339 .36468 m .40562 .37052 L .39331 .365 L p 0 .391 .69 r
F P
0 g
s
.39331 .365 m .38001 .36083 L .39339 .36468 L p 0 .391 .69 r
F P
0 g
s
.59653 .55599 m .60837 .56606 L .59131 .55002 L p .532 0 0 r
F P
0 g
s
.52437 .47865 m .52474 .47946 L .52834 .48368 L p .569 .083 0 r
F P
0 g
s
.52834 .48368 m .53153 .48694 L .52437 .47865 L p .569 .083 0 r
F P
0 g
s
.68923 .60318 m .67799 .6016 L .7011 .60639 L p .103 0 0 r
F P
0 g
s
.7011 .60639 m .71419 .60514 L .68923 .60318 L p .103 0 0 r
F P
0 g
s
.42981 .38564 m .44181 .39482 L .43278 .38705 L p .427 0 0 r
F P
0 g
s
.44588 .39736 m .43278 .38705 L .44181 .39482 L p .473 0 0 r
F P
0 g
s
.38106 .35999 m .39339 .36468 L .38001 .36083 L p 0 .498 .738 r
F P
0 g
s
.38001 .36083 m .36661 .3583 L .38106 .35999 L p 0 .498 .738 r
F P
0 g
s
.47211 .42173 m .48527 .43547 L .48382 .43355 L p .533 .032 0 r
F P
0 g
s
.49746 .44855 m .48382 .43355 L .48527 .43547 L p .556 .063 0 r
F P
0 g
s
.48382 .43355 m .49746 .44855 L .49831 .44928 L p .545 .053 0 r
F P
0 g
s
.23884 .39683 m .25376 .38872 L .24977 .42353 L p .886 .972 .833 r
F P
0 g
s
.24977 .42353 m .23481 .4361 L .23884 .39683 L p .886 .972 .833 r
F P
0 g
s
.7892 .56975 m .77711 .57799 L .79511 .5518 L p .726 .96 .683 r
F P
0 g
s
.79511 .5518 m .80817 .53899 L .7892 .56975 L p .726 .96 .683 r
F P
0 g
s
.44181 .39482 m .45376 .405 L .44588 .39736 L p .473 0 0 r
F P
0 g
s
.45898 .40897 m .44588 .39736 L .45376 .405 L p .508 0 0 r
F P
0 g
s
.36861 .35645 m .38106 .35999 L .36661 .3583 L p .038 .604 .78 r
F P
0 g
s
.36661 .3583 m .35309 .35737 L .36861 .35645 L p .038 .604 .78 r
F P
0 g
s
.51162 .4646 m .49831 .44928 L .49746 .44855 L p .568 .08 0 r
F P
0 g
s
.49831 .44928 m .51162 .4646 L .51293 .46599 L p .565 .078 0 r
F P
0 g
s
.582 .54131 m .57263 .53207 L .58465 .54495 L p .544 .024 0 r
F P
0 g
s
.58465 .54495 m .59653 .55599 L .582 .54131 L p .544 .024 0 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54424 .50186 L p .567 .077 0 r
F P
0 g
s
.54424 .50186 m .55375 .51226 L .54482 .50197 L p .567 .077 0 r
F P
0 g
s
.53153 .48694 m .52834 .48368 L .53174 .48769 L p .572 .086 0 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53153 .48694 L p .572 .086 0 r
F P
0 g
s
.45376 .405 m .46567 .41608 L .45898 .40897 L p .508 0 0 r
F P
0 g
s
.47211 .42173 m .45898 .40897 L .46567 .41608 L p .533 .021 0 r
F P
0 g
s
.67799 .6016 m .66662 .59881 L .68787 .60591 L p .187 0 0 r
F P
0 g
s
.68787 .60591 m .7011 .60639 L .67799 .6016 L p .187 0 0 r
F P
0 g
s
.35602 .35403 m .36861 .35645 L .35309 .35737 L p .165 .702 .814 r
F P
0 g
s
.35309 .35737 m .33942 .35802 L .35602 .35403 L p .165 .702 .814 r
F P
0 g
s
.57263 .53207 m .56321 .52236 L .57275 .53308 L p .555 .046 0 r
F P
0 g
s
.57275 .53308 m .58465 .54495 L .57263 .53207 L p .555 .046 0 r
F P
0 g
s
.46567 .41608 m .47757 .42795 L .47211 .42173 L p .533 .021 0 r
F P
0 g
s
.48527 .43547 m .47211 .42173 L .47757 .42795 L p .552 .05 0 r
F P
0 g
s
.22376 .40525 m .23884 .39683 L .23481 .4361 L p .895 .963 .829 r
F P
0 g
s
.23481 .4361 m .2197 .44906 L .22376 .40525 L p .895 .963 .829 r
F P
0 g
s
.48527 .43547 m .49849 .44998 L .49746 .44855 L p .556 .063 0 r
F P
0 g
s
.51122 .46428 m .49746 .44855 L .49849 .44998 L p .572 .083 0 r
F P
0 g
s
.49746 .44855 m .51122 .46428 L .51162 .4646 L p .568 .08 0 r
F P
0 g
s
.77711 .57799 m .76487 .58559 L .78187 .56382 L p .684 .95 .685 r
F P
0 g
s
.78187 .56382 m .79511 .5518 L .77711 .57799 L p .684 .95 .685 r
F P
0 g
s
.34329 .35266 m .35602 .35403 L .33942 .35802 L p .288 .787 .837 r
F P
0 g
s
.33942 .35802 m .3256 .36015 L .34329 .35266 L p .288 .787 .837 r
F P
0 g
s
.52511 .48046 m .51787 .47154 L .51506 .46836 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .52117 .47532 L .51787 .47154 L closepath p .58 .094 0 r
F P
0 g
s
.66662 .59881 m .65515 .59477 L .67451 .60364 L p .264 0 0 r
F P
0 g
s
.67451 .60364 m .68787 .60591 L .66662 .59881 L p .264 0 0 r
F P
0 g
s
.52511 .48046 m .51506 .46836 L .51293 .46599 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .52474 .47946 L .52117 .47532 L closepath p .58 .094 0 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .5347 .49123 L p .575 .087 0 r
F P
0 g
s
.5347 .49123 m .54424 .50186 L .5383 .49486 L p .575 .087 0 r
F P
0 g
s
.56321 .52236 m .55375 .51226 L .56084 .52053 L p .563 .063 0 r
F P
0 g
s
.56084 .52053 m .57275 .53308 L .56321 .52236 L p .563 .063 0 r
F P
0 g
s
.52511 .48046 m .51293 .46599 L .51162 .4646 L closepath p .58 .094 0 r
F P
0 g
s
.47757 .42795 m .48945 .44047 L .48527 .43547 L p .552 .05 0 r
F P
0 g
s
.49849 .44998 m .48527 .43547 L .48945 .44047 L p .565 .071 0 r
F P
0 g
s
.52511 .48046 m .52834 .48368 L .52474 .47946 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .51162 .4646 L .51122 .46428 L closepath p .58 .094 0 r
F P
0 g
s
.65515 .59477 m .64357 .58945 L .66104 .59954 L p .333 0 0 r
F P
0 g
s
.66104 .59954 m .67451 .60364 L .65515 .59477 L p .333 0 0 r
F P
0 g
s
.33041 .35228 m .34329 .35266 L .3256 .36015 L p .4 .856 .852 r
F P
0 g
s
.3256 .36015 m .3116 .36367 L .33041 .35228 L p .4 .856 .852 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52834 .48368 L closepath p .58 .094 0 r
F P
0 g
s
.55375 .51226 m .54424 .50186 L .54893 .50746 L p .57 .077 0 r
F P
0 g
s
.54893 .50746 m .56084 .52053 L .55375 .51226 L p .57 .077 0 r
F P
0 g
s
.20853 .41376 m .22376 .40525 L .2197 .44906 L p .899 .953 .827 r
F P
0 g
s
.2197 .44906 m .20445 .46214 L .20853 .41376 L p .899 .953 .827 r
F P
0 g
s
.48945 .44047 m .50134 .4535 L .49849 .44998 L p .565 .071 0 r
F P
0 g
s
.51177 .46506 m .49849 .44998 L .50134 .4535 L p .574 .086 0 r
F P
0 g
s
.49849 .44998 m .51177 .46506 L .51122 .46428 L p .572 .083 0 r
F P
0 g
s
.52511 .48046 m .51122 .46428 L .51177 .46506 L closepath p .58 .094 0 r
F P
0 g
s
.76487 .58559 m .75246 .59231 L .76845 .57475 L p .636 .937 .696 r
F P
0 g
s
.76845 .57475 m .78187 .56382 L .76487 .58559 L p .636 .937 .696 r
F P
0 g
s
.64357 .58945 m .63191 .58287 L .64748 .59363 L p .391 0 0 r
F P
0 g
s
.64748 .59363 m .66104 .59954 L .64357 .58945 L p .391 0 0 r
F P
0 g
s
.52511 .48046 m .5347 .49123 L .53174 .48769 L closepath p .58 .094 0 r
F P
0 g
s
.54424 .50186 m .5347 .49123 L .53702 .49405 L p .576 .087 0 r
F P
0 g
s
.53702 .49405 m .54893 .50746 L .54424 .50186 L p .576 .087 0 r
F P
0 g
s
.85906 .48583 m .84648 .49883 L .84705 .45014 L p .939 .949 .76 r
F P
0 g
s
.84705 .45014 m .85986 .43317 L .85906 .48583 L p .939 .949 .76 r
F P
0 g
s
.31737 .35279 m .33041 .35228 L .3116 .36367 L p .498 .907 .86 r
F P
0 g
s
.3116 .36367 m .29742 .36844 L .31737 .35279 L p .498 .907 .86 r
F P
0 g
s
.50134 .4535 m .51322 .46689 L .51177 .46506 L p .574 .086 0 r
F P
0 g
s
.52511 .48046 m .51177 .46506 L .51322 .46689 L closepath p .58 .094 0 r
F P
0 g
s
.63191 .58287 m .62017 .57505 L .63386 .58597 L p .438 0 0 r
F P
0 g
s
.63386 .58597 m .64748 .59363 L .63191 .58287 L p .438 0 0 r
F P
0 g
s
.52511 .48046 m .53702 .49405 L .5347 .49123 L closepath p .58 .094 0 r
F P
0 g
s
.62017 .57505 m .60837 .56606 L .62019 .57666 L p .475 0 0 r
F P
0 g
s
.62019 .57666 m .63386 .58597 L .62017 .57505 L p .475 0 0 r
F P
0 g
s
.19318 .42214 m .20853 .41376 L .20445 .46214 L p .899 .943 .829 r
F P
0 g
s
.20445 .46214 m .18911 .47507 L .19318 .42214 L p .899 .943 .829 r
F P
0 g
s
.47661 .42778 m .4864 .43788 L .47757 .42795 L p .548 .04 0 r
F P
0 g
s
.47757 .42795 m .46567 .41608 L .47661 .42778 L p .548 .04 0 r
F P
0 g
s
.48945 .44047 m .47757 .42795 L .4864 .43788 L p .56 .061 0 r
F P
0 g
s
.4864 .43788 m .49614 .44828 L .48945 .44047 L p .56 .061 0 r
F P
0 g
s
.50134 .4535 m .48945 .44047 L .49614 .44828 L p .569 .076 0 r
F P
0 g
s
.46677 .41806 m .45687 .40876 L .46191 .41357 L p .497 0 0 r
F P
0 g
s
.46677 .41806 m .47661 .42778 L .47222 .42308 L p .532 .013 0 r
F P
0 g
s
.4864 .43788 m .47661 .42778 L .49116 .44341 L p .54 .041 0 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47661 .42778 L p .521 .017 0 r
F P
0 g
s
.47661 .42778 m .46677 .41806 L .48419 .43581 L p .521 .017 0 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46677 .41806 L p .497 0 0 r
F P
0 g
s
.46191 .41357 m .47717 .42815 L p .46677 .41806 L .497 0 0 r
F P
0 g
s
.47222 .42308 m .46567 .41608 L p .46677 .41806 L .532 .013 0 r
F P
0 g
s
.46567 .41608 m .45376 .405 L .46677 .41806 L p .532 .013 0 r
F P
0 g
s
.75246 .59231 m .73987 .59794 L .75484 .58433 L p .577 .92 .714 r
F P
0 g
s
.75484 .58433 m .76845 .57475 L .75246 .59231 L p .577 .92 .714 r
F P
0 g
s
.49614 .44828 m .50584 .4589 L .50134 .4535 L p .569 .076 0 r
F P
0 g
s
.51322 .46689 m .50134 .4535 L .50584 .4589 L p .575 .087 0 r
F P
0 g
s
.44691 .39995 m .45687 .40876 L .4523 .40453 L p .484 0 0 r
F P
0 g
s
.4523 .40453 m .44181 .39482 L p .44691 .39995 L .484 0 0 r
F P
0 g
s
.44181 .39482 m .42981 .38564 L .44691 .39995 L p .484 0 0 r
F P
0 g
s
.43688 .39167 m .44691 .39995 L .44226 .39606 L p .448 0 0 r
F P
0 g
s
.44226 .39606 m .42981 .38564 L p .43688 .39167 L .448 0 0 r
F P
0 g
s
.42981 .38564 m .41775 .37752 L .43082 .38719 L p .448 0 0 r
F P
0 g
s
.43082 .38719 m .43688 .39167 L p .43484 .38993 L .448 0 0 r
F P
0 g
s
.42981 .38564 m .43082 .38719 L .43484 .38993 L .448 0 0 r
F
.42677 .38394 m .43688 .39167 L .43215 .38817 L p .402 0 0 r
F P
0 g
s
.43215 .38817 m .41775 .37752 L p .42677 .38394 L .402 0 0 r
F P
0 g
s
.41775 .37752 m .40562 .37052 L .42101 .38029 L p .402 0 0 r
F P
0 g
s
.42101 .38029 m .42677 .38394 L p .42474 .3825 L .402 0 0 r
F P
0 g
s
.41775 .37752 m .42101 .38029 L .42474 .3825 L .402 0 0 r
F
.41669 .37755 m .40562 .37052 L p .41042 .37327 L .345 0 0 r
F P
0 g
s
.41042 .37327 m .41657 .3768 L .41669 .37755 L .345 0 0 r
F
.40562 .37052 m .39339 .36468 L .41113 .37395 L p F P
0 g
s
.41113 .37395 m .41657 .3768 L p .41461 .37567 L .345 0 0 r
F P
0 g
s
.40562 .37052 m .41113 .37395 L .41461 .37567 L .345 0 0 r
F
.40412 .37028 m .39339 .36468 L p .398 .36666 L .276 0 0 r
F P
0 g
s
.398 .36666 m .40629 .37023 L .40412 .37028 L .276 0 0 r
F
.39339 .36468 m .38106 .35999 L .40118 .36815 L p F P
0 g
s
.40118 .36815 m .40629 .37023 L p .40442 .36942 L .276 0 0 r
F P
0 g
s
.39339 .36468 m .40118 .36815 L .40442 .36942 L .276 0 0 r
F
.39139 .36418 m .38106 .35999 L p .38546 .36125 L .194 0 0 r
F P
0 g
s
.38546 .36125 m .3959 .36423 L .39139 .36418 L .194 0 0 r
F
.38106 .35999 m .36861 .35645 L .3959 .36423 L p F P
0 g
s
.38541 .3588 m .3959 .36423 L .37849 .35927 L p 0 .485 .722 r
F P
0 g
s
.37849 .35927 m .36861 .35645 L p .37278 .35703 L 0 .485 .722 r
F P
0 g
s
.37278 .35703 m .38541 .3588 L .37849 .35927 L 0 .485 .722 r
F
.3959 .36423 m .40629 .37023 L .39139 .36418 L p .194 0 0 r
F P
0 g
s
.40629 .37023 m .41657 .3768 L .40412 .37028 L p .276 0 0 r
F P
0 g
s
.42677 .38394 m .41657 .3768 L .42201 .38021 L p 0 .206 .646 r
F P
0 g
s
.42201 .38021 m .44846 .39682 L p .42677 .38394 L 0 .206 .646 r
F P
0 g
s
.41657 .3768 m .42677 .38394 L .41669 .37755 L p .345 0 0 r
F P
0 g
s
.43688 .39167 m .42677 .38394 L .43212 .38779 L p 0 .146 .603 r
F P
0 g
s
.45376 .405 m .44181 .39482 L .45687 .40876 L p .511 0 0 r
F P
0 g
s
.43212 .38779 m .45573 .40475 L p .43688 .39167 L 0 .146 .603 r
F P
0 g
s
.44691 .39995 m .43688 .39167 L .44213 .39589 L p 0 .095 .564 r
F P
0 g
s
.46228 .41356 m .45376 .405 L p .45687 .40876 L .511 0 0 r
F P
0 g
s
.44213 .39589 m .46294 .41262 L p .44691 .39995 L 0 .095 .564 r
F P
0 g
s
.45687 .40876 m .44691 .39995 L .45205 .4045 L p 0 .051 .531 r
F P
0 g
s
.45205 .4045 m .47008 .42042 L p .45687 .40876 L 0 .051 .531 r
F P
0 g
s
.45687 .40876 m .46677 .41806 L .46228 .41356 L p .511 0 0 r
F P
0 g
s
.50584 .4589 m .51549 .46966 L .51322 .46689 L p .575 .087 0 r
F P
0 g
s
.52511 .48046 m .51322 .46689 L .51549 .46966 L closepath p .58 .094 0 r
F P
0 g
s
.60837 .56606 m .59653 .55599 L .60651 .56584 L p .504 0 0 r
F P
0 g
s
.60651 .56584 m .62019 .57666 L .60837 .56606 L p .504 0 0 r
F P
0 g
s
.52511 .48046 m .53534 .49279 L .53749 .49517 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .53249 .48955 L .53534 .49279 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .52913 .48569 L .53249 .48955 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .5255 .48148 L .52913 .48569 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .52185 .47721 L .5255 .48148 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47721 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .51549 .46966 L .51844 .47318 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .53853 .49595 L .53702 .49405 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .53914 .4968 L .53853 .49595 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .53878 .49654 L .53914 .4968 L closepath p .58 .094 0 r
F P
0 g
s
.52511 .48046 m .53749 .49517 L .53878 .49654 L closepath p .58 .094 0 r
F P
0 g
s
.54893 .50746 m .53702 .49405 L .53853 .49595 L p .575 .086 0 r
F P
0 g
s
.59653 .55599 m .58465 .54495 L .59284 .55368 L p .526 0 0 r
F P
0 g
s
.59284 .55368 m .60651 .56584 L .59653 .55599 L p .526 0 0 r
F P
0 g
s
.56084 .52053 m .54893 .50746 L .55202 .51127 L p .567 .073 0 r
F P
0 g
s
.53853 .49595 m .55202 .51127 L .54893 .50746 L p .575 .086 0 r
F P
0 g
s
.30416 .35408 m .31737 .35279 L .29742 .36844 L p .581 .944 .864 r
F P
0 g
s
.29742 .36844 m .28306 .37433 L .30416 .35408 L p .581 .944 .864 r
F P
0 g
s
.58465 .54495 m .57275 .53308 L .57919 .54038 L p .543 .029 0 r
F P
0 g
s
.57919 .54038 m .59284 .55368 L .58465 .54495 L p .543 .029 0 r
F P
0 g
s
.57275 .53308 m .56084 .52053 L .56558 .52616 L p .556 .054 0 r
F P
0 g
s
.55202 .51127 m .56558 .52616 L .56084 .52053 L p .567 .073 0 r
F P
0 g
s
.56558 .52616 m .57919 .54038 L .57275 .53308 L p .556 .054 0 r
F P
0 g
s
.84648 .49883 m .83383 .51221 L .83417 .46754 L p .94 .955 .752 r
F P
0 g
s
.83417 .46754 m .84705 .45014 L .84648 .49883 L p .94 .955 .752 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51549 .46966 L p .575 .087 0 r
F P
0 g
s
.51549 .46966 m .50584 .4589 L .5117 .46583 L p .575 .087 0 r
F P
0 g
s
.55202 .51127 m .53853 .49595 L .53914 .4968 L p .572 .084 0 r
F P
0 g
s
.73987 .59794 m .72711 .60228 L .74104 .59229 L p .506 .896 .736 r
F P
0 g
s
.74104 .59229 m .75484 .58433 L .73987 .59794 L p .506 .896 .736 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50584 .4589 L p .566 .076 0 r
F P
0 g
s
.50584 .4589 m .49614 .44828 L .50491 .45842 L p .566 .076 0 r
F P
0 g
s
.51854 .47383 m .52185 .47721 L .51844 .47318 L p .572 .086 0 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51854 .47383 L p .572 .086 0 r
F P
0 g
s
.29078 .35602 m .30416 .35408 L .28306 .37433 L p .65 .969 .866 r
F P
0 g
s
.28306 .37433 m .2685 .38115 L .29078 .35602 L p .65 .969 .866 r
F P
0 g
s
.53914 .4968 m .5533 .51299 L .55202 .51127 L p .572 .084 0 r
F P
0 g
s
.5533 .51299 m .53914 .4968 L .53878 .49654 L p .569 .081 0 r
F P
0 g
s
.56558 .52616 m .55202 .51127 L .5533 .51299 L p .558 .065 0 r
F P
0 g
s
.83383 .51221 m .82107 .52569 L .8212 .48505 L p .938 .96 .75 r
F P
0 g
s
.8212 .48505 m .83417 .46754 L .83383 .51221 L p .938 .96 .75 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49614 .44828 L p .555 .061 0 r
F P
0 g
s
.49614 .44828 m .4864 .43788 L .49806 .45095 L p .555 .061 0 r
F P
0 g
s
.52588 .48234 m .5255 .48148 L .52185 .47721 L p .569 .083 0 r
F P
0 g
s
.52185 .47721 m .51854 .47383 L .52588 .48234 L p .569 .083 0 r
F P
0 g
s
.72711 .60228 m .71419 .60514 L .72705 .59842 L p .418 .858 .76 r
F P
0 g
s
.72705 .59842 m .74104 .59229 L .72711 .60228 L p .418 .858 .76 r
F P
0 g
s
.53878 .49654 m .55263 .51248 L .5533 .51299 L p .569 .081 0 r
F P
0 g
s
.55263 .51248 m .53878 .49654 L .53749 .49517 L p .565 .078 0 r
F P
0 g
s
.5255 .48148 m .52588 .48234 L .53321 .49076 L p .566 .081 0 r
F P
0 g
s
.52913 .48569 m .53321 .49076 L .53999 .49849 L p .563 .078 0 r
F P
0 g
s
.53321 .49076 m .52588 .48234 L p .53358 .49109 L .535 .055 0 r
F P
0 g
s
.53736 .4954 m .53517 .49296 L p .53358 .49109 L .535 .055 0 r
F P
0 g
s
.53517 .49296 m .53321 .49076 L p .53358 .49109 L .535 .055 0 r
F P
0 g
s
.52913 .48569 m .5255 .48148 L p .53121 .48836 L .566 .081 0 r
F P
0 g
s
.53188 .48911 m .52913 .48569 L p .53121 .48836 L .566 .081 0 r
F P
0 g
s
.53249 .48955 m .52913 .48569 L p .53826 .49645 L .563 .078 0 r
F P
0 g
s
.53999 .49849 m .53863 .49686 L p .53826 .49645 L .563 .078 0 r
F P
0 g
s
.53863 .49686 m .53249 .48955 L p .53826 .49645 L .563 .078 0 r
F P
0 g
s
.53534 .49279 m .54575 .50498 L .55006 .50975 L p .563 .077 0 r
F P
0 g
s
.54575 .50498 m .53534 .49279 L .53249 .48955 L p .562 .077 0 r
F P
0 g
s
.53249 .48955 m .53999 .49849 L .54575 .50498 L p .562 .077 0 r
F P
0 g
s
.53736 .4954 m .54763 .50697 L p .53442 .49212 L 0 0 .472 r
F P
0 g
s
.53321 .49076 m .53374 .49135 L p .53442 .49212 L 0 0 .472 r
F P
0 g
s
.53374 .49135 m .53736 .4954 L p .53442 .49212 L 0 0 .472 r
F P
0 g
s
.52668 .48283 m .54158 .49937 L p .5293 .48611 L 0 0 .509 r
F P
0 g
s
.52588 .48234 m .52599 .48247 L p .52735 .48401 L .535 .055 0 r
F P
0 g
s
.52599 .48247 m .52628 .48284 L p .52735 .48401 L .535 .055 0 r
F P
0 g
s
.52628 .48284 m .5265 .48284 L p .5293 .48611 L 0 0 .509 r
F P
0 g
s
.5265 .48284 m .52668 .48283 L p .5293 .48611 L 0 0 .509 r
F P
0 g
s
.52628 .48284 m .53736 .4954 L p .52735 .48401 L .535 .055 0 r
F P
0 g
s
.53321 .49076 m .53188 .48911 L p .53121 .48836 L .566 .081 0 r
F P
0 g
s
.57919 .54038 m .56558 .52616 L .56758 .52871 L p .538 .036 0 r
F P
0 g
s
.5533 .51299 m .56758 .52871 L .56558 .52616 L p .558 .065 0 r
F P
0 g
s
.53749 .49517 m .55006 .50975 L .55263 .51248 L p .565 .078 0 r
F P
0 g
s
.55006 .50975 m .53749 .49517 L .53534 .49279 L p .563 .077 0 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .4864 .43788 L p .54 .041 0 r
F P
0 g
s
.5152 .47021 m .51854 .47383 L .5117 .46583 L p .558 .072 0 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .5152 .47021 L p .558 .072 0 r
F P
0 g
s
.71419 .60514 m .7011 .60639 L .71289 .60252 L p .313 .801 .779 r
F P
0 g
s
.71289 .60252 m .72705 .59842 L .71419 .60514 L p .313 .801 .779 r
F P
0 g
s
.27724 .35847 m .29078 .35602 L .2685 .38115 L p .705 .985 .868 r
F P
0 g
s
.2685 .38115 m .25376 .38872 L .27724 .35847 L p .705 .985 .868 r
F P
0 g
s
.56758 .52871 m .5533 .51299 L .55263 .51248 L p .547 .055 0 r
F P
0 g
s
.82107 .52569 m .80817 .53899 L .8081 .50235 L p .933 .965 .753 r
F P
0 g
s
.8081 .50235 m .8212 .48505 L .82107 .52569 L p .933 .965 .753 r
F P
0 g
s
.59284 .55368 m .57919 .54038 L .58198 .54365 L p .511 0 0 r
F P
0 g
s
.56758 .52871 m .58198 .54365 L .57919 .54038 L p .538 .036 0 r
F P
0 g
s
.7011 .60639 m .68787 .60591 L .69858 .60447 L p .191 .723 .787 r
F P
0 g
s
.69858 .60447 m .71289 .60252 L .7011 .60639 L p .191 .723 .787 r
F P
0 g
s
.36861 .35645 m .35602 .35403 L .38541 .3588 L p 0 .485 .722 r
F P
0 g
s
.60651 .56584 m .59284 .55368 L .59648 .5575 L p .474 0 0 r
F P
0 g
s
.58198 .54365 m .59648 .5575 L .59284 .55368 L p .511 0 0 r
F P
0 g
s
.5152 .47021 m .51181 .46629 L .51525 .47011 L p 0 0 .485 r
F P
0 g
s
.51854 .47383 m .5152 .47021 L .52628 .48284 L p .547 .064 0 r
F P
0 g
s
.51525 .47011 m .52668 .48283 L p .51851 .47385 L 0 0 .485 r
F P
0 g
s
.5152 .47021 m .51525 .47011 L .51851 .47385 L 0 0 .485 r
F
.52628 .48284 m .52588 .48234 L .52437 .48059 L p .547 .064 0 r
F P
0 g
s
.52437 .48059 m .51854 .47383 L p .52221 .47811 L .547 .064 0 r
F P
0 g
s
.52221 .47811 m .52628 .48284 L .52437 .48059 L .547 .064 0 r
F
.51181 .46629 m .5152 .47021 L .50491 .45842 L p .538 .052 0 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51181 .46629 L p .538 .052 0 r
F P
0 g
s
.55263 .51248 m .56666 .52793 L .56758 .52871 L p .547 .055 0 r
F P
0 g
s
.56666 .52793 m .55263 .51248 L .55006 .50975 L p .535 .047 0 r
F P
0 g
s
.68787 .60591 m .67451 .60364 L .68414 .60418 L p .06 .623 .777 r
F P
0 g
s
.68414 .60418 m .69858 .60447 L .68787 .60591 L p .06 .623 .777 r
F P
0 g
s
.62019 .57666 m .60651 .56584 L .61106 .56998 L p .426 0 0 r
F P
0 g
s
.59648 .5575 m .61106 .56998 L .60651 .56584 L p .474 0 0 r
F P
0 g
s
.26353 .36128 m .27724 .35847 L .25376 .38872 L p .749 .993 .871 r
F P
0 g
s
.25376 .38872 m .23884 .39683 L .26353 .36128 L p .749 .993 .871 r
F P
0 g
s
.80817 .53899 m .79511 .5518 L .79486 .51909 L p .924 .972 .762 r
F P
0 g
s
.79486 .51909 m .8081 .50235 L .80817 .53899 L p .924 .972 .762 r
F P
0 g
s
.58198 .54365 m .56758 .52871 L .56666 .52793 L p .513 .016 0 r
F P
0 g
s
.67451 .60364 m .66104 .59954 L .6696 .60162 L p 0 .51 .749 r
F P
0 g
s
.6696 .60162 m .68414 .60418 L .67451 .60364 L p 0 .51 .749 r
F P
0 g
s
.63386 .58597 m .62019 .57666 L .62569 .58084 L p 0 .194 .609 r
F P
0 g
s
.61106 .56998 m .62569 .58084 L .62019 .57666 L p .426 0 0 r
F P
0 g
s
.37481 .35389 m .38541 .3588 L .35602 .35403 L p .001 .573 .765 r
F P
0 g
s
.35602 .35403 m .34329 .35266 L .37481 .35389 L p .001 .573 .765 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45687 .40876 L p 0 .051 .531 r
F P
0 g
s
.66104 .59954 m .64748 .59363 L .655 .59681 L p 0 .395 .707 r
F P
0 g
s
.655 .59681 m .6696 .60162 L .66104 .59954 L p 0 .395 .707 r
F P
0 g
s
.64748 .59363 m .63386 .58597 L .64035 .58984 L p 0 .288 .658 r
F P
0 g
s
.62569 .58084 m .64035 .58984 L .63386 .58597 L p 0 .194 .609 r
F P
0 g
s
.64035 .58984 m .655 .59681 L .64748 .59363 L p 0 .288 .658 r
F P
0 g
s
.55006 .50975 m .56283 .52384 L .56666 .52793 L p .535 .047 0 r
F P
0 g
s
.56283 .52384 m .55006 .50975 L .54575 .50498 L p .526 .042 0 r
F P
0 g
s
.50839 .46196 m .51181 .46629 L .49806 .45095 L p 0 0 .488 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50839 .46196 L p 0 0 .488 r
F P
0 g
s
.54763 .50697 m .53999 .49849 L .53321 .49076 L p 0 0 .472 r
F P
0 g
s
.54575 .50498 m .55633 .51668 L .56283 .52384 L p .526 .042 0 r
F P
0 g
s
.55633 .51668 m .54575 .50498 L .53999 .49849 L p 0 0 .476 r
F P
0 g
s
.79511 .5518 m .78187 .56382 L .78144 .53492 L p .912 .978 .778 r
F P
0 g
s
.78144 .53492 m .79486 .51909 L .79511 .5518 L p .912 .978 .778 r
F P
0 g
s
.53999 .49849 m .54763 .50697 L .55633 .51668 L p 0 0 .476 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44691 .39995 L p 0 .095 .564 r
F P
0 g
s
.52668 .48283 m .52628 .48284 L .5152 .47021 L p 0 0 .485 r
F P
0 g
s
.24967 .36429 m .26353 .36128 L .23884 .39683 L p .783 .994 .874 r
F P
0 g
s
.23884 .39683 m .22376 .40525 L .24967 .36429 L p .783 .994 .874 r
F P
0 g
s
.56666 .52793 m .58085 .54255 L .58198 .54365 L p .513 .016 0 r
F P
0 g
s
.59648 .5575 m .58198 .54365 L .58085 .54255 L p 0 .04 .535 r
F P
0 g
s
.36409 .34947 m .37481 .35389 L .34329 .35266 L p .108 .659 .805 r
F P
0 g
s
.34329 .35266 m .33041 .35228 L .36409 .34947 L p .108 .659 .805 r
F P
0 g
s
.58085 .54255 m .56666 .52793 L .56283 .52384 L p 0 .003 .513 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43688 .39167 L p 0 .146 .603 r
F P
0 g
s
.50492 .45714 m .50839 .46196 L .49116 .44341 L p 0 .007 .522 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50492 .45714 L p 0 .007 .522 r
F P
0 g
s
.78187 .56382 m .76845 .57475 L .76785 .54952 L p .894 .984 .8 r
F P
0 g
s
.76785 .54952 m .78144 .53492 L .78187 .56382 L p .894 .984 .8 r
F P
0 g
s
.61106 .56998 m .59648 .5575 L .59518 .55597 L p 0 .113 .596 r
F P
0 g
s
.58085 .54255 m .59518 .55597 L .59648 .5575 L p 0 .04 .535 r
F P
0 g
s
.35326 .34548 m .36409 .34947 L .33041 .35228 L p .216 .737 .841 r
F P
0 g
s
.33041 .35228 m .31737 .35279 L .35326 .34548 L p .216 .737 .841 r
F P
0 g
s
.54158 .49937 m .53736 .4954 L .52628 .48284 L p 0 0 .509 r
F P
0 g
s
.23567 .36734 m .24967 .36429 L .22376 .40525 L p .808 .991 .878 r
F P
0 g
s
.22376 .40525 m .20853 .41376 L .23567 .36734 L p .808 .991 .878 r
F P
0 g
s
.56283 .52384 m .57578 .53707 L .58085 .54255 L p 0 .003 .513 r
F P
0 g
s
.57578 .53707 m .56283 .52384 L .55633 .51668 L p 0 .013 .531 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42677 .38394 L p 0 .206 .646 r
F P
0 g
s
.52708 .48212 m .52668 .48283 L .51181 .46629 L p 0 .003 .528 r
F P
0 g
s
.51181 .46629 m .50839 .46196 L .52708 .48212 L p 0 .003 .528 r
F P
0 g
s
.76845 .57475 m .75484 .58433 L .75407 .56257 L p .869 .989 .829 r
F P
0 g
s
.75407 .56257 m .76785 .54952 L .76845 .57475 L p .869 .989 .829 r
F P
0 g
s
.50142 .45177 m .50492 .45714 L .48419 .43581 L p 0 .047 .561 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50142 .45177 L p 0 .047 .561 r
F P
0 g
s
.59518 .55597 m .58085 .54255 L .57578 .53707 L p 0 .073 .58 r
F P
0 g
s
.5554 .51466 m .54763 .50697 L .53736 .4954 L p 0 .003 .528 r
F P
0 g
s
.53736 .4954 m .54158 .49937 L .5554 .51466 L p 0 .003 .528 r
F P
0 g
s
.62569 .58084 m .61106 .56998 L .60964 .56789 L p 0 .207 .67 r
F P
0 g
s
.59518 .55597 m .60964 .56789 L .61106 .56998 L p 0 .113 .596 r
F P
0 g
s
.55633 .51668 m .56709 .52755 L .57578 .53707 L p 0 .013 .531 r
F P
0 g
s
.56709 .52755 m .55633 .51668 L .54763 .50697 L p 0 .013 .536 r
F P
0 g
s
.85986 .43317 m .84705 .45014 L .82439 .40079 L p .928 .857 .751 r
F P
0 g
s
.82439 .40079 m .8366 .38074 L .85986 .43317 L p .928 .857 .751 r
F P
0 g
s
.3423 .34187 m .35326 .34548 L .31737 .35279 L p .32 .806 .871 r
F P
0 g
s
.31737 .35279 m .30416 .35408 L .3423 .34187 L p .32 .806 .871 r
F P
0 g
s
.54763 .50697 m .5554 .51466 L .56709 .52755 L p 0 .013 .536 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41657 .3768 L p 0 .273 .694 r
F P
0 g
s
.41657 .3768 m .40629 .37023 L .44112 .38881 L p 0 .273 .694 r
F P
0 g
s
.22154 .37026 m .23567 .36734 L .20853 .41376 L p .825 .982 .882 r
F P
0 g
s
.20853 .41376 m .19318 .42214 L .22154 .37026 L p .825 .982 .882 r
F P
0 g
s
.75484 .58433 m .74104 .59229 L .74011 .57377 L p .832 .99 .865 r
F P
0 g
s
.74011 .57377 m .75407 .56257 L .75484 .58433 L p .832 .99 .865 r
F P
0 g
s
.64035 .58984 m .62569 .58084 L .6242 .57799 L p 0 .323 .753 r
F P
0 g
s
.60964 .56789 m .6242 .57799 L .62569 .58084 L p 0 .207 .67 r
F P
0 g
s
.49788 .44578 m .50142 .45177 L .47717 .42815 L p 0 .093 .606 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49788 .44578 L p 0 .093 .606 r
F P
0 g
s
.54587 .50241 m .54158 .49937 L .52668 .48283 L p 0 .038 .568 r
F P
0 g
s
.52668 .48283 m .52708 .48212 L .54587 .50241 L p 0 .038 .568 r
F P
0 g
s
.84705 .45014 m .83417 .46754 L .81215 .42126 L p .931 .859 .747 r
F P
0 g
s
.81215 .42126 m .82439 .40079 L .84705 .45014 L p .931 .859 .747 r
F P
0 g
s
.52749 .48055 m .52708 .48212 L .50839 .46196 L p 0 .051 .58 r
F P
0 g
s
.50839 .46196 m .50492 .45714 L .52749 .48055 L p 0 .051 .58 r
F P
0 g
s
.74104 .59229 m .72705 .59842 L .72598 .58288 L p .779 .983 .905 r
F P
0 g
s
.72598 .58288 m .74011 .57377 L .74104 .59229 L p .779 .983 .905 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40629 .37023 L p 0 .346 .746 r
F P
0 g
s
.40629 .37023 m .3959 .36423 L .43372 .38074 L p 0 .346 .746 r
F P
0 g
s
.57578 .53707 m .5889 .54908 L .59518 .55597 L p 0 .073 .58 r
F P
0 g
s
.5889 .54908 m .57578 .53707 L .56709 .52755 L p 0 .09 .608 r
F P
0 g
s
.33122 .33855 m .3423 .34187 L .30416 .35408 L p .416 .861 .896 r
F P
0 g
s
.30416 .35408 m .29078 .35602 L .33122 .33855 L p .416 .861 .896 r
F P
0 g
s
.60964 .56789 m .59518 .55597 L .5889 .54908 L p 0 .165 .662 r
F P
0 g
s
.655 .59681 m .64035 .58984 L .63882 .58603 L p 0 .457 .838 r
F P
0 g
s
.6242 .57799 m .63882 .58603 L .64035 .58984 L p 0 .323 .753 r
F P
0 g
s
.72705 .59842 m .71289 .60252 L .71168 .58969 L p .703 .961 .944 r
F P
0 g
s
.71168 .58969 m .72598 .58288 L .72705 .59842 L p .703 .961 .944 r
F P
0 g
s
.6696 .60162 m .655 .59681 L .65347 .59178 L p .119 .6 .914 r
F P
0 g
s
.63882 .58603 m .65347 .59178 L .655 .59681 L p 0 .457 .838 r
F P
0 g
s
.49431 .43912 m .49788 .44578 L .47008 .42042 L p 0 .147 .655 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49431 .43912 L p 0 .147 .655 r
F P
0 g
s
.83417 .46754 m .8212 .48505 L .79984 .44183 L p .932 .861 .748 r
F P
0 g
s
.79984 .44183 m .81215 .42126 L .83417 .46754 L p .932 .861 .748 r
F P
0 g
s
.56329 .52126 m .5554 .51466 L .54158 .49937 L p 0 .069 .599 r
F P
0 g
s
.54158 .49937 m .54587 .50241 L .56329 .52126 L p 0 .069 .599 r
F P
0 g
s
.71289 .60252 m .69858 .60447 L .69726 .59405 L p .598 .917 .975 r
F P
0 g
s
.69726 .59405 m .71168 .58969 L .71289 .60252 L p .598 .917 .975 r
F P
0 g
s
.56709 .52755 m .57801 .53722 L .5889 .54908 L p 0 .09 .608 r
F P
0 g
s
.57801 .53722 m .56709 .52755 L .5554 .51466 L p 0 .089 .614 r
F P
0 g
s
.68414 .60418 m .6696 .60162 L .66812 .59509 L p .295 .733 .966 r
F P
0 g
s
.65347 .59178 m .66812 .59509 L .6696 .60162 L p .119 .6 .914 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .3959 .36423 L p 0 .425 .798 r
F P
0 g
s
.3959 .36423 m .38541 .3588 L .42626 .3726 L p 0 .425 .798 r
F P
0 g
s
.69858 .60447 m .68414 .60418 L .68273 .59586 L p .46 .842 .985 r
F P
0 g
s
.68273 .59586 m .69726 .59405 L .69858 .60447 L p .46 .842 .985 r
F P
0 g
s
.66812 .59509 m .68273 .59586 L .68414 .60418 L p .295 .733 .966 r
F P
0 g
s
.5554 .51466 m .56329 .52126 L .57801 .53722 L p 0 .089 .614 r
F P
0 g
s
.32001 .33547 m .33122 .33855 L .29078 .35602 L p .501 .904 .916 r
F P
0 g
s
.29078 .35602 m .27724 .35847 L .32001 .33547 L p .501 .904 .916 r
F P
0 g
s
.52791 .47798 m .52749 .48055 L .50492 .45714 L p 0 .107 .636 r
F P
0 g
s
.50492 .45714 m .50142 .45177 L .52791 .47798 L p 0 .107 .636 r
F P
0 g
s
.6242 .57799 m .60964 .56789 L .60217 .55952 L p 0 .279 .755 r
F P
0 g
s
.5889 .54908 m .60217 .55952 L .60964 .56789 L p 0 .165 .662 r
F P
0 g
s
.55021 .50428 m .54587 .50241 L .52708 .48212 L p 0 .103 .636 r
F P
0 g
s
.52708 .48212 m .52749 .48055 L .55021 .50428 L p 0 .103 .636 r
F P
0 g
s
.8212 .48505 m .8081 .50235 L .78743 .46215 L p .93 .863 .752 r
F P
0 g
s
.78743 .46215 m .79984 .44183 L .8212 .48505 L p .93 .863 .752 r
F P
0 g
s
.49071 .43175 m .49431 .43912 L .46294 .41262 L p 0 .206 .707 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49071 .43175 L p 0 .206 .707 r
F P
0 g
s
.60217 .55952 m .5889 .54908 L .57801 .53722 L p 0 .189 .698 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38541 .3588 L p 0 .505 .849 r
F P
0 g
s
.38541 .3588 m .37481 .35389 L .41873 .36438 L p 0 .505 .849 r
F P
0 g
s
.30868 .33253 m .32001 .33547 L .27724 .35847 L p .574 .934 .93 r
F P
0 g
s
.27724 .35847 m .26353 .36128 L .30868 .33253 L p .574 .934 .93 r
F P
0 g
s
.8081 .50235 m .79486 .51909 L .77491 .48186 L p .926 .866 .76 r
F P
0 g
s
.77491 .48186 m .78743 .46215 L .8081 .50235 L p .926 .866 .76 r
F P
0 g
s
.63882 .58603 m .6242 .57799 L .61556 .56809 L p 0 .409 .848 r
F P
0 g
s
.60217 .55952 m .61556 .56809 L .6242 .57799 L p 0 .279 .755 r
F P
0 g
s
.52833 .47427 m .52791 .47798 L .50142 .45177 L p 0 .171 .695 r
F P
0 g
s
.50142 .45177 m .49788 .44578 L .52833 .47427 L p 0 .171 .695 r
F P
0 g
s
.57129 .52648 m .56329 .52126 L .54587 .50241 L p 0 .151 .679 r
F P
0 g
s
.54587 .50241 m .55021 .50428 L .57129 .52648 L p 0 .151 .679 r
F P
0 g
s
.48708 .42365 m .49071 .43175 L .45573 .40475 L p 0 .269 .759 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48708 .42365 L p 0 .269 .759 r
F P
0 g
s
.57801 .53722 m .58907 .54538 L .60217 .55952 L p 0 .189 .698 r
F P
0 g
s
.58907 .54538 m .57801 .53722 L .56329 .52126 L p 0 .183 .701 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37481 .35389 L p .086 .584 .896 r
F P
0 g
s
.37481 .35389 m .36409 .34947 L .41113 .35609 L p .086 .584 .896 r
F P
0 g
s
.56329 .52126 m .57129 .52648 L .58907 .54538 L p 0 .183 .701 r
F P
0 g
s
.79486 .51909 m .78144 .53492 L .76225 .5006 L p .919 .869 .773 r
F P
0 g
s
.76225 .5006 m .77491 .48186 L .79486 .51909 L p .919 .869 .773 r
F P
0 g
s
.55461 .50478 m .55021 .50428 L .52749 .48055 L p 0 .179 .705 r
F P
0 g
s
.52749 .48055 m .52791 .47798 L .55461 .50478 L p 0 .179 .705 r
F P
0 g
s
.61556 .56809 m .60217 .55952 L .58907 .54538 L p 0 .305 .791 r
F P
0 g
s
.65347 .59178 m .63882 .58603 L .62905 .5745 L p .159 .543 .926 r
F P
0 g
s
.61556 .56809 m .62905 .5745 L .63882 .58603 L p 0 .409 .848 r
F P
0 g
s
.29724 .32966 m .30868 .33253 L .26353 .36128 L p .635 .952 .939 r
F P
0 g
s
.26353 .36128 m .24967 .36429 L .29724 .32966 L p .635 .952 .939 r
F P
0 g
s
.48341 .4148 m .48708 .42365 L .44846 .39682 L p 0 .335 .808 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48341 .4148 L p 0 .335 .808 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36409 .34947 L p .186 .657 .935 r
F P
0 g
s
.36409 .34947 m .35326 .34548 L .40346 .34772 L p .186 .657 .935 r
F P
0 g
s
.52876 .46933 m .52833 .47427 L .49788 .44578 L p 0 .238 .75 r
F P
0 g
s
.49788 .44578 m .49431 .43912 L .52876 .46933 L p 0 .238 .75 r
F P
0 g
s
.78144 .53492 m .76785 .54952 L .74944 .51802 L p .908 .872 .79 r
F P
0 g
s
.74944 .51802 m .76225 .5006 L .78144 .53492 L p .908 .872 .79 r
F P
0 g
s
.66812 .59509 m .65347 .59178 L .6426 .57853 L p .34 .661 .973 r
F P
0 g
s
.62905 .5745 m .6426 .57853 L .65347 .59178 L p .159 .543 .926 r
F P
0 g
s
.5794 .53003 m .57129 .52648 L .55021 .50428 L p 0 .243 .755 r
F P
0 g
s
.55021 .50428 m .55461 .50478 L .5794 .53003 L p 0 .243 .755 r
F P
0 g
s
.76785 .54952 m .75407 .56257 L .73648 .53379 L p .892 .875 .812 r
F P
0 g
s
.73648 .53379 m .74944 .51802 L .76785 .54952 L p .892 .875 .812 r
F P
0 g
s
.58907 .54538 m .60026 .55171 L .61556 .56809 L p 0 .305 .791 r
F P
0 g
s
.60026 .55171 m .58907 .54538 L .57129 .52648 L p 0 .289 .786 r
F P
0 g
s
.28567 .32676 m .29724 .32966 L .24967 .36429 L p .683 .959 .945 r
F P
0 g
s
.24967 .36429 m .23567 .36734 L .28567 .32676 L p .683 .959 .945 r
F P
0 g
s
.62905 .5745 m .61556 .56809 L .60026 .55171 L p .072 .426 .87 r
F P
0 g
s
.47972 .4052 m .48341 .4148 L .44112 .38881 L p .01 .401 .853 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .47972 .4052 L p .01 .401 .853 r
F P
0 g
s
.55907 .5037 m .55461 .50478 L .52791 .47798 L p 0 .258 .767 r
F P
0 g
s
.52791 .47798 m .52833 .47427 L .55907 .5037 L p 0 .258 .767 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35326 .34548 L p .284 .721 .965 r
F P
0 g
s
.35326 .34548 m .3423 .34187 L .39573 .33928 L p .284 .721 .965 r
F P
0 g
s
.68273 .59586 m .66812 .59509 L .65618 .58001 L p .5 .752 .985 r
F P
0 g
s
.6426 .57853 m .65618 .58001 L .66812 .59509 L p .34 .661 .973 r
F P
0 g
s
.57129 .52648 m .5794 .53003 L .60026 .55171 L p 0 .289 .786 r
F P
0 g
s
.75407 .56257 m .74011 .57377 L .72337 .5476 L p .869 .876 .839 r
F P
0 g
s
.72337 .5476 m .73648 .53379 L .75407 .56257 L p .869 .876 .839 r
F P
0 g
s
.52918 .46307 m .52876 .46933 L .49431 .43912 L p 0 .305 .798 r
F P
0 g
s
.49431 .43912 m .49071 .43175 L .52918 .46307 L p 0 .305 .798 r
F P
0 g
s
.69726 .59405 m .68273 .59586 L .66976 .57882 L p .627 .812 .971 r
F P
0 g
s
.65618 .58001 m .66976 .57882 L .68273 .59586 L p .5 .752 .985 r
F P
0 g
s
.74011 .57377 m .72598 .58288 L .71012 .55919 L p .836 .874 .871 r
F P
0 g
s
.71012 .55919 m .72337 .5476 L .74011 .57377 L p .836 .874 .871 r
F P
0 g
s
.71168 .58969 m .69726 .59405 L .68329 .57493 L p .722 .847 .941 r
F P
0 g
s
.66976 .57882 m .68329 .57493 L .69726 .59405 L p .627 .812 .971 r
F P
0 g
s
.72598 .58288 m .71168 .58969 L .69676 .56836 L p .789 .866 .906 r
F P
0 g
s
.69676 .56836 m .71012 .55919 L .72598 .58288 L p .789 .866 .906 r
F P
0 g
s
.68329 .57493 m .69676 .56836 L .71168 .58969 L p .722 .847 .941 r
F P
0 g
s
.47601 .39488 m .47972 .4052 L .43372 .38074 L p .103 .464 .89 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47601 .39488 L p .103 .464 .89 r
F P
0 g
s
.8366 .38074 m .82439 .40079 L .77837 .35467 L p .879 .773 .741 r
F P
0 g
s
.77837 .35467 m .78901 .33274 L .8366 .38074 L p .879 .773 .741 r
F P
0 g
s
.27399 .32374 m .28567 .32676 L .23567 .36734 L p .719 .958 .946 r
F P
0 g
s
.23567 .36734 m .22154 .37026 L .27399 .32374 L p .719 .958 .946 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .3423 .34187 L p .374 .773 .986 r
F P
0 g
s
.3423 .34187 m .33122 .33855 L .38792 .33076 L p .374 .773 .986 r
F P
0 g
s
.6426 .57853 m .62905 .5745 L .61155 .55594 L p .249 .535 .92 r
F P
0 g
s
.60026 .55171 m .61155 .55594 L .62905 .5745 L p .072 .426 .87 r
F P
0 g
s
.61155 .55594 m .60026 .55171 L .5794 .53003 L p .08 .394 .852 r
F P
0 g
s
.58759 .53169 m .5794 .53003 L .55461 .50478 L p .018 .335 .817 r
F P
0 g
s
.55461 .50478 m .55907 .5037 L .58759 .53169 L p .018 .335 .817 r
F P
0 g
s
.56356 .5009 m .55907 .5037 L .52833 .47427 L p .031 .333 .815 r
F P
0 g
s
.52833 .47427 m .52876 .46933 L .56356 .5009 L p .031 .333 .815 r
F P
0 g
s
.82439 .40079 m .81215 .42126 L .76772 .37698 L p .88 .771 .738 r
F P
0 g
s
.76772 .37698 m .77837 .35467 L .82439 .40079 L p .88 .771 .738 r
F P
0 g
s
.52962 .45543 m .52918 .46307 L .49071 .43175 L p .065 .367 .836 r
F P
0 g
s
.49071 .43175 m .48708 .42365 L .52962 .45543 L p .065 .367 .836 r
F P
0 g
s
.5794 .53003 m .58759 .53169 L .61155 .55594 L p .08 .394 .852 r
F P
0 g
s
.47227 .38387 m .47601 .39488 L .42626 .3726 L p .192 .522 .918 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47227 .38387 L p .192 .522 .918 r
F P
0 g
s
.81215 .42126 m .79984 .44183 L .75703 .39935 L p .878 .769 .737 r
F P
0 g
s
.75703 .39935 m .76772 .37698 L .81215 .42126 L p .878 .769 .737 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .33122 .33855 L p .454 .813 .996 r
F P
0 g
s
.33122 .33855 m .32001 .33547 L .38005 .32217 L p .454 .813 .996 r
F P
0 g
s
.65618 .58001 m .6426 .57853 L .62292 .55785 L p .407 .62 .938 r
F P
0 g
s
.61155 .55594 m .62292 .55785 L .6426 .57853 L p .249 .535 .92 r
F P
0 g
s
.53005 .44641 m .52962 .45543 L .48708 .42365 L p .165 .424 .861 r
F P
0 g
s
.48708 .42365 m .48341 .4148 L .53005 .44641 L p .165 .424 .861 r
F P
0 g
s
.79984 .44183 m .78743 .46215 L .74629 .42142 L p .875 .767 .74 r
F P
0 g
s
.74629 .42142 m .75703 .39935 L .79984 .44183 L p .875 .767 .74 r
F P
0 g
s
.62292 .55785 m .61155 .55594 L .58759 .53169 L p .242 .484 .889 r
F P
0 g
s
.56809 .49626 m .56356 .5009 L .52876 .46933 L p .155 .4 .846 r
F P
0 g
s
.52876 .46933 m .52918 .46307 L .56809 .49626 L p .155 .4 .846 r
F P
0 g
s
.46851 .37221 m .47227 .38387 L .41873 .36438 L p .277 .572 .938 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46851 .37221 L p .277 .572 .938 r
F P
0 g
s
.59585 .53125 m .58759 .53169 L .55907 .5037 L p .165 .416 .856 r
F P
0 g
s
.55907 .5037 m .56356 .5009 L .59585 .53125 L p .165 .416 .856 r
F P
0 g
s
.66976 .57882 m .65618 .58001 L .63435 .55727 L p .534 .679 .931 r
F P
0 g
s
.62292 .55785 m .63435 .55727 L .65618 .58001 L p .407 .62 .938 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .32001 .33547 L p .523 .841 .999 r
F P
0 g
s
.32001 .33547 m .30868 .33253 L .3721 .3135 L p .523 .841 .999 r
F P
0 g
s
.78743 .46215 m .77491 .48186 L .73548 .44287 L p .87 .766 .746 r
F P
0 g
s
.73548 .44287 m .74629 .42142 L .78743 .46215 L p .87 .766 .746 r
F P
0 g
s
.58759 .53169 m .59585 .53125 L .62292 .55785 L p .242 .484 .889 r
F P
0 g
s
.53049 .43599 m .53005 .44641 L .48341 .4148 L p .256 .471 .876 r
F P
0 g
s
.48341 .4148 m .47972 .4052 L .53049 .43599 L p .256 .471 .876 r
F P
0 g
s
.77491 .48186 m .76225 .5006 L .72457 .46332 L p .862 .765 .755 r
F P
0 g
s
.72457 .46332 m .73548 .44287 L .77491 .48186 L p .862 .765 .755 r
F P
0 g
s
.68329 .57493 m .66976 .57882 L .64579 .5541 L p .631 .716 .908 r
F P
0 g
s
.63435 .55727 m .64579 .5541 L .66976 .57882 L p .534 .679 .931 r
F P
0 g
s
.46472 .35995 m .46851 .37221 L .41113 .35609 L p .353 .615 .949 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46472 .35995 L p .353 .615 .949 r
F P
0 g
s
.63435 .55727 m .62292 .55785 L .59585 .53125 L p .381 .553 .899 r
F P
0 g
s
.57265 .48969 m .56809 .49626 L .52918 .46307 L p .265 .455 .86 r
F P
0 g
s
.52918 .46307 m .52962 .45543 L .57265 .48969 L p .265 .455 .86 r
F P
0 g
s
.76225 .5006 m .74944 .51802 L .71357 .48246 L p .851 .765 .767 r
F P
0 g
s
.71357 .48246 m .72457 .46332 L .76225 .5006 L p .851 .765 .767 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30868 .33253 L p .579 .858 .996 r
F P
0 g
s
.30868 .33253 m .29724 .32966 L .36408 .30475 L p .579 .858 .996 r
F P
0 g
s
.60416 .52857 m .59585 .53125 L .56356 .5009 L p .295 .481 .872 r
F P
0 g
s
.56356 .5009 m .56809 .49626 L .60416 .52857 L p .295 .481 .872 r
F P
0 g
s
.69676 .56836 m .68329 .57493 L .65723 .54828 L p .701 .738 .88 r
F P
0 g
s
.64579 .5541 m .65723 .54828 L .68329 .57493 L p .631 .716 .908 r
F P
0 g
s
.74944 .51802 m .73648 .53379 L .70247 .49995 L p .836 .763 .783 r
F P
0 g
s
.70247 .49995 m .71357 .48246 L .74944 .51802 L p .836 .763 .783 r
F P
0 g
s
.71012 .55919 m .69676 .56836 L .66864 .53984 L p .752 .751 .851 r
F P
0 g
s
.65723 .54828 m .66864 .53984 L .69676 .56836 L p .701 .738 .88 r
F P
0 g
s
.59585 .53125 m .60416 .52857 L .63435 .55727 L p .381 .553 .899 r
F P
0 g
s
.53092 .42422 m .53049 .43599 L .47972 .4052 L p .335 .511 .882 r
F P
0 g
s
.47972 .4052 m .47601 .39488 L .53092 .42422 L p .335 .511 .882 r
F P
0 g
s
.73648 .53379 m .72337 .5476 L .69127 .5155 L p .816 .762 .802 r
F P
0 g
s
.69127 .5155 m .70247 .49995 L .73648 .53379 L p .816 .762 .802 r
F P
0 g
s
.46091 .34717 m .46472 .35995 L .40346 .34772 L p .42 .651 .954 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46091 .34717 L p .42 .651 .954 r
F P
0 g
s
.72337 .5476 m .71012 .55919 L .67999 .52887 L p .789 .758 .825 r
F P
0 g
s
.66864 .53984 m .67999 .52887 L .71012 .55919 L p .752 .751 .851 r
F P
0 g
s
.67999 .52887 m .69127 .5155 L .72337 .5476 L p .789 .758 .825 r
F P
0 g
s
.64579 .5541 m .63435 .55727 L .60416 .52857 L p .492 .601 .89 r
F P
0 g
s
.57723 .48116 m .57265 .48969 L .52962 .45543 L p .357 .497 .862 r
F P
0 g
s
.52962 .45543 m .53005 .44641 L .57723 .48116 L p .357 .497 .862 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29724 .32966 L p .624 .867 .988 r
F P
0 g
s
.29724 .32966 m .28567 .32676 L .35599 .29592 L p .624 .867 .988 r
F P
0 g
s
.61251 .52355 m .60416 .52857 L .56809 .49626 L p .403 .529 .87 r
F P
0 g
s
.56809 .49626 m .57265 .48969 L .61251 .52355 L p .403 .529 .87 r
F P
0 g
s
.53137 .41117 m .53092 .42422 L .47601 .39488 L p .403 .543 .882 r
F P
0 g
s
.47601 .39488 m .47227 .38387 L .53137 .41117 L p .403 .543 .882 r
F P
0 g
s
.45708 .33393 m .46091 .34717 L .39573 .33928 L p .478 .679 .954 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45708 .33393 L p .478 .679 .954 r
F P
0 g
s
.60416 .52857 m .61251 .52355 L .64579 .5541 L p .492 .601 .89 r
F P
0 g
s
.65723 .54828 m .64579 .5541 L .61251 .52355 L p .576 .633 .871 r
F P
0 g
s
.58182 .47069 m .57723 .48116 L .53005 .44641 L p .433 .529 .856 r
F P
0 g
s
.53005 .44641 m .53049 .43599 L .58182 .47069 L p .433 .529 .856 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28567 .32676 L p .66 .868 .978 r
F P
0 g
s
.28567 .32676 m .27399 .32374 L .34782 .287 L p .66 .868 .978 r
F P
0 g
s
.78901 .33274 m .77837 .35467 L .71118 .316 L p .824 .711 .74 r
F P
0 g
s
.71118 .316 m .71927 .29362 L .78901 .33274 L p .824 .711 .74 r
F P
0 g
s
.53181 .39693 m .53137 .41117 L .47227 .38387 L p .46 .569 .878 r
F P
0 g
s
.47227 .38387 m .46851 .37221 L .53181 .39693 L p .46 .569 .878 r
F P
0 g
s
.45323 .32033 m .45708 .33393 L .38792 .33076 L p .528 .702 .95 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45323 .32033 L p .528 .702 .95 r
F P
0 g
s
.66864 .53984 m .65723 .54828 L .62088 .51613 L p .639 .653 .847 r
F P
0 g
s
.61251 .52355 m .62088 .51613 L .65723 .54828 L p .576 .633 .871 r
F P
0 g
s
.62088 .51613 m .61251 .52355 L .57265 .48969 L p .488 .563 .858 r
F P
0 g
s
.57265 .48969 m .57723 .48116 L .62088 .51613 L p .488 .563 .858 r
F P
0 g
s
.77837 .35467 m .76772 .37698 L .70311 .33866 L p .822 .706 .737 r
F P
0 g
s
.70311 .33866 m .71118 .316 L .77837 .35467 L p .822 .706 .737 r
F P
0 g
s
.76772 .37698 m .75703 .39935 L .69504 .36132 L p .818 .702 .736 r
F P
0 g
s
.69504 .36132 m .70311 .33866 L .76772 .37698 L p .818 .702 .736 r
F P
0 g
s
.67999 .52887 m .66864 .53984 L .62925 .50635 L p .686 .666 .825 r
F P
0 g
s
.62088 .51613 m .62925 .50635 L .66864 .53984 L p .639 .653 .847 r
F P
0 g
s
.58642 .45833 m .58182 .47069 L .53049 .43599 L p .495 .553 .845 r
F P
0 g
s
.53049 .43599 m .53092 .42422 L .58642 .45833 L p .495 .553 .845 r
F P
0 g
s
.75703 .39935 m .74629 .42142 L .68695 .38367 L p .813 .698 .738 r
F P
0 g
s
.68695 .38367 m .69504 .36132 L .75703 .39935 L p .813 .698 .738 r
F P
0 g
s
.53225 .38161 m .53181 .39693 L .46851 .37221 L p .507 .59 .872 r
F P
0 g
s
.46851 .37221 m .46472 .35995 L .53225 .38161 L p .507 .59 .872 r
F P
0 g
s
.44935 .30644 m .45323 .32033 L .38005 .32217 L p .569 .719 .943 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44935 .30644 L p .569 .719 .943 r
F P
0 g
s
.74629 .42142 m .73548 .44287 L .67883 .40539 L p .805 .694 .742 r
F P
0 g
s
.67883 .40539 m .68695 .38367 L .74629 .42142 L p .805 .694 .742 r
F P
0 g
s
.69127 .5155 m .67999 .52887 L .6376 .49426 L p .721 .674 .804 r
F P
0 g
s
.62925 .50635 m .6376 .49426 L .67999 .52887 L p .686 .666 .825 r
F P
0 g
s
.62925 .50635 m .62088 .51613 L .57723 .48116 L p .553 .586 .841 r
F P
0 g
s
.57723 .48116 m .58182 .47069 L .62925 .50635 L p .553 .586 .841 r
F P
0 g
s
.73548 .44287 m .72457 .46332 L .67068 .42617 L p .796 .691 .749 r
F P
0 g
s
.67068 .42617 m .67883 .40539 L .73548 .44287 L p .796 .691 .749 r
F P
0 g
s
.70247 .49995 m .69127 .5155 L .64593 .48 L p .747 .68 .786 r
F P
0 g
s
.6376 .49426 m .64593 .48 L .69127 .5155 L p .721 .674 .804 r
F P
0 g
s
.72457 .46332 m .71357 .48246 L .66247 .44572 L p .783 .688 .758 r
F P
0 g
s
.66247 .44572 m .67068 .42617 L .72457 .46332 L p .783 .688 .758 r
F P
0 g
s
.71357 .48246 m .70247 .49995 L .65422 .46375 L p .768 .684 .771 r
F P
0 g
s
.64593 .48 m .65422 .46375 L .70247 .49995 L p .747 .68 .786 r
F P
0 g
s
.65422 .46375 m .66247 .44572 L .71357 .48246 L p .768 .684 .771 r
F P
0 g
s
.59102 .44417 m .58642 .45833 L .53092 .42422 L p .543 .571 .833 r
F P
0 g
s
.53092 .42422 m .53137 .41117 L .59102 .44417 L p .543 .571 .833 r
F P
0 g
s
.53269 .36535 m .53225 .38161 L .46472 .35995 L p .547 .607 .865 r
F P
0 g
s
.46472 .35995 m .46091 .34717 L .53269 .36535 L p .547 .607 .865 r
F P
0 g
s
.44545 .29235 m .44935 .30644 L .3721 .3135 L p .604 .733 .936 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44545 .29235 L p .604 .733 .936 r
F P
0 g
s
.6376 .49426 m .62925 .50635 L .58182 .47069 L p .603 .603 .824 r
F P
0 g
s
.58182 .47069 m .58642 .45833 L .6376 .49426 L p .603 .603 .824 r
F P
0 g
s
.59561 .42835 m .59102 .44417 L .53137 .41117 L p .582 .586 .821 r
F P
0 g
s
.53137 .41117 m .53181 .39693 L .59561 .42835 L p .582 .586 .821 r
F P
0 g
s
.53314 .3483 m .53269 .36535 L .46091 .34717 L p .58 .622 .858 r
F P
0 g
s
.46091 .34717 m .45708 .33393 L .53314 .3483 L p .58 .622 .858 r
F P
0 g
s
.64593 .48 m .6376 .49426 L .58642 .45833 L p .642 .614 .807 r
F P
0 g
s
.58642 .45833 m .59102 .44417 L .64593 .48 L p .642 .614 .807 r
F P
0 g
s
.44151 .27815 m .44545 .29235 L .36408 .30475 L p .632 .743 .928 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44151 .27815 L p .632 .743 .928 r
F P
0 g
s
.65422 .46375 m .64593 .48 L .59102 .44417 L p .672 .623 .792 r
F P
0 g
s
.6002 .41106 m .59561 .42835 L .53181 .39693 L p .614 .597 .81 r
F P
0 g
s
.53181 .39693 m .53225 .38161 L .6002 .41106 L p .614 .597 .81 r
F P
0 g
s
.53358 .33062 m .53314 .3483 L .45708 .33393 L p .608 .635 .852 r
F P
0 g
s
.45708 .33393 m .45323 .32033 L .53358 .33062 L p .608 .635 .852 r
F P
0 g
s
.59102 .44417 m .59561 .42835 L .65422 .46375 L p .672 .623 .792 r
F P
0 g
s
.66247 .44572 m .65422 .46375 L .59561 .42835 L p .696 .63 .779 r
F P
0 g
s
.67068 .42617 m .66247 .44572 L .6002 .41106 L p .715 .636 .768 r
F P
0 g
s
.59561 .42835 m .6002 .41106 L .66247 .44572 L p .696 .63 .779 r
F P
0 g
s
.43754 .26392 m .44151 .27815 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.60479 .39248 m .6002 .41106 L .53225 .38161 L p .64 .607 .801 r
F P
0 g
s
.53225 .38161 m .53269 .36535 L .60479 .39248 L p .64 .607 .801 r
F P
0 g
s
.67883 .40539 m .67068 .42617 L .60479 .39248 L p .73 .641 .76 r
F P
0 g
s
.6002 .41106 m .60479 .39248 L .67068 .42617 L p .715 .636 .768 r
F P
0 g
s
.71927 .29362 m .71118 .316 L .62766 .28866 L p .772 .672 .753 r
F P
0 g
s
.62766 .28866 m .63227 .26744 L .71927 .29362 L p .772 .672 .753 r
F P
0 g
s
.71118 .316 m .70311 .33866 L .62308 .31005 L p .767 .665 .75 r
F P
0 g
s
.62308 .31005 m .62766 .28866 L .71118 .316 L p .767 .665 .75 r
F P
0 g
s
.68695 .38367 m .67883 .40539 L .60936 .37285 L p .742 .647 .754 r
F P
0 g
s
.60479 .39248 m .60936 .37285 L .67883 .40539 L p .73 .641 .76 r
F P
0 g
s
.70311 .33866 m .69504 .36132 L .6185 .33138 L p .76 .658 .749 r
F P
0 g
s
.6185 .33138 m .62308 .31005 L .70311 .33866 L p .76 .658 .749 r
F P
0 g
s
.53403 .31249 m .53358 .33062 L .45323 .32033 L p .632 .647 .847 r
F P
0 g
s
.45323 .32033 m .44935 .30644 L .53403 .31249 L p .632 .647 .847 r
F P
0 g
s
.69504 .36132 m .68695 .38367 L .61393 .3524 L p .752 .652 .751 r
F P
0 g
s
.61393 .3524 m .6185 .33138 L .69504 .36132 L p .752 .652 .751 r
F P
0 g
s
.60936 .37285 m .61393 .3524 L .68695 .38367 L p .742 .647 .754 r
F P
0 g
s
.60936 .37285 m .60479 .39248 L .53269 .36535 L p .661 .616 .793 r
F P
0 g
s
.53269 .36535 m .53314 .3483 L .60936 .37285 L p .661 .616 .793 r
F P
0 g
s
.53448 .29409 m .53403 .31249 L .44935 .30644 L p .651 .658 .843 r
F P
0 g
s
.44935 .30644 m .44545 .29235 L .53448 .29409 L p .651 .658 .843 r
F P
0 g
s
.61393 .3524 m .60936 .37285 L .53314 .3483 L p .678 .624 .787 r
F P
0 g
s
.53314 .3483 m .53358 .33062 L .61393 .3524 L p .678 .624 .787 r
F P
0 g
s
.53493 .27558 m .53448 .29409 L .44545 .29235 L p .668 .668 .841 r
F P
0 g
s
.44545 .29235 m .44151 .27815 L .53493 .27558 L p .668 .668 .841 r
F P
0 g
s
.6185 .33138 m .61393 .3524 L .53358 .33062 L p .692 .632 .784 r
F P
0 g
s
.53358 .33062 m .53403 .31249 L .6185 .33138 L p .692 .632 .784 r
F P
0 g
s
.62308 .31005 m .6185 .33138 L .53403 .31249 L p .705 .64 .782 r
F P
0 g
s
.53403 .31249 m .53448 .29409 L .62308 .31005 L p .705 .64 .782 r
F P
0 g
s
.62766 .28866 m .62308 .31005 L .53448 .29409 L p .715 .648 .782 r
F P
0 g
s
.53539 .25714 m .53493 .27558 L .44151 .27815 L p .682 .678 .84 r
F P
0 g
s
.44151 .27815 m .43754 .26392 L .53539 .25714 L p .682 .678 .84 r
F P
0 g
s
.63227 .26744 m .62766 .28866 L .53493 .27558 L p .723 .657 .784 r
F P
0 g
s
.53448 .29409 m .53493 .27558 L .62766 .28866 L p .715 .648 .782 r
F P
0 g
s
.53493 .27558 m .53539 .25714 L .63227 .26744 L p .723 .657 .784 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojj]e`03o`00
0?niZ<So^JS800?o^JS82ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?n^[ML00ol0003o^JS8
okVXb00>okVXb0_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nW`>/00ol0003o[ZgGojj]
e`0Mojj]e`03o`000?niZ<So^JS801Wo^JS81ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001_nW`>/00ol0003o[ZgGojj]e`0Mojj]e`03o`000?niZ<So^JS801go^JS800?o0000
olF/`?o5[<000ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool0
02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002_nW`>/00ol0
003o[ZgGojj]e`0Lojj]e`03o`000?niZ<So^JS801go^JS800?o0000olF/`?o5[<000oo5[<03o`00
00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Ko
oooo00?o0000ooooooooool0IOooool4o`0000koYl3[00?o0000ojj]eon^[ML03On^[ML@o`0001ko
^JS800?o0000olF/`?o5[<001oo5[<03o`0000[ooooo00?o0000ooooooooool0<_ooool2o`0002go
oooo000/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?ooool4o`00013oYl3[
0ol000000on^[MOo0000o`00000<o`0000ooZj_G00?o0000okNUb?ngYLP00_ngYLP7o`0001?o^JS8
00?o0000olF/`?o5[<002_o5[<03o`0000Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0[ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05co
oooo0ol0000?ojO0j`Go00000_nQ_^d00ol0003oZj_Goj^[e`0Loj^[e`03o`000?ngYLSo]jG800Wo
]jG82?l0000;okVXb003o`000?o5[<3oaJc000goaJc00ol00005ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Eoooool4o`0000goYl3[1Ol00007oj6nk@03o`000?n[ZmOoZj_G01coZj_G00?o0000okNUb?ng
YLP04OngYLP7o`0000?o^JS800?o0000olF/`?o5[<004Oo5[<03o`0000;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Zooooo`002Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`03o`000?oooooooooo05?o
oooo0ol0000=ojO0j`Co00003OnQ_^d00ol0003oZj_Goj^[e`0Koj^[e`03o`000?ngYLSo]jG801So
]jG81_l0000DolF/`0?o0000=_ooool00ol0003oooooooooo`0Yooooo`004Oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo053ooooo0_l00002ojSNnP03o`000?nW`>_oYl3[00KoYl3[1Ol0000>oj6nk@Co
00000_n[ZmL=o`0000koZj_G00?o0000okNUb?ngYLP06ongYLP00ol0003oa:ZoolBZ_`03o`0001?o
aJc01?l0000dooooo`03o`000?oooooooooo02Sooooo000Aooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1=ooooo`;o00001OnXg_X00ol0003oYl3[ojO0j`02ojO0j`?o00003_nQ_^d5o`00
00?oV[__00?o0000ojJXeonVZ=L03OnVZ=L?o`0001go]jG800?o0000olBZ_oo4Z[l00oo4Z[l3o`00
013oaJc000Co0000olF/`?o5[<3oaJc00ol0000aooooo`;o0000:Oooool0017ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1:ooooo`;o00001onXg_X3o`0000koXKk]1Ol00009oiZkk`03o`000?nVZ=Oo
YZSG01[oYZSG00Co0000okBSb?ndXlSo]:?81_l0000DokNUb003o`000?o4Z[ooa:Zo00Koa:Zo0ol0
000=olF/`003o`000?o5[<3oaJc000;oaJc000Co0000om:f_Ol0003o0000;oooool2o`0002Wooooo
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o0000
4?ooool00ol0003oooooooooo`17ooooo`;o00001onXg_X2o`0000;oWmgl00?o0000oj6nkOnQ_^d0
1onQ_^d5o`0000koV[__00?o0000ojJXeonVZ=L06_nVZ=L00ol0003o]:?8okBSb007okBSb0Ko0000
3OngYLP00ol0003oa:ZoolBZ_`0:olBZ_`?o00002_o5[<000ol0003oaJc0olF/`002olF/`005o`00
0?oB][god[Jmom:f_Ol00000<?ooool00ol0003oooooooooo`0Vooooo`004Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo0_l00015ooooo`;o
00001_nXg_X3o`0000GoWmgl00?o0000oj6nkOnQ_^d00_nQ_^d4o`0001?oV[__00?o0000ojJXeonV
Z=L06_nVZ=L00ol0003o]:?8okBSb00=okBSb0Go00002?ngYLP00ol0003oa:ZoolBZ_`0=olBZ_`?o
00001_o5[<02o`0000?oaJc000?o0000om:f_OoB][d00ooB][d2o`0002kooooo00?o0000oooooooo
ool09_ooool002[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`10ooooo`;o0000
1_nXg_X2o`0000SoWmgl1?l0000CoiZkk`Oo00000onVZ=L4o`0001?oYZSG00?o0000okBSb?ndXlP0
4ondXlP6o`0000;o]jG800?o0000olBZ_oo4Z[l04?o4Z[l6o`000003olF/`?l0003oaJc000;oaJc0
00?o0000om:f_OoB][d01OoB][d2o`0002gooooo00?o0000ooooooooool09Oooool002[ooooo0_l0
000Eooooo`03o`000?oooooooooo03gooooo0_l00006ojSNnP;o00001onOgO`3o`0000;oU=_n00?o
0000oiZkkonJ^nl01OnJ^nl=o`0000KoTKSa00?o0000oj6Uf?nQYMP01OnQYMP=o`0000KoYZSG00?o
0000okBSb?ndXlP06OndXlP4o`00017oa:Zo1_l00002olF/`004o`000?o5[<3oaJc0o`0000Wod[Jm
0_l0000/ooooo`03o`000?oooooooooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0>_ooool2o`0000GoZ=kj0ol00006oioMo0?o00001OnDfoh2o`000003oiZkkol0
003o000000?o00004onA^?400ol0003oXJGHoj6Uf00Boj6Uf0Oo00007OndXlP00ol0003o`ZRoo`00
0002o`0000_oa:Zo0ol00006olBZ_`Go00003?oB][d2o`0002[ooooo0_l0000Uooooo`00:_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03Oooooo0_l00005ojSNnP;o00001_nOgO`3
o`0000GoU=_n0ol00002ohGGo`03o`000?nA^?7oTKSa01OoTKSa00?o0000oj6Uf?nQYMP05onQYMP0
0ol0003o/J78ok6Qb005o`0001Ko]:?800?o0000ol:X_oo2Z;l00_o2Z;l3o`0000Goa:Zo0ol0000<
olBZ_`?o00003OoB][d00ol0003oooooooooo`0Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00001OnXg_X2o`0000KoWmgl0_l0
0005oiCKoP?o00001_n5eol00ol0003oTKSaoi6hl@0Foi6hl@03o`000?nQYMSoXJGH01OoXJGH00?o
0000ok6Qb?naXLP01OnaXLP5o`00013o]:?800?o0000ol:X_oo2Z;l01_o2Z;l5o`00013oa:Zo00Co
0000om:d_?l0003o00003?oB][d2o`0002Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o0000
6Oooool00ol0003oooooooooo`0aooooo`;o00001OnXg_X2o`0000GoWmgl0ol00004oiCKoP?o0000
2?n5eol3o`000003oi6hlOl0003o000001Go00000onQYMP00ol0003oXJGHoj6Uf00Coj6Uf003o`00
0?naXLSo/J7800[o/J781?l0000<okBSb003o`000?o2Z;oo`ZRo00Go`ZRo1_l0000?olBZ_`03o`00
0?oB];co000000;od[Bl00?o0000om:f_OoB][d02ooB][d2o`0002Oooooo00?o0000ooooooooool0
1Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool002Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`Co00000onXg_X00ol0003oWmgl
oioMo003oioMo0?o00001?nDfoh3o`0000OoQMOo1?l00002ogC@oP03o`000?n7/o?oQk?c01GoQk?c
00?o0000oi^Rf_nKX]X00_nKX]X9o`0000coXJGH00?o0000ok6Qb?naXLP03_naXLP5o`0000Oo]:?8
00?o0000ol:X_oo2Z;l00_o2Z;l3o`0000Ko`ZRo0_l0000=olBZ_`04o`000?oB];cod[Blo`0000;o
d[Bl0_l0000=om:f_@;o00009_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`06ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02cooooo00?o0000okSel_nhmO800_nhmO84o`0000CoWmgl00?o0000oiCKo_nD
foh00_nDfoh3o`0000KoQMOo1?l00007ogC@oP03o`000?n7/o?oQk?c01CoQk?c00?o0000oi^Rf_nK
X]X02onKX]X9o`0000?oXJGH00?o0000ok6Qb?naXLP04onaXLP5o`000004okBSb?l0003o`ZRool:X
_`?o00002oo2Z;l3o`0000[oa:Zo00Go0000om:d_?oB];cod[Blo`000003om:d_0;o00003OoB][d0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01oooool002Wooooo0ol0000Looooo`03o`000?oo
oooooooo02[ooooo00?o0000okSel_nhmO800_nhmO800ol0003o[_Gaojkel@02ojkel@Co00000onD
foh2o`0000GoQMOo1?l00009ogC@oPCo00000on7/o<9o`0000[oQk?c00?o0000oi^Rf_nKX]X04onK
X]X4o`0001[o/J781?l0000Aol:X_`?o00001_o4Z[l00ol0003od[Blom:d_002om:d_003o`000?oB
];cod[Bl00?od[Bl00?o0000om:f_OoB][d02ooB][d2o`0002Cooooo00?o0000ooooooooool00ooo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`03o`000?nhmO;o^?Gb00;o^?Gb00?o
0000ojkelOn^mO400_n^mO401?l0003oX_?`oj;cl?nRlo04o`0000CoQMOo0ol00007ogC@oPKo0000
1?mOaO`00ol0003oNZgdogZ]m009ogZ]m0_o00006?nKX]X00ol0003o[Io9ojfOb@04o`0001;o/J78
1?l000001?o0Y/3o0000o`000?l0000Bol:X_`;o00001?o4Z[l00ol0003od[Blom:d_003om:d_003
o`000?oB];cod[Bl00?od[Bl0_l0000=om:f_@03o`000?oooooooooo023ooooo0ol00004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00Co0000okSel_nhmO;o^?Gb0_l00003ojke
l@;o00000onRlo000ol0003oT^o^oi;_kP02oi;_kPCo00001Omdd?h5o`0000_oGlGl00?o0000ogZ]
m?mj[O@04_mj[O@01?l0003oU9oKoiBOfonDWm/5o`00013oVj;J00?o0000ojfObOn]WlT01?n]WlT4
o`0000_o/J780ol00003ok6Qb003o`000?o0Y/3o`:K000;o`:K00_l0000Bol:X_`?o000000?oa:Zo
o`000?oB];`01OoB];`00ol0003od[Blom:d_004om:d_0;o00002ooB][d2o`0002?ooooo00?o0000
ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`05o`00
0?nhmO;o^?GbokSel_l000001?n^mO401?l0003oX_?`oj;cl?nRlo02o`0000?oT^o^0_l00004oh3W
jPCo00002_mOaO`9o`0000CoNZgd00?o0000ogZ]m?mj[O@03?mj[O@00ol0003oU9oKoiBOf`06oiBO
f`Go00002onKX]X00ol0003o[Io9ojfOb@08ojfOb@Co00001?naXLP3o`0000Ko/J7800?o0000ol2V
`?o0Y/001?o0Y/03o`0001;o`ZRo0_l00007om:d_003o`000?oB];cod[Bl00God[Bl00?o0000om:f
_OoB][d01ooB][d01?l0003ohLFmon75_Ol0000Sooooo`03o`000?oooooooooo01kooooo0006oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Qooooo`03o`000?oooooooooo02;ooooo00Go
0000okSel_nhmO;o^?Gbo`000003ojkel@;o00000onRlo001?l0003oT^o^oi;_k_nBknh2o`0000?o
P>OZ0ol00003of[Li@?o000000?oGlGlo`000?l000001Ol00009odRhm`03o`000?m[Y_CoJjKd00;o
JjKd2ol00004ogZ]m003o`000?nDWm_oU9oK00[oU9oK1Ol00006oi^RfP03o`000?n]WlWo[Io900co
[Io91?l00008ok6Qb003o`000?o0Y/3o`:K000So`:K00_l0000@ol:X_`04o`000?oA/kco0000o`00
00God[Bl00?o0000om:d_?oB];`01_oB];`2o`0000Ood[Jm00Go0000on75_OoQaKgohLFmo`00000S
ooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01oooooo0_l00002okSelP;o00000on^mO401?l0003oX_?`oj;cl?nR
lo02o`0000;oT^o^0_l00002oh3WjP?o00000omZg>D3o`0000;oDLkN1?l00003odRhm`Ko00001_m8
^?L00ol0003oJjKdof^Vm00<of^Vm0Go00004OnDWm/5o`000003oi^Rf_l0003o[Io900co[Io90ol0
00000on]WlWo0000o`000002o`0000Go/J7800?o0000ol2V`?o0Y/002_o0Y/03o`0000co`ZRo00?o
0000om6c_?oA/k`00_oA/k`00ol0003od[Blom:d_003om:d_003o`000?oB];cod[Bl00Ood[Bl0_l0
0004om:f_@03o`000?oQaKgohLFm00?ohLFm00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Mooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07Ooo
ool01Ol0003o^?GbokSel_nhmO;o000000Co[_Ga00?o0000oj;cl?nRlo000_l00002oi;_kP;o0000
0_n0inX2o`0000?oJ]cU0ol000000omAc]ko0000o`000002o`0000;o=kcG1_l00005obnXk`So0000
4Om[Y_@00ol0003oS9_MohbKg@04o`00013oU9oK0_l0000:ojfOb@?o00002?n]WlT4o`000003ok6Q
b?l0003o`:K000ko`:K00_l0000:ol:X_`03o`000?oA/kcodK>l00?odK>l0_l00004om:d_003o`00
0?oB];cod[Bl00Sod[Bl00Go0000om:f_OoB][god[Jmo`000006on75_@03o`000?oooooooooo023o
oooo0_l0000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09?ooool2o`00
01cooooo00Go0000okSel_nhmO;o^?Gbo`000003ojkel@;o00000_nRlo000ol0003oT^o^oi;_kP02
o`0000;oP>OZ0_l00003of[Li@;o000000?oDLkNo`000?l000000_l000000olg_=Oo0000o`000002
o`0000;o6jS>0_l00003oa^XcP03o`000?lFUNGo5YGU00Oo00000_l_Z>l00ol0003oFYgboeZMlP05
o`0000[oJjKd00?o0000ohbKgOn<Vmd00on<Vmd4o`0000goU9oK00?o0000ojVMbonYWL/00ol00002
ojfOb@?o00003on]WlT3o`00013o`:K00ol00006ol:X_`03o`000?oA/kcodK>l00KodK>l0_l00003
om:d_003o`000?oB];cod[Bl00Sod[Bl0_l000000ooB][go0000on75_@06on75_@03o`000?oooooo
oooo01kooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0002Oooooo00?o0000
ooooooooool06?ooool01Ol0003o^?GbokSel_nhmO;o000000?o[_Ga00Go0000oj;cl?nRlo3oX_?`
o`000002oi;_kP[o00000omoj=`2o`0000;oI]_J0_l00003odW9eP?o000000?o09;3o`000?l00000
0ol00008oaJEi@Co00001_mJWO85o`0000GoJjKd00?o0000ohbKgOn<Vmd01on<Vmd4o`0000WoU9oK
00?o0000ojVMbonYWL/00_nYWL/4o`0001;o[Io900?o0000okfU`Ol000000_l0000@ol2V`0;o0000
1?o2Z;l00ol0003odK>lom6c_008om6c_0;o000000?od[Blo`000?oB];`02ooB];`00ol0003ohLFm
on75_@07on75_@03o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool000Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05_ooool01Ol0003o
^?GbokSel_nhmO;o000000?o[_Ga00Co0000oj;cl?nRlo3oX_?`1Ol00002okClgP03o`000?nVn=go
000000;oU?7M00Go0000ogoXg?moj=coOnSLo`000003ofKKfPgo000000?o07bho`000?l000001ol0
0004oaJEi@03o`000?m6T_3o000000;o00001_mJWO86o`0000goS9_M1?l00005oiBOf`03o`000?nY
WL_o000000;o00001?nYWL/3o`0000oo[Io900?o0000okfU`OnmYL400_nmYL42o`00013o`:K00ol0
00000oo2Z;oo0000om6c_00;om6c_003o`000?oB];co000000_od[Bl0_l00009on75_@03o`000?oo
oooooooo01oooooo00?o0000ooooooooool06_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Dooooo`04o`000?nhmO;o^?GbokSelPCo[_Ga00?oX_?`o`000?l0
00000_l00002okongP07o`000?ndo=ko]?cNokClg_l0003oY_SMo`000002oiCag@03o`000?moj=co
OnSL00Oo00000_nXmNl01Ol0003oSn_doho[m?n?joCo000000?oK]Wd00Co0000odO1kom7`NooAl7_
1ol000000ol0PMWo0000o`000004o`0000?oAY;`0ol00008oeZMlP;o00004?n<Vmd7o`0000[oZIg;
0ol0000;ojfOb@03o`000?nmYL7o_JG100Go_JG10_l0000Aol2V`0;o00003OoA/k`3o`0000Wod[Bl
00Co0000on75_?oQaKco00002OoQaKd00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[o
oooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04_ooool01Ol0003o^?Gb
okSel_nhmO;o[_Ga00Go00000_o8o]l01?l0003o_okNokong_l00003okClgP03o`000?nVn=go0000
00;oU?7M1_l00002ok_jjP05o`000?nXmNooZ?G_ojSekol000000on?jo@00ol0003oK]Wdo`000009
o`000005oafQi?l0003o0000o`000?l0K<`00ol00002o`21f@;o00001Om6T_03o`0000KoFYgb00?o
0000oh6Ggon1Uml00ol0000<ohbKg@Go00003_nYWL/3o`0000So[Io900?o0000okfU`OnmYL401onm
YL43o`0000ko`:K000?o0000om2b_?l000003_oA/k`2o`0000Sod[Bl00Go0000on75_?oQaKcohLFl
o`000009on75_@03o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool002Oooooo0_l0
000/ooooo`03o`000?oooooooooo013ooooo1_l00002olkmh005o`000?o8o]oob?kOolSngol00000
0_noo]h02?l0003o]?cNokClg_ndo=ko0000ojKhgOl0003oU?7M0ol00002olWli003o`000?nkn^[o
^o[Z00;o^o[Z00Ko0000ojSekonXmNooZ?G_o`000?n?jo@4o`0000;o[n?i00?o0000oi;Go_nBeoh0
0_nBeoh00ol0003oKLCnofg4oP06o`0000;o06c<0_l000000ol0PMWo0000oc65j`02o`0000GoAY;`
0ol00003oeZMlP03o`000?n1UmooPIOO00?oPIOO0ol00006ohbKg@?o00001?n<Vmd00ol0003oXi_=
o`000002o`0000goZIg;0ol00005ojfOb@03o`000?nmYL7o_JG100[o_JG10_l0000<ol2V`003o`00
0?o@/[cod;:l00;o00003OoA/k`3o`0000God[Bl00?o0000on75_?oQaK`00ooQaK`00ol0003ohLFm
on75_@07on75_@03o`000?oooooooooo01kooooo00?o0000ooooooooool06?ooool002Oooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`;o00000_oCnn401Ol0003oc_gPolkm
h?o>oN3o000000?ob?kO00Co0000okong_noo]ko00000ondo=h00ol0003oY_SMo`000002o`000003
om?mg_l0003obOcT00;obOcT00Go0000ok_jj_nkn^[o^o[Zo`000002ojSek`Co00000_o3j?000ol0
003o[n?iojoSn@02ojoSn@03o`000?nBeokoT]On00;oT]On00Co0000ofg4o_m]a?ko00000oloYoH4
o`000004o`1/c?l0003o0000o`0000?o<HG[0_l00005odJBl0?o000000?oFYgbo`000?n1Uml01_n1
Uml6o`0000OoS9_M00?o0000oj>KcOnSVld00_nSVld3o`0000goZIg;0ol000000on]WlWo0000okfU
`@0>okfU`@?o00002?o0Y/000ol0003od;:lom2b_003om2b_0;o00003?oA/k`00ol0003odK>lo`00
0003om:d_003o`000?oQaKcohLFl00GohLFl00?o0000on75_OoQaKd01ooQaKd00ol0003ooooooooo
o`0Looooo`;o00006_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=
ooooo`04o`000?oCnn7odo_Qo`0000Coc_gP00Oo0000olSngoo8o]oob?kOo`000?noo]ko000000?o
]?cN0ol00004om?mgP05o`000?o9o>CobOcTolWli?l000000onkn^X3o`000003om3Ziol0003o`nS`
00Co`nS`00?o0000ojoSnOn_hoT00_n_hoT01Ol0003oT]Onoi;Go_nBeoko000000?oKLCn00Ko0000
ocnWm_loYoKo?jOfo`000?l?Q>D4o`000003o`1/c?l0003o<HG[00?o<HG[0ol00005odJBl0;o0000
1on1Uml6o`0000OoS9_M00?o0000oj>KcOnSVld01OnSVld2o`0000koZIg;0_l0000BokfU`@;o0000
1_o0Y/000ol0003od;:lom2b_005om2b_003o`000?oA/kcodK>l00[odK>l00Ko0000om6c_?l0003o
0000om:d_?l00008on75_003o`000?oQaKgohLFm00OohLFm00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_o
oooo00Go0000om?khOoCnn7odo_Qo`000003olkmh005o`000?o8o]oob?kOolSngol000000_noo]h0
0ol0003o]?cNokClgP02o`000003om[lf_l0003odogN00?odogN00Co0000olWli?o9o>Co00000onk
n^X2o`0000Cod>[W00?o0000ol?Xl?o3j?000oo3j?001Ol0003o[n?iojoSnOn_hoWo000000;oT]On
2Ol000001_loYoKo0000o`n4iOmH003o0000o`1H_PCo00001OlaQN/2o`0000CoAY;`00?o0000ogFA
h?l000001Ol00006oh6Gg`?o00001?n<Vmd00ol0003oXi_=oj>Kc@07oj>Kc@?o00003?nYWL/01?l0
003o^ZC2o`000?l0000AokfU`@;o00001?o0Y/000ol0003od;:lom2b_006om2b_0;o00002_oA/k`0
1Ol0003odK>lom6c_?oA/kco000000[ohLFl00?o0000on75_OoQaKd01ooQaKd00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Kooooo000Wooooo`;o0000<?ooool00ol0003oooooooooo`0:
ooooo`04o`000?oCnn7odo_Qo`0000?oc_gP00Go0000olSngoo8o]oob?kOo`000002okongP04o`00
0?ndo=ko]?cNo`0000?of_cJ00?o0000om?mg_oCoMh00_oCoMh00ol0003obOcTolWli004o`000003
om[Zgol0003od>[W00?od>[W00?o0000ol?Xl?o3j?000oo3j?000ol0003o[n?iojoSn@04o`0000;o
ZLO_00?o0000ohjmm_n>_OH00_n>_OH00ol0003oJjcgo`000002o`000004o`n4iOl0003o0000o`15
/@?o000000Co6WKSo`000?l0003o00000olaQN/2o`0000;oAY;`00?o0000ogFAh?l000001Ol00009
oh6Gg`?o000000?oS9_Mo`000?nSVld02onSVld3o`0000WoZIg;00Co0000okZT`_njY<;o^ZC20_l0
000AokfU`@Co00002oo@/[`2o`0000WodK>l00?o0000om6c_?oA/k`00_l0000:on75_003o`000?oQ
aKgohLFm00OohLFm00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`009_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00Go0000om?khOoCnn7odo_Qo`00
0003olkmh008o`000?o8o]oob?kOolSngol0003o_okNo`000?ndo=h2o`0000Cof_cJ00Go0000om?m
g_oCoMkodogNo`000002olWli0;o00001OoJj]l00ol0003od>[Wom3Zi`02om3Zi`03o`000?o3j?3o
`nS`00;o`nS`0ol00002ok_<i`03o`000?nYanooZLO_00;oZLO_00?o0000ohjmm_n>_OH00_n>_OH0
1?l0003oJjcgo`000?lnTo42o`000003o`1OcOl0003o000000?o00000olJM^<2o`0000?o<HG[1?l0
0006ogFAh0;o00002_n1Uml2o`0000ooXi_=0_l00007ojVMb`03o`000?njY<;o^ZC200?o^ZC20_l0
000BokfU`@;o00003?o@/[`00ol0003odK>lom6c_007om6c_0;o00000_oPa;`00ol0003ohLFlon75
_008on75_003o`000?oQaKgohLFm00OohLFm00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Eooooo`009_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Co0000
om?khOoCnn7o00000oo>oN001_l0003ob?kOolSngoo8o]oo0000okongP?o000000?ogo[Go`000?oJ
o=X00ooJo=X02Ol0003odogNom?mg_oCoMko0000olWli?l0003oh>WIo`000005om[Zg`03o`000?o@
j^Ood>[W00;od>[W00?o0000ol?Xl?l000000_l000000oo8cmoo0000ok_<i`03ok_<i`03o`000?nY
anooZLO_00;oZLO_00?o0000ohjmm_n>_OH00_n>_OH00ol0003oJjcgo`000002ocjCl@So00000olJ
M^<5o`000003oc65jol0003oMI7P00OoMI7P0ol00008oh6Gg`03o`000?nMV<oo000000;o00003OnS
Vld3o`0000?oZIg;00?o0000okZT`_njY<801_njY<82o`00013o_JG100?o0000olja_Ol000003?o@
/[`2o`0000SodK>l00Go0000on34_?oPa;coh<Blo`00000:on75_003o`000?oQaKgohLFm00KohLFm
00?o0000ooooooooool07?ooool2o`0001Kooooo000Vooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01Oooool01Ol0003odo_Qom?khOoCnn7o000000?oc_gP00?o0000olSngoo8o]l0
0ol00004omoje`05o`000?oJo=[of_cJom[lf_l000001?oCoMh2o`0000?oh>WI00?o0000om[ZgooJ
j]l00ooJj]l01?l0003od>[Wom3Zioo@j^L2o`0000Gob<oO00?o0000ok_<ionkc>L00_nkc>L00ol0
003oZLO_ojW7k`02ojW7k`03o`000?n>_OKoS[gf00;oS[gf00?o0000of^/mol000000_lnTo45o`00
0003o`15/Ol0003o0VKJ00Oo000000?o<HG[o`000?mWRn400_l00008ogFAh0;o00001_n1Uml00ol0
003oWIS?oifHc`02oifHc`;o00003_nSVld4o`0000[o^ZC20ol0000<okfU`@04o`000?o>/Kgoc[6m
olja_@;o00003?o@/[`00ol0003odK>lom6c_005om6c_003o`000?oPa;coh<Bl00;oh<Bl00?o0000
on75_?oQaK`02?oQaK`00ol0003ohLFmon75_@04on75_@03o`000?o]fl3o000001kooooo00?o0000
ooooooooool05?ooool002Kooooo0ol0000dooooo`03o`000?oooooooooo00Cooooo00Co0000om?k
hOoCnn7o00000oo>oN001ol0003ob?kOolSngoo8o]oo0000on;heOl000001?oOn]L01Ol0003of_cJ
om[lf_oJo=[o000000?odogN0_l00004on3Yf@03o`000?oJj]oof^[O00?of^[O00Ko0000om3Zioo@
j^Oo0000om7?f?l00006olS?g`03o`000?nkc>Oo^lcW00;o^lcW00?o0000ojW7konYanl00_nYanl0
0ol0003oS[gfohjmmP05o`0000;o?Y?a00Co0000o`abh?l<L^3oLP001?l000000ol2I][o0000o`00
0003oaYfh`?o00000_mWRn43o`0000OoMI7P0ol00003oh6Gg`03o`000?nMV<ooWIS?00CoWIS?0ol0
000>oj>Kc@03o`000?njY<;o^ZC200_o^ZC20_l0000:okfU`@03o`000?o>/Kgoc[6m00?oc[6m00?o
0000om2b_?o@/[`02_o@/[`2o`0000CodK>l00?o0000on34_?l000001?oPa;`00ol0003ohLFlon75
_008on75_003o`000?oQaKgohLFm00;ohLFm00Co0000ongK`?o]fl3o00007oooool00ol0003ooooo
ooooo`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Co
0000om?khOoCnn7o00001?o>oN001?l0003ob?kOolSngol00002on;he@03o`000?oOn]Oogo[G00;o
go[G00Ko0000om[lf_oJo=[of_cJo`000?oCoMh2o`000003onCWdol0003oh>WI00Coh>WI00?o0000
om[ZgooJj]l00_oJj]l00ol0003od>[Wo`000003om7?f003o`000?o8cmoob<oO00Cob<oO00?o0000
ok_<ionkc>L00_nkc>L00ol0003oZLO_ojW7k`04o`0000;oTJcX00?o0000ogBPkOmdX>d02Ol00000
1Ol0ELko0000o`9Vf_l2I][o000000Co6WKS00?o0000ofN;hOmWRn400omWRn42o`0000SoMI7P1?l0
0009oifHc`;o00003?nSVld00ol0003o]j;4o`00000=okZT`P;o00002?nmYL400ol0003oc[6molja
_@04olja_@;o00003?o@/[`2o`0000;odK>l00Co0000on34_?oPa;co00001?oPa;`00ol0003ohLFl
on75_008on75_005o`000?oQaKgohLFmon75_Ol000000_o]fl000ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01;ooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0fooooo`04o`000?ooooooooooo`0000?odo_Q00Ko0000olkmh?o>oN3oc_gPo`000?o8
o]l2o`0000?oh_SE00?o0000omojeooOn]L00_oOn]L01?l0003of_cJom[lf_oJo=X2o`0000Coi>OC
00?o0000on3YfOoPjMT00_oPjMT00ol0003of^[Oom[Zg`02om[Zg`;o00001OoAcmP00ol0003ob<oO
olS?g`04olS?g`04o`000?nkc>Oo^lcWok_<i`?o00001?nV/^43oi6/j003o`000?mdX>goM:3]00Oo
000000Ko01R@o`000?l0ELko05G>o`000?l2I]X2o`0000;o6WKS00?o0000oeF2hOl000001OmWRn42
o`0000WoMI7P00?o0000oifHconMV<l02OnMV<l2o`0000WoXi_=00?o0000okNRa?ngX/@00_ngX/@2
o`0000co^ZC20_l00005okfU`@03o`000?o>/Kgoc[6m00Ooc[6m00?o0000om2b_?o@/[`02oo@/[`0
0ol0003odK>lo`000003on34_003o`000?oPa;coh<Bl00;oh<Bl00?o0000on75_?oQaK`02?oQaK`0
0ol0003ohLFmo`000004ongK`003o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool0
01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo0ol00002
om?kh@04o`000?o>oN3oc_gPolkmh0?o000000?oiOKDo`000?oRn=D00_oRn=D01Ol0003ogo[Gomoj
eooOn]Oo000000?of_cJ0_l00005onCWd`03o`000?oPjMWoh>WI00?oh>WI00Ko0000om[ZgooJj]oo
0000omO?dOl00006om7?f003o`000?o8cmoob<oO00Cob<oO00?o0000ok_<iol000000ond]]X5ojJb
h@03o`000?nA[>So000000;o000000KoM:3]o`000?m?S^coChk/o`000?lQLn84o`0000;o05G>0_l0
00001Ol2I][o0000o`000?lJM^?o000000;oEH;Q0_l00004ofN;h@;o00001omeTN001?l0003oU9KB
o`000?l0000:oifHc`?o00001_nSVld00ol0003o]j;4okNRa004okNRa0;o00003?njY<82o`0000?o
_JG100?o0000olja_Oo>/Kd02?o>/Kd2o`0000cod;:l00?o0000on34_?oPa;`00_oPa;`00ol0003o
h<Blon34_003on34_003o`000?oQaKcohLFl00SohLFl00?o0000ongK`?o]fl000oo]fl000ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`00
6oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0000iooooo`05o`000?oCnn7odo_Qom?k
hOl000000oo>oN001Ol0003oiOKDonGfe?oUm]Co000000?oh_SE00Go0000omojeooOn]Oogo[Go`00
0002om[lfP03o`000?oWi/oo000000Goi>OC00?o0000on3YfOoPjMT00ooPjMT00ol0003of^[Oo`00
0003omO?d@03o`000?oAcmSodLoH00CodLoH00?o0000olS?goo8cml00oo8cml2o`0000Go];KJ00?o
0000ojJbhOnV/^400ol00002oi6/j004o`000?mdX>goM:3]o`0000;oChk/00Co0000ob5ch_l0003o
05C?0ol00002o`1EcP;o000000?o0VKJo`000?l000001?mEP^400ol0003oIh_QofN;h@03ofN;h@;o
00001OmeTN001?l0003oU9KBoiBFd_nDU]82o`0000_oWIS?0_l00004oj>Kc@03o`000?ngX/Co]j;4
00Ko]j;40_l0000<okZT`P;o000000?o_JG1o`000?o>/Kd02oo>/Kd00ol0003od;:lom2b_009om2b
_0;o00001?oPa;`00ol0003oh<Blon34_003on34_003o`000?oQaKcohLFl00OohLFl00?o0000ongK
`?o]fl001?o]fl000ol0003oooooooooo`0Looooo`?o00002_ooool00ol0003oooooooooo`05oooo
o`006oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>Oooool01?l0
003odo_Qom?khOl00002olkmh0;o00001?oUm]@01Ol0003oh_SEon;heOoRn=Go000000?ogo[G00?o
0000om[lf_l000000ooWi/l00ol0003oi>OConCWd`03onCWd`03o`000?oPjMWoh>WI00;oh>WI0_l0
0005omO?d@03o`000?oAcmSodLoH00CodLoH00Go0000olS?goo8cmoob<oOo`000002oknhd`03o`00
0?nd]][o];KJ00;o];KJ0ol00003ojJbh@04o`000?nA[>SoTJcXo`0000;oM:3]00Oo0000odn>k?m?
S^co0000ob5ch_l0003o05C?00;o000000Go03Bdo`000?l0ELko05G>o`000002o`9VfP03o`000?mE
P^7oEH;Q00;oEH;Q0_l00005ofN;h@?o00000_meTN000ol0003oU9KBoiBFdP03oiBFdP;o00002onM
V<l4o`0000_o]j;40_l0000<okZT`P;o00003Oo>/Kd00ol0003od;:lom2b_007om2b_004o`000?oO
a;goglBmo`0000Coh<Bl00?o0000on34_?oPa;`00ooPa;`00ol0003ohLFlon75_005on75_003o`00
0?o^fkoo000000GokM_000?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Gooooo000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`0hooooo`04o`000?oCnn7odo_Qom?kh@?o000000?oi_?Co`000?oUm]@00_oUm]@01Ol0003o
h_SEon;heOoRn=Go000000Cogo[G0_l00004onOVc`03o`000?oTim?oi>OC00?oi>OC00Oo0000on3Y
fOoPjMWoh>WIo`000?oKc/co000000KoeloA00?o0000om7?f?oAcmP01?oAcmP00ol0003ob<oOo`00
0004oknhd`Co00000_nd]]X00ol0003oY[;QojJbh@02ojJbh@04o`000?nA[>SoTJcXo`0000;oM:3]
00Go0000odn>k?m?S^co0000ob5chP04o`000004o`0d]?l0003o0000o`1EcP?o000000?o@GSPoeF2
hOmEP^400omEP^42o`0000KoIh_Q0ol00007oiBFdP;o00003?nMV<l00ol0003o]j;4okNRa00;okNR
a003o`000?njY<;o^ZC200Wo^ZC200?o0000ol^`_ol000003Oo>/Kd2o`0000Ood;:l00Go0000omo4
_OoOa;goglBmo`000004on34_003o`000?oPa;coh<Bl00?oh<Bl00?o0000on75_?oQaK`01?oQaK`0
0ol0003ok]^oo`000006ongK`003o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool0>?ooool01?l0003odo_Qo`000?l00004onKcd`05o`000?oUm]CoiOKDonGfe?l00000
0ooRn=D01?l0003ogo[GomojeooOn]L2o`0000GoinK?00?o0000onCWdooTim<00ooTim<01?l0003o
h>WIon3YfOl00003om_>c003o`000?oGcm7oeloA00CoeloA00?o0000om7?f?oAcmP00ooAcmP2o`00
00?o_kSC1?l00005okBffP03o`000?nV/^7oY[;Q00;oY[;Q00?o0000oi6/j?l000003?l000000ol0
=;Co0000o`000002o`1EcP;o000000?o@GSPo`000?l000001?mEP^42o`0000KoIh_Q00?o0000oiBF
d_nDU]801onDU]83o`0000WoWIS?00?o0000ok:Qaol000003?ngX/@2o`0000So^ZC200Co0000ol^`
_oo;/;oobk2o0_l0000=olja_@03o`000?o@/[cod;:l00?od;:l00?o0000omo4_OoOa;d00ooOa;d0
1Ol0003oh<Blon34_?oPa;co000000Koh<Bl00?o0000on75_?oQaK`00_oQaK`01Ol0003ok]^oonkK
_oo^fkoo000000GokM_000?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0003Sooooo
0ol000000ooVlMCo0000onKcd`03onKcd`05o`000?oUm]CoiOKDonGfe?l000000ooRn=D01_l0003o
go[Gomojeol0003ojNC<o`0000KoinK?00?o0000onCWdooTim<00ooTim<2o`0000Goflk<00?o0000
omO?dOoGcm401?oGcm401Ol0003odLoHom7?f?oAcmSo000000;oa[W=0ol00004oknhd`03o`000?nd
]][o];KJ00?o];KJ00Co0000ojJbhOnV/^7oY[;Q0_l00002ohJJg`04o`000?m/T>CoK93To`0000?o
BX3S00Ko86[Lo`000?l0003o0000o`0UYol0=;@2o`0000;o05G>00Co0000od5hh?m1N>3o@GSP0_l0
0004oeF2h@;o00001?mWRn400ol0003oRi;Eo`00000:oiBFdP;o00001onMV<l01Ol0003o/Z77ok:Q
aonbXLOo000000co]j;40_l00006okZT`P03o`000?o;/;oobk2o00?obk2o0_l0000<olja_@;o0000
0_o@/[`00ol0003oglBmomo4_@05omo4_@05o`000?oPa;coh<Blon34_?l000001_oPa;`01?l0003o
hLFlon75_?l00004onkK_`03o`000?o]fl3okM_000?okM_000?o0000ooooooooool07oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`0gooooo`05o`000?oVlMCoi_7DonKae?l000000ooVlm<0
0ol0003oiOKDonGfe002onGfe007o`000?oRn=Goh_SEon;heOl0003ogo[Go`000003onWTc003o`00
0?oWi/ooinK?00?oinK?00?o0000onCWdooTim<00ooTim<00ol0003oflk<om_>c005om_>c003o`00
0?oGcm7oeloA00CoeloA00?o0000om7?f?l000000ol00002olJic@03o`000?no^=?o_kSC00?o_kSC
00?o0000okBff_nd]]X00ond]]X00ol0003oY[;Qo`000002oiVPfP04o`000?n6V]ooQY[Oo`0000;o
K93T00Go0000odZ0hom:P>?oBX3Sob1Zg003o`000003o`0UYol0=;Co03Bd00?o000000?o:VcLod5h
h?m1N>000_m1N>000ol0003oEH;QoeF2h@03oeF2h@05o`000?mWRn7oIh_QofN;hOl000000on;T]D2
o`0000WoU9KB0_l00005oifHc`03o`000?nbXLOo/Z7700;o/Z770_l0000<okNRa0;o00000onjY<80
0ol0003obk2ool^`_`06ol^`_`03o`000?o>/Kgoc[6m00_oc[6m00?o0000om2b_?l000002?oOa;d0
1Ol0003oh<Blon34_?oPa;co000000Koh<Bl00?o0000on75_?l000001?o^fkl00ol0003okM_0ongK
`004ongK`003o`000?oooooooooo01kooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000T
ooooo`03o`000?oooooooooo03Oooooo00?o0000onKae?oVlM@00_oVlM@01Ol0003oi_?ConKcdooV
lm?o000000CoiOKD00Co0000on;heOoRn=Goh_SE0_l00004onWTc003o`000?oWi/ooinK?00CoinK?
00Co0000onCWdooTim?oi>OC0_l00008om_>c003o`000?oGcm7oeloA00?oeloA0ol00006olJic@03
o`000?no^=?o_kSC00?o_kSC00?o0000okBff_nd]]X00ond]]X00ol0003oVJ3JoiVPfP02oiVPfP04
o`000?n6V]ooQY[Oo`0000;oK93T00Go0000odZ0hom:P>?oBX3Sob1Zg003o`000003o`0UYol0003o
03Bd00?o000000?o:VcLo`000?m1N>000_m1N>02o`0000CoEH;Q0ol00006oh^Be@;o00002OnDU]82
o`0000;oWIS?00?o0000ok:QaonbXLL01OnbXLL2o`0000co]j;40_l000000onjY<;o0000ol^`_`08
ol^`_`;o00003?o>/Kd2o`0000WoglBm00Go0000on34_?oPa;coh<Blo`000006on34_003o`000?o^
fkook]^o00Cok]^o00?o0000ongK`?o]fl000oo]fl000ol0003oooooooooo`0Mooooo`03o`000?oo
oooo000000Gooooo00?oEEEEofIVI_l000001oooool002Cooooo00?o0000ooooooooool0=oooool0
0ol0003oi_7DonKae002onKae005o`000?oVlm?oi_?ConKcdol000001?oUm]@00ol0003oh_SEon;h
e@02o`0000GojNC<00?o0000onOVcooWi/l01?oWi/l01?l0003oi>OConCWdol00002omk>b003o`00
0?oKc/coflk<00Goflk<00Co0000omO?dOoGcm7oeloA0ol00002ol^ib0Ooa[W=00?o0000oknhdono
^=<00ono^=<01Ol0003o];KJokBff_nd]][o000000;oYZCD1?nIX=X01?l0003oQY[OohJJgol00002
ofb@i005o`000?m:P>?oBX3SodZ0holPJ]`00ol000000ol09JOo0000o`0d]002o`0000?o:VcL00Go
0000od5hh?m1N>3o@GSPo`000005oeF2h@03o`000?n;T]GoRi;E00KoRi;E0_l00009oiBFdP?o0000
2OnbXLL2o`0000co]j;40_l0000;ol^`_`03o`000?o>/Kgoc[6m00Woc[6m00?o0000omk4__l00000
2OoOa;d01?l0003oh<Blon34_?l00006on34_003o`000?o^fkook]^o00Cok]^o00?o0000ongK`?o]
fl001?o]fl000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo000Tooooo`;o0000
>?ooool01Ol0003oi_7DonKae?oVlMCo000000Coi_?C00?o0000onGfe?oUm]@00_oUm]@01Ol0003o
h_SEo`000?oYh/[o000000KojNC<00?o0000onOVcooWi/l00ooWi/l00ol0003oi>OCo`000004omk>
b003o`000?oKc/coflk<00Goflk<0ol000000ooGcm7o0000ol^ib003ol^ib003o`000?o6^Lgoa[W=
00Coa[W=00?o0000oknhdono^=<00ono^=<00ol0003o];KJo`000004ojJTe005o`000?nIX=[oVJ3J
oiVPf_l000000_n6V]l01?l0003oK93Tofb@i?l00003odZ0h`Co000000Go02FWo`000?l0=;Co0000
oa1MeP03obY/g0;o00000_m1N>02o`0000?oEH;Q00?o0000ogj=f?l000002?n;T]D00ol0003oU9KB
oiBFdP08oiBFdP03o`000?nbXLOo/Z7700Wo/Z7700?o0000okNRa?ngX/@02OngX/@00ol0003ob;32
o`00000;ol^`_`;o00002?o>/Kd01Ol0003og/Bnomk4__oNa;ko000000WoglBm00Co0000on34_?oP
a;co00001?oPa;`00ol0003ok]boo`000006onkK_`03o`000?o]fl3okM_000?okM_000?o0000oooo
ooooool07_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo03Oooooo00Go0000onKae?oV
lMCoi_7Do`000004onKcd`07o`000?oUm]CoiOKDonGfe?l0003oh_SEo`000003onWRbP03o`000?oY
i<cojNC<00?ojNC<00?o0000onOVcooWi/l01?oWi/l00ol0003og/k8omk>b004omk>b004o`000?oK
c/coflk<om_>c0?o000000Coflk<o`000?oGcm7o00001_o;^LP00ol0003oa[W=olJic@04olJic@03
o`000?no^=?o_kSC00?o_kSC00?o0000ojJTe?nVY=@01?nVY=@01Ol0003oVJ3JoiVPf_nIX=[o0000
00;oQY[O00Co0000ofb@i?m/T>Co00000om:P><4o`000006o`0UYol0003o03Bdo`000?l@GMKo0000
0olZK=`01?l0003o@GSPod5hh?m1N>02o`000003oeF2hOl0003oOXgH00;oOXgH00?o0000oh^BeOn;
T]D01On;T]D2o`0000SoU9KB00?o0000ojbOb_l000002_nbXLL2o`0000Wo]j;400Co0000olR``_o8
/<;o00003?o;/;l00ol0003oc[6molja_@05olja_@03o`000?oNa;kog/Bn00;og/Bn00?o0000omo4
_OoOa;d01ooOa;d01?l0003oh<Blon34_?l00003on34_003o`000?o^g;oo000000Kok]^o00?o0000
ongK`?o]fl000oo]fl000ol0003oooooooooo`0Kooooo`?o00000_ooool00ol0003oooooooooo`0;
ooooo`009?ooool00ol0003oooooooooo`0gooooo`05o`000?oVlMCoi_7DonKae?l000001?oVlm<0
1?l0003oiOKDonGfe?oUm]@2o`0000CojN;:00?o0000onWTc?oYi<`00ooYi<`00ol0003oinK?onOV
c`03onOVc`;o00001ooNc/P3o`0000Goflk<00?o0000ol^ib?o;^LP01_o;^LP00ol0003oa[W=olJi
c@04olJic@05o`000?no^=?o_kSCoknhdol000000_n`Y/h6ojJTe005o`000?nIX=[oVJ3JoiVPf_l0
00000_n6V]l01?l0003oK93Tofb@i?l00002odZ0h`So000000Co04k<oa1Me_l@GMKo00000_lZK=`2
o`0000?o@GSP0_l00004ogj=f0;o00001on;T]D2o`0000GoU9KB00Co0000ojbOb_n/Wl[o[9o:0_l0
000:ok:Qa`;o00001_ngX/@00ol0003ob;32olR``P02olR``P;o00002oo;/;l2o`0000Coc[6m00?o
0000omk4__oNa;h01?oNa;h00ol0003oglBmomo4_@07omo4_@06o`000?oPa;coh<Blo`000?oPa;co
00000oo^g;l00ol0003ok]^oonkK_`04onkK_`03o`000?o]fl3okM_000?okM_000?o0000oooooooo
ool05oooool3o`0000Gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0
=_ooool00ol0003oi_7DonKae002onKae003o`000?oVlm?oi_?C00;oi_?C00?o0000onGfe?oUm]@0
0_l00005onWRbP03o`000?oYi<cojNC<00CojNC<00Go0000onOVcooWi/ooinK?o`000002on3=a@04
o`000?oNc/Sog/k8omk>b0Co00001ooKc/`00ol0003ockW5ol^ib007ol^ib003o`000?o6^Lgoa[W=
00Coa[W=00?o0000oknhdol000001?n`Y/h00ol0003oYZCDojJTe003ojJTe005o`000?nIX=[oVJ3J
oiVPf_l000000_n6V]l00ol0003oK93To`000002o`000003ocE_g?l0003o3e_D00Ko000000Co04k<
oa1Me_l@GMKo00000olZK=`01Ol0003o@GSPod5hh?m1N>3o000000KoOXgH0_l00007oh^Be@;o0000
0onDU]800ol0003o[9o:ojbObP03ojbObP;o00002_nbXLL2o`0000Co]j;400?o0000olR``_o8/<80
1?o8/<800ol0003obk2ool^`_`0:ol^`_`;o00000_o>/Kd00ol0003og/Bnomk4_P05omk4_P03o`00
0?oOa;goglBm00OoglBm00Co0000on34_?l0003o00001?o^g;l00ol0003ok]^oonkK_`04onkK_`03
o`000?o]fl3okM_000?okM_000?o0000ooooooooool04oooool4o`0000Sooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0000gooooo`03o`000?oVlMCoi_7D00;oi_7D00Go0000onKcdooVlm?o
i_?Co`000002onGfe003o`000?oZhLWo000000KojN;:00?o0000onWTc?oYi<`00ooYi<`01?l0003o
inK?onOVcol00004on3=a@?o00001?oNc/P00ol0003oflk<om_>c003om_>c005o`000?o?^LGockW5
olniaOl000001oo;^LP00ol0003oa[W=olJic@04olJic@03o`000?n`Y/ko/:K>00Co/:K>00?o0000
ojJTe?nVY=@00onVY=@01_l0003oVJ3JoiVPf_nIX=[o0000ohJJg`?o00000_mFOmh01?l0003o=FoL
o`000?l?Fm@5o`0000;o04k<00Co0000oa1Me_l0003o00000_lZK=`2o`000003od5hh?l0003oKXOK
00OoOXgH0_l00007oh^Be@;o000000?oU9KBo`000?n/WlX01_n/WlX00ol0003o/Z77ok:Qa`09ok:Q
a`05o`000?ngX/Co]j;4okNRa?l000001oo8/<82o`0000cobk2o00?o0000olja_Ol000002?oNa;h0
0ol0003oglBmomo4_@07omo4_@03o`000?oPa;co000000Gok]bo00?o0000onkK_oo^fkl00oo^fkl0
0ol0003okM_0ongK`002ongK`0;o00004_ooool3o`0000gooooo00?o0000ooooooooool02_ooool0
02?ooooo00?o0000ooooooooool0=oooool00ol0003oi_7DonKae002onKae007o`000?oVlm?oi_?C
onKcdol0003oiOKDo`000003on[Qb@03o`000?oYh/[ojN;:00?ojN;:00?o0000onWTc?oYi<`00ooY
i<`00ol0003oinK?o`000002on3=a@?o000000?oh<g5o`000?oNc/P01OoNc/P01Ol0003oflk<om_>
c?oKc/co000000GockW500?o0000ol^ib?o;^LP01Oo;^LP00ol0003oa[W=olJic@03olJic@03o`00
0?nhZ<Wo/:K>00Go/:K>0_l00004ojJTe004o`000?nIX=[oVJ3JoiVPfP;o00000_m`R]`01ol0003o
EWoNoeIog_l0003o=FoLo`000?l?Fm@01Ol00002o`1>c004o`000?l@GMKo45gFo`0000?o:VcL0_l0
0002ofj7f`;o00001_mnSMP00ol0003oRi;Eoh^Be@06oh^Be@03o`000?n/Wl[o[9o:00Oo[9o:0_l0
000:ok:Qa`?o00002_o8/<800ol0003obk2ool^`_`0:ol^`_`03o`000?oNa;kog/Bn00Sog/Bn00?o
0000omo4_OoOa;d01ooOa;d00ol0003ok]boo`000004onkL_`03o`000?o^fkook]^o00Cok]^o00Ko
0000ongK`?o]fl3o0000oo3b`_l0000?ooooo`?o00004?ooool00ol0003oooooooooo`0:ooooo`00
8oooool00ol0003oooooooooo`0gooooo`03o`000?oVlMCoi_7D00;oi_7D00Co0000onKcdooVlm?o
i_?C0_l00004on[Qb@03o`000?oYh/[ojN;:00CojN;:00?o0000onWTc?oYi<`00ooYi<`4o`0000Go
h<g500?o0000omk>b?oNc/P01?oNc/P00ol0003oflk<o`000007olnia@03o`000?o;^LSobkW800Go
bkW800Go0000olJicOo6^Lgoa[W=o`000003okRXb@03o`000?n`Y/ko/:K>00Co/:K>00?o0000ojJT
e?nVY=@00_nVY=@00ol0003oVJ3Jo`000002ohBAf004o`000?m`R]coL8[Lo`0000;oEWoN00Co0000
ocE_g?l0003o3e_D1Ol00002o`1>c0;o000000?o45gFo`000?l000000_lZK=`00ol0003oKXOKofj7
f`02ofj7f`03o`000?mnSMSoOXgH00CoOXgH0_l00006oh^Be@03o`000?nTWLko000000Wo[9o:00?o
0000ok:QaonbXLL02OnbXLL2o`0000[ob;3200?o0000ol^`_oo;/;l02Oo;/;l2o`0000[og/Bn00?o
0000omo4_OoOa;d01_oOa;d01?l0003ok]boonkL_ol00004onkL_`03o`000?o^fkook]^o00?ok]^o
00?o0000ongK`?l000000_o`l/800ol0003oooooooooo`09ooooo`Co00004oooool00ol0003ooooo
ooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`000?oVlMCoi_7D00;oi_7D00?o
0000onKcdooVlm<00_l00005on[Qb@03o`000?oYh/[ojN;:00CojN;:00Co0000onWTc?oYi<cojNC<
0ol00009on3=a@03o`000?oNc/Sog/k800Cog/k800?o0000olniaOo?^LD01oo?^LD00ol0003obkW8
ol^ib005ol^ib003o`000?o6^Lgo000000Go^:S90_l00005ok2VcP03o`000?nVY=CoYZCD00;oYZCD
0_l00003ohBAf004o`000?m`R]coL8[Lo`0000;oEWoN0ol000000ol?FmCo0000o`000002o`000005
o`0[/Ol0003o04k<o`1>c?l000000_l@GMH01?l0003o:VcLo`000?mKOm`4ofj7f`;o00001_mnSMP2
o`0000CoRi;E00?o0000ojBMc_nTWLh00_l00008ojbObP;o00002OnbXLL00ol0003oa:o5o`00000:
olR``P;o00002?o;/;l01?l0003og<?1omc3`Ol0000:omk4_P03o`000?oOa;goglBm00CoglBm00Go
0000onkL`?l0003ok]boo`000004onkL_`03o`000?o^fkook]^o00Cok]^o00Go0000oo3b`_o`l/;o
l?;2o`000008ooooo`?o00005oooool00ol0003oooooooooo`0:ooooo`008oooool3o`0003Oooooo
00Go0000onKae?oVlMCoi_7Do`000002onKcd`03o`000?oYglSo000000Koj^7900?o0000onWRb_oY
h/X01?oYh/X3o`000004onWTc?l0003ohLc3o`0000Woh<g500?o0000omk>b?oNc/P00ooNc/P00ol0
003od[W2o`000008olnia@03o`000?o;^LSobkW800GobkW800?o0000okRXbOnhZ<T01_nhZ<T00ol0
003o/:K>ok2VcP03ok2VcP07o`000?nVY=CoYZCDojJTe?l0003oTiKCo`000003ohBAf004o`000?m`
R]coL8[Lo`0000?oEWoN0_l000000ol?FmCo0000o`000002o`000005o`0[/Ol0003o04k<o`1>c?l0
00000_l@GMH2o`0000;oFgoL00?o0000ofj7fom^Qm/00_m^Qm/2o`0000KoOXgH00Co0000oh^BeOn;
T]Go00001OnTWLh00ol0003o[9o:ojbObP07ojbObP03o`000?nbXLOo/Z7700Go/Z7700Go0000olB_
aOo4[lGoa:o5o`00000;olR``P03o`000?o;/;oobk2o00Gobk2o00Go0000omc3`OoL`l7og<?1o`00
000:omk4_P03o`000?oOa;goglBm00;oglBm00Co0000onkL`?o^g<3o00000_o^g;l01Ol0003ok]bo
onkL_oo^g;oo000000Kok]^o00Go0000oo3b`_o`l/;ol?;2o`000005ooooo`?o00006_ooool00ol0
003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`07o`000?oVlMCoi_7DonKa
e?l0003oi_?Co`000003onWOb003o`000?oZhLWoj^7900?oj^7900Co0000onWRb_oYh/[ojN;:1?l0
0002onWTc005o`000?oQc<?ohLc3on7<`ol000002OoPcLD01Ol0003og/k8omk>b?oNc/So000000?o
d[W200?o0000olniaOo?^LD01_o?^LD00ol0003obkW8ol^ib003ol^ib004o`000?nmZLGo_JW5o`00
00Oo^:S900?o0000ok2Vc_n`Y/h00on`Y/h00ol0003oYZCDo`000003oi>Fd`05o`000?n4TMSoQ97H
ohBAf?l000000_m`R]`01?l0003oEWoNoeIog_mFOmh2o`000003o`mKe?l0003o000000;o000000Go
02^ao`000?l0003o04k<o`000002oa1MeP03o`000?mKOmcoFgoL00;oFgoL00?o0000ofj7fom^Qm/0
0_m^Qm/00ol0003oOXgHogj=f004ogj=f0?o00001_nTWLh2o`0000So[9o:0_l00005ok:Qa`03o`00
0?o4[lGoa:o500;oa:o50_l0000:olR``P;o00001?o;/;l00ol0003og<?1omc3`@03omc3`@03o`00
0?oNa;kog/Bn00Sog/Bn00Go0000omo4_OoOa;goglBmo`000003onkL`004o`000?o^g;ook]boo`00
00?ok]bo00?o0000onkK_oo^fkl00_o^fkl2o`0000?ol?;200?o0000ooooooooool00ol0000Moooo
o`03o`000?oooooooooo00[ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0>?ooool0
1?l0003oi_7DonKae?oVlM@2o`0000CojMo800?o0000on[QbOoZhLT01?oZhLT3o`0000?ojN;:00?o
0000onWTc?l000001OoQc<<00ol0003oh<g5on3=a@07on3=a@03o`000?oNc/So000000God[W200?o
0000olniaOo?^LD01_o?^LD01Ol0003obkW8ol^ib?o;^LSo000000Co_JW50_l00006okRXb@;o0000
1?n`Y/h00ol0003oTiKCoi>Fd`03oi>Fd`05o`000?n4TMSoQ97HohBAf?l000000_m`R]`01?l0003o
EWoNoeIog_mFOmh2o`000003o`mKe?l0003o000000;o000000So02^ao`0l_ol0003o04k<o`000?l@
GMKo0000od=dg0CoFgoL0_l00003ofj7f`;o00001_mnSMP00ol0003oY9g>ojBMcP06ojBMcP03o`00
0?n/Wl[o[9o:00Oo[9o:0_l00002ok:Qa`03o`000?o4[lGoa:o500Goa:o500?o0000olR``_o8/<80
2Oo8/<801?l0003obk2ool^`_ol00007omc3`@03o`000?oNa;kog/Bn00Sog/Bn00?o0000omo4_Ol0
00001?o^g<001?l0003ok]boonkL_ol00003onkL_`07o`000?o^fkook]^oonkK_ol0003ol?C0o`00
0003oo3b`P?o00008?ooool00ol0003oooooooooo`0:ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0
0oooool00ol0003oooooooooo`0hooooo`03o`000?oVlMCoi_7D00;o00001_oYglP00ol0003oj^79
on[Qb@04o`0000KojN;:00?o0000on7<`ooQc<<01OoQc<<00ol0003oh<g5on3=a@07on3=a@;o0000
1_oB^L800ol0003ockW5olnia@06olnia@03o`000?o;^LSo000000Oo_JW500?o0000okRXbOnhZ<T0
1OnhZ<T01_l0003o/:K>ok2Vc_n`Y/ko0000oijIc`GoTiKC00Go0000ohBAf?n4TMSoQ97Ho`000002
og2:g004o`000?mFOmkoEWoNoeIogPOo000000Co02^ao`000?l0003o04k<0_l00002od=dg003o`00
0?mKOmcoFgoL00;oFgoL00?o0000ofj7fom^Qm/00_m^Qm/00ol0003oOXgHogj=f003ogj=f003o`00
0?nJV];oY9g>00OoY9g>0_l00009ojbObP03o`000?nbXLOo000000Soa:o500?o0000olR``_o8/<80
2Oo8/<800ol0003obk2oo`000008omc3`@03o`000?oNa;kog/Bn00Sog/Bn00?o0000onkL`?o^g<00
1?o^g<001?l0003ok]boonkL_ol00003onkL_`06o`000?o^fkook]^oo`000?o`m<3o00000oo`l/80
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000>?ooool0
1_l0003oi_7DonKae?l0003oj=g9o`0000KojMo80ol00003on[Qb@03o`000?oYh/[ojN;:00?ojN;:
0_l00008on7<``03o`000?oPcLGoh<g500Koh<g500?o0000omBi_ol000001_oB^L82o`0000OockW5
00?o0000okfYaOnmZLD01onmZLD2o`0000Ko^:S900?o0000ok2Vc_l000000onNVLl00ol0003oTiKC
oi>Fd`02oi>Fd`;o00000_n4TMP02Ol0003oL8[Log2:g?l0003oEWoNo`000?lbJm[o0000oa5Jd`05
o`000005o`0[/Ol0003o0000o`1>c?l000000om3M=`00ol0003oFgoLoe]og002oe]og003o`000?m^
Qm_oKXOK00;oKXOK0_l00002ogj=f005o`000?nJV];oVY[BoiZJd_l000002?nTWLh00ol0003o[9o:
ojbObP07ojbObP03o`000?o4[lGoa:o500Soa:o50_l0000:olR``P03o`000?oL`l7og<?100Sog<?1
00?o0000omk4__oNa;h01ooNa;h00ol0003ok]c0onkL`004onkL`005o`000?o^g;ook]boonkL_ol0
00000_o^g;l00ol0003ok]^oo`000002oo3d`005o`000?o`l/;ol?;2oo3b`_l000008oooool00ol0
003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oVlMCo0000
00?oj=g900Co0000onWOb?oYglSojMo80ol00006on[Qb@05o`000?oYh/[ojN;:onWRb_l000000_oR
c<400ol0003ohLc3on7<``06on7<``03o`000?oPcLGoh<g500Coh<g500Go0000omBi_ooD^Kooe;Vo
o`000007om:i`P03o`000?o?^LGockW500CockW500?o0000ol6Z`_l000002OnmZLD00ol0003o^:S9
okRXb@04okRXb@03o`000?nNVLooWYW?00?oWYW?0_l00004oi>Fd`04o`000?n4TMSoQ97Ho`0000;o
L8[L0_l00002oc9[fP03o`000?lAF]?o000000Co000000Go02^ao`000?l0003o0000obMVf003od=d
g0;o00000omKOm`2o`0000CoKXOK00?o0000ogj=f?l000001?nJV]82o`0000OoY9g>0_l00007ojbO
bP03o`000?no[/Wo000000[oa:o500?o0000olR``_o8/<801oo8/<82o`0000[og<?100?o0000omk4
__oNa;h01OoNa;h00ol0003okMg2o`000006onkL`005o`000?o^g;ook]boonkL_ol000000_o^g;l0
1Ol0003ol?C0oo3d`?o`m<3o000000?ol?;200?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo0_l00004onSMb@Co0000
0ooYglP00ol0003oj^79on[Qb@03on[Qb@04o`000?oYh/[ojN;:o`0000Coh/c100?o0000on7<`ooQ
c<<01_oQc<<00ol0003oh<g5on3=a@02on3=a@03o`000?oD^Kooe;Vo00?oe;Vo00?o0000om:i`_oB
^L801OoB^L800ol0003ockW5olnia@02olnia@04o`000?o1Z/;o`J[2ol6Z`P;o00002?nmZLD00ol0
003o^:S9okRXb@03okRXb@03o`000?nWW<_oWYW?00GoWYW?00?o0000oi>FdonCU]<00_nCU]<02?l0
003oQ97HohBAf?l0003oL8[Lo`000?m>N=co00000_lbJmX00ol0003o4E[Co`000004o`000003o`0[
/Ol0003o000000;o9fKH00Go0000od=dg?m3M=co@gCLo`000004oe]og003o`000?m^Qm_oKXOK00;o
KXOK00?o0000oiZJd_nJV]801OnJV]800ol0003oY9g>ojBMcP06ojBMcP03o`000?n/Wl[o[9o:00?o
[9o:00Go0000okn^bOno[/Wo_jk9o`00000:olB_a@03o`000?o8/<;ob;3200Gob;3200Co0000omW3
a?oI`lCo00002_oL`l400ol0003og/Bnomk4_P04omk4_P03o`000?o]gL;o000000Kok]c000Go0000
onkL_oo^g;ook]boo`000002onkL_`05o`000?o`m<3ol?C0oo3d`?l000000oo`l/800ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo
00Co0000onSMbOoXgLWoj=g90ol00006onWOb003o`000?oZhLWoj^7900?oj^7900?o0000onWRb_l0
00001_oRc<400ol0003ohLc3on7<``06on7<``05o`000?oPcLGoh<g5on3=aOl000001_oD^Kl00ol0
003od[W2om:i`P05om:i`P04o`000?o?^LGockW5o`0000Ko`J[200?o0000okfYaOnmZLD01_nmZLD2
o`0000;o^:S900Go0000ojNLbonWW<_oYic;o`000005oijIc`03o`000?nCU]?oTiKC00;oTiKC00?o
0000ohBAf?n4TMP00_l00002odihg005o`000?lbJm[o<V_Jo`000?lAF]<01Ol000000ol0:k7o0000
o`MEd002obMVf005o`000?m3M=co@gCLod=dg?l000001?mKOm`2o`0000;oKXOK00?o0000ohfFeonJ
V]801_nJV]800ol0003oY9g>ojBMcP06ojBMcP;o00000_n/WlX00ol0003o_jk9okn^b@03okn^b@;o
00002Oo4[lD2o`0000Cob;3200?o0000omW3a?oI`l@00_oI`l@00ol0003og<?1omc3`@08omc3`@03
o`000?oNa;kog/Bn00;og/Bn00Go0000ongM`_o]gL;okMg2o`000006onkL`004o`000?o^g;ook]bo
onkL_`?o00000oo`m<001Ol0003ol?;2oo3b`_o`l/;o000002?ooooo00?o0000ooooooooool02Ooo
ool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo
00?o0000ooooooooool01_ooool2o`0003Sooooo1?l00003onSMb@03o`000?oYglSojMo800CojMo8
00?o0000on[QbOoZhLT00ooZhLT00ol0003oh/c1on;<`@06on;<`@03o`000?oQc<?ohLc300KohLc3
00?o0000on3=aOl000002?oD^Kl00ol0003od[W2om:i`P05om:i`P03o`000?o?^LGo000000Oo`J[2
00?o0000okfYaOnmZLD01onmZLD00ol0003o^:S9o`000005ojNLb`03o`000?nNVLooWYW?00;oWYW?
00?o0000oi>FdonCU]<00_nCU]<01Ol0003oQ97Ho`000?mUP]_o000000;oCWSL00Go0000oc9[f_lb
Jm[o0000oa5Jd`05o`000003o`12a?l0003o1eG@00?o9fKH00?o0000od=dg?m3M=`00_l00004oe]o
g0;o00000on=U]L00ol0003oVY[BoiZJdP04oiZJdP;o00002?nTWLh00ol0003o[9o:o`000007okn^
b@03o`000?o4[lGoa:o500Soa:o500Go0000olR``_o8/<;ob;32o`000005omW3a003o`000?oL`l7o
g<?100Sog<?100Co0000omk4__oNa;ko00001?o]gL800ol0003ok]c0onkL`004onkL`004o`000?o^
g;ook]boonkL_`?o00000oo`m<001Ol0003ol?;2oo3b`_o`l/;o000002?ooooo00?o0000oooooooo
ool02Oooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Cooooo1?l00004ooooo`03o`000?oooooooooo03Kooooo1?l00005onSMb@03o`000?oYglSojMo8
00CojMo800?o0000on[QbOoZhLT00ooZhLT00ol0003oh/c1on;<`@07on;<`@03o`000?oQc<?ohLc3
00KohLc30_l00009omBi_`03o`000?oB^L;od[W200God[W200?o0000ol6Z`_o1Z/801oo1Z/82o`00
00So_JW500?o0000ojNLbonWW</01OnWW</00ol0003oWYW?oijIc`02oijIc`;o00000onCU]<2o`00
00;oIH;K00?o0000odihg?m>N=`00_l000000olbJm[o0000oa5Jd`05o`000004o`12a?l0003o1eG@
o`0000;o9fKH00Go0000od=dg?m3M=co@gCLo`000004oe]og003o`000?n=U]OoSIKG00;oSIKG0_l0
0006oiZJdP03o`000?nTWLkoY9g>00KoY9g>00?o0000okn^bOno[/T01ono[/T00ol0003oa:o5olB_
a@08olB_a@03o`000?o8/<;o000000OofL?400?o0000omc3`OoL`l402?oL`l400ol0003og/Bno`00
0005ongM`P03o`000?o^g<3ok]c000Cok]c000Ko0000onkL_oo^g;oo0000oo3e_ol00003oo3d`005
o`000?o`l/;ol?;2oo3b`_l000008oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003o
ooooooooo`0cooooo`?o00000oooool00ol0003oj=g9onSMb@03onSMb@03o`000?oYglSojMo800Go
jMo800Oo0000on[QbOoZhLWoj^79o`000?oRbl7o000000Soh/c100?o0000on7<`ooQc<<01_oQc<<0
0ol0003oe[Vmo`000009omBi_`03o`000?oB^L;od[W200Cod[W200?o0000olFZ_ol000002Oo1Z/80
0ol0003o_JW5okfYa@05okfYa@03o`000?n]WLOoYic;00KoYic;0_l00004oijIc`06o`000?nCU]?o
TiKCo`000?mgRMSo00000_mUP]/2o`0000;oCWSL00Co0000oc9[f_l0003o4E[C1Ol000001?l0@/Co
0000o`MEd?l00002obMVf005o`000?m3M=co@gCLod=dg?l000000omKOm`00ol0003oO93KohfFe`04
ohfFe`03o`000?nJV];oVY[B00CoVY[B00?o0000ojBMc_nTWLh01OnTWLh00ol0003o^:c=okn^b@08
okn^b@;o00002Oo4[lD00ol0003ofL?4omW3a007omW3a003o`000?oL`l7og<?100Sog<?100?o0000
ongM`_o]gL801?o]gL800ol0003ok]c0onkL`004onkL`003o`000?o^g;oo000000;ol?Fo00Go0000
oo3d`?o`m<3ol?C0o`000003oo3b`P03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?oo
ool0027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo00?o0000onSMbOoXgLT01?oXgLT0
0ol0003ojMo8onWOb004onWOb004o`000?oZhLWoj^79o`0000?oh/_100?o0000on;<`OoRc<401_oR
c<400ol0003ohLc3on7<``04on7<``05o`000?oF^Kgoe[VmomJi_Ol000002OoD^Kl00ol0003od[W2
om:i`P02om:i`P04o`000?o5Z[ooaJZoolFZ_`;o00002?o1Z/82o`0000Co_JW500Co0000ojfMaon]
WLOo[Ig70_l00006ojNLb`03o`000?nNVLooWYW?00;oWYW?0_l00003ogN9f005o`000?mUP]_oIH;K
ofF2fol000000_m>N=`01?l0003o<V_Jo`000?lAF]<5o`000004o`12a?l0003o1eG@o`0000;o9fKH
0_l00002od=dg003o`000?mKOmco000000?oO93K00?o0000ohfFeon=U]L00_n=U]L00ol0003oVY[B
oiZJdP04oiZJdP;o00001?nTWLh01Ol0003o^:c=okR/cOnh[<go000000Wo_jk900?o0000olB_aOo4
[lD01_o4[lD2o`0000WofL?400?o0000omc3`OoL`l401ooL`l400ol0003okMg2ongM`P04ongM`P03
o`000?o^g<3ok]c000Gok]c000Co0000oo3e_oo`mKool?Fo0_l00002oo3d`005o`000?o`l/;ol?;2
oo3b`_l000009?ooool00ol0003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0000:oooo
o`03o`000?oXgLWoj=g900?oj=g900?o0000onWOb?oYglP01?oYglP00ol0003oj^79o`000005on;;
`@03o`000?oRc<7oh/c100Koh/c100?o0000on7<`ooQc<<00_oQc<<00ol0003oe[VmomJi_@03omJi
_@03o`000?oD^Kooe;Vo00Ooe;Vo00Co0000om:i`_oB^L;o00001_o5Z[l00ol0003o`J[2ol6Z`P07
ol6Z`P04o`000?nmZLGo_JW5o`0000Ko[Ig700?o0000ojNLbonWW</01?nWW</2o`0000?oWYW?0_l0
0003ogN9f0;o00000_mUP]/01Ol0003oCWSLodihg?l0003o<V_J00?o000000SoT1<0o`000?l0003o
0000o`12a?l0003o1eG@o`0000?o9fKH00Co0000od=dg?m3M=co00001OmlT=/00ol0003oSIKGohfF
e`02ohfFe`;o00001_nJV]801?l0003oY9g>ojBMc_l00005okR/c@03o`000?no[/Wo_jk900Oo_jk9
00?o0000olB_aOo4[lD01?o4[lD01?l0003oe/?8omK3b?l00009omW3a003o`000?oL`l7og<?100Go
g<?100?o0000on_NaOl000001_o]gL800ol0003ok]c0onkL`003onkL`0;o00000oo`mKl01Ol0003o
l?C0o`000?o`m<3o000000;ol?;20_l0000Tooooo`03o`000?oooooooooo00Sooooo000Qooooo`03
o`000?oooooooooo02[ooooo0ol0000=ooooo`03o`000?oXgLWoj=g900Coj=g900?o0000onWOb?oY
glP01?oYglP00ol0003oh/_1on;;`@05on;;`@03o`000?oRc<7oh/c100Koh/c100Go0000on7<`ooQ
c<?ohLc3o`000006omJi_@03o`000?oD^Kooe;Vo00Ooe;Vo00?o0000om:i`_l000001oo5Z[l2o`00
00So`J[200?o0000okfYaOl000001on]WLL2o`0000KoYic;00Ko0000oijIconNVLoo0000ohF?eOl0
0004ogN9f003o`000?mUP]_oIH;K00;o000000CoCWSLo`000?l0003o05;?1_l000001?l0@/Co0000
o`MEd?l00003obMVf004o`000?m3M=co0000ofN7gPGoO93K00?o0000ohfFeon=U]L00on=U]L00ol0
003oVY[BoiZJdP04oiZJdP03o`000?nTWLko000000Ko^:c=0_l00008okn^b@;o00001?o4[lD01Ol0
003oe/?8omK3b?oF`lSo000000WofL?400?o0000omc3`OoL`l400ooL`l401?l0003ojmk5on_NaOl0
0006ongM`P03o`000?o^g<3ok]c000;ok]c000?o0000onkg`?l000000oo`mKl00ol0003ol?C0oo3d
`002o`000003oo3b`_l0003o000002Gooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000
ooooooooool09oooool3o`00013ooooo00?o0000onSMbOoXgLT01?oXgLT00ol0003ojMo8onWOb004
onWOb003o`000?oRbl7oh/_100Koh/_100?o0000on;<`OoRc<401_oRc<400ol0003ohLc3o`000008
omJi_@;o00002?oD^Kl00ol0003oaJZoolFZ_`08olFZ_`03o`000?o1Z/;o`J[200Ko`J[200?o0000
ojfMaon]WLL02?n]WLL00ol0003oYic;ojNLb`04ojNLb`;o00000on5SmD2o`0000?oMhWH00Ko0000
ofF2fomUP]_oIH;Ko`000?m>N=`2o`000003o`1Bcol0003o000000Co000000Co04;4o`000?l7EM3o
00000olWI]P01Ol0003oIhONofN7g_mWQmko000000CoO93K00?o0000ohfFeon=U]L00on=U]L00ol0
003oVY[BoiZJdP04oiZJdP03o`000?nh[<go^:c=00Oo^:c=00?o0000okn^bOno[/T01ono[/T01?l0
003oa:o5olB_aOl00005omK3b003o`000?oI`lCofL?400OofL?400Go0000omc3`OoL`l7og<?1o`00
0004on_Na@03o`000?o]gL;okMg200CokMg200Co0000onkL`?o^g<3o00000_o^ml001Ol0003ol?Fo
oo3e_oo`mKoo000000;ol?C00ol000000ooHo[oo0000ooooo`0Tooooo`03o`000?oooooooooo00So
oooo000Pooooo`03o`000?oooooooooo02Gooooo0ol0000Dooooo`03o`000?oXgLWoj=g900?oj=g9
00?o0000onWOb?oYglP00ooYglP00ol0003oh/_1o`000008on;;`@03o`000?oRc<7oh/c100Koh/c1
0_l0000:omJi_@03o`000?oD^Kooe;Vo00Goe;Vo00?o0000olN[_Ol000002Oo5Z[l2o`0000Ko`J[2
00?o0000ok:Oa?l000002On]WLL2o`0000GoYic;0_l00004ohF?e@05o`000?mgRMSoMhWHogN9f?l0
00000omUP]/2o`000003oaURf?l0003o05;?00;o000000co0027o`000?l0003o0000o`12a?l0003o
1eG@o`000?lWI]So0000od]kgol00003ofN7gP03o`000?mlT=_oO93K00;oO93K0_l00004ohfFe`;o
00001?nJV]800ol0003o[j[CokR/c@08okR/c@03o`000?no[/Wo_jk900Oo_jk900?o0000olB_aOl0
00001_oF`lP00ol0003ofL?4omW3a007omW3a003o`000?oL`l7o000000Gojmk500?o0000ongM`_o]
gL801?o]gL800ol0003ok]c0o`000003onkg`005o`000?o`mKool?Fooo3e_ol000000oo`m<000ol0
003of?joo`00000Vooooo`03o`000?oooooooooo00Sooooo000Pooooo`;o00008oooool3o`0001Oo
oooo00?o0000onSMbOoXgLT01?oXgLT01Ol0003ojMo8onWOb?oYglSo000000?oh/_100?o0000on;;
`OoRbl401_oRbl400ol0003oh/c1on;<`@05on;<`@03o`000?oG^Kco000000[oe[Vm00?o0000omBi
_ooD^Kl00ooD^Kl01?l0003oaj^molN[_Oo7Zkd2o`0000WoaJZo00?o0000ol6Z`_o1Z/800_o1Z/80
0ol0003o/Yo4ok:Oa002ok:Oa003o`000?n]WLOo[Ig700Oo[Ig700?o0000ojNLbonWW</00_nWW</0
0ol0003oT9?Bo`000004ohF?e@04o`000?mgRMSoMhWHogN9f0;o00000_mUP]/2o`000003oaURf?l0
003o05;?00;o000000So016Io`000?l0003o0000o`12a?l0003o1eG@o`0000?oBg_O00Go0000ofN7
g_mWQmkoIhONo`000005ogb@f`03o`000?n=U]OoSIKG00?oSIKG00Co0000oiZJd_nJV];o00000on_
Z]<00ol0003o^:c=okR/c@06okR/c@03o`000?no[/Wo_jk900Oo_jk900?o0000omK3b?oF`lP01_oF
`lP00ol0003ofL?4omW3a007omW3a003o`000?o[g/Gojmk500Gojmk500?o0000ongM`_o]gL801?o]
gL800ol0003ok_O0onkg`002onkg`005o`000?o`mKool?Fooo3e_ol000000oo`m<03o`0002Kooooo
00?o0000ooooooooool02?ooool0023ooooo00?o0000ooooooooool08?ooool2o`0001[ooooo00?o
0000onSMbOoXgLT01?oXgLT01?l0003ojMo8onWOb?l00005on;;`@03o`000?oRbl7oh/_100Koh/_1
00?o0000on;<`OoRc<400ooRc<401Ol0003oekVlomNi_?oG^Kco000000[oe[Vm00?o0000omBi_ooD
^Kl00_oD^Kl00ol0003oaj^molN[_@03olN[_@;o00002?o5Z[l2o`0000;o`J[200?o0000ok:Oa?nb
Wl@00onbWl@2o`0000So[Ig70_l00002ojNLb`03o`000?n@Tm;oT9?B00;o00000on5SmD2o`0000?o
MhWH00So0000ofF2fol0003o<g3Mo`000?lIH]So0000o`1Bc`?o000000?o02J]o`000?l000000_l0
0002obYZf`?oBg_O00Co0000ofN7g_mWQmkoIhON0_l00004ogb@f`03o`000?n=U]OoSIKG00?oSIKG
00?o0000oiZJd_l000001?n_Z]<00ol0003o^:c=okR/c@06okR/c@;o00001ono[/T2o`0000Soe/?8
00?o0000omW3a?oI`l@01_oI`l@00ol0003ojmk5on_Na@05on_Na@03o`000?o]gL;okMg200CokMg2
00?o0000onkg`?o^ml000_o^ml001Ol0003ol?Fooo3e_oo`mKoo000000;ol?C000Co0000omSn_ooH
o[oo00009oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Mooooo`?o
00007Oooool00ol0003oj=g9onSMb@03onSMb@03o`000?oYglSo000000Ooh/_100?o0000on;;`OoR
bl401_oRbl401Ol0003oh/c1on;<`OoRc<7o000000GoekVl00?o0000omJi_OoF^Kd02?oF^Kd01?l0
003oe;VoomBi_ol00008olN[_@03o`000?o5Z[ooaJZo00OoaJZo00?o0000ol6Z`_l000001onbWl@2
o`0000So[Ig70_l00005oi2CdP03o`000?n5SmGoQHoE00;oQHoE00Co0000ogN9f?mgRMSoMhWH0_l0
0002oc=`g@09o`000?lIH]So0000o`1Bcol0003oQPX0o`000?l09Zgo000000;o15GA00?o0000obYZ
folZJ]/00om;Nml00ol0003oIhONofN7gP02ofN7gP03o`000?mlT=_oO93K00;oO93K00?o0000ohfF
eon=U]L00on=U]L00ol0003o[j[CojnZd`04ojnZd`;o00002?nh[<d00ol0003o_jk9okn^b@03okn^
b@04o`000?o@`lgod<?=o`0000Soe/?800?o0000omW3a?oI`l@01?oI`l@00ol0003oj=o:o`000007
on_Na@03o`000?o]gL;okMg200;okMg20_l00004onkg`006o`000?o`mKool?Fooo3e_ol0003ol?C0
0_l000000ooHo[oo0000o`00000Wooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oo
oooooooo01[ooooo0ol0000Pooooo`03o`000?oXgLWoj=g900Coj=g900?o0000on;;`OoRbl401_oR
bl400ol0003oh/_1on;;`@07on;;`@03o`000?oRc<7o000000OoekVl0_l00009omJi_@03o`000?oD
^Koo000000Woaj^m0_l00008olFZ_`03o`000?nbWlCo/Yo400So/Yo40_l00007ojfMa`;o00001On@
Tm82o`0000?oQHoE0_l00002ogN9f0;o00000_lcL=d5o`000004o`03ROl0003o02J]o`0000;o15GA
00Co0000obYZfolZJ]_o00000_m;Nml00ol0003oIhONofN7gP02ofN7gP03o`000?mlT=_oO93K00;o
O93K00Go0000ohfFeon=U]OoSIKGo`000002oj>Wf0Oo[j[C00?o0000okR/cOnh[<d01_nh[<d01Ol0
003o_jk9okn^bOno[/Wo000000Cod<?=00?o0000omK3b?oF`lP01_oF`lP00ol0003ofL?4omW3a002
omW3a005o`000?oXgl[oj=o:onSOb_l000001_o[g/D01ol0003okMg2ongM`_o]gL;o0000onch`ol0
00001?o^ml001?l0003ol?Fooo3e_oo`mKl3o`0000;of?jo00?o0000ooooool000009_ooool00ol0
003oooooooooo`07ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`03o`000?oXgLWoj=g900?o
j=g90_l00009on;;`@03o`000?oRbl7oh/_100Ooh/_10_l00009omNi_003o`000?oF^Kgoe[Vm00Oo
e[Vm00?o0000olN[_Oo7Zkd02_o7Zkd00ol0003oaJZoolFZ_`05olFZ_`03o`000?nfX<;o000000[o
/Yo40_l00005ojfMa`04o`000?nIU/oo0000o`0000GoT9?B00?o0000ohF?eOn5SmD00_n5SmD01Ol0
003oMhWHo`000?m:O>3o000000?o<g3M00So0000oaURf?l0003o0000o`03ROl0003o02J]o`0000;o
15GA00Co0000obYZfolZJ]_o00000_m;Nml00ol0003oIhONofN7gP02ofN7gP03o`000?mlT=_oO93K
00;oO93K00?o0000ohfFeol000001?nSYmP00ol0003o[j[CojnZd`04ojnZd`03o`000?nh[<go^:c=
00Ko^:c=00?o0000okn^bOl000001_o@`ld00ol0003oe/?8omK3b006omK3b005o`000?oI`lCofL?4
omW3a?l000000ooXglX00ol0003ojmk5on_Na@05on_Na@06o`000?o]gL;okMg2o`000?o/n<?o0000
1?o^ml002Ol0003ol?Fooo3e_oo`mKoo0000om;l^?l0003of?joo`000003ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01oooool001oooooo0_l0000Fooooo`?o00009oooool01Ol0
003oj=g9onSMbOoXgLWo000000;ohL[100?o0000on;;`OoRbl401ooRbl400ol0003oh/_1on;;`@06
on;;`@03o`000?oG^[co000000WoekVl00?o0000omJi_OoF^Kd01_oF^Kd00ol0003obJ^lo`00000;
olN[_@;o00001?o5Z[l00ol0003o]Z32okJP`P02okJP`P;o00002OnbWl@01Ol0003o[Ig7ojfMaon]
WLOo000000CoVIK?00?o0000oi2Cd_n@Tm800on@Tm82o`0000?oQHoE0_l00002odYlh0;o00000_lc
L=d00ol0003o6F;Ho`000003o`000005o`0V[Ol0003o15GAo`AEdOl000000_lZJ]/01?l0003oBg_O
od]kgol00004ofN7gP04o`000?mlT=_oO93Kogb@f`;o00001_nSYmP00ol0003o[j[CojnZd`04ojnZ
d`;o00001onh[<d2o`0000Ood<?=00?o0000omK3b?oF`lP01_oF`lP00ol0003ofL?4o`000005onSO
bP03o`000?o[g/Gojmk500Cojmk500?o0000ongM`_l000000_o/n<<00ol0003ok_O0onkg`002onkg
`003o`000?o`mKool?Fo00?o00000_oHo[l00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01oooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool3
o`0002[ooooo00Co0000onSMbOoXgLWo00001?oQb/400ol0003oh/_1on;;`@07on;;`@03o`000?oR
bl7oh/_100Coh/_100Go0000omNj_?oG^[coekZlo`000009omNi_0;o00001OoF^Kd00ol0003obJ^l
olV[_002olV[_003o`000?o7Zkgoaj^m00Woaj^m0_l00002olFZ_`03o`000?nfX<;o]Z3200Co]Z32
0_l00008ok:Oa0;o000000?o[Ig7o`000?nIU/l01?nIU/l2o`0000GoT9?B00Co0000ohF?eOn5SmGo
QHoE0_l00003odYlh005o`000?lcL=go<g3Mo`000?lIH]P01?l000001Ol09Zgo0000o`AEdOl4EM7o
000000;o:V[K00Co0000od]kgom;Nmoo00001?mWQmh00ol0003oO93Ko`000003oi>RgPKoXjOH00?o
0000ojnZdon_Z]<01On_Z]<00ol0003o^:c=okR/c@03okR/c@04o`000?o9`]?obL;Co`0000Ood<?=
00?o0000omK3b?oF`lP01_oF`lP00ol0003oj=o:onSObP05onSObP03o`000?o[g/Gojmk500Cojmk5
00Go0000onch`oo/n<?ok?S3o`000004onkg`008o`000?o`mKoo0000o`000?oBo;So0000omSn_ol0
0005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo00oooooo0ol0000]ooooo`03o`000?oXgLWo000000KohL[100?o0000on;;`OoRbl401_oR
bl400ol0003oh/_1on;;`@04on;;`@03o`000?oG^[coekZl00;oekZl00?o0000omNi_?oG^K`02?oG
^K`00ol0003oe[VmomJi_@02omJi_@03o`000?o9ZkcobJ^l00?obJ^l0_l0000;olN[_@03o`000?o5
Z[oo000000So]Z320_l00008ok:Oa0;o00001onIU/l2o`0000CoT9?B0_l000001?n5SmGo0000oej5
hOl00003odYlh0;o000000Go<g3Mo`000?l0003o0000o`0d]004o`0000;o15GA00Co0000obYZfolZ
J]_o00000_m;Nml01?l0003oIhONofN7g_mWQmh2o`0000GoTj;N00?o0000oj>Wf?nSYmP00onSYmP2
o`0000Ko[j[C00Go0000okR/cOnh[<go^:c=o`000004olW2d`03o`000?o@`lgod<?=00God<?=00?o
0000omK3b?oF`lP01OoF`lP00ol0003oj=o:onSObP05onSObP03o`000?o[g/Gojmk500Cojmk500?o
0000onch`oo/n<<00_o/n<<01?l0003ok_O0onkg`?o^ml02o`000003ol_j/ol0003o000000;of?jo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00cooooo0ol0000aooooo`03o`000?oQb/7ohL[100KohL[100?o0000on;;`OoRbl40
1_oRbl400ol0003oh/_1on;;`@02on;;`@03o`000?oG^[coekZl00CoekZl0_l00009omNi_004o`00
0?oF^Kgoe[Vmo`0000SobJ^l0_l0000:olN[_@03o`000?nfX<;o]Z3200Wo]Z3200?o0000ok:Oa?nb
Wl@01OnbWl@01?l0003oX9S<o`000?l00007oiVFc`;o00001?n@Tm82o`0000;oGXGQ0_l00003odYl
h0;o000000?o<g3Mo`000?l000000ol000001Ol0;[?o0000o`AEdOl4EM7o000000;o:V[K00Ko0000
od]kgom;Nmoo0000ofN7g_l00003ogfIh`GoTj;N00?o0000oj>Wf?nSYmP01?nSYmP00ol0003o[j[C
ojnZd`04ojnZd`03o`000?nh[<go000000KobL;C00?o0000om33cOo@`ld01Oo@`ld00ol0003oe/?8
omK3b003omK3b003o`000?oTgloo000000Ooj=o:00?o0000on_NaOo[g/D00_o[g/D2o`0000Cok?S3
00Wo0000onkg`?o^ml3ok_O0o`000?o;n[?o0000om;l^?l000000_oHo[l00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool000Cooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000:ooooo`?o0000=?ooool0
0ol0003ohL[1on7:`@07on7:`@03o`000?oRbl7oh/_100Koh/_100Co0000on;;`OoRbl7o00002OoG
^[`00ol0003oekVlomNi_007omNi_003o`000?oF^Kgo000000[obJ^l00?o0000olN[_Oo7Zkd01oo7
Zkd00ol0003o^J70o`00000:okJP`P;o00001OnbWl@01?l0003oX9S<oj2Hc?nPV<`2o`0000OoVIK?
0_l00003oi2CdP;o00000omNQN400ol0003oBWcPodYlh002odYlh004o`000?lcL=go0000o`14`PGo
00000_l4EM401Ol0003o:V[KobYZfol0003oBg_O00;o00001OmmVN<00ol0003oTj;Noi>RgP02oi>R
gP03o`000?nSYmSoXjOH00CoXjOH00?o0000ojnZdon_Z]<01?n_Z]<00ol0003obL;ColW2d`06olW2
d`03o`000?o@`lgod<?=00God<?=00Go0000omK3b?oF`lSoe/?8o`000003onCOc`03o`000?oXgl[o
j=o:00Coj=o:00Oo0000on_NaOo[g/Gojmk5o`000?oYn/Oo000000Cok?S300?o0000onkg`?o^ml00
0_l000001_o;n[?o0000om;l^?l0003of?joo`0000Wooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Kooooo0ol0000hooooo`03o`000?oQb/7o
hL[100OohL[100?o0000on;;`OoRbl401_oRbl400ol0003oh/_1o`00000:omNj_003o`000?oG^Kco
ekVl00OoekVl00?o0000olV[_?o9Zk`02_o9Zk`2o`0000Koaj^m00?o0000okVQ`?niXL000_niXL02
o`0000Wo]Z320_l00002ok:Oa003o`000?nPV<coX9S<00CoX9S<0_l00007oiVFc`05o`000?n@Tm;o
T9?Bo`000?m^SMl00_l00002oej5h@;o00000om:O>05o`000003o`0GVol0003o000000Oo00000omQ
SNH5ogfIh`03o`000?nCX]koTj;N00;oTj;N00?o0000oj>Wf?nSYmP01?nSYmP00ol0003o[j[CojnZ
d`03ojnZd`;o00002?o9`]<00ol0003od<?=om33c@05om33c@03o`000?oF`lSo000000Coi=o?00?o
0000onSOb_oXglX01OoXglX00ol0003ojmk5o`000002onWja`03o`000?o/n<?ok?S300;ok?S300So
0000onkg`?l0003o0000ol_j/ol0003od_bho`0000;of?jo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000loooo
o`03o`000?oQb/7ohL[100KohL[100?o0000on;;`OoRbl401ooRbl42o`0000_oekZl00?o0000omNi
_?oG^K`01_oG^K`01?l0003obZbko`000?l0000;olV[_0;o00001?o7Zkd00ol0003o^J70okVQ`004
okVQ`0;o00002OnfX<83o`0000SoX9S<0_l00006oiVFc`?o00000om^SMl2o`0000;oGXGQ0_l00003
odYlh005o`000?l0ELko0000o`000?l05i/00ol00002oaATfP04o`000?lmNn?o?G_So`0000?oHHgV
00?o0000ogfIhommVN<00_mmVN<00ol0003oTj;Noi>RgP02oi>RgP03o`000?nSYmSoXjOH00CoXjOH
00Go0000ojnZdon_Z]?o[j[Co`000002ol30f@03o`000?o9`]?obL;C00KobL;C00?o0000om33cOo@
`ld01Oo@`ld00ol0003oi=o?onCOc`04onCOc`03o`000?oXgl[oj=o:00Goj=o:00Go0000onWjaooY
n/OojO[7o`000004onch``;o000000?o`oR`o`000?l000000_oBo;P3o`0000_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo00?o0000
on7:`OoQb/401_oQb/400ol0003oh/_1on;;`@06on;;`@03o`000?oG^[co000000_oekZl0_l00005
omNi_003o`000?o:[;_obZbk00;obZbk0_l0000;olV[_005o`000?o7Zkgoaj^molN[_Ol000002?ni
XL02o`0000Wo]Z320_l00009oj2Hc0;o00001_nIU/l2o`0000CoKXgO0_l00002oej5h@04o`000?m:
O>3oBWcPodYlh0Co000000Co01NKo`000?l0003o00000_lDI=X01?l0003o?G_Socekhol00003of6=
iP03o`000?mmVN?oOIWS00;oOIWS00?o0000oi>Rg_nCX]h00_nCX]h00ol0003oXjOHoj>Wf004oj>W
f003o`000?n_Z]?o000000Co`<3I00?o0000olW2doo9`]<01_o9`]<00ol0003od<?=om33c@03om33
c@;o00001_oTgll00ol0003oj=o:onSObP04onSObP;o00000ooYn/L00ol0003ok?S3onch``02onch
``06o`000?o3n;3o0000ol_j/ol0003od_bh0ol0000=ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool01_ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool4o`0004Cooooo00?o0000on7:`OoQb/401_oQb/400ol0003oh/_1on;;`@04on;;`@04o`000?oG
^[coekZlomNj_0;o00002ooG^[`00ol0003oekVlomNi_002omNi_003o`000?o:[;_obZbk00CobZbk
0_l0000:olV[_0?o00002oniXL02o`0000Oo]Z3200?o0000ojJJbOl000000_l00008oj2Hc0;o0000
1?nIU/l01?l0003oO9;No`000?l00004ofj=g`03o`000?mNQN7oGXGQ00;o000000GoBWcPo`000?l2
I][o0000o`1EcP02o`000003o`0`/_l0003o000000;o56CJ00Co0000ocekholmNn?o00000omQSNH0
0ol0003oOIWSogfIh`02ogfIh`03o`000?nCX]koTj;N00;oTj;N00?o0000oj>Wf?nSYmP00onSYmP2
o`0000Ko`<3I00?o0000olW2doo9`]<01_o9`]<01Ol0003od<?=om33cOo@`lgo000000;og^3F00?o
0000onCOcooTgll01?oTgll00ol0003oj=o:onSObP02onSObP03o`000?oTnlco000000?ojO[700Co
0000onch`oo/n<?ok?S30ol000001?o;n[?o0000om;l^?oBo;P2o`0000oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`007_ooool2o`0004Oooooo00?o0000on7:`OoQb/40
1_oQb/400ol0003oh/_1on;;`@02on;;`@03o`000?oG^[coekZl00CoekZl00?o0000omNj_?oG^[`0
2OoG^[`01?l0003oekVlomNi_?l00009olZ/^`;o00002_o9Zk`00ol0003o^J70okVQ`00;okVQ`0;o
00001OnfX<800ol0003oYY[9ojJJb@02ojJJb@;o00002?nPV<`2o`0000;oVIK?00Co0000ogbBg_ml
T]koO9;N0_l00003ofj=g`;o00000_mNQN42o`0000;o0VKJ1?l000000ol0<;;o0000o`000002oaAT
fP04o`000?lmNn?o?G_So`0000?oHHgV00?o0000ogfIhommVN<00_mmVN<00ol0003oTj;Noi>RgP02
oi>RgP05o`000?nSYmSoXjOHoj>Wf?l000000_nc_>400ol0003o`<3Iol30f@04ol30f@03o`000?o9
`]?obL;C00KobL;C00?o0000om33cOl000001?oNh=H00ol0003oi=o?onCOc`04onCOc`04o`000?oX
gl[oj=o:o`0000;oi?_<00Go0000onWjaooYn/OojO[7o`000002onch``;o000000?o`oR`o`000?o;
n[<01?l0000@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool0023ooooo
00?o0000ooooooooool0AOooool00ol0003ohL[1on7:`@06on7:`@05o`000?oRbl7oh/_1on;;`Ol0
00001ooG^[`2o`0000[oekZl00?o0000omNi_?l000002oo:[;/2o`0000SobJ^l00Co0000okbR__l0
003o00003?niXL02o`0000;o]Z3200?o0000ojJJbOnVV/T01OnVV/T2o`0000SoX9S<0ol00005ogbB
gP;o00000om^SMl2o`000003oej5hOl0003o000000?o0VKJ00Co0000o`1Ec_l0003o032b0_l00002
oaATfP04o`000?lmNn?o?G_So`0000?oHHgV00?o0000ogfIhommVN<00_mmVN<00ol0003oTj;Noi>R
gP02oi>RgP03o`000?nSYmSo000000Co/kcQ00?o0000ol30fOo0`=T01?o0`=T00ol0003obL;ColW2
d`05olW2d`;o00001OoNh=H00ol0003oi=o?onCOc`04onCOc`03o`000?oXgl[o000000?oi?_<00Ko
0000onWjaooYn/OojO[7o`000?o/n<<2o`000003ol?h/?l0003oboZc00Co00004_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo
00?o0000on7:`OoQb/401_oQb/400ol0003oh/_1o`00000:omNj_003o`000?oG^[coekZl00SoekZl
0_l0000=olZ/^`;o00001Oo9Zk`00ol0003o_::nokbR_P03okbR_P;o00002oniXL03o`0000WoYY[9
0ol00007oj2Hc0;o00001_mlT]h2o`0000?oKXgO0_l000000olJM^?o0000o`000002o`9VfPKo0000
0_lDI=X01?l0003o?G_Socekhol00003of6=iP03o`000?mmVN?oOIWS00;oOIWS00?o0000oi>Rg_nC
X]h00ol00006ok>lh@03o`000?o0`=Wo`<3I00Co`<3I00?o0000olW2doo9`]<00oo9`]<00ol0003o
e]oNo`000006omkPeP03o`000?oTglooi=o?00Coi=o?00?o0000onCkc?oTnl`00_oTnl`01?l0003o
jO[7onWjaooYn/L2o`000005okWe[_l0003o`oR`o`000?o;n[<00ol0000Dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01Oooool002;ooooo00?o0000ooooooooool0A?ooool00ol0
003ohL[1on7:`@07on7:`@;o00002ooG^[`00ol0003oekZlomNj_007omNj_004o`000?o<[K_o0000
o`0000gobZbk0_l00003olV[_003o`000?nlX[ko_::n00Go_::n0_l0000;okVQ`0;o00002onVV/T2
o`0000GoX9S<00?o0000ohNGg?l000000_l00005ogbBgP;o00000om^SMl2o`000003oaYfhol0003o
0VKJ00;o0VKJ00?o0000o`0:R?l000001Ol00002ocekh`05o`000?mQSNKoHHgVof6=i_l000000_mm
VN<4o`0000?oXKOX00?o0000ok>lhOnc_>401?nc_>400ol0003o`<3Iol30f@04ol30f@05o`000?o9
`]?obL;ColW2dol000000ooFgmh00ol0003og^3FomkPeP04omkPeP03o`000?oTglooi=o?00;oi=o?
0_l00004onCkc008o`000?oYn/OojO[7onWjaol0003o^OF^o`000?o3n;05o`0001Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`008oooool2o`0004Gooooo00?o0000on7:
`OoQb/401_oQb/400ol0003oekZmo`00000;omNj_0;o00001_oG^[`00ol0003oc:fkolb]^`02olb]
^`;o00003Oo:[;/2o`000003olV[_?l0003o_::n00So_::n0ol00008okVQ`003o`000?n[W<So0000
00;o00002_nVV/T2o`0000?oX9S<00?o0000ohNGg?n7Um`00_n7Um`2o`0000GoO9;N0_l000000om^
SMoo0000oc65j`04o`0000;o0VKJ00?o0000o`0:R?l0:ZT00_l000000olBKMko0000o`000003o`00
00;oHHgV0ol00002ohR]kP03o`000?nQ]nSoXKOX00?oXKOX00?o0000ok>lhOnc_>401?nc_>400ol0
003o`<3Iol30f@04ol30f@03o`000?o9`]?o000000Coe]oN00?o0000omkPe_oNh=H01?oNh=H01ol0
003oi=o?onCOcooTgloo0000omkme?l000001?oTnl`00ol0003ojO[7onWja`03o`000004ol?h/?l0
003o0000oiS[/0;o00005oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo
000Uooooo`03o`000?oooooooooo04?ooooo00?o0000on7:`OoQb/401?oQb/401?l0003oekZmomNj
_OoG^[d2o`0000_oekZl00?o0000omNj_?oG^[`00ooG^[`00ol0003oc:fkolb]^`04olb]^`;o0000
3Oo:[;/00ol0003o_::nokbR_P0;okbR_P;o00001_niXL000ol0003oZic8oj^Lb002oj^Lb0?o0000
2OnVV/T4o`0000KoQiOL0ol00004ogbBgP?o00000_laQN/4o`000004o`9Vf_l0003o0000o`0ZZ@;o
00000_lBKMh00ol0003o?hS[o`000002o`0000;oJ9k`00Go0000ohR]k_n8[NkoR:g^o`000005oj6g
j003o`000?nc_>7o/kcQ00Co/kcQ00?o0000ol30fOo0`=T00oo0`=T2o`0000Koe]oN00?o0000omkP
e_oNh=H01?oNh=H00ol0003oi=o?o`000002omkme003o`000?oTnlcoi?_<00;oi?_<00Wo0000onWj
aol0003o0000okWe[_l0003o`oR`o`000?nHjk000_l0000Iooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool002Kooooo00?o0000ooooooooool0@oooool00ol0003ohL[1on7:
`@02on7:`@03o`000?oG^[goekZm00CoekZm00?o0000omNj_?oG^[`02OoG^[`2o`0000;oekZl00?o
0000olb]^oo<[K/01oo<[K/3o`0000[obZbk00?o0000okjS__l000000_l0000;okbR_P;o00000oni
XL000ol0003oZic8oj^Lb006oj^Lb0?o00002OnVV/T2o`0000SoQiOL0_l00004ogbBgP;o00000ola
QN/4o`000005o`9Vf_l0003o0000o`17`Ol000000_lBKMh01?l0003o?hS[ocn8jol00003ofRNl005
o`000?n8[NkoR:g^ohR]k_l000001OnQ]nP00ol0003o/kcQok>lh@04ok>lh@07o`000?o0`=Wo`<3I
ol30fOl0003obMgWo`000007omKOgP03o`000?oNh=Kog^3F00?og^3F0_l00003omkme003o`000?oT
nlcoi?_<00;oi?_<0ol000001OnimJko0000o`000?l0003oV>^`00;o00006oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Go
0000on7:`OoQb/7ohL[1o`000007omNj_@03o`000?oG^[coekZl00[oekZl00?o0000omNj_?l00000
3?o<[K/2o`0000OobZbk00?o0000okjS__nnXkh00onnXkh2o`0000_o_::n1?l0000;oj^Lb0;o0000
1onVV/T00ol0003oT9_Jo`000002o`0000OoQiOL0_l00002ogbBgP04o`000?m6T_3o0000o`0000?o
<HG[00Co0000oaYfhol0003o0VKJ0_l000001Ol0Al7o0000oa9]g_lBKMko000000;o?hS[00Go0000
ofRNl?mXW_3oJ9k`o`000003ohR]kP03o`000?nQ]nSoXKOX00?oXKOX00?o0000ok>lhOnc_>401?nc
_>400ol0003o`<3Io`000003olWMi`03o`000?oFgmkoe]oN00Coe]oN00?o0000omkPe_oNh=H00_oN
h=H00ol0003oe?gMo`000003omkme004o`000?oTnlcoi?_<onCkc0?o00000_nimJh2o`000003oiS[
/?l0003o000001cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`00:?oo
ool2o`0004Cooooo00?o0000on7:`Ol000002OoG^[d2o`0000_oekZl0_l0000>olb]^`;o00001Oo:
[;/00ol0003o_Z>nokjS_P05okjS_P?o00002onlX[h2o`0000coZic80ol00004ojJJb@03o`000?n@
Vm[oT9_J00;oT9_J0_l00007ohNGg0Co00000_m6T_03o`000003oc65jol0003o000000;o000000?o
04V]o`000?l000000_l000001OlBKMko0000ocn8joloR>_o000000?oJ9k`00Go0000ohR]k_n8[Nko
R:g^o`000005oj6gj003o`000?nc_>7o/kcQ00?o/kcQ0_l00005olWMi`03o`000?oFgmkoe]oN00Co
e]oN00Co0000omkPe_oNh=Ko00000_oDoMd01_l0003og_gDomkme?oNoMCo0000onCkc0;o000000Co
X^nbo`000?l0003o^OF^0_l000000onHjk3o0000o`00000Nooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0@_ooool2o`0000_oekZm00?o
0000omNj_?oG^[`02?oG^[`01?l0003oc:jko`000?l0000>olb]^`;o00000oo:[;/00ol0003o_Z>n
okjS_P08okjS_P;o00002OnlX[h00ol0003o[Yg6o`000002o`0000coZic81?l00007oi2KfP?o0000
1on7Um`2o`0000CoAY;`0_l000001OlaQN_o0000o`000?l0003o04V]00Ko00000_loR>/01Ol0003o
J9k`ofRNl?mXW_3o000000?oR:g^00?o0000oj6gj?nQ]nP00onQ]nP00ol0003o/kcQo`000002o`00
0003okSHl?l0003obMgW00GobMgW00?o0000omKOg_oFgmh00ooFgmh00ol0003og^3Fo`000003omCm
g@04o`000?oNoMCog_gDomkme0;o00000_nRkk84o`0000;oV>^`0_l0000Pooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@oooool00ol0
003oekZmomNj_@09omNj_@;o00001ooG^[`00ol0003oc:jkolb^^`02olb^^`;o00003_o<[K/3o`00
00go_Z>n0ol00006okbR_P03o`000?n^WLKo[Yg600;o[Yg60ol0000<oj^Lb0?o00002?n@VmX3o`00
00CoQiOL00?o0000oeZMl_l000000_l00003odJBl0;o000000?o<HG[o`000?l000000_l0BJd01?l0
=:_o0000o`1XfOl0J=T4o`0000?oJ9k`00Go0000ohR]k_n8[NkoR:g^o`000004oj6gj0;o00001Onh
f?000ol0003obMgWolWMi`03olWMi`03o`000?oFgmkoe]oN00?oe]oN0_l00004omCmg@03o`000?oN
oMCog_gD00;o00000_nRkk84o`0000;oV>^`0_l0000Rooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@oooool2o`0000_oekZm00?o0000
omNj_?oG^[`01?oG^[`00ol0003oc:jkolb^^`04olb^^`;o00003_o<[K/00ol0003o_Z>nokjS_P0>
okjS_P;o00000onlX[h00ol0003o[Yg6ojjMaP06ojjMaP?o00002On[W<P00ol0003oV9kHoiRNf003
o`0000SoT9_J0_l00002ohNGg003o`000?mJWO;oFYgb00;oFYgb0ol00002odJBl0Co000000Ko05^h
o`000?l0003o0000o`1XfOl00002obR;k@Ko00000on8[Nh01_l0003oXKOXo`000?l0003oX<oho`00
00Ko^=S`00?o0000olWMioo9gNL00oo9gNL01ol0003oe]oNomKOg_oFgmko0000olOkiol000001?oD
oMd01_l0003og_gDo`000?nCjkKo0000oj;_/PCo00000_nHjk02o`0002?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`00;Oooool2o`0004Gooooo00?o0000omNj_OoG^[d0
2OoG^[d00ol0003oekZlomNj_002omNj_003o`000?o<[[_oc:jk00Ooc:jk0_l0000<olb]^`03o`00
0?o0Y;go000000;o00003_nnXkh4o`0000_o[Yg60ol00006oj^Lb003o`000?nHW]SoV9kH00?oV9kH
0ol00007oi2KfPCo00001_mJWO83o`0000;oAY;`0_l00002o`1K^0Co00000_lXRnd01?l0003oEjWi
oeNYnOmGZOT6o`0000CoX<oh00?o0000okSHl?nhf?001?nhf?000ol0003obMgWolWMi`03olWMi`03
o`000?oFgmko000000;oao_W00?o0000omCmgOoDoMd00_oDoMd2o`000003oi?[]_l0003oX^nb00Co
00000_nHjk000ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool002oooooo00?o0000ooooooooool0@oooool00ol0003oekZmomNj_@09omNj_@;o0000
0_oG^[`00ol0003oc:jkolb^^`09olb^^`03o`000?o<[K_oc:fk00Soc:fk00?o0000ol2T_Oo0Y;d0
0oo0Y;d3o`0000ko_Z>n0ol0000<ojjMaP?o00000on[W<P00ol0003oV9kHoiRNf006oiRNf0Co0000
1_n@VmX3o`0000OoFYgb0ol000002?m6T_3o0000o`1^a?l0K/Co05^ho`0aVol0D/3o00000_lXRnd0
1Ol0003oEjWioeNYnOmGZOWo000000?oOl3l00?o0000oj3?n?nPcoP00onPcoP00ol0003o^=S`okSH
l003okSHl003o`000?o9gNOobMgW00?obMgW0_l00003olOki`04o`000?oDoMgoe?gMomCmg@;o0000
00?oTn^fo`000?nRkk800_l000000on6hJCo0000o`000002o`0002Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`13ooooo`;o00002ooG
^[d00ol0003oekZlo`00000<olb^^`;o00002?o<[K/00ol0003o`:Bmol2T_@06ol2T_@;o00003?nn
Xkh00ol0003o/Io5ok6Oa@03o`0000co[Yg61?l0000<oiRNf0?o00000on@VmX00ol0003oJjKdof^V
m005o`0000GoFYgb0ol000001Ol0P]3o06k4o`1^a?l0003o05;000;o000000?o:8_]o`000?mGZOT0
0_mGZOT01Ol0003oOl3logo0o?mo`?co000000GoX<oh00?o0000okSHl?nhf?000onhf?000ol0003o
bMgWo`000002o`000003ok?flOl0003oao_W00;oao_W00?o0000omCmgOl000000_l000000onCjkKo
0000o`000006o`0002_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00
<Oooool2o`0004Gooooo00?o0000omNj_OoG^[d02OoG^[d2o`0000koc:jk0_l00005olb]^`03o`00
0?o0Y;go`:Bm00Wo`:Bm0ol00009okjS_P03o`000?naWlGo/Io500?o/Io51?l0000;ojjMaPCo0000
3?nHW]P3o`000003oi2Kf_l0003oJjKd00GoJjKd1?l00004oeZMlP?o00000_l0P]05o`0000?oEjWi
00Go0000ogo0o?mo`?coOl3lo`000004oj3?n003o`000?nhf?3o^=S`00?o^=S`0_l00004ok?fl@04
o`000?o7nnOoao_WolOki`;o000000?oPNFlo`000?nCjkH01ol000000onAl=_oooooooooo`0Zoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool003?ooooo00?o0000oooooooo
ool0@oooool2o`0000WoekZm00Co0000olf__?l0003o00003_o<[[/2o`0000?oc:fk00?o0000ol2T
_Oo0Y;d03?o0Y;d2o`0000Oo_Z>n00?o0000ok6OaOnaWlD01onaWlD3o`0000So[Yg600Co0000oijQ
e_nNXMKoWZ7F1Ol0000:oiRNf0Go00001om[Y_@6o`000003o`bEfol0003o000000Co000000?o07CF
o`000?l000000ol00003ogo0o003o`000?nPcoSoX<oh00;oX<oh00?o0000okSHl?l000000_l00000
0onIj_Wo0000ok?fl@03ok?fl@03o`000?o7nnOoao_W00;o000000?oPNFlo`000?l000001ol0000_
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000oooo
ooooool0A?ooool00ol0003oekZmomNj_@05omNj_@03o`000?o=[kcocJnl00;ocJnl0ol0000=olb^
^`;o000000?oc:fko`000?o0Y;d03oo0Y;d3o`0000?o_Z>n00?o0000ok6OaOnaWlD02onaWlD4o`00
00Co[Yg600?o0000oijQe_nNXMH01_nNXMH5o`0000KoV9kH00Co0000ogZ]m?mj[OCoNZgd1ol00005
of^Vm0_o00000_lNVNT;o`0000CoVN[i00?o0000ok?flOncm_400_ncm_43o`0000;oPNFl2?l0000b
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool003Gooooo00?o0000oooo
ooooool0A?ooool00ol0003oekZmomNj_@03omNj_@03o`000?o=[kcocJnl00KocJnl0_l0000=olb^
^`03o`000?o0Y;go`:Bm01;o`:Bm1?l0000Aok6Oa@?o000000?o[Yg6o`000?nNXMH03?nNXMH5o`00
00;oV9kH00?o0000ogZ]m?mj[O@01omj[O@6o`000003of^Vm?l0003o9JSU00;o9JSU1ol000000olN
VNWo0000od^km`02od^km`03o`000?meeocoMMOl00;oMMOl00?o0000oiWZnOnIj_T00_nIj_T00ol0
003o/oKaok?fl@08o`000003odc8]Ol0003o000000?o0000=?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00?ooooo000fooooo`;o0000AOooool2o`0000?oekZm00?o0000olf__?o=
[k`02?o=[k`2o`0000_oc:jk00?o0000ol6V__o1Y[h01?l0000Aol2T_@03o`000?naWlGo/Io501;o
/Io51Ol0000?oijQePSo00002_mj[O@Ao`000003od^kmol0003oMMOl00?oMMOl00?o0000oiWZnOl0
00002ol000001OmkiLoo0000o`000?nAl=_o000003Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`03o`000?oG^[go000000go
cJnl0_l00008olb^^`03o`000?o1Y[ko`JJn00Go`JJn1?l0000=ol2T_@03o`000?ndXLGo]:7500Go
00003_naWlD01?l0003oY:CEojBTeOnTY=D5o`0000coWZ7F00?o0000ohNclon7/o<00on7/o<:o`00
00?oNZgd00?o0000ocjik_ln^Nh01_ln^NhBo`000003odc8]Ol0003o000000;o000000CoNnG?o`00
0?l0003oTO3K0_l0000hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0
03Wooooo00?o0000ooooooooool0A?ooool2o`0000oocJnl0_l00006olb^^`03o`000?o1Y[ko`JJn
00Wo`JJn0ol0000:ol2T_@03o`000?ndXLGo]:7500Go]:751?l0000:ok6Oa@03o`000?nTY=GoY:CE
00KoY:CE1_l00006oijQeP03o`000?n7/o?oQk?c00goQk?c7?l000001_m<b;Go0000o`000?m<b;Go
0000og_Uc`;o000000?oTO3Ko`000?l00000>oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo000jooooo`03o`000?oooooooooo04Gooooo0ol0000>olf__0?o00000oo<[[/0
0ol0003o`JJnol6V_P0<ol6V_PCo00001Oo0Y;d00ol0003o]:75okBQa@0:okBQa@Co00001_naWlD0
0ol0003oY:CEojBTe@0<ojBTe@Go00000_nNXMH00ol0003oQk?cohNcl`0AohNcl`03o`000?mFb?Go
E/Se00?oE/Se2Ol00005ofcCnP[o000000?oTO3Ko`000?ooool0?Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;ooooo000kooooo`;o0000B?ooool2o`0000oocJnl0ol0000Col6V
_PCo000000?o`:Bmo`000?ndXLD03ondXLD5o`000003ok6OaOl0003oY:CE01;oY:CE7?l00007ofcC
nPgo00000onMhod2o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`00?Oooool00ol0003oooooooooo`17ooooo`?o00003_o=[k`00ol0003o`JJnol6V_P0Eol6V_P;o
00005OndXLD8o`0000ooY:CE00?o0000oi6hlOnA^?404onA^?401?l0003oK=?jofcCn_m/doX7o`00
00;oOmcl1?l000001?n?hOgo0000o`000?l00003oigSo@?o0000@_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo000nooooo`03o`000?oooooooooo04Wooooo0_l0000<olf_
_003o`000?o2Ykko`ZNn00Co00004_o1Y[h01?l0003o]Z?5okJSaOnfXlD6o`0000go]:7500?o0000
ojRVe?nXY]@01?nXY]@;o`0000GoY:CE00?o0000oi6hlOnA^?402?nA^?4>o`0000GoOmcl1?l00002
ohoQo@?o00000onMhod3o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`00?oooool00ol0003oooooooooo`1:ooooo`;o00002Oo=[k`00ol0003o`ZNnol:W_P05ol:W
_PCo00003Oo1Y[h00ol0003o]Z?5okJSa@08okJSa@Go00002?ndXLD00ol0003oZ:KDojRVe00?ojRV
e13o00003?nJ^nl00ol0003oOmclogoLo004o`0000?oSn7m0ol00003oigSo@?o0000B_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0010ooooo`;o0000C?ooool3o`0000Ko
cJnl00?o0000ol:W__o2Ykh02Oo2Ykh3o`0000[o`JJn00?o0000okJSaOnfXlD03OnfXlD6o`0000;o
]:7500?o0000ojRVe?nXY]@05?nXY]@00ol0003oV[__oiZkk`0?oiZkk`So00001?n?hOd3o`0000Co
WN?m0_l0001=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool004;ooooo
00?o0000ooooooooool0C?ooool2o`0000CocJnl00?o0000ol:W__o2Ykh03?o2Ykh4o`0000Ko`JJn
00?o0000okJSaOnfXlD04onfXlD?o`0000_oZ:KD00?o0000oiZkkonJ^nl00onJ^nl;o`0000KoXKk]
00?o0000ohoQoOn?hOd00ol00004oigSo@?o0000D?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo04gooooo1?l0000Col:W_PCo000000?o
`JJno`000?nfXlD05onfXlD00ol0003o[:SCojbXd`0:ojbXda7o00003onQ_^d5o`0000CoWN?m0ol0
001Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000
ooooooooool0Coooool00ol0003o`ZNnol:W_P0Eol:W_P;o00006?nfXlD00ol0003o[:SCojbXd`0E
ojbXd`03o`000?nQ_^goXKk]00coXKk]1_l00004ojO0j`03o`000?nMhogo000000;o0000F?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000D_ooool5o`00
017o`ZNn00?o0000okRUaOnhYLD00_nhYLD9o`0000_o]Z?500?o0000ojbXdon/Z=<05On/Z=<00ol0
003oXKk]oj6nk@07oj6nk@Go00002OnW`>/3o`0005_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`1Dooooo`Go00003?o2Ykh00ol0003o
^:G5okRUa@0;okRUa@So00000onfXlD00ol0003o[:SCojbXd`0FojbXd`03o`000?nQ_^goXKk]00Ko
00002OnW`>/5o`0005oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00
B?ooool00ol0003oooooooooo`1Hooooo`Go00001_o2Ykh00ol0003o^:G5okRUa@0DokRUaAoo0000
2_nW`>/5o`0006Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00BOoo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00;ooooo1Ol000000oo2Ykko0000okRU
a@0HokRUa@03o`000?n_Zm?o[j_C01Ko[j_C00?o0000ojO0jonW`>/01OnW`>/5o`0006_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00B_ooool2o`0005Oooooo00?o0000
ooooooooool01oooool2o`0001Wo^:G500?o0000ojn[don_Zm<05on_Zm<00ol0003oYl3[o`000004
o`00073ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00gooooo2Ol0000<okRUa@03o`000?n_Zm?o[j_C
017o[j_C2?l0001fooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001=ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool05_ooool9o`0000?o^:G500?o0000ojn[don_
Zm<01?n_Zm<=o`0007oooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004kooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Oooooo`[o0000S?ooool00ol0003ooooo
ooooo`07ooooo`7o00000Oooool1ooooo`00Coooool2o`0005;ooooo00?o0000ooooooooool0]_oo
ool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool00ol0003oooooooooo`1?
ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool0
05;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo001Cooooo`;o0000C_ooool00ol0003oooooooooo`2hooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool0^Oooool00ol0003oooooooooo`04ooooo`7o00000Oooool005Kooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00?ooooo0Ol0
0001ooooo`00Eoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooooooool00_ooool1o`00007ooooo001Hooooo`;o0000BOooool00ol0003oooooooooo`2koooo
o`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00Foooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo00000Oooool005co
oooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooo0000007o
oooo001Mooooo`;o0000A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo007o0000
001Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0_oooool1o`00007ooooo0Ol0
0000063ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`30ooooo`;o0000001Qoooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool0_oooool3o`000000H_ooool2o`0003oo
oooo00?o0000ooooooooool0^oooool4o`0000?ooooo001Tooooo`03o`000?oooooooooo03cooooo
00?o0000ooooooooool0]oooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0/oooool4o`0000_ooooo001Vooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0/?ooool3o`0000oooooo001Wooooo`;o0000>_ooool00ol0003oooooooooo`2/oooo
o`Co00004_ooool006Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2Xooooo`Co
00005_ooool006[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Tooooo`Co0000
6_ooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`Co00007_oo
ool006cooooo0_l0000dooooo`03o`000?oooooooooo09gooooo1?l0000Rooooo`00K_ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo09Wooooo1?l0000Vooooo`00Koooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo09Gooooo1?l0000Zooooo`00L?ooool2o`00033ooooo
00?o0000ooooooooool0TOooool4o`0002kooooo001booooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0S_ooool3o`0003;ooooo001cooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0R_ooool4o`0003Gooooo001dooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0Q_ooool4o`0003Wooooo001eooooo`;o0000:oooool00ol0003oooooooooo`22ooooo`Co
0000?Oooool007Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1nooooo`Co0000
@Oooool007Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1jooooo`Co0000AOoo
ool007Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1fooooo`Co0000BOooool0
07[ooooo0_l0000Vooooo`03o`000?oooooooooo07;ooooo1?l0001=ooooo`00O?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo06oooooo0ol0001Aooooo`00OOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo06_ooooo1?l0001Dooooo`00O_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo06Oooooo1?l0001Hooooo`00Ooooool2o`00027ooooo00?o0000
ooooooooool0Hoooool4o`0005cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0Goooool4o`00063ooooo0022ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0Foooool4o`0006Cooooo0023ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
Eoooool4o`0006Sooooo0024ooooo`;o00007?ooool00ol0003oooooooooo`1Cooooo`Co0000K?oo
ool008Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000L?ooool0
08Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`?o0000M?ooool008So
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`18ooooo`Co0000Moooool008Wooooo
0_l0000Gooooo`03o`000?oooooooooo04Cooooo1?l0001kooooo`00Roooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo043ooooo1?l0001oooooo`00S?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03cooooo1?l00023ooooo`00SOooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo03Sooooo1?l00027ooooo`00S_ooool2o`0001;ooooo00?o0000oooooooo
ool0=?ooool4o`0008_ooooo002@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
<Oooool4o`0008oooooo002Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;_oo
ool3o`0009?ooooo002Booooo`;o00003Oooool00ol0003oooooooooo`0Zooooo`Co0000U_ooool0
09Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`Co0000V_ooool009Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000W_ooool009Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000X_ooool009Oooooo0_l0
0008ooooo`03o`000?oooooooooo01[ooooo1?l0002Vooooo`00VOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo1?l0002Zooooo`00V_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo1?l0002^ooooo`00Voooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo1?l0002booooo`00W?ooool2o`0000?ooooo00?o0000ooooooooool0
2oooool3o`000;Kooooo002Nooooo`04o`000?ooooooooooo`0000Wooooo1?l0002iooooo`00Wooo
ool00ol0003oooooo`000005ooooo`Co0000_Oooool00:3ooooo0_l000000ooooooo0000o`000002
o`000<7ooooo002Qooooo`;o0000aOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886655, -0.0135833, \
0.0036241, 0.0036241}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .64859 m .51694 .65827 L .43899 .65168 L p .701 .697 .843 r
F P
0 g
s
.51694 .65827 m .51725 .64859 L .59264 .64817 L p .64 .772 .943 r
F P
0 g
s
.59264 .64817 m .59527 .65394 L .51694 .65827 L p .64 .772 .943 r
F P
0 g
s
.59527 .65394 m .59264 .64817 L .6649 .6373 L p .485 .866 .978 r
F P
0 g
s
.6649 .6373 m .67023 .63881 L .59527 .65394 L p .485 .866 .978 r
F P
0 g
s
.43899 .65168 m .4424 .63865 L .51725 .64859 L p .701 .697 .843 r
F P
0 g
s
.51757 .63877 m .51725 .64859 L .4424 .63865 L p .688 .685 .841 r
F P
0 g
s
.51725 .64859 m .51757 .63877 L .58999 .64235 L p .615 .758 .947 r
F P
0 g
s
.58999 .64235 m .59264 .64817 L .51725 .64859 L p .615 .758 .947 r
F P
0 g
s
.4424 .63865 m .43899 .65168 L .36521 .63435 L p .746 .68 .786 r
F P
0 g
s
.36521 .63435 m .37175 .61875 L .4424 .63865 L p .746 .68 .786 r
F P
0 g
s
.44583 .62542 m .4424 .63865 L .37175 .61875 L p .739 .67 .783 r
F P
0 g
s
.4424 .63865 m .44583 .62542 L .51757 .63877 L p .688 .685 .841 r
F P
0 g
s
.51789 .62889 m .51757 .63877 L .44583 .62542 L p .674 .673 .841 r
F P
0 g
s
.51757 .63877 m .51789 .62889 L .58732 .63649 L p .586 .741 .95 r
F P
0 g
s
.58732 .63649 m .58999 .64235 L .51757 .63877 L p .586 .741 .95 r
F P
0 g
s
.59264 .64817 m .58999 .64235 L .65951 .63586 L p .416 .836 .965 r
F P
0 g
s
.65951 .63586 m .6649 .6373 L .59264 .64817 L p .416 .836 .965 r
F P
0 g
s
.37175 .61875 m .37831 .60292 L .44583 .62542 L p .739 .67 .783 r
F P
0 g
s
.44927 .61215 m .44583 .62542 L .37831 .60292 L p .73 .661 .782 r
F P
0 g
s
.44583 .62542 m .44927 .61215 L .51789 .62889 L p .674 .673 .841 r
F P
0 g
s
.51821 .61901 m .51789 .62889 L .44927 .61215 L p .656 .659 .841 r
F P
0 g
s
.51789 .62889 m .51821 .61901 L .58462 .63055 L p .552 .72 .952 r
F P
0 g
s
.58462 .63055 m .58732 .63649 L .51789 .62889 L p .552 .72 .952 r
F P
0 g
s
.37831 .60292 m .38487 .58708 L .44927 .61215 L p .73 .661 .782 r
F P
0 g
s
.45272 .59896 m .44927 .61215 L .38487 .58708 L p .719 .652 .782 r
F P
0 g
s
.44927 .61215 m .45272 .59896 L .51821 .61901 L p .656 .659 .841 r
F P
0 g
s
.58999 .64235 m .58732 .63649 L .65407 .6344 L p .343 .796 .948 r
F P
0 g
s
.65407 .6344 m .65951 .63586 L .58999 .64235 L p .343 .796 .948 r
F P
0 g
s
.67023 .63881 m .6649 .6373 L .73026 .6162 L p .252 .746 .665 r
F P
0 g
s
.73577 .61415 m .73066 .61608 L p .7284 .61691 L .252 .746 .665 r
F P
0 g
s
.73066 .61608 m .67104 .63851 L p .72497 .61819 L .252 .746 .665 r
F P
0 g
s
.7284 .61691 m .73066 .61608 L .72497 .61819 L .252 .746 .665 r
F
.72244 .61929 m .73026 .6162 L .73014 .61624 L p 0 0 0 r
F P
0 g
s
.73026 .6162 m .67104 .63851 L .67161 .63829 L .252 .746 .665 r
F
.73014 .61624 m .6649 .6373 L p .72244 .61929 L 0 0 0 r
F P
0 g
s
.6649 .6373 m .65951 .63586 L .71573 .62106 L p 0 0 0 r
F P
0 g
s
.71573 .62106 m .7196 .62004 L p .71718 .6208 L 0 0 0 r
F P
0 g
s
.71718 .6208 m .6649 .6373 L .71573 .62106 L 0 0 0 r
F
.72033 .61988 m .71765 .62072 L .7196 .62004 L F
.71765 .62072 m .6649 .6373 L .71718 .6208 L F
.71765 .62072 m .71718 .6208 L .7196 .62004 L F
.7196 .62004 m .72095 .61968 L p .72033 .61988 L F P
0 g
s
.7198 .62012 m .71375 .62201 L .72095 .61968 L 0 0 0 r
F
.71375 .62201 m .6649 .6373 L .7134 .62206 L F
.71375 .62201 m .7134 .62206 L .72095 .61968 L F
.72095 .61968 m .71052 .62243 L p .71203 .62302 L F P
0 g
s
.71052 .62243 m .65951 .63586 L p .70804 .62399 L 0 0 0 r
F P
0 g
s
.71203 .62302 m .71052 .62243 L .70804 .62399 L 0 0 0 r
F
.65951 .63586 m .65407 .6344 L .70463 .62437 L p F P
0 g
s
.71454 .6224 m .72095 .61968 L .71203 .62302 L 0 0 0 r
F
.70463 .62437 m .71454 .6224 L p .70804 .62399 L F P
0 g
s
.70804 .62399 m .65951 .63586 L .70463 .62437 L 0 0 0 r
F
.70502 .62563 m .70751 .6247 L .70353 .62542 L .01 0 0 r
F
.70294 .62599 m .70353 .62542 L .65413 .63439 L F
.70502 .62563 m .70353 .62542 L .70294 .62599 L F
.70935 .62343 m .65413 .63439 L p .70751 .6247 L F P
0 g
s
.70502 .62563 m .65413 .63439 L .6541 .6344 L .01 0 0 r
F
.65413 .63439 m .65407 .6344 L p .6541 .6344 L F P
0 g
s
.65407 .6344 m .64857 .63283 L .69383 .627 L p .01 0 0 r
F P
0 g
s
.69581 .62693 m .65407 .6344 L .69383 .627 L .01 0 0 r
F
.70294 .62599 m .69182 .6279 L .69931 .6263 L F
.69182 .6279 m .65407 .6344 L .69047 .62788 L F
.69182 .6279 m .69047 .62788 L .69931 .6263 L F
.70654 .62537 m .71267 .62277 L .70502 .62563 L F
.69931 .6263 m .70654 .62537 L p .70294 .62599 L F P
0 g
s
.70529 .62553 m .69931 .6263 L p .70008 .62747 L .073 0 0 r
F P
0 g
s
.69383 .627 m .69931 .6263 L p .69581 .62693 L .01 0 0 r
F P
0 g
s
.69931 .6263 m .64938 .63273 L p .69863 .62762 L .073 0 0 r
F P
0 g
s
.70008 .62747 m .69931 .6263 L .69863 .62762 L .073 0 0 r
F
.70008 .62747 m .64938 .63273 L .6491 .63277 L F
.69843 .628 m .70008 .62747 L p .6491 .63277 L F P
0 g
s
.69843 .628 m .6491 .63277 L .64906 .63278 L .073 0 0 r
F
.64938 .63273 m .64857 .63283 L p .6491 .63277 L F P
0 g
s
.64906 .63278 m .6491 .63277 L .64857 .63283 L .073 0 0 r
F
.64857 .63283 m .643 .63104 L .67628 .62922 L p F P
0 g
s
.67628 .62922 m .69843 .628 L p .681 .62969 L .073 0 0 r
F P
0 g
s
.681 .62969 m .64857 .63283 L .67628 .62922 L .073 0 0 r
F
.69021 .63013 m .64533 .63092 L .64436 .63101 L .126 0 0 r
F
.69021 .63013 m .69843 .628 L .64583 .63088 L p F P
0 g
s
.69021 .63013 m .64583 .63088 L .6455 .63092 L .126 0 0 r
F
.64533 .63092 m .64501 .63093 L .64451 .63099 L F
.64533 .63092 m .64451 .63099 L .64436 .63101 L F
.64583 .63088 m .64501 .63093 L p .6455 .63092 L F P
0 g
s
.64501 .63093 m .643 .63104 L p .64436 .63101 L .126 0 0 r
F P
0 g
s
.643 .63104 m .63737 .62893 L .66545 .62957 L p .126 0 0 r
F P
0 g
s
.66545 .62957 m .69021 .63013 L p .67021 .63052 L .126 0 0 r
F P
0 g
s
.67021 .63052 m .643 .63104 L .66545 .62957 L .126 0 0 r
F
.67288 .62974 m .64199 .62903 L p .67529 .63116 L .17 0 0 r
F P
0 g
s
.68186 .63158 m .67288 .62974 L .67529 .63116 L .17 0 0 r
F
.68186 .63158 m .64199 .62903 L .64027 .6291 L F
.64199 .62903 m .63737 .62893 L p .64027 .6291 L F P
0 g
s
.63737 .62893 m .63166 .62641 L .65482 .62879 L p .17 0 0 r
F P
0 g
s
.65482 .62879 m .68186 .63158 L p .65942 .63024 L .17 0 0 r
F P
0 g
s
.65942 .63024 m .63737 .62893 L .65482 .62879 L .17 0 0 r
F
.67338 .63219 m .68186 .63158 L .65482 .62879 L p .207 0 0 r
F P
0 g
s
.65482 .62879 m .63854 .62712 L p .65726 .62984 L .207 0 0 r
F P
0 g
s
.67338 .63219 m .65482 .62879 L .65726 .62984 L .207 0 0 r
F
.67338 .63219 m .63854 .62712 L .63657 .62709 L F
.63854 .62712 m .63166 .62641 L p .63657 .62709 L F P
0 g
s
.63166 .62641 m .62589 .62338 L .64435 .6268 L p .207 0 0 r
F P
0 g
s
.64435 .6268 m .67338 .63219 L p .64859 .62875 L .207 0 0 r
F P
0 g
s
.64859 .62875 m .63166 .62641 L .64435 .6268 L .207 0 0 r
F
.65246 .62831 m .63485 .62504 L p .6561 .62983 L .236 0 0 r
F P
0 g
s
.66478 .63179 m .65246 .62831 L .6561 .62983 L .236 0 0 r
F
.66478 .63179 m .63485 .62504 L .63246 .6248 L F
.63485 .62504 m .62589 .62338 L p .63246 .6248 L F P
0 g
s
.62589 .62338 m .62004 .61977 L .66478 .63179 L p .236 0 0 r
F P
0 g
s
.65605 .63027 m .66478 .63179 L .63092 .62269 L p .256 0 0 r
F P
0 g
s
.63092 .62269 m .62004 .61977 L p .62823 .62216 L .256 0 0 r
F P
0 g
s
.65605 .63027 m .63092 .62269 L .62823 .62216 L .256 0 0 r
F
.62004 .61977 m .61412 .6155 L .65605 .63027 L p F P
0 g
s
.6472 .62751 m .65605 .63027 L .62676 .61995 L p .266 0 0 r
F P
0 g
s
.63823 .62343 m .6472 .62751 L .62239 .61672 L p 0 .31 .667 r
F P
0 g
s
.62239 .61672 m .60813 .61051 L p .61953 .6154 L 0 .31 .667 r
F P
0 g
s
.63823 .62343 m .62239 .61672 L .61953 .6154 L 0 .31 .667 r
F
.66478 .63179 m .67338 .63219 L .65246 .62831 L p .236 0 0 r
F P
0 g
s
.62676 .61995 m .61412 .6155 L p .62391 .61905 L .266 0 0 r
F P
0 g
s
.6472 .62751 m .62676 .61995 L .62391 .61905 L .266 0 0 r
F
.68186 .63158 m .69021 .63013 L .67288 .62974 L p .17 0 0 r
F P
0 g
s
.71267 .62277 m .70935 .62343 L p .70751 .6247 L .01 0 0 r
F P
0 g
s
.70008 .62747 m .70654 .62537 L .70529 .62553 L p .073 0 0 r
F P
0 g
s
.70654 .62537 m .71454 .6224 L .71267 .62277 L p .01 0 0 r
F P
0 g
s
.73799 .61332 m .73577 .61415 L p .7302 .61622 L .252 .746 .665 r
F P
0 g
s
.7302 .61622 m .73577 .61415 L .7284 .61691 L .252 .746 .665 r
F
.73026 .6162 m .73058 .61608 L p .7302 .61622 L F P
0 g
s
.73058 .61608 m .73799 .61332 L p .7302 .61622 L .252 .746 .665 r
F P
0 g
s
.72095 .61968 m .72244 .61929 L p .7198 .62012 L 0 0 0 r
F P
0 g
s
.71454 .6224 m .72244 .61929 L .72095 .61968 L p 0 0 0 r
F P
0 g
s
.67104 .63851 m .67023 .63881 L p .67161 .63829 L .252 .746 .665 r
F P
0 g
s
.38487 .58708 m .39144 .57143 L .45272 .59896 L p .719 .652 .782 r
F P
0 g
s
.45619 .586 m .45272 .59896 L .39144 .57143 L p .707 .643 .783 r
F P
0 g
s
.45272 .59896 m .45619 .586 L .51853 .60919 L p .636 .645 .842 r
F P
0 g
s
.51853 .60919 m .51821 .61901 L .45272 .59896 L p .636 .645 .842 r
F P
0 g
s
.51821 .61901 m .51853 .60919 L .58189 .62453 L p .514 .695 .951 r
F P
0 g
s
.58189 .62453 m .58462 .63055 L .51821 .61901 L p .514 .695 .951 r
F P
0 g
s
.39144 .57143 m .398 .55618 L .45619 .586 L p .707 .643 .783 r
F P
0 g
s
.45966 .57341 m .45619 .586 L .398 .55618 L p .691 .633 .785 r
F P
0 g
s
.45619 .586 m .45966 .57341 L .51885 .5995 L p .613 .63 .844 r
F P
0 g
s
.51885 .5995 m .51853 .60919 L .45619 .586 L p .613 .63 .844 r
F P
0 g
s
.37175 .61875 m .36521 .63435 L .29943 .6068 L p .79 .696 .76 r
F P
0 g
s
.58732 .63649 m .58462 .63055 L .64857 .63283 L p .27 .75 .93 r
F P
0 g
s
.64857 .63283 m .65407 .6344 L .58732 .63649 L p .27 .75 .93 r
F P
0 g
s
.29943 .6068 m .30897 .5896 L .37175 .61875 L p .79 .696 .76 r
F P
0 g
s
.37831 .60292 m .37175 .61875 L .30897 .5896 L p .786 .689 .757 r
F P
0 g
s
.30897 .5896 m .31851 .57218 L .37831 .60292 L p .786 .689 .757 r
F P
0 g
s
.38487 .58708 m .37831 .60292 L .31851 .57218 L p .78 .682 .755 r
F P
0 g
s
.51853 .60919 m .51885 .5995 L .57914 .61841 L p .473 .666 .947 r
F P
0 g
s
.57914 .61841 m .58189 .62453 L .51853 .60919 L p .473 .666 .947 r
F P
0 g
s
.31851 .57218 m .32804 .5548 L .38487 .58708 L p .78 .682 .755 r
F P
0 g
s
.39144 .57143 m .38487 .58708 L .32804 .5548 L p .773 .675 .755 r
F P
0 g
s
.398 .55618 m .40456 .54151 L .45966 .57341 L p .691 .633 .785 r
F P
0 g
s
.46313 .5613 m .45966 .57341 L .40456 .54151 L p .673 .622 .789 r
F P
0 g
s
.45966 .57341 m .46313 .5613 L .51918 .59 L p .586 .613 .846 r
F P
0 g
s
.51918 .59 m .51885 .5995 L .45966 .57341 L p .586 .613 .846 r
F P
0 g
s
.32804 .5548 m .33755 .5377 L .39144 .57143 L p .773 .675 .755 r
F P
0 g
s
.398 .55618 m .39144 .57143 L .33755 .5377 L p .764 .668 .757 r
F P
0 g
s
.33755 .5377 m .34701 .52116 L .398 .55618 L p .764 .668 .757 r
F P
0 g
s
.40456 .54151 m .398 .55618 L .34701 .52116 L p .753 .661 .76 r
F P
0 g
s
.40456 .54151 m .4111 .52761 L .46313 .5613 L p .673 .622 .789 r
F P
0 g
s
.46662 .54979 m .46313 .5613 L .4111 .52761 L p .652 .61 .794 r
F P
0 g
s
.46313 .5613 m .46662 .54979 L .51951 .58074 L p .556 .594 .847 r
F P
0 g
s
.51951 .58074 m .51918 .59 L .46313 .5613 L p .556 .594 .847 r
F P
0 g
s
.58462 .63055 m .58189 .62453 L .643 .63104 L p .2 .699 .913 r
F P
0 g
s
.643 .63104 m .64857 .63283 L .58462 .63055 L p .2 .699 .913 r
F P
0 g
s
.34701 .52116 m .35642 .5054 L .40456 .54151 L p .753 .661 .76 r
F P
0 g
s
.4111 .52761 m .40456 .54151 L .35642 .5054 L p .739 .653 .765 r
F P
0 g
s
.51885 .5995 m .51918 .59 L .57637 .61216 L p .428 .634 .941 r
F P
0 g
s
.57637 .61216 m .57914 .61841 L .51885 .5995 L p .428 .634 .941 r
F P
0 g
s
.35642 .5054 m .36578 .49064 L .4111 .52761 L p .739 .653 .765 r
F P
0 g
s
.41762 .51464 m .4111 .52761 L .36578 .49064 L p .722 .645 .772 r
F P
0 g
s
.4111 .52761 m .41762 .51464 L .46662 .54979 L p .652 .61 .794 r
F P
0 g
s
.47011 .53899 m .46662 .54979 L .41762 .51464 L p .626 .596 .8 r
F P
0 g
s
.46662 .54979 m .47011 .53899 L .51984 .57176 L p .521 .573 .849 r
F P
0 g
s
.51984 .57176 m .51951 .58074 L .46662 .54979 L p .521 .573 .849 r
F P
0 g
s
.36578 .49064 m .37508 .4771 L .41762 .51464 L p .722 .645 .772 r
F P
0 g
s
.42414 .50275 m .41762 .51464 L .37508 .4771 L p .701 .634 .779 r
F P
0 g
s
.41762 .51464 m .42414 .50275 L .47011 .53899 L p .626 .596 .8 r
F P
0 g
s
.51918 .59 m .51951 .58074 L .57357 .60578 L p .38 .598 .932 r
F P
0 g
s
.57357 .60578 m .57637 .61216 L .51918 .59 L p .38 .598 .932 r
F P
0 g
s
.58189 .62453 m .57914 .61841 L .63737 .62893 L p .135 .647 .896 r
F P
0 g
s
.63737 .62893 m .643 .63104 L .58189 .62453 L p .135 .647 .896 r
F P
0 g
s
.37508 .4771 m .38433 .46494 L .42414 .50275 L p .701 .634 .779 r
F P
0 g
s
.43064 .49207 m .42414 .50275 L .38433 .46494 L p .675 .622 .788 r
F P
0 g
s
.42414 .50275 m .43064 .49207 L .4736 .52899 L p .596 .581 .806 r
F P
0 g
s
.4736 .52899 m .47011 .53899 L .42414 .50275 L p .596 .581 .806 r
F P
0 g
s
.47011 .53899 m .4736 .52899 L .52017 .56312 L p .481 .549 .849 r
F P
0 g
s
.52017 .56312 m .51984 .57176 L .47011 .53899 L p .481 .549 .849 r
F P
0 g
s
.51951 .58074 m .51984 .57176 L .57074 .59925 L p .331 .56 .92 r
F P
0 g
s
.57074 .59925 m .57357 .60578 L .51951 .58074 L p .331 .56 .92 r
F P
0 g
s
.38433 .46494 m .39354 .45433 L .43064 .49207 L p .675 .622 .788 r
F P
0 g
s
.43714 .48271 m .43064 .49207 L .39354 .45433 L p .644 .607 .798 r
F P
0 g
s
.43064 .49207 m .43714 .48271 L .47711 .51986 L p .56 .562 .812 r
F P
0 g
s
.47711 .51986 m .4736 .52899 L .43064 .49207 L p .56 .562 .812 r
F P
0 g
s
.79464 .57831 m .79163 .58017 L p .78481 .58555 L 0 0 0 r
F P
0 g
s
.79163 .58017 m .7394 .61245 L p .78252 .58691 L 0 0 0 r
F P
0 g
s
.78481 .58555 m .79163 .58017 L .78252 .58691 L 0 0 0 r
F
.78529 .58521 m .79464 .57831 L p .78481 .58555 L F P
0 g
s
.7394 .61245 m .73799 .61332 L p .74018 .61202 L 0 0 0 r
F P
0 g
s
.78487 .58552 m .7394 .61245 L .74018 .61202 L 0 0 0 r
F
.73799 .61332 m .73026 .6162 L .78487 .58552 L p F P
0 g
s
.73298 .61467 m .73026 .6162 L p .7345 .61401 L 0 0 0 r
F P
0 g
s
.77501 .59303 m .73298 .61467 L .7345 .61401 L 0 0 0 r
F
.77501 .59303 m .78487 .58552 L .73298 .61467 L p F P
0 g
s
.73026 .6162 m .72244 .61929 L .77115 .59496 L p 0 0 0 r
F P
0 g
s
.77115 .59496 m .77298 .59405 L p .77219 .59446 L 0 0 0 r
F P
0 g
s
.77219 .59446 m .73026 .6162 L .77115 .59496 L 0 0 0 r
F
.77175 .59472 m .73026 .6162 L .77298 .59405 L F
.76191 .602 m .76923 .59674 L .72244 .61929 L F
.77298 .59405 m .77115 .59496 L p .76923 .59674 L F P
0 g
s
.77115 .59496 m .72244 .61929 L p .76923 .59674 L 0 0 0 r
F P
0 g
s
.76503 .60063 m .77298 .59405 L .76191 .602 L 0 0 0 r
F
.72244 .61929 m .71454 .6224 L .76503 .60063 L p F P
0 g
s
.7625 .60173 m .71464 .62236 L p .75302 .60874 L 0 0 0 r
F P
0 g
s
.71464 .62236 m .71454 .6224 L p .71459 .62239 L 0 0 0 r
F P
0 g
s
.75302 .60874 m .71464 .62236 L .71459 .62239 L 0 0 0 r
F
.75492 .60806 m .76503 .60063 L .7625 .60173 L p F P
0 g
s
.75492 .60806 m .7625 .60173 L .75302 .60874 L 0 0 0 r
F
.77298 .59405 m .77501 .59303 L p .77175 .59472 L F P
0 g
s
.76503 .60063 m .77501 .59303 L .77298 .59405 L p 0 0 0 r
F P
0 g
s
.78487 .58552 m .78529 .58521 L p .78481 .58555 L 0 0 0 r
F P
0 g
s
.3061 .48264 m .31796 .46687 L .35642 .5054 L p .808 .709 .756 r
F P
0 g
s
.35642 .5054 m .34701 .52116 L .3061 .48264 L p .808 .709 .756 r
F P
0 g
s
.36578 .49064 m .35642 .5054 L .31796 .46687 L p .796 .703 .762 r
F P
0 g
s
.31796 .46687 m .32972 .45229 L .36578 .49064 L p .796 .703 .762 r
F P
0 g
s
.37508 .4771 m .36578 .49064 L .32972 .45229 L p .781 .696 .77 r
F P
0 g
s
.29414 .49935 m .3061 .48264 L .34701 .52116 L p .817 .715 .752 r
F P
0 g
s
.34701 .52116 m .33755 .5377 L .29414 .49935 L p .817 .715 .752 r
F P
0 g
s
.4736 .52899 m .47711 .51986 L .5205 .55485 L p .437 .523 .848 r
F P
0 g
s
.5205 .55485 m .52017 .56312 L .4736 .52899 L p .437 .523 .848 r
F P
0 g
s
.57914 .61841 m .57637 .61216 L .63166 .62641 L p .077 .594 .881 r
F P
0 g
s
.63166 .62641 m .63737 .62893 L .57914 .61841 L p .077 .594 .881 r
F P
0 g
s
.32972 .45229 m .34136 .43912 L .37508 .4771 L p .781 .696 .77 r
F P
0 g
s
.38433 .46494 m .37508 .4771 L .34136 .43912 L p .762 .688 .78 r
F P
0 g
s
.28209 .51672 m .29414 .49935 L .33755 .5377 L p .824 .72 .749 r
F P
0 g
s
.33755 .5377 m .32804 .5548 L .28209 .51672 L p .824 .72 .749 r
F P
0 g
s
.26997 .53448 m .28209 .51672 L .32804 .5548 L p .83 .724 .749 r
F P
0 g
s
.32804 .5548 m .31851 .57218 L .26997 .53448 L p .83 .724 .749 r
F P
0 g
s
.34136 .43912 m .3529 .42755 L .38433 .46494 L p .762 .688 .78 r
F P
0 g
s
.39354 .45433 m .38433 .46494 L .3529 .42755 L p .738 .677 .792 r
F P
0 g
s
.39354 .45433 m .4027 .44538 L .43714 .48271 L p .644 .607 .798 r
F P
0 g
s
.44364 .47473 m .43714 .48271 L .4027 .44538 L p .605 .589 .808 r
F P
0 g
s
.43714 .48271 m .44364 .47473 L .48063 .51166 L p .518 .54 .818 r
F P
0 g
s
.48063 .51166 m .47711 .51986 L .43714 .48271 L p .518 .54 .818 r
F P
0 g
s
.25779 .55232 m .26997 .53448 L .31851 .57218 L p .833 .729 .75 r
F P
0 g
s
.31851 .57218 m .30897 .5896 L .25779 .55232 L p .833 .729 .75 r
F P
0 g
s
.24558 .56996 m .25779 .55232 L .30897 .5896 L p .835 .734 .753 r
F P
0 g
s
.30897 .5896 m .29943 .6068 L .24558 .56996 L p .835 .734 .753 r
F P
0 g
s
.51984 .57176 m .52017 .56312 L .56789 .59256 L p .281 .519 .904 r
F P
0 g
s
.56789 .59256 m .57074 .59925 L .51984 .57176 L p .281 .519 .904 r
F P
0 g
s
.3529 .42755 m .36435 .41776 L .39354 .45433 L p .738 .677 .792 r
F P
0 g
s
.4027 .44538 m .39354 .45433 L .36435 .41776 L p .707 .663 .804 r
F P
0 g
s
.47711 .51986 m .48063 .51166 L .52084 .54697 L p .389 .493 .845 r
F P
0 g
s
.52084 .54697 m .5205 .55485 L .47711 .51986 L p .389 .493 .845 r
F P
0 g
s
.36435 .41776 m .37571 .40988 L .4027 .44538 L p .707 .663 .804 r
F P
0 g
s
.41184 .43819 m .4027 .44538 L .37571 .40988 L p .669 .645 .818 r
F P
0 g
s
.4027 .44538 m .41184 .43819 L .44364 .47473 L p .605 .589 .808 r
F P
0 g
s
.57637 .61216 m .57357 .60578 L .62589 .62338 L p .026 .541 .867 r
F P
0 g
s
.62589 .62338 m .63166 .62641 L .57637 .61216 L p .026 .541 .867 r
F P
0 g
s
.45015 .4682 m .44364 .47473 L .41184 .43819 L p .559 .566 .817 r
F P
0 g
s
.44364 .47473 m .45015 .4682 L .48416 .50443 L p .469 .514 .822 r
F P
0 g
s
.48416 .50443 m .48063 .51166 L .44364 .47473 L p .469 .514 .822 r
F P
0 g
s
.52017 .56312 m .5205 .55485 L .56501 .5857 L p .231 .478 .887 r
F P
0 g
s
.56501 .5857 m .56789 .59256 L .52017 .56312 L p .231 .478 .887 r
F P
0 g
s
.37571 .40988 m .387 .40401 L .41184 .43819 L p .669 .645 .818 r
F P
0 g
s
.42096 .43282 m .41184 .43819 L .387 .40401 L p .621 .622 .83 r
F P
0 g
s
.41184 .43819 m .42096 .43282 L .45015 .4682 L p .559 .566 .817 r
F P
0 g
s
.48063 .51166 m .48416 .50443 L .52118 .53951 L p .336 .461 .839 r
F P
0 g
s
.52118 .53951 m .52084 .54697 L .48063 .51166 L p .336 .461 .839 r
F P
0 g
s
.45667 .46314 m .45015 .4682 L .42096 .43282 L p .503 .537 .824 r
F P
0 g
s
.45015 .4682 m .45667 .46314 L .48771 .49818 L p .412 .483 .823 r
F P
0 g
s
.48771 .49818 m .48416 .50443 L .45015 .4682 L p .412 .483 .823 r
F P
0 g
s
.57357 .60578 m .57074 .59925 L .62004 .61977 L p 0 .491 .853 r
F P
0 g
s
.62004 .61977 m .62589 .62338 L .57357 .60578 L p 0 .491 .853 r
F P
0 g
s
.387 .40401 m .39823 .40023 L .42096 .43282 L p .621 .622 .83 r
F P
0 g
s
.43009 .42931 m .42096 .43282 L .39823 .40023 L p .562 .591 .841 r
F P
0 g
s
.42096 .43282 m .43009 .42931 L .45667 .46314 L p .503 .537 .824 r
F P
0 g
s
.5205 .55485 m .52084 .54697 L .5621 .57866 L p .183 .437 .867 r
F P
0 g
s
.5621 .57866 m .56501 .5857 L .5205 .55485 L p .183 .437 .867 r
F P
0 g
s
.31862 .40277 m .33182 .39265 L .3529 .42755 L p .815 .761 .802 r
F P
0 g
s
.3529 .42755 m .34136 .43912 L .31862 .40277 L p .815 .761 .802 r
F P
0 g
s
.36435 .41776 m .3529 .42755 L .33182 .39265 L p .789 .75 .817 r
F P
0 g
s
.33182 .39265 m .34488 .38442 L .36435 .41776 L p .789 .75 .817 r
F P
0 g
s
.37571 .40988 m .36435 .41776 L .34488 .38442 L p .756 .735 .834 r
F P
0 g
s
.30525 .41461 m .31862 .40277 L .34136 .43912 L p .835 .769 .789 r
F P
0 g
s
.34136 .43912 m .32972 .45229 L .30525 .41461 L p .835 .769 .789 r
F P
0 g
s
.48416 .50443 m .48771 .49818 L .52152 .53246 L p .279 .425 .83 r
F P
0 g
s
.52152 .53246 m .52118 .53951 L .48416 .50443 L p .279 .425 .83 r
F P
0 g
s
.34488 .38442 m .35781 .37822 L .37571 .40988 L p .756 .735 .834 r
F P
0 g
s
.387 .40401 m .37571 .40988 L .35781 .37822 L p .713 .715 .85 r
F P
0 g
s
.29173 .42797 m .30525 .41461 L .32972 .45229 L p .849 .774 .778 r
F P
0 g
s
.32972 .45229 m .31796 .46687 L .29173 .42797 L p .849 .774 .778 r
F P
0 g
s
.46322 .45956 m .45667 .46314 L .43009 .42931 L p .437 .502 .828 r
F P
0 g
s
.45667 .46314 m .46322 .45956 L .49129 .49292 L p .349 .448 .821 r
F P
0 g
s
.49129 .49292 m .48771 .49818 L .45667 .46314 L p .349 .448 .821 r
F P
0 g
s
.57074 .59925 m .56789 .59256 L .61412 .6155 L p 0 .443 .84 r
F P
0 g
s
.61412 .6155 m .62004 .61977 L .57074 .59925 L p 0 .443 .84 r
F P
0 g
s
.27804 .44261 m .29173 .42797 L .31796 .46687 L p .861 .779 .769 r
F P
0 g
s
.31796 .46687 m .3061 .48264 L .27804 .44261 L p .861 .779 .769 r
F P
0 g
s
.39823 .40023 m .40944 .39856 L .43009 .42931 L p .562 .591 .841 r
F P
0 g
s
.43922 .42766 m .43009 .42931 L .40944 .39856 L p .491 .553 .847 r
F P
0 g
s
.43009 .42931 m .43922 .42766 L .46322 .45956 L p .437 .502 .828 r
F P
0 g
s
.35781 .37822 m .37062 .37416 L .387 .40401 L p .713 .715 .85 r
F P
0 g
s
.39823 .40023 m .387 .40401 L .37062 .37416 L p .659 .687 .865 r
F P
0 g
s
.52084 .54697 m .52118 .53951 L .55917 .57143 L p .137 .396 .847 r
F P
0 g
s
.55917 .57143 m .5621 .57866 L .52084 .54697 L p .137 .396 .847 r
F P
0 g
s
.26419 .45828 m .27804 .44261 L .3061 .48264 L p .869 .782 .763 r
F P
0 g
s
.3061 .48264 m .29414 .49935 L .26419 .45828 L p .869 .782 .763 r
F P
0 g
s
.37062 .37416 m .38334 .3723 L .39823 .40023 L p .659 .687 .865 r
F P
0 g
s
.40944 .39856 m .39823 .40023 L .38334 .3723 L p .591 .65 .877 r
F P
0 g
s
.71454 .6224 m .70654 .62537 L .75492 .60806 L p 0 0 0 r
F P
0 g
s
.48771 .49818 m .49129 .49292 L .52186 .52584 L p .221 .388 .818 r
F P
0 g
s
.52186 .52584 m .52152 .53246 L .48771 .49818 L p .221 .388 .818 r
F P
0 g
s
.2502 .47468 m .26419 .45828 L .29414 .49935 L p .874 .785 .759 r
F P
0 g
s
.29414 .49935 m .28209 .51672 L .2502 .47468 L p .874 .785 .759 r
F P
0 g
s
.46981 .45742 m .46322 .45956 L .43922 .42766 L p .361 .46 .826 r
F P
0 g
s
.46322 .45956 m .46981 .45742 L .49489 .48862 L p .279 .408 .814 r
F P
0 g
s
.49489 .48862 m .49129 .49292 L .46322 .45956 L p .279 .408 .814 r
F P
0 g
s
.56789 .59256 m .56501 .5857 L .60813 .61051 L p 0 .398 .826 r
F P
0 g
s
.60813 .61051 m .61412 .6155 L .56789 .59256 L p 0 .398 .826 r
F P
0 g
s
.40944 .39856 m .42065 .39901 L .43922 .42766 L p .491 .553 .847 r
F P
0 g
s
.4484 .42783 m .43922 .42766 L .42065 .39901 L p .408 .506 .846 r
F P
0 g
s
.43922 .42766 m .4484 .42783 L .46981 .45742 L p .361 .46 .826 r
F P
0 g
s
.38334 .3723 m .396 .37268 L .40944 .39856 L p .591 .65 .877 r
F P
0 g
s
.42065 .39901 m .40944 .39856 L .396 .37268 L p .509 .602 .881 r
F P
0 g
s
.23609 .49154 m .2502 .47468 L .28209 .51672 L p .877 .787 .757 r
F P
0 g
s
.28209 .51672 m .26997 .53448 L .23609 .49154 L p .877 .787 .757 r
F P
0 g
s
.52118 .53951 m .52152 .53246 L .55621 .56401 L p .093 .357 .825 r
F P
0 g
s
.55621 .56401 m .55917 .57143 L .52118 .53951 L p .093 .357 .825 r
F P
0 g
s
.79464 .57831 m .78487 .58552 L .82489 .54637 L p .535 .842 .529 r
F P
0 g
s
.82489 .54637 m .83625 .53514 L .79464 .57831 L p .535 .842 .529 r
F P
0 g
s
.49129 .49292 m .49489 .48862 L .52221 .51963 L p .162 .35 .803 r
F P
0 g
s
.52221 .51963 m .52186 .52584 L .49129 .49292 L p .162 .35 .803 r
F P
0 g
s
.22187 .50852 m .23609 .49154 L .26997 .53448 L p .879 .79 .758 r
F P
0 g
s
.26997 .53448 m .25779 .55232 L .22187 .50852 L p .879 .79 .758 r
F P
0 g
s
.70654 .62537 m .69843 .628 L .74466 .61508 L p 0 0 0 r
F P
0 g
s
.74466 .61508 m .75492 .60806 L .70654 .62537 L p 0 0 0 r
F P
0 g
s
.396 .37268 m .40862 .3753 L .42065 .39901 L p .509 .602 .881 r
F P
0 g
s
.43187 .40154 m .42065 .39901 L .40862 .3753 L p .416 .543 .877 r
F P
0 g
s
.42065 .39901 m .43187 .40154 L .4484 .42783 L p .408 .506 .846 r
F P
0 g
s
.56501 .5857 m .5621 .57866 L .60206 .60476 L p 0 .357 .811 r
F P
0 g
s
.60206 .60476 m .60813 .61051 L .56501 .5857 L p 0 .357 .811 r
F P
0 g
s
.45762 .42976 m .4484 .42783 L .43187 .40154 L p .317 .451 .838 r
F P
0 g
s
.4484 .42783 m .45762 .42976 L .47645 .45668 L p .279 .412 .818 r
F P
0 g
s
.47645 .45668 m .46981 .45742 L .4484 .42783 L p .279 .412 .818 r
F P
0 g
s
.46981 .45742 m .47645 .45668 L .49852 .48525 L p .206 .365 .803 r
F P
0 g
s
.49852 .48525 m .49489 .48862 L .46981 .45742 L p .206 .365 .803 r
F P
0 g
s
.20758 .52532 m .22187 .50852 L .25779 .55232 L p .878 .792 .761 r
F P
0 g
s
.25779 .55232 m .24558 .56996 L .20758 .52532 L p .878 .792 .761 r
F P
0 g
s
.52152 .53246 m .52186 .52584 L .55322 .5564 L p .053 .321 .804 r
F P
0 g
s
.55322 .5564 m .55621 .56401 L .52152 .53246 L p .053 .321 .804 r
F P
0 g
s
.33666 .35636 m .35037 .35237 L .35781 .37822 L p .779 .827 .89 r
F P
0 g
s
.35781 .37822 m .34488 .38442 L .33666 .35636 L p .779 .827 .89 r
F P
0 g
s
.37062 .37416 m .35781 .37822 L .35037 .35237 L p .724 .799 .911 r
F P
0 g
s
.32277 .36236 m .33666 .35636 L .34488 .38442 L p .82 .846 .868 r
F P
0 g
s
.34488 .38442 m .33182 .39265 L .32277 .36236 L p .82 .846 .868 r
F P
0 g
s
.35037 .35237 m .36395 .35049 L .37062 .37416 L p .724 .799 .911 r
F P
0 g
s
.38334 .3723 m .37062 .37416 L .36395 .35049 L p .655 .759 .926 r
F P
0 g
s
.30869 .37025 m .32277 .36236 L .33182 .39265 L p .851 .858 .847 r
F P
0 g
s
.33182 .39265 m .31862 .40277 L .30869 .37025 L p .851 .858 .847 r
F P
0 g
s
.36395 .35049 m .37739 .35079 L .38334 .3723 L p .655 .759 .926 r
F P
0 g
s
.396 .37268 m .38334 .3723 L .37739 .35079 L p .571 .706 .933 r
F P
0 g
s
.81343 .558 m .82489 .54637 L .78487 .58552 L p 0 0 0 r
F P
0 g
s
.78487 .58552 m .77501 .59303 L .80271 .56778 L p 0 0 0 r
F P
0 g
s
.80271 .56778 m .80888 .56216 L p .8057 .56525 L 0 0 0 r
F P
0 g
s
.8057 .56525 m .78487 .58552 L .80271 .56778 L 0 0 0 r
F
.81162 .55975 m .78487 .58552 L .80888 .56216 L F
.80888 .56216 m .81343 .558 L p .81162 .55975 L F P
0 g
s
.80185 .56975 m .81343 .558 L .77501 .59303 L p 0 0 0 r
F P
0 g
s
.77501 .59303 m .76503 .60063 L .79358 .57669 L p 0 0 0 r
F P
0 g
s
.79358 .57669 m .80185 .56975 L p .79825 .57288 L 0 0 0 r
F P
0 g
s
.79825 .57288 m .77501 .59303 L .79358 .57669 L 0 0 0 r
F
.79011 .58132 m .80185 .56975 L .79358 .57669 L p F P
0 g
s
.79358 .57669 m .76517 .60052 L p .79011 .58132 L 0 0 0 r
F P
0 g
s
.76517 .60052 m .76503 .60063 L p .76508 .60059 L 0 0 0 r
F P
0 g
s
.79011 .58132 m .76517 .60052 L .76508 .60059 L 0 0 0 r
F
.76503 .60063 m .75492 .60806 L .79011 .58132 L p F P
0 g
s
.7782 .59241 m .79011 .58132 L .75831 .60549 L p 0 0 0 r
F P
0 g
s
.75831 .60549 m .75681 .60663 L p .75737 .60626 L 0 0 0 r
F P
0 g
s
.7782 .59241 m .75831 .60549 L .75737 .60626 L 0 0 0 r
F
.75681 .60663 m .75492 .60806 L p .75586 .60743 L F P
0 g
s
.7782 .59241 m .75681 .60663 L .75586 .60743 L 0 0 0 r
F
.40862 .3753 m .42124 .3801 L .43187 .40154 L p .416 .543 .877 r
F P
0 g
s
.44313 .40607 m .43187 .40154 L .42124 .3801 L p .314 .477 .861 r
F P
0 g
s
.43187 .40154 m .44313 .40607 L .45762 .42976 L p .317 .451 .838 r
F P
0 g
s
.49489 .48862 m .49852 .48525 L .52256 .51381 L p .104 .311 .786 r
F P
0 g
s
.52256 .51381 m .52221 .51963 L .49489 .48862 L p .104 .311 .786 r
F P
0 g
s
.5621 .57866 m .55917 .57143 L .59594 .59821 L p 0 .321 .796 r
F P
0 g
s
.59594 .59821 m .60206 .60476 L .5621 .57866 L p 0 .321 .796 r
F P
0 g
s
.69843 .628 m .69021 .63013 L .73424 .62143 L p .03 0 0 r
F P
0 g
s
.73424 .62143 m .74466 .61508 L .69843 .628 L p .03 0 0 r
F P
0 g
s
.29441 .37985 m .30869 .37025 L .31862 .40277 L p .873 .865 .828 r
F P
0 g
s
.31862 .40277 m .30525 .41461 L .29441 .37985 L p .873 .865 .828 r
F P
0 g
s
.37739 .35079 m .39074 .35331 L .396 .37268 L p .571 .706 .933 r
F P
0 g
s
.40862 .3753 m .396 .37268 L .39074 .35331 L p .473 .639 .928 r
F P
0 g
s
.46692 .43336 m .45762 .42976 L .44313 .40607 L p .221 .39 .82 r
F P
0 g
s
.45762 .42976 m .46692 .43336 L .48314 .45725 L p .192 .36 .803 r
F P
0 g
s
.48314 .45725 m .47645 .45668 L .45762 .42976 L p .192 .36 .803 r
F P
0 g
s
.47645 .45668 m .48314 .45725 L .50218 .48275 L p .132 .32 .786 r
F P
0 g
s
.50218 .48275 m .49852 .48525 L .47645 .45668 L p .132 .32 .786 r
F P
0 g
s
.52186 .52584 m .52221 .51963 L .55021 .54861 L p .016 .287 .784 r
F P
0 g
s
.55021 .54861 m .55322 .5564 L .52186 .52584 L p .016 .287 .784 r
F P
0 g
s
.27993 .39096 m .29441 .37985 L .30525 .41461 L p .89 .869 .812 r
F P
0 g
s
.30525 .41461 m .29173 .42797 L .27993 .39096 L p .89 .869 .812 r
F P
0 g
s
.39074 .35331 m .40402 .35803 L .40862 .3753 L p .473 .639 .928 r
F P
0 g
s
.42124 .3801 m .40862 .3753 L .40402 .35803 L p .367 .562 .91 r
F P
0 g
s
.55917 .57143 m .55621 .56401 L .58974 .59085 L p 0 .289 .781 r
F P
0 g
s
.58974 .59085 m .59594 .59821 L .55917 .57143 L p 0 .289 .781 r
F P
0 g
s
.42124 .3801 m .43387 .38703 L .44313 .40607 L p .314 .477 .861 r
F P
0 g
s
.45446 .4125 m .44313 .40607 L .43387 .38703 L p .212 .406 .836 r
F P
0 g
s
.44313 .40607 m .45446 .4125 L .46692 .43336 L p .221 .39 .82 r
F P
0 g
s
.26525 .40336 m .27993 .39096 L .29173 .42797 L p .901 .871 .799 r
F P
0 g
s
.29173 .42797 m .27804 .44261 L .26525 .40336 L p .901 .871 .799 r
F P
0 g
s
.49852 .48525 m .50218 .48275 L .52291 .50835 L p .049 .274 .768 r
F P
0 g
s
.52291 .50835 m .52256 .51381 L .49852 .48525 L p .049 .274 .768 r
F P
0 g
s
.69021 .63013 m .68186 .63158 L .72364 .62686 L p .068 0 0 r
F P
0 g
s
.72364 .62686 m .73424 .62143 L .69021 .63013 L p .068 0 0 r
F P
0 g
s
.61412 .6155 m .60813 .61051 L .6472 .62751 L p .266 0 0 r
F P
0 g
s
.40402 .35803 m .41726 .3649 L .42124 .3801 L p .367 .562 .91 r
F P
0 g
s
.43387 .38703 m .42124 .3801 L .41726 .3649 L p .26 .48 .881 r
F P
0 g
s
.52221 .51963 m .52256 .51381 L .54716 .54062 L p 0 .257 .764 r
F P
0 g
s
.54716 .54062 m .55021 .54861 L .52221 .51963 L p 0 .257 .764 r
F P
0 g
s
.4763 .43849 m .46692 .43336 L .45446 .4125 L p .127 .329 .795 r
F P
0 g
s
.46692 .43336 m .4763 .43849 L .48991 .45902 L p .108 .307 .782 r
F P
0 g
s
.48991 .45902 m .48314 .45725 L .46692 .43336 L p .108 .307 .782 r
F P
0 g
s
.48314 .45725 m .48991 .45902 L .50589 .48104 L p .062 .276 .766 r
F P
0 g
s
.50589 .48104 m .50218 .48275 L .48314 .45725 L p .062 .276 .766 r
F P
0 g
s
.25036 .41679 m .26525 .40336 L .27804 .44261 L p .909 .872 .789 r
F P
0 g
s
.27804 .44261 m .26419 .45828 L .25036 .41679 L p .909 .872 .789 r
F P
0 g
s
.55621 .56401 m .55322 .5564 L .58349 .58267 L p 0 .26 .766 r
F P
0 g
s
.58349 .58267 m .58974 .59085 L .55621 .56401 L p 0 .26 .766 r
F P
0 g
s
.43387 .38703 m .44655 .39595 L .45446 .4125 L p .212 .406 .836 r
F P
0 g
s
.46588 .42069 m .45446 .4125 L .44655 .39595 L p .116 .337 .805 r
F P
0 g
s
.45446 .4125 m .46588 .42069 L .4763 .43849 L p .127 .329 .795 r
F P
0 g
s
.41726 .3649 m .43049 .37386 L .43387 .38703 L p .26 .48 .881 r
F P
0 g
s
.44655 .39595 m .43387 .38703 L .43049 .37386 L p .16 .399 .844 r
F P
0 g
s
.60813 .61051 m .60206 .60476 L .63823 .62343 L p 0 .31 .667 r
F P
0 g
s
.68186 .63158 m .67338 .63219 L .71287 .63116 L p .102 0 0 r
F P
0 g
s
.71287 .63116 m .72364 .62686 L .68186 .63158 L p .102 0 0 r
F P
0 g
s
.50218 .48275 m .50589 .48104 L .52327 .50321 L p 0 .24 .749 r
F P
0 g
s
.52327 .50321 m .52291 .50835 L .50218 .48275 L p 0 .24 .749 r
F P
0 g
s
.23528 .43098 m .25036 .41679 L .26419 .45828 L p .914 .872 .782 r
F P
0 g
s
.26419 .45828 m .2502 .47468 L .23528 .43098 L p .914 .872 .782 r
F P
0 g
s
.52256 .51381 m .52291 .50835 L .5441 .53247 L p 0 .23 .747 r
F P
0 g
s
.5441 .53247 m .54716 .54062 L .52256 .51381 L p 0 .23 .747 r
F P
0 g
s
.55322 .5564 m .55021 .54861 L .57718 .57371 L p 0 .236 .752 r
F P
0 g
s
.57718 .57371 m .58349 .58267 L .55322 .5564 L p 0 .236 .752 r
F P
0 g
s
.36781 .33471 m .3811 .33727 L .37739 .35079 L p .555 .804 .991 r
F P
0 g
s
.37739 .35079 m .36395 .35049 L .36781 .33471 L p .555 .804 .991 r
F P
0 g
s
.39074 .35331 m .37739 .35079 L .3811 .33727 L p .452 .722 .983 r
F P
0 g
s
.35437 .33416 m .36781 .33471 L .36395 .35049 L p .645 .868 .983 r
F P
0 g
s
.36395 .35049 m .35037 .35237 L .35437 .33416 L p .645 .868 .983 r
F P
0 g
s
.3811 .33727 m .39428 .34186 L .39074 .35331 L p .452 .722 .983 r
F P
0 g
s
.40402 .35803 m .39074 .35331 L .39428 .34186 L p .345 .63 .959 r
F P
0 g
s
.48579 .44499 m .4763 .43849 L .46588 .42069 L p .042 .271 .766 r
F P
0 g
s
.4763 .43849 m .48579 .44499 L .49676 .46187 L p .03 .257 .757 r
F P
0 g
s
.49676 .46187 m .48991 .45902 L .4763 .43849 L p .03 .257 .757 r
F P
0 g
s
.34076 .33555 m .35437 .33416 L .35037 .35237 L p .719 .914 .962 r
F P
0 g
s
.35037 .35237 m .33666 .35636 L .34076 .33555 L p .719 .914 .962 r
F P
0 g
s
.48991 .45902 m .49676 .46187 L .50963 .48003 L p 0 .235 .745 r
F P
0 g
s
.50963 .48003 m .50589 .48104 L .48991 .45902 L p 0 .235 .745 r
F P
0 g
s
.22002 .44563 m .23528 .43098 L .2502 .47468 L p .916 .871 .779 r
F P
0 g
s
.2502 .47468 m .23609 .49154 L .22002 .44563 L p .916 .871 .779 r
F P
0 g
s
.39428 .34186 m .40736 .34847 L .40402 .35803 L p .345 .63 .959 r
F P
0 g
s
.41726 .3649 m .40402 .35803 L .40736 .34847 L p .241 .534 .921 r
F P
0 g
s
.43049 .37386 m .44374 .38478 L .44655 .39595 L p .16 .399 .844 r
F P
0 g
s
.45931 .40672 m .44655 .39595 L .44374 .38478 L p .072 .326 .805 r
F P
0 g
s
.44655 .39595 m .45931 .40672 L .46588 .42069 L p .116 .337 .805 r
F P
0 g
s
.60206 .60476 m .59594 .59821 L .62915 .61796 L p 0 .288 .699 r
F P
0 g
s
.62915 .61796 m .63823 .62343 L .60206 .60476 L p 0 .288 .699 r
F P
0 g
s
.32696 .3388 m .34076 .33555 L .33666 .35636 L p .775 .943 .934 r
F P
0 g
s
.33666 .35636 m .32277 .36236 L .32696 .3388 L p .775 .943 .934 r
F P
0 g
s
.47742 .43045 m .46588 .42069 L .45931 .40672 L p .032 .274 .771 r
F P
0 g
s
.46588 .42069 m .47742 .43045 L .48579 .44499 L p .042 .271 .766 r
F P
0 g
s
.67338 .63219 m .66478 .63179 L .67198 .63224 L p .133 0 0 r
F P
0 g
s
.67198 .63224 m .68264 .6329 L p .67418 .63225 L .133 0 0 r
F P
0 g
s
.67418 .63225 m .67338 .63219 L .67198 .63224 L .133 0 0 r
F
.6908 .63549 m .70192 .63409 L .66478 .63179 L p .16 0 0 r
F P
0 g
s
.6688 .63218 m .6908 .63549 L p .6701 .63255 L .16 0 0 r
F P
0 g
s
.6701 .63255 m .66478 .63179 L .6688 .63218 L .16 0 0 r
F
.66478 .63179 m .65605 .63027 L .6688 .63218 L p F P
0 g
s
.67951 .63518 m .6688 .63218 L .66401 .63194 L .182 0 0 r
F
.6688 .63218 m .65605 .63027 L p .66401 .63194 L F P
0 g
s
.65605 .63027 m .6472 .62751 L .65793 .63006 L p .182 0 0 r
F P
0 g
s
.65793 .63006 m .67951 .63518 L p .66146 .6314 L .182 0 0 r
F P
0 g
s
.66146 .6314 m .65605 .63027 L .65793 .63006 L .182 0 0 r
F
.66704 .63222 m .6472 .62751 L p .66489 .63221 L .196 0 0 r
F P
0 g
s
.66806 .63305 m .66704 .63222 L .66489 .63221 L .196 0 0 r
F
.65647 .62904 m .66806 .63305 L .65326 .62828 L p 0 .381 .695 r
F P
0 g
s
.65326 .62828 m .63823 .62343 L p .65015 .62709 L 0 .381 .695 r
F P
0 g
s
.65647 .62904 m .65326 .62828 L .65015 .62709 L 0 .381 .695 r
F
.66806 .63305 m .67951 .63518 L .66704 .63222 L p .196 0 0 r
F P
0 g
s
.67951 .63518 m .6908 .63549 L .6688 .63218 L p .182 0 0 r
F P
0 g
s
.68264 .6329 m .70192 .63409 L p .68887 .63322 L .133 0 0 r
F P
0 g
s
.68887 .63322 m .67338 .63219 L .68264 .6329 L .133 0 0 r
F
.70192 .63409 m .71287 .63116 L .67338 .63219 L p F P
0 g
s
.75492 .60806 m .74466 .61508 L .7782 .59241 L p 0 0 0 r
F P
0 g
s
.40736 .34847 m .42038 .35705 L .41726 .3649 L p .241 .534 .921 r
F P
0 g
s
.43049 .37386 m .41726 .3649 L .42038 .35705 L p .147 .444 .877 r
F P
0 g
s
.55021 .54861 m .54716 .54062 L .57082 .56399 L p 0 .215 .739 r
F P
0 g
s
.57082 .56399 m .57718 .57371 L .55021 .54861 L p 0 .215 .739 r
F P
0 g
s
.52291 .50835 m .52327 .50321 L .541 .52414 L p 0 .206 .731 r
F P
0 g
s
.541 .52414 m .5441 .53247 L .52291 .50835 L p 0 .206 .731 r
F P
0 g
s
.50589 .48104 m .50963 .48003 L .52363 .49835 L p 0 .209 .731 r
F P
0 g
s
.52363 .49835 m .52327 .50321 L .50589 .48104 L p 0 .209 .731 r
F P
0 g
s
.31295 .34378 m .32696 .3388 L .32277 .36236 L p .818 .96 .904 r
F P
0 g
s
.32277 .36236 m .30869 .37025 L .31295 .34378 L p .818 .96 .904 r
F P
0 g
s
.20462 .46043 m .22002 .44563 L .23609 .49154 L p .915 .87 .779 r
F P
0 g
s
.23609 .49154 m .22187 .50852 L .20462 .46043 L p .915 .87 .779 r
F P
0 g
s
.59594 .59821 m .58974 .59085 L .61998 .61109 L p 0 .267 .719 r
F P
0 g
s
.61998 .61109 m .62915 .61796 L .59594 .59821 L p 0 .267 .719 r
F P
0 g
s
.42038 .35705 m .43336 .36754 L .43049 .37386 L p .147 .444 .877 r
F P
0 g
s
.44374 .38478 m .43049 .37386 L .43336 .36754 L p .068 .363 .833 r
F P
0 g
s
.83625 .53514 m .82489 .54637 L .84665 .50057 L p .831 .977 .678 r
F P
0 g
s
.84665 .50057 m .85906 .48583 L .83625 .53514 L p .831 .977 .678 r
F P
0 g
s
.44374 .38478 m .45704 .39751 L .45931 .40672 L p .072 .326 .805 r
F P
0 g
s
.47218 .41915 m .45931 .40672 L .45704 .39751 L p 0 .264 .768 r
F P
0 g
s
.45931 .40672 m .47218 .41915 L .47742 .43045 L p .032 .274 .771 r
F P
0 g
s
.29873 .35035 m .31295 .34378 L .30869 .37025 L p .849 .968 .876 r
F P
0 g
s
.30869 .37025 m .29441 .37985 L .29873 .35035 L p .849 .968 .876 r
F P
0 g
s
.49541 .45267 m .48579 .44499 L .47742 .43045 L p 0 .221 .738 r
F P
0 g
s
.48579 .44499 m .49541 .45267 L .50369 .46562 L p 0 .213 .732 r
F P
0 g
s
.50369 .46562 m .49676 .46187 L .48579 .44499 L p 0 .213 .732 r
F P
0 g
s
.49676 .46187 m .50369 .46562 L .51343 .4796 L p 0 .199 .724 r
F P
0 g
s
.51343 .4796 m .50963 .48003 L .49676 .46187 L p 0 .199 .724 r
F P
0 g
s
.54716 .54062 m .5441 .53247 L .5644 .55355 L p 0 .198 .727 r
F P
0 g
s
.5644 .55355 m .57082 .56399 L .54716 .54062 L p 0 .198 .727 r
F P
0 g
s
.18911 .47507 m .20462 .46043 L .22187 .50852 L p .913 .868 .781 r
F P
0 g
s
.22187 .50852 m .20758 .52532 L .18911 .47507 L p .913 .868 .781 r
F P
0 g
s
.4891 .44157 m .47742 .43045 L .47218 .41915 L p 0 .222 .739 r
F P
0 g
s
.47742 .43045 m .4891 .44157 L .49541 .45267 L p 0 .221 .738 r
F P
0 g
s
.74466 .61508 m .73424 .62143 L .76609 .6027 L p 0 0 0 r
F P
0 g
s
.76609 .6027 m .7782 .59241 L .74466 .61508 L p 0 0 0 r
F P
0 g
s
.52327 .50321 m .52363 .49835 L .53788 .51566 L p 0 .186 .717 r
F P
0 g
s
.53788 .51566 m .541 .52414 L .52327 .50321 L p 0 .186 .717 r
F P
0 g
s
.43336 .36754 m .44632 .37981 L .44374 .38478 L p .068 .363 .833 r
F P
0 g
s
.45704 .39751 m .44374 .38478 L .44632 .37981 L p .003 .296 .792 r
F P
0 g
s
.58974 .59085 m .58349 .58267 L .61071 .60282 L p 0 .245 .729 r
F P
0 g
s
.61071 .60282 m .61998 .61109 L .58974 .59085 L p 0 .245 .729 r
F P
0 g
s
.28429 .35831 m .29873 .35035 L .29441 .37985 L p .871 .971 .852 r
F P
0 g
s
.29441 .37985 m .27993 .39096 L .28429 .35831 L p .871 .971 .852 r
F P
0 g
s
.50963 .48003 m .51343 .4796 L .524 .49371 L p 0 .184 .714 r
F P
0 g
s
.524 .49371 m .52363 .49835 L .50963 .48003 L p 0 .184 .714 r
F P
0 g
s
.82489 .54637 m .81343 .558 L .83416 .51576 L p .813 .968 .655 r
F P
0 g
s
.83416 .51576 m .84665 .50057 L .82489 .54637 L p .813 .968 .655 r
F P
0 g
s
.45704 .39751 m .47042 .41185 L .47218 .41915 L p 0 .264 .768 r
F P
0 g
s
.48517 .43302 m .47218 .41915 L .47042 .41185 L p 0 .214 .736 r
F P
0 g
s
.47218 .41915 m .48517 .43302 L .4891 .44157 L p 0 .222 .739 r
F P
0 g
s
.5441 .53247 m .541 .52414 L .55795 .54248 L p 0 .183 .717 r
F P
0 g
s
.55795 .54248 m .5644 .55355 L .5441 .53247 L p 0 .183 .717 r
F P
0 g
s
.58349 .58267 m .57718 .57371 L .60137 .59319 L p 0 .226 .731 r
F P
0 g
s
.60137 .59319 m .61071 .60282 L .58349 .58267 L p 0 .226 .731 r
F P
0 g
s
.44632 .37981 m .4593 .39371 L .45704 .39751 L p .003 .296 .792 r
F P
0 g
s
.47042 .41185 m .45704 .39751 L .4593 .39371 L p 0 .242 .756 r
F P
0 g
s
.26962 .36745 m .28429 .35831 L .27993 .39096 L p .888 .971 .832 r
F P
0 g
s
.27993 .39096 m .26525 .40336 L .26962 .36745 L p .888 .971 .832 r
F P
0 g
s
.73424 .62143 m .72364 .62686 L .73505 .6212 L p 0 0 0 r
F P
0 g
s
.74126 .61971 m .75378 .6119 L .72364 .62686 L p 0 0 0 r
F P
0 g
s
.72364 .62686 m .71287 .63116 L .72072 .62799 L p 0 0 0 r
F P
0 g
s
.72072 .62799 m .74126 .61971 L p .72424 .62662 L 0 0 0 r
F P
0 g
s
.72424 .62662 m .72364 .62686 L .72072 .62799 L 0 0 0 r
F
.72608 .62583 m .71287 .63116 L p .7212 .62835 L F P
0 g
s
.72853 .62589 m .72608 .62583 L .7212 .62835 L 0 0 0 r
F
.71287 .63116 m .70603 .63299 L p .72853 .62589 L F P
0 g
s
.70603 .63299 m .70192 .63409 L .70644 .6327 L p 0 0 0 r
F P
0 g
s
.70644 .6327 m .72853 .62589 L p .70603 .63299 L 0 0 0 r
F P
0 g
s
.70246 .63242 m .70821 .63144 L p .6908 .63549 L .163 .701 .734 r
F P
0 g
s
.717 .62944 m .70192 .63409 L p .71371 .63072 L 0 0 0 r
F P
0 g
s
.71559 .63019 m .717 .62944 L .71371 .63072 L 0 0 0 r
F
.70821 .63144 m .71559 .63019 L .70756 .6319 L p .163 .701 .734 r
F P
0 g
s
.70756 .6319 m .6908 .63549 L p .70821 .63144 L .163 .701 .734 r
F P
0 g
s
.71559 .63019 m .72853 .62589 L .717 .62944 L p 0 0 0 r
F P
0 g
s
.72853 .62589 m .74126 .61971 L .72608 .62583 L p 0 0 0 r
F P
0 g
s
.73505 .6212 m .75378 .6119 L p .74086 .6182 L 0 0 0 r
F P
0 g
s
.74086 .6182 m .73424 .62143 L .73505 .6212 L 0 0 0 r
F
.75378 .6119 m .76609 .6027 L .73424 .62143 L p F P
0 g
s
.50516 .46131 m .49541 .45267 L .4891 .44157 L p 0 .182 .713 r
F P
0 g
s
.49541 .45267 m .50516 .46131 L .51072 .47011 L p 0 .178 .71 r
F P
0 g
s
.51072 .47011 m .50369 .46562 L .49541 .45267 L p 0 .178 .71 r
F P
0 g
s
.52363 .49835 m .524 .49371 L .53473 .50704 L p 0 .17 .706 r
F P
0 g
s
.53473 .50704 m .53788 .51566 L .52363 .49835 L p 0 .17 .706 r
F P
0 g
s
.50369 .46562 m .51072 .47011 L .51727 .47962 L p 0 .171 .706 r
F P
0 g
s
.51727 .47962 m .51343 .4796 L .50369 .46562 L p 0 .171 .706 r
F P
0 g
s
.39472 .33299 m .4068 .33943 L .39428 .34186 L p .202 .625 .949 r
F P
0 g
s
.39428 .34186 m .3811 .33727 L .39472 .33299 L p .202 .625 .949 r
F P
0 g
s
.40736 .34847 m .39428 .34186 L .4068 .33943 L p .123 .531 .916 r
F P
0 g
s
.4068 .33943 m .41877 .34756 L .40736 .34847 L p .123 .531 .916 r
F P
0 g
s
.42038 .35705 m .40736 .34847 L .41877 .34756 L p .056 .443 .876 r
F P
0 g
s
.50093 .4538 m .4891 .44157 L .48517 .43302 L p 0 .182 .713 r
F P
0 g
s
.4891 .44157 m .50093 .4538 L .50516 .46131 L p 0 .182 .713 r
F P
0 g
s
.6472 .62751 m .63823 .62343 L .66806 .63305 L p .196 0 0 r
F P
0 g
s
.38252 .32825 m .39472 .33299 L .3811 .33727 L p .289 .719 .969 r
F P
0 g
s
.3811 .33727 m .36781 .33471 L .38252 .32825 L p .289 .719 .969 r
F P
0 g
s
.41877 .34756 m .43067 .35734 L .42038 .35705 L p .056 .443 .876 r
F P
0 g
s
.43336 .36754 m .42038 .35705 L .43067 .35734 L p .002 .366 .835 r
F P
0 g
s
.57718 .57371 m .57082 .56399 L .59196 .58227 L p 0 .208 .728 r
F P
0 g
s
.59196 .58227 m .60137 .59319 L .57718 .57371 L p 0 .208 .728 r
F P
0 g
s
.541 .52414 m .53788 .51566 L .55145 .53083 L p 0 .171 .708 r
F P
0 g
s
.55145 .53083 m .55795 .54248 L .541 .52414 L p 0 .171 .708 r
F P
0 g
s
.81343 .558 m .80185 .56975 L .82155 .53108 L p .797 .962 .643 r
F P
0 g
s
.82155 .53108 m .83416 .51576 L .81343 .558 L p .797 .962 .643 r
F P
0 g
s
.51343 .4796 m .51727 .47962 L .52436 .48922 L p 0 .164 .701 r
F P
0 g
s
.52436 .48922 m .524 .49371 L .51343 .4796 L p 0 .164 .701 r
F P
0 g
s
.43067 .35734 m .4425 .3687 L .43336 .36754 L p .002 .366 .835 r
F P
0 g
s
.44632 .37981 m .43336 .36754 L .4425 .3687 L p 0 .303 .798 r
F P
0 g
s
.37017 .3252 m .38252 .32825 L .36781 .33471 L p .377 .802 .971 r
F P
0 g
s
.36781 .33471 m .35437 .33416 L .37017 .3252 L p .377 .802 .971 r
F P
0 g
s
.4593 .39371 m .47232 .40908 L .47042 .41185 L p 0 .242 .756 r
F P
0 g
s
.4839 .42759 m .47042 .41185 L .47232 .40908 L p 0 .201 .728 r
F P
0 g
s
.47042 .41185 m .4839 .42759 L .48517 .43302 L p 0 .214 .736 r
F P
0 g
s
.25472 .37755 m .26962 .36745 L .26525 .40336 L p .899 .969 .818 r
F P
0 g
s
.26525 .40336 m .25036 .41679 L .25472 .37755 L p .899 .969 .818 r
F P
0 g
s
.49832 .44805 m .48517 .43302 L .4839 .42759 L p 0 .178 .711 r
F P
0 g
s
.48517 .43302 m .49832 .44805 L .50093 .4538 L p 0 .182 .713 r
F P
0 g
s
.4425 .3687 m .45429 .38154 L .44632 .37981 L p 0 .303 .798 r
F P
0 g
s
.4593 .39371 m .44632 .37981 L .45429 .38154 L p 0 .253 .765 r
F P
0 g
s
.35766 .32379 m .37017 .3252 L .35437 .33416 L p .459 .868 .955 r
F P
0 g
s
.35437 .33416 m .34076 .33555 L .35766 .32379 L p .459 .868 .955 r
F P
0 g
s
.57082 .56399 m .5644 .55355 L .58249 .57014 L p 0 .193 .721 r
F P
0 g
s
.58249 .57014 m .59196 .58227 L .57082 .56399 L p 0 .193 .721 r
F P
0 g
s
.63823 .62343 m .62915 .61796 L .65647 .62904 L p 0 .381 .695 r
F P
0 g
s
.524 .49371 m .52436 .48922 L .53155 .49829 L p 0 .157 .697 r
F P
0 g
s
.53155 .49829 m .53473 .50704 L .524 .49371 L p 0 .157 .697 r
F P
0 g
s
.53788 .51566 m .53473 .50704 L .54492 .51871 L p 0 .161 .7 r
F P
0 g
s
.54492 .51871 m .55145 .53083 L .53788 .51566 L p 0 .161 .7 r
F P
0 g
s
.45429 .38154 m .46605 .39572 L .4593 .39371 L p 0 .253 .765 r
F P
0 g
s
.47232 .40908 m .4593 .39371 L .46605 .39572 L p 0 .214 .738 r
F P
0 g
s
.34497 .32394 m .35766 .32379 L .34076 .33555 L p .53 .915 .928 r
F P
0 g
s
.34076 .33555 m .32696 .3388 L .34497 .32394 L p .53 .915 .928 r
F P
0 g
s
.51506 .47067 m .50516 .46131 L .50093 .4538 L p 0 .155 .695 r
F P
0 g
s
.50516 .46131 m .51506 .47067 L .51786 .47513 L p 0 .154 .695 r
F P
0 g
s
.51786 .47513 m .51072 .47011 L .50516 .46131 L p 0 .154 .695 r
F P
0 g
s
.23961 .38835 m .25472 .37755 L .25036 .41679 L p .907 .965 .809 r
F P
0 g
s
.25036 .41679 m .23528 .43098 L .23961 .38835 L p .907 .965 .809 r
F P
0 g
s
.47232 .40908 m .48539 .42569 L .4839 .42759 L p 0 .201 .728 r
F P
0 g
s
.4975 .44447 m .4839 .42759 L .48539 .42569 L p 0 .171 .707 r
F P
0 g
s
.4839 .42759 m .4975 .44447 L .49832 .44805 L p 0 .178 .711 r
F P
0 g
s
.51072 .47011 m .51786 .47513 L .52116 .47996 L p 0 .152 .693 r
F P
0 g
s
.52116 .47996 m .51727 .47962 L .51072 .47011 L p 0 .152 .693 r
F P
0 g
s
.80185 .56975 m .79011 .58132 L .80878 .5462 L p .782 .959 .643 r
F P
0 g
s
.80878 .5462 m .82155 .53108 L .80185 .56975 L p .782 .959 .643 r
F P
0 g
s
.5644 .55355 m .55795 .54248 L .57299 .55694 L p 0 .18 .714 r
F P
0 g
s
.57299 .55694 m .58249 .57014 L .5644 .55355 L p 0 .18 .714 r
F P
0 g
s
.51293 .46686 m .50093 .4538 L .49832 .44805 L p 0 .155 .695 r
F P
0 g
s
.50093 .4538 m .51293 .46686 L .51506 .47067 L p 0 .155 .695 r
F P
0 g
s
.62915 .61796 m .61998 .61109 L .64476 .62309 L p 0 .351 .736 r
F P
0 g
s
.64476 .62309 m .65647 .62904 L .62915 .61796 L p 0 .351 .736 r
F P
0 g
s
.51727 .47962 m .52116 .47996 L .52474 .48483 L p 0 .15 .692 r
F P
0 g
s
.52474 .48483 m .52436 .48922 L .51727 .47962 L p 0 .15 .692 r
F P
0 g
s
.46605 .39572 m .47782 .4111 L .47232 .40908 L p 0 .214 .738 r
F P
0 g
s
.48539 .42569 m .47232 .40908 L .47782 .4111 L p 0 .184 .717 r
F P
0 g
s
.51163 .46398 m .49832 .44805 L .4975 .44447 L p 0 .154 .695 r
F P
0 g
s
.49832 .44805 m .51163 .46398 L .51293 .46686 L p 0 .155 .695 r
F P
0 g
s
.33208 .32554 m .34497 .32394 L .32696 .3388 L p .59 .946 .896 r
F P
0 g
s
.32696 .3388 m .31295 .34378 L .33208 .32554 L p .59 .946 .896 r
F P
0 g
s
.53473 .50704 m .53155 .49829 L .53835 .5062 L p 0 .152 .694 r
F P
0 g
s
.53835 .5062 m .54492 .51871 L .53473 .50704 L p 0 .152 .694 r
F P
0 g
s
.55795 .54248 m .55145 .53083 L .56345 .54281 L p 0 .168 .707 r
F P
0 g
s
.56345 .54281 m .57299 .55694 L .55795 .54248 L p 0 .168 .707 r
F P
0 g
s
.61998 .61109 m .61071 .60282 L .63294 .61523 L p 0 .316 .756 r
F P
0 g
s
.63294 .61523 m .64476 .62309 L .61998 .61109 L p 0 .316 .756 r
F P
0 g
s
.52436 .48922 m .52474 .48483 L .52835 .48942 L p 0 .148 .69 r
F P
0 g
s
.52835 .48942 m .53155 .49829 L .52436 .48922 L p 0 .148 .69 r
F P
0 g
s
.2243 .39957 m .23961 .38835 L .23528 .43098 L p .912 .961 .805 r
F P
0 g
s
.23528 .43098 m .22002 .44563 L .2243 .39957 L p .912 .961 .805 r
F P
0 g
s
.47782 .4111 m .4896 .42747 L .48539 .42569 L p 0 .184 .717 r
F P
0 g
s
.49854 .4433 m .48539 .42569 L .4896 .42747 L p 0 .163 .702 r
F P
0 g
s
.48539 .42569 m .49854 .4433 L .4975 .44447 L p 0 .171 .707 r
F P
0 g
s
.51123 .4622 m .4975 .44447 L .49854 .4433 L p 0 .152 .693 r
F P
0 g
s
.4975 .44447 m .51123 .4622 L .51163 .46398 L p 0 .154 .695 r
F P
0 g
s
.79011 .58132 m .7782 .59241 L .79584 .56079 L p .77 .961 .655 r
F P
0 g
s
.79584 .56079 m .80878 .5462 L .79011 .58132 L p .77 .961 .655 r
F P
0 g
s
.55145 .53083 m .54492 .51871 L .55388 .52792 L p 0 .159 .7 r
F P
0 g
s
.55388 .52792 m .56345 .54281 L .55145 .53083 L p 0 .159 .7 r
F P
0 g
s
.61071 .60282 m .60137 .59319 L .62104 .60551 L p 0 .281 .759 r
F P
0 g
s
.62104 .60551 m .63294 .61523 L .61071 .60282 L p 0 .281 .759 r
F P
0 g
s
.70192 .63409 m .6908 .63549 L .71559 .63019 L p 0 0 0 r
F P
0 g
s
.31899 .32846 m .33208 .32554 L .31295 .34378 L p .639 .966 .865 r
F P
0 g
s
.31295 .34378 m .29873 .35035 L .31899 .32846 L p .639 .966 .865 r
F P
0 g
s
.53155 .49829 m .52835 .48942 L .53175 .49342 L p 0 .146 .689 r
F P
0 g
s
.53175 .49342 m .53835 .5062 L .53155 .49829 L p 0 .146 .689 r
F P
0 g
s
.44774 .36608 m .45754 .37755 L .4425 .3687 L p 0 .282 .779 r
F P
0 g
s
.4425 .3687 m .43067 .35734 L .44774 .36608 L p 0 .282 .779 r
F P
0 g
s
.45429 .38154 m .4425 .3687 L .45754 .37755 L p 0 .243 .757 r
F P
0 g
s
.52511 .48046 m .51506 .47067 L .51293 .46686 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .51786 .47513 L .51506 .47067 L closepath p 0 .142 .686 r
F P
0 g
s
.45754 .37755 m .46728 .39007 L .45429 .38154 L p 0 .243 .757 r
F P
0 g
s
.46605 .39572 m .45429 .38154 L .46728 .39007 L p 0 .212 .737 r
F P
0 g
s
.52511 .48046 m .52116 .47996 L .51786 .47513 L closepath p 0 .142 .686 r
F P
0 g
s
.43788 .35576 m .44774 .36608 L .43067 .35734 L p 0 .33 .802 r
F P
0 g
s
.43067 .35734 m .41877 .34756 L .43788 .35576 L p 0 .33 .802 r
F P
0 g
s
.52511 .48046 m .51293 .46686 L .51163 .46398 L closepath p 0 .142 .686 r
F P
0 g
s
.4896 .42747 m .5014 .44465 L .49854 .4433 L p 0 .163 .702 r
F P
0 g
s
.51178 .46166 m .49854 .4433 L .5014 .44465 L p 0 .149 .692 r
F P
0 g
s
.49854 .4433 m .51178 .46166 L .51123 .4622 L p 0 .152 .693 r
F P
0 g
s
.54492 .51871 m .53835 .5062 L .5443 .51243 L p 0 .152 .694 r
F P
0 g
s
.5443 .51243 m .55388 .52792 L .54492 .51871 L p 0 .152 .694 r
F P
0 g
s
.60137 .59319 m .59196 .58227 L .60907 .59404 L p 0 .25 .752 r
F P
0 g
s
.60907 .59404 m .62104 .60551 L .60137 .59319 L p 0 .25 .752 r
F P
0 g
s
.46728 .39007 m .47698 .40356 L .46605 .39572 L p 0 .212 .737 r
F P
0 g
s
.47782 .4111 m .46605 .39572 L .47698 .40356 L p 0 .188 .72 r
F P
0 g
s
.52511 .48046 m .52474 .48483 L .52116 .47996 L closepath p 0 .142 .686 r
F P
0 g
s
.42793 .34664 m .43788 .35576 L .41877 .34756 L p 0 .387 .824 r
F P
0 g
s
.41877 .34756 m .4068 .33943 L .42793 .34664 L p 0 .387 .824 r
F P
0 g
s
.52511 .48046 m .51163 .46398 L .51123 .4622 L closepath p 0 .142 .686 r
F P
0 g
s
.20881 .41093 m .2243 .39957 L .22002 .44563 L p .914 .957 .804 r
F P
0 g
s
.22002 .44563 m .20462 .46043 L .20881 .41093 L p .914 .957 .804 r
F P
0 g
s
.47698 .40356 m .48664 .41788 L .47782 .4111 L p 0 .188 .72 r
F P
0 g
s
.4896 .42747 m .47782 .4111 L .48664 .41788 L p 0 .17 .707 r
F P
0 g
s
.52511 .48046 m .52835 .48942 L .52474 .48483 L closepath p 0 .142 .686 r
F P
0 g
s
.41788 .33875 m .42793 .34664 L .4068 .33943 L p 0 .45 .842 r
F P
0 g
s
.4068 .33943 m .39472 .33299 L .41788 .33875 L p 0 .45 .842 r
F P
0 g
s
.52511 .48046 m .51123 .4622 L .51178 .46166 L closepath p 0 .142 .686 r
F P
0 g
s
.59196 .58227 m .58249 .57014 L .59706 .58096 L p 0 .223 .741 r
F P
0 g
s
.59706 .58096 m .60907 .59404 L .59196 .58227 L p 0 .223 .741 r
F P
0 g
s
.6908 .63549 m .67951 .63518 L .70246 .63242 L p .163 .701 .734 r
F P
0 g
s
.30568 .33255 m .31899 .32846 L .29873 .35035 L p .681 .978 .839 r
F P
0 g
s
.29873 .35035 m .28429 .35831 L .30568 .33255 L p .681 .978 .839 r
F P
0 g
s
.48664 .41788 m .49628 .4329 L .4896 .42747 L p 0 .17 .707 r
F P
0 g
s
.5014 .44465 m .4896 .42747 L .49628 .4329 L p 0 .156 .697 r
F P
0 g
s
.53835 .5062 m .53175 .49342 L .53471 .49655 L p 0 .146 .689 r
F P
0 g
s
.53471 .49655 m .5443 .51243 L .53835 .5062 L p 0 .146 .689 r
F P
0 g
s
.7782 .59241 m .76609 .6027 L .7827 .5745 L p .758 .967 .68 r
F P
0 g
s
.7827 .5745 m .79584 .56079 L .7782 .59241 L p .758 .967 .68 r
F P
0 g
s
.52511 .48046 m .53175 .49342 L .52835 .48942 L closepath p 0 .142 .686 r
F P
0 g
s
.58249 .57014 m .57299 .55694 L .58504 .56644 L p 0 .2 .728 r
F P
0 g
s
.58504 .56644 m .59706 .58096 L .58249 .57014 L p 0 .2 .728 r
F P
0 g
s
.5014 .44465 m .51324 .4624 L .51178 .46166 L p 0 .149 .692 r
F P
0 g
s
.52511 .48046 m .51178 .46166 L .51324 .4624 L closepath p 0 .142 .686 r
F P
0 g
s
.40773 .33211 m .41788 .33875 L .39472 .33299 L p 0 .518 .852 r
F P
0 g
s
.39472 .33299 m .38252 .32825 L .40773 .33211 L p 0 .518 .852 r
F P
0 g
s
.49628 .4329 m .5059 .44845 L .5014 .44465 L p 0 .156 .697 r
F P
0 g
s
.51324 .4624 m .5014 .44465 L .5059 .44845 L p 0 .147 .69 r
F P
0 g
s
.85906 .48583 m .84665 .50057 L .8471 .45067 L p .943 .95 .75 r
F P
0 g
s
.8471 .45067 m .85986 .43317 L .85906 .48583 L p .943 .95 .75 r
F P
0 g
s
.57299 .55694 m .56345 .54281 L .573 .55071 L p 0 .181 .716 r
F P
0 g
s
.573 .55071 m .58504 .56644 L .57299 .55694 L p 0 .181 .716 r
F P
0 g
s
.52511 .48046 m .53471 .49655 L .53175 .49342 L closepath p 0 .142 .686 r
F P
0 g
s
.56345 .54281 m .55388 .52792 L .56099 .53398 L p 0 .167 .705 r
F P
0 g
s
.56099 .53398 m .573 .55071 L .56345 .54281 L p 0 .167 .705 r
F P
0 g
s
.5059 .44845 m .51551 .46437 L .51324 .4624 L p 0 .147 .69 r
F P
0 g
s
.52511 .48046 m .51324 .4624 L .51551 .46437 L closepath p 0 .142 .686 r
F P
0 g
s
.67951 .63518 m .66806 .63305 L .68915 .63245 L p .122 .67 .808 r
F P
0 g
s
.68915 .63245 m .70246 .63242 L .67951 .63518 L p .122 .67 .808 r
F P
0 g
s
.19318 .42214 m .20881 .41093 L .20462 .46043 L p .913 .951 .808 r
F P
0 g
s
.20462 .46043 m .18911 .47507 L .19318 .42214 L p .913 .951 .808 r
F P
0 g
s
.39745 .32669 m .40773 .33211 L .38252 .32825 L p .045 .584 .851 r
F P
0 g
s
.38252 .32825 m .37017 .3252 L .39745 .32669 L p .045 .584 .851 r
F P
0 g
s
.55388 .52792 m .5443 .51243 L .54899 .51653 L p 0 .155 .697 r
F P
0 g
s
.54899 .51653 m .56099 .53398 L .55388 .52792 L p 0 .155 .697 r
F P
0 g
s
.5443 .51243 m .53471 .49655 L .53703 .4986 L p 0 .147 .69 r
F P
0 g
s
.53703 .4986 m .54899 .51653 L .5443 .51243 L p 0 .147 .69 r
F P
0 g
s
.52511 .48046 m .53703 .4986 L .53471 .49655 L closepath p 0 .142 .686 r
F P
0 g
s
.29216 .33763 m .30568 .33255 L .28429 .35831 L p .716 .986 .821 r
F P
0 g
s
.28429 .35831 m .26962 .36745 L .29216 .33763 L p .716 .986 .821 r
F P
0 g
s
.52511 .48046 m .53533 .49042 L .53749 .49428 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .53248 .48588 L .53533 .49042 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .52912 .48098 L .53248 .48588 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .5255 .47604 L .52912 .48098 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .52185 .47143 L .5255 .47604 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .51845 .46745 L .52185 .47143 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .51551 .46437 L .51845 .46745 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .53855 .49941 L .53703 .4986 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .53915 .49893 L .53855 .49941 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .53879 .49718 L .53915 .49893 L closepath p 0 .142 .686 r
F P
0 g
s
.52511 .48046 m .53749 .49428 L .53879 .49718 L closepath p 0 .142 .686 r
F P
0 g
s
.76609 .6027 m .75378 .6119 L .76934 .58698 L p .745 .974 .717 r
F P
0 g
s
.76934 .58698 m .7827 .5745 L .76609 .6027 L p .745 .974 .717 r
F P
0 g
s
.51175 .45447 m .51845 .46745 L .51551 .46437 L p 0 .146 .69 r
F P
0 g
s
.51551 .46437 m .5059 .44845 L .51175 .45447 L p 0 .146 .69 r
F P
0 g
s
.50502 .44165 m .51175 .45447 L .5059 .44845 L p 0 .153 .695 r
F P
0 g
s
.5059 .44845 m .49628 .4329 L .50502 .44165 L p 0 .153 .695 r
F P
0 g
s
.49825 .42909 m .50502 .44165 L .49628 .4329 L p 0 .161 .701 r
F P
0 g
s
.49628 .4329 m .48664 .41788 L .49825 .42909 L p 0 .161 .701 r
F P
0 g
s
.66806 .63305 m .65647 .62904 L .67568 .63018 L p .078 .616 .856 r
F P
0 g
s
.67568 .63018 m .68915 .63245 L .66806 .63305 L p .078 .616 .856 r
F P
0 g
s
.84665 .50057 m .83416 .51576 L .83427 .46862 L p .945 .951 .744 r
F P
0 g
s
.83427 .46862 m .8471 .45067 L .84665 .50057 L p .945 .951 .744 r
F P
0 g
s
.38703 .32248 m .39745 .32669 L .37017 .3252 L p .102 .646 .839 r
F P
0 g
s
.37017 .3252 m .35766 .32379 L .38703 .32248 L p .102 .646 .839 r
F P
0 g
s
.54899 .51653 m .53703 .4986 L .53855 .49941 L p 0 .149 .692 r
F P
0 g
s
.49144 .41686 m .49825 .42909 L .48664 .41788 L p 0 .173 .71 r
F P
0 g
s
.48664 .41788 m .47698 .40356 L .49144 .41686 L p 0 .173 .71 r
F P
0 g
s
.51857 .46233 m .52185 .47143 L .51845 .46745 L p 0 .146 .689 r
F P
0 g
s
.51845 .46745 m .51175 .45447 L .51857 .46233 L p 0 .146 .689 r
F P
0 g
s
.48459 .40507 m .49144 .41686 L .47698 .40356 L p 0 .188 .721 r
F P
0 g
s
.47698 .40356 m .46728 .39007 L .48459 .40507 L p 0 .188 .721 r
F P
0 g
s
.56099 .53398 m .54899 .51653 L .55208 .51818 L p 0 .162 .701 r
F P
0 g
s
.53855 .49941 m .55208 .51818 L .54899 .51653 L p 0 .149 .692 r
F P
0 g
s
.65647 .62904 m .64476 .62309 L .66209 .62557 L p .035 .545 .873 r
F P
0 g
s
.66209 .62557 m .67568 .63018 L .65647 .62904 L p .035 .545 .873 r
F P
0 g
s
.55208 .51818 m .53855 .49941 L .53915 .49893 L p 0 .151 .693 r
F P
0 g
s
.47768 .39378 m .48459 .40507 L .46728 .39007 L p 0 .207 .733 r
F P
0 g
s
.46728 .39007 m .45754 .37755 L .47768 .39378 L p 0 .207 .733 r
F P
0 g
s
.52588 .4715 m .5255 .47604 L .52185 .47143 L p 0 .148 .69 r
F P
0 g
s
.52185 .47143 m .51857 .46233 L .52588 .4715 L p 0 .148 .69 r
F P
0 g
s
.27842 .34349 m .29216 .33763 L .26962 .36745 L p .746 .992 .81 r
F P
0 g
s
.26962 .36745 m .25472 .37755 L .27842 .34349 L p .746 .992 .81 r
F P
0 g
s
.51525 .45319 m .51857 .46233 L .51175 .45447 L p 0 .153 .694 r
F P
0 g
s
.51175 .45447 m .50502 .44165 L .51525 .45319 L p 0 .153 .694 r
F P
0 g
s
.573 .55071 m .56099 .53398 L .5657 .53644 L p 0 .181 .715 r
F P
0 g
s
.55208 .51818 m .5657 .53644 L .56099 .53398 L p 0 .162 .701 r
F P
0 g
s
.75378 .6119 m .74126 .61971 L .75577 .59793 L p .729 .982 .767 r
F P
0 g
s
.75577 .59793 m .76934 .58698 L .75378 .6119 L p .729 .982 .767 r
F P
0 g
s
.37647 .31941 m .38703 .32248 L .35766 .32379 L p .162 .699 .82 r
F P
0 g
s
.35766 .32379 m .34497 .32394 L .37647 .31941 L p .162 .699 .82 r
F P
0 g
s
.47073 .38306 m .47768 .39378 L .45754 .37755 L p 0 .231 .747 r
F P
0 g
s
.45754 .37755 m .44774 .36608 L .47073 .38306 L p 0 .231 .747 r
F P
0 g
s
.53915 .49893 m .55333 .51724 L .55208 .51818 L p 0 .151 .693 r
F P
0 g
s
.55333 .51724 m .53915 .49893 L .53879 .49718 L p 0 .153 .694 r
F P
0 g
s
.64476 .62309 m .63294 .61523 L .64839 .61865 L p 0 .468 .865 r
F P
0 g
s
.64839 .61865 m .66209 .62557 L .64476 .62309 L p 0 .468 .865 r
F P
0 g
s
.53319 .48133 m .52912 .48098 L .5255 .47604 L p 0 .15 .692 r
F P
0 g
s
.5255 .47604 m .52588 .4715 L .53319 .48133 L p 0 .15 .692 r
F P
0 g
s
.58504 .56644 m .573 .55071 L .57941 .55388 L p 0 .206 .733 r
F P
0 g
s
.5657 .53644 m .57941 .55388 L .573 .55071 L p 0 .181 .715 r
F P
0 g
s
.83416 .51576 m .82155 .53108 L .82135 .48669 L p .944 .952 .744 r
F P
0 g
s
.82135 .48669 m .83427 .46862 L .83416 .51576 L p .944 .952 .744 r
F P
0 g
s
.53879 .49718 m .55265 .51376 L .55333 .51724 L p 0 .153 .694 r
F P
0 g
s
.55265 .51376 m .53879 .49718 L .53749 .49428 L p 0 .155 .695 r
F P
0 g
s
.63294 .61523 m .62104 .60551 L .63462 .60949 L p 0 .396 .841 r
F P
0 g
s
.63462 .60949 m .64839 .61865 L .63294 .61523 L p 0 .396 .841 r
F P
0 g
s
.53996 .49115 m .53248 .48588 L .52912 .48098 L p 0 .152 .693 r
F P
0 g
s
.52912 .48098 m .53319 .48133 L .53996 .49115 L p 0 .152 .693 r
F P
0 g
s
.59706 .58096 m .58504 .56644 L .59317 .57018 L p 0 .239 .756 r
F P
0 g
s
.57941 .55388 m .59317 .57018 L .58504 .56644 L p 0 .206 .733 r
F P
0 g
s
.46371 .37295 m .47073 .38306 L .44774 .36608 L p 0 .261 .761 r
F P
0 g
s
.44774 .36608 m .43788 .35576 L .46371 .37295 L p 0 .261 .761 r
F P
0 g
s
.5119 .44403 m .51525 .45319 L .50502 .44165 L p 0 .162 .701 r
F P
0 g
s
.50502 .44165 m .49825 .42909 L .5119 .44403 L p 0 .162 .701 r
F P
0 g
s
.5657 .53644 m .55208 .51818 L .55333 .51724 L p 0 .17 .706 r
F P
0 g
s
.53749 .49428 m .55005 .50796 L .55265 .51376 L p 0 .155 .695 r
F P
0 g
s
.55005 .50796 m .53749 .49428 L .53533 .49042 L p 0 .155 .695 r
F P
0 g
s
.62104 .60551 m .60907 .59404 L .62081 .59823 L p 0 .333 .812 r
F P
0 g
s
.62081 .59823 m .63462 .60949 L .62104 .60551 L p 0 .333 .812 r
F P
0 g
s
.54572 .50024 m .53533 .49042 L .53248 .48588 L p 0 .154 .694 r
F P
0 g
s
.53248 .48588 m .53996 .49115 L .54572 .50024 L p 0 .154 .694 r
F P
0 g
s
.60907 .59404 m .59706 .58096 L .60698 .58505 L p 0 .281 .782 r
F P
0 g
s
.59317 .57018 m .60698 .58505 L .59706 .58096 L p 0 .239 .756 r
F P
0 g
s
.53533 .49042 m .54572 .50024 L .55005 .50796 L p 0 .155 .695 r
F P
0 g
s
.60698 .58505 m .62081 .59823 L .60907 .59404 L p 0 .281 .782 r
F P
0 g
s
.52627 .46675 m .52588 .4715 L .51857 .46233 L p 0 .157 .697 r
F P
0 g
s
.51857 .46233 m .51525 .45319 L .52627 .46675 L p 0 .157 .697 r
F P
0 g
s
.74126 .61971 m .72853 .62589 L .74198 .60704 L p .705 .984 .825 r
F P
0 g
s
.74198 .60704 m .75577 .59793 L .74126 .61971 L p .705 .984 .825 r
F P
0 g
s
.36575 .31739 m .37647 .31941 L .34497 .32394 L p .223 .745 .799 r
F P
0 g
s
.34497 .32394 m .33208 .32554 L .36575 .31739 L p .223 .745 .799 r
F P
0 g
s
.45663 .3635 m .46371 .37295 L .43788 .35576 L p 0 .296 .776 r
F P
0 g
s
.43788 .35576 m .42793 .34664 L .45663 .3635 L p 0 .296 .776 r
F P
0 g
s
.50853 .43486 m .5119 .44403 L .49825 .42909 L p 0 .173 .71 r
F P
0 g
s
.49825 .42909 m .49144 .41686 L .50853 .43486 L p 0 .173 .71 r
F P
0 g
s
.26448 .34992 m .27842 .34349 L .25472 .37755 L p .772 .996 .806 r
F P
0 g
s
.25472 .37755 m .23961 .38835 L .26448 .34992 L p .772 .996 .806 r
F P
0 g
s
.55333 .51724 m .56766 .53505 L .5657 .53644 L p 0 .17 .706 r
F P
0 g
s
.56766 .53505 m .55333 .51724 L .55265 .51376 L p 0 .176 .71 r
F P
0 g
s
.57941 .55388 m .5657 .53644 L .56766 .53505 L p 0 .197 .726 r
F P
0 g
s
.82155 .53108 m .80878 .5462 L .80829 .50455 L p .942 .953 .75 r
F P
0 g
s
.80829 .50455 m .82135 .48669 L .82155 .53108 L p .942 .953 .75 r
F P
0 g
s
.53731 .48137 m .53319 .48133 L .52588 .4715 L p 0 .163 .701 r
F P
0 g
s
.52588 .4715 m .52627 .46675 L .53731 .48137 L p 0 .163 .701 r
F P
0 g
s
.44948 .35471 m .45663 .3635 L .42793 .34664 L p 0 .336 .789 r
F P
0 g
s
.42793 .34664 m .41788 .33875 L .44948 .35471 L p 0 .336 .789 r
F P
0 g
s
.50512 .42568 m .50853 .43486 L .49144 .41686 L p 0 .188 .72 r
F P
0 g
s
.49144 .41686 m .48459 .40507 L .50512 .42568 L p 0 .188 .72 r
F P
0 g
s
.52667 .46172 m .52627 .46675 L .51525 .45319 L p 0 .17 .706 r
F P
0 g
s
.51525 .45319 m .5119 .44403 L .52667 .46172 L p 0 .17 .706 r
F P
0 g
s
.72853 .62589 m .71559 .63019 L .72799 .61406 L p .668 .974 .887 r
F P
0 g
s
.72799 .61406 m .74198 .60704 L .72853 .62589 L p .668 .974 .887 r
F P
0 g
s
.55265 .51376 m .56668 .52985 L .56766 .53505 L p 0 .176 .71 r
F P
0 g
s
.56668 .52985 m .55265 .51376 L .55005 .50796 L p 0 .18 .713 r
F P
0 g
s
.35487 .31633 m .36575 .31739 L .33208 .32554 L p .284 .784 .78 r
F P
0 g
s
.33208 .32554 m .31899 .32846 L .35487 .31633 L p .284 .784 .78 r
F P
0 g
s
.59317 .57018 m .57941 .55388 L .58213 .55199 L p 0 .234 .752 r
F P
0 g
s
.56766 .53505 m .58213 .55199 L .57941 .55388 L p 0 .197 .726 r
F P
0 g
s
.54756 .49601 m .53996 .49115 L .53319 .48133 L p 0 .171 .706 r
F P
0 g
s
.53319 .48133 m .53731 .48137 L .54756 .49601 L p 0 .171 .706 r
F P
0 g
s
.44224 .34661 m .44948 .35471 L .41788 .33875 L p 0 .382 .8 r
F P
0 g
s
.41788 .33875 m .40773 .33211 L .44224 .34661 L p 0 .382 .8 r
F P
0 g
s
.55005 .50796 m .5628 .52116 L .56668 .52985 L p 0 .18 .713 r
F P
0 g
s
.5628 .52116 m .55005 .50796 L .54572 .50024 L p 0 .181 .712 r
F P
0 g
s
.50168 .41653 m .50512 .42568 L .48459 .40507 L p 0 .206 .733 r
F P
0 g
s
.48459 .40507 m .47768 .39378 L .50168 .41653 L p 0 .206 .733 r
F P
0 g
s
.25034 .35669 m .26448 .34992 L .23961 .38835 L p .796 .999 .808 r
F P
0 g
s
.23961 .38835 m .2243 .39957 L .25034 .35669 L p .796 .999 .808 r
F P
0 g
s
.55627 .50961 m .54572 .50024 L .53996 .49115 L p 0 .177 .71 r
F P
0 g
s
.53996 .49115 m .54756 .49601 L .55627 .50961 L p 0 .177 .71 r
F P
0 g
s
.58213 .55199 m .56766 .53505 L .56668 .52985 L p 0 .211 .734 r
F P
0 g
s
.80878 .5462 m .79584 .56079 L .79508 .52183 L p .937 .954 .762 r
F P
0 g
s
.79508 .52183 m .80829 .50455 L .80878 .5462 L p .937 .954 .762 r
F P
0 g
s
.54572 .50024 m .55627 .50961 L .5628 .52116 L p 0 .181 .712 r
F P
0 g
s
.71559 .63019 m .70246 .63242 L .7138 .61878 L p .614 .944 .943 r
F P
0 g
s
.7138 .61878 m .72799 .61406 L .71559 .63019 L p .614 .944 .943 r
F P
0 g
s
.60698 .58505 m .59317 .57018 L .5967 .56771 L p 0 .283 .784 r
F P
0 g
s
.58213 .55199 m .5967 .56771 L .59317 .57018 L p 0 .234 .752 r
F P
0 g
s
.52707 .45635 m .52667 .46172 L .5119 .44403 L p 0 .186 .718 r
F P
0 g
s
.5119 .44403 m .50853 .43486 L .52707 .45635 L p 0 .186 .718 r
F P
0 g
s
.54149 .48093 m .53731 .48137 L .52627 .46675 L p 0 .183 .714 r
F P
0 g
s
.52627 .46675 m .52667 .46172 L .54149 .48093 L p 0 .183 .714 r
F P
0 g
s
.43493 .33918 m .44224 .34661 L .40773 .33211 L p 0 .432 .808 r
F P
0 g
s
.40773 .33211 m .39745 .32669 L .43493 .33918 L p 0 .432 .808 r
F P
0 g
s
.49821 .4074 m .50168 .41653 L .47768 .39378 L p 0 .227 .748 r
F P
0 g
s
.47768 .39378 m .47073 .38306 L .49821 .4074 L p 0 .227 .748 r
F P
0 g
s
.34381 .3161 m .35487 .31633 L .31899 .32846 L p .344 .818 .768 r
F P
0 g
s
.31899 .32846 m .30568 .33255 L .34381 .3161 L p .344 .818 .768 r
F P
0 g
s
.70246 .63242 m .68915 .63245 L .69943 .62104 L p .539 .888 .982 r
F P
0 g
s
.69943 .62104 m .7138 .61878 L .70246 .63242 L p .539 .888 .982 r
F P
0 g
s
.62081 .59823 m .60698 .58505 L .61137 .58189 L p .03 .343 .822 r
F P
0 g
s
.5967 .56771 m .61137 .58189 L .60698 .58505 L p 0 .283 .784 r
F P
0 g
s
.56668 .52985 m .58089 .54506 L .58213 .55199 L p 0 .211 .734 r
F P
0 g
s
.58089 .54506 m .56668 .52985 L .5628 .52116 L p 0 .218 .738 r
F P
0 g
s
.79584 .56079 m .7827 .5745 L .7817 .53818 L p .928 .954 .78 r
F P
0 g
s
.7817 .53818 m .79508 .52183 L .79584 .56079 L p .928 .954 .78 r
F P
0 g
s
.5967 .56771 m .58213 .55199 L .58089 .54506 L p 0 .257 .764 r
F P
0 g
s
.68915 .63245 m .67568 .63018 L .68492 .62074 L p .448 .807 .997 r
F P
0 g
s
.68492 .62074 m .69943 .62104 L .68915 .63245 L p .448 .807 .997 r
F P
0 g
s
.63462 .60949 m .62081 .59823 L .62609 .59423 L p .092 .418 .865 r
F P
0 g
s
.61137 .58189 m .62609 .59423 L .62081 .59823 L p .03 .343 .822 r
F P
0 g
s
.55527 .50024 m .54756 .49601 L .53731 .48137 L p 0 .198 .723 r
F P
0 g
s
.53731 .48137 m .54149 .48093 L .55527 .50024 L p 0 .198 .723 r
F P
0 g
s
.23602 .36355 m .25034 .35669 L .2243 .39957 L p .815 1 .816 r
F P
0 g
s
.2243 .39957 m .20881 .41093 L .23602 .36355 L p .815 1 .816 r
F P
0 g
s
.52747 .45058 m .52707 .45635 L .50853 .43486 L p 0 .207 .731 r
F P
0 g
s
.50853 .43486 m .50512 .42568 L .52747 .45058 L p 0 .207 .731 r
F P
0 g
s
.4947 .39831 m .49821 .4074 L .47073 .38306 L p 0 .253 .765 r
F P
0 g
s
.47073 .38306 m .46371 .37295 L .4947 .39831 L p 0 .253 .765 r
F P
0 g
s
.64839 .61865 m .63462 .60949 L .64085 .60447 L p .166 .505 .911 r
F P
0 g
s
.62609 .59423 m .64085 .60447 L .63462 .60949 L p .092 .418 .865 r
F P
0 g
s
.67568 .63018 m .66209 .62557 L .6703 .61785 L p .35 .708 .985 r
F P
0 g
s
.6703 .61785 m .68492 .62074 L .67568 .63018 L p .35 .708 .985 r
F P
0 g
s
.42752 .3324 m .43493 .33918 L .39745 .32669 L p 0 .485 .812 r
F P
0 g
s
.39745 .32669 m .38703 .32248 L .42752 .3324 L p 0 .485 .812 r
F P
0 g
s
.5628 .52116 m .57572 .53354 L .58089 .54506 L p 0 .218 .738 r
F P
0 g
s
.57572 .53354 m .5628 .52116 L .55627 .50961 L p 0 .218 .736 r
F P
0 g
s
.66209 .62557 m .64839 .61865 L .6556 .61239 L p .253 .604 .953 r
F P
0 g
s
.64085 .60447 m .6556 .61239 L .64839 .61865 L p .166 .505 .911 r
F P
0 g
s
.6556 .61239 m .6703 .61785 L .66209 .62557 L p .253 .604 .953 r
F P
0 g
s
.56697 .51823 m .55627 .50961 L .54756 .49601 L p 0 .211 .731 r
F P
0 g
s
.54756 .49601 m .55527 .50024 L .56697 .51823 L p 0 .211 .731 r
F P
0 g
s
.54572 .47984 m .54149 .48093 L .52667 .46172 L p 0 .208 .73 r
F P
0 g
s
.52667 .46172 m .52707 .45635 L .54572 .47984 L p 0 .208 .73 r
F P
0 g
s
.55627 .50961 m .56697 .51823 L .57572 .53354 L p 0 .218 .736 r
F P
0 g
s
.33259 .31658 m .34381 .3161 L .30568 .33255 L p .403 .85 .763 r
F P
0 g
s
.30568 .33255 m .29216 .33763 L .33259 .31658 L p .403 .85 .763 r
F P
0 g
s
.7827 .5745 m .76934 .58698 L .76812 .55325 L p .916 .953 .803 r
F P
0 g
s
.76812 .55325 m .7817 .53818 L .7827 .5745 L p .916 .953 .803 r
F P
0 g
s
.61137 .58189 m .5967 .56771 L .59525 .55906 L p .051 .315 .8 r
F P
0 g
s
.58089 .54506 m .59525 .55906 L .5967 .56771 L p 0 .257 .764 r
F P
0 g
s
.49117 .38925 m .4947 .39831 L .46371 .37295 L p 0 .284 .784 r
F P
0 g
s
.46371 .37295 m .45663 .3635 L .49117 .38925 L p 0 .284 .784 r
F P
0 g
s
.52788 .44433 m .52747 .45058 L .50512 .42568 L p 0 .231 .748 r
F P
0 g
s
.50512 .42568 m .50168 .41653 L .52788 .44433 L p 0 .231 .748 r
F P
0 g
s
.59525 .55906 m .58089 .54506 L .57572 .53354 L p .021 .268 .768 r
F P
0 g
s
.85986 .43317 m .8471 .45067 L .82432 .40004 L p .922 .856 .76 r
F P
0 g
s
.82432 .40004 m .8366 .38074 L .85986 .43317 L p .922 .856 .76 r
F P
0 g
s
.42002 .32624 m .42752 .3324 L .38703 .32248 L p 0 .538 .813 r
F P
0 g
s
.38703 .32248 m .37647 .31941 L .42002 .32624 L p 0 .538 .813 r
F P
0 g
s
.22154 .37026 m .23602 .36355 L .20881 .41093 L p .831 .999 .827 r
F P
0 g
s
.20881 .41093 m .19318 .42214 L .22154 .37026 L p .831 .999 .827 r
F P
0 g
s
.56309 .50359 m .55527 .50024 L .54149 .48093 L p 0 .232 .743 r
F P
0 g
s
.54149 .48093 m .54572 .47984 L .56309 .50359 L p 0 .232 .743 r
F P
0 g
s
.76934 .58698 m .75577 .59793 L .75436 .56671 L p .896 .948 .832 r
F P
0 g
s
.75436 .56671 m .76812 .55325 L .76934 .58698 L p .896 .948 .832 r
F P
0 g
s
.48759 .38024 m .49117 .38925 L .45663 .3635 L p 0 .32 .805 r
F P
0 g
s
.45663 .3635 m .44948 .35471 L .48759 .38024 L p 0 .32 .805 r
F P
0 g
s
.62609 .59423 m .61137 .58189 L .60973 .57149 L p .128 .384 .839 r
F P
0 g
s
.59525 .55906 m .60973 .57149 L .61137 .58189 L p .051 .315 .8 r
F P
0 g
s
.55001 .47798 m .54572 .47984 L .52707 .45635 L p 0 .237 .747 r
F P
0 g
s
.52707 .45635 m .52747 .45058 L .55001 .47798 L p 0 .237 .747 r
F P
0 g
s
.32119 .3176 m .33259 .31658 L .29216 .33763 L p .461 .88 .767 r
F P
0 g
s
.29216 .33763 m .27842 .34349 L .32119 .3176 L p .461 .88 .767 r
F P
0 g
s
.57572 .53354 m .58882 .54475 L .59525 .55906 L p .021 .268 .768 r
F P
0 g
s
.58882 .54475 m .57572 .53354 L .56697 .51823 L p .033 .266 .764 r
F P
0 g
s
.8471 .45067 m .83427 .46862 L .81201 .41973 L p .923 .854 .756 r
F P
0 g
s
.81201 .41973 m .82432 .40004 L .8471 .45067 L p .923 .854 .756 r
F P
0 g
s
.52829 .43756 m .52788 .44433 L .50168 .41653 L p 0 .258 .765 r
F P
0 g
s
.50168 .41653 m .49821 .4074 L .52829 .43756 L p 0 .258 .765 r
F P
0 g
s
.57783 .52579 m .56697 .51823 L .55527 .50024 L p .023 .252 .755 r
F P
0 g
s
.55527 .50024 m .56309 .50359 L .57783 .52579 L p .023 .252 .755 r
F P
0 g
s
.41242 .32064 m .42002 .32624 L .37647 .31941 L p .034 .592 .813 r
F P
0 g
s
.37647 .31941 m .36575 .31739 L .41242 .32064 L p .034 .592 .813 r
F P
0 g
s
.56697 .51823 m .57783 .52579 L .58882 .54475 L p .033 .266 .764 r
F P
0 g
s
.75577 .59793 m .74198 .60704 L .7404 .57827 L p .869 .937 .863 r
F P
0 g
s
.7404 .57827 m .75436 .56671 L .75577 .59793 L p .869 .937 .863 r
F P
0 g
s
.60973 .57149 m .59525 .55906 L .58882 .54475 L p .098 .327 .801 r
F P
0 g
s
.64085 .60447 m .62609 .59423 L .62432 .58205 L p .218 .462 .879 r
F P
0 g
s
.60973 .57149 m .62432 .58205 L .62609 .59423 L p .128 .384 .839 r
F P
0 g
s
.48398 .37128 m .48759 .38024 L .44948 .35471 L p 0 .36 .827 r
F P
0 g
s
.44948 .35471 m .44224 .34661 L .48398 .37128 L p 0 .36 .827 r
F P
0 g
s
.83427 .46862 m .82135 .48669 L .79964 .43951 L p .921 .851 .756 r
F P
0 g
s
.79964 .43951 m .81201 .41973 L .83427 .46862 L p .921 .851 .756 r
F P
0 g
s
.74198 .60704 m .72799 .61406 L .72626 .58765 L p .83 .919 .895 r
F P
0 g
s
.72626 .58765 m .7404 .57827 L .74198 .60704 L p .83 .919 .895 r
F P
0 g
s
.57101 .50585 m .56309 .50359 L .54572 .47984 L p .054 .271 .764 r
F P
0 g
s
.54572 .47984 m .55001 .47798 L .57101 .50585 L p .054 .271 .764 r
F P
0 g
s
.55435 .4752 m .55001 .47798 L .52747 .45058 L p .042 .27 .766 r
F P
0 g
s
.52747 .45058 m .52788 .44433 L .55435 .4752 L p .042 .27 .766 r
F P
0 g
s
.52871 .43024 m .52829 .43756 L .49821 .4074 L p .02 .289 .785 r
F P
0 g
s
.49821 .4074 m .4947 .39831 L .52871 .43024 L p .02 .289 .785 r
F P
0 g
s
.6556 .61239 m .64085 .60447 L .63897 .59046 L p .318 .547 .915 r
F P
0 g
s
.62432 .58205 m .63897 .59046 L .64085 .60447 L p .218 .462 .879 r
F P
0 g
s
.30963 .319 m .32119 .3176 L .27842 .34349 L p .518 .909 .779 r
F P
0 g
s
.27842 .34349 m .26448 .34992 L .30963 .319 L p .518 .909 .779 r
F P
0 g
s
.40472 .31556 m .41242 .32064 L .36575 .31739 L p .091 .644 .814 r
F P
0 g
s
.36575 .31739 m .35487 .31633 L .40472 .31556 L p .091 .644 .814 r
F P
0 g
s
.58882 .54475 m .60205 .55447 L .60973 .57149 L p .098 .327 .801 r
F P
0 g
s
.60205 .55447 m .58882 .54475 L .57783 .52579 L p .112 .321 .792 r
F P
0 g
s
.72799 .61406 m .7138 .61878 L .71196 .59464 L p .777 .889 .925 r
F P
0 g
s
.71196 .59464 m .72626 .58765 L .72799 .61406 L p .777 .889 .925 r
F P
0 g
s
.48034 .36235 m .48398 .37128 L .44224 .34661 L p 0 .406 .851 r
F P
0 g
s
.44224 .34661 m .43493 .33918 L .48034 .36235 L p 0 .406 .851 r
F P
0 g
s
.62432 .58205 m .60973 .57149 L .60205 .55447 L p .187 .394 .833 r
F P
0 g
s
.6703 .61785 m .6556 .61239 L .65365 .59651 L p .423 .634 .943 r
F P
0 g
s
.63897 .59046 m .65365 .59651 L .6556 .61239 L p .318 .547 .915 r
F P
0 g
s
.82135 .48669 m .80829 .50455 L .78718 .45904 L p .917 .847 .759 r
F P
0 g
s
.78718 .45904 m .79964 .43951 L .82135 .48669 L p .917 .847 .759 r
F P
0 g
s
.58881 .53202 m .57783 .52579 L .56309 .50359 L p .096 .3 .779 r
F P
0 g
s
.56309 .50359 m .57101 .50585 L .58881 .53202 L p .096 .3 .779 r
F P
0 g
s
.7138 .61878 m .69943 .62104 L .69752 .59909 L p .708 .846 .948 r
F P
0 g
s
.69752 .59909 m .71196 .59464 L .7138 .61878 L p .708 .846 .948 r
F P
0 g
s
.57783 .52579 m .58881 .53202 L .60205 .55447 L p .112 .321 .792 r
F P
0 g
s
.68492 .62074 m .6703 .61785 L .66833 .60002 L p .527 .716 .959 r
F P
0 g
s
.65365 .59651 m .66833 .60002 L .6703 .61785 L p .423 .634 .943 r
F P
0 g
s
.69943 .62104 m .68492 .62074 L .68296 .60089 L p .624 .788 .96 r
F P
0 g
s
.68296 .60089 m .69752 .59909 L .69943 .62104 L p .624 .788 .96 r
F P
0 g
s
.66833 .60002 m .68296 .60089 L .68492 .62074 L p .527 .716 .959 r
F P
0 g
s
.52913 .42232 m .52871 .43024 L .4947 .39831 L p .058 .324 .806 r
F P
0 g
s
.4947 .39831 m .49117 .38925 L .52913 .42232 L p .058 .324 .806 r
F P
0 g
s
.55873 .47139 m .55435 .4752 L .52788 .44433 L p .095 .306 .784 r
F P
0 g
s
.52788 .44433 m .52829 .43756 L .55873 .47139 L p .095 .306 .784 r
F P
0 g
s
.80829 .50455 m .79508 .52183 L .77461 .47799 L p .91 .842 .766 r
F P
0 g
s
.77461 .47799 m .78718 .45904 L .80829 .50455 L p .91 .842 .766 r
F P
0 g
s
.57902 .50681 m .57101 .50585 L .55001 .47798 L p .12 .313 .784 r
F P
0 g
s
.55001 .47798 m .55435 .4752 L .57902 .50681 L p .12 .313 .784 r
F P
0 g
s
.39691 .3109 m .40472 .31556 L .35487 .31633 L p .155 .694 .818 r
F P
0 g
s
.35487 .31633 m .34381 .3161 L .39691 .3109 L p .155 .694 .818 r
F P
0 g
s
.2979 .32062 m .30963 .319 L .26448 .34992 L p .573 .936 .798 r
F P
0 g
s
.26448 .34992 m .25034 .35669 L .2979 .32062 L p .573 .936 .798 r
F P
0 g
s
.47665 .35346 m .48034 .36235 L .43493 .33918 L p .03 .456 .875 r
F P
0 g
s
.43493 .33918 m .42752 .3324 L .47665 .35346 L p .03 .456 .875 r
F P
0 g
s
.63897 .59046 m .62432 .58205 L .61541 .5624 L p .283 .464 .862 r
F P
0 g
s
.60205 .55447 m .61541 .5624 L .62432 .58205 L p .187 .394 .833 r
F P
0 g
s
.61541 .5624 m .60205 .55447 L .58881 .53202 L p .2 .38 .818 r
F P
0 g
s
.52956 .4138 m .52913 .42232 L .49117 .38925 L p .1 .361 .827 r
F P
0 g
s
.49117 .38925 m .48759 .38024 L .52956 .4138 L p .1 .361 .827 r
F P
0 g
s
.79508 .52183 m .7817 .53818 L .76191 .496 L p .899 .837 .776 r
F P
0 g
s
.76191 .496 m .77461 .47799 L .79508 .52183 L p .899 .837 .776 r
F P
0 g
s
.59992 .53666 m .58881 .53202 L .57101 .50585 L p .176 .351 .8 r
F P
0 g
s
.57101 .50585 m .57902 .50681 L .59992 .53666 L p .176 .351 .8 r
F P
0 g
s
.58881 .53202 m .59992 .53666 L .61541 .5624 L p .2 .38 .818 r
F P
0 g
s
.56316 .46646 m .55873 .47139 L .52829 .43756 L p .15 .343 .801 r
F P
0 g
s
.52829 .43756 m .52871 .43024 L .56316 .46646 L p .15 .343 .801 r
F P
0 g
s
.65365 .59651 m .63897 .59046 L .62886 .56827 L p .382 .533 .883 r
F P
0 g
s
.61541 .5624 m .62886 .56827 L .63897 .59046 L p .283 .464 .862 r
F P
0 g
s
.47293 .3446 m .47665 .35346 L .42752 .3324 L p .075 .509 .899 r
F P
0 g
s
.42752 .3324 m .42002 .32624 L .47293 .3446 L p .075 .509 .899 r
F P
0 g
s
.38899 .3066 m .39691 .3109 L .34381 .3161 L p .222 .743 .827 r
F P
0 g
s
.34381 .3161 m .33259 .31658 L .38899 .3066 L p .222 .743 .827 r
F P
0 g
s
.58711 .50629 m .57902 .50681 L .55435 .4752 L p .19 .356 .8 r
F P
0 g
s
.55435 .4752 m .55873 .47139 L .58711 .50629 L p .19 .356 .8 r
F P
0 g
s
.7817 .53818 m .76812 .55325 L .74908 .51276 L p .884 .83 .788 r
F P
0 g
s
.74908 .51276 m .76191 .496 L .7817 .53818 L p .884 .83 .788 r
F P
0 g
s
.28602 .32226 m .2979 .32062 L .25034 .35669 L p .625 .959 .821 r
F P
0 g
s
.25034 .35669 m .23602 .36355 L .28602 .32226 L p .625 .959 .821 r
F P
0 g
s
.62886 .56827 m .61541 .5624 L .59992 .53666 L p .292 .44 .838 r
F P
0 g
s
.52999 .40465 m .52956 .4138 L .48759 .38024 L p .144 .4 .848 r
F P
0 g
s
.48759 .38024 m .48398 .37128 L .52999 .40465 L p .144 .4 .848 r
F P
0 g
s
.66833 .60002 m .65365 .59651 L .64237 .57189 L p .478 .598 .894 r
F P
0 g
s
.62886 .56827 m .64237 .57189 L .65365 .59651 L p .382 .533 .883 r
F P
0 g
s
.76812 .55325 m .75436 .56671 L .7361 .52794 L p .864 .821 .804 r
F P
0 g
s
.7361 .52794 m .74908 .51276 L .76812 .55325 L p .864 .821 .804 r
F P
0 g
s
.56762 .46033 m .56316 .46646 L .52871 .43024 L p .207 .381 .817 r
F P
0 g
s
.52871 .43024 m .52913 .42232 L .56762 .46033 L p .207 .381 .817 r
F P
0 g
s
.46916 .33576 m .47293 .3446 L .42002 .32624 L p .126 .564 .922 r
F P
0 g
s
.42002 .32624 m .41242 .32064 L .46916 .33576 L p .126 .564 .922 r
F P
0 g
s
.61113 .53947 m .59992 .53666 L .57902 .50681 L p .258 .402 .817 r
F P
0 g
s
.57902 .50681 m .58711 .50629 L .61113 .53947 L p .258 .402 .817 r
F P
0 g
s
.59992 .53666 m .61113 .53947 L .62886 .56827 L p .292 .44 .838 r
F P
0 g
s
.68296 .60089 m .66833 .60002 L .65591 .57308 L p .566 .655 .896 r
F P
0 g
s
.64237 .57189 m .65591 .57308 L .66833 .60002 L p .478 .598 .894 r
F P
0 g
s
.75436 .56671 m .7404 .57827 L .72299 .54126 L p .838 .809 .822 r
F P
0 g
s
.72299 .54126 m .7361 .52794 L .75436 .56671 L p .838 .809 .822 r
F P
0 g
s
.38097 .30256 m .38899 .3066 L .33259 .31658 L p .293 .791 .841 r
F P
0 g
s
.33259 .31658 m .32119 .3176 L .38097 .30256 L p .293 .791 .841 r
F P
0 g
s
.53042 .39489 m .52999 .40465 L .48398 .37128 L p .192 .441 .868 r
F P
0 g
s
.48398 .37128 m .48034 .36235 L .53042 .39489 L p .192 .441 .868 r
F P
0 g
s
.59527 .50416 m .58711 .50629 L .55873 .47139 L p .26 .399 .813 r
F P
0 g
s
.55873 .47139 m .56316 .46646 L .59527 .50416 L p .26 .399 .813 r
F P
0 g
s
.64237 .57189 m .62886 .56827 L .61113 .53947 L p .382 .496 .85 r
F P
0 g
s
.27399 .32374 m .28602 .32226 L .23602 .36355 L p .672 .976 .847 r
F P
0 g
s
.23602 .36355 m .22154 .37026 L .27399 .32374 L p .672 .976 .847 r
F P
0 g
s
.69752 .59909 m .68296 .60089 L .66945 .57174 L p .644 .703 .889 r
F P
0 g
s
.65591 .57308 m .66945 .57174 L .68296 .60089 L p .566 .655 .896 r
F P
0 g
s
.7404 .57827 m .72626 .58765 L .70975 .55248 L p .805 .792 .84 r
F P
0 g
s
.70975 .55248 m .72299 .54126 L .7404 .57827 L p .805 .792 .84 r
F P
0 g
s
.8366 .38074 m .82432 .40004 L .7782 .35267 L p .866 .776 .76 r
F P
0 g
s
.7782 .35267 m .78901 .33274 L .8366 .38074 L p .866 .776 .76 r
F P
0 g
s
.71196 .59464 m .69752 .59909 L .68296 .56783 L p .709 .741 .876 r
F P
0 g
s
.66945 .57174 m .68296 .56783 L .69752 .59909 L p .644 .703 .889 r
F P
0 g
s
.72626 .58765 m .71196 .59464 L .6964 .56138 L p .762 .77 .859 r
F P
0 g
s
.6964 .56138 m .70975 .55248 L .72626 .58765 L p .762 .77 .859 r
F P
0 g
s
.68296 .56783 m .6964 .56138 L .71196 .59464 L p .709 .741 .876 r
F P
0 g
s
.57211 .45296 m .56762 .46033 L .52913 .42232 L p .263 .418 .829 r
F P
0 g
s
.52913 .42232 m .52956 .4138 L .57211 .45296 L p .263 .418 .829 r
F P
0 g
s
.46536 .32693 m .46916 .33576 L .41242 .32064 L p .183 .619 .943 r
F P
0 g
s
.41242 .32064 m .40472 .31556 L .46536 .32693 L p .183 .619 .943 r
F P
0 g
s
.82432 .40004 m .81201 .41973 L .7674 .3729 L p .864 .77 .756 r
F P
0 g
s
.7674 .3729 m .7782 .35267 L .82432 .40004 L p .864 .77 .756 r
F P
0 g
s
.62241 .54028 m .61113 .53947 L .58711 .50629 L p .338 .45 .828 r
F P
0 g
s
.58711 .50629 m .59527 .50416 L .62241 .54028 L p .338 .45 .828 r
F P
0 g
s
.61113 .53947 m .62241 .54028 L .64237 .57189 L p .382 .496 .85 r
F P
0 g
s
.53085 .38452 m .53042 .39489 L .48034 .36235 L p .242 .482 .887 r
F P
0 g
s
.48034 .36235 m .47665 .35346 L .53085 .38452 L p .242 .482 .887 r
F P
0 g
s
.65591 .57308 m .64237 .57189 L .62241 .54028 L p .466 .547 .855 r
F P
0 g
s
.37284 .29868 m .38097 .30256 L .32119 .3176 L p .364 .835 .859 r
F P
0 g
s
.32119 .3176 m .30963 .319 L .37284 .29868 L p .364 .835 .859 r
F P
0 g
s
.81201 .41973 m .79964 .43951 L .75658 .39316 L p .86 .763 .755 r
F P
0 g
s
.75658 .39316 m .7674 .3729 L .81201 .41973 L p .86 .763 .755 r
F P
0 g
s
.60349 .5003 m .59527 .50416 L .56316 .46646 L p .327 .438 .822 r
F P
0 g
s
.56316 .46646 m .56762 .46033 L .60349 .5003 L p .327 .438 .822 r
F P
0 g
s
.57664 .44433 m .57211 .45296 L .52956 .4138 L p .318 .453 .839 r
F P
0 g
s
.52956 .4138 m .52999 .40465 L .57664 .44433 L p .318 .453 .839 r
F P
0 g
s
.79964 .43951 m .78718 .45904 L .74572 .41314 L p .853 .757 .756 r
F P
0 g
s
.74572 .41314 m .75658 .39316 L .79964 .43951 L p .853 .757 .756 r
F P
0 g
s
.46151 .31809 m .46536 .32693 L .40472 .31556 L p .244 .672 .961 r
F P
0 g
s
.40472 .31556 m .39691 .3109 L .46151 .31809 L p .244 .672 .961 r
F P
0 g
s
.66945 .57174 m .65591 .57308 L .63374 .53894 L p .541 .59 .852 r
F P
0 g
s
.62241 .54028 m .63374 .53894 L .65591 .57308 L p .466 .547 .855 r
F P
0 g
s
.63374 .53894 m .62241 .54028 L .59527 .50416 L p .414 .493 .832 r
F P
0 g
s
.53129 .37357 m .53085 .38452 L .47665 .35346 L p .292 .523 .904 r
F P
0 g
s
.47665 .35346 m .47293 .3446 L .53129 .37357 L p .292 .523 .904 r
F P
0 g
s
.59527 .50416 m .60349 .5003 L .63374 .53894 L p .414 .493 .832 r
F P
0 g
s
.78718 .45904 m .77461 .47799 L .7348 .43256 L p .844 .75 .76 r
F P
0 g
s
.7348 .43256 m .74572 .41314 L .78718 .45904 L p .844 .75 .76 r
F P
0 g
s
.61175 .49464 m .60349 .5003 L .56762 .46033 L p .39 .474 .826 r
F P
0 g
s
.56762 .46033 m .57211 .45296 L .61175 .49464 L p .39 .474 .826 r
F P
0 g
s
.3646 .29487 m .37284 .29868 L .30963 .319 L p .435 .874 .881 r
F P
0 g
s
.30963 .319 m .2979 .32062 L .3646 .29487 L p .435 .874 .881 r
F P
0 g
s
.68296 .56783 m .66945 .57174 L .64511 .53536 L p .606 .626 .845 r
F P
0 g
s
.63374 .53894 m .64511 .53536 L .66945 .57174 L p .541 .59 .852 r
F P
0 g
s
.77461 .47799 m .76191 .496 L .72382 .4511 L p .831 .742 .765 r
F P
0 g
s
.72382 .4511 m .7348 .43256 L .77461 .47799 L p .831 .742 .765 r
F P
0 g
s
.58119 .43445 m .57664 .44433 L .52999 .40465 L p .371 .486 .847 r
F P
0 g
s
.52999 .40465 m .53042 .39489 L .58119 .43445 L p .371 .486 .847 r
F P
0 g
s
.45763 .30922 m .46151 .31809 L .39691 .3109 L p .307 .722 .975 r
F P
0 g
s
.39691 .3109 m .38899 .3066 L .45763 .30922 L p .307 .722 .975 r
F P
0 g
s
.6964 .56138 m .68296 .56783 L .65648 .5295 L p .66 .655 .834 r
F P
0 g
s
.64511 .53536 m .65648 .5295 L .68296 .56783 L p .606 .626 .845 r
F P
0 g
s
.64511 .53536 m .63374 .53894 L .60349 .5003 L p .481 .53 .831 r
F P
0 g
s
.76191 .496 m .74908 .51276 L .71276 .46848 L p .816 .733 .773 r
F P
0 g
s
.71276 .46848 m .72382 .4511 L .76191 .496 L p .816 .733 .773 r
F P
0 g
s
.53173 .36208 m .53129 .37357 L .47293 .3446 L p .342 .563 .919 r
F P
0 g
s
.47293 .3446 m .46916 .33576 L .53173 .36208 L p .342 .563 .919 r
F P
0 g
s
.60349 .5003 m .61175 .49464 L .64511 .53536 L p .481 .53 .831 r
F P
0 g
s
.74908 .51276 m .7361 .52794 L .70163 .48442 L p .796 .723 .783 r
F P
0 g
s
.70163 .48442 m .71276 .46848 L .74908 .51276 L p .796 .723 .783 r
F P
0 g
s
.70975 .55248 m .6964 .56138 L .66783 .52137 L p .705 .678 .821 r
F P
0 g
s
.65648 .5295 m .66783 .52137 L .6964 .56138 L p .66 .655 .834 r
F P
0 g
s
.62004 .48715 m .61175 .49464 L .57211 .45296 L p .448 .506 .826 r
F P
0 g
s
.57211 .45296 m .57664 .44433 L .62004 .48715 L p .448 .506 .826 r
F P
0 g
s
.7361 .52794 m .72299 .54126 L .69042 .49869 L p .772 .711 .795 r
F P
0 g
s
.69042 .49869 m .70163 .48442 L .7361 .52794 L p .772 .711 .795 r
F P
0 g
s
.72299 .54126 m .70975 .55248 L .67916 .51106 L p .742 .696 .808 r
F P
0 g
s
.66783 .52137 m .67916 .51106 L .70975 .55248 L p .705 .678 .821 r
F P
0 g
s
.67916 .51106 m .69042 .49869 L .72299 .54126 L p .742 .696 .808 r
F P
0 g
s
.58575 .42334 m .58119 .43445 L .53042 .39489 L p .419 .517 .851 r
F P
0 g
s
.53042 .39489 m .53085 .38452 L .58575 .42334 L p .419 .517 .851 r
F P
0 g
s
.35626 .29101 m .3646 .29487 L .2979 .32062 L p .503 .907 .904 r
F P
0 g
s
.2979 .32062 m .28602 .32226 L .35626 .29101 L p .503 .907 .904 r
F P
0 g
s
.65648 .5295 m .64511 .53536 L .61175 .49464 L p .54 .562 .826 r
F P
0 g
s
.4537 .30032 m .45763 .30922 L .38899 .3066 L p .37 .766 .986 r
F P
0 g
s
.38899 .3066 m .38097 .30256 L .4537 .30032 L p .37 .766 .986 r
F P
0 g
s
.53218 .35008 m .53173 .36208 L .46916 .33576 L p .391 .6 .93 r
F P
0 g
s
.46916 .33576 m .46536 .32693 L .53218 .35008 L p .391 .6 .93 r
F P
0 g
s
.61175 .49464 m .62004 .48715 L .65648 .5295 L p .54 .562 .826 r
F P
0 g
s
.62834 .47783 m .62004 .48715 L .57664 .44433 L p .498 .534 .824 r
F P
0 g
s
.57664 .44433 m .58119 .43445 L .62834 .47783 L p .498 .534 .824 r
F P
0 g
s
.66783 .52137 m .65648 .5295 L .62004 .48715 L p .591 .588 .818 r
F P
0 g
s
.59034 .41107 m .58575 .42334 L .53085 .38452 L p .464 .545 .854 r
F P
0 g
s
.53085 .38452 m .53129 .37357 L .59034 .41107 L p .464 .545 .854 r
F P
0 g
s
.62004 .48715 m .62834 .47783 L .66783 .52137 L p .591 .588 .818 r
F P
0 g
s
.34782 .287 m .35626 .29101 L .28602 .32226 L p .566 .932 .925 r
F P
0 g
s
.28602 .32226 m .27399 .32374 L .34782 .287 L p .566 .932 .925 r
F P
0 g
s
.53263 .33764 m .53218 .35008 L .46536 .32693 L p .438 .635 .939 r
F P
0 g
s
.46536 .32693 m .46151 .31809 L .53263 .33764 L p .438 .635 .939 r
F P
0 g
s
.67916 .51106 m .66783 .52137 L .62834 .47783 L p .633 .61 .809 r
F P
0 g
s
.44972 .29136 m .4537 .30032 L .38097 .30256 L p .431 .803 .994 r
F P
0 g
s
.38097 .30256 m .37284 .29868 L .44972 .29136 L p .431 .803 .994 r
F P
0 g
s
.63666 .46676 m .62834 .47783 L .58119 .43445 L p .543 .558 .82 r
F P
0 g
s
.58119 .43445 m .58575 .42334 L .63666 .46676 L p .543 .558 .82 r
F P
0 g
s
.78901 .33274 m .7782 .35267 L .71099 .31287 L p .808 .722 .77 r
F P
0 g
s
.71099 .31287 m .71927 .29362 L .78901 .33274 L p .808 .722 .77 r
F P
0 g
s
.69042 .49869 m .67916 .51106 L .63666 .46676 L p .669 .628 .8 r
F P
0 g
s
.62834 .47783 m .63666 .46676 L .67916 .51106 L p .633 .61 .809 r
F P
0 g
s
.59494 .39771 m .59034 .41107 L .53129 .37357 L p .505 .57 .855 r
F P
0 g
s
.53129 .37357 m .53173 .36208 L .59494 .39771 L p .505 .57 .855 r
F P
0 g
s
.7782 .35267 m .7674 .3729 L .70275 .33229 L p .803 .713 .766 r
F P
0 g
s
.70275 .33229 m .71099 .31287 L .7782 .35267 L p .803 .713 .766 r
F P
0 g
s
.7674 .3729 m .75658 .39316 L .69452 .35167 L p .796 .705 .764 r
F P
0 g
s
.69452 .35167 m .70275 .33229 L .7674 .3729 L p .796 .705 .764 r
F P
0 g
s
.70163 .48442 m .69042 .49869 L .64496 .45401 L p .699 .644 .791 r
F P
0 g
s
.63666 .46676 m .64496 .45401 L .69042 .49869 L p .669 .628 .8 r
F P
0 g
s
.75658 .39316 m .74572 .41314 L .68629 .37078 L p .787 .696 .765 r
F P
0 g
s
.68629 .37078 m .69452 .35167 L .75658 .39316 L p .787 .696 .765 r
F P
0 g
s
.74572 .41314 m .7348 .43256 L .67806 .38936 L p .775 .687 .767 r
F P
0 g
s
.67806 .38936 m .68629 .37078 L .74572 .41314 L p .775 .687 .767 r
F P
0 g
s
.71276 .46848 m .70163 .48442 L .65326 .43972 L p .723 .657 .783 r
F P
0 g
s
.64496 .45401 m .65326 .43972 L .70163 .48442 L p .699 .644 .791 r
F P
0 g
s
.53308 .3248 m .53263 .33764 L .46151 .31809 L p .483 .667 .944 r
F P
0 g
s
.46151 .31809 m .45763 .30922 L .53308 .3248 L p .483 .667 .944 r
F P
0 g
s
.64496 .45401 m .63666 .46676 L .58575 .42334 L p .581 .579 .815 r
F P
0 g
s
.58575 .42334 m .59034 .41107 L .64496 .45401 L p .581 .579 .815 r
F P
0 g
s
.7348 .43256 m .72382 .4511 L .66981 .4072 L p .761 .678 .77 r
F P
0 g
s
.66981 .4072 m .67806 .38936 L .7348 .43256 L p .761 .678 .77 r
F P
0 g
s
.72382 .4511 m .71276 .46848 L .66155 .42405 L p .744 .668 .776 r
F P
0 g
s
.65326 .43972 m .66155 .42405 L .71276 .46848 L p .723 .657 .783 r
F P
0 g
s
.66155 .42405 m .66981 .4072 L .72382 .4511 L p .744 .668 .776 r
F P
0 g
s
.59955 .38339 m .59494 .39771 L .53173 .36208 L p .541 .593 .855 r
F P
0 g
s
.53173 .36208 m .53218 .35008 L .59955 .38339 L p .541 .593 .855 r
F P
0 g
s
.44571 .28232 m .44972 .29136 L .37284 .29868 L p .488 .833 .997 r
F P
0 g
s
.37284 .29868 m .3646 .29487 L .44571 .28232 L p .488 .833 .997 r
F P
0 g
s
.65326 .43972 m .64496 .45401 L .59034 .41107 L p .615 .597 .81 r
F P
0 g
s
.59034 .41107 m .59494 .39771 L .65326 .43972 L p .615 .597 .81 r
F P
0 g
s
.53353 .31164 m .53308 .3248 L .45763 .30922 L p .523 .694 .947 r
F P
0 g
s
.45763 .30922 m .4537 .30032 L .53353 .31164 L p .523 .694 .947 r
F P
0 g
s
.60418 .36821 m .59955 .38339 L .53218 .35008 L p .574 .614 .855 r
F P
0 g
s
.53218 .35008 m .53263 .33764 L .60418 .36821 L p .574 .614 .855 r
F P
0 g
s
.66155 .42405 m .65326 .43972 L .59494 .39771 L p .643 .613 .805 r
F P
0 g
s
.59494 .39771 m .59955 .38339 L .66155 .42405 L p .643 .613 .805 r
F P
0 g
s
.44165 .27318 m .44571 .28232 L .3646 .29487 L p .54 .854 .997 r
F P
0 g
s
.3646 .29487 m .35626 .29101 L .44165 .27318 L p .54 .854 .997 r
F P
0 g
s
.66981 .4072 m .66155 .42405 L .59955 .38339 L p .667 .628 .8 r
F P
0 g
s
.60881 .35231 m .60418 .36821 L .53263 .33764 L p .603 .633 .854 r
F P
0 g
s
.53263 .33764 m .53308 .3248 L .60881 .35231 L p .603 .633 .854 r
F P
0 g
s
.67806 .38936 m .66981 .4072 L .60418 .36821 L p .688 .641 .797 r
F P
0 g
s
.59955 .38339 m .60418 .36821 L .66981 .4072 L p .667 .628 .8 r
F P
0 g
s
.53399 .29823 m .53353 .31164 L .4537 .30032 L p .56 .718 .947 r
F P
0 g
s
.4537 .30032 m .44972 .29136 L .53399 .29823 L p .56 .718 .947 r
F P
0 g
s
.68629 .37078 m .67806 .38936 L .60881 .35231 L p .706 .653 .794 r
F P
0 g
s
.60418 .36821 m .60881 .35231 L .67806 .38936 L p .688 .641 .797 r
F P
0 g
s
.69452 .35167 m .68629 .37078 L .61346 .33585 L p .721 .664 .793 r
F P
0 g
s
.60881 .35231 m .61346 .33585 L .68629 .37078 L p .706 .653 .794 r
F P
0 g
s
.70275 .33229 m .69452 .35167 L .61813 .31897 L p .733 .675 .794 r
F P
0 g
s
.61346 .33585 m .61813 .31897 L .69452 .35167 L p .721 .664 .793 r
F P
0 g
s
.43754 .26392 m .44165 .27318 L .35626 .29101 L p .586 .869 .994 r
F P
0 g
s
.35626 .29101 m .34782 .287 L .43754 .26392 L p .586 .869 .994 r
F P
0 g
s
.61346 .33585 m .60881 .35231 L .53308 .3248 L p .628 .65 .853 r
F P
0 g
s
.53308 .3248 m .53353 .31164 L .61346 .33585 L p .628 .65 .853 r
F P
0 g
s
.71099 .31287 m .70275 .33229 L .62281 .30184 L p .744 .686 .795 r
F P
0 g
s
.61813 .31897 m .62281 .30184 L .70275 .33229 L p .733 .675 .794 r
F P
0 g
s
.71927 .29362 m .71099 .31287 L .62752 .28461 L p .752 .697 .799 r
F P
0 g
s
.62281 .30184 m .62752 .28461 L .71099 .31287 L p .744 .686 .795 r
F P
0 g
s
.53445 .28462 m .53399 .29823 L .44972 .29136 L p .592 .738 .945 r
F P
0 g
s
.44972 .29136 m .44571 .28232 L .53445 .28462 L p .592 .738 .945 r
F P
0 g
s
.62752 .28461 m .63227 .26744 L .71927 .29362 L p .752 .697 .799 r
F P
0 g
s
.61813 .31897 m .61346 .33585 L .53353 .31164 L p .65 .666 .852 r
F P
0 g
s
.53353 .31164 m .53399 .29823 L .61813 .31897 L p .65 .666 .852 r
F P
0 g
s
.53492 .2709 m .53445 .28462 L .44571 .28232 L p .62 .755 .942 r
F P
0 g
s
.44571 .28232 m .44165 .27318 L .53492 .2709 L p .62 .755 .942 r
F P
0 g
s
.62281 .30184 m .61813 .31897 L .53399 .29823 L p .669 .68 .852 r
F P
0 g
s
.53399 .29823 m .53445 .28462 L .62281 .30184 L p .669 .68 .852 r
F P
0 g
s
.62752 .28461 m .62281 .30184 L .53445 .28462 L p .685 .694 .853 r
F P
0 g
s
.53539 .25714 m .53492 .2709 L .44165 .27318 L p .645 .768 .938 r
F P
0 g
s
.44165 .27318 m .43754 .26392 L .53539 .25714 L p .645 .768 .938 r
F P
0 g
s
.53445 .28462 m .53492 .2709 L .62752 .28461 L p .685 .694 .853 r
F P
0 g
s
.63227 .26744 m .62752 .28461 L .53492 .2709 L p .699 .707 .854 r
F P
0 g
s
.53492 .2709 m .53539 .25714 L .63227 .26744 L p .699 .707 .854 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojG4l003o`00
0?nb]=[o/[CJ00?o/[CJ2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?nUa?000ol0003o/[CJ
ok:dfP0>ok:dfP_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nFg_h00ol0003oYLC`ojG4
l00MojG4l003o`000?nb]=[o/[CJ01Wo/[CJ1ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001onFg_h00ol0003oYLC`ojG4l00=ojG4l13o00007onb]=X00ol0003o`;;<ol2bc003
o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l00008oiKNoP?o00000_nUa?0=o`00
00ooW/7a00Co0000ojnaf_n_/M[o[k7J1_l0000Eok:dfP03o`000?o0//co`;;<00Co`;;<0ol0000=
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?ooool002cooooo0ol00006oooo
o`03o`000?oooooooooo06Gooooo1?l00007oiKNoPGo00000_n:f_l00ol0003oW/7aoik1l@0Loik1
l@03o`000?n_/M[o[k7J00Oo[k7J1_l0000?ok:dfP03o`000?o0//co`;;<00Oo`;;<0ol0000:oooo
o`03o`000?oooooooooo03;ooooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo063ooooo1?l00006oiKNoPGo00002?n:f_l00ol0003oW/7aoik1l@0Koik1l@03
o`000?n_/M[o[k7J00go[k7J1_l00009ok:dfP03o`000?o0//co`;;<00[o`;;<0ol00007ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool0017ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Looooo`?o00001_nFg_h4o`0000[oR][o1?l00003oik1
l@co00003_nN`O400ol0003o[k7JojnafP0CojnafPKo00000_nb]=X00ol0003o`;;<ol2bc00>ol2b
c0?o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo1?l00005oiKNoPCo00001on:f_l7o`00
00?oO=Go00?o0000oiNllOnG_?403OnG_?4?o`0001_o[k7J0ol0000Col2bc0?o00000_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo0009ooooo`Ko00000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000oooo
ooooool0Doooool4o`0000GoU]kn0_l00006oh[Jo`Ko00002omleOl00ol0003oUkcaoiNll@0JoiNl
l@03o`000?n[[][oZjkJ00Go00005_n_/MX00ol0003o_Zo;okj_b`03o`00017o`;;<0ol0000foooo
o`03o`000?oooooooooo02Wooooo000Aooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool2o`00
00?oT>k/0_l000000onFg_ko0000oh[Jo`04oh[Jo`Go00003_mleOl5o`0000KoUkca00?o0000oiNl
lOnG_?404_nG_?400ol0003oZjkJoj^^fP05oj^^fPGo00004On_/MX00ol0003o_Zo;okj_b`03okj_
b`?o00004?o0//`4o`0003Cooooo00?o0000ooooooooool0:?ooool0017ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04gooooo0_l00003oi3^k0;o00000on0j>L2o`000003oh[Jool0003o
O=Go00_oO=Go2Ol00004ofk=oP03o`000?n?]o;oSkOb00GoSkOb3Ol00006oiNll@03o`000?n[[][o
ZjkJ00_oZjkJ1Ol0000<ojnafP03o`000?nn[l_o_Zo;00Ko_Zo;0ol0000=ol2bc004o`000?o0//co
`;;<ol2bc0?o0000<Oooool2o`0002Wooooo000Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_oo
ool2o`0000;oT>k/0ol00002oh3Xi`?o00000om_gn400ol0003oO=GoogcEo`04ogcEo`Ko00003_m^
cOh00ol0003oSkObohnglP0AohnglPOo00004_n[[]X5o`0000Ko[k7J00?o0000okj_bonn[l/02_nn
[l/3o`0000[o`;;<00?o0000ol2bc?o0//`00_o0//`01?l0003oc[S5o`000?l0000_ooooo`;o0000
:Oooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
0_l0000@ooooo`03o`000?oooooooooo04Oooooo0_l00002oi3^k0;o00000on0j>L2o`0000GoKmoQ
0ol000000omleOoo0000o`00000:ofk=oPgo00006On?]o800ol0003oYZ[JojJZfP04o`00017oZjkJ
1Ol000000on_/M[o0000okj_b`0>okj_b`?o00001oo0//`01Ol0003o`;;<ol2bc?o0//co000000Co
c[S500?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Vooooo`004Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo0_l00015ooooo`;o
00000_n@k^`2o`0000;oP>SW0ol00004ofoOh@?o00000_mMeM/3o`0000;oK/gn2Ol0000<oek4o004
o`000?n5/O;oQK7bohFalPOo00003on?]o800ol0003oYZ[JojJZfP04ojJZfPCo00004_n[[]X2o`00
01;o_Zo;0ol00003ol2bc0;o00000oo0//`00ol0003oc[S5oljha@03oljha@;o0000;_ooool00ol0
003oooooooooo`0Vooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo043o
oooo0_l000001?n@k^co0000o`000?l00002oh3Xi`;o00000om_gn44o`000003oegEfol0003o0000
00;o00000_m;b]L4o`0000CoG/Cl1ol0000:oek4o003o`000?n5/O;oQK7b00OoQK7b1_l00009ohng
lP03o`000?nVZ][oYZ[J00SoYZ[J1?l0000?oj^^fP03o`000?nk[<_o000000;o00004Onn[l/3o`00
0003ol2bc?l0003o`;;<00;o`;;<00?o0000oljhaOo>^<D01Oo>^<D2o`0002gooooo00?o0000oooo
ooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l000000on@k^co
0000o`000003oh3Xi`;o00000_m_gn43o`0000;oGMGK2Ol00004ocRnd`03o`000?m>^?WoC[Si00So
C[Si2ol0000?ohFalPOo00000_n?]o800ol0003oYZ[JojJZfP0<ojJZfPCo00002_n[[]X00ol0003o
^jc;ok^/b`03ok^/b`?o00002onn[l/3o`0000?o_Zo;0ol000000oo0//co0000oljha@09oljha@;o
0000;?ooool00ol0003oooooooooo`0Tooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo03[ooooo0_l000000on@k^co0000o`000003oh3Xi`;o000000CoKmoQo`000?l0003o
00000_mMeM/5o`0000Co>;kC2Ol0000Codjhn@04o`000?mkZ_7oNj[aog^Zl@Go00003_n5/O83o`00
01;oYZ[J1?l00006oj^^fP03o`000?nk[<_o^jc;00Ko^jc;0_l00006okj_b`?o00002Onn[l/3o`00
00_oc[S50_l0000Zooooo`;o00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0gooooo`;o00000_n@k^`01_l0003oP>SWoh3Xion0j>Oo0000ofoOh@;o00000omMeM/4
o`0000;o>;kC1_l00002obNad@[o00000oln[?H;o`0000?oC[Si00?o0000og^ZlOmkZ_401OmkZ_45
o`0000_oQK7b00?o0000oj2Vf_nPY]X00ol0000AojJZfPCo00000_n[[]X00ol0003o^jc;ok^/b`08
ok^/b`Ko00003Onn[l/01?l0003ocKK4o`000?l0000;oljha@03o`000?oooooooooo02Oooooo0_l0
0008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@07ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo
0_l00002oi3^k0CoP>SW1ol00002ofOI``;o000000GoF=74o`000?l0003o0000odS8a`04o`0000Ko
5jC@0_l00006oaNTd003o`000?l^W_7o000000Co00001_ln[?H5o`0000_oNj[a1Ol00006ohFalP03
o`000?nPY][oX:KJ00?oX:KJ0ol0000BojJZfP;o00002onk[</5o`0000go_Zo;0_l00003olffa003
o`000?o>^<Goc[S500Woc[S50_l0000Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`00:_ooool2o`0001Wo
oooo00?o0000ooooooooool0<Oooool:o`0000;oQ>S70ol00002ofOI``Wo000000Co>Kk<o`000?l0
003o00000_lY/]4>o`0000Go;Yka1Ol00005ocj/mP03o`000?m`X_3oL:;`00Co00002_mkZ_45o`00
0003ohFal_l0003oX:KJ00OoX:KJ1?l0000?ojJZfP04o`000?nhZL_o0000o`0000Go^jc;0ol00005
ok^/b`?o00002_nn[l/00ol0003ocKK4o`000003olffa0;o00002oo>^<D2o`0002Oooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Ooo
ool002Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`Co00000onOmM80
1?l0003oT^o<o`000?l00002ohCXa`;o000000?oImW3o`000?l000001ol000000oli_/co0000o`00
0002o`000004obVbdOl0003o0000o`0000;o6ZGF0ol000001?lJYMKo0000o`000?l0RM06o`000003
ob2@k?l0003o000000Ko;Yka1Ol000000oln[?Ko0000og2Rl004og2Rl0Co00002omkZ_42o`0000co
X:KJ0ol0000<ojJZfP04o`000?nhZL_o^:W;okRYb`Go00002onk[</3o`0000Ko_Zo;00Go0000olff
a?o=]/CocKK4o`000004olffa0;o00002oo>^<D2o`0002Kooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool002Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0/ooooo`04o`000?n/nMSo[?WHo`0000?oWoGB00?o
0000oi;_c?l000000_n4j<L2o`0000;oImW30ol000001OnSmmgo0000oiObiOnGl^Go000000CoQn[]
00?o0000ogGNm?meg_@00_l00004of3=n0;o000000?o2iGIo`000?l000000_l000001Ol0O<oo0000
o`000?l0003o08W@00;o00000olPT>`4o`0000Ko;Yka0_l00009og2Rl0?o00002OmkZ_401?l0003o
VZ;Jo`000?l0000<oj2VfPCo00002?nVZ]X00ol0003o^:W;okRYb`03o`000003okRYbol0003o0000
00ko^jc;0_l00004okj_b`03o`000?o=]/CocKK400;ocKK400?o0000olffa?o=]/@00oo=]/@00ol0
003oc[S5oljha@0:oljha@03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3
o`0001cooooo00?o0000ooooooooool0:_ooool01?l0003o[?WHojcif?l00002oioedPCo000000Go
Q>S7o`000?l0003o0000ofOI``02o`000004ojkje_l0003oXoOMo`0000;oUo;U00Co0000ohOZkOn7
j^goQn[]0_l00002ogGNm004o`000?mPcOSoH<ghof3=n0?o00000om9^?P6o`0000;o07c?1_l00004
ob2@k0Co00000ol^W_400ol0003oI9W^ofBIkP02o`0000SoL:;`1?l00005og^Zl@03o`000?nJX][o
VZ;J00;oVZ;J0ol0000<oj2VfP?o00001?nVZ]X4o`0000Ko^:W;0_l0000>ok^/b`?o000000?o_Zo;
o`000?o=]/@00oo=]/@00ol0003ocKK4olffa004olffa0;o00002oo>^<D2o`0002Cooooo00?o0000
ooooooooool00oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02Ooo
ool002Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`04o`000?n/nMSo
[?WHo`0000;oWoGB00Co0000oi;_c?l0003oQ>S71Ol00003ojkjeP03o`000?nSmmgo000000;oUo;U
00Co0000ohOZkOn7j^goQn[]2ol00004odVhn0?o00000_l0Q=X2o`0000;o06k>1?l00002oa>2iP?o
00001?lPT>`3o`000003objNlOl0003oI9W^00?oI9W^0ol00008og2Rl0Co000000?oNj[ao`000?nJ
X]X01_nJX]X3o`0000coX:KJ1Ol0000;okRYb`?o00003_nk[</2o`0000GocKK400?o0000olffa?o=
]/@01Oo=]/@2o`0000_oc[S500?o0000ooooooooool08?ooool3o`0000Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool09_ooool01?l0003o[?WHojcif?l00002oioedP?o000000CoQ>S7o`00
0?l0003o00000_ngo=801_l0003o[_[Fojkje_l0003oXoOMo`0000;oUo;U00?o0000ohOZkOl00000
0ol00002okSYmP03o`000?nUg__oYMkk00;oYMkk00?o0000ohk=oOn>cOd01?l00004oc>OlPGo0000
0ol0K/h3o`0000?o4h;V0ol00004ob2@k0;o00001omTVNh3o`0000WoL:;`0_l0000:oiZRfP?o0000
2?nPY]X3o`000003oj2Vf_l0003o000000ko^:W;0_l0000<ok^/b`03o`000?o;]<?o000000GocKK4
00?o0000olffa?o=]/@01_o=]/@00ol0003oc[S5oljha@08oljha@;o00008oooool00ol0003ooooo
ooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Sooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00Go0000ojci
f?n/nMSo0000oioedP03o`0000;oQ>S700?o0000okkmcol000000_ngo=801Ol0003o[_[Fojkje_l0
003oXoOM00Ko00000_o6lNl01Ol0003o^>WfokSYm_nhjOKo000000CoYMkk00Co0000ohk=oOn>cOgo
S/gm0_mc^?/3o`0000;o<iob0ol000001?l0LmOo0000o`000?l0HL`3o`000003o`1^c_l0003o1gCO
00;o00000_lCP^H3o`0000;o893/00Co0000oeN@jol0003o00001omTVNh3o`0000OoL:;`00Co0000
oi:Mf_l0003o00002_nJX]X2o`0000?oX:KJ0ol00005oj2VfP04o`000?ndYl_o0000o`0000go^:W;
0_l00009ok^/b`04o`000?o;]<?obkC3ol^d``;o00001?o=]/@00ol0003ocKK4olffa006olffa0;o
00001oo>^<D01?l0003ogLK2omg6`_l0000Sooooo`03o`000?oooooooooo01kooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Qooooo`03o`000?oooooooooo02;ooooo00Oo0000
ojcif?n/nMSo0000oioed_l0003oT^o<00?o00000_nnoLl01?l0003o]ocBokOld_l00002ojkjePCo
00000_oAmNL00ol0003oa_7_olKak`02olKak`05o`000?nhjOKo^>WfokSYm_l000001?nUg_/01Ol0
003oS/gmohk=oOn>cOgo000000CoLkSk0_l00004oan7jPCo00000_l0HL`3o`0000;o1gCO0ol00002
oa>2iPCo00000omGT>/3o`0000KoI9W^0ol00004og2Rl003o`000?nBWM[oTYgJ00;oTYgJ0_l00009
oiZRfP?o00001onPY]X00ol0003o]:O;okBWb`02okBWb`;o00003OnhZL/2o`0000Oo^jc;00?o0000
ol^d`oo;]<<00oo;]<<2o`0000;ocKK400?o0000olffa?o=]/@02?o=]/@2o`0000Goc[S500Go0000
omg6`_oMa/;ogLK2o`00000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00002ojcif0;oWoGB00So
0000oi;_c?l0003o0000olGnc_l0003o__g?o`0000;o]ocB00?o0000ojkje_n^n]H00_l000000ooI
mn3o0000om7ei`02om7ei`03o`000?o6lNooa_7_00;oa_7_00Co0000okSYm_nhjOKo00001?nUg_/0
1Ol0003oS/gmohk=oOn>cOgo000000GoLkSk0_mHXOD2o`0000?o7hOZ00?o0000o`1Sd_l0Hm801?l0
00001?l0HLco0000o`1WfOl00002o`Mdg`;o00000olCP^H00ol0003oEi3[oeN@j`04oeN@j`;o0000
1omTVNh3o`000003og2Rl?l0003oTYgJ00GoTYgJ0_l00005oiZRfP?o00000_nJX]X3o`0000CoX:KJ
00?o0000okBWbondYl/01?ndYl/2o`0000go^:W;0ol00003ok^/b`03o`000?o;]<?obkC300KobkC3
00Co0000olffa?o=]/Co00002oo=]/@01Ol0003oc[S5oljhaOo>^<Go000000GogLK200?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Mooooo`001_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool07Oooool01?l0003o[?WHojcif?n/nMP2oioedP;o00000oo5o/h0
1_l0003o__g?okkmcol0003o]ocBo`0000;o[_[F00Go0000omWgh?oImn3ofOOPo`000003om7ei`05
o`000?o6lNooa_7_olKakol000000onhjOH00ol0003oYMkkojGNn`02ojGNn`05o`000?n>cOgoS/gm
ohk=oOl000001?mc^?/00ol0003oF:7eoeRQm@02oeRQm@Go000000Go06?Bo`000?l0Hm;o0000o`1F
b@03o`0000;o06OI0_l000001ol7M=oo0000o`000?lCP^Ko0000odZ5iol000001_mGT>/3o`0000Oo
I9W^0_l00008oi:MfPGo00002?nJX]X3o`000003oj2Vf_l0003o]:O;00Oo]:O;0_l0000>okRYb`;o
000000?o^jc;o`000?o;]<<02?o;]<<2o`000003olffa?l0003ocKK400[ocKK40_l000000oo>^<Go
0000omg6`P05omg6`P03o`000?oooooooooo023ooooo0_l0000Mooooo`001_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool09?ooool2o`0001cooooo00Co0000ojcif?n/nMSo[?WH0_nOmM80
0ol0003oboo>o`000002olGncP07o`000?nnoLoo__g?o`000?ngo=;o0000ojkjeP02o`0000?ofOOP
00Go0000om7eiooAmNOodOGWo`000004olKak`03o`000?nhjOKo^>Wf00go00000_mc^?/00ol0003o
F:7eoeRQm@02oeRQm@;o?HS[00Co0000o`iah?l>LN3o3W7P2?l000001?l0G=?o0000o`1WfOl0ImT5
o`0000;oBXGW0ol00005oeN@j`;o00001_mTVNh00ol0003oRYOJo`000005oi:MfP?o000000?oTYgJ
o`000?l000002onJX]X00ol0003o]:O;okBWb`09okBWb`?o00003OnhZL/2o`0000_obkC30ol0000<
olffa003o`000?oMa/;ogLK200KogLK200?o0000ooooooooool07_ooool00ol0003oooooo`00000M
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`04o`000?n/nMSo
[?WHojcif0;oWoGB0_o;olh01?l0003oaOk>olGnc_l00002okkmc`03o`000?ngo=;o000000;o0000
00?og_SJo`000?oImn000_oImn001Ol0003odOGWom7eiooAmNOo000000Coa_7_0ol000000oo7dn?o
0000okW<j@03okW<j@CoYl;]0onB]>h5o`000003oeRQmOl0003o?HS[00;o?HS[00Go0000o`iah?l>
LN3o3W7Po`000002o`1Dc@06o`000?l0BlKo0000o`1FbOl0003o05cC0_l00002o`1Wf@;o000000?o
1gCOo`000?m:QNL00om:QNL2o`0000GoEi3[0ol00003ofBIkP04o`000?n:Um[oRYOJohZGfPCo0000
1_nBWMX3o`0000SoVZ;J00?o0000ok2Tc?l000003?ndYl/2o`0000_o^:W;00?o0000olVb`ol00000
3?o;]<<00ol0003ocKK4olffa00:olffa003o`000?oMa/;ogLK200OogLK200?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Fooooo`04o`000?n/nMSo[?WHojcif0;o00000_o;olh01_l0
003oaOk>olGnc_o5o/ko0000okkmc`?o00001?oNn=X01Ol0003ofOOPomWgh?oImn3o000000?odOGW
00?o0000olKakoo6lNl00ol00004olOCh`05o`000?nic>Wo^LcYokW<jOl000000onW`^d01?l0003o
T[C^oi:dk_nB]>h4ogVSk@?o00000olmR>/7o`000005o`12`_l0BlKo0000o`000?l0DLh00_l0G=<2
o`0000;o06OI0_l000000olmNn?o0000odZ5i`03odZ5i`;o00001_mGT>/4o`000005ohZGf_l0003o
0000o`000?n:UmX00_l00009oi:MfP;o00001_nJX]X01?l0003o/:C<ok2Tc?n`Y<`2o`0000_o]:O;
0_l00008okRYb`04o`000?o9//?obK;3olVb``;o00002oo;]<<2o`0000WocKK400?o0000omg5`Ol0
00002OoMa/800ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool01ol0003o[?WHojcif?n/nMSo
0000om3od?l000000_o;olh01?l0003oaOk>olGnc_l00002okkmc`03o`000?oSn=Co000000Cog_SJ
00Go0000omWgh?oImn3ofOOPo`000002om7ei`Co00000_oAf=h00ol0003oam?SolOCh`02olOCh`03
o`000?nic>Wo^LcY00;o^LcY00Go0000ojO2kOnW`^goYl;]o`000003oi:dkPCoNJ?]0_mMSnP00ol0
003o?HS[ocf8j`02obEah004o`000?l0GMGo0000o`18a`;o000000Ko04;2o`000?l0BlKo0000o`1A
c_l00002o`1Ld`;o00000_l0ImT01?l0003o?G_Socekhol00004odZ5i`;o00001_mGT>/3o`0000Ko
RYOJ0_l00009oi:MfP;o00000onJX]X00ol0003o/:C<ok2Tc004ok2Tc0;o00002ondYl/2o`0000Ko
^:W;00?o0000olVb`oo9//<00oo9//<00ol0003obkC3ol^d``09ol^d``;o00002?o=]/@01?l0003o
gLG1omg5`Ol00009omg6`P03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool002Oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`04o`000?n/nMSo0000o`00
00;od?o@00Co0000ol_oc_o;olko00000_o5o/h01?l0003o__g?okkmcol00002on?he003o`000?oN
n=[og_SJ00;og_SJ00Co0000omWgh?oImn3ofOOP0ol000000ooIfmSo0000om7HgP03om7HgP03o`00
0?o7dn?oam?S00;oam?S00?o0000okW<jOnic>T00_nic>T01Ol0003oYl;]ojO2kOnW`^go000000?o
T[C^00Go0000ogVSkOmiXngoNJ?]o`000003oef?j0;o00000_lULN000ol0003o05gEo`000002o`18
a`03o`000?l0@/;o000000;o00000_l0DLh01ol0003o05cCo`1Ldol0003o06OIo`000?laL=h00_lm
Nn<2o`0000CoBXGW0_l000002?mGT>_o0000o`000?l0003oEi3[o`000?n1TM[o00001on:UmX2o`00
00WoTYgJ1?l00008ok2Tc0;o00002ondYl/2o`0000?o^:W;00?o0000olVb`oo9//<01Oo9//<2o`00
00WobkC300Co0000ol^d`ol0003o00001Oo=]/@00ol0003ogLG1omg5`@02omg5`@03o`000?oMa/;o
gLK200OogLK200?o0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`009oooool2o`00
02cooooo00?o0000ooooooooool04?ooool3o`000005omCodol0003od?o@om3od?l000000_o;olh0
0ol0003oaOk>olGncP03o`0000?ohoSD00Go0000omkhf_oNn=[og_SJo`000003omWgh0;o00000ooI
fmP00ol0003odMSNom7HgP03om7HgP03o`000?o7dn?oam?S00;oam?S00Go0000okW<jOnic>Wo^LcY
o`000003ojO2k@05o`000?nB]>koT[C^oi:dk_l000000omiXnd01?l0003oGHoXoef?j?mMSnP2od9j
h@03o`000?lULN3o9G7P00?o00000_l0B<L01Ol0003o04;2o`12`_l0003o04S800;o057>0_l00000
1_l0G=?o0000o`000?l0003o<G3No`0000;o?G_S0_l00002odZ5i`Go00000_mGT>/01Ol0003oPI7J
oh6Af_n1TM[o000000OoRYOJ0_l0000:oi:MfP03o`000?n`Y<co/:C<00So/:C<0_l0000;okBWb`;o
000000?o^:W;o`000?o9//<02?o9//<00ol0003obkC3ol^d``07ol^d``03o`000?o;]<?obkC300;o
00000_o=]/@00ol0003ogLG1omg5`@04omg5`@03o`000?oMa/;ogLK200OogLK200?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00kooooo00Go0000omCodooDom?oe?oCo`000002om3od004o`000?o;olkoboo>o`00
00;oaOk>0_l000000ooVn=7o0000on?he002on?he005o`000?oNn=[og_SJomkhf_l000000_oImn02
o`0000GofM_H00?o0000om7Hg_oAf=h00_oAf=h00ol0003oam?SolOCh`02olOCh`03o`000?nic>Wo
^LcY00;o^LcY00Go0000ojO2kOnW`^goYl;]o`000003oi:dkP05o`000?miXngoNJ?]ogVSkOl00000
0_mMSnP00ol0003o@W[Qod9jh@02obEah0;o4EcE0ol000001ol0B<Oo0000o`12`_l0@/;o0000o`18
b?l000000_l0DLh01?l0003o05cCo`1Ldol00003oc5`gP03o`000?lmNn?o000000;o00001Om:QNL3
o`0000CoPI7J0_l00007ohZGfP;o00002?nBWMX00ol0003oZZ3<o`00000:ok2Tc003o`000?ndYl_o
]:O;00[o]:O;0_l0000:olVb``;o00002?o;]<<01ol0003obkC3ol^d`oo;]<?o0000olffa?l00000
1ooMaL400ol0003ogLK2omg6`P07omg6`P03o`000?oooooooooo01cooooo0_l0000Jooooo`009ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00Co0000omCodooDom?o0000
0_o@om001?l0003oboo>ol_oc_l00002olGncP05o`000?oVn=7oi_SAonKhdOl000000ooSn=@02Ol0
003og_SJomkhf_oNn=[o0000omWgh?l0003ogmgCo`000005omWKf003o`000?oAf=kodMSN00;odMSN
00?o0000olOChoo7dn<00_o7dn<01?l0003o^LcYokW<jOnic>T<o`000003ogVSkOl0003oGHoX00;o
GHoX00?o0000od9jhOm2N^400_l00002oa5Le@03o`1=c?l0003o000000Go000000Co04S8o`000?l0
003o057>0ol000000olTI]Wo<G3No`000003o`000003ocekhol0003o000000KoBXGW00?o0000oh6A
f_n1TMX01?n1TMX2o`0000OoRYOJ0_l00005oi:MfP04o`000?nZX<coZZ3<ojZPc0;o00002On`Y<`2
o`0000[o]:O;00?o0000olJ_a?l000002oo9//<00ol0003obkC3ol^d``06ol^d``05o`000?o;]<?o
bkC3ol^d`ol000002OoMaL400ol0003ogLK2omg6`P07omg6`P03o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool002Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;
ooooo`05o`000?oDom?oe?oComCodol000000_o@om000ol0003oboo>ol_ocP03o`0000Coi_SA00Co
0000on?he?oSn=Co00001?oNn=X2o`0000?ogmgC00?o0000omWKf?oIfmP00_oIfmP00ol0003odMSN
om7HgP02om7HgP03o`000?o7dn?oam?S00?oam?S0ol000000onf]mWo0000ojR_g@02ojR_g@04o`00
0?nGY^3oUjKPoiNVh0?oPY[Q1?l000001?mMSnSo0000od9jhOm2N^42obQVf005o`000?lAG=Go4EcE
o`1=c?l000000_l0?/401?l0003o03^oo`000?l00002o`18b003o`000?l0DLko057>00Co00000ola
L=h00ol0003o?G_Socekh`02o`0000CoBXGW00?o0000ogJ;f_n1TMX01_n1TMX00ol0003oRYOJohZG
fP06ohZGfP;o00000onBWMX00ol0003oZZ3<ojZPc003ojZPc0;o00002On`Y<`2o`0000Oo]:O;00Co
0000olJ_a?o6[lCoaZo40_l0000:olVb``;o00001_o;]<<01?l0003obkC3ol^d`oo;]<<2o`0000Wo
gLG100?o0000omg6`_oMa/801ooMa/800ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Ko
oooo000Wooooo`;o0000<?ooool00ol0003oooooooooo`0:ooooo`04o`000?oDom?oe?oCo`0000;o
d?o@00?o0000ol_oc_o;olh00_l000000ooXmloo0000onKhd@02onKhd@05o`000?oSn=CohoSDon?h
e?l000000ooNn=X2o`0000CogmgC00?o0000omWKf?oIfmP00ooIfmP01Ol0003odMSNom7Hg_oAf=ko
000000Coam?S0_l00004okJgf@05o`000?nX[mgoZ:oMojR_gOl000000onGY^03oh:Jh@03o`000?mZ
Rn3oJX_P00?o00000_m2N^42obQVf0?o4EcE0_l000000ol0?/7o0000o`0d^`02o`0k_`Go000000Co
057>o`000?lTI]Wo96KI0_l00002oc5`gP05o`000?lmNn?o?G_Socekhol000000om:QNL00ol0003o
MX_JogJ;fP02o`0000GoPI7J0_l00008ohZGfP;o000000?oTYgJo`000?nZX<`01_nZX<`00ol0003o
/:C<ok2Tc008ok2Tc0;o00001OndYl/00ol0003oaZo4olJ_a003olJ_a003o`000?o9//?obK;300Wo
bK;300?o0000ol^d`oo;]<<01?o;]<<00ol0003obkC3o`000002omc3`@03o`000?oMaL7ogLG100Oo
gLG100?o0000omg6`_oMa/801ooMa/800ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Ko
oooo000Vooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool01Ol0003oe?oC
omCodooDom?o000000;od?o@00Co0000ol_oc_o;olko00000_oXmll01Ol0003oi_SAonKhdOoVn=7o
000000?ohoSD00Ko0000omkhf_oNn=[o0000on?Ncol00004omoMd`03o`000?oIfmSofM_H00?ofM_H
00?o0000om7Hg_oAf=h00_oAf=h4o`000003ol6leOl0003o][OI00?o][OI00Go0000ojR_gOnX[mgo
Z:oMo`000004oiNVh0?oPY[Q00?o0000ofZ;h?mZRn000_m@N]`00ol0003o@W[Qo`000002obQVf0;o
4EcE00?o0000o`10`ol000000_l000000ol0=;_o0000o`000003o`000004o`18b?l0003o0000oaUL
d`?o96KI00?o0000oc5`g_laL=h00_l00002ocekh`?o00001OmfRmX2o`0000GoPI7J0_l00008ohZG
fP03o`000?nZX<coZZ3<00OoZZ3<0_l0000:ok2Tc0;o00000ondYl/00ol0003oaZo4olJ_a004olJ_
a003o`000?o9//?obK;300WobK;30_l00005ol^d``;o00000ooL`l400ol0003ogLG1omg5`@07omg5
`@03o`000?oMa/;ogLK200OogLK200?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eoooo
o`009_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Co0000omCodooD
om?o00000_o@om001?l0003oboo>ol_oc_l00003onSgc`05o`000?oVn=7oi_SAonKhdOl000000ooS
n=@00ol0003og_SJo`000002on?Nc`03o`000?oOgM?ogmgC00?ogmgC00?o0000omWKf?oIfmP00_oI
fmP01?l0003odMSNom7Hg_oAf=h2o`0000Go`KcE00?o0000okJgfOnf]mT00_nf]mT01Ol0003oZ:oM
ojR_gOnX[mgo000000?oUjKP00Co0000oh:JhOn2V^7o00000omZRn03oe1jg008o`000?lXI]So:6KH
obQVf?l0003o04_:o`000?l0@<<6o`000004o`0j_ol0@<?o0000o`18b0;o000000Co6EcCo`000?lT
I]Wo96KI0_l00002oc5`gP05o`000?lmNn?o?G_Socekhol000001omfRmX00ol0003oPI7Joh6AfP04
oh6AfP03o`000?n:Um[oRYOJ00GoRYOJ00?o0000ojBLc_nZX<`02OnZX<`2o`0000[o/:C<0ol00008
olJ_a0;o00002oo9//<00ol0003obkC3ol^d``02ol^d``;o00001?oL`l400ol0003ogLG1omg5`@07
omg5`@03o`000?oMa/;ogLK200KogLK200?o0000ooooooooool07?ooool2o`0001Kooooo000Voooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool01?l0003oe?oComCodol00003
om3od0?o00000ooXmll00ol0003oi_SAonKhd@02onKhd@04o`000?oSn=CohoSDon?he0;o00001?oS
g/l00ol0003ogmgComoMd`02omoMd`03o`000?oIfmSofM_H00?ofM_H0ol000000oo9_m7o0000ol6l
e@04ol6le@03o`000?nf]mWo][OI00;o][OI00?o0000ojR_gOnX[md00_nX[md01Ol0003oUjKPoiNV
h?nGY^3o000000;oPY[Q00Co0000ofZ;h?mZRn3o00000om@N]`01?l0003o:6KHobQVf?lBDlh5o`00
0003o`0f_?l0003o03Bk00;o000000?o03Zoo`10`ol000000_l00002oaULd`05o`000?lTI]Wo96KI
obAVfOl000000_laL=h2o`000003ocekhol0003oJhCI00OoMX_J0_l00005oh6AfP;o00001?n:UmX0
1?l0003oY9c>ojBLc_nTW<h2o`0000WoZZ3<00?o0000ok2Tc?n`Y<`02On`Y<`2o`0000WoaZo400?o
0000olVb`oo9//<02Oo9//<2o`0000;obkC30_l00005omc3`@03o`000?oMaL7ogLG100OogLG100?o
0000omg6`_oMa/801?oMa/800ol0003ok=_2o`00000Nooooo`03o`000?oooooooooo01Cooooo000V
ooooo`?o0000=?ooool00ol0003oooooooooo`04ooooo`04o`000?oDom?oe?oCo`0000;od?o@0_l0
00000ooYm/ko0000onSgc`02onSgc`03o`000?oVn=7oi_SA00;oi_SA00?o0000on?he?oSn=@00_l0
0005on?Nc`03o`000?oOgM?ogmgC00;ogmgC00?o0000omWKf?oIfmP00ooIfmP00ol0003obKoAolVo
d@02olVod@03o`000?o1_=Go`KcE00?o`KcE00?o0000okJgfOnf]mT00_nf]mT01Ol0003oZ:oMojR_
gOnX[mgo000000?oUjKP00Co0000oh:JhOn2V^7o00000omZRn000ol0003oD7[Loe1jg002ocIWePCo
000000So04_:o`10`ol0@<?o0000o`0f_?l0003o03Bko`0000;o03Zo00Co0000o`10`ol0003o3U;>
0_lIG=<2o`0000;o96KI00Co0000oc5`g_laL=ko<G3N0_l00002of^4f@03o`000?mfRm[oMX_J00Go
MX_J00?o0000oh6Af_n1TMX01?n1TMX2o`0000;oRYOJ00?o0000ojBLc_nTW<h00onTW<h00ol0003o
ZZ3<ojZPc007ojZPc0;o00002On`Y<`00ol0003o`Zg5o`000009olJ_a0;o00002oo9//<01Ol0003o
bkC3o`000?oL`l7o000000Gog<?100?o0000omg5`OoMaL401ooMaL400ol0003ogLK2omg6`P02omg6
`P04o`000?o/fl;ok=_2o`0001oooooo00?o0000ooooooooool04oooool002Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`02ooooo`04o`000?oDom?oe?oCo`0000;od?o@0_l00002
onWfcP05o`000?oXmlooj?O?onSgcol000001?oVn=401Ol0003ohoSDo`000?oVg/co000000Gohmk?
00?o0000omoMdooOgM<00ooOgM<01?l0003ofM_HomWKf?oIfmP2o`0000GobKoA00?o0000ol6leOo1
_=D00_o1_=D00ol0003o][OIokJgf@02okJgf@03o`000?nX[mgoZ:oM00;oZ:oM00Go0000oiNVh?nG
Y^3oUjKPo`000002oh:Jh@04o`000?mZRn3oJX_PofZ;h0Co000000Co=VOFobQVf?l0003o4U?>0_l0
BlX5o`000008o`0d^ol0003o03Zoo`0j_ol0003o0433o`000?l>D/h3oaULd`03o`000?lTI]Wo96KI
00;o00000_laL=h01?l0003oJhCIof^4fOm[Q=T2o`0000KoMX_J0_l00006oh6AfP03o`000?n:Um[o
000000KoY9c>00?o0000ojZPc?nZX<`02?nZX<`00ol0003o/:C<ok2Tc005ok2Tc005o`000?o2[LGo
`Zg5ol:]aOl000002_o6[l@00ol0003obK;3olVb``09olVb``05o`000?oL`l7og<?1omc3`Ol00000
1OoL`l400ol0003ogLG1omg5`@07omg5`@05o`000?oMa/;ogLK2omg6`_l000000_o/fl800ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000?oe?oC00Co0000om3o
d?o@om3o00000ooYm/h01Ol0003oj?O?onSgcooXmloo000000?oi_SA00?o0000on?he?l000000ooV
g/`00ol0003ohmk?on?Nc`02on?Nc`03o`000?oOgM?ogmgC00?ogmgC00Co0000omWKf?oIfmSo0000
0_o@`/d00ol0003obKoAolVod@02olVod@03o`000?o1_=Go`KcE00?o`KcE00?o0000okJgfOnf]mT0
0_nf]mT01Ol0003oZ:oMojR_gOnX[mgo000000;oUjKP1Ol000001?mZRn3o0000o`000?l00002oe1j
g003o`000?lfImKo=VOF00;o000000Ko4U?>o`000?l0003o03Jlo`000?l0<;P3o`000008o`0d^ol0
>[oo03Zoo`000?l0@<?o0000o`iBc_l00002oaULd`08o`000?lTI]Wo96KIobAVfOl0003o<G3No`00
0?mNO=P4of^4f@03o`000?mfRm[oMX_J00GoMX_J00?o0000oh6Af_n1TMX01?n1TMX00ol0003oY9c>
ojBLcP06ojBLcP;o00002OnZX<`2o`0000Go/:C<00?o0000ol:]aOo2[LD00_o2[LD00ol0003oaZo4
olJ_a008olJ_a0;o00002Oo9//<00ol0003og<?1omc3`@02omc3`@03o`000?oL`l7og<?100?og<?1
00?o0000omg5`OoMaL401ooMaL400ol0003ogLK2o`000004oncK`P03o`000?oooooooooo01gooooo
00?o0000ooooooooool04_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`00
0?oooooooooo03Sooooo0ol00002omCod`04o`000?o@om3o0000o`0000?ojOK>00?o0000onSgcooX
mll00_oXmll01?l0003oi_SAonKhdOoVn=42o`0000Coi]k<00?o0000on?NcooSg/l00ooSg/l00ol0
003ogmgComoMd`02omoMd`03o`000?oIfmSo000000?od<;=00?o0000olVodOo9_m400oo9_m400ol0
003o`KcEol6le@02ol6le@03o`000?nf]mWo][OI00;o][OI00?o0000ojR_gOnX[md01?l00002ohnG
e`03ogf=f?l0003o000000Ko000000?oD7[Lo`000?lfImH00_lME/h01olBDlko04?4o`000?l0003o
03Jlo`000?l0<;P00ol000000ol0=;_o0000o`0j_`03o`000004o`iBc_l0003o6EcCoaULd`;o0000
0_lTI]T2o`0000;oGWcH00Co0000of^4fOm[Q=WoJhCI0_l00006ogJ;fP;o00001?n1TMX00ol0003o
WIS?ojBLcP08ojBLcP03o`000?nZX<coZZ3<00SoZZ3<0_l00002ok2Tc003o`000?o2[LGo`Zg500Co
`Zg500?o0000olJ_a?o6[l@02Oo6[l@00ol0003obK;3olVb``05olVb``03o`000?oJ`L7o000000?o
g<?100?o0000omc3`OoL`l401?oL`l400ol0003ogLG1omg5`@07omg5`@03o`000?o/fl;ok=_200?o
k=_200?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`Co000000?o410@oooooooo
ool00oooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`?o0000>Oooool00ol0003o
e?oComCod`03o`000003onWdcOl0003ojOK>00;ojOK>00?o0000onSgcooXmll00_oXmll00ol0003o
i_SAonKhd@02o`0000Goi]k<00?o0000on?NcooSg/l00ooSg/l00ol0003ogmgComoMd`02omoMd`;o
00001Oo@`/d00ol0003obKoAolVod@03olVod@03o`000?o1_=Go`KcE00;o`KcE00Co0000okJgfOnf
]mWo][OI0ol00002oijOe003o`000?n?UmOo000000;o00000_mmSMP01?l0003oJ87HofR1f?mXPMP2
oe5ceP;o00000_lfImH2oaeFcP07oa9Cc_l0@lCo0000o`000?l0=[co0000o`0`^002o`0000;o03Bk
00?o0000o`0j_ol000000_l000000ol>D/ko0000o`000002oaULd`04o`000?lTI]Wo96KIo`0000?o
GWcH0_l00003of^4f@03o`000?mfRm[oMX_J00GoMX_J0_l00002oh6AfP03o`000?nMV<ooWIS?00;o
00001onTW<h2o`0000[oZZ3<00?o0000ok2Tc?l000001oo2[LD2o`0000[oaZo400?o0000olVb`oo9
//<00oo9//<01Ol0003of/71om[1`OoJ`L7o000000?og<?100?o0000omc3`OoL`l401?oL`l400ol0
003ogLG1omg5`@06omg5`@03o`000?o/fl;ok=_200Cok=_200?o0000ooooooooool07?ooool3o`00
00[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo03Wooooo00Co0000omCodooDom?o00000ooYm<d01Ol0003ojOK>onWfc_oY
m/ko000000Coj?O?00Go0000onKhdOl0003oj=o9o`000006onKNc003o`000?oSg/oohmk?00;ohmk?
00Oo0000omoMdooOgM?ogmgCo`000?oEa<Wo000000Kod<;=00?o0000olVodOo9_m400_o9_m400ol0
003o`KcEol6le@02ol6le@06o`000?nf]mWo0000o`000?n[YM7o00000_nNWm@3o`0000CoSiOG0_mm
SMP01?l0003oJ87HofR1f?mXPMP3oe5ceP03o`000?lfImKo000000;o7EK>00?o0000o`13a?l0?L40
0_l0=[`4o`0000;o03Bk00Go0000o`0j_ol0003o1DW8o`000002o`iBcP07o`000?lIG=?o6EcCo`00
0?lTI]Wo0000oe5ceP04oeilf005o`000?m[Q=WoJhCIof^4fOl000002?mfRmX2o`0000GoWIS?00?o
0000ojBLc_nTW<h01_nTW<h00ol0003oZZ3<ojZPc008ojZPc0;o00002Oo2[LD00ol0003oaZo4olJ_
a008olJ_a0;o00000oo9//<00ol0003of/71om[1`@02om[1`@05o`000?oL`l7og<?1omc3`Ol00000
1_oL`l400ol0003ogLG1omg5`@04omg5`@03o`000?o/f/7o000000Gok=_200?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0hooooo`04o`000?oDom?o0000o`0000Co
jOC=00Go0000onWfc_oYm/kojOK>o`000003onSgc`03o`000?oVn=7o000000;oj=o900?o0000onKN
c?oVg/`01?oVg/`00ol0003ohmk?on?Nc`02on?Nc`04o`000?oOgM?ogmgCo`0000?oeLC900?o0000
om32cOo@`/d00oo@`/d00ol0003obKoAolVod@03olVod@03o`000?o1_=Go`KcE00;o`KcE00Co0000
oj^UdOn[YM7oZjGA0ol00003oijOe005o`000?n?UmOoSiOGohnGeol000000_mmSMP01?l0003oJ87H
ofR1f?l00002oe5ceP;o>6?A00Oo0000oaeFc_lME/ko24K5o`000?l0@lCo03g100Go000000?o032h
o`0d^ol0=;/00ol000001Ol5BLSo0000o`iBc_l>D/ko000000;o6EcC0_l00002oe5ceP05o`000?mN
O=SoGWcHoeilf?l000000om[Q=T2o`0000OoMX_J00?o0000oifHconMV<l01?nMV<l00ol0003oY9c>
ojBLcP06ojBLcP;o00002?nZX<`00ol0003o_Z_6o`000009ol:]a@03o`000?o6[lCoaZo400WoaZo4
00?o0000olVb`ol000001_oJ`L401Ol0003og<?1omc3`OoL`l7o000000Kog<?100?o0000omg5`OoM
aL400_oMaL401?l0003ok=[1oncJ`Ol00006oncK`P03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`006oooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool0>?ooool2o`000003onWcc_l0003ojOC=00?ojOC=00Go0000onWf
c_oYm/kojOK>o`000003onSgc`;o00001?oXglT00ol0003oi]k<onKNc003onKNc003o`000?oSg/oo
hmk?00?ohmk?0_l00004omG4b@03o`000?o@`/god<;=00Cod<;=00?o0000olVodOo9_m400_o9_m40
1?l0003o`KcEol6leOo1_=D5o`0000;oZjGA00Go0000oijOe?nNWmCoWYoDo`000004ohnGe`03o`00
0?mmSMSo000000?oJ87H00?o0000oe5ce_mALmH00_lhHm401?l0003o7EK>oaeFc_l8A/D2o`13a003
o`000?l0;kOo000000?o000000?o032ho`000?l0=;/00ol000001Ol5BLSo0000o`iBc_l>D/ko0000
00;o6EcC00Go0000oe5ce_mALmKoDG?Fo`000003oeilf0;o00000om[Q=T00ol0003oMX_JogJ;fP04
ogJ;fP03o`000?nDU=3oWIS?00GoWIS?0_l00008ojBLcP03o`000?nZX<coZZ3<00CoZZ3<00Go0000
okj[a_nnZlKo_Z_6o`000009ol:]a@03o`000?o6[lCoaZo400WoaZo400?o0000om[1`OoJ`L401_oJ
`L401?l0003og<?1omc3`Ol00007omc3`@05o`000?oMaL7ogLG1omg5`Ol000000oo/f/400ol0003o
k=_2oncK`P03oncK`P03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000hooooo`;o
00000_oYllh01Ol0003ojOC=onWdcOoYm<go000000CojOK>00Go0000onSgcooXmlooj?O?o`000005
onSOb@03o`000?oVg/coi]k<00Coi]k<00?o0000on?NcooSg/l00_oSg/l00ol0003oeLC9omG4b@04
omG4b@03o`000?o@`/god<;=00?od<;=00?o0000olVodOo9_m400oo9_m400ol0003o`KcEo`000003
o`0000GoZjGA00Go0000oijOe?nNWmCoWYoDo`000003ohnGe`04o`000?mmSMSoOHgHo`0000?oJ87H
00[o0000oe5ce_l0003o>6?Ao`000?lPE<_o7EK>o`000?l8A/Go04?40_l000003Ol0;kOo0000o`00
0?l0;;Go0000o`0`^?l0003o03Bko`000?l0@/?o0000o`E9b?l000000_l>D/h01?l0003o6EcCo`00
0?m3Jm@3oe5ceP03o`000?mNO=SoGWcH00;oGWcH00Co0000of^4fOm[Q=WoJhCI0_l00003ogJ;fP05
o`000?nDU=3oU9C@oiBDd?l000001_nMV<l00ol0003oY9c>ojBLcP06ojBLcP03o`000?nZX<coZZ3<
00?oZZ3<00?o0000okj[a_nnZlH00_nnZlH00ol0003o`Zg5ol:]a@07ol:]a@03o`000?o6[lCoaZo4
00SoaZo400?o0000om[1`OoJ`L401ooJ`L401?l0003og<?1omc3`Ol00007omc3`@03o`000?oMaL7o
000000Cok=[100?o0000oncK`_o/fl800oo/fl800ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo03Oooooo00Go0000onWcc_oYllkojO?>o`000003onWdc@03o`000?oY
m/kojOK>00;ojOK>00?o0000onSgcooXmll00_l00005onSOb@03o`000?oVg/coi]k<00Coi]k<00Co
0000on?NcooSg/oohmk?0_l00007omG4b@03o`000?o@`/god<;=00?od<;=00Co0000olVodOo9_m7o
bKoA0ol00004okBYc@03o`000?n[YM7oZjGA00;oZjGA00?o0000oijOe?nNWm@00_nNWm@01Ol0003o
SiOGohnGeon?UmOo000000;oOHgH00Co0000ofR1f?mXPMSo00000_mALmH01Ol0003o>6?Ao`000?lP
E<_o000000;o24K50ol000000ol0;kOo0000o`000002o`000003o`0`^?l0003o000000;o04;300?o
0000o`E9b?l000000_l>D/h2o`0000;o@f_D0omALmH00ol0003oGWcHoeilf002oeilf003o`000?m[
Q=WoJhCI00;oJhCI00Co0000ogJ;f_mfRm[o00001?nDU=000ol0003oWIS?oifHc`04oifHc`;o0000
1onTW<h2o`0000;oZZ3<00?o0000okj[a_nnZlH01?nnZlH00ol0003o`Zg5ol:]a@07ol:]a@;o0000
1oo6[l@00ol0003of;o2o`000009om[1`@04o`000?oL`l7og<?1o`0000Oog<?100?o0000oncJ`Oo/
f/400oo/f/400ol0003ok=_2oncK`P04oncK`P03o`000?oooooooooo01kooooo0_l00007ooooo`03
o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000onWcc_oYllh0
0_oYllh01Ol0003ojOC=onWdcOoYm<go000000?ojOK>00Co0000onSgcooXmloo00000_oYglP00ol0
003oj=o9onSOb@03onSOb@03o`000?oVg/coi]k<00?oi]k<00Co0000on?NcooSg/oo00000_oIa/L0
0ol0003oeLC9omG4b@04omG4b@03o`000?o@`/god<;=00Cod<;=1?l000000onl[L[o0000okBYc@04
okBYc@03o`000?n[YM7oZjGA00;oZjGA00Go0000oijOe?nNWmCoWYoDo`000004ohnGe`03o`000?mm
SMSo000000?oJ87H00Go0000oe5ce_l0003o>6?Ao`000002ob1Db`06o`000?l8A/Go0000o`0f_?l0
<k[o02ng0_l000001?l0:K?o0000o`000?l0<;P2o`0000;o04;300?o0000o`E9b?l000000_l>D/h0
1Ol0003o@f_Dod=[e?m3JmCo000000;oDG?F0_l00003oeilf003o`000?m[Q=WoJhCI00;oJhCI00?o
0000ogJ;f_l000001OnDU=000ol0003oWIS?oifHc`05oifHc`03o`000?nTW<koY9c>00KoY9c>00?o
0000ojZPc?l000001onnZlH2o`0000Wo`Zg500?o0000olJ_a?o6[l@01?o6[l@01?l0003of;o2omRo
`_l00009om[1`@04o`000?oL`l7og<?1o`0000Kog<?100?o0000oncJ`Oo/f/401?o/f/400ol0003o
k=_2oncK`P03oncK`P03o`000?oooooooooo01gooooo00?o0000ooooool000001Oooool00omEEEGo
IVIVo`000007ooooo`009?ooool00ol0003oooooooooo`0gooooo`05o`000?oYllkojO?>onWcc_l0
00001?oYm<d01ol0003ojOK>onWfc_oYm/ko0000onSgcol000000ooYglP00ol0003oj=o9onSOb@03
onSOb@03o`000?oVg/coi]k<00Coi]k<0_l00004omW6a`03o`000?oEa<WoeLC900CoeLC900Co0000
om32cOo@`/god<;=0ol000000oo9_m7o0000okb]bP02okb]bP03o`000?ndZLgo]:W=00;o]:W=00?o
0000oj^UdOn[YM400on[YM401Ol0003oWYoDoijOe?nNWmCo000000?oSiOG00Co0000ogf=f?mmSMSo
00000_mXPMP01ol0003oDG?Foe5ce_l0003o>6?Ao`000?lPE</00_l:AL@01?l8A/Go0000o`0f_?l0
<kX3o`000004o`0Y/ol0003o0000o`0`^0;o00000_l0@/<01Ol0003o1DW8o`000?l>D/ko000000Co
@f_D00Go0000oe5ce_mALmKoDG?Fo`000003oeilf0;o00000om[Q=T00ol0003oU9C@oiBDd005oiBD
d0;o00001_nMV<l2o`0000OoY9c>00?o0000okj[a_nnZlH02?nnZlH00ol0003o`Zg5ol:]a@07ol:]
a@03o`000?o6[lCoaZo400;oaZo400?o0000omRo`_oH_l800_oH_l800ol0003of/71om[1`@07om[1
`@03o`000?oL`l7o000000Gog<?100?o0000on_I`Ol000001Oo/f/400ol0003ok=_2oncK`P04oncK
`P03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool002Cooooo0_l0000hooooo`05
o`000?oYllkojO?>onWcc_l000001?oYm<d01?l0003ojOK>onWfc_oYm/h2o`0000CojMo800?o0000
onSObOoXglT00ooXglT00ol0003oi]k<onKNc004onKNc003o`000?oIa/OofLK700?ofLK700?o0000
omG4bOoEa<T01?oEa<T4o`0000?od<;=00?o0000okb]b_nl[LX00onl[LX00ol0003o]:W=okBYc@02
okBYc@03o`000?n[YM7oZjGA00;oZjGA00Go0000oijOe?nNWmCoWYoDo`000003ohnGe`[o00000_lh
Hm401?l0003o85C;o`Y5a?l:AL@2o`000003o`0f_?l0003o02Vc00;o000000Ko02Vco`000?l0003o
0000o`0k_ol00002o`12``03o`000?l5BLSo000000;o00001?m3Jm@01Ol0003oDG?Foe5ce_mALmKo
000000CoGWcH00Go0000of^4fOm[Q=Wo0000oh^>d@08oiBDd003o`000?nMV<ooWIS?00GoWIS?00?o
0000ojBLc_nTW<h01?nTW<h00ol0003o^JS8okj[aP09okj[aP03o`000?o2[LGo`Zg500Oo`Zg500Co
0000olJ_a?o6[lCo00001_oH_l800ol0003of/71om[1`@07om[1`@03o`000?oL`l7o000000Cog<?1
00?o0000on_I`Ol000001_o/f/400ol0003ok=_2oncK`P03oncK`P03o`000?oooooooooo01kooooo
0ol0000=ooooo`009?ooool00ol0003oooooooooo`0gooooo`05o`000?oYllkojO?>onWcc_l00000
1?oYm<d01Ol0003ojOK>onWfc_oYm/ko000000KojMo800?o0000onSObOoXglT00ooXglT00ol0003o
i]k<onKNc002onKNc0;o00001_oIa/L01?l0003oeLC9omG4bOoEa<T4o`0000Cod<;=0_l00006okb]
bP03o`000?ndZLgo]:W=00;o]:W=00?o0000oj^UdOn[YM400_n[YM402Ol0003oWYoDoijOe?nNWmCo
0000ohnGeol0003oP8WBo`000002ofn0d`04o`000?mLMM?oG7GCo`0000;oAfWA0ol00002ob1Db`;o
2TG400?o0000o`0f_?l000000ol000000ol0:K?o0000o`0/]@02o`000009o`0k_ol0003o04;3o`12
`ol0003o1DW8o`000?ldHM7o000000Co@f_D00Go0000oe5ce_mALmKoDG?Fo`000004oeilf0;o0000
0on;S]400ol0003oU9C@oiBDd005oiBDd003o`000?nMV<ooWIS?00GoWIS?00?o0000ojBLc_nTW<h0
0_nTW<h01Ol0003o^JS8okVXb?niZ<So000000Wo_Z_600?o0000ol:]aOo2[LD01oo2[LD00ol0003o
aZo4o`000007omRo`P03o`000?oJ`L7of/7100Oof/7100?o0000omc3`Ol000000_oL`l401Ol0003o
jmW1on_I`Oo[fL7o000000Gok=[100?o0000oncK`_o/fl800oo/fl800ol0003oooooooooo`0Koooo
o`?o00000_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0gooooo`05
o`000?oYllkojO?>onWcc_l000001?oYm<d00ol0003ojOK>onWfcP02o`0000KojMo800?o0000onSO
bOoXglT00ooXglT01Ol0003oi]k<onKNc?oVg/co000000;og<O400?o0000omW6aooIa/L01?oIa/L3
o`0000CoeLC900Co0000om32cOo@`/go00000_o3/<L00ol0003o_:g:okb]bP03okb]bP03o`000?nd
ZLgo]:W=00?o]:W=00?o0000oj^UdOn[YM400_n[YM400ol0003oWYoDoijOe002o`0000?oP8WB00Co
0000ofn0dom_P=?o00000_mLMM<00ol0003oAfWAo`000002oc5Lc@?o000000?o2TG4o`0h_?l0>;`0
1Ol000000ol0:K?o0000o`0/]@02o`000004o`0k_ol0003o04;3o`12``;o00000_ldHM400ol0003o
@f_Dod=[e002od=[e005o`000?mALmKoDG?Foe5ce_l000001?mNO=P00ol0003oRhkAoh^>d@02oh^>
d@03o`000?nDU=3oU9C@00GoU9C@00?o0000oifHconMV<l01OnMV<l2o`0000;oY9c>00?o0000okVX
b?niZ<P00_niZ<P00ol0003o_Z_6okj[aP07okj[aP03o`000?o2[LGo`Zg500Oo`Zg500?o0000omRo
`_oH_l801ooH_l800ol0003of/71om[1`@07om[1`@04o`000?oL`l7o0000o`0000CojmW100?o0000
oncJ`Oo/f/401?o/f/400ol0003ok=_2oncK`P03oncK`P03o`000?oooooooooo01Oooooo0ol00005
ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Kooooo00?o0000onWc
c_oYllh00_oYllh01Ol0003ojOC=onWdcOoYm<go000000;ojOK>00Co0000on[NaooZg/Oo00001OoY
glP00ol0003oj=o9onSOb@03onSOb@04o`000?oVg/coi]k<o`0000Cog<O400?o0000omW6aooIa/L0
1?l00006omG4b@03o`000?o@`/go000000Co`k3700?o0000okb]b_nl[LX00onl[LX00ol0003o]:W=
okBYc@02okBYc@03o`000?n[YM7oZjGA00?oZjGA0_l000000on?T=7o0000oh29dP03oh29dP04o`00
0?m_P=?oKh3Co`0000;oG7GC00Go0000odMYdOl0003o<Ec=o`000002oa]>b006o`000?l:ALCo03Rl
o`0^]_l0003o02^d1_l000001?l0=;_o0000o`0k_ol00002o`12``;o00000_ldHM400ol0003o@f_D
od=[e002od=[e005o`000?mALmKoDG?Foe5ce_l000000omNO=P00ol0003oOhSBoh^>d@03oh^>d@03
o`000?nDU=3oU9C@00GoU9C@00?o0000oifHconMV<l01_nMV<l00ol0003oY9c>o`000005okVXb003
o`000?nnZlKo_Z_600Oo_Z_60_l00007ol:]a@03o`000?oH_l;of;o200Sof;o200?o0000om[1`OoJ
`L401ooJ`L43o`0000CojmW100?o0000oncJ`Oo/f/401?o/f/400ol0003ok=_2oncK`P03oncK`P03
o`000?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000
=oooool00ol0003ojO?>onWccP02onWccP07o`000?oYm<gojOC=onWdcOl0003ojOK>o`000003on[N
a`03o`000?oYglSojMo800CojMo800?o0000onSObOoXglT00ooXglT2o`0000Gog<O40ol00004omW6
a`03o`000?oEa<WoeLC900CoeLC900?o0000ol>`aoo3/<L01?o3/<L00ol0003o_:g:okb]bP03okb]
bP03o`000?ndZLgo]:W=00;o]:W=00Co0000oj^UdOn[YM7oZjGA0_l00003ohn@d@03o`000?n0RM;o
P8WB00;oP8WB00Ko0000ofn0dom_P=?o0000oeaedol00002odMYd@03o`000?laG<go000000;o6dk8
00Ko0000o`Y5a?l0>;co02jfo`000?l0:k@3o`00000;o`0Y/ol0003o0000o`0d^ol0003o03^oo`00
0?l0@/?o0000obIGcOl000000_ldHM400ol0003o@f_Dod=[e002od=[e007o`000?mALmKoDG?Foe5c
e_l0003oGWcHo`000003ogn8dPCoRhkA0_l00006oiBDd0;o00001onMV<l00ol0003o^JS8okVXb005
okVXb0;o00002OnnZlH00ol0003o`Zg5ol:]a@03ol:]a@03o`000?oD_L?o000000[of;o200?o0000
om[1`OoJ`L401ooJ`L42o`0000GojmW100?o0000oncJ`Oo/f/400oo/f/400ol0003ok=_2oncK`P02
oncK`P;o00004_ooool3o`0000gooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooo
ooooool0=oooool00ol0003ojO?>onWccP02onWccP04o`000?oYm<gojOC=onWdc@;o00001?oZg/L0
0ol0003ojMo8onWOb004onWOb003o`000?oXglWoj=o900?oj=o900Co0000omc7a?oLalCog<O40ol0
00000ooLalCo0000omW6a`05omW6a`03o`000?oEa<WoeLC900;oeLC90_l00007ol>`a`03o`000?nl
[L[o_:g:00?o_:g:00?o0000okBYcOndZLd00_ndZLd00ol0003oZjGAo`000002oiZFcP05o`000?n?
T=7oSi3Aohn@dOl000000on0RM801ol0003oKh3Cofn0dom_P=?o0000oeaedol000000_m7JM400ol0
003o<Ec=o`000002oa]>b0;o000000Go03Rlo`0^]_l0;KKo0000o`0W/P02o`00000;o`0Y/ol0003o
0000o`0d^ol0003o03^oo`000?lHC/So0000obIGcOl000000_ldHM400ol0003o@f_Dod=[e002od=[
e005o`000?mALmKoDG?Foe5ce_l000001OmoR=800ol0003oRhkAoh^>d@02oh^>d@03o`000?nDU=3o
U9C@00GoU9C@00?o0000oifHconMV<l01?nMV<l00ol0003o/ZC:okVXb007okVXb003o`000?nnZlKo
_Z_600Oo_Z_600?o0000ol:]aOo2[LD00_o2[LD01?l0003oe;g3omBm`ol0000:omRo`P03o`000?oJ
`L7of/7100Kof/7100?o0000on_I`Ol000001?o[fL400ol0003ok=[1oncJ`@04oncJ`@06o`000?o/
fl;ok=_2o`000?oalkoo00003oooool3o`00013ooooo00?o0000ooooooooool02_ooool002?ooooo
00?o0000ooooooooool0=oooool00ol0003ojO?>onWccP02onWccP05o`000?oYm<gojOC=onWdcOl0
00001_oZg/L00ol0003ojMo8onWOb003onWOb003o`000?oXglWoj=o900?oj=o91?l00005omc7a003
o`000?oIa/OofLK700?ofLK700Go0000omG4bOoEa<WoeLC9o`000002olNba@03o`000?o3/<Oo`k37
00Go`k3700?o0000okb]b_nl[LX00_nl[LX00ol0003o]:W=okBYc@03okBYc@03o`000?nJU/koVYK>
00;oVYK>00Go0000ohn@dOn?T=7oSi3Ao`000003oh29dP04o`000?m_P=?oKh3Co`0000;oG7GC00co
0000odMYdOm7JM7o0000oc5LcOl0003o6dk8o`000?l7@L7o0000o`0h_?l0;[H6o`000003o`0_]ol0
003o03Bk00;o00000_lHC/P00ol0003o9UO=o`000002ocAQd@03o`000?m3JmCo@f_D00;o@f_D00Go
0000oe5ce_mALmKo0000og:1d`05ogn8dP03o`000?n;S]7oRhkA00;oRhkA00?o0000oiBDd?nDU=00
1OnDU=000ol0003oWIS?oifHc`02oifHc`05o`000?nbY<[o/ZC:ok:Tb_l000001oniZ<P00ol0003o
_Z_6okj[aP07okj[aP04o`000?o2[LGo`Zg5o`0000Coe;g300?o0000omRo`_oH_l802?oH_l800ol0
003of/71om[1`@04om[1`@05o`000?oZf<;o0000on_I`Ol000001?o[fL400ol0003ok=[1oncJ`@03
oncJ`@03o`000?o/fl;o000000;olO>o00?o0000ooooooooool02Oooool4o`0001?ooooo00?o0000
ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003ojO?>onWccP02onWc
cP03o`000?oYm<gojOC=00;o00001_oZg/L00ol0003ojMo8onWOb004onWOb003o`000?oXglWoj=o9
00Co00002?oLal@00ol0003ofLK7omW6a`03omW6a`03o`000?oEa<Wo000000Coak;500?o0000ol>`
aoo3/<L01?o3/<L00ol0003o_:g:okb]bP03okb]bP07o`000?ndZLgo]:W=okBYcOl0003oY9_<o`00
0004oiZFcP05o`000?n?T=7oSi3Aohn@dOl000000on0RM801?l0003oKh3Cofn0dol00002oeaed`03
o`000?m7JM7oAfWA00;o00000_lKC/P2o`000003o`0f^ol0003o02jf00Ko000000?o02ngo`000?l0
=;/00_l00002oaQ>b003o`000?lVElgo000000;o=67A00?o0000od=[e?m3Jm@00_m3Jm@2o`0000?o
LX7C1OmoR=800ol0003oRhkAoh^>d@02oh^>d@03o`000?nDU=3oU9C@00GoU9C@00Co0000oifHconM
V<oo00001OnbY<X00ol0003o^JS8okVXb005okVXb003o`000?nnZlKo_Z_600Oo_Z_600?o0000ol:]
aOl000001OoD_L<00ol0003of;o2omRo`P08omRo`P03o`000?oJ`L7of/7100;of/7100Ko0000on[H
`_oZf<;o0000on_I`Ol00004on_I`@03o`000?o/f/7ok=[100Cok=[100Go0000oo7c_ooalkoolO>o
o`000008ooooo`?o00005oooool00ol0003oooooooooo`0:ooooo`008oooool3o`0003Oooooo00Go
0000onWcc_oYllkojO?>o`000002onWdc@04o`000?oZg/Ooj]k7o`0000Goj]k700?o0000onWOb?oY
glP01?oYglP4o`0000?og/S300?o0000omc7a?oLal@01OoLal@00ol0003ofLK7omW6a`04omW6a`03
o`000?o7//Goak;500Coak;500?o0000ol>`aoo3/<L01?o3/<L00ol0003o_:g:okb]bP03okb]bP03
o`000?ndZLgo000000?oY9_<00?o0000oiZFc_nJU/h00_nJU/h01Ol0003oSi3Aohn@dOn?T=7o0000
00?oP8WB00Ko0000ofn0dom_P=?o0000oeaedol00003odMYd@;o00000_lKC/P2o`000003o`0f^ol0
003o000000?o000000Co02Nao`000?l0003o02ng0_l000001ol:ALCo0000oaQ>b?lHC/So0000obIG
cOl000000_ldHM400ol0003o@f_Dod=[e002od=[e003o`000?mbPM?oLX7C00;oLX7C00?o0000ogn8
d_moR=800_moR=800ol0003oRhkAoh^>d@02oh^>d@;o00001_nDU=000ol0003oWIS?o`000006ok:T
bP03o`000?niZ<So^JS800Go^JS80_l00008okj[aP03o`000?oD_L?oe;g300Goe;g300?o0000omRo
`_oH_l802?oH_l801Ol0003of/71om[1`OoJ`L7o000000?oj]S200?o0000on_I`Ol000001?o[fL40
0ol0003ok=[1oncJ`@03oncJ`@05o`000?oalkoolO>ooo7c_ol000001Oooool3o`0001[ooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool01ol0003ojO?>onWcc_oY
llko0000onWdcOl000000ooZg/L00ol0003oj]k7on[Na`04on[Na`03o`000?oYglSojMo800Co0000
00?oj=o9o`000?oNb<<01?oNb<<00ol0003og<O4omc7a005omc7a003o`000?oIa/OofLK700?ofLK7
00?o0000olNbaOo7//D01Oo7//D00ol0003o`k37ol>`a`04ol>`a`03o`000?nl[L[o_:g:00?o_:g:
00?o0000ojBKc?nTVl`00onTVl`00ol0003oVYK>oiZFcP02oiZFcP05o`000?n?T=7oSi3Aohn@dOl0
00000_n0RM801ol0003oKh3Cofn0dom_P=?o0000oeaedol000000_m7JM43o`000003oa]>b?l0003o
1d7100;o000000?o02jfo`000?l000000ol000000ol0:kCo0000o`0_]`02o`000007o`Y5a?l0003o
64k8oaQ>b?l0003o9UO=o`000002ocAQd@05o`000?m3JmCo@f_Dod=[e?l000001OmbPM<00ol0003o
OhSBogn8dP02ogn8dP03o`000?n;S]7oRhkA00?oRhkA00?o0000oiBDd?nDU=001?nDU=000ol0003o
/ZC:ok:TbP06ok:TbP03o`000?niZ<So^JS800Ko^JS800?o0000okj[a_nnZlH01OnnZlH00ol0003o
e;g3omBm``06omBm``03o`000?oH_l;of;o200Sof;o200?o0000om[1`Ol000001?oZf<801?l0003o
jmW1on_I`Ol00003on_I`@03o`000?o/f/7ok=[100;ok=[10_l00003oo7c_`03o`000?oooooooooo
00?o00007Oooool00ol0003oooooooooo`0:ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo03Sooooo00Co0000onWcc_oYllkojO?>0_l00004on[Na`03o`000?oZg/Ooj]k700Coj]k70ol0
0004onWOb003o`000?oNb<?og/S300Cog/S300?o0000omc7a?oLal@01_oLal@01ol0003ofLK7omW6
aooIa/Oo0000ol^c`ol000001oo7//D00ol0003o`k37ol>`a`04ol>`a`05o`000?nl[L[o_:g:okb]
b_l000000_n/WlT5ojBKc003o`000?nJU/koVYK>00;oVYK>00Go0000ohn@dOn?T=7oSi3Ao`000002
oh29dP04o`000?m_P=?oKh3Cofn0d`Co000000?o=5g=o`000?lQDLT01?l000001Ol0=[_o0000o`0W
/Ol09k7o02Ja00?o000000Oo02^do`000?l0003o03boo`000?l:ALCo000000;o64k800?o0000obIG
cOl000000_ldHM401Ol0003o@f_Do`000?mSNM?o000000GoLX7C00?o0000ogn8d_moR=800_moR=80
0ol0003oRhkAoh^>d@03oh^>d@03o`000?nDU=3oU9C@00?oU9C@00?o0000oj^Pc?nbY<X01onbY<X0
0ol0003o^JS8okVXb006okVXb003o`000?nnZlKo_Z_600?o_Z_600?o0000om2kaOl000002?oD_L<0
0ol0003of;o2omRo`P08omRo`P03o`000?oZf<;oj]S200Coj]S200?o0000on_I`Ol000000oo[fL40
1ol0003ok=[1oncJ`Oo/f/7o0000oo7c__l000000ooalkl3o`00023ooooo00?o0000ooooooooool0
2_ooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool00ol0003o
jO?>onWccP02o`0000Koj]k700?o0000on[NaooZg/L01?l00005onWOb0;o00001ooNb<<00ol0003o
g<O4omc7a005omc7a004o`000?oIa/OofLK7o`0000?obk?300?o0000olNbaOo7//D01Oo7//D00ol0
003o`k37ol>`a`04ol>`a`03o`000?nl[L[o000000Co[9o900?o0000ojBKc?nTVl`00_nTVl`00ol0
003oVYK>oiZFcP02oiZFcP05o`000?n?T=7oSi3Aohn@dOl000000_n0RM801_l0003oKh3Co`000?l0
003oAfS@o`0000?o=5g=0_l000000ol?A/Co0000o`0l_P03o`0000;o02Na1?l000001ol0:kCo0000
o`000?l0?;oo0000o`Y5a?l000000_lHC/P00ol0003o9UO=o`000002ocAQd@05o`000?mSNM?oHgWC
of=idol000001OmbPM<00ol0003oOhSBogn8dP02ogn8dP03o`000?n;S]7oRhkA00?oRhkA00Go0000
oiBDd?nDU=3oU9C@o`000003oj^Pc003o`000?nbY<[o/ZC:00Go/ZC:00?o0000okVXb?niZ<P01_ni
Z<P01Ol0003o_Z_6okj[a_nnZlKo000000?od;_500?o0000omBm`ooD_L<01_oD_L<00ol0003of;o2
omRo`P07omRo`P03o`000?oZf<;oj]S200Coj]S200Co0000on_I`Oo[fL7o00000oo[fL401_l0003o
k=[1oncJ`Ol0003olO>no`0000?olO>o00?o0000ooooooooool08Oooool00ol0003oooooooooo`09
ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000
ooooooooool00_ooool2o`0003Sooooo00Ko0000onWcc_oYllko0000onWNaol00006on[Na`?o0000
1?oZg/L01Ol0003ojMo8onWOb?oYglSo000000;oglS200?o0000omk8`ooNb<<01OoNb<<00ol0003o
g<O4omc7a005omc7a003o`000?oIa/Oo000000Cobk?300?o0000olNbaOo7//D01Oo7//D00ol0003o
`k37ol>`a`04ol>`a`03o`000?n/WlWo[9o900Co[9o900?o0000ojBKc?nTVl`00_nTVl`00ol0003o
VYK>oiZFcP02oiZFcP06o`000?n?T=7oSi3Aohn@dOl0003oP8WB0_l00002oeUbdP03o`000?m7J=3o
000000?o=5g=0_l000000ol?A/Co0000o`000002o`0b^@03o`000?l09k7o000000Go000000?o03Fj
o`000?l0?;l00_l00003oaQ>b005o`000?lVElgo0000ocAQdOl000001?mSNM<00ol0003oLX7Cog:1
d`03og:1d`03o`000?moR=;oOhSB00;oOhSB00?o0000oh^>dOn;S]400on;S]400ol0003oU9C@o`00
0005oj^Pc003o`000?nbY<[o/ZC:00Go/ZC:00?o0000okVXb?niZ<P01_niZ<P00ol0003o_Z_6o`00
0005om2ka@03o`000?oD_L?oe;g300Koe;g300?o0000omRo`_oH_l801OoH_l800ol0003oj=O4o`00
0006on[H`P04o`000?o[fL7ojmW1o`0000;ojmW100?o0000oncJ`Ol000000_oalkh01Ol0003olO>o
oo7c_ooalkoo000002?ooooo00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0=oooool00ol0003ojO?>o`000003onWNa`04o`000?oZg/Ooj]k7on[Na`Co00001OoZg/L01?l0
003ojMo8onWOb?l00004omo8`P03o`000?oNb<?og/S300Gog/S300?o0000omc7a?oLal@01OoLal@0
0ol0003obk?3ol^c``04ol^c``03o`000?o7//Goak;500Goak;500?o0000ol>`aoo3/<L00oo3/<L2
o`0000Ko[9o900?o0000ojBKc?nTVl`00_nTVl`00ol0003oVYK>oiZFcP02oiZFcP07o`000?n?T=7o
Si3Aohn@dOl0003oJG_Bo`000003oeUbdP03o`000?m7J=3o000000;o=5g=00Co0000ob5AbOl0003o
3dK40_l000001?l0<[Wo0000o`000?l09k46o`000003o`0e^_l0003o03bo00;o00000olHC/P01Ol0
003o9UO=o`000?mCL=;o000000CoHgWC00?o0000og:1dombPM<00ombPM<00ol0003oOhSBogn8dP02
ogn8dP03o`000?n;S]7oRhkA00?oRhkA00?o0000oj^Pc?n[X<`01On[X<`00ol0003o/ZC:ok:TbP05
ok:TbP03o`000?niZ<So^JS800Ko^JS800?o0000om2kaOo@^lD01Oo@^lD00ol0003oe;g3omBm``06
omBm``03o`000?oH_l;of;o200?of;o200Co0000onSGa?oXelCo00001_oZf<801Ol0003ojmW1on_I
`Oo[fL7o000000;ojmW100Go0000oo7c__oalkkolO>no`000003oo7c_`03o`000?oooooooooo027o
oooo00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0goooo
o`;o00001?oYg/L4o`0000?oj]k700?o0000on[NaooZg/L00ooZg/L00ol0003ojMo8o`000006omo8
`P03o`000?oNb<?og/S300Gog/S300?o0000omc7a?oLal@01?oLal@2o`0000Kobk?300?o0000olNb
aOo7//D01Oo7//D01Ol0003o`k37ol>`aoo3/<Oo000000;o/j;700?o0000ojbObOn/WlT01?n/WlT0
0ol0003oY9_<ojBKc002ojBKc003o`000?nJU/koVYK>00;oVYK>00Co0000ohn@dOl0003o00000_mY
Nm801ol0003oFG;BoeUbd_mIL];o0000odMXd?l000000_ldGLd01?l0003o8E79o`000?l?A/@2o`00
0003o`0b^Ol0003o000000?o000000?o02F`o`000?l0;[H00_l00002o`0l_`;o00000olHC/P2o`00
00;oDg3B00?o0000of=idomSNM<00_mSNM<00ol0003oLX7Cog:1d`03og:1d`03o`000?moR=;oOhSB
00;oOhSB00Oo0000oh^>dOn;S]7oRhkAo`000?nRW<oo000000OoZj3<00?o0000ok:Tb_nbY<X01Onb
Y<X00ol0003o^JS8okVXb005okVXb003o`000?o@^lGod;_500Kod;_500?o0000omBm`ooD_L<01_oD
_L<01Ol0003of;o2omRo`_oH_l;o000000Coj=O400?o0000on[H`_oZf<800ooZf<801Ol0003ojmW1
on_I`Oo[fL7o000000;ojmW100Go0000oo7c__oalkkolO>no`000003oo7c_`03o`000?oooooooooo
027ooooo00?o0000ooooooooool02Oooool00005oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01?l0
003ojMk7onWNaooYg/L3o`0000Koj]k700?o0000on[NaooZg/L01?oZg/L00ol0003oglS2omo8`P05
omo8`P03o`000?oNb<?og/S300Gog/S300?o0000omc7a?oLal@00ooLal@01?l0003oc[G1olje`Ol0
0006ol^c``03o`000?o7//Goak;500Goak;500?o0000ol>`aol000001?ncX/L00ol0003o[9o9ojbO
b@04ojbOb@03o`000?nTVlcoY9_<00;oY9_<00?o0000oiZFc_nJU/h00_nJU/h01?l0003oN8?BogR3
d_l00002ofUkdP07o`000?mIL];oFG;BoeUbd_l0003oAfS@o`000002ocAMc@;o000000?o3dK4o`00
0?l000000_l0<[T2o`000003o`0T[ol0003o000000;o000000?o02jfo`000?l000000_l0?;l2o`00
0005oaQ>b?l0003o0000od9Vd?l000000_mCL=800ol0003oHgWCof=id`02of=id`03o`000?mbPM?o
LX7C00?oLX7C00?o0000ogn8d_moR=800_moR=800ol0003oRhkAo`000003oj:Lc`03o`000?n[X<co
Zj3<00GoZj3<00?o0000ok:Tb_nbY<X01OnbY<X00ol0003o^JS8okVXb003okVXb003o`000?o;^LSo
000000Sod;_500?o0000omBm`ooD_L<01_oD_L<00ol0003of;o2o`000005onSGa003o`000?oZf<;o
j]S200Coj]S200Co0000on_I`Oo[fL7ojmW10ol00003oo7c_P05o`000?oalkoolO>ooo7c_ol00000
8oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool4o`0000?o
jMk700?o0000on[NaooZg/L01?oZg/L00ol0003oj]k7on[Na`03on[Na`03o`000?oOb<;oglS200Ko
glS200?o0000omk8`ooNb<<01OoNb<<01Ol0003og<O4omc7a?oLalCo000000Coc[G100?o0000ol^c
`oo;/l<01?o;/l<00ol0003oak;5olNba@05olNba@03o`000?ncX/Oo/j;700Co/j;700?o0000ojbO
bOn/WlT01?n/WlT00ol0003oY9_<ojBKc002ojBKc005o`000?nJU/koVYK>oiZFc_l000000omhPm80
1?l0003oJG_BofUkd_l00003oeUbdP03o`000?m7J=3o000000;o=5g=0_l000001?l?A/Co0000o`00
0?l0<[T8o`000004o`0^]_l0003o0000o`0l_`?o00000_l`Fl`00ol0003o@VK@o`000002oe=`dP03
o`000?mSNM?oHgWC00;oHgWC00?o0000og:1dombPM<00ombPM<00ol0003oOhSBogn8dP02ogn8dP03
o`000?nRW<ooXYc?00?oXYc?00?o0000oj^Pc?n[X<`01On[X<`00ol0003o/ZC:ok:TbP05ok:TbP03
o`000?niZ<So^JS800;o^JS800Co0000ol^ib?o;^LSo00001oo@^lD00ol0003oe;g3omBm``07omBm
``03o`000?oXelCoj=O400Goj=O400?o0000on[H`_oZf<800ooZf<801?l0003ojmW1on_I`Oo[fL43
o`0000?olO>n00Go0000oo7c_ooalkoolO>oo`00000Sooooo`03o`000?oooooooooo00Wooooo0000
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000
1?ooool00ol0003oooooooooo`0fooooo`Co00001OoYg/L00ol0003oj]k7on[Na`04on[Na`03o`00
0?oZg/Ooj]k700;oj]k700?o0000on39`Ol000002?oOb<800ol0003og/S3omk8``05omk8``03o`00
0?oLalCo000000Koc[G100?o0000ol^c`oo;/l<01?o;/l<00ol0003oak;5olNba@04olNba@03o`00
0?nhYLGo/j;700Go/j;700?o0000ojbObOn/WlT01?n/WlT00ol0003oY9_<ojBKc002ojBKc005o`00
0?nJU/ko0000ohB:dOl000000omhPm801?l0003oJG_BofUkd_l00002oeUbdP09o`000?m7J=3oAfS@
o`000?ldGLgo0000ob5AbOl0003o3dK400Wo000000?o02Vco`000?l0;[H00_l000000ol=AL?o7U38
o`000003oc1Kc003o`000?m2I]3o000000;oDg3B00?o0000of=idomSNM<00_mSNM<00ol0003oLX7C
og:1d`03og:1d`05o`000?moR=;oOhSBogn8d_l000001_nRW<l00ol0003oZj3<oj^Pc005oj^Pc003
o`000?nbY<[o/ZC:00Go/ZC:00Co0000okVXb?niZ<So00001?o;^LP00ol0003od;_5om2ka@05om2k
a@03o`000?oD_L?oe;g300Koe;g300?o0000onSGa?oXel@01OoXel@00ol0003oj]S2on[H`P04on[H
`P06o`000?o[fL7ojmW1o`000?oalkko00000ooalkh01Ol0003olO>ooo7c_ooalkoo000002?ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0<oooool3o`0000?ooooo00?o
0000onWNaooYg/L01?oYg/L00ol0003oj]k7on[Na`04on[Na`04o`000?oZg/Ooj]k7o`0000?oh<W1
00?o0000omo8`_oOb<801_oOb<800ol0003og/S3omk8``05omk8``03o`000?o>]L7oc[G100Koc[G1
00?o0000ol^c`oo;/l<01?o;/l<00ol0003oak;5olNba@02olNba@05o`000?nhYLGo^:G5okRUaOl0
00001OncX/L00ol0003o[9o9ojbOb@04ojbOb@03o`000?nTVlcoY9_<00;oY9_<0_l00002ohB:d@05
o`000?mhPm;oN8?BogR3d_l000000_mYNm801?l0003oFG;BoeUbd_l00002odMXd004o`000?ldGLgo
0000ob5Ab@?o000000Oo02nfo`000?l0003o0000o`0T[ol0003o02Ja00?o000000Ko03^no`000?l=
AL?o3DG3oai@b?l00003oc1Kc003o`000?m2I]3o000000;oDg3B00?o0000of=idomSNM<00_mSNM<0
0ol0003oLX7Cog:1d`03og:1d`05o`000?moR=;o0000oiNFdOl000001_nRW<l00ol0003oZj3<oj^P
c005oj^Pc003o`000?nbY<[o/ZC:00Go/ZC:00?o0000okVXb?l000001Oo;^LP00ol0003od;_5om2k
a@05om2ka@03o`000?oD_L?oe;g300Coe;g300?o0000onKFa_l000001ooXel@00ol0003oj]S2on[H
`P03on[H`P03o`000?o[fL7o000000;olO>n00Go0000oo7c__oalkkolO>no`000003oo7c_`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0<?oo
ool3o`0000Kooooo00?o0000onWNaooYg/L01?oYg/L00ol0003oj]k7on[Na`04on[Na`04o`000?oZ
g/Ooj]k7o`0000Coh<W100?o0000omo8`_oOb<801_oOb<800ol0003og/S3omk8``04omk8``;o0000
2?o>]L400ol0003obk?3ol^c``04ol^c``04o`000?o7//Goak;5o`0000Go^:G500?o0000ok>Raonc
X/L00oncX/L00ol0003o[9o9ojbOb@04ojbOb@07o`000?nTVlcoY9_<ojBKc?l0003oSho?o`000002
ohB:d@05o`000?mhPm;oN8?BogR3d_l000000_mYNm801?l0003oFG;BoeUbd_l00002odMXd005o`00
0?ldGLgo0000o`000?l0?Kl00_l000000ol0;kKo0000o`000004o`000005o`0[]?l0<[Wo03:io`0k
__l000000_l=AL<01OlND<So0000oc1Kc?l`Flco000000;o@VK@00Co0000oe=`d_mCL=;o00001?mS
NM<00ol0003oLX7Cog:1d`03og:1d`05o`000?nGU]7oUiKAoiNFdOl000001_nRW<l00ol0003oZj3<
oj^Pc005oj^Pc003o`000?nbY<[o/ZC:00Go/ZC:00?o0000ol^ib?o;^LP01?o;^LP00ol0003od;_5
om2ka@06om2ka@03o`000?oD_L?oe;g300;oe;g300Co0000onKFa_oVe/Ko00001ooXel@00ol0003o
j]S2on[H`P04on[H`P04o`000?oalkkolO>noo7c_P;o00000_oalkh01Ol0003olO>ooo7c_ooalkoo
000002Cooooo00?o0000ooooooooool02?ooool0027ooooo0_l0000^ooooo`?o00002_ooool00ol0
003ojMk7onWNa`03onWNa`03o`000?oZg/Ooj]k700Coj]k700?o0000on[Naol000001_oPbL400ol0
003oglS2omo8`P05omo8`P03o`000?oNb<?og/S300?og/S300Co0000om6g`?oA]l3o00002?o>]L40
0ol0003obk?3ol^c``04ol^c``03o`000?o7//Go000000Ko^:G500?o0000ok>RaoncX/L00oncX/L0
0ol0003o[9o9ojbOb@04ojbOb@03o`000?nTVlco000000?oSho?00Co0000ohB:dOn4R]7o00000omh
Pm801?l0003oJG_BofUkd_l00002oeUbdP03o`000?m7J=3o000000;o000000?o34K4o`000?l0?Kl0
0_l000004?l0;kKo0000o`000?l09K3o0000o`0W/Ol0003o02^do`0b^Ol0003o03^no`000?l=AL?o
0000oai@b?l00002oc1Kc004o`000?m2I]3o@VK@o`0000;oDg3B00?o0000of=idomSNM<00_mSNM<0
1?l0003oLX7Cog:1dombPM<2o`0000CoUiKA00?o0000oj:LconRW<l01?nRW<l00ol0003oZj3<oj^P
c005oj^Pc003o`000?nbY<[o/ZC:00?o/ZC:0_l00007ol^ib003o`000?o@^lGod;_500Kod;_500Go
0000omBm`ooD_L?oe;g3o`000003onKFaP03o`000?oXelCoj=O400Coj=O400?o0000on[H`_oZf<80
1?oZf<802Ol0003olO>noo7c__oalkko0000oo7c__l0003olO>no`000003oo7c_`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3o`00
00gooooo00?o0000onWNaooYg/L01?oYg/L00ol0003oj]k7on[Na`04on[Na`03o`000?oPbL7oh<W1
00Goh<W100?o0000omo8`_oOb<801_oOb<801Ol0003og/S3omk8`ooNb<?o000000CodKO000?o0000
olje`Oo>]L401_o>]L400ol0003obk?3ol^c``04ol^c``03o`000?nhYLGo^:G500Ko^:G500?o0000
ok>RaoncX/L00oncX/L00ol0003o[9o9ojbOb@04ojbOb@;o00001?n?Sll01?l0003oQ8[AohB:dOl0
0003ogR3dP04o`000?mYNm;oJG_Bo`0000;oFG;B00So0000obUIcOl0003o6To9o`000?l<A/Co0000
o`0m_`[o000000So03:io`000?l0>kko0000o`e5`ol0003o7U38o`0000;o<5_<00Co0000od9Vd?m2
I]3o00000_mCL=800ol0003oHgWCof=id`02of=id`03o`000?mbPM?o000000;oRXoC00?o0000oiNF
dOnGU]400_nGU]400ol0003oXYc?oj:Lc`04oj:Lc`03o`000?n[X<coZj3<00GoZj3<00Go0000ok:T
b_nbY<[o/ZC:o`000002olFfb`03o`000?o;^LSobkW800GobkW800?o0000om2kaOo@^lD01_o@^lD0
0ol0003oe;g3o`000004onKFaP03o`000?oXelCoj=O400Goj=O400?o0000on[H`_oZf<800_oZf<82
o`0000?olO>n00?o0000oo7c__oalkh00_l00002oo7c_`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02?ooool0027ooooo00?o0000ooooooooool09oooool3o`00013ooooo00?o0000onWN
aooYg/L01?oYg/L00ol0003oj]k7on[Na`03on[Na`;o00002?oPbL400ol0003oglS2omo8`P06omo8
`P03o`000?oNb<?o000000KodKO000?o0000olje`Oo>]L401_o>]L400ol0003obk?3ol^c``03ol^c
``03o`000?nmYl?o^:G500Oo^:G50_l00004ok>Ra`03o`000?n/WlWo[9o900?o[9o900?o0000oiRD
c_l000001?n?Sll01?l0003oQ8[AohB:dOl00003ogR3dP06o`000?mYNm;oJG_Bo`000?mIL];o0000
0_lYFLd01?l0003o6To9o`000?l<A/@2o`000004o`0e^ol0003o0000o`0X/PCo00000_l0;KD3o`00
00;o3DG30_l00003oc1Kc004o`000?m2I]3o@VK@o`0000;oDg3B00Co0000of=idomSNM?oHgWC0_l0
0004ohZ?d`03o`000?nGU]7oUiKA00;oUiKA00?o0000oj:LconRW<l01?nRW<l00ol0003oZj3<oj^P
c005oj^Pc003o`000?nbY<[o000000CoaKK;00?o0000ol^ib?o;^LP01Oo;^LP00ol0003od;_5om2k
a@06om2ka@03o`000?oVe/Koi]K600Coi]K600?o0000onSGa?oXel@01?oXel@01ol0003oj]S2on[H
`_oZf<;o0000oo7c_ol000000ooalkh00ol0003olO>noo7c_P02o`000003oo7c_ol0003o000002Go
oooo00?o0000ooooooooool02?ooool0023ooooo00?o0000ooooooooool09Oooool3o`0001Cooooo
00?o0000onWNaooYg/L01?oYg/L01Ol0003oj]k7on[NaooZg/Oo000000;ohL[200?o0000on39`OoP
bL401_oPbL400ol0003oglS2omo8`P06omo8`P;o00001ooA]l000ol0003oc[G1olje`@06olje`@05
o`000?o;/l?obk?3ol^c`ol000000onmYl<00ol0003o^:G5okRUa@06okRUa@03o`000?ncX/Oo/j;7
00;o/j;700Go0000ojbObOn/WlWo[9o9o`000003oiRDcP03o`000?n?SlooSho?00;oSho?00Co0000
ohB:dOn4R]7o00000omhPm801_l0003oJG_BofUkd_l0003o>6?Ao`0000;o:EW=00Co0000oaY?bOl0
003o34K40_l000001?l0=K_o0000o`000?l0:;82o`000007o`0W/Ol0003o02feo`0f^ol0003o03^n
o`000002o`e5``;o00000_l`Fl`01Ol0003o@VK@od9Vd?m2I]3o000000;oDg3B00Go0000of=idol0
003oNhODo`000005ohZ?d`03o`000?nGU]7oUiKA00;oUiKA00?o0000oj:LconRW<l01?nRW<l00ol0
003oZj3<oj^Pc005oj^Pc003o`000?o5]/_oaKK;00CoaKK;00?o0000ol^ib?o;^LP01Oo;^LP00ol0
003od;_5om2ka@05om2ka@03o`000?oVe/Koi]K600Coi]K600?o0000onSGa?oXel@01OoXel@01_l0
003oj]S2on[H`_l0003olO>oo`0000?olO>n00Co0000oo7c__oalkkolO>n0ol0000Vooooo`03o`00
0?oooooooooo00Sooooo000Pooooo`;o00008oooool3o`0001Oooooo00?o0000onWNaooYg/L01?oY
g/L01?l0003oj]k7on[Naol00004on7:`P03o`000?oPbL7oh<W100Koh<W100?o0000omo8`_oOb<80
1OoOb<800ol0003od[Roo`000007om6g`003o`000?o>]L7oc[G100Koc[G100?o0000ol^c`ol00000
1OnmYl<00ol0003o^:G5okRUa@06okRUa@03o`000?ncX/Oo/j;700;o/j;700?o0000ojbObOl00000
1OnHU<h00ol0003oSho?ohn?c`02ohn?c`04o`000?n4R]7oQ8[Ao`0000?oN8?B00Ko0000ofUkd_l0
003o0000ocQSdOl00002obUIc@04o`000?lJClWo0000o`a6a0?o000000Co02^do`000?l0003o0000
0_l09k42o`000008o`0f^ol0003o0000o`000?l=AL?o0000oai@b?l00002oc1Kc006o`000?m2I]3o
@VK@od9Vd?l0003oDg3B0_l00003og^7e003o`000?n:Sm?oRXoC00?oRXoC00?o0000oiNFdOnGU]40
0_nGU]400ol0003oXYc?oj:Lc`04oj:Lc`03o`000?n[X<coZj3<00?oZj3<0_l00007olFfb`03o`00
0?o;^LSobkW800CobkW800?o0000om2kaOo@^lD01?o@^lD00ol0003oh]C9o`000006onKFaP03o`00
0?oXelCoj=O400Coj=O400?o0000on[H`_l000000_oalkl01Ol0003olO>noo7c__oalkko000000?o
lO>n0ol0000Vooooo`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo023ooooo
0_l0000Jooooo`03o`000?oYg/OojMk700CojMk700?o0000on[Naol000001_oQb/800ol0003oh<W1
on39`@05on39`@03o`000?oOb<;oglS200CoglS200Go0000om:h_ooB^;ood[Roo`000007om6g`003
o`000?o>]L7oc[G100Koc[G100?o0000okfW`onmYl<01OnmYl<2o`0000Oo^:G500?o0000ok>Raonc
X/L00_ncX/L2o`0000KoV9C>00?o0000ohn?con?Sll00_n?Sll01?l0003oQ8[AohB:dOl00003ogR3
dP06o`000?m7K=CoAfcDo`000?lhHm7o00000_lYFLd01?l0003o6To9o`000?l<A/@3o`000005o`0[
]?l0003o0000o`000?l09k400_l0;[H2o`0000;o1D310ol000001OlND<So0000oc1Kc?l`Flco0000
00;o@VK@0_l000000omYO]Co0000og^7e003og^7e003o`000?n:Sm?oRXoC00?oRXoC00Go0000oiNF
dOnGU]7oUiKAo`000007oj:Lc`05o`000?n[X<coZj3<oj^Pc?l000000_nm//h00ol0003oaKK;olFf
b`04olFfb`03o`000?o;^LSobkW800GobkW800?o0000om2kaOo@^lD00_o@^lD01?l0003oh]C9on;D
bOl00006onKFaP03o`000?oXelCoj=O400Goj=O400Go0000oo7c_ooalkoolO>oo`000003oo7c_P07
o`000?oalkkolO>noo7c__l0003oe?Z]o`00000Wooooo`03o`000?oooooooooo00Oooooo000Poooo
o`03o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?oYg/OojMk700CojMk700?o0000on7:
`_oQb/801_oQb/800ol0003oh<W1on39`@05on39`@03o`000?oOb<;oglS200;oglS200?o0000om:h
_ooB^;l00ooB^;l00ol0003odKO0om6g`005om6g`003o`000?o>]L7oc[G100Goc[G100?o0000ol2Y
`_nmYl<01onmYl<00ol0003o^:G5okRUa@05okRUa@07o`000?ncX/Oo/j;7ok>Raol0003oX9S<o`00
0006oiRDcP03o`000?n?SlooSho?00;oSho?00Co0000ohB:dOn4R]7o00000_mhPm82o`0000;oAfcD
00?o0000ocQSdOl000000_lYFLd02?l0003o6To9o`000?l<A/Co0000o`0_]ol0003o02^d0_l00000
1?l09[7o02Nao`0^]_l0;[H2o`000004o`E0`OlHC<Oo64c7oaQ<a`Oo000000GoEW?Co`000?mYO]Co
JGkDo`000004og^7e003o`000?n:Sm?oRXoC00?oRXoC00Go0000oiNFdOnGU]7oUiKAo`000007oj:L
c`03o`000?n[X<co000000Co_K;>00?o0000olFfboo5]//01?o5]//00ol0003obkW8ol^ib005ol^i
b005o`000?o@^lGod;_5om2kaOl000000ooRe<T00ol0003oi]K6onKFaP03onKFaP03o`000?oXelCo
j=O400Goj=O400Go0000oo7c_ooalkoolO>oo`000003oo7c_P05o`000?oalkkolO>no`000?oDnZd0
0_l0000Wooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo0ol0
000Pooooo`03o`000?oYg/OojMk700CojMk700?o0000on7:`_oQb/801_oQb/800ol0003oh<W1on39
`@06on39`@05o`000?oOb<;oglS2omo8`_l000001_oB^;l00ol0003odKO0om6g`005om6g`003o`00
0?o>]L7oc[G100?oc[G100Go0000ol2Y`_o0ZL;o`:W2o`000007okfW``03o`000?nhYLGo^:G500Go
^:G500?o0000ok>Raol000000onPV<`00ol0003oV9C>oiRDcP04oiRDcP;o00000on?Sll00ol0003o
Q8[AohB:d@02o`0000;oEWKF00Ko0000odM/e?m7K=Co0000ocQSdOl00002obUIc@03o`000?lJClWo
000000;o000000?o02ngo`000?l000000_l000001?l09[7o02Nao`0^]_l0;[H2o`000003o`E0`OlH
C<Oo64c700;o;EW<00Co0000od9VdOm2I]7o00000omFLm<01?l0003oJGkDofUne?l00004og^7e003
o`000?n:Sm?oRXoC00;oRXoC00?o0000oiNFdOnGU]400_nGU]400ol0003oXYc?oj:Lc`05oj:Lc`03
o`000?nm//ko_K;>00Co_K;>00?o0000olFfboo5]//01?o5]//00ol0003obkW8ol^ib005ol^ib003
o`000?o@^lGo000000Coh]C900?o0000onKFa_oVe/H01?oVe/H00ol0003oj=O4onSGa003onSGa0;o
00000ooalkl01_l0003olO>noo7c__oalkko0000oo7c_P;o000000Coe?Z]o`000?oooooo00009_oo
ool00ol0003oooooooooo`07ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`03o`000?oYg/Oo
jMk700?ojMk700?o0000on3:`_l000002?oQb/800ol0003oh<W1on39`@06on39`@03o`000?oOb<;o
000000Sod[Ro00?o0000om6g`?oA]l001OoA]l000ol0003oc[G1olje`@02olje`@03o`000?o0ZL;o
`:W200;o`:W20_l00006okfW``03o`000?nhYLGo^:G500Go^:G500?o0000oj2Hc?nPV<`00onPV<`2
o`0000KoV9C>00Go0000ohn?con?SlooSho?o`000002ohB:d@;o00000_mFM]H01_l0003oAfcDodM/
e?l0003o>6?Ao`0000;o:EW=00?o0000oaY?bOl000000_l000001?l0;kOo0000o`000?l00002o`0V
/@04o`0W/Ol0;[Ko03Nlo`0000;o1D310_lHC<L2obeIc004o`000?m2I]7o@VKAo`0000?oEW?C00Co
0000ofUne?mYO]Co00001?mkQm@00ol0003oRXoCohZ?d`02ohZ?d`03o`000?nGU]7oUiKA00;oUiKA
00?o0000oj:LconRW<l00onRW<l2o`0000Oo_K;>00?o0000olFfboo5]//01?o5]//00ol0003obkW8
ol^ib005ol^ib003o`000?oRe<Woh]C900Coh]C900?o0000onKFa_oVe/H00ooVe/H00ol0003oj=O4
onSGa002onSGa003o`000?o_m<?o000000?olO>o00Co0000oo7c__oalkkolO>n0ol000000ooDnZgo
0000ooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01oooool001oooooo
0_l0000Fooooo`?o00009oooool01Ol0003ojMk7onWNaooYg/Oo000000?oh<[200?o0000on7:`_oQ
b/801_oQb/800ol0003oh<W1on39`@06on39`@;o00002OoB^;l00ol0003odKO0om6g`005om6g`004
o`000?o>]L7oc[G1o`0000Oo`:W200?o0000okfW`onmYl<01?nmYl<2o`0000Go^:G500?o0000ojJL
bonPV<`01OnPV<`00ol0003oV9C>oiRDcP04oiRDcP09o`000?n?SlooSho?ohn?col0003oQ8[Ao`00
0?mSO]So000000;oEWKF00Ko0000odM/e?m7K=Co0000ocQSdOl00002obUIc@;o000000Co03Zoo`00
0?l0003o02ng0ol00002o`0V/@04o`000?l0;[Ko03Nlo`0000;o1D310_lHC<L2obeIc004o`000?m2
I]7o@VKAo`0000;oEW?C00Go0000ofUne?mYO]CoJGkDo`000004og^7e003o`000?n:Sm?oRXoC00;o
RXoC00?o0000oiNFdOnGU]400_nGU]401Ol0003oXYc?oj:LconRW<oo000000;o]:gB00?o0000okfb
c_nm//h01?nm//h00ol0003oaKK;olFfb`04olFfb`03o`000?o;^LSobkW800GobkW800?o0000on;D
bOoRe<T01?oRe<T00ol0003oi]K6onKFaP04onKFaP04o`000?oXelCoj=O4o`0000;okoC300Go0000
oo7c_ooalkoolO>oo`000003oo7c_P05o`000?o@mjOo0000omCj[Ol000001?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;o
oooo0ol0000Zooooo`04o`000?oYg/OojMk7o`0000Goh<[200?o0000on7:`_oQb/801_oQb/800ol0
003oh<W1on39`@05on39`@03o`000?oD^Koo000000Wod[Ro00?o0000om6g`?oA]l001OoA]l000ol0
003oc[G1o`000008ol2Y`P03o`000?nmYl?o_JO300Go_JO300Go0000okRUaOnhYLGo^:G5o`000003
ojJLb`03o`000?nPV<coX9S<00?oX9S<0_l00005oiRDcP04o`000?n?SlooSho?ohn?c`;o00000_mS
O]P01?l0003oEWKFoeIfe_l00002odM/e003o`000?lhHm7o000000;o:EW=0_l000001Ol0>[oo0000
o`000?l0003o02Vc00Ko000000So03Nlo`000?l0003o0000oaQ<aol0003o;EW<o`0000?o@VKA00Co
0000oeIcdomFLm?o00000omYO]@01Ol0003oNhODog^7e?mkQmCo000000GoRXoC00?o0000oiNFdOnG
U]400_nGU]400ol0003oXYc?o`000004okB]dP03o`000?nm//ko_K;>00Co_K;>00?o0000olFfboo5
]//01?o5]//00ol0003obkW8ol^ib003ol^ib003o`000?oMd/go000000Koh]C900?o0000onKFa_oV
e/H00ooVe/H00ol0003oj=O4o`000003onod``05o`000?oalkoolO>ooo7c_ol000000ooalkh2o`00
0003omCj[Ol0003ooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool03oooool3o`0002gooooo00?o0000onWNaol000001ooPb/800ol0
003ohL[2on7:`P05on7:`P03o`000?oPbL7oh<W100Coh<W100Go0000omBi_ooD^Kooe;Voo`000009
om:h_`03o`000?oA]l3odKO000GodKO000?o0000ol2Y`_o0ZL802?o0ZL82o`0000Ko_JO300Co0000
okRUaOnhYLGo00001?nVW</2o`0000GoX9S<00?o0000oiRDc_nHU<h00onHU<h01_l0003oSho?ohn?
col0003oKhGIo`0000;oHgkH00Co0000oeIfe_mFM]Ko00000_m7K=@02?l0003o>6?Ao`000?lYFLgo
0000o`11`ol0003o03Zo1_l000001?l0:kCo0000o`0^]_l00002o`Q4``;o000000Co64c7o`000?l]
FLco00000_m2I]401Ol0003oEW?CoeIcdomFLm?o000000;oJGkD00?o0000og^7e?mkQm@00_mkQm@0
0ol0003oRXoCohZ?d`03ohZ?d`04o`000?nGU]7oUiKAoiNFd@;o00001_nd[M800ol0003o_K;>okfb
cP04okfbcP03o`000?o5]/_oaKK;00CoaKK;00Go0000ol^ib?o;^LSobkW8o`000002omgBc@03o`00
0?oRe<Woh]C900Coh]C900?o0000onKFa_oVe/H01?oVe/H00ol0003okoC3onod``02onod``05o`00
0?oalkoolO>ooo7c_ol000000_oalkh01Ol0003od?NWo`000?oDnZgo000000Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Oooool00ol0
003oh<[2on3:`P06on3:`P03o`000?oQb/;ohL[200KohL[200?o0000on39`OoPbL400_oPbL400ol0
003oe;VoomBi_`03omBi_`03o`000?oB^;ood[Ro00Ood[Ro00?o0000om6g`?oA]l001?oA]l000ol0
003o`j_1o`00000:ol2Y`P03o`000?nmYl?o_JO300Co_JO300?o0000okRUaOl000001_nVW</00ol0
003oX9S<oj2Hc003oj2Hc003o`000?nHU<koV9C>00?oV9C>0_l00003ofn5f@04o`000?mSO]SoHgkH
o`0000;oEWKF00Go0000odM/e?m7K=Co0000ocQSd@03o`000003o`11`ol0003o03Zo00Co000000Co
02Nbo`000?l0:kCo00000_l0=k`3o`Q4``;o00000_l]FL`01?l0003o@VKAod9VdOl00002oeIcd`05
o`000?mYO]CoJGkDofUne?l000001?mkQm@00ol0003oRXoCohZ?d`03ohZ?d`05o`000?nGU]7o0000
ojRWeOl000001_nd[M800ol0003o_K;>okfbcP05okfbcP03o`000?o5]/_oaKK;00CoaKK;00?o0000
ol^ib?l000001?oMd/d00ol0003oh]C9on;Db@04on;Db@03o`000?oVe/Koi]K600?oi]K600?o0000
onod`oo_m<<00_o_m<<01_l0003olO>ooo7c_ooalkoo0000oo7c_P?o00000_oDnZd00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool000Cooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000:ooooo`?o0000
=?ooool00ol0003oh<[2on3:`P07on3:`P03o`000?oQb/;ohL[200KohL[200Go0000on39`OoPbL7o
h<W1o`000006omBi_`03o`000?oB^;ood[Ro00Ood[Ro00?o0000om6g`?oA]l000_oA]l001?l0003o
`j_1ol>[`Oo3Zl42o`0000Wo`:W200?o0000okfW`onmYl<01?nmYl<00ol0003oYYc;ojJLb`06ojJL
b`03o`000?nPV<coX9S<00?oX9S<0_l00004oiRDcP;o00000om_QMT00ol0003oHgkHof=nf002o`00
0004oeIfe_l0003oAfcDodM/e0;o000000[o3E;=o`000?l0003o0473o`000?l0>[oo0000o`0[]Ol0
003o02Rc0_l000001?l0:kCo02feo`0g_?l0=k`2o`Q4``;o75;:00Co0000obeIc?l]FLco00000_m2
I]401?l0003oEW?CoeIcdol00003ofUne003o`000?mkQmCoNhOD00;oNhOD00?o0000ohZ?don:Sm<0
0_n:Sm<2o`0000?oZ:OE00?o0000okB]d_nd[M801?nd[M800ol0003o_K;>okfbcP04okfbcP03o`00
0?o5]/_oaKK;00GoaKK;00?o0000omgBcOoMd/d00ooMd/d00ol0003oh]C9on;Db@04on;Db@03o`00
0?oVe/Koi]K600;oi]K60_l00004onod``04o`000?oalkoolO>ooo7c_`?o000000Cod?NWo`000?oD
nZgo00002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool01_ooool3o`0003Sooooo00?o0000on3:`_oPb/801ooPb/800ol0003ohL[2on7:`P06
on7:`P03o`000?oPbL7o000000Soe;Vo00?o0000om:h_ooB^;l01ooB^;l01?l0003odKO0om6g`?l0
0006ol>[`@03o`000?o0ZL;o`:W200Oo`:W20_l00004okfW``03o`000?n/WlWoYYc;00OoYYc;0_l0
0005oj2Hc007o`000?nHU<koV9C>oiRDc_l0003oNhcIo`000003ofn5f@07o`000?mSO]SoHgkHof=n
f?l0003oEWKFo`000002odM/e0;o000000So3E;=o`000?l0003o0473o`000?l0>[oo0000o`0[]@;o
000000Ko02Vco`000?l0:kCo03Jko`0g_?l00002o`Q4``;o75;:0ol00002od9Vd@05o`000?mFLm?o
EW?CoeIcdol000000omYO]@00ol0003oNhODog^7e002og^7e006o`000?n:Sm?o0000o`000?nKX=So
00001?nXYmD00ol0003o]:gBokB]dP04okB]dP03o`000?nm//ko_K;>00Co_K;>00?o0000olFfboo5
]//00oo5]//2o`0000KogM;=00?o0000on;DbOoRe<T01?oRe<T01_l0003oi]K6onKFa_l0003okOC7
o`0000CokoC300_o0000oo7c_ooalkoolO>oo`000?o<mZCo0000om3gYol0003oe?Z]o`000009oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`00
03cooooo00?o0000on3:`_oPb/801ooPb/800ol0003ohL[2on7:`P06on7:`P;o00002OoD^Kl2o`00
00Sod[Ro00?o0000om6g`?l000001oo3Zl42o`0000Wo`:W200Co0000okfW`onmYl?o00000on/WlT2
o`0000OoYYc;00?o0000oj2Hc?nPV<`00onPV<`00ol0003oV9C>o`000003og^<f@05o`000?m_QMWo
KhGIofn5fOl000000omSO]P02?l0003oEWKFo`000?m7K=Co0000oaMKdol0003o3E;=0_l000000ol0
@L?o0000o`000005o`0000;o02^d00Ko03Jko`0g_?l0003o24C3o`000?lLD/X2oc=Qd@;o00000_m2
I]401?l0003oEW?CoeIcdol00004ofUne003o`000?mkQmCoNhOD00?o00001?nKX=P00ol0003oZ:OE
ojRWe@02ojRWe@03o`000?nd[M;o]:gB00?o]:gB00?o0000okfbc_nm//h01Onm//h01Ol0003oaKK;
olFfboo5]/_o000000;oe/oB00?o0000omgBcOoMd/d00ooMd/d00ol0003oh]C9on;Db@04on;Db@03
o`000?oVe/Ko000000;okOC700?o0000onod`oo_m<<00_o_m<<01?l0003olO>ooo7c_ooalkl2o`00
0004om3gYol0003oe?Z]o`0000_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06
ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooooooool3o`00043ooooo00?o0000on3:`_oPb/801ooPb/800ol0003ohL[2on7:
`P05on7:`P03o`000?oE^[oo000000[oe;Vo00?o0000om:h_ooB^;l01_oB^;l00ol0003o`j_1ol>[
`@08ol>[`@;o00002?o0ZL800ol0003o_JO3o`000005ojbOb@03o`000?nVW<_oYYc;00GoYYc;00?o
0000oj2Hc?nPV<`00onPV<`2o`0000CoNhcI0_l00002ofn5f@;o00000_mSO]P01?l0003oEWKFo`00
0?l00002oaMKd`05o`000?l=D/go0000o`000?l0@L<01_l000001?l0;[Oo0000o`000?l0=[/2o`E4
a003o`Q4`ol0003o75;:00?o<f7A1?l00002oeIcd`03o`000?mYO]CoJGkD00Co00000_n:UmX00ol0
003oVj3Hoi^Pf003oi^Pf005o`000?nXYmGoZ:OEojRWeOl000001_nd[M800ol0003o_K;>okfbcP05
okfbcP03o`000?o5]/_o000000?oe/oB00?o0000omgBcOoMd/d00ooMd/d00ol0003oh]C9on;Db@05
on;Db@05o`000?o]m<OokOC7ongdaol000001?o_m<<01ol0003olO>ooo7c_ol0003oc?JTo`000?o@
mjL00_l0000=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool4o`0004Cooooo00?o0000on3:`_oP
b/801_oPb/800ol0003ohL[2on7:`P04on7:`P05o`000?oE^[ooeKZoomFj_ol000002_oD^Kl00ol0
003od[Room:h_`05om:h_`03o`000?o5[<7o000000[o`j_100?o0000ol2Y`_o0ZL801_o0ZL800ol0
003o[9o9ojbOb@05ojbOb@;o00001_nVW</2o`0000?oX9S<00?o0000ohFBfOl000001OmkS=T01Ol0
003oKhGIofn5fOm_QMWo000000;oHgkH00Co0000oeIfe_l0003o00000_lGFm<01Ol0003o3E;=o`00
0?l0003o047300?o000000Go02^do`000?l0003o0000o`0b^@02o`0f^`;o1DC400?o0000oaaBb_lL
D/X00_lcHM400ol0003oBW3FodY`eP06o`0000;oMhcJ00?o0000ohZGf_n:UmX00_n:UmX00ol0003o
Vj3Hoi^Pf002oi^Pf003o`000?nXYmGoZ:OE00;oZ:OE00?o0000okB]d_nd[M801?nd[M800ol0003o
_K;>okfbcP04okfbcP;o00001OoFcm800ol0003ogM;=omgBc@03omgBc@03o`000?oRe<Woh]C900?o
h]C90_l00003ongda`03o`000?o_m<?okoC300;okoC300?o0000oo7c_ol000000_l000000oo@mjOo
0000o`00000?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool001kooooo
0_l00017ooooo`03o`000?oPb/;oh<[200Koh<[200?o0000on7:`_oQb/800_oQb/800ol0003oeKZo
omFj_`03omFj_`;o00002OoD^Kl00ol0003od[Room:h_`03om:h_`04o`000?o5[<7oaJc1olF/`@;o
00002Oo3Zl42o`0000Ko`:W200?o0000ok2Rb?n/WlT01on/WlT2o`0000KoYYc;00Co0000oj2Hc?nP
V<co00000_n5T]T2o`0000CoNhcI0_l00002ofn5f@03o`000?mSO]SoHgkH00;o000000Ko8fGHo`00
0?lGFm?o5e_Co`000?l=D/d:o`000003o`0b^Ol0=[_o03Jk00;o1DC400?o0000oaaBb_l000000_lc
HM401?l0003oBW3FodY`e_l00002of5nf@03o`000?mgS=[oMhcJ00;oMhcJ00?o0000ohZGf_n:UmX0
0_n:UmX00ol0003oVj3Hoi^Pf002oi^Pf003o`000?nXYmGoZ:OE00;oZ:OE00?o0000okB]d_nd[M80
1?nd[M800ol0003o_K;>okfbcP02okfbcP03o`000?o>b]Oo000000Goe/oB00?o0000omgBcOoMd/d0
0ooMd/d00ol0003oh]C9on;Db@02on;Db@03o`000?oZllgo000000?okOC700?o0000onod`oo_m<<0
0_o_m<<3o`000004olcfY?l0003od?NWo`00013ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`008?ooool00ol0003oooooooooo`15ooooo`03o`000?oPb/;oh<[200Koh<[2
00Go0000on7:`_oQb/;ohL[2o`000007omFj_`03o`000?oD^Kooe;Vo00Ooe;Vo00?o0000om:h_ooB
^;l00_oB^;l00ol0003oaJc1olF/`@03olF/`@;o00002Oo3Zl400ol0003o`:W2ol2Y`P02ol2Y`P04
o`000?n`X/So/:;8ok2Rb0;o00001on/WlT00ol0003oYYc;ojJLb`04ojJLb`;o00001On5T]T00ol0
003oNhcIog^<f@03og^<f@04o`000?m_QMWoKhGIo`0000;oHgkH0_l000001_lSIMSo0000oaMKdolG
Fm?o0000o`eBc@Go000000Go02jfo`000?l0;[Oo02jgo`000002o`0f^`06o`11`ol5A<Co6E?=oaUC
cOlLD/[o00000_lcHM401?l0003oBW3FodY`e_l00002of5nf@05o`000?mgS=[oMhcJogN<f_l00000
1?n:UmX00ol0003oVj3Hoi^Pf002oi^Pf003o`000?nXYmGoZ:OE00?oZ:OE00?o0000okB]d_nd[M80
0ond[M801Ol0003o_K;>okfbc_nm//ko000000?oc/[G00?o0000omK?d_oFcm800ooFcm800ol0003o
gM;=omgBc@03omgBc@04o`000?oRe<Woh]C9o`0000;oj_?=00Go0000ongdaoo]m<OokOC7o`000004
onod``06o`000?o8mJCo0000o`000?o@mjOo00004_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000on3:`_oPb/801_oP
b/800ol0003ohL[2o`000009omFj_`03o`000?oD^Kooe;Vo00Ooe;Vo00Co0000om:h_ooB^;oo0000
2?o5[<400ol0003o`j_1ol>[`@07ol>[`@;o00000_o0ZL800ol0003o/:;8ok2Rb003ok2Rb0;o0000
1_n/WlT2o`0000GoYYc;0_l00005ohFBf@;o00001?mkS=T02Ol0003oKhGIofn5fOl0003oHgkHo`00
0?l^Kmgo0000ob=Uf002o`000003oaMKdol0003o3E;=00Go000000Wo02jfo`000?l0;[Oo0000o`0b
^Ol0=[_o0000o`11`ol5A<@00_lIDld01?l0003o<f7Aoc=QdOl00003odY`eP04o`000?mQO]WoHGkI
o`0000?oMhcJ00?o0000ohZGf_n:UmX00_n:UmX00ol0003oVj3Hoi^Pf002oi^Pf003o`000?nXYmGo
Z:OE00?oZ:OE00?o0000okB]d_nd[M800ond[M800ol0003o_K;>o`000004olk:e`03o`000?oFcm;o
e/oB00?oe/oB00?o0000omgBcOoMd/d00ooMd/d00ol0003oh]C9o`000003on[cc@05o`000?o]m<Oo
kOC7ongdaol000000oo_m<<3o`000003olcfY?l0003o000001Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`05ooooo`008_ooool00ol0003oooooooooo`14ooooo`03o`000?oPb/;o
h<[200Ooh<[20_l0000:omFj_`;o00002?oD^Kl00ol0003od[Roo`000009olF/`@;o00002Oo3Zl40
0ol0003o`:W2o`000007ok2Rb003o`000?n/WlWo[9o900Go[9o900?o0000ojJLbonVW</00_nVW</0
1?l0003oSYSHo`000?l00005ohFBf@;o00000omkS=T2o`000003ofn5fOl0003o000000;o;VoM00Wo
0000ob=Uf?lSIMSo0000oaMKdol0003o3E;=o`000?l0?<000ol000001?l0;[Ko0000o`000?l0=;/2
o`0000;o047300Co1DC4oaUCcOlIDlgo00000_lcHM401?l0003oBW3FodY`e_l00002of5nf@03o`00
0?mgS=[oMhcJ00;oMhcJ00?o0000ohZGf_n:UmX00_n:UmX00ol0003oVj3Hoi^Pf002oi^Pf003o`00
0?nXYmGoZ:OE00;oZ:OE00?o0000okB]d_nd[M800ond[M82o`0000Goc/[G00?o0000omK?d_oFcm80
0ooFcm800ol0003ogM;=omgBc@04omgBc@03o`000?oZllgoj_?=00;oj_?=00Go0000ongdaoo]m<Oo
kOC7o`000002onod``?o000000?oc?JTo`000?l000005_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo000Sooooo`;o0000AOooool00ol0003oh<[2on3:`P06on3:`P03o`00
0?oE^l3o000000_oeKZo00?o0000omBi_ooD^Kl01_oD^Kl00ol0003oaJc1olF/`@0:olF/`@;o0000
2?o3Zl400ol0003o/:;8ok2Rb007ok2Rb0;o00001_n/WlT2o`0000;oYYc;00Co0000ohjHf?n>V=So
SYSH0_l00005ohFBf@03o`000?mkS=WoNhcI00;oNhcI00Co0000ofn5fOl0003o00000_l^Kmd01ol0
003o8fGHob=Uf?l0003o5e_Co`000?l=D/d01Ol000001_l0;[Ko0000o`000?l0003o03_0o`0000;o
047300?o0000oaUCcOlIDld00ol00003odY`eP04o`000?mQO]WoHGkIo`0000?oMhcJ00?o0000ohZG
f_n:UmX00_n:UmX00ol0003oVj3Hoi^Pf002oi^Pf003o`000?nXYmGoZ:OE00?oZ:OE00Oo0000okB]
d_nd[M;o]:gBo`000?o3aM_o000000Koc/[G00?o0000omK?d_oFcm800ooFcm800ol0003ogM;=omgB
c@03omgBc@03o`000?oZllgoj_?=00;oj_?=00So0000ongdaoo]m<OokOC7o`000?o_m<?o0000olGf
Y`;o000000?oc?JTo`000?ooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Gooooo000Uooooo`03o`000?oooooooooo04?ooooo00?o0000on3:`_oPb/801?oPb/801?l0003o
eK_0omFk`?oE^l02o`0000[oeKZo00?o0000omBi_ooD^Kl01OoD^Kl00ol0003oajk1o`00000<olF/
`@03o`000?o3Zl7o`j_100Go`j_100?o0000okBTb?l000002On`X/P2o`0000Ko[9o90_l00006ohjH
f003o`000?n5T]WoQI;I00?oQI;I0_l00003og^<f@;o000000Co>g[So`000?l^Kmgo;VoM0_l00000
0olSIMSo0000oaMKd`02o`000003o`12a?l0003o000000Ko000000Ko03_0o`000?l0@L?o0473o`00
0?lIDld2obmTe@;o00000om:L=H01?l0003oHGkIof5nfOl00003ogN<fP03o`000?n:Um[oRYOJ00;o
RYOJ00?o0000oi^Pf?nKX=P00_nKX=P00ol0003oZ:OEojRWe@03ojRWe@03o`000?nd[M;o000000?o
`lGK00?o0000olk:eoo>b]L00oo>b]L00ol0003oe/oBomK?dP03omK?dP03o`000?oMd/gogM;=00;o
gM;=0_l00004on[cc@04o`000?o]m<OokOC7ongda`;o000000GoaOJWo`000?l0003oc?JTo`00000I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o0000oooo
ooooool0@oooool00ol0003oh<[2on3:`P02on3:`P03o`000?oE^l3oeK_000CoeK_000?o0000omFj
_ooE^[l02?oE^[l2o`0000Coe;Vo00?o0000olN^`Oo7[/400_o7[/42o`0000[oaJc10_l00004ol>[
`@03o`000?ndY<So]:C800;o]:C80_l00008ok2Rb003o`000?n/WlWo[9o900Co[9o90_l00006ohjH
f0;o00001On5T]T01?l0003oNhcIog^<fOmkS=T2o`000003oc]jhol0003o000000;o;VoM00?o0000
ob=Uf?l000000ol000000ol0@/Co0000o`000004o`000003o`0d^ol0003o03_000;o047300?o3E3<
oaUCcOlIDld00ol_I=D2o`000003odY`e_l0003oHGkI00;oHGkI00Co0000ogN<f_mgS=[o00001On:
UmX01Ol0003oVj3Hoi^Pf?nKX=So000000GoZ:OE0_l00004ol?5f`03o`000?o>b]Ooc/[G00Coc/[G
00?o0000omK?d_oFcm800ooFcm801_l0003ogM;=omgBcOl0003oiO;Do`0000Coj_?=00Go0000ongd
aoo]m<OokOC7o`000002olGfY`?o00006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Go0000on3:`_oPb/;oh<[2o`000007
omFk`003o`000?oE^[ooeKZo00WoeKZo00Co0000omBi_ooD^Koo00001oo7[/400ol0003oaJc1olF/
`@09olF/`@;o00000_o3Zl400ol0003o]:C8okBTb004okBTb0;o00001on`X/P2o`0000Co[9o900Co
0000oiJLf?l0003o00001_n>V=P2o`0000CoQI;I0_l000001?mkS=Wo0000odN4iol00002oc]jh`04
o`000?l^Kmgo;VoMo`0000;o8fGH0ol000000ol0@/Co0000o`000003o`0000;o03Bk0_l0>l001Ol0
@L?o0000o`e@c?lIDlgo000000;o;fCE0_m8M]`3o`0000;oHGkI00Go0000ogN<f_mgS=[oMhcJo`00
0004ohZGfP03o`000?nKX=SoVj3H00;oVj3H00?o0000ojRWeOl000000_l000000one_N3o0000ol?5
f`04ol?5f`03o`000?o>b]Ooc/[G00?oc/[G00?o0000omK?d_oFcm800ooFcm800ol0003ogM;=o`00
0002onGbe003o`000?oZllgoj_?=00;oj_?=00?o0000ongdaoo]m<L00_l000001?o5mZOo0000o`00
0?l0000Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Sooooo0_l0
0014ooooo`03o`000?oPb/;o000000WoeK_00_l0000:omFj_`03o`000?oD^Koo000000Soajk10_l0
000;olF/`@03o`000?o3Zl7o000000So]:C80_l00007ok2Rb0;o00000_n/WlT01?l0003oUYcHoiJL
f?nFW=P2o`0000KoSYSH0_l00004ohFBf@;o00000_m7Q>L2o`000004oc]jhol0003o0000obi_g@;o
000000Go8fGHo`000?l0BLOo0000o`12a004o`000003o`0c^_l0003o000000;o03_000Co0000o`e@
c?l=D<co00000ol_I=D4odQfg0Co00000omgS=X00ol0003oRYOJohZGfP02ohZGfP03o`000?nKX=So
Vj3H00?o00001One_N000ol0003o`lGKol?5f`02ol?5f`03o`000?o>b]Ooc/[G00Coc/[G00?o0000
omK?d_oFcm800_oFcm82o`0000?oiO;D00?o0000on[ccOoZlld00_oZlld02?l0003okOC7o`000?l0
003oaOJWo`000?o8mJCo00007_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Co
oooo000Zooooo`03o`000?oooooooooo04;ooooo0_l0000;omFk`003o`000?oE^[ooeKZo00SoeKZo
00?o0000olN^`Oo7[/402Oo7[/42o`0000[oaJc100?o0000okBTb?ndY<P02OndY<P00ol0003o/:;8
ok2Rb006ok2Rb0;o00001_nFW=P2o`0000KoSYSH0_l00003ohFBf@;o00000om7Q>L2o`000006oc]j
hol0003o;VoMobi_gOl0003o8fGH0ol000000ol0@/Co0000o`000004o`000004o`0m`Ol0003o04S8
o`0000;o3E3<0_l000000ol_I=Go0000odQfg002odQfg0?oHHSR1Ol00003ohZGfPCo00000_nT/n<0
0ol0003o]KgPokFmh003okFmh003o`000?o3aM_o`lGK00?o`lGK00?o0000olk:eoo>b]L00oo>b]L0
0ol0003oe/oBomK?dP02o`000003omk_g?l0003oiO;D00?oiO;D00Co0000on[ccOoZllgoj_?=0_l0
00000oo2mjko0000olGfY`02o`00023ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`04ooooo`00:oooool00ol0003oooooooooo`13ooooo`03o`000?oE^l3oeK_000WoeK_00_l00008
omFj_`03o`000?o9/<7o000000_oajk10_l00008olF/`@03o`000?nhY/So000000[o]:C80_l00007
ok2Rb0;o00001onFW=P3o`0000GoSYSH00Go0000ohFBfOn5T]Wo0000oeB?j`02o`0000?oAhCW00Go
0000oc]jhol0003o0000obi_g@02o`000004o`1Bbol0003o0000o`12a0?o000000Co03Vmo`000?l0
003o00000_l0B<P01?l0003o3E3<ob1Re_lPH]H2obmTe@04o`000?m8M]coB7KLodQfg0?oHHSR0omj
VN@4o`0000;oT:OU00?o0000ojBchonT/n<00_nT/n<00ol0003o]KgPokFmh003okFmh003o`000?o3
aM_o`lGK00?o`lGK00?o0000olk:eoo>b]L00_o>b]L00ol0003oe/oBo`000003omk_g003o`000?oU
l]CoiO;D00;oiO;D00So0000on[ccOoZllgoj_?=o`000?o2mjko0000olGfY`;o00008_ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000/ooooo`03o`000?oooooooooo04?o
oooo0_l0000;omFk`003o`000?oE^[ooeKZo00CoeKZo00?o0000olV``Oo9/<400_o9/<42o`0000[o
ajk10_l00005olF/`@03o`000?nhY/So^:K800;o^:K80ol00008okBTb0;o00001On`X/P00ol0003o
W:7Ho`000002o`0000OoUYcH0_l00004ohjHf0?o00000omDSn/2o`0000;oAhCW0_l000000olkN^?o
0000obi_g@02o`000003o`1Bbol0003o000000;o000000Co03Vko`000?l0>Kgo03Vm0_l00002o`18
b006o`e@c?l0003o86;Fob1Re_l_I=Go00000om8M]`01?l0003oHHSRof68h_mQR>83ogZIi003o`00
0?n@YnGoT:OU00?oT:OU00Go0000ojBchonT/n?oY;?So`000005okFmh003o`000?o3aM_o`lGK00?o
`lGK00?o0000olk:eoo>b]L00_o>b]L2o`0000Cog^oL00?o0000onGbe?oUl]@00_oUl]@00ol0003o
j_?=on[cc@02o`000004ol;g[_l0003oaOJWo`0002?ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`04ooooo`00;Oooool2o`0004Gooooo00?o0000omFk`?oE^l002OoE^l000ol0003o
eKZoomFj_`03omFj_`03o`000?o9/<7obK3100CobK310_l0000:olN^`@05o`000?o5[<7oaJc1olF/
`Ol000002?nhY/P2o`0000So]:C80_l00003ok2Rb003o`000?nLXMSoW:7H00;oW:7H0_l00007oiJL
f0;o00001?n>V=P2o`0000CoE8o[0_l00002odN4i`03o`000?lkN^?o000000?o000000?o05;;o`00
0?l000000_l000001?l0>K_o0000o`0i_Ol0>Kd2o`0000;o04S800Go3E3<o`000?lPH]Ko86;Fo`00
0004odQfg004o`000?mQR>;oHHSRo`0000?oNYWT00?o0000oi2WiOn@YnD00_n@YnD00ol0003oY;?S
ojBch`02ojBch`03o`000?ne_N3o]KgP00?o]KgP00?o0000ol?5foo3aM/00oo3aM/01_l0003oc/[G
olk:eol0003oe>_Uo`0000Cog^oL00?o0000onGbe?oUl]@00_oUl]@02?l0003oj_?=o`000?l0003o
`_N^o`000?o5mZOo00009Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
000_ooooo`03o`000?oooooooooo04?ooooo00?o0000omFk`?oE^l002OoE^l02o`0000;oeKZo00?o
0000olV``Oo9/<401oo9/<42o`0000Woajk10_l000000oo5[<7o0000okRVb009okRVb0;o00002?nd
Y<P3o`0000OoW:7H0_l00007oiJLf0;o00000_n>V=P01?l0003oHIW^o`000?l00004oeB?j`;o0000
00OoAhCWo`000?l0003o>g[So`000?l0Floo000000;o05;;1ol000000ol0AlSo04S8o`18b003o`00
00;o86;F0_l00002odQfg005o`000?mQR>;oHHSRof68h_l000000_mjVN@00ol0003oT:OUoi2Wi@02
oi2Wi@03o`000?nT/n?oY;?S00;oY;?S00?o0000okFmh?ne_N000one_N000ol0003o`lGKol?5f`03
ol?5f`03o`000?o>b]Oo000000;oe>_U00?o0000omk_g?oNkm`00_oNkm`00ol0003oiO;DonGbe002
onGbe0;o000000?o__Vgo`000?o2mjh00_l0000Wooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool01?ooool0033ooooo00?o0000ooooooooool0@oooool2o`0000_oeK_000?o0000omFj
_ol000002oo9/<400ol0003oajk1olN^`@08olN^`@03o`000?nhY/So^:K800_o^:K80_l00008okBT
b0;o00002?nLXMP3o`0000KoUYcH0ol00003of6IkP;o00001?mDSn/00ol0003oAhCWodN4i`06o`00
0006o`1Bbol0003o0000o`0n^_l0003o03Vk0_l000000ol0AlSo0000o`000002o`MGdP;o86;F0_lg
M^43o`0000?oHHSR00Go0000ogZIi?mjVNCoNYWTo`000004oi2Wi@03o`000?nT/n?oY;?S00;oY;?S
00?o0000okFmh?ne_N000_ne_N000ol0003o`lGKol?5f`03ol?5f`;o00000ooDjnD00ol0003og^oL
omk_g002omk_g004o`000?oUl]CoiO;DonGbe0;o000000?o__Vgo`000?o2mjh00_l0000Yooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0037ooooo0_l00015ooooo`03o`00
0?oE^l3oeK_000WoeK_000?o0000olV``Oo9/<402oo9/<42o`0000Soajk100Co0000okZYb?l0003o
00003?nhY/P2o`0000Ko]:C800?o0000oj:Ueol000000_l00008oibQf0;o00001_nFW=P2o`0000Co
HIW^0_l00003oeB?j`;o00000_m7Q>L00ol0003o06GCo`000005o`000003o`0n^_l0003o000000;o
00000_l0AlP01Ol0003o1eOBo`MGd_lPH]Ko000000Co=gKQ0_l00002of68hP05o`000?mjVNCoNYWT
ogZIi?l000000on@YnD00ol0003oY;?SojBch`02ojBch`03o`000?ne_N3o]KgP00?o]KgP00?o0000
ol?5foo3aM/00_l000000oo6hnco0000omC[i@02omC[i@03o`000?oNkmcog^oL00;og^oL00Go0000
onGbe?oUl]Co0000ok[ka002o`0000;o`_N^00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00?ooooo000cooooo`03o`000?oooooooooo04?ooooo0_l00009
omFk`004o`000?o://;o0000o`0000cobK310_l00005olN^`@03o`000?njZLSo^ZW800?o^ZW80_l0
000;okRVb0?o00000ondY<P00ol0003oXZGGoj:Ue`02oj:Ue`;o00002?nLXMP2o`0000CoUYcH00Co
0000offRl?l0003o00001?mQVNh3o`0000;oE8o[0_l000002?m7Q>Oo0000o`000?l0IM?o0000o`1K
col0003o05;;0_l000001?l0?[[o0000o`000?l00002o`17b005o`000?l7Em;o1eOBob1Re_l00000
0olgM^42oe6<jP?o00000omjVN@00ol0003oT:OUoi2Wi@02oi2Wi@03o`000?nT/n?oY;?S00;oY;?S
00?o0000okFmh?ne_N000_ne_N000ol0003o`lGKo`000003olKSk005o`000?oDjnGoe>_UomC[iOl0
00001?oNkm`01_l0003oiO;Do`000?njnlCo0000okki]`?o0000;?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00?ooooo000dooooo`03o`000?oooooooooo04Cooooo00?o0000omFk
`?oE^l001OoE^l000ol0003ob[;2olZb`P02olZb`P;o00003?o9/<42o`0000?oajk100?o0000okZY
b?njZLP01OnjZLP3o`0000_o^:K80ol00007oj:Ue`?o00001onLXMP4o`0000CoKJ;`0ol00004of6I
kP;o00000_mDSn/2o`000003o`1aeol0003o000000co00000_l7Em83o`0000;o=gKQ00?o0000oe6<
j_mAS>X00_mAS>X2o`0000;oNYWT00Go0000oi2WiOn@YnGoT:OUo`000004ojBch`04o`000?ne_N3o
]KgPokFmh0?o00001?o6hn`00ol0003oe>_UomC[i@02omC[i@04o`000?oNkmcog^oLomk_g0;o0000
00?o^__4o`000?nnnKL00_l0000_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool003Gooooo00?o0000ooooooooool0A?ooool00ol0003oeK_0omFk`003omFk`003o`000?o:
//;ob[;200Gob[;20_l0000<olV``@;o000000?oajk1o`000?njZLP02OnjZLP2o`0000_o^:K80ol0
0008oj:Ue`;o00002?nLXMP2o`0000KoKJ;`0_l00004of6IkP;o00000_mDSn/2o`000003o`1aeol0
003o000000Ko000000?o03jjo`000?l000001?l00002oaM[g@04o`000?lgM^7o=gKQo`0000?oDHcZ
0_m/X_43o`0000?oT:OU00Co0000ojBchonT/n?oY;?S1Ol00002okGHlP03o`000?o6hncoa^?/00;o
a^?/00?o0000omC[iOoDjnD00_oDjnD00ol0003og^oLomk_g002o`0000;o^__400?o0000okki]ol0
0000<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000fooooo`;o0000
AOooool2o`0000?oeK_000?o0000olZb`_o://801oo://82o`0000cobK3100?o0000okZYb?njZLP0
2onjZLP2o`0000Wo^:K800?o0000ojNXeonWZ=L00ol00007oj:Ue`?o00001OnLXMP00ol0003oNJ[b
o`000002o`0000GoKJ;`0_l00004of6IkP?o000000Co07gJo`000?l0003o077G2ol00002o`1Ec`06
o`000?lGJmgo5f_MoaM[gOlgM^7o00000omAS>X00ol0003oK:;aofbRl@02ofbRl@Oo00000_nObOD0
0ol0003o]MSbokGHlP02okGHlP03o`000?o6hncoa^?/00;oa^?/00?o0000omC[iOoDjnD00_oDjnD0
1_l0003og^oLo`000?ndnm?o0000ok[ka0?o0000<_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00?ooooo000hooooo`03o`000?oooooooooo04Cooooo00?o0000omFk`?l000003?o:
//82o`0000[obK3100Co0000okf[b?l0003o00003?njZLP3o`0000Ko^:K800?o0000ojNXeonWZ=L0
0onWZ=L3o`0000OoXZGG0_l00003oibQf003o`000?miZ_;oNJ[b00;oNJ[b0ol00004offRl0;o0000
1?mQVNh3o`000003o`1mf_l0003o000000;o000000?o06GCo`000?l000001ol000000ol0ELoo0000
oaM[g@02oaM[g@;o00000_mAS>X00ol0003oK:;aofbRl@02ofbRl@CoQ[Oe00?o0000oio9mOnObOD0
0_nObOD00ol0003o]MSbokGHlP02okGHlP03o`000?o6hncoa^?/00;oa^?/00?o0000omC[iOoDjnD0
0_oDjnD2o`000005okCkdol0003o^__4ok[ka?l00000=Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo00?o0000olZb`_o://80
3Oo://82o`0000OobK3100?o0000okf[b?nmZlP00onmZlP3o`0000_o^ZW80_l00003okRVb003o`00
0?nWZ=OoYjSG00OoYjSG0ol00006oj:Ue`Co00001omiZ_83o`0000?oKJ;`0ol000001?mQVNko0000
o`J:gOl6R]d3o`000003o`1mf_l0003o000000_o00000_lGJmd00ol0003o:X7YobZ1j@02oe6<jP03
o`000?m/X_7oK:;a00;oK:;a00Go0000ohJgmOn6]oGoQ[Oeo`000004oio9m@03o`000?nef?;o]MSb
00;o]MSb00?o0000olKSk?o6hn`00_o6hn`01?l0003oe>_UomC[iOoDjnD2o`0000;o]?_C00?o0000
ok[ka?l00000=oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000joooo
o`03o`000?oooooooooo04Gooooo0_l0000>olZb`P;o00001Oo9/<400ol0003o_J_8okf[b006okf[
b0?o00002_njZLP4o`0000coYjSG0ol00006oj:Ue`?o00002?miZ_83o`0000?oKJ;`0ol00004o`J:
g@Oo000000?o04nZo`000?l000000ol00002o`1Ue`;o00000olZPNT00omAS>[o0000ofbRl@03ofbR
l@05o`000?n6]oGoQ[OeohJgmOl000001OnObOD00ol0003o]MSbokGHlP02okGHlP04o`000?o6hnco
a^?/olKSk0Co000000?oZoWSo`000?ndnm<00ol0000iooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00_ooool003_ooooo0_l00018ooooo`;o00003Oo://82o`0000?obK3100?o0000
okf[b?nmZlP02OnmZlP2o`0000_o^ZW800?o0000ojNXeonWZ=L03OnWZ=L3o`0000?oXZGG00?o0000
oh>alon3/O<01?l00007ogVZlP?o00000_m]X_03o`0000Go1X[M1Ol00002o`1?ZPCo00000ol0IML0
1?l0003o:X7YobZ1jOlZPNT4o`000003ofbRlOl0003oQ[Oe00?oQ[Oe00?o0000oio9mOnObOD00_nO
bOD00ol0003o]MSbokGHlP02okGHlP03o`000?o6hncoa^?/00;o00000on[nN<01?l0003o]?_Co`00
0?l0000kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003gooooo00?o
0000ooooooooool0Aoooool3o`0000cob[;20ol0000>okf[b0?o00002?njZLP00ol0003o[:cGojb/
e`04o`0000coYjSG1?l00006oh>al`Go00001OmiZ_83o`0000;o4iSQ1Ol00003o`J:g@?o000000?o
A000o`000?l0CjX01_l00002obZ1j@03o`000?m0V_?o@9[c00;o@9[c1Ol000000on6]oGo0000oio9
m@03oio9m@03o`000?nef?;o]MSb00;o]MSb0ol000001OnMlO7o0000oj_ihon[nN?o000000;o]?_C
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
000nooooo`03o`000?oooooooooo04Wooooo0_l0000<olZb`P03o`000?nmZlSo_J_800oo_J_80ol0
0004okZYb003o`000?n/[=Oo[:cG00Ko[:cG1?l0000:ojNXe`Co00002?n3/O<4o`0000CoNJ[b1?l0
0003oa>Hh@Go000000Ko1X[Mo`000?m4003oA000o`000?l0CjX7o`0000Go@9[c00Co0000oeVeo?mI
]OcoFKGl3?l00002oigal@05o`000?n[nN?oZoWSo`000?ndnm<00_l0000oooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool003oooooo00?o0000ooooooooool0B_ooool2o`00
00[ob[;200?o0000okj^bOnn[/T01?l0000>okf[b0?o000000?o^ZW8o`000?n/[=L02on/[=L4o`00
00KoYjSG00Co0000ohfhlon=^??oSKSc1Ol00007oh>al`Go00000olRYND7o`000003oa>HhOl0003o
000000?o00000_m40008o`0000;o@9[c00?o0000oeVeo?mI]O`00_mI]O`00ol0003oL/koog;>o`02
og;>o`03o`000?n9ho_oRN?k00;oRN?k00Co0000oigalOnMlO7o00000_n[nN<3o`0004;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@?ooool2o`0004cooooo0ol00006
olZb`P03o`000?nn[/Wo_Zk900Go_Zk91?l0000=okf[b003o`000?n/[=Oo[:cG00oo[:cG1Ol00000
0onWZ=Oo0000ohfhl`07ohfhl`Ko00001On3/O<7o`0000Co8ZGU2?l000001Oll003oA000o`000?l0
003o066a00Oo00000_mI]O`00ol0003oL/koog;>o`02og;>o`03o`000?n9ho_oRN?k00;oRN?k00?o
0000oigalOnMlO401?l00015ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool004;ooooo00?o0000ooooooooool0C?ooool2o`0000Cob[;200?o0000okj^bOnn[/T02Onn[/T3
o`0000[o_J_800Co0000ok2_eon`[mOo/:oG1_l0000=ojb/e`Ko00002_n=^?<5o`000003oh>alol0
003o<k;Y00Co<k;Y3_l000000ol[003o=000o`000002oc8000Wo00000_mbc_l00ol0003oRN?kohWS
n`02ohWSn`Ko0000B?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0013
ooooo`03o`000?oooooooooo04gooooo0ol000000oo://;o0000okj^b@0=okj^b@Co00001_nmZlP0
0ol0003o/:oGok2_e`07ok2_e`Ko00002?n/[=L00ol0003oU[gcoiJml`02oiJml`So00001on=^?<I
o`0000;o80000_lb000Ao`0004_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01
ooooo`00A?ooool00ol0003oooooooooo`1?ooooo`03o`000?nn[/Wo_Zk9017o_Zk91?l000000onm
ZlSo0000ok2_e`0?ok2_e`Ko00000_n/[=L00ol0003oU[gcoiJml`0:oiJml`Oo00000_n=^?<00ol0
003oAKo^odFokP09odFokPco00000_l20003o`000003obh00?l0003o000000Co000000?o:K>ko`00
0?l000000_l0001?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Go
oooo0_l0001Booooo`Go00004?nn[/T2o`0001Ko/:oG3ol00007oiJmlaGo00000omZe_L7o`000003
od2nZ_oooooooooo05Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00
Aoooool00ol0003oooooooooo`1Dooooo`Go00003?nn[/T00ol0003o/k;Gok>be`02ok>be`Wo0000
2on`[mL00ol0003oWL;boig2lP0:oig2lQ7o00001_mZe_L<o`0005oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`01ooooo`00B?ooool00ol0003oooooooooo`1Hooooo`Go00001onn
[/T00ol0003o/k;Gok>be`0;ok>be`So00000on`[mL00ol0003oWL;boig2lP0Eoig2lP03o`000?mZ
e_OoJ]Kg00;oJ]Kg1ol00002ogcMnPGo0000IOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo0019ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool00_ooool5
o`000003okj^bOl0003o/k;G01Go/k;G8?l00004ogcMnPGo0000Joooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000Eoooool00ol0003oooooooooo`07oooo
o`;o00006Onc/]L00ol0003oXlGaoj?5l@0Foj?5l@03o`000?mlgO[oO=gj00Go0000L?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001<ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool03Oooool9o`0000co/k;G00?o0000oj?5lOnSaO404OnSaO48o`0007Ko
oooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0Fooooo`Wo00000onc/]L00ol0003oXlGaoj?5l@04oj?5l@go0000
Ooooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00C_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo01oooooo2_l0002<ooooo`03o`000?oooooooooo00Oooooo0Ol0
0001ooooo`7ooooo001?ooooo`;o0000D_ooool00ol0003oooooooooo`2fooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0]oooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00D_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool005?ooooo0_l0001>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool005Gooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00E_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool00oooool1o`00007ooooo001Goooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`02oooo
o`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo0;_ooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
_?ooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0_Oooool01?l0003oooooooooool00001ooooo`00G?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooool000000Oooool005gooooo0_l0
0014ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool00Ol0000005oooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`2oooooo`7o00000Oooool1o`000000H?ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo0_l00000067ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000?oooool00ol0003ooooo
ooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2c
ooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`oooo
o`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:cooooo1?l0000Booooo`00
JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0000Fooooo`00J_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000Jooooo`00Joooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000Nooooo`00K?ooool2o`00
03Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool00ol0003ooooooooo
o`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2>
ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:oooo
o`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co
0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0000mooooo`00Mooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l00011ooooo`00N?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015ooooo`00NOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019ooooo`00N_ooool2o`0002Ko
oooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0003oooooooooo`1Soooo
o`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Oooooo`Co
0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`Co0000
I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000J?oo
ool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/ooooo`00Q_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`ooooo`00Qoooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00R?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROooool2o`0001Oooooo00?o
0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003oooooooooo`0dooooo`Co0000
Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`Co0000Sooo
ool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`?o0000Toooool0
09;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00U?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2o`0000Sooooo00?o0000
ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000]_oo
ool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002Oooooo`03o`000?oooooo
000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o000000;o0000`Oooool00:7o
oooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.68821e-16 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51724 .65311 m .51694 .65827 L .43899 .65168 L p .604 .781 .966 r
F P
0 g
s
.51694 .65827 m .51724 .65311 L .59273 .65263 L p .291 .774 .917 r
F P
0 g
s
.59273 .65263 m .59527 .65394 L .51694 .65827 L p .291 .774 .917 r
F P
0 g
s
.67023 .63881 m .59634 .65373 L p .665 .64142 L .077 0 0 r
F P
0 g
s
.66528 .6413 m .67023 .63881 L p .665 .64142 L .077 0 0 r
F P
0 g
s
.66507 .64141 m .59634 .65373 L .59719 .6536 L .077 0 0 r
F
.59634 .65373 m .59527 .65394 L p .59719 .6536 L F P
0 g
s
.59527 .65394 m .59273 .65263 L .66507 .64141 L p .077 0 0 r
F P
0 g
s
.65984 .64422 m .66507 .64141 L .59273 .65263 L p .152 0 0 r
F P
0 g
s
.65802 .64441 m .65984 .64422 L p .65645 .64464 L .152 0 0 r
F P
0 g
s
.65455 .64706 m .65984 .64422 L .65802 .64441 L p .21 0 0 r
F P
0 g
s
.59273 .65263 m .59016 .65141 L .65637 .64458 L p .152 0 0 r
F P
0 g
s
.65637 .64458 m .65802 .64441 L p .65721 .64451 L .152 0 0 r
F P
0 g
s
.65721 .64451 m .59273 .65263 L .65637 .64458 L .152 0 0 r
F
.65645 .64464 m .59273 .65263 L .65802 .64441 L F
.65802 .64441 m .59016 .65141 L p .65131 .64727 L .21 0 0 r
F P
0 g
s
.65455 .64706 m .65802 .64441 L .65131 .64727 L .21 0 0 r
F
.59016 .65141 m .58757 .65017 L .64821 .64735 L p F P
0 g
s
.64821 .64735 m .65455 .64706 L p .65128 .64728 L .21 0 0 r
F P
0 g
s
.65128 .64728 m .59016 .65141 L .64821 .64735 L .21 0 0 r
F
.64918 .64973 m .65455 .64706 L .58764 .65017 L p .252 0 0 r
F P
0 g
s
.64918 .64973 m .58764 .65017 L .5876 .65017 L .252 0 0 r
F
.58764 .65017 m .58757 .65017 L p .5876 .65017 L F P
0 g
s
.58757 .65017 m .58494 .6488 L .64034 .6496 L p .252 0 0 r
F P
0 g
s
.64034 .6496 m .64918 .64973 L p .64446 .64977 L .252 0 0 r
F P
0 g
s
.64446 .64977 m .58757 .65017 L .64034 .6496 L .252 0 0 r
F
.64373 .65205 m .64918 .64973 L .58688 .64883 L p .283 0 0 r
F P
0 g
s
.64373 .65205 m .58688 .64883 L .58588 .64885 L .283 0 0 r
F
.58688 .64883 m .58494 .6488 L p .58588 .64885 L F P
0 g
s
.58494 .6488 m .58227 .64718 L .63268 .65118 L p .283 0 0 r
F P
0 g
s
.63268 .65118 m .64373 .65205 L p .63762 .65172 L .283 0 0 r
F P
0 g
s
.63762 .65172 m .58494 .6488 L .63268 .65118 L .283 0 0 r
F
.63819 .65383 m .64373 .65205 L .58587 .64746 L p .302 0 0 r
F P
0 g
s
.63819 .65383 m .58587 .64746 L .58408 .64739 L .302 0 0 r
F
.58587 .64746 m .58227 .64718 L p .58408 .64739 L F P
0 g
s
.58227 .64718 m .57957 .64519 L .62519 .65191 L p .302 0 0 r
F P
0 g
s
.62519 .65191 m .63819 .65383 L p .63072 .65294 L .302 0 0 r
F P
0 g
s
.63072 .65294 m .58227 .64718 L .62519 .65191 L .302 0 0 r
F
.63256 .65486 m .63819 .65383 L .58465 .64594 L p .31 0 0 r
F P
0 g
s
.63256 .65486 m .58465 .64594 L .58222 .64567 L .31 0 0 r
F
.58465 .64594 m .57957 .64519 L p .58222 .64567 L F P
0 g
s
.57957 .64519 m .57683 .64272 L .61781 .65165 L p .31 0 0 r
F P
0 g
s
.61781 .65165 m .63256 .65486 L p .62374 .65325 L .31 0 0 r
F P
0 g
s
.62374 .65325 m .57957 .64519 L .61781 .65165 L .31 0 0 r
F
.62683 .65498 m .63256 .65486 L .58325 .64412 L p .304 0 0 r
F P
0 g
s
.62683 .65498 m .58325 .64412 L .5803 .64357 L .304 0 0 r
F
.58325 .64412 m .57683 .64272 L p .5803 .64357 L F P
0 g
s
.57683 .64272 m .57406 .63967 L .61054 .65025 L p .304 0 0 r
F P
0 g
s
.61054 .65025 m .62683 .65498 L p .61666 .65249 L .304 0 0 r
F P
0 g
s
.61666 .65249 m .57683 .64272 L .61054 .65025 L .304 0 0 r
F
.621 .65401 m .62683 .65498 L .58169 .64189 L p .28 0 0 r
F P
0 g
s
.61507 .65182 m .621 .65401 L .57998 .63912 L p 0 .349 .67 r
F P
0 g
s
.57998 .63912 m .57124 .63594 L p .57636 .63779 L 0 .349 .67 r
F P
0 g
s
.61507 .65182 m .57998 .63912 L .57636 .63779 L 0 .349 .67 r
F
.58169 .64189 m .57406 .63967 L p .57834 .64098 L .28 0 0 r
F P
0 g
s
.621 .65401 m .58169 .64189 L .57834 .64098 L .28 0 0 r
F
.66507 .64141 m .66528 .6413 L p .665 .64142 L .077 0 0 r
F P
0 g
s
.4423 .64294 m .43899 .65168 L .36521 .63435 L p .706 .723 .863 r
F P
0 g
s
.43899 .65168 m .4423 .64294 L .51724 .65311 L p .604 .781 .966 r
F P
0 g
s
.51755 .64793 m .51724 .65311 L .4423 .64294 L p .579 .761 .965 r
F P
0 g
s
.51724 .65311 m .51755 .64793 L .59016 .65141 L p .219 .727 .893 r
F P
0 g
s
.59016 .65141 m .59273 .65263 L .51724 .65311 L p .219 .727 .893 r
F P
0 g
s
.36521 .63435 m .37158 .62253 L .4423 .64294 L p .706 .723 .863 r
F P
0 g
s
.44563 .6341 m .4423 .64294 L .37158 .62253 L p .694 .708 .858 r
F P
0 g
s
.4423 .64294 m .44563 .6341 L .51755 .64793 L p .579 .761 .965 r
F P
0 g
s
.51786 .6427 m .51755 .64793 L .44563 .6341 L p .552 .738 .962 r
F P
0 g
s
.51755 .64793 m .51786 .6427 L .58757 .65017 L p .157 .681 .875 r
F P
0 g
s
.58757 .65017 m .59016 .65141 L .51755 .64793 L p .157 .681 .875 r
F P
0 g
s
.37158 .62253 m .37797 .61055 L .44563 .6341 L p .694 .708 .858 r
F P
0 g
s
.44898 .6252 m .44563 .6341 L .37797 .61055 L p .68 .692 .854 r
F P
0 g
s
.44563 .6341 m .44898 .6252 L .51786 .6427 L p .552 .738 .962 r
F P
0 g
s
.67023 .63881 m .66507 .64141 L .73047 .61969 L p .097 0 0 r
F P
0 g
s
.73047 .61969 m .73799 .61332 L .67023 .63881 L p .097 0 0 r
F P
0 g
s
.51817 .63739 m .51786 .6427 L .44898 .6252 L p .524 .711 .957 r
F P
0 g
s
.51786 .6427 m .51817 .63739 L .58494 .6488 L p .108 .64 .866 r
F P
0 g
s
.58494 .6488 m .58757 .65017 L .51786 .6427 L p .108 .64 .866 r
F P
0 g
s
.37797 .61055 m .38439 .59853 L .44898 .6252 L p .68 .692 .854 r
F P
0 g
s
.45235 .61628 m .44898 .6252 L .38439 .59853 L p .664 .675 .851 r
F P
0 g
s
.44898 .6252 m .45235 .61628 L .51817 .63739 L p .524 .711 .957 r
F P
0 g
s
.37158 .62253 m .36521 .63435 L .29943 .6068 L p .766 .716 .806 r
F P
0 g
s
.29943 .6068 m .30878 .59262 L .37158 .62253 L p .766 .716 .806 r
F P
0 g
s
.37797 .61055 m .37158 .62253 L .30878 .59262 L p .759 .704 .801 r
F P
0 g
s
.38439 .59853 m .39083 .58659 L .45235 .61628 L p .664 .675 .851 r
F P
0 g
s
.45575 .60741 m .45235 .61628 L .39083 .58659 L p .646 .657 .847 r
F P
0 g
s
.45235 .61628 m .45575 .60741 L .51848 .63195 L p .495 .681 .949 r
F P
0 g
s
.51848 .63195 m .51817 .63739 L .45235 .61628 L p .495 .681 .949 r
F P
0 g
s
.66507 .64141 m .65984 .64422 L .72286 .62638 L p .155 0 0 r
F P
0 g
s
.72286 .62638 m .73047 .61969 L .66507 .64141 L p .155 0 0 r
F P
0 g
s
.51817 .63739 m .51848 .63195 L .58227 .64718 L p .072 .603 .866 r
F P
0 g
s
.58227 .64718 m .58494 .6488 L .51817 .63739 L p .072 .603 .866 r
F P
0 g
s
.30878 .59262 m .31814 .57826 L .37797 .61055 L p .759 .704 .801 r
F P
0 g
s
.38439 .59853 m .37797 .61055 L .31814 .57826 L p .75 .693 .797 r
F P
0 g
s
.31814 .57826 m .3275 .56389 L .38439 .59853 L p .75 .693 .797 r
F P
0 g
s
.39083 .58659 m .38439 .59853 L .3275 .56389 L p .739 .681 .794 r
F P
0 g
s
.39083 .58659 m .39729 .57487 L .45575 .60741 L p .646 .657 .847 r
F P
0 g
s
.45916 .59862 m .45575 .60741 L .39729 .57487 L p .626 .638 .843 r
F P
0 g
s
.45575 .60741 m .45916 .59862 L .5188 .62637 L p .467 .65 .938 r
F P
0 g
s
.5188 .62637 m .51848 .63195 L .45575 .60741 L p .467 .65 .938 r
F P
0 g
s
.3275 .56389 m .33686 .54973 L .39083 .58659 L p .739 .681 .794 r
F P
0 g
s
.39729 .57487 m .39083 .58659 L .33686 .54973 L p .726 .668 .793 r
F P
0 g
s
.51848 .63195 m .5188 .62637 L .57957 .64519 L p .05 .57 .871 r
F P
0 g
s
.57957 .64519 m .58227 .64718 L .51848 .63195 L p .05 .57 .871 r
F P
0 g
s
.33686 .54973 m .3462 .53595 L .39729 .57487 L p .726 .668 .793 r
F P
0 g
s
.40376 .56348 m .39729 .57487 L .3462 .53595 L p .711 .655 .792 r
F P
0 g
s
.39729 .57487 m .40376 .56348 L .45916 .59862 L p .626 .638 .843 r
F P
0 g
s
.4626 .58996 m .45916 .59862 L .40376 .56348 L p .603 .618 .839 r
F P
0 g
s
.45916 .59862 m .4626 .58996 L .51913 .6206 L p .439 .617 .926 r
F P
0 g
s
.51913 .6206 m .5188 .62637 L .45916 .59862 L p .439 .617 .926 r
F P
0 g
s
.65984 .64422 m .65455 .64706 L .71514 .63315 L p .198 0 0 r
F P
0 g
s
.71514 .63315 m .72286 .62638 L .65984 .64422 L p .198 0 0 r
F P
0 g
s
.3462 .53595 m .35552 .52275 L .40376 .56348 L p .711 .655 .792 r
F P
0 g
s
.41023 .55253 m .40376 .56348 L .35552 .52275 L p .693 .64 .792 r
F P
0 g
s
.40376 .56348 m .41023 .55253 L .4626 .58996 L p .603 .618 .839 r
F P
0 g
s
.73799 .61332 m .73047 .61969 L .78508 .58812 L p 0 0 0 r
F P
0 g
s
.78508 .58812 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.5188 .62637 m .51913 .6206 L .57683 .64272 L p .04 .541 .879 r
F P
0 g
s
.57683 .64272 m .57957 .64519 L .5188 .62637 L p .04 .541 .879 r
F P
0 g
s
.46606 .58147 m .4626 .58996 L .41023 .55253 L p .579 .597 .835 r
F P
0 g
s
.4626 .58996 m .46606 .58147 L .51945 .61461 L p .411 .584 .911 r
F P
0 g
s
.51945 .61461 m .51913 .6206 L .4626 .58996 L p .411 .584 .911 r
F P
0 g
s
.35552 .52275 m .36482 .5103 L .41023 .55253 L p .693 .64 .792 r
F P
0 g
s
.41672 .54214 m .41023 .55253 L .36482 .5103 L p .673 .625 .793 r
F P
0 g
s
.41023 .55253 m .41672 .54214 L .46606 .58147 L p .579 .597 .835 r
F P
0 g
s
.65455 .64706 m .64918 .64973 L .70731 .63975 L p .23 0 0 r
F P
0 g
s
.70731 .63975 m .71514 .63315 L .65455 .64706 L p .23 0 0 r
F P
0 g
s
.36482 .5103 m .37408 .49875 L .41672 .54214 L p .673 .625 .793 r
F P
0 g
s
.42322 .5324 m .41672 .54214 L .37408 .49875 L p .65 .608 .793 r
F P
0 g
s
.41672 .54214 m .42322 .5324 L .46954 .57319 L p .553 .575 .831 r
F P
0 g
s
.46954 .57319 m .46606 .58147 L .41672 .54214 L p .553 .575 .831 r
F P
0 g
s
.30878 .59262 m .29943 .6068 L .24558 .56996 L p .817 .742 .782 r
F P
0 g
s
.46606 .58147 m .46954 .57319 L .51978 .60839 L p .386 .551 .895 r
F P
0 g
s
.51978 .60839 m .51945 .61461 L .46606 .58147 L p .386 .551 .895 r
F P
0 g
s
.24558 .56996 m .25762 .55437 L .30878 .59262 L p .817 .742 .782 r
F P
0 g
s
.31814 .57826 m .30878 .59262 L .25762 .55437 L p .813 .733 .777 r
F P
0 g
s
.25762 .55437 m .26965 .53858 L .31814 .57826 L p .813 .733 .777 r
F P
0 g
s
.3275 .56389 m .31814 .57826 L .26965 .53858 L p .807 .724 .774 r
F P
0 g
s
.26965 .53858 m .28164 .52286 L .3275 .56389 L p .807 .724 .774 r
F P
0 g
s
.33686 .54973 m .3275 .56389 L .28164 .52286 L p .799 .715 .772 r
F P
0 g
s
.51913 .6206 m .51945 .61461 L .57406 .63967 L p .042 .513 .886 r
F P
0 g
s
.57406 .63967 m .57683 .64272 L .51913 .6206 L p .042 .513 .886 r
F P
0 g
s
.28164 .52286 m .29357 .50744 L .33686 .54973 L p .799 .715 .772 r
F P
0 g
s
.3462 .53595 m .33686 .54973 L .29357 .50744 L p .788 .705 .772 r
F P
0 g
s
.29357 .50744 m .30543 .49259 L .3462 .53595 L p .788 .705 .772 r
F P
0 g
s
.35552 .52275 m .3462 .53595 L .30543 .49259 L p .776 .694 .773 r
F P
0 g
s
.30543 .49259 m .31722 .47852 L .35552 .52275 L p .776 .694 .773 r
F P
0 g
s
.36482 .5103 m .35552 .52275 L .31722 .47852 L p .761 .682 .775 r
F P
0 g
s
.37408 .49875 m .38332 .48825 L .42322 .5324 L p .65 .608 .793 r
F P
0 g
s
.42973 .52338 m .42322 .5324 L .38332 .48825 L p .624 .589 .794 r
F P
0 g
s
.42322 .5324 m .42973 .52338 L .47304 .56515 L p .525 .552 .825 r
F P
0 g
s
.47304 .56515 m .46954 .57319 L .42322 .5324 L p .525 .552 .825 r
F P
0 g
s
.73047 .61969 m .72286 .62638 L .77541 .59834 L p 0 0 0 r
F P
0 g
s
.77541 .59834 m .78508 .58812 L .73047 .61969 L p 0 0 0 r
F P
0 g
s
.31722 .47852 m .32892 .46546 L .36482 .5103 L p .761 .682 .775 r
F P
0 g
s
.37408 .49875 m .36482 .5103 L .32892 .46546 L p .743 .669 .778 r
F P
0 g
s
.32892 .46546 m .34053 .45361 L .37408 .49875 L p .743 .669 .778 r
F P
0 g
s
.38332 .48825 m .37408 .49875 L .34053 .45361 L p .722 .654 .782 r
F P
0 g
s
.46954 .57319 m .47304 .56515 L .52011 .60189 L p .362 .519 .879 r
F P
0 g
s
.52011 .60189 m .51978 .60839 L .46954 .57319 L p .362 .519 .879 r
F P
0 g
s
.38332 .48825 m .39254 .47892 L .42973 .52338 L p .624 .589 .794 r
F P
0 g
s
.43626 .51516 m .42973 .52338 L .39254 .47892 L p .596 .569 .794 r
F P
0 g
s
.42973 .52338 m .43626 .51516 L .47656 .55738 L p .496 .528 .82 r
F P
0 g
s
.47656 .55738 m .47304 .56515 L .42973 .52338 L p .496 .528 .82 r
F P
0 g
s
.34053 .45361 m .35206 .44313 L .38332 .48825 L p .722 .654 .782 r
F P
0 g
s
.39254 .47892 m .38332 .48825 L .35206 .44313 L p .697 .637 .785 r
F P
0 g
s
.51945 .61461 m .51978 .60839 L .57124 .63594 L p .052 .487 .888 r
F P
0 g
s
.57124 .63594 m .57406 .63967 L .51945 .61461 L p .052 .487 .888 r
F P
0 g
s
.64918 .64973 m .64373 .65205 L .69935 .64591 L p .255 0 0 r
F P
0 g
s
.69935 .64591 m .70731 .63975 L .64918 .64973 L p .255 0 0 r
F P
0 g
s
.35206 .44313 m .36352 .43418 L .39254 .47892 L p .697 .637 .785 r
F P
0 g
s
.40173 .47084 m .39254 .47892 L .36352 .43418 L p .668 .617 .789 r
F P
0 g
s
.39254 .47892 m .40173 .47084 L .43626 .51516 L p .596 .569 .794 r
F P
0 g
s
.47304 .56515 m .47656 .55738 L .52045 .59511 L p .34 .489 .862 r
F P
0 g
s
.52045 .59511 m .52011 .60189 L .47304 .56515 L p .34 .489 .862 r
F P
0 g
s
.44281 .50779 m .43626 .51516 L .40173 .47084 L p .564 .547 .794 r
F P
0 g
s
.43626 .51516 m .44281 .50779 L .48011 .5499 L p .466 .504 .813 r
F P
0 g
s
.48011 .5499 m .47656 .55738 L .43626 .51516 L p .466 .504 .813 r
F P
0 g
s
.72286 .62638 m .71514 .63315 L .76561 .60869 L p 0 0 0 r
F P
0 g
s
.76561 .60869 m .77541 .59834 L .72286 .62638 L p 0 0 0 r
F P
0 g
s
.36352 .43418 m .37491 .42687 L .40173 .47084 L p .668 .617 .789 r
F P
0 g
s
.41093 .46411 m .40173 .47084 L .37491 .42687 L p .635 .595 .792 r
F P
0 g
s
.40173 .47084 m .41093 .46411 L .44281 .50779 L p .564 .547 .794 r
F P
0 g
s
.51978 .60839 m .52011 .60189 L .56839 .63144 L p .068 .461 .885 r
F P
0 g
s
.56839 .63144 m .57124 .63594 L .51978 .60839 L p .068 .461 .885 r
F P
0 g
s
.44938 .5013 m .44281 .50779 L .41093 .46411 L p .53 .523 .793 r
F P
0 g
s
.44281 .50779 m .44938 .5013 L .48368 .54272 L p .436 .48 .806 r
F P
0 g
s
.48368 .54272 m .48011 .5499 L .44281 .50779 L p .436 .48 .806 r
F P
0 g
s
.47656 .55738 m .48011 .5499 L .52079 .58803 L p .321 .462 .846 r
F P
0 g
s
.52079 .58803 m .52045 .59511 L .47656 .55738 L p .321 .462 .846 r
F P
0 g
s
.37491 .42687 m .38624 .42129 L .41093 .46411 L p .635 .595 .792 r
F P
0 g
s
.42012 .45876 m .41093 .46411 L .38624 .42129 L p .598 .57 .794 r
F P
0 g
s
.41093 .46411 m .42012 .45876 L .44938 .5013 L p .53 .523 .793 r
F P
0 g
s
.64373 .65205 m .63819 .65383 L .69124 .65138 L p .272 0 0 r
F P
0 g
s
.69124 .65138 m .69935 .64591 L .64373 .65205 L p .272 0 0 r
F P
0 g
s
.30485 .42044 m .3182 .40918 L .34053 .45361 L p .803 .731 .785 r
F P
0 g
s
.34053 .45361 m .32892 .46546 L .30485 .42044 L p .803 .731 .785 r
F P
0 g
s
.35206 .44313 m .34053 .45361 L .3182 .40918 L p .781 .716 .791 r
F P
0 g
s
.3182 .40918 m .3314 .39953 L .35206 .44313 L p .781 .716 .791 r
F P
0 g
s
.36352 .43418 m .35206 .44313 L .3314 .39953 L p .755 .698 .797 r
F P
0 g
s
.29135 .43313 m .30485 .42044 L .32892 .46546 L p .82 .744 .78 r
F P
0 g
s
.32892 .46546 m .31722 .47852 L .29135 .43313 L p .82 .744 .78 r
F P
0 g
s
.3314 .39953 m .34447 .39166 L .36352 .43418 L p .755 .698 .797 r
F P
0 g
s
.37491 .42687 m .36352 .43418 L .34447 .39166 L p .724 .677 .803 r
F P
0 g
s
.2777 .44702 m .29135 .43313 L .31722 .47852 L p .834 .755 .776 r
F P
0 g
s
.31722 .47852 m .30543 .49259 L .2777 .44702 L p .834 .755 .776 r
F P
0 g
s
.34447 .39166 m .35741 .38571 L .37491 .42687 L p .724 .677 .803 r
F P
0 g
s
.38624 .42129 m .37491 .42687 L .35741 .38571 L p .688 .652 .808 r
F P
0 g
s
.38624 .42129 m .39754 .41751 L .42012 .45876 L p .598 .57 .794 r
F P
0 g
s
.42933 .45483 m .42012 .45876 L .39754 .41751 L p .558 .543 .794 r
F P
0 g
s
.42012 .45876 m .42933 .45483 L .45598 .49571 L p .494 .498 .79 r
F P
0 g
s
.45598 .49571 m .44938 .5013 L .42012 .45876 L p .494 .498 .79 r
F P
0 g
s
.52011 .60189 m .52045 .59511 L .56549 .6261 L p .088 .437 .876 r
F P
0 g
s
.56549 .6261 m .56839 .63144 L .52011 .60189 L p .088 .437 .876 r
F P
0 g
s
.2639 .46187 m .2777 .44702 L .30543 .49259 L p .846 .765 .773 r
F P
0 g
s
.30543 .49259 m .29357 .50744 L .2639 .46187 L p .846 .765 .773 r
F P
0 g
s
.44938 .5013 m .45598 .49571 L .48728 .53585 L p .406 .455 .799 r
F P
0 g
s
.48728 .53585 m .48368 .54272 L .44938 .5013 L p .406 .455 .799 r
F P
0 g
s
.57406 .63967 m .57124 .63594 L .621 .65401 L p .28 0 0 r
F P
0 g
s
.71514 .63315 m .70731 .63975 L .75566 .61886 L p .024 0 0 r
F P
0 g
s
.75566 .61886 m .76561 .60869 L .71514 .63315 L p .024 0 0 r
F P
0 g
s
.48011 .5499 m .48368 .54272 L .52113 .58063 L p .303 .436 .83 r
F P
0 g
s
.52113 .58063 m .52079 .58803 L .48011 .5499 L p .303 .436 .83 r
F P
0 g
s
.35741 .38571 m .37025 .38177 L .38624 .42129 L p .688 .652 .808 r
F P
0 g
s
.39754 .41751 m .38624 .42129 L .37025 .38177 L p .647 .623 .811 r
F P
0 g
s
.24997 .47742 m .2639 .46187 L .29357 .50744 L p .854 .773 .772 r
F P
0 g
s
.29357 .50744 m .28164 .52286 L .24997 .47742 L p .854 .773 .772 r
F P
0 g
s
.79464 .57831 m .78508 .58812 L .82503 .5479 L p 0 0 0 r
F P
0 g
s
.8137 .56112 m .82503 .5479 L .78508 .58812 L p 0 0 0 r
F P
0 g
s
.82503 .5479 m .8137 .56112 L .81398 .56052 L p .822 .968 .652 r
F P
0 g
s
.83572 .53568 m .79464 .57831 L p .82503 .5479 L 0 0 0 r
F P
0 g
s
.81398 .56052 m .83422 .5164 L p .82503 .5479 L .822 .968 .652 r
F P
0 g
s
.82503 .5479 m .83625 .53514 L .83572 .53568 L p 0 0 0 r
F P
0 g
s
.23592 .49337 m .24997 .47742 L .28164 .52286 L p .86 .78 .772 r
F P
0 g
s
.28164 .52286 m .26965 .53858 L .23592 .49337 L p .86 .78 .772 r
F P
0 g
s
.37025 .38177 m .383 .37991 L .39754 .41751 L p .647 .623 .811 r
F P
0 g
s
.40882 .41556 m .39754 .41751 L .383 .37991 L p .601 .59 .812 r
F P
0 g
s
.39754 .41751 m .40882 .41556 L .42933 .45483 L p .558 .543 .794 r
F P
0 g
s
.63819 .65383 m .63256 .65486 L .68298 .65589 L p .282 0 0 r
F P
0 g
s
.68298 .65589 m .69124 .65138 L .63819 .65383 L p .282 0 0 r
F P
0 g
s
.43856 .45231 m .42933 .45483 L .40882 .41556 L p .514 .513 .792 r
F P
0 g
s
.42933 .45483 m .43856 .45231 L .46262 .49101 L p .456 .472 .787 r
F P
0 g
s
.46262 .49101 m .45598 .49571 L .42933 .45483 L p .456 .472 .787 r
F P
0 g
s
.22178 .50944 m .23592 .49337 L .26965 .53858 L p .863 .787 .774 r
F P
0 g
s
.26965 .53858 m .25762 .55437 L .22178 .50944 L p .863 .787 .774 r
F P
0 g
s
.52045 .59511 m .52079 .58803 L .56256 .61987 L p .108 .415 .863 r
F P
0 g
s
.56256 .61987 m .56549 .6261 L .52045 .59511 L p .108 .415 .863 r
F P
0 g
s
.45598 .49571 m .46262 .49101 L .49091 .52929 L p .376 .431 .791 r
F P
0 g
s
.49091 .52929 m .48728 .53585 L .45598 .49571 L p .376 .431 .791 r
F P
0 g
s
.48368 .54272 m .48728 .53585 L .52148 .57292 L p .288 .413 .815 r
F P
0 g
s
.52148 .57292 m .52113 .58063 L .48368 .54272 L p .288 .413 .815 r
F P
0 g
s
.383 .37991 m .39569 .38017 L .40882 .41556 L p .601 .59 .812 r
F P
0 g
s
.4201 .41543 m .40882 .41556 L .39569 .38017 L p .55 .554 .811 r
F P
0 g
s
.40882 .41556 m .4201 .41543 L .43856 .45231 L p .514 .513 .792 r
F P
0 g
s
.20758 .52532 m .22178 .50944 L .25762 .55437 L p .865 .793 .778 r
F P
0 g
s
.25762 .55437 m .24558 .56996 L .20758 .52532 L p .865 .793 .778 r
F P
0 g
s
.57124 .63594 m .56839 .63144 L .61507 .65182 L p 0 .349 .67 r
F P
0 g
s
.44784 .45118 m .43856 .45231 L .4201 .41543 L p .468 .482 .789 r
F P
0 g
s
.43856 .45231 m .44784 .45118 L .4693 .4872 L p .418 .445 .782 r
F P
0 g
s
.4693 .4872 m .46262 .49101 L .43856 .45231 L p .418 .445 .782 r
F P
0 g
s
.70731 .63975 m .69935 .64591 L .74554 .62854 L p .041 0 0 r
F P
0 g
s
.74554 .62854 m .75566 .61886 L .70731 .63975 L p .041 0 0 r
F P
0 g
s
.3368 .35392 m .35052 .34985 L .35741 .38571 L p .765 .752 .841 r
F P
0 g
s
.35741 .38571 m .34447 .39166 L .3368 .35392 L p .765 .752 .841 r
F P
0 g
s
.37025 .38177 m .35741 .38571 L .35052 .34985 L p .722 .72 .848 r
F P
0 g
s
.78508 .58812 m .77541 .59834 L .8137 .56112 L p 0 0 0 r
F P
0 g
s
.32292 .36005 m .3368 .35392 L .34447 .39166 L p .801 .779 .833 r
F P
0 g
s
.34447 .39166 m .3314 .39953 L .32292 .36005 L p .801 .779 .833 r
F P
0 g
s
.52079 .58803 m .52113 .58063 L .55959 .61271 L p .128 .395 .847 r
F P
0 g
s
.55959 .61271 m .56256 .61987 L .52079 .58803 L p .128 .395 .847 r
F P
0 g
s
.46262 .49101 m .4693 .4872 L .49457 .52303 L p .348 .408 .783 r
F P
0 g
s
.49457 .52303 m .49091 .52929 L .46262 .49101 L p .348 .408 .783 r
F P
0 g
s
.35052 .34985 m .36408 .34793 L .37025 .38177 L p .722 .72 .848 r
F P
0 g
s
.383 .37991 m .37025 .38177 L .36408 .34793 L p .673 .682 .85 r
F P
0 g
s
.39569 .38017 m .40836 .38252 L .4201 .41543 L p .55 .554 .811 r
F P
0 g
s
.43141 .41709 m .4201 .41543 L .40836 .38252 L p .498 .515 .806 r
F P
0 g
s
.4201 .41543 m .43141 .41709 L .44784 .45118 L p .468 .482 .789 r
F P
0 g
s
.63256 .65486 m .62683 .65498 L .65098 .65712 L p .285 0 0 r
F P
0 g
s
.66598 .66111 m .67456 .65921 L .62683 .65498 L p .276 0 0 r
F P
0 g
s
.62683 .65498 m .621 .65401 L .64045 .65708 L p .276 0 0 r
F P
0 g
s
.64045 .65708 m .66598 .66111 L p .64464 .65777 L .276 0 0 r
F P
0 g
s
.64464 .65777 m .62683 .65498 L .64045 .65708 L .276 0 0 r
F
.63672 .65649 m .621 .65401 L p .63222 .65629 L .25 0 0 r
F P
0 g
s
.65725 .66138 m .63672 .65649 L .63222 .65629 L .25 0 0 r
F
.621 .65401 m .61507 .65182 L .63001 .65521 L p F P
0 g
s
.63001 .65521 m .65725 .66138 L p .63122 .65609 L .25 0 0 r
F P
0 g
s
.63122 .65609 m .621 .65401 L .63001 .65521 L .25 0 0 r
F
.64836 .65987 m .65725 .66138 L .63263 .6558 L p .201 0 0 r
F P
0 g
s
.65725 .66138 m .66598 .66111 L .63672 .65649 L p .25 0 0 r
F P
0 g
s
.63933 .65644 m .64836 .65987 L .6283 .65395 L p 0 .436 .758 r
F P
0 g
s
.6283 .65395 m .60905 .64828 L p .62725 .65318 L 0 .436 .758 r
F P
0 g
s
.65688 .65738 m .63256 .65486 L .65098 .65712 L .285 0 0 r
F
.67456 .65921 m .68298 .65589 L .63256 .65486 L p F P
0 g
s
.63933 .65644 m .6283 .65395 L .62725 .65318 L 0 .436 .758 r
F
.63263 .6558 m .61507 .65182 L p .62924 .65525 L .201 0 0 r
F P
0 g
s
.64836 .65987 m .63263 .6558 L .62924 .65525 L .201 0 0 r
F
.65098 .65712 m .67456 .65921 L p .65688 .65738 L .285 0 0 r
F P
0 g
s
.48728 .53585 m .49091 .52929 L .52183 .56488 L p .274 .392 .801 r
F P
0 g
s
.52183 .56488 m .52148 .57292 L .48728 .53585 L p .274 .392 .801 r
F P
0 g
s
.30884 .36809 m .32292 .36005 L .3314 .39953 L p .83 .801 .823 r
F P
0 g
s
.3314 .39953 m .3182 .40918 L .30884 .36809 L p .83 .801 .823 r
F P
0 g
s
.36408 .34793 m .37751 .34824 L .383 .37991 L p .673 .682 .85 r
F P
0 g
s
.39569 .38017 m .383 .37991 L .37751 .34824 L p .619 .639 .849 r
F P
0 g
s
.56839 .63144 m .56549 .6261 L .60905 .64828 L p 0 .369 .753 r
F P
0 g
s
.60905 .64828 m .61507 .65182 L .56839 .63144 L p 0 .369 .753 r
F P
0 g
s
.29456 .37788 m .30884 .36809 L .3182 .40918 L p .854 .818 .813 r
F P
0 g
s
.3182 .40918 m .30485 .42044 L .29456 .37788 L p .854 .818 .813 r
F P
0 g
s
.45716 .45138 m .44784 .45118 L .43141 .41709 L p .422 .449 .784 r
F P
0 g
s
.44784 .45118 m .45716 .45138 L .47603 .48423 L p .38 .419 .776 r
F P
0 g
s
.47603 .48423 m .4693 .4872 L .44784 .45118 L p .38 .419 .776 r
F P
0 g
s
.37751 .34824 m .39085 .3508 L .39569 .38017 L p .619 .639 .849 r
F P
0 g
s
.40836 .38252 m .39569 .38017 L .39085 .3508 L p .56 .592 .842 r
F P
0 g
s
.40836 .38252 m .42101 .38695 L .43141 .41709 L p .498 .515 .806 r
F P
0 g
s
.44276 .42048 m .43141 .41709 L .42101 .38695 L p .444 .476 .798 r
F P
0 g
s
.43141 .41709 m .44276 .42048 L .45716 .45138 L p .422 .449 .784 r
F P
0 g
s
.28007 .38922 m .29456 .37788 L .30485 .42044 L p .872 .831 .804 r
F P
0 g
s
.30485 .42044 m .29135 .43313 L .28007 .38922 L p .872 .831 .804 r
F P
0 g
s
.52113 .58063 m .52148 .57292 L .55659 .60461 L p .145 .377 .831 r
F P
0 g
s
.55659 .60461 m .55959 .61271 L .52113 .58063 L p .145 .377 .831 r
F P
0 g
s
.4693 .4872 m .47603 .48423 L .49826 .51706 L p .321 .387 .774 r
F P
0 g
s
.49826 .51706 m .49457 .52303 L .4693 .4872 L p .321 .387 .774 r
F P
0 g
s
.49091 .52929 m .49457 .52303 L .52218 .55652 L p .263 .374 .789 r
F P
0 g
s
.52218 .55652 m .52183 .56488 L .49091 .52929 L p .263 .374 .789 r
F P
0 g
s
.69935 .64591 m .69124 .65138 L .73522 .63741 L p .05 0 0 r
F P
0 g
s
.73522 .63741 m .74554 .62854 L .69935 .64591 L p .05 0 0 r
F P
0 g
s
.39085 .3508 m .40411 .3556 L .40836 .38252 L p .56 .592 .842 r
F P
0 g
s
.42101 .38695 m .40836 .38252 L .40411 .3556 L p .5 .543 .832 r
F P
0 g
s
.77541 .59834 m .76561 .60869 L .80224 .57449 L p 0 0 0 r
F P
0 g
s
.80224 .57449 m .8137 .56112 L .77541 .59834 L p 0 0 0 r
F P
0 g
s
.26537 .40187 m .28007 .38922 L .29135 .43313 L p .885 .841 .796 r
F P
0 g
s
.29135 .43313 m .2777 .44702 L .26537 .40187 L p .885 .841 .796 r
F P
0 g
s
.56549 .6261 m .56256 .61987 L .60294 .64329 L p 0 .38 .809 r
F P
0 g
s
.60294 .64329 m .60905 .64828 L .56549 .6261 L p 0 .38 .809 r
F P
0 g
s
.46656 .45284 m .45716 .45138 L .44276 .42048 L p .377 .418 .776 r
F P
0 g
s
.45716 .45138 m .46656 .45284 L .48282 .48204 L p .343 .393 .769 r
F P
0 g
s
.48282 .48204 m .47603 .48423 L .45716 .45138 L p .343 .393 .769 r
F P
0 g
s
.40411 .3556 m .41734 .36261 L .42101 .38695 L p .5 .543 .832 r
F P
0 g
s
.43369 .39337 m .42101 .38695 L .41734 .36261 L p .442 .495 .818 r
F P
0 g
s
.42101 .38695 m .43369 .39337 L .44276 .42048 L p .444 .476 .798 r
F P
0 g
s
.45417 .42549 m .44276 .42048 L .43369 .39337 L p .393 .438 .788 r
F P
0 g
s
.44276 .42048 m .45417 .42549 L .46656 .45284 L p .377 .418 .776 r
F P
0 g
s
.52148 .57292 m .52183 .56488 L .55355 .59555 L p .161 .362 .814 r
F P
0 g
s
.55355 .59555 m .55659 .60461 L .52148 .57292 L p .161 .362 .814 r
F P
0 g
s
.25046 .41557 m .26537 .40187 L .2777 .44702 L p .895 .849 .79 r
F P
0 g
s
.2777 .44702 m .2639 .46187 L .25046 .41557 L p .895 .849 .79 r
F P
0 g
s
.47603 .48423 m .48282 .48204 L .50198 .51134 L p .296 .367 .766 r
F P
0 g
s
.50198 .51134 m .49826 .51706 L .47603 .48423 L p .296 .367 .766 r
F P
0 g
s
.49457 .52303 m .49826 .51706 L .52253 .54786 L p .252 .358 .778 r
F P
0 g
s
.52253 .54786 m .52218 .55652 L .49457 .52303 L p .252 .358 .778 r
F P
0 g
s
.69124 .65138 m .68298 .65589 L .72471 .64517 L p .051 0 0 r
F P
0 g
s
.72471 .64517 m .73522 .63741 L .69124 .65138 L p .051 0 0 r
F P
0 g
s
.56256 .61987 m .55959 .61271 L .59675 .6368 L p 0 .379 .836 r
F P
0 g
s
.59675 .6368 m .60294 .64329 L .56256 .61987 L p 0 .379 .836 r
F P
0 g
s
.36845 .32201 m .38169 .32458 L .37751 .34824 L p .659 .743 .912 r
F P
0 g
s
.37751 .34824 m .36408 .34793 L .36845 .32201 L p .659 .743 .912 r
F P
0 g
s
.39085 .3508 m .37751 .34824 L .38169 .32458 L p .594 .682 .902 r
F P
0 g
s
.35505 .32165 m .36845 .32201 L .36408 .34793 L p .718 .797 .913 r
F P
0 g
s
.36408 .34793 m .35052 .34985 L .35505 .32165 L p .718 .797 .913 r
F P
0 g
s
.23536 .43005 m .25046 .41557 L .2639 .46187 L p .902 .855 .786 r
F P
0 g
s
.2639 .46187 m .24997 .47742 L .23536 .43005 L p .902 .855 .786 r
F P
0 g
s
.41734 .36261 m .43055 .37173 L .43369 .39337 L p .442 .495 .818 r
F P
0 g
s
.44641 .40167 m .43369 .39337 L .43055 .37173 L p .387 .449 .803 r
F P
0 g
s
.43369 .39337 m .44641 .40167 L .45417 .42549 L p .393 .438 .788 r
F P
0 g
s
.38169 .32458 m .3948 .32939 L .39085 .3508 L p .594 .682 .902 r
F P
0 g
s
.40411 .3556 m .39085 .3508 L .3948 .32939 L p .529 .619 .885 r
F P
0 g
s
.34147 .32344 m .35505 .32165 L .35052 .34985 L p .77 .843 .907 r
F P
0 g
s
.35052 .34985 m .3368 .35392 L .34147 .32344 L p .77 .843 .907 r
F P
0 g
s
.76561 .60869 m .75566 .61886 L .79061 .58767 L p 0 0 0 r
F P
0 g
s
.79061 .58767 m .80224 .57449 L .76561 .60869 L p 0 0 0 r
F P
0 g
s
.47604 .45544 m .46656 .45284 L .45417 .42549 L p .334 .387 .768 r
F P
0 g
s
.46656 .45284 m .47604 .45544 L .48967 .48058 L p .309 .369 .762 r
F P
0 g
s
.48967 .48058 m .48282 .48204 L .46656 .45284 L p .309 .369 .762 r
F P
0 g
s
.52183 .56488 m .52218 .55652 L .55049 .58556 L p .175 .349 .799 r
F P
0 g
s
.55049 .58556 m .55355 .59555 L .52183 .56488 L p .175 .349 .799 r
F P
0 g
s
.46567 .432 m .45417 .42549 L .44641 .40167 L p .345 .401 .777 r
F P
0 g
s
.45417 .42549 m .46567 .432 L .47604 .45544 L p .334 .387 .768 r
F P
0 g
s
.3948 .32939 m .40782 .33644 L .40411 .3556 L p .529 .619 .885 r
F P
0 g
s
.41734 .36261 m .40411 .3556 L .40782 .33644 L p .466 .557 .864 r
F P
0 g
s
.32769 .32729 m .34147 .32344 L .3368 .35392 L p .813 .88 .894 r
F P
0 g
s
.3368 .35392 m .32292 .36005 L .32769 .32729 L p .813 .88 .894 r
F P
0 g
s
.49826 .51706 m .50198 .51134 L .52289 .53891 L p .243 .344 .768 r
F P
0 g
s
.52289 .53891 m .52253 .54786 L .49826 .51706 L p .243 .344 .768 r
F P
0 g
s
.48282 .48204 m .48967 .48058 L .50574 .50586 L p .274 .349 .759 r
F P
0 g
s
.50574 .50586 m .50198 .51134 L .48282 .48204 L p .274 .349 .759 r
F P
0 g
s
.22008 .44501 m .23536 .43005 L .24997 .47742 L p .906 .86 .785 r
F P
0 g
s
.24997 .47742 m .23592 .49337 L .22008 .44501 L p .906 .86 .785 r
F P
0 g
s
.40782 .33644 m .42076 .34567 L .41734 .36261 L p .466 .557 .864 r
F P
0 g
s
.43055 .37173 m .41734 .36261 L .42076 .34567 L p .408 .499 .84 r
F P
0 g
s
.55959 .61271 m .55659 .60461 L .59047 .62877 L p .027 .372 .839 r
F P
0 g
s
.59047 .62877 m .59675 .6368 L .55959 .61271 L p .027 .372 .839 r
F P
0 g
s
.31369 .33305 m .32769 .32729 L .32292 .36005 L p .846 .907 .878 r
F P
0 g
s
.32292 .36005 m .30884 .36809 L .31369 .33305 L p .846 .907 .878 r
F P
0 g
s
.43055 .37173 m .44379 .38286 L .44641 .40167 L p .387 .449 .803 r
F P
0 g
s
.45921 .4117 m .44641 .40167 L .44379 .38286 L p .339 .408 .787 r
F P
0 g
s
.44641 .40167 m .45921 .4117 L .46567 .432 L p .345 .401 .777 r
F P
0 g
s
.61507 .65182 m .60905 .64828 L .64836 .65987 L p .201 0 0 r
F P
0 g
s
.52218 .55652 m .52253 .54786 L .54739 .57469 L p .186 .338 .785 r
F P
0 g
s
.54739 .57469 m .55049 .58556 L .52218 .55652 L p .186 .338 .785 r
F P
0 g
s
.68298 .65589 m .67456 .65921 L .714 .65152 L p .042 0 0 r
F P
0 g
s
.714 .65152 m .72471 .64517 L .68298 .65589 L p .042 0 0 r
F P
0 g
s
.42076 .34567 m .43366 .35701 L .43055 .37173 L p .408 .499 .84 r
F P
0 g
s
.44379 .38286 m .43055 .37173 L .43366 .35701 L p .357 .448 .817 r
F P
0 g
s
.20465 .46012 m .22008 .44501 L .23592 .49337 L p .907 .864 .786 r
F P
0 g
s
.23592 .49337 m .22178 .50944 L .20465 .46012 L p .907 .864 .786 r
F P
0 g
s
.48562 .45907 m .47604 .45544 L .46567 .432 L p .296 .36 .759 r
F P
0 g
s
.47604 .45544 m .48562 .45907 L .4966 .47974 L p .279 .347 .755 r
F P
0 g
s
.4966 .47974 m .48967 .48058 L .47604 .45544 L p .279 .347 .755 r
F P
0 g
s
.47728 .43985 m .46567 .432 L .45921 .4117 L p .303 .369 .765 r
F P
0 g
s
.46567 .432 m .47728 .43985 L .48562 .45907 L p .296 .36 .759 r
F P
0 g
s
.29944 .34057 m .31369 .33305 L .30884 .36809 L p .871 .926 .859 r
F P
0 g
s
.30884 .36809 m .29456 .37788 L .29944 .34057 L p .871 .926 .859 r
F P
0 g
s
.83625 .53514 m .82503 .5479 L .84668 .50088 L p .827 .973 .665 r
F P
0 g
s
.84668 .50088 m .85906 .48583 L .83625 .53514 L p .827 .973 .665 r
F P
0 g
s
.75566 .61886 m .74554 .62854 L .77879 .60032 L p 0 0 0 r
F P
0 g
s
.77879 .60032 m .79061 .58767 L .75566 .61886 L p 0 0 0 r
F P
0 g
s
.50198 .51134 m .50574 .50586 L .52326 .52969 L p .236 .332 .759 r
F P
0 g
s
.52326 .52969 m .52289 .53891 L .50198 .51134 L p .236 .332 .759 r
F P
0 g
s
.55659 .60461 m .55355 .59555 L .58413 .61922 L p .077 .361 .83 r
F P
0 g
s
.58413 .61922 m .59047 .62877 L .55659 .60461 L p .077 .361 .83 r
F P
0 g
s
.48967 .48058 m .4966 .47974 L .50953 .50057 L p .255 .334 .752 r
F P
0 g
s
.50953 .50057 m .50574 .50586 L .48967 .48058 L p .255 .334 .752 r
F P
0 g
s
.44379 .38286 m .45708 .39584 L .45921 .4117 L p .339 .408 .787 r
F P
0 g
s
.47211 .42329 m .45921 .4117 L .45708 .39584 L p .297 .372 .771 r
F P
0 g
s
.45921 .4117 m .47211 .42329 L .47728 .43985 L p .303 .369 .765 r
F P
0 g
s
.60905 .64828 m .60294 .64329 L .63933 .65644 L p 0 .436 .758 r
F P
0 g
s
.43366 .35701 m .44656 .37032 L .44379 .38286 L p .357 .448 .817 r
F P
0 g
s
.45708 .39584 m .44379 .38286 L .44656 .37032 L p .315 .404 .795 r
F P
0 g
s
.18911 .47507 m .20465 .46012 L .22178 .50944 L p .906 .867 .789 r
F P
0 g
s
.22178 .50944 m .20758 .52532 L .18911 .47507 L p .906 .867 .789 r
F P
0 g
s
.52253 .54786 m .52289 .53891 L .54427 .56298 L p .196 .329 .773 r
F P
0 g
s
.54427 .56298 m .54739 .57469 L .52253 .54786 L p .196 .329 .773 r
F P
0 g
s
.28496 .34964 m .29944 .34057 L .29456 .37788 L p .889 .938 .841 r
F P
0 g
s
.29456 .37788 m .28007 .38922 L .28496 .34964 L p .889 .938 .841 r
F P
0 g
s
.67456 .65921 m .66707 .66087 L p .70307 .65619 L .022 0 0 r
F P
0 g
s
.66892 .66072 m .70307 .65619 L p .66707 .66087 L .022 0 0 r
F P
0 g
s
.69194 .65894 m .70307 .65619 L .66598 .66111 L p 0 0 0 r
F P
0 g
s
.68062 .65958 m .68854 .65913 L p .65725 .66138 L .06 .625 .722 r
F P
0 g
s
.68854 .65913 m .69194 .65894 L .68391 .65951 L p .06 .625 .722 r
F P
0 g
s
.68391 .65951 m .65725 .66138 L p .68854 .65913 L .06 .625 .722 r
F P
0 g
s
.66707 .66087 m .66598 .66111 L .66892 .66072 L p .022 0 0 r
F P
0 g
s
.70307 .65619 m .714 .65152 L .67456 .65921 L p .022 0 0 r
F P
0 g
s
.55355 .59555 m .55049 .58556 L .57772 .60817 L p .116 .35 .815 r
F P
0 g
s
.57772 .60817 m .58413 .61922 L .55355 .59555 L p .116 .35 .815 r
F P
0 g
s
.39566 .31074 m .40763 .31759 L .3948 .32939 L p .495 .689 .954 r
F P
0 g
s
.3948 .32939 m .38169 .32458 L .39566 .31074 L p .495 .689 .954 r
F P
0 g
s
.40782 .33644 m .3948 .32939 L .40763 .31759 L p .436 .611 .922 r
F P
0 g
s
.40763 .31759 m .41949 .3265 L .40782 .33644 L p .436 .611 .922 r
F P
0 g
s
.42076 .34567 m .40782 .33644 L .41949 .3265 L p .384 .54 .887 r
F P
0 g
s
.50574 .50586 m .50953 .50057 L .52362 .52022 L p .23 .322 .752 r
F P
0 g
s
.52362 .52022 m .52326 .52969 L .50574 .50586 L p .23 .322 .752 r
F P
0 g
s
.49531 .46357 m .48562 .45907 L .47728 .43985 L p .264 .337 .751 r
F P
0 g
s
.48562 .45907 m .49531 .46357 L .5036 .47943 L p .254 .329 .748 r
F P
0 g
s
.5036 .47943 m .4966 .47974 L .48562 .45907 L p .254 .329 .748 r
F P
0 g
s
.48902 .44885 m .47728 .43985 L .47211 .42329 L p .268 .342 .755 r
F P
0 g
s
.47728 .43985 m .48902 .44885 L .49531 .46357 L p .264 .337 .751 r
F P
0 g
s
.38355 .30598 m .39566 .31074 L .38169 .32458 L p .557 .769 .977 r
F P
0 g
s
.38169 .32458 m .36845 .32201 L .38355 .30598 L p .557 .769 .977 r
F P
0 g
s
.83422 .5164 m .84668 .50088 L .82503 .5479 L p .822 .968 .652 r
F P
0 g
s
.41949 .3265 m .43127 .33743 L .42076 .34567 L p .384 .54 .887 r
F P
0 g
s
.43366 .35701 m .42076 .34567 L .43127 .33743 L p .34 .48 .854 r
F P
0 g
s
.44656 .37032 m .45947 .38546 L .45708 .39584 L p .315 .404 .795 r
F P
0 g
s
.47044 .41047 m .45708 .39584 L .45947 .38546 L p .28 .368 .776 r
F P
0 g
s
.45708 .39584 m .47044 .41047 L .47211 .42329 L p .297 .372 .771 r
F P
0 g
s
.74554 .62854 m .73522 .63741 L .76676 .6121 L p 0 0 0 r
F P
0 g
s
.76676 .6121 m .77879 .60032 L .74554 .62854 L p 0 0 0 r
F P
0 g
s
.60294 .64329 m .59675 .6368 L .63017 .65102 L p 0 .448 .839 r
F P
0 g
s
.63017 .65102 m .63933 .65644 L .60294 .64329 L p 0 .448 .839 r
F P
0 g
s
.27022 .36003 m .28496 .34964 L .28007 .38922 L p .901 .946 .826 r
F P
0 g
s
.28007 .38922 m .26537 .40187 L .27022 .36003 L p .901 .946 .826 r
F P
0 g
s
.52289 .53891 m .52326 .52969 L .54113 .55053 L p .203 .321 .763 r
F P
0 g
s
.54113 .55053 m .54427 .56298 L .52289 .53891 L p .203 .321 .763 r
F P
0 g
s
.37127 .30326 m .38355 .30598 L .36845 .32201 L p .617 .844 .986 r
F P
0 g
s
.36845 .32201 m .35505 .32165 L .37127 .30326 L p .617 .844 .986 r
F P
0 g
s
.4966 .47974 m .5036 .47943 L .51337 .49543 L p .24 .321 .746 r
F P
0 g
s
.51337 .49543 m .50953 .50057 L .4966 .47974 L p .24 .321 .746 r
F P
0 g
s
.48513 .43623 m .47211 .42329 L .47044 .41047 L p .264 .343 .758 r
F P
0 g
s
.47211 .42329 m .48513 .43623 L .48902 .44885 L p .268 .342 .755 r
F P
0 g
s
.43127 .33743 m .44298 .3503 L .43366 .35701 L p .34 .48 .854 r
F P
0 g
s
.44656 .37032 m .43366 .35701 L .44298 .3503 L p .305 .429 .823 r
F P
0 g
s
.55049 .58556 m .54739 .57469 L .57125 .59569 L p .146 .339 .799 r
F P
0 g
s
.57125 .59569 m .57772 .60817 L .55049 .58556 L p .146 .339 .799 r
F P
0 g
s
.35881 .30255 m .37127 .30326 L .35505 .32165 L p .669 .906 .978 r
F P
0 g
s
.35505 .32165 m .34147 .32344 L .35881 .30255 L p .669 .906 .978 r
F P
0 g
s
.66598 .66111 m .65725 .66138 L .69194 .65894 L p 0 0 0 r
F P
0 g
s
.44298 .3503 m .45466 .36499 L .44656 .37032 L p .305 .429 .823 r
F P
0 g
s
.45947 .38546 m .44656 .37032 L .45466 .36499 L p .276 .389 .797 r
F P
0 g
s
.50953 .50057 m .51337 .49543 L .52399 .51053 L p .224 .314 .746 r
F P
0 g
s
.52399 .51053 m .52362 .52022 L .50953 .50057 L p .224 .314 .746 r
F P
0 g
s
.45947 .38546 m .47243 .40222 L .47044 .41047 L p .28 .368 .776 r
F P
0 g
s
.48391 .42652 m .47044 .41047 L .47243 .40222 L p .253 .34 .76 r
F P
0 g
s
.47044 .41047 m .48391 .42652 L .48513 .43623 L p .264 .343 .758 r
F P
0 g
s
.59675 .6368 m .59047 .62877 L .62089 .64356 L p .025 .437 .868 r
F P
0 g
s
.62089 .64356 m .63017 .65102 L .59675 .6368 L p .025 .437 .868 r
F P
0 g
s
.25524 .3715 m .27022 .36003 L .26537 .40187 L p .909 .951 .813 r
F P
0 g
s
.26537 .40187 m .25046 .41557 L .25524 .3715 L p .909 .951 .813 r
F P
0 g
s
.52326 .52969 m .52362 .52022 L .53796 .5374 L p .208 .315 .754 r
F P
0 g
s
.53796 .5374 m .54113 .55053 L .52326 .52969 L p .208 .315 .754 r
F P
0 g
s
.50089 .45878 m .48902 .44885 L .48513 .43623 L p .241 .321 .746 r
F P
0 g
s
.48902 .44885 m .50089 .45878 L .50511 .46876 L p .239 .319 .744 r
F P
0 g
s
.50511 .46876 m .49531 .46357 L .48902 .44885 L p .239 .319 .744 r
F P
0 g
s
.49531 .46357 m .50511 .46876 L .51068 .47954 L p .235 .315 .743 r
F P
0 g
s
.51068 .47954 m .5036 .47943 L .49531 .46357 L p .235 .315 .743 r
F P
0 g
s
.34614 .30374 m .35881 .30255 L .34147 .32344 L p .71 .951 .953 r
F P
0 g
s
.34147 .32344 m .32769 .32729 L .34614 .30374 L p .71 .951 .953 r
F P
0 g
s
.8137 .56112 m .80224 .57449 L .82164 .53205 L p .82 .968 .651 r
F P
0 g
s
.82164 .53205 m .83422 .5164 L .8137 .56112 L p .82 .968 .651 r
F P
0 g
s
.54739 .57469 m .54427 .56298 L .56474 .58191 L p .169 .33 .784 r
F P
0 g
s
.56474 .58191 m .57125 .59569 L .54739 .57469 L p .169 .33 .784 r
F P
0 g
s
.45466 .36499 m .46632 .38134 L .45947 .38546 L p .276 .389 .797 r
F P
0 g
s
.47243 .40222 m .45947 .38546 L .46632 .38134 L p .254 .357 .776 r
F P
0 g
s
.75451 .62267 m .76676 .6121 L .73522 .63741 L p 0 0 0 r
F P
0 g
s
.73522 .63741 m .72471 .64517 L .75451 .62267 L p 0 0 0 r
F P
0 g
s
.4983 .45025 m .48513 .43623 L .48391 .42652 L p .239 .322 .747 r
F P
0 g
s
.48513 .43623 m .4983 .45025 L .50089 .45878 L p .241 .321 .746 r
F P
0 g
s
.5036 .47943 m .51068 .47954 L .51724 .49041 L p .228 .311 .742 r
F P
0 g
s
.51724 .49041 m .51337 .49543 L .5036 .47943 L p .228 .311 .742 r
F P
0 g
s
.59047 .62877 m .58413 .61922 L .6115 .63407 L p .083 .415 .864 r
F P
0 g
s
.6115 .63407 m .62089 .64356 L .59047 .62877 L p .083 .415 .864 r
F P
0 g
s
.65725 .66138 m .64836 .65987 L .68062 .65958 L p .06 .625 .722 r
F P
0 g
s
.33325 .30671 m .34614 .30374 L .32769 .32729 L p .739 .978 .918 r
F P
0 g
s
.32769 .32729 m .31369 .33305 L .33325 .30671 L p .739 .978 .918 r
F P
0 g
s
.52362 .52022 m .52399 .51053 L .53478 .52372 L p .212 .31 .747 r
F P
0 g
s
.53478 .52372 m .53796 .5374 L .52362 .52022 L p .212 .31 .747 r
F P
0 g
s
.54427 .56298 m .54113 .55053 L .55819 .56694 L p .186 .322 .77 r
F P
0 g
s
.55819 .56694 m .56474 .58191 L .54427 .56298 L p .186 .322 .77 r
F P
0 g
s
.24003 .38374 m .25524 .3715 L .25046 .41557 L p .914 .953 .805 r
F P
0 g
s
.25046 .41557 m .23536 .43005 L .24003 .38374 L p .914 .953 .805 r
F P
0 g
s
.47243 .40222 m .48546 .42038 L .48391 .42652 L p .253 .34 .76 r
F P
0 g
s
.4975 .44374 m .48391 .42652 L .48546 .42038 L p .234 .32 .748 r
F P
0 g
s
.48391 .42652 m .4975 .44374 L .4983 .45025 L p .239 .322 .747 r
F P
0 g
s
.51337 .49543 m .51724 .49041 L .52436 .50065 L p .22 .307 .741 r
F P
0 g
s
.52436 .50065 m .52399 .51053 L .51337 .49543 L p .22 .307 .741 r
F P
0 g
s
.46632 .38134 m .478 .39917 L .47243 .40222 L p .254 .357 .776 r
F P
0 g
s
.48546 .42038 m .47243 .40222 L .478 .39917 L p .238 .334 .76 r
F P
0 g
s
.58413 .61922 m .57772 .60817 L .60203 .62262 L p .125 .391 .844 r
F P
0 g
s
.60203 .62262 m .6115 .63407 L .58413 .61922 L p .125 .391 .844 r
F P
0 g
s
.43869 .32679 m .44842 .33873 L .43127 .33743 L p .27 .486 .883 r
F P
0 g
s
.43127 .33743 m .41949 .3265 L .43869 .32679 L p .27 .486 .883 r
F P
0 g
s
.44298 .3503 m .43127 .33743 L .44842 .33873 L p .255 .436 .848 r
F P
0 g
s
.80224 .57449 m .79061 .58767 L .8089 .54751 L p .824 .972 .664 r
F P
0 g
s
.8089 .54751 m .82164 .53205 L .80224 .57449 L p .824 .972 .664 r
F P
0 g
s
.44842 .33873 m .45808 .3523 L .44298 .3503 L p .255 .436 .848 r
F P
0 g
s
.45466 .36499 m .44298 .3503 L .45808 .3523 L p .243 .396 .818 r
F P
0 g
s
.42887 .31656 m .43869 .32679 L .41949 .3265 L p .29 .546 .921 r
F P
0 g
s
.41949 .3265 m .40763 .31759 L .42887 .31656 L p .29 .546 .921 r
F P
0 g
s
.51292 .46941 m .50089 .45878 L .4983 .45025 L p .223 .307 .74 r
F P
0 g
s
.50089 .45878 m .51292 .46941 L .51505 .47446 L p .223 .306 .739 r
F P
0 g
s
.51505 .47446 m .50511 .46876 L .50089 .45878 L p .223 .306 .739 r
F P
0 g
s
.50511 .46876 m .51505 .47446 L .51785 .47993 L p .221 .305 .739 r
F P
0 g
s
.51785 .47993 m .51068 .47954 L .50511 .46876 L p .221 .305 .739 r
F P
0 g
s
.54113 .55053 m .53796 .5374 L .55161 .55094 L p .198 .315 .759 r
F P
0 g
s
.55161 .55094 m .55819 .56694 L .54113 .55053 L p .198 .315 .759 r
F P
0 g
s
.72471 .64517 m .714 .65152 L .74202 .6317 L p .442 .826 .593 r
F P
0 g
s
.74202 .6317 m .75451 .62267 L .72471 .64517 L p .442 .826 .593 r
F P
0 g
s
.45808 .3523 m .46769 .36739 L .45466 .36499 L p .243 .396 .818 r
F P
0 g
s
.46632 .38134 m .45466 .36499 L .46769 .36739 L p .234 .366 .793 r
F P
0 g
s
.32013 .31132 m .33325 .30671 L .31369 .33305 L p .758 .992 .88 r
F P
0 g
s
.31369 .33305 m .29944 .34057 L .32013 .31132 L p .758 .992 .88 r
F P
0 g
s
.51162 .4651 m .4983 .45025 L .4975 .44374 L p .223 .307 .74 r
F P
0 g
s
.4983 .45025 m .51162 .4651 L .51292 .46941 L p .223 .307 .74 r
F P
0 g
s
.41894 .30809 m .42887 .31656 L .40763 .31759 L p .313 .617 .956 r
F P
0 g
s
.40763 .31759 m .39566 .31074 L .41894 .30809 L p .313 .617 .956 r
F P
0 g
s
.64836 .65987 m .63933 .65644 L .66911 .65794 L p .113 .649 .858 r
F P
0 g
s
.66911 .65794 m .68062 .65958 L .64836 .65987 L p .113 .649 .858 r
F P
0 g
s
.51068 .47954 m .51785 .47993 L .52116 .48543 L p .219 .304 .738 r
F P
0 g
s
.52116 .48543 m .51724 .49041 L .51068 .47954 L p .219 .304 .738 r
F P
0 g
s
.478 .39917 m .4897 .41826 L .48546 .42038 L p .238 .334 .76 r
F P
0 g
s
.49857 .43968 m .48546 .42038 L .4897 .41826 L p .226 .316 .748 r
F P
0 g
s
.48546 .42038 m .49857 .43968 L .4975 .44374 L p .234 .32 .748 r
F P
0 g
s
.52399 .51053 m .52436 .50065 L .53157 .50959 L p .215 .306 .742 r
F P
0 g
s
.53157 .50959 m .53478 .52372 L .52399 .51053 L p .215 .306 .742 r
F P
0 g
s
.46769 .36739 m .47727 .38388 L .46632 .38134 L p .234 .366 .793 r
F P
0 g
s
.478 .39917 m .46632 .38134 L .47727 .38388 L p .227 .342 .773 r
F P
0 g
s
.22459 .39648 m .24003 .38374 L .23536 .43005 L p .917 .954 .8 r
F P
0 g
s
.23536 .43005 m .22008 .44501 L .22459 .39648 L p .917 .954 .8 r
F P
0 g
s
.57772 .60817 m .57125 .59569 L .5925 .6093 L p .156 .369 .821 r
F P
0 g
s
.5925 .6093 m .60203 .62262 L .57772 .60817 L p .156 .369 .821 r
F P
0 g
s
.51123 .46183 m .4975 .44374 L .49857 .43968 L p .221 .307 .74 r
F P
0 g
s
.4975 .44374 m .51123 .46183 L .51162 .4651 L p .223 .307 .74 r
F P
0 g
s
.40889 .30139 m .41894 .30809 L .39566 .31074 L p .339 .692 .981 r
F P
0 g
s
.39566 .31074 m .38355 .30598 L .40889 .30139 L p .339 .692 .981 r
F P
0 g
s
.51724 .49041 m .52116 .48543 L .52474 .49062 L p .217 .303 .738 r
F P
0 g
s
.52474 .49062 m .52436 .50065 L .51724 .49041 L p .217 .303 .738 r
F P
0 g
s
.53796 .5374 m .53478 .52372 L .54501 .5341 L p .207 .31 .75 r
F P
0 g
s
.54501 .5341 m .55161 .55094 L .53796 .5374 L p .207 .31 .75 r
F P
0 g
s
.47727 .38388 m .48683 .40159 L .478 .39917 L p .227 .342 .773 r
F P
0 g
s
.4897 .41826 m .478 .39917 L .48683 .40159 L p .223 .325 .758 r
F P
0 g
s
.57125 .59569 m .56474 .58191 L .58291 .59427 L p .177 .351 .8 r
F P
0 g
s
.58291 .59427 m .5925 .6093 L .57125 .59569 L p .177 .351 .8 r
F P
0 g
s
.63933 .65644 m .63017 .65102 L .65744 .65394 L p .159 .628 .93 r
F P
0 g
s
.65744 .65394 m .66911 .65794 L .63933 .65644 L p .159 .628 .93 r
F P
0 g
s
.4897 .41826 m .50145 .43836 L .49857 .43968 L p .226 .316 .748 r
F P
0 g
s
.51179 .45981 m .49857 .43968 L .50145 .43836 L p .219 .306 .74 r
F P
0 g
s
.49857 .43968 m .51179 .45981 L .51123 .46183 L p .221 .307 .74 r
F P
0 g
s
.3987 .29644 m .40889 .30139 L .38355 .30598 L p .363 .762 .985 r
F P
0 g
s
.38355 .30598 m .37127 .30326 L .3987 .29644 L p .363 .762 .985 r
F P
0 g
s
.52436 .50065 m .52474 .49062 L .52835 .49513 L p .215 .302 .738 r
F P
0 g
s
.52835 .49513 m .53157 .50959 L .52436 .50065 L p .215 .302 .738 r
F P
0 g
s
.30675 .31736 m .32013 .31132 L .29944 .34057 L p .771 .997 .843 r
F P
0 g
s
.29944 .34057 m .28496 .34964 L .30675 .31736 L p .771 .997 .843 r
F P
0 g
s
.79061 .58767 m .77879 .60032 L .79597 .56242 L p .83 .98 .69 r
F P
0 g
s
.79597 .56242 m .8089 .54751 L .79061 .58767 L p .83 .98 .69 r
F P
0 g
s
.48683 .40159 m .49639 .42034 L .4897 .41826 L p .223 .325 .758 r
F P
0 g
s
.50145 .43836 m .4897 .41826 L .49639 .42034 L p .219 .312 .747 r
F P
0 g
s
.714 .65152 m .70307 .65619 L .72931 .6389 L p .475 .875 .708 r
F P
0 g
s
.72931 .6389 m .74202 .6317 L .714 .65152 L p .475 .875 .708 r
F P
0 g
s
.53478 .52372 m .53157 .50959 L .53839 .5166 L p .212 .306 .743 r
F P
0 g
s
.53839 .5166 m .54501 .5341 L .53478 .52372 L p .212 .306 .743 r
F P
0 g
s
.56474 .58191 m .55819 .56694 L .57328 .57771 L p .192 .336 .781 r
F P
0 g
s
.57328 .57771 m .58291 .59427 L .56474 .58191 L p .192 .336 .781 r
F P
0 g
s
.52511 .48046 m .51292 .46941 L .51162 .4651 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .51505 .47446 L .51292 .46941 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .51785 .47993 L .51505 .47446 L closepath p .215 .3 .736 r
F P
0 g
s
.20897 .40938 m .22459 .39648 L .22008 .44501 L p .917 .954 .8 r
F P
0 g
s
.22008 .44501 m .20465 .46012 L .20897 .40938 L p .917 .954 .8 r
F P
0 g
s
.52511 .48046 m .51162 .4651 L .51123 .46183 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .52116 .48543 L .51785 .47993 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .51123 .46183 L .51179 .45981 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .52474 .49062 L .52116 .48543 L closepath p .215 .3 .736 r
F P
0 g
s
.49639 .42034 m .50595 .43989 L .50145 .43836 L p .219 .312 .747 r
F P
0 g
s
.51325 .45919 m .50145 .43836 L .50595 .43989 L p .217 .304 .74 r
F P
0 g
s
.50145 .43836 m .51325 .45919 L .51179 .45981 L p .219 .306 .74 r
F P
0 g
s
.38834 .29319 m .3987 .29644 L .37127 .30326 L p .383 .816 .961 r
F P
0 g
s
.37127 .30326 m .35881 .30255 L .38834 .29319 L p .383 .816 .961 r
F P
0 g
s
.63017 .65102 m .62089 .64356 L .64562 .64753 L p .19 .576 .939 r
F P
0 g
s
.64562 .64753 m .65744 .65394 L .63017 .65102 L p .19 .576 .939 r
F P
0 g
s
.55819 .56694 m .55161 .55094 L .56364 .55985 L p .202 .324 .766 r
F P
0 g
s
.56364 .55985 m .57328 .57771 L .55819 .56694 L p .202 .324 .766 r
F P
0 g
s
.53157 .50959 m .52835 .49513 L .53176 .49865 L p .215 .302 .739 r
F P
0 g
s
.53176 .49865 m .53839 .5166 L .53157 .50959 L p .215 .302 .739 r
F P
0 g
s
.52511 .48046 m .51179 .45981 L .51325 .45919 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .52835 .49513 L .52474 .49062 L closepath p .215 .3 .736 r
F P
0 g
s
.55161 .55094 m .54501 .5341 L .554 .54092 L p .209 .315 .754 r
F P
0 g
s
.554 .54092 m .56364 .55985 L .55161 .55094 L p .209 .315 .754 r
F P
0 g
s
.48494 .37761 m .49169 .39309 L .47727 .38388 L p .203 .342 .783 r
F P
0 g
s
.47727 .38388 m .46769 .36739 L .48494 .37761 L p .203 .342 .783 r
F P
0 g
s
.48683 .40159 m .47727 .38388 L .49169 .39309 L p .208 .327 .767 r
F P
0 g
s
.47814 .36315 m .48494 .37761 L .46769 .36739 L p .196 .361 .802 r
F P
0 g
s
.46769 .36739 m .45808 .3523 L .47814 .36315 L p .196 .361 .802 r
F P
0 g
s
.49169 .39309 m .49841 .40945 L .48683 .40159 L p .208 .327 .767 r
F P
0 g
s
.49639 .42034 m .48683 .40159 L .49841 .40945 L p .212 .316 .754 r
F P
0 g
s
.29313 .32463 m .30675 .31736 L .28496 .34964 L p .781 .998 .813 r
F P
0 g
s
.28496 .34964 m .27022 .36003 L .29313 .32463 L p .781 .998 .813 r
F P
0 g
s
.85906 .48583 m .84668 .50088 L .84701 .44972 L p .936 .948 .768 r
F P
0 g
s
.84701 .44972 m .85986 .43317 L .85906 .48583 L p .936 .948 .768 r
F P
0 g
s
.70307 .65619 m .69194 .65894 L .71636 .644 L p .504 .909 .83 r
F P
0 g
s
.71636 .644 m .72931 .6389 L .70307 .65619 L p .504 .909 .83 r
F P
0 g
s
.50595 .43989 m .51552 .46002 L .51325 .45919 L p .217 .304 .74 r
F P
0 g
s
.52511 .48046 m .51325 .45919 L .51552 .46002 L closepath p .215 .3 .736 r
F P
0 g
s
.49841 .40945 m .50511 .42655 L .49639 .42034 L p .212 .316 .754 r
F P
0 g
s
.50595 .43989 m .49639 .42034 L .50511 .42655 L p .214 .308 .745 r
F P
0 g
s
.54501 .5341 m .53839 .5166 L .54435 .52119 L p .213 .308 .745 r
F P
0 g
s
.54435 .52119 m .554 .54092 L .54501 .5341 L p .213 .308 .745 r
F P
0 g
s
.4713 .34982 m .47814 .36315 L .45808 .3523 L p .188 .385 .826 r
F P
0 g
s
.45808 .3523 m .44842 .33873 L .4713 .34982 L p .188 .385 .826 r
F P
0 g
s
.52511 .48046 m .53176 .49865 L .52835 .49513 L closepath p .215 .3 .736 r
F P
0 g
s
.62089 .64356 m .6115 .63407 L .63369 .63873 L p .207 .517 .915 r
F P
0 g
s
.63369 .63873 m .64562 .64753 L .62089 .64356 L p .207 .517 .915 r
F P
0 g
s
.77879 .60032 m .76676 .6121 L .78285 .57644 L p .837 .99 .727 r
F P
0 g
s
.78285 .57644 m .79597 .56242 L .77879 .60032 L p .837 .99 .727 r
F P
0 g
s
.50511 .42655 m .51179 .44421 L .50595 .43989 L p .214 .308 .745 r
F P
0 g
s
.51552 .46002 m .50595 .43989 L .51179 .44421 L p .215 .303 .739 r
F P
0 g
s
.19318 .42214 m .20897 .40938 L .20465 .46012 L p .915 .952 .804 r
F P
0 g
s
.20465 .46012 m .18911 .47507 L .19318 .42214 L p .915 .952 .804 r
F P
0 g
s
.53839 .5166 m .53176 .49865 L .53472 .50095 L p .215 .303 .739 r
F P
0 g
s
.53472 .50095 m .54435 .52119 L .53839 .5166 L p .215 .303 .739 r
F P
0 g
s
.37781 .29157 m .38834 .29319 L .35881 .30255 L p .396 .847 .911 r
F P
0 g
s
.35881 .30255 m .34614 .30374 L .37781 .29157 L p .396 .847 .911 r
F P
0 g
s
.4644 .33771 m .4713 .34982 L .44842 .33873 L p .178 .416 .853 r
F P
0 g
s
.44842 .33873 m .43869 .32679 L .4644 .33771 L p .178 .416 .853 r
F P
0 g
s
.51179 .44421 m .51846 .46225 L .51552 .46002 L p .215 .303 .739 r
F P
0 g
s
.52511 .48046 m .51552 .46002 L .51846 .46225 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53472 .50095 L .53176 .49865 L closepath p .215 .3 .736 r
F P
0 g
s
.6115 .63407 m .60203 .62262 L .62167 .62762 L p .216 .464 .88 r
F P
0 g
s
.62167 .62762 m .63369 .63873 L .6115 .63407 L p .216 .464 .88 r
F P
0 g
s
.52511 .48046 m .53532 .48655 L .53748 .49168 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53247 .48101 L .53532 .48655 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .52911 .47544 L .53247 .48101 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .5255 .47023 L .52911 .47544 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .52186 .46573 L .5255 .47023 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .51846 .46225 L .52186 .46573 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53704 .50185 L .53472 .50095 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53856 .5013 L .53704 .50185 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53915 .49931 L .53856 .5013 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53878 .49603 L .53915 .49931 L closepath p .215 .3 .736 r
F P
0 g
s
.52511 .48046 m .53748 .49168 L .53878 .49603 L closepath p .215 .3 .736 r
F P
0 g
s
.45743 .32688 m .4644 .33771 L .43869 .32679 L p .166 .453 .881 r
F P
0 g
s
.43869 .32679 m .42887 .31656 L .45743 .32688 L p .166 .453 .881 r
F P
0 g
s
.51859 .45104 m .52186 .46573 L .51846 .46225 L p .215 .302 .739 r
F P
0 g
s
.51846 .46225 m .51179 .44421 L .51859 .45104 L p .215 .302 .739 r
F P
0 g
s
.54435 .52119 m .53472 .50095 L .53704 .50185 L p .216 .304 .74 r
F P
0 g
s
.60203 .62262 m .5925 .6093 L .60958 .61432 L p .221 .42 .846 r
F P
0 g
s
.60958 .61432 m .62167 .62762 L .60203 .62262 L p .221 .42 .846 r
F P
0 g
s
.69194 .65894 m .68062 .65958 L .70321 .64678 L p .516 .907 .933 r
F P
0 g
s
.70321 .64678 m .71636 .644 L .69194 .65894 L p .516 .907 .933 r
F P
0 g
s
.5153 .43653 m .51859 .45104 L .51179 .44421 L p .213 .306 .743 r
F P
0 g
s
.51179 .44421 m .50511 .42655 L .5153 .43653 L p .213 .306 .743 r
F P
0 g
s
.84668 .50088 m .83422 .5164 L .83409 .46668 L p .939 .945 .763 r
F P
0 g
s
.83409 .46668 m .84701 .44972 L .84668 .50088 L p .939 .945 .763 r
F P
0 g
s
.554 .54092 m .54435 .52119 L .54904 .52303 L p .218 .312 .747 r
F P
0 g
s
.53704 .50185 m .54904 .52303 L .54435 .52119 L p .216 .304 .74 r
F P
0 g
s
.27926 .33288 m .29313 .32463 L .27022 .36003 L p .79 .997 .792 r
F P
0 g
s
.27022 .36003 m .25524 .3715 L .27926 .33288 L p .79 .997 .792 r
F P
0 g
s
.45038 .31736 m .45743 .32688 L .42887 .31656 L p .151 .496 .906 r
F P
0 g
s
.42887 .31656 m .41894 .30809 L .45038 .31736 L p .151 .496 .906 r
F P
0 g
s
.52588 .45994 m .5255 .47023 L .52186 .46573 L p .215 .302 .738 r
F P
0 g
s
.52186 .46573 m .51859 .45104 L .52588 .45994 L p .215 .302 .738 r
F P
0 g
s
.5925 .6093 m .58291 .59427 L .59745 .59903 L p .222 .386 .816 r
F P
0 g
s
.59745 .59903 m .60958 .61432 L .5925 .6093 L p .222 .386 .816 r
F P
0 g
s
.51199 .42231 m .5153 .43653 L .50511 .42655 L p .208 .311 .75 r
F P
0 g
s
.50511 .42655 m .49841 .40945 L .51199 .42231 L p .208 .311 .75 r
F P
0 g
s
.56364 .55985 m .554 .54092 L .56109 .54366 L p .22 .323 .757 r
F P
0 g
s
.54904 .52303 m .56109 .54366 L .554 .54092 L p .218 .312 .747 r
F P
0 g
s
.54904 .52303 m .53704 .50185 L .53856 .5013 L p .219 .305 .74 r
F P
0 g
s
.36709 .29145 m .37781 .29157 L .34614 .30374 L p .405 .859 .847 r
F P
0 g
s
.34614 .30374 m .33325 .30671 L .36709 .29145 L p .405 .859 .847 r
F P
0 g
s
.76676 .6121 m .75451 .62267 L .7695 .5892 L p .842 .997 .773 r
F P
0 g
s
.7695 .5892 m .78285 .57644 L .76676 .6121 L p .842 .997 .773 r
F P
0 g
s
.57328 .57771 m .56364 .55985 L .57319 .56341 L p .221 .339 .772 r
F P
0 g
s
.56109 .54366 m .57319 .56341 L .56364 .55985 L p .22 .323 .757 r
F P
0 g
s
.58291 .59427 m .57328 .57771 L .58531 .58197 L p .222 .359 .791 r
F P
0 g
s
.58531 .58197 m .59745 .59903 L .58291 .59427 L p .222 .359 .791 r
F P
0 g
s
.57319 .56341 m .58531 .58197 L .57328 .57771 L p .221 .339 .772 r
F P
0 g
s
.50866 .40849 m .51199 .42231 L .49841 .40945 L p .202 .318 .76 r
F P
0 g
s
.49841 .40945 m .49169 .39309 L .50866 .40849 L p .202 .318 .76 r
F P
0 g
s
.53316 .4703 m .52911 .47544 L .5255 .47023 L p .217 .303 .738 r
F P
0 g
s
.5255 .47023 m .52588 .45994 L .53316 .4703 L p .217 .303 .738 r
F P
0 g
s
.53856 .5013 m .55211 .52195 L .54904 .52303 L p .219 .305 .74 r
F P
0 g
s
.55211 .52195 m .53856 .5013 L .53915 .49931 L p .221 .306 .74 r
F P
0 g
s
.52627 .44964 m .52588 .45994 L .51859 .45104 L p .215 .306 .742 r
F P
0 g
s
.51859 .45104 m .5153 .43653 L .52627 .44964 L p .215 .306 .742 r
F P
0 g
s
.50531 .39516 m .50866 .40849 L .49169 .39309 L p .194 .327 .772 r
F P
0 g
s
.49169 .39309 m .48494 .37761 L .50531 .39516 L p .194 .327 .772 r
F P
0 g
s
.44324 .30917 m .45038 .31736 L .41894 .30809 L p .134 .541 .921 r
F P
0 g
s
.41894 .30809 m .40889 .30139 L .44324 .30917 L p .134 .541 .921 r
F P
0 g
s
.68062 .65958 m .66911 .65794 L .68985 .64709 L p .502 .859 .99 r
F P
0 g
s
.68985 .64709 m .70321 .64678 L .68062 .65958 L p .502 .859 .99 r
F P
0 g
s
.56109 .54366 m .54904 .52303 L .55211 .52195 L p .225 .316 .748 r
F P
0 g
s
.53992 .48142 m .53247 .48101 L .52911 .47544 L p .219 .304 .738 r
F P
0 g
s
.52911 .47544 m .53316 .4703 L .53992 .48142 L p .219 .304 .738 r
F P
0 g
s
.53915 .49931 m .55334 .51801 L .55211 .52195 L p .221 .306 .74 r
F P
0 g
s
.55334 .51801 m .53915 .49931 L .53878 .49603 L p .222 .307 .74 r
F P
0 g
s
.54567 .49249 m .53532 .48655 L .53247 .48101 L p .221 .305 .739 r
F P
0 g
s
.53247 .48101 m .53992 .48142 L .54567 .49249 L p .221 .305 .739 r
F P
0 g
s
.53878 .49603 m .55263 .51146 L .55334 .51801 L p .222 .307 .74 r
F P
0 g
s
.55263 .51146 m .53878 .49603 L .53748 .49168 L p .223 .307 .74 r
F P
0 g
s
.83422 .5164 m .82164 .53205 L .82108 .48374 L p .939 .941 .764 r
F P
0 g
s
.82108 .48374 m .83409 .46668 L .83422 .5164 L p .939 .941 .764 r
F P
0 g
s
.55001 .50275 m .53748 .49168 L .53532 .48655 L p .223 .306 .739 r
F P
0 g
s
.53532 .48655 m .54567 .49249 L .55001 .50275 L p .223 .306 .739 r
F P
0 g
s
.53748 .49168 m .55001 .50275 L .55263 .51146 L p .223 .307 .74 r
F P
0 g
s
.50193 .38241 m .50531 .39516 L .48494 .37761 L p .183 .338 .786 r
F P
0 g
s
.48494 .37761 m .47814 .36315 L .50193 .38241 L p .183 .338 .786 r
F P
0 g
s
.52666 .43936 m .52627 .44964 L .5153 .43653 L p .213 .31 .747 r
F P
0 g
s
.5153 .43653 m .51199 .42231 L .52666 .43936 L p .213 .31 .747 r
F P
0 g
s
.35617 .29272 m .36709 .29145 L .33325 .30671 L p .414 .859 .784 r
F P
0 g
s
.33325 .30671 m .32013 .31132 L .35617 .29272 L p .414 .859 .784 r
F P
0 g
s
.57319 .56341 m .56109 .54366 L .56577 .54207 L p .235 .332 .76 r
F P
0 g
s
.55211 .52195 m .56577 .54207 L .56109 .54366 L p .225 .316 .748 r
F P
0 g
s
.26515 .34186 m .27926 .33288 L .25524 .3715 L p .799 .996 .779 r
F P
0 g
s
.25524 .3715 m .24003 .38374 L .26515 .34186 L p .799 .996 .779 r
F P
0 g
s
.75451 .62267 m .74202 .6317 L .75594 .6004 L p .841 .998 .824 r
F P
0 g
s
.75594 .6004 m .7695 .5892 L .75451 .62267 L p .841 .998 .824 r
F P
0 g
s
.53725 .465 m .53316 .4703 L .52588 .45994 L p .22 .308 .741 r
F P
0 g
s
.52588 .45994 m .52627 .44964 L .53725 .465 L p .22 .308 .741 r
F P
0 g
s
.66911 .65794 m .65744 .65394 L .67633 .64482 L p .467 .778 .998 r
F P
0 g
s
.67633 .64482 m .68985 .64709 L .66911 .65794 L p .467 .778 .998 r
F P
0 g
s
.56577 .54207 m .55211 .52195 L .55334 .51801 L p .233 .319 .748 r
F P
0 g
s
.436 .3023 m .44324 .30917 L .40889 .30139 L p .116 .583 .916 r
F P
0 g
s
.40889 .30139 m .3987 .29644 L .436 .3023 L p .116 .583 .916 r
F P
0 g
s
.49852 .37032 m .50193 .38241 L .47814 .36315 L p .169 .352 .803 r
F P
0 g
s
.47814 .36315 m .4713 .34982 L .49852 .37032 L p .169 .352 .803 r
F P
0 g
s
.58531 .58197 m .57319 .56341 L .57953 .56128 L p .248 .354 .776 r
F P
0 g
s
.56577 .54207 m .57953 .56128 L .57319 .56341 L p .235 .332 .76 r
F P
0 g
s
.52705 .42914 m .52666 .43936 L .51199 .42231 L p .211 .316 .755 r
F P
0 g
s
.51199 .42231 m .50866 .40849 L .52705 .42914 L p .211 .316 .755 r
F P
0 g
s
.54746 .48153 m .53992 .48142 L .53316 .4703 L p .227 .311 .742 r
F P
0 g
s
.53316 .4703 m .53725 .465 L .54746 .48153 L p .227 .311 .742 r
F P
0 g
s
.65744 .65394 m .64562 .64753 L .66267 .63993 L p .424 .687 .973 r
F P
0 g
s
.66267 .63993 m .67633 .64482 L .65744 .65394 L p .424 .687 .973 r
F P
0 g
s
.55334 .51801 m .56768 .53619 L .56577 .54207 L p .233 .319 .748 r
F P
0 g
s
.56768 .53619 m .55334 .51801 L .55263 .51146 L p .238 .321 .747 r
F P
0 g
s
.49508 .35893 m .49852 .37032 L .4713 .34982 L p .153 .369 .822 r
F P
0 g
s
.4713 .34982 m .4644 .33771 L .49508 .35893 L p .153 .369 .822 r
F P
0 g
s
.82164 .53205 m .8089 .54751 L .80795 .50059 L p .937 .936 .771 r
F P
0 g
s
.80795 .50059 m .82108 .48374 L .82164 .53205 L p .937 .936 .771 r
F P
0 g
s
.59745 .59903 m .58531 .58197 L .59336 .57924 L p .265 .383 .797 r
F P
0 g
s
.57953 .56128 m .59336 .57924 L .58531 .58197 L p .248 .354 .776 r
F P
0 g
s
.54138 .45947 m .53725 .465 L .52627 .44964 L p .225 .314 .746 r
F P
0 g
s
.52627 .44964 m .52666 .43936 L .54138 .45947 L p .225 .314 .746 r
F P
0 g
s
.57953 .56128 m .56577 .54207 L .56768 .53619 L p .25 .339 .76 r
F P
0 g
s
.55616 .49806 m .54567 .49249 L .53992 .48142 L p .234 .315 .743 r
F P
0 g
s
.53992 .48142 m .54746 .48153 L .55616 .49806 L p .234 .315 .743 r
F P
0 g
s
.42865 .29671 m .436 .3023 L .3987 .29644 L p .098 .615 .886 r
F P
0 g
s
.3987 .29644 m .38834 .29319 L .42865 .29671 L p .098 .615 .886 r
F P
0 g
s
.64562 .64753 m .63369 .63873 L .64889 .63244 L p .381 .601 .934 r
F P
0 g
s
.64889 .63244 m .66267 .63993 L .64562 .64753 L p .381 .601 .934 r
F P
0 g
s
.55263 .51146 m .56664 .52641 L .56768 .53619 L p .238 .321 .747 r
F P
0 g
s
.56664 .52641 m .55263 .51146 L .55001 .50275 L p .24 .321 .746 r
F P
0 g
s
.74202 .6317 m .72931 .6389 L .74216 .60972 L p .829 .986 .874 r
F P
0 g
s
.74216 .60972 m .75594 .6004 L .74202 .6317 L p .829 .986 .874 r
F P
0 g
s
.60958 .61432 m .59745 .59903 L .60724 .59561 L p .285 .42 .823 r
F P
0 g
s
.59336 .57924 m .60724 .59561 L .59745 .59903 L p .265 .383 .797 r
F P
0 g
s
.34504 .2952 m .35617 .29272 L .32013 .31132 L p .424 .855 .731 r
F P
0 g
s
.32013 .31132 m .30675 .31736 L .34504 .2952 L p .424 .855 .731 r
F P
0 g
s
.52745 .419 m .52705 .42914 L .50866 .40849 L p .207 .324 .763 r
F P
0 g
s
.50866 .40849 m .50531 .39516 L .52745 .419 L p .207 .324 .763 r
F P
0 g
s
.56271 .51339 m .55001 .50275 L .54567 .49249 L p .239 .318 .744 r
F P
0 g
s
.54567 .49249 m .55616 .49806 L .56271 .51339 L p .239 .318 .744 r
F P
0 g
s
.55001 .50275 m .56271 .51339 L .56664 .52641 L p .24 .321 .746 r
F P
0 g
s
.63369 .63873 m .62167 .62762 L .63504 .62245 L p .343 .527 .892 r
F P
0 g
s
.63504 .62245 m .64889 .63244 L .63369 .63873 L p .343 .527 .892 r
F P
0 g
s
.62167 .62762 m .60958 .61432 L .62114 .6101 L p .311 .468 .855 r
F P
0 g
s
.60724 .59561 m .62114 .6101 L .60958 .61432 L p .285 .42 .823 r
F P
0 g
s
.25082 .35128 m .26515 .34186 L .24003 .38374 L p .808 .997 .776 r
F P
0 g
s
.24003 .38374 m .22459 .39648 L .25082 .35128 L p .808 .997 .776 r
F P
0 g
s
.62114 .6101 m .63504 .62245 L .62167 .62762 L p .311 .468 .855 r
F P
0 g
s
.49161 .3483 m .49508 .35893 L .4644 .33771 L p .134 .39 .843 r
F P
0 g
s
.4644 .33771 m .45743 .32688 L .49161 .3483 L p .134 .39 .843 r
F P
0 g
s
.59336 .57924 m .57953 .56128 L .58215 .5535 L p .274 .365 .775 r
F P
0 g
s
.56768 .53619 m .58215 .5535 L .57953 .56128 L p .25 .339 .76 r
F P
0 g
s
.55509 .48122 m .54746 .48153 L .53725 .465 L p .239 .321 .746 r
F P
0 g
s
.53725 .465 m .54138 .45947 L .55509 .48122 L p .239 .321 .746 r
F P
0 g
s
.58215 .5535 m .56768 .53619 L .56664 .52641 L p .261 .342 .758 r
F P
0 g
s
.8089 .54751 m .79597 .56242 L .79468 .5169 L p .931 .929 .781 r
F P
0 g
s
.79468 .5169 m .80795 .50059 L .8089 .54751 L p .931 .929 .781 r
F P
0 g
s
.52785 .40897 m .52745 .419 L .50531 .39516 L p .203 .333 .774 r
F P
0 g
s
.50531 .39516 m .50193 .38241 L .52785 .40897 L p .203 .333 .774 r
F P
0 g
s
.54556 .45367 m .54138 .45947 L .52666 .43936 L p .23 .322 .752 r
F P
0 g
s
.52666 .43936 m .52705 .42914 L .54556 .45367 L p .23 .322 .752 r
F P
0 g
s
.72931 .6389 m .71636 .644 L .72816 .61691 L p .801 .957 .916 r
F P
0 g
s
.72816 .61691 m .74216 .60972 L .72931 .6389 L p .801 .957 .916 r
F P
0 g
s
.42117 .29233 m .42865 .29671 L .38834 .29319 L p .086 .634 .833 r
F P
0 g
s
.38834 .29319 m .37781 .29157 L .42117 .29233 L p .086 .634 .833 r
F P
0 g
s
.48809 .33844 m .49161 .3483 L .45743 .32688 L p .113 .415 .862 r
F P
0 g
s
.45743 .32688 m .45038 .31736 L .48809 .33844 L p .113 .415 .862 r
F P
0 g
s
.56678 .50304 m .55616 .49806 L .54746 .48153 L p .253 .329 .748 r
F P
0 g
s
.54746 .48153 m .55509 .48122 L .56678 .50304 L p .253 .329 .748 r
F P
0 g
s
.56664 .52641 m .58081 .54054 L .58215 .5535 L p .261 .342 .758 r
F P
0 g
s
.58081 .54054 m .56664 .52641 L .56271 .51339 L p .266 .341 .754 r
F P
0 g
s
.3337 .29871 m .34504 .2952 L .30675 .31736 L p .439 .854 .693 r
F P
0 g
s
.30675 .31736 m .29313 .32463 L .3337 .29871 L p .439 .854 .693 r
F P
0 g
s
.60724 .59561 m .59336 .57924 L .59674 .56956 L p .304 .399 .794 r
F P
0 g
s
.58215 .5535 m .59674 .56956 L .59336 .57924 L p .274 .365 .775 r
F P
0 g
s
.52826 .39906 m .52785 .40897 L .50193 .38241 L p .199 .345 .787 r
F P
0 g
s
.50193 .38241 m .49852 .37032 L .52826 .39906 L p .199 .345 .787 r
F P
0 g
s
.23627 .36085 m .25082 .35128 L .22459 .39648 L p .818 .998 .78 r
F P
0 g
s
.22459 .39648 m .20897 .40938 L .23627 .36085 L p .818 .998 .78 r
F P
0 g
s
.71636 .644 m .70321 .64678 L .71396 .62174 L p .758 .908 .942 r
F P
0 g
s
.71396 .62174 m .72816 .61691 L .71636 .644 L p .758 .908 .942 r
F P
0 g
s
.57557 .52331 m .56271 .51339 L .55616 .49806 L p .262 .336 .751 r
F P
0 g
s
.55616 .49806 m .56678 .50304 L .57557 .52331 L p .262 .336 .751 r
F P
0 g
s
.56271 .51339 m .57557 .52331 L .58081 .54054 L p .266 .341 .754 r
F P
0 g
s
.54978 .44755 m .54556 .45367 L .52705 .42914 L p .237 .332 .759 r
F P
0 g
s
.52705 .42914 m .52745 .419 L .54978 .44755 L p .237 .332 .759 r
F P
0 g
s
.79597 .56242 m .78285 .57644 L .78124 .53233 L p .921 .919 .795 r
F P
0 g
s
.78124 .53233 m .79468 .5169 L .79597 .56242 L p .921 .919 .795 r
F P
0 g
s
.48453 .32937 m .48809 .33844 L .45038 .31736 L p .089 .442 .879 r
F P
0 g
s
.45038 .31736 m .44324 .30917 L .48453 .32937 L p .089 .442 .879 r
F P
0 g
s
.59674 .56956 m .58215 .5535 L .58081 .54054 L p .292 .369 .771 r
F P
0 g
s
.56282 .48034 m .55509 .48122 L .54138 .45947 L p .254 .333 .752 r
F P
0 g
s
.54138 .45947 m .54556 .45367 L .56282 .48034 L p .254 .333 .752 r
F P
0 g
s
.62114 .6101 m .60724 .59561 L .61142 .58405 L p .342 .441 .817 r
F P
0 g
s
.59674 .56956 m .61142 .58405 L .60724 .59561 L p .304 .399 .794 r
F P
0 g
s
.41357 .28909 m .42117 .29233 L .37781 .29157 L p .081 .641 .768 r
F P
0 g
s
.37781 .29157 m .36709 .29145 L .41357 .28909 L p .081 .641 .768 r
F P
0 g
s
.70321 .64678 m .68985 .64709 L .69959 .62406 L p .7 .844 .952 r
F P
0 g
s
.69959 .62406 m .71396 .62174 L .70321 .64678 L p .7 .844 .952 r
F P
0 g
s
.52867 .3893 m .52826 .39906 L .49852 .37032 L p .194 .359 .802 r
F P
0 g
s
.49852 .37032 m .49508 .35893 L .52867 .3893 L p .194 .359 .802 r
F P
0 g
s
.63504 .62245 m .62114 .6101 L .62617 .59666 L p .387 .491 .843 r
F P
0 g
s
.61142 .58405 m .62617 .59666 L .62114 .6101 L p .342 .441 .817 r
F P
0 g
s
.58081 .54054 m .59513 .55352 L .59674 .56956 L p .292 .369 .771 r
F P
0 g
s
.59513 .55352 m .58081 .54054 L .57557 .52331 L p .298 .367 .765 r
F P
0 g
s
.57753 .50719 m .56678 .50304 L .55509 .48122 L p .277 .346 .755 r
F P
0 g
s
.55509 .48122 m .56282 .48034 L .57753 .50719 L p .277 .346 .755 r
F P
0 g
s
.68985 .64709 m .67633 .64482 L .68506 .62375 L p .633 .769 .945 r
F P
0 g
s
.68506 .62375 m .69959 .62406 L .68985 .64709 L p .633 .769 .945 r
F P
0 g
s
.55404 .44105 m .54978 .44755 L .52745 .419 L p .245 .345 .768 r
F P
0 g
s
.52745 .419 m .52785 .40897 L .55404 .44105 L p .245 .345 .768 r
F P
0 g
s
.78285 .57644 m .7695 .5892 L .76763 .54655 L p .906 .905 .812 r
F P
0 g
s
.76763 .54655 m .78124 .53233 L .78285 .57644 L p .906 .905 .812 r
F P
0 g
s
.48093 .32108 m .48453 .32937 L .44324 .30917 L p .064 .471 .888 r
F P
0 g
s
.44324 .30917 m .436 .3023 L .48093 .32108 L p .064 .471 .888 r
F P
0 g
s
.32216 .30303 m .3337 .29871 L .29313 .32463 L p .46 .858 .671 r
F P
0 g
s
.29313 .32463 m .27926 .33288 L .32216 .30303 L p .46 .858 .671 r
F P
0 g
s
.61142 .58405 m .59674 .56956 L .59513 .55352 L p .33 .403 .786 r
F P
0 g
s
.64889 .63244 m .63504 .62245 L .64094 .60712 L p .439 .55 .872 r
F P
0 g
s
.62617 .59666 m .64094 .60712 L .63504 .62245 L p .387 .491 .843 r
F P
0 g
s
.22154 .37026 m .23627 .36085 L .20897 .40938 L p .828 .999 .792 r
F P
0 g
s
.20897 .40938 m .19318 .42214 L .22154 .37026 L p .828 .999 .792 r
F P
0 g
s
.85986 .43317 m .84701 .44972 L .82412 .39785 L p .902 .853 .785 r
F P
0 g
s
.82412 .39785 m .8366 .38074 L .85986 .43317 L p .902 .853 .785 r
F P
0 g
s
.67633 .64482 m .66267 .63993 L .67043 .6208 L p .565 .692 .926 r
F P
0 g
s
.67043 .6208 m .68506 .62375 L .67633 .64482 L p .565 .692 .926 r
F P
0 g
s
.57557 .52331 m .58857 .53221 L .59513 .55352 L p .298 .367 .765 r
F P
0 g
s
.58857 .53221 m .57557 .52331 L .56678 .50304 L p .293 .358 .759 r
F P
0 g
s
.56678 .50304 m .57753 .50719 L .58857 .53221 L p .293 .358 .759 r
F P
0 g
s
.57063 .47876 m .56282 .48034 L .54556 .45367 L p .273 .348 .759 r
F P
0 g
s
.54556 .45367 m .54978 .44755 L .57063 .47876 L p .273 .348 .759 r
F P
0 g
s
.66267 .63993 m .64889 .63244 L .65571 .61522 L p .499 .617 .9 r
F P
0 g
s
.64094 .60712 m .65571 .61522 L .64889 .63244 L p .439 .55 .872 r
F P
0 g
s
.65571 .61522 m .67043 .6208 L .66267 .63993 L p .499 .617 .9 r
F P
0 g
s
.52908 .37971 m .52867 .3893 L .49508 .35893 L p .189 .376 .818 r
F P
0 g
s
.49508 .35893 m .49161 .3483 L .52908 .37971 L p .189 .376 .818 r
F P
0 g
s
.40584 .28686 m .41357 .28909 L .36709 .29145 L p .084 .642 .704 r
F P
0 g
s
.39797 .28553 m .40584 .28686 L .35617 .29272 L p 0 0 0 r
F P
0 g
s
.36709 .29145 m .35617 .29272 L .39079 .28863 L p .084 .642 .704 r
F P
0 g
s
.39079 .28863 m .39417 .28824 L p .39198 .2885 L .084 .642 .704 r
F P
0 g
s
.36709 .29145 m .39079 .28863 L .39198 .2885 L .084 .642 .704 r
F
.35617 .29272 m .34504 .2952 L .38666 .28759 L p 0 0 0 r
F P
0 g
s
.35617 .29272 m .38666 .28759 L .3874 .28744 L 0 0 0 r
F
.35617 .29272 m .3886 .28724 L .39308 .28637 L F
.36342 .29184 m .34504 .2952 L p .35587 .29273 L F P
0 g
s
.35587 .29273 m .38995 .28494 L .36342 .29184 L 0 0 0 r
F
.34504 .2952 m .3337 .29871 L .38293 .28666 L p F P
0 g
s
.34504 .2952 m .38293 .28666 L .38305 .28663 L 0 0 0 r
F
.34504 .2952 m .38321 .28659 L .38667 .28569 L F
.3604 .29217 m .3337 .29871 L p .35386 .29293 L F P
0 g
s
.35386 .29293 m .3818 .28493 L .3604 .29217 L 0 0 0 r
F
.3337 .29871 m .32216 .30303 L .37973 .28556 L p F P
0 g
s
.37973 .28556 m .3818 .28493 L p .38058 .28528 L 0 0 0 r
F P
0 g
s
.3337 .29871 m .37973 .28556 L .38058 .28528 L 0 0 0 r
F
.3104 .30795 m .32216 .30303 L .27926 .33288 L p .487 .869 .665 r
F P
0 g
s
.33774 .29772 m .3381 .29753 L .34054 .29703 L 0 0 0 r
F
.33774 .29772 m .34054 .29703 L .34478 .29617 L F
.34478 .29617 m .33497 .29914 L p .33774 .29772 L F P
0 g
s
.33497 .29914 m .32216 .30303 L p .32871 .30077 L 0 0 0 r
F P
0 g
s
.32871 .30077 m .3381 .29753 L .33497 .29914 L 0 0 0 r
F
.3381 .29753 m .3735 .28533 L .34478 .29617 L F
.32216 .30303 m .3104 .30795 L .3735 .28533 L p F P
0 g
s
.32826 .30155 m .3104 .30795 L p .32221 .30319 L 0 0 0 r
F P
0 g
s
.32221 .30319 m .36507 .28593 L .32826 .30155 L 0 0 0 r
F
.27926 .33288 m .26515 .34186 L .3104 .30795 L p .487 .869 .665 r
F P
0 g
s
.29845 .31321 m .3104 .30795 L .26515 .34186 L p .52 .886 .674 r
F P
0 g
s
.3104 .30795 m .29845 .31321 L .36507 .28593 L p 0 0 0 r
F P
0 g
s
.3565 .28656 m .36507 .28593 L .31068 .3082 L p .305 .775 .658 r
F P
0 g
s
.31068 .3082 m .29845 .31321 L p .30605 .30972 L .305 .775 .658 r
F P
0 g
s
.30605 .30972 m .3565 .28656 L .31068 .3082 L .305 .775 .658 r
F
.36507 .28593 m .3735 .28533 L .32826 .30155 L p 0 0 0 r
F P
0 g
s
.38293 .28666 m .38321 .28659 L p .38305 .28663 L 0 0 0 r
F P
0 g
s
.38321 .28659 m .38995 .28494 L p .38667 .28569 L 0 0 0 r
F P
0 g
s
.3735 .28533 m .3818 .28493 L .34478 .29617 L p 0 0 0 r
F P
0 g
s
.38666 .28759 m .3886 .28724 L p .3874 .28744 L 0 0 0 r
F P
0 g
s
.3886 .28724 m .39797 .28553 L p .39308 .28637 L 0 0 0 r
F P
0 g
s
.3818 .28493 m .38995 .28494 L .3604 .29217 L p 0 0 0 r
F P
0 g
s
.38995 .28494 m .39797 .28553 L .36342 .29184 L p 0 0 0 r
F P
0 g
s
.39417 .28824 m .40584 .28686 L p .39927 .28764 L .084 .642 .704 r
F P
0 g
s
.36709 .29145 m .39417 .28824 L .39927 .28764 L .084 .642 .704 r
F
.7695 .5892 m .75594 .6004 L .75384 .55927 L p .884 .886 .829 r
F P
0 g
s
.75384 .55927 m .76763 .54655 L .7695 .5892 L p .884 .886 .829 r
F P
0 g
s
.55834 .43416 m .55404 .44105 L .52785 .40897 L p .255 .359 .778 r
F P
0 g
s
.52785 .40897 m .52826 .39906 L .55834 .43416 L p .255 .359 .778 r
F P
0 g
s
.84701 .44972 m .83409 .46668 L .81161 .41528 L p .901 .846 .781 r
F P
0 g
s
.81161 .41528 m .82412 .39785 L .84701 .44972 L p .901 .846 .781 r
F P
0 g
s
.62617 .59666 m .61142 .58405 L .60957 .56502 L p .375 .443 .803 r
F P
0 g
s
.59513 .55352 m .60957 .56502 L .61142 .58405 L p .33 .403 .786 r
F P
0 g
s
.47727 .31353 m .48093 .32108 L .436 .3023 L p .041 .5 .886 r
F P
0 g
s
.436 .3023 m .42865 .29671 L .47727 .31353 L p .041 .5 .886 r
F P
0 g
s
.60957 .56502 m .59513 .55352 L .58857 .53221 L p .338 .398 .776 r
F P
0 g
s
.5884 .51032 m .57753 .50719 L .56282 .48034 L p .305 .367 .762 r
F P
0 g
s
.56282 .48034 m .57063 .47876 L .5884 .51032 L p .305 .367 .762 r
F P
0 g
s
.5295 .37027 m .52908 .37971 L .49161 .3483 L p .184 .396 .836 r
F P
0 g
s
.49161 .3483 m .48809 .33844 L .5295 .37027 L p .184 .396 .836 r
F P
0 g
s
.57852 .47637 m .57063 .47876 L .54978 .44755 L p .294 .366 .766 r
F P
0 g
s
.54978 .44755 m .55404 .44105 L .57852 .47637 L p .294 .366 .766 r
F P
0 g
s
.75594 .6004 m .74216 .60972 L .73988 .5702 L p .854 .861 .845 r
F P
0 g
s
.73988 .5702 m .75384 .55927 L .75594 .6004 L p .854 .861 .845 r
F P
0 g
s
.58857 .53221 m .60171 .53982 L .60957 .56502 L p .338 .398 .776 r
F P
0 g
s
.60171 .53982 m .58857 .53221 L .57753 .50719 L p .329 .384 .768 r
F P
0 g
s
.57753 .50719 m .5884 .51032 L .60171 .53982 L p .329 .384 .768 r
F P
0 g
s
.83409 .46668 m .82108 .48374 L .79906 .43277 L p .896 .837 .779 r
F P
0 g
s
.79906 .43277 m .81161 .41528 L .83409 .46668 L p .896 .837 .779 r
F P
0 g
s
.64094 .60712 m .62617 .59666 L .6241 .57476 L p .426 .489 .821 r
F P
0 g
s
.60957 .56502 m .6241 .57476 L .62617 .59666 L p .375 .443 .803 r
F P
0 g
s
.56269 .42682 m .55834 .43416 L .52826 .39906 L p .267 .376 .789 r
F P
0 g
s
.52826 .39906 m .52867 .3893 L .56269 .42682 L p .267 .376 .789 r
F P
0 g
s
.47356 .3067 m .47727 .31353 L .42865 .29671 L p .023 .526 .871 r
F P
0 g
s
.42865 .29671 m .42117 .29233 L .47356 .3067 L p .023 .526 .871 r
F P
0 g
s
.6241 .57476 m .60957 .56502 L .60171 .53982 L p .383 .433 .788 r
F P
0 g
s
.74216 .60972 m .72816 .61691 L .72575 .57909 L p .817 .829 .859 r
F P
0 g
s
.72575 .57909 m .73988 .5702 L .74216 .60972 L p .817 .829 .859 r
F P
0 g
s
.52992 .36101 m .5295 .37027 L .48809 .33844 L p .18 .42 .856 r
F P
0 g
s
.48809 .33844 m .48453 .32937 L .52992 .36101 L p .18 .42 .856 r
F P
0 g
s
.65571 .61522 m .64094 .60712 L .6387 .5825 L p .482 .538 .838 r
F P
0 g
s
.6241 .57476 m .6387 .5825 L .64094 .60712 L p .426 .489 .821 r
F P
0 g
s
.82108 .48374 m .80795 .50059 L .78645 .45002 L p .889 .827 .78 r
F P
0 g
s
.78645 .45002 m .79906 .43277 L .82108 .48374 L p .889 .827 .78 r
F P
0 g
s
.59937 .51225 m .5884 .51032 L .57063 .47876 L p .338 .39 .769 r
F P
0 g
s
.57063 .47876 m .57852 .47637 L .59937 .51225 L p .338 .39 .769 r
F P
0 g
s
.58648 .47306 m .57852 .47637 L .55404 .44105 L p .318 .385 .774 r
F P
0 g
s
.55404 .44105 m .55834 .43416 L .58648 .47306 L p .318 .385 .774 r
F P
0 g
s
.72816 .61691 m .71396 .62174 L .71146 .58575 L p .772 .791 .868 r
F P
0 g
s
.71146 .58575 m .72575 .57909 L .72816 .61691 L p .772 .791 .868 r
F P
0 g
s
.67043 .6208 m .65571 .61522 L .65333 .58801 L p .542 .591 .853 r
F P
0 g
s
.6387 .5825 m .65333 .58801 L .65571 .61522 L p .482 .538 .838 r
F P
0 g
s
.60171 .53982 m .61496 .54591 L .6241 .57476 L p .383 .433 .788 r
F P
0 g
s
.61496 .54591 m .60171 .53982 L .5884 .51032 L p .369 .413 .776 r
F P
0 g
s
.56707 .41903 m .56269 .42682 L .52867 .3893 L p .28 .395 .802 r
F P
0 g
s
.52867 .3893 m .52908 .37971 L .56707 .41903 L p .28 .395 .802 r
F P
0 g
s
.5884 .51032 m .59937 .51225 L .61496 .54591 L p .369 .413 .776 r
F P
0 g
s
.26515 .34186 m .25082 .35128 L .29845 .31321 L p .52 .886 .674 r
F P
0 g
s
.71396 .62174 m .69959 .62406 L .69705 .59003 L p .721 .746 .872 r
F P
0 g
s
.69705 .59003 m .71146 .58575 L .71396 .62174 L p .721 .746 .872 r
F P
0 g
s
.68506 .62375 m .67043 .6208 L .66795 .59116 L p .603 .644 .864 r
F P
0 g
s
.65333 .58801 m .66795 .59116 L .67043 .6208 L p .542 .591 .853 r
F P
0 g
s
.6387 .5825 m .6241 .57476 L .61496 .54591 L p .432 .471 .799 r
F P
0 g
s
.80795 .50059 m .79468 .5169 L .77375 .46675 L p .878 .815 .783 r
F P
0 g
s
.77375 .46675 m .78645 .45002 L .80795 .50059 L p .878 .815 .783 r
F P
0 g
s
.69959 .62406 m .68506 .62375 L .68254 .59185 L p .663 .697 .871 r
F P
0 g
s
.68254 .59185 m .69705 .59003 L .69959 .62406 L p .663 .697 .871 r
F P
0 g
s
.66795 .59116 m .68254 .59185 L .68506 .62375 L p .603 .644 .864 r
F P
0 g
s
.53035 .35191 m .52992 .36101 L .48453 .32937 L p .178 .448 .876 r
F P
0 g
s
.48453 .32937 m .48093 .32108 L .53035 .35191 L p .178 .448 .876 r
F P
0 g
s
.4698 .30052 m .47356 .3067 L .42117 .29233 L p .013 .549 .846 r
F P
0 g
s
.42117 .29233 m .41357 .28909 L .4698 .30052 L p .013 .549 .846 r
F P
0 g
s
.59451 .46875 m .58648 .47306 L .55834 .43416 L p .343 .406 .782 r
F P
0 g
s
.55834 .43416 m .56269 .42682 L .59451 .46875 L p .343 .406 .782 r
F P
0 g
s
.61043 .51279 m .59937 .51225 L .57852 .47637 L p .372 .415 .776 r
F P
0 g
s
.57852 .47637 m .58648 .47306 L .61043 .51279 L p .372 .415 .776 r
F P
0 g
s
.79468 .5169 m .78124 .53233 L .76095 .48267 L p .864 .801 .787 r
F P
0 g
s
.76095 .48267 m .77375 .46675 L .79468 .5169 L p .864 .801 .787 r
F P
0 g
s
.5715 .41077 m .56707 .41903 L .52908 .37971 L p .295 .416 .815 r
F P
0 g
s
.52908 .37971 m .5295 .37027 L .5715 .41077 L p .295 .416 .815 r
F P
0 g
s
.61496 .54591 m .6283 .55025 L .6387 .5825 L p .432 .471 .799 r
F P
0 g
s
.6283 .55025 m .61496 .54591 L .59937 .51225 L p .412 .444 .784 r
F P
0 g
s
.65333 .58801 m .6387 .5825 L .6283 .55025 L p .484 .51 .809 r
F P
0 g
s
.59937 .51225 m .61043 .51279 L .6283 .55025 L p .412 .444 .784 r
F P
0 g
s
.53078 .34297 m .53035 .35191 L .48093 .32108 L p .179 .479 .895 r
F P
0 g
s
.48093 .32108 m .47727 .31353 L .53078 .34297 L p .179 .479 .895 r
F P
0 g
s
.78124 .53233 m .76763 .54655 L .74804 .49751 L p .845 .785 .794 r
F P
0 g
s
.74804 .49751 m .76095 .48267 L .78124 .53233 L p .845 .785 .794 r
F P
0 g
s
.2863 .31856 m .29845 .31321 L .25082 .35128 L p .558 .908 .695 r
F P
0 g
s
.25082 .35128 m .23627 .36085 L .2863 .31856 L p .558 .908 .695 r
F P
0 g
s
.46598 .29493 m .4698 .30052 L .41357 .28909 L p .013 .57 .815 r
F P
0 g
s
.41357 .28909 m .40584 .28686 L .46598 .29493 L p .013 .57 .815 r
F P
0 g
s
.66795 .59116 m .65333 .58801 L .64169 .55266 L p .536 .55 .816 r
F P
0 g
s
.6283 .55025 m .64169 .55266 L .65333 .58801 L p .484 .51 .809 r
F P
0 g
s
.6026 .46338 m .59451 .46875 L .56269 .42682 L p .371 .428 .791 r
F P
0 g
s
.56269 .42682 m .56707 .41903 L .6026 .46338 L p .371 .428 .791 r
F P
0 g
s
.62157 .51184 m .61043 .51279 L .58648 .47306 L p .409 .441 .782 r
F P
0 g
s
.58648 .47306 m .59451 .46875 L .62157 .51184 L p .409 .441 .782 r
F P
0 g
s
.57596 .40202 m .5715 .41077 L .5295 .37027 L p .312 .44 .83 r
F P
0 g
s
.5295 .37027 m .52992 .36101 L .57596 .40202 L p .312 .44 .83 r
F P
0 g
s
.76763 .54655 m .75384 .55927 L .73502 .51101 L p .822 .767 .8 r
F P
0 g
s
.73502 .51101 m .74804 .49751 L .76763 .54655 L p .822 .767 .8 r
F P
0 g
s
.64169 .55266 m .6283 .55025 L .61043 .51279 L p .457 .476 .791 r
F P
0 g
s
.68254 .59185 m .66795 .59116 L .65513 .55303 L p .588 .59 .821 r
F P
0 g
s
.64169 .55266 m .65513 .55303 L .66795 .59116 L p .536 .55 .816 r
F P
0 g
s
.61043 .51279 m .62157 .51184 L .64169 .55266 L p .457 .476 .791 r
F P
0 g
s
.75384 .55927 m .73988 .5702 L .72189 .52292 L p .795 .746 .807 r
F P
0 g
s
.72189 .52292 m .73502 .51101 L .75384 .55927 L p .795 .746 .807 r
F P
0 g
s
.53121 .33417 m .53078 .34297 L .47727 .31353 L p .183 .513 .914 r
F P
0 g
s
.47727 .31353 m .47356 .3067 L .53121 .33417 L p .183 .513 .914 r
F P
0 g
s
.69705 .59003 m .68254 .59185 L .66857 .55125 L p .638 .627 .823 r
F P
0 g
s
.65513 .55303 m .66857 .55125 L .68254 .59185 L p .588 .59 .821 r
F P
0 g
s
.73988 .5702 m .72575 .57909 L .70867 .53304 L p .763 .721 .814 r
F P
0 g
s
.70867 .53304 m .72189 .52292 L .73988 .5702 L p .763 .721 .814 r
F P
0 g
s
.61074 .45691 m .6026 .46338 L .56707 .41903 L p .399 .452 .799 r
F P
0 g
s
.56707 .41903 m .5715 .41077 L .61074 .45691 L p .399 .452 .799 r
F P
0 g
s
.4621 .28984 m .46598 .29493 L .40584 .28686 L p .024 .591 .786 r
F P
0 g
s
.40584 .28686 m .39797 .28553 L .4621 .28984 L p .024 .591 .786 r
F P
0 g
s
.65513 .55303 m .64169 .55266 L .62157 .51184 L p .502 .508 .795 r
F P
0 g
s
.71146 .58575 m .69705 .59003 L .68199 .54731 L p .684 .662 .822 r
F P
0 g
s
.66857 .55125 m .68199 .54731 L .69705 .59003 L p .638 .627 .823 r
F P
0 g
s
.63277 .50927 m .62157 .51184 L .59451 .46875 L p .446 .467 .788 r
F P
0 g
s
.59451 .46875 m .6026 .46338 L .63277 .50927 L p .446 .467 .788 r
F P
0 g
s
.58046 .39279 m .57596 .40202 L .52992 .36101 L p .332 .466 .845 r
F P
0 g
s
.52992 .36101 m .53035 .35191 L .58046 .39279 L p .332 .466 .845 r
F P
0 g
s
.72575 .57909 m .71146 .58575 L .69536 .54121 L p .726 .693 .819 r
F P
0 g
s
.69536 .54121 m .70867 .53304 L .72575 .57909 L p .726 .693 .819 r
F P
0 g
s
.27399 .32374 m .2863 .31856 L .23627 .36085 L p .6 .933 .728 r
F P
0 g
s
.23627 .36085 m .22154 .37026 L .27399 .32374 L p .6 .933 .728 r
F P
0 g
s
.68199 .54731 m .69536 .54121 L .71146 .58575 L p .684 .662 .822 r
F P
0 g
s
.8366 .38074 m .82412 .39785 L .77794 .34939 L p .839 .779 .795 r
F P
0 g
s
.77794 .34939 m .78901 .33274 L .8366 .38074 L p .839 .779 .795 r
F P
0 g
s
.62157 .51184 m .63277 .50927 L .65513 .55303 L p .502 .508 .795 r
F P
0 g
s
.53166 .3255 m .53121 .33417 L .47356 .3067 L p .193 .549 .931 r
F P
0 g
s
.47356 .3067 m .4698 .30052 L .53166 .3255 L p .193 .549 .931 r
F P
0 g
s
.82412 .39785 m .81161 .41528 L .76689 .36623 L p .834 .769 .789 r
F P
0 g
s
.76689 .36623 m .77794 .34939 L .82412 .39785 L p .834 .769 .789 r
F P
0 g
s
.66857 .55125 m .65513 .55303 L .63277 .50927 L p .546 .539 .799 r
F P
0 g
s
.61893 .44932 m .61074 .45691 L .5715 .41077 L p .429 .476 .807 r
F P
0 g
s
.5715 .41077 m .57596 .40202 L .61893 .44932 L p .429 .476 .807 r
F P
0 g
s
.64401 .50504 m .63277 .50927 L .6026 .46338 L p .483 .493 .792 r
F P
0 g
s
.6026 .46338 m .61074 .45691 L .64401 .50504 L p .483 .493 .792 r
F P
0 g
s
.58499 .3831 m .58046 .39279 L .53035 .35191 L p .353 .494 .861 r
F P
0 g
s
.53035 .35191 m .53078 .34297 L .58499 .3831 L p .353 .494 .861 r
F P
0 g
s
.81161 .41528 m .79906 .43277 L .75584 .38305 L p .827 .757 .786 r
F P
0 g
s
.75584 .38305 m .76689 .36623 L .81161 .41528 L p .827 .757 .786 r
F P
0 g
s
.63277 .50927 m .64401 .50504 L .66857 .55125 L p .546 .539 .799 r
F P
0 g
s
.45815 .28516 m .4621 .28984 L .39797 .28553 L p .048 .614 .764 r
F P
0 g
s
.39797 .28553 m .38995 .28494 L .45815 .28516 L p .048 .614 .764 r
F P
0 g
s
.68199 .54731 m .66857 .55125 L .64401 .50504 L p .587 .569 .8 r
F P
0 g
s
.79906 .43277 m .78645 .45002 L .74478 .39964 L p .817 .745 .784 r
F P
0 g
s
.74478 .39964 m .75584 .38305 L .79906 .43277 L p .817 .745 .784 r
F P
0 g
s
.78645 .45002 m .77375 .46675 L .7337 .41577 L p .804 .732 .784 r
F P
0 g
s
.7337 .41577 m .74478 .39964 L .78645 .45002 L p .804 .732 .784 r
F P
0 g
s
.69536 .54121 m .68199 .54731 L .65527 .49911 L p .626 .596 .8 r
F P
0 g
s
.64401 .50504 m .65527 .49911 L .68199 .54731 L p .587 .569 .8 r
F P
0 g
s
.62716 .44061 m .61893 .44932 L .57596 .40202 L p .458 .501 .815 r
F P
0 g
s
.57596 .40202 m .58046 .39279 L .62716 .44061 L p .458 .501 .815 r
F P
0 g
s
.5321 .31692 m .53166 .3255 L .4698 .30052 L p .207 .588 .945 r
F P
0 g
s
.4698 .30052 m .46598 .29493 L .5321 .31692 L p .207 .588 .945 r
F P
0 g
s
.65527 .49911 m .64401 .50504 L .61074 .45691 L p .519 .519 .796 r
F P
0 g
s
.61074 .45691 m .61893 .44932 L .65527 .49911 L p .519 .519 .796 r
F P
0 g
s
.77375 .46675 m .76095 .48267 L .72259 .43122 L p .789 .717 .785 r
F P
0 g
s
.72259 .43122 m .7337 .41577 L .77375 .46675 L p .789 .717 .785 r
F P
0 g
s
.58956 .37295 m .58499 .3831 L .53078 .34297 L p .377 .524 .877 r
F P
0 g
s
.53078 .34297 m .53121 .33417 L .58956 .37295 L p .377 .524 .877 r
F P
0 g
s
.70867 .53304 m .69536 .54121 L .66654 .49149 L p .662 .621 .798 r
F P
0 g
s
.65527 .49911 m .66654 .49149 L .69536 .54121 L p .626 .596 .8 r
F P
0 g
s
.76095 .48267 m .74804 .49751 L .71145 .44578 L p .77 .702 .787 r
F P
0 g
s
.71145 .44578 m .72259 .43122 L .76095 .48267 L p .77 .702 .787 r
F P
0 g
s
.72189 .52292 m .70867 .53304 L .6778 .48225 L p .694 .645 .796 r
F P
0 g
s
.66654 .49149 m .6778 .48225 L .70867 .53304 L p .662 .621 .798 r
F P
0 g
s
.74804 .49751 m .73502 .51101 L .70026 .45925 L p .748 .685 .79 r
F P
0 g
s
.70026 .45925 m .71145 .44578 L .74804 .49751 L p .748 .685 .79 r
F P
0 g
s
.73502 .51101 m .72189 .52292 L .68905 .47146 L p .723 .666 .793 r
F P
0 g
s
.6778 .48225 m .68905 .47146 L .72189 .52292 L p .694 .645 .796 r
F P
0 g
s
.68905 .47146 m .70026 .45925 L .73502 .51101 L p .723 .666 .793 r
F P
0 g
s
.45415 .28078 m .45815 .28516 L .38995 .28494 L p .083 .643 .754 r
F P
0 g
s
.38995 .28494 m .3818 .28493 L .45415 .28078 L p .083 .643 .754 r
F P
0 g
s
.66654 .49149 m .65527 .49911 L .61893 .44932 L p .553 .544 .798 r
F P
0 g
s
.63542 .43083 m .62716 .44061 L .58046 .39279 L p .487 .525 .822 r
F P
0 g
s
.58046 .39279 m .58499 .3831 L .63542 .43083 L p .487 .525 .822 r
F P
0 g
s
.61893 .44932 m .62716 .44061 L .66654 .49149 L p .553 .544 .798 r
F P
0 g
s
.53255 .30842 m .5321 .31692 L .46598 .29493 L p .228 .627 .956 r
F P
0 g
s
.46598 .29493 m .4621 .28984 L .53255 .30842 L p .228 .627 .956 r
F P
0 g
s
.59416 .36238 m .58956 .37295 L .53121 .33417 L p .402 .555 .893 r
F P
0 g
s
.53121 .33417 m .53166 .3255 L .59416 .36238 L p .402 .555 .893 r
F P
0 g
s
.6778 .48225 m .66654 .49149 L .62716 .44061 L p .585 .567 .8 r
F P
0 g
s
.29845 .31321 m .2863 .31856 L .3565 .28656 L p .305 .775 .658 r
F P
0 g
s
.62716 .44061 m .63542 .43083 L .6778 .48225 L p .585 .567 .8 r
F P
0 g
s
.6437 .42002 m .63542 .43083 L .58499 .3831 L p .516 .55 .829 r
F P
0 g
s
.58499 .3831 m .58956 .37295 L .6437 .42002 L p .516 .55 .829 r
F P
0 g
s
.68905 .47146 m .6778 .48225 L .63542 .43083 L p .615 .589 .801 r
F P
0 g
s
.45009 .27658 m .45415 .28078 L .3818 .28493 L p .129 .678 .758 r
F P
0 g
s
.3818 .28493 m .3735 .28533 L .45009 .27658 L p .129 .678 .758 r
F P
0 g
s
.5988 .35141 m .59416 .36238 L .53166 .3255 L p .429 .587 .907 r
F P
0 g
s
.53166 .3255 m .5321 .31692 L .5988 .35141 L p .429 .587 .907 r
F P
0 g
s
.70026 .45925 m .68905 .47146 L .6437 .42002 L p .643 .61 .802 r
F P
0 g
s
.63542 .43083 m .6437 .42002 L .68905 .47146 L p .615 .589 .801 r
F P
0 g
s
.53301 .29997 m .53255 .30842 L .4621 .28984 L p .256 .667 .965 r
F P
0 g
s
.4621 .28984 m .45815 .28516 L .53301 .29997 L p .256 .667 .965 r
F P
0 g
s
.65201 .40826 m .6437 .42002 L .58956 .37295 L p .544 .574 .835 r
F P
0 g
s
.58956 .37295 m .59416 .36238 L .65201 .40826 L p .544 .574 .835 r
F P
0 g
s
.71145 .44578 m .70026 .45925 L .65201 .40826 L p .668 .63 .802 r
F P
0 g
s
.6437 .42002 m .65201 .40826 L .70026 .45925 L p .643 .61 .802 r
F P
0 g
s
.72259 .43122 m .71145 .44578 L .66033 .39564 L p .69 .648 .803 r
F P
0 g
s
.65201 .40826 m .66033 .39564 L .71145 .44578 L p .668 .63 .802 r
F P
0 g
s
.34782 .287 m .3565 .28656 L .2863 .31856 L p .374 .824 .707 r
F P
0 g
s
.2863 .31856 m .27399 .32374 L .34782 .287 L p .374 .824 .707 r
F P
0 g
s
.7337 .41577 m .72259 .43122 L .66867 .38227 L p .71 .665 .804 r
F P
0 g
s
.66033 .39564 m .66867 .38227 L .72259 .43122 L p .69 .648 .803 r
F P
0 g
s
.74478 .39964 m .7337 .41577 L .67704 .36826 L p .728 .681 .805 r
F P
0 g
s
.66867 .38227 m .67704 .36826 L .7337 .41577 L p .71 .665 .804 r
F P
0 g
s
.75584 .38305 m .74478 .39964 L .68542 .35377 L p .743 .696 .807 r
F P
0 g
s
.67704 .36826 m .68542 .35377 L .74478 .39964 L p .728 .681 .805 r
F P
0 g
s
.60347 .3401 m .5988 .35141 L .5321 .31692 L p .457 .619 .92 r
F P
0 g
s
.5321 .31692 m .53255 .30842 L .60347 .3401 L p .457 .619 .92 r
F P
0 g
s
.76689 .36623 m .75584 .38305 L .69383 .33891 L p .755 .711 .81 r
F P
0 g
s
.68542 .35377 m .69383 .33891 L .75584 .38305 L p .743 .696 .807 r
F P
0 g
s
.77794 .34939 m .76689 .36623 L .70226 .32385 L p .765 .724 .815 r
F P
0 g
s
.69383 .33891 m .70226 .32385 L .76689 .36623 L p .755 .711 .81 r
F P
0 g
s
.78901 .33274 m .77794 .34939 L .71074 .3087 L p .773 .738 .82 r
F P
0 g
s
.70226 .32385 m .71074 .3087 L .77794 .34939 L p .765 .724 .815 r
F P
0 g
s
.66033 .39564 m .65201 .40826 L .59416 .36238 L p .57 .597 .841 r
F P
0 g
s
.59416 .36238 m .5988 .35141 L .66033 .39564 L p .57 .597 .841 r
F P
0 g
s
.71074 .3087 m .71927 .29362 L .78901 .33274 L p .773 .738 .82 r
F P
0 g
s
.44596 .27246 m .45009 .27658 L .3735 .28533 L p .186 .719 .775 r
F P
0 g
s
.3735 .28533 m .36507 .28593 L .44596 .27246 L p .186 .719 .775 r
F P
0 g
s
.53348 .29152 m .53301 .29997 L .45815 .28516 L p .291 .705 .973 r
F P
0 g
s
.45815 .28516 m .45415 .28078 L .53348 .29152 L p .291 .705 .973 r
F P
0 g
s
.66867 .38227 m .66033 .39564 L .5988 .35141 L p .595 .62 .846 r
F P
0 g
s
.5988 .35141 m .60347 .3401 L .66867 .38227 L p .595 .62 .846 r
F P
0 g
s
.60817 .32847 m .60347 .3401 L .53255 .30842 L p .485 .65 .932 r
F P
0 g
s
.53255 .30842 m .53301 .29997 L .60817 .32847 L p .485 .65 .932 r
F P
0 g
s
.67704 .36826 m .66867 .38227 L .60347 .3401 L p .619 .641 .851 r
F P
0 g
s
.53395 .28306 m .53348 .29152 L .45415 .28078 L p .331 .742 .979 r
F P
0 g
s
.45415 .28078 m .45009 .27658 L .53395 .28306 L p .331 .742 .979 r
F P
0 g
s
.44178 .26828 m .44596 .27246 L .36507 .28593 L p .253 .765 .804 r
F P
0 g
s
.36507 .28593 m .3565 .28656 L .44178 .26828 L p .253 .765 .804 r
F P
0 g
s
.60347 .3401 m .60817 .32847 L .67704 .36826 L p .619 .641 .851 r
F P
0 g
s
.68542 .35377 m .67704 .36826 L .60817 .32847 L p .64 .662 .855 r
F P
0 g
s
.61291 .31658 m .60817 .32847 L .53301 .29997 L p .514 .68 .941 r
F P
0 g
s
.53301 .29997 m .53348 .29152 L .61291 .31658 L p .514 .68 .941 r
F P
0 g
s
.69383 .33891 m .68542 .35377 L .61291 .31658 L p .659 .681 .86 r
F P
0 g
s
.60817 .32847 m .61291 .31658 L .68542 .35377 L p .64 .662 .855 r
F P
0 g
s
.70226 .32385 m .69383 .33891 L .61769 .30448 L p .677 .7 .864 r
F P
0 g
s
.61291 .31658 m .61769 .30448 L .69383 .33891 L p .659 .681 .86 r
F P
0 g
s
.53442 .27453 m .53395 .28306 L .45009 .27658 L p .376 .776 .985 r
F P
0 g
s
.45009 .27658 m .44596 .27246 L .53442 .27453 L p .376 .776 .985 r
F P
0 g
s
.71074 .3087 m .70226 .32385 L .62251 .29222 L p .692 .717 .868 r
F P
0 g
s
.61769 .30448 m .62251 .29222 L .70226 .32385 L p .677 .7 .864 r
F P
0 g
s
.61769 .30448 m .61291 .31658 L .53348 .29152 L p .542 .708 .948 r
F P
0 g
s
.53348 .29152 m .53395 .28306 L .61769 .30448 L p .542 .708 .948 r
F P
0 g
s
.43754 .26392 m .44178 .26828 L .3565 .28656 L p .328 .813 .842 r
F P
0 g
s
.3565 .28656 m .34782 .287 L .43754 .26392 L p .328 .813 .842 r
F P
0 g
s
.71927 .29362 m .71074 .3087 L .62737 .27986 L p .704 .733 .873 r
F P
0 g
s
.62251 .29222 m .62737 .27986 L .71074 .3087 L p .692 .717 .868 r
F P
0 g
s
.62737 .27986 m .63227 .26744 L .71927 .29362 L p .704 .733 .873 r
F P
0 g
s
.62251 .29222 m .61769 .30448 L .53395 .28306 L p .568 .733 .953 r
F P
0 g
s
.53395 .28306 m .53442 .27453 L .62251 .29222 L p .568 .733 .953 r
F P
0 g
s
.5349 .2659 m .53442 .27453 L .44596 .27246 L p .424 .807 .99 r
F P
0 g
s
.44596 .27246 m .44178 .26828 L .5349 .2659 L p .424 .807 .99 r
F P
0 g
s
.62737 .27986 m .62251 .29222 L .53442 .27453 L p .593 .755 .955 r
F P
0 g
s
.53442 .27453 m .5349 .2659 L .62737 .27986 L p .593 .755 .955 r
F P
0 g
s
.53539 .25714 m .5349 .2659 L .44178 .26828 L p .473 .833 .994 r
F P
0 g
s
.44178 .26828 m .43754 .26392 L .53539 .25714 L p .473 .833 .994 r
F P
0 g
s
.63227 .26744 m .62737 .27986 L .5349 .2659 L p .616 .774 .956 r
F P
0 g
s
.5349 .2659 m .53539 .25714 L .63227 .26744 L p .616 .774 .956 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ogWEoP03o`00
0?nMa_CoWLKd00?oWLKd2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo0_l00002ooooo`03o`000?oooooooooo07Sooooo2_l0000HogWEoP03o`000?nM
a_CoWLKd00koWLKd2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_oo
ool002cooooo0_l00004ooooo`03o`000?oooooooooo07?ooooo1?l00002oe?@e`03o`000?mieOko
NMGn00koNMGn4?l0000Koig6m0Oo00004oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02kooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool3o`00
00GoDm3G0ol00003ogWEoPco00003om/c_d00ol0003oUl7doiO1m002oiO1m0Oo00005?nMa_@00ol0
003o];_OokBkg`03o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]oooo
o`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l00003oe?@e`Go
000000?o@<?=o`000?l000000_l00006ofc>o@Wo00003Om/c_d00ol0003oUl7doiO1m009oiO1m0So
00002onMa_@00ol0003o];_OokBkg`04okBkg`?o00003Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02cooooo000/ooooo`?o00001_ooool00ol0003oooooooooo`1Uooooo`Co0000
0_mCd=L@o`0000koH<Kl3_l0000CoiO1m0Oo00001?nMa_@00ol0003o];_OokBkg`07okBkg`?o0000
2_ooool00ol0003oooooooooo`0booooo`;o0000;Oooool002cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Pooooo`Co00000_mCd=L8o`000003obnha_l0003o000000Co00001?lQ
[L800ol0003oE;gjoeBmnP05oeBmnPgo00001omPa_`01?l0003oTK_coi6klonA^o<6o`00017oUl7d
1?l0000=okBkg`?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0000;o
Dm3G1Ol00002obnhaP?o00000_lQ[L8=o`0001?oE;gj1ol0000:oi6kl`Ko00003_nG`O@01?l0003o
/KONo`000?l0000=okBkg`?o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02[ooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo1?l00002oe?@
e`;o00000_l_^<H00ol0003o8Jg2ob6]`P08o`0000;o5JC13Ol00002odZdn@Wo00003?mD_OX00ol0
003oR[GbohZelP03o`0000_oTK_c1Ol00009oiO1m003o`000?na]mko/KON00;o/KON0ol0000<okBk
g`?o00000_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo0009ooooo`Ko
00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00
00_ooooo00?o0000ooooooooool0Doooool5o`000003oe?@eol0003o000000go00000ol6UlT;o`00
00?o39g300?o0000od6Zmom1Z_L01?l00005odZdn@Wo00000omD_OX00ol0003oR[GbohZelP04ohZe
lPCo00002onA^o<6o`0000;oUl7d00?o0000ok6gg_na]mh01_na]mh2o`0000go];_O0ol0000foooo
o`03o`000?oooooooooo02Wooooo000Aooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool2o`00
0003oeoB]?l0003o000000go000000?o5:C4o`000?l000003?l00004o`JGb@Go00001_m1Z_L5o`00
00SoB[Ci1?l0000:ohZelPCo00003OnA^o<3o`0000[o/KON0ol0000<okBkg`Co0000=?ooool00ol0
003oooooooooo`0Xooooo`004Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0COooool>
o`0000?oIMSY0ol00004oaJRe@?o00001?lFX]D2o`0000;o0hcH1?l000000ol3TM3o0000o`000003
o`000003ocZPm?l0003o000000Oo@J[g1Ol00006odZdn@03o`000?n3[_3oPjk`00;o00002_n:]O84
o`0000_oTK_c00?o0000ojfcgOl000002ona]mh3o`0000Wo];_O00Co0000okBkgond^moo];_O0ol0
000aooooo`;o0000:Oooool0017ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Kooooo0_l0000?ooooo`03o`000?oooooooooo04[ooooo1?l000000om>aZSo0000o`00
0006o`0000?oIMSY0ol00003of;@mP?o00001?lIWN86o`0000;o1HKN0ol000000ol3S=So0000o`00
0004o`000003ocBFlOl0003o>Z3d00;o>Z3d1?l00006od6Zm`Go000000?oB[Cio`000?n3[_001?n3
[_03o`0000[oR[Gb1?l00006oi6kl`03o`000?n]/mgo[K?M00?o[K?M0_l0000:ok6ggP?o00001_nd
^ml00ol0003o];_OokBkg`02okBkg`04o`000?o5_=7o0000o`0002oooooo0_l0000Yooooo`004Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04Oooooo2_l00002ofOKf003o`000?mUf>WoIMSY00?o0000
0_mRd?H4o`0000?oG<?l2Ol000001?lIWN;o0000o`Yoh_l00003o`F6gPCo000000?o0hcHo`000?l0
00000oldU_43o`0000;o>Z3d0ol00008od6Zm`;o00002?n3[_03o`0000_oR[Gb1?l00002oi6kl`03
o`000?n]/mgo[K?M00Go[K?M0_l0000;ok6ggP;o00001?nd^ml01Ol0003o];_OokBkgond^moo0000
00CoaKcA00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Vooooo`004Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013ooooo0_l00015oooo
o`Ko000000CoK=Zko`000?l0003oJM_83?l00003oec3o0Co00001?mF/O/4o`000004oafEj_l0003o
0000o`0000?o2WoR0ol00002o`F6gPGo00001?ldU_43o`0000;o>Z3d1?l00005od6Zm`04o`000?ml
Y^ko0000o`0000SoPjk`1?l0000;ohZelP;o00002_n]/md3o`0000[o/KON1Ol00002okBkg`03o`00
0?o5_=7oaKcA00CoaKcA0_l0000^ooooo`03o`000?oooooooooo02Kooooo000Zooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0@?ooool3o`000004odk6Z?l0003o0000og3J/@Co0000
0_nmn^/01Ol0003o]O?cokGclonelo?o000000?oZnOj00?o0000oigHo?nMf?`00ol00009oeJan`04
o`000?lRR^_o8X[[ob::j`Go00001?l:On83o`0000;o1HKN0_l00002oc6<kP03o`000?ldU_7o=9Ka
00;o=9Ka0_l00004ocZPm0Co000000?o@J[go`000?mlY^h00omlY^h3o`0000SoPjk`0ol00009ohZe
lP03o`000?nX[]co000000_o[K?M0_l00008ok6ggPKo000000?o];_Oo`000?o5_=401oo5_=42o`00
02gooooo00?o0000ooooooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03go
oooo0ol000001Om>aZSo0000o`000?l0003oK=Zk00;o000000Go`_gQo`000?nmn^_o_O[[o`000003
okGcl`05o`000?n[io[oZnOjoj_Wn_l000000onMf?`00ol0003oS/Cjohk4nP02o`0000CoE[7k1Ol0
0006ob::j`;o000000?o47SSo`000?l000000ol:On84o`000003obj3jOl0003o<Hc^00;o<Hc^0_l0
0002ocBFl@?o00001OljX?@2o`0000OoO:K^0ol00008oh>^l0?o00001On:]O800ol0003oZ:kLojR^
g002ojR^g0;o00002_n]/md2o`0000?o/KON0ol00005ok6ggP;o00002oo5_=42o`0002cooooo00?o
0000ooooooooool09?ooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0j
ooooo`Oo000000?oL=Zao`000?o2oN400_o2oN401?l0003o_O[[okgjjol00003okGcl`05o`000?n[
io[oZnOjoj_Wn_l000000onMf?`00ol0003oS/Cjohk4nP02ohk4nPGo00001_m@WO@4o`0000;o8X[[
00Co0000oaIahOl0003o47SS0ol00003o`YohP;o00000_l^PnT2o`0000;o<Hc^0ol00002ocBFl@?o
00000oljX?@00ol0003oM9k[o`000008ogbVkP?o00002?n3[_03o`0000;oR[Gb00?o0000ojR^g?nX
[]`01?nX[]`2o`0000[o[K?M0ol00009ok6ggP03o`000?o3^M3o000000_oaKcA0_l0000Zooooo`;o
00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0gooooo`;o0000
0_n5hZ`3o`000004og3J/Ol0003oaOoGo`0000;o`_gQ00Co0000okgjjonmn^_o00000onelo<01Ol0
003oZnOjoj_Wn_n[io[o000000?oWMSl00?o0000ohk4n_n>a?X00_n>a?X01?l0003oO[3dogj`m?mn
/?@2o`0000CoD9gd1?l00002obIni`Co00000_lFLN42o`000003oa1hhol0003o000000;o2WoR00?o
0000obejiOl^PnT00_l^PnT2o`0000?o<Hc^0_l00003ocBFl@Co00000omdW^/3o`0000OoO:K^0_l0
0009oh>^l0;o00002OnX[]`2o`0000Go[K?M0ol00003ojfcg@;o00001_na]mh00ol0003o`kW@o`00
0002ol>id003o`000?o5_=7oaKcA00WoaKcA00?o0000ooooooooool09oooool2o`0000Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Oo
oooo000Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=?ooool3o`000003ohGR
[?l0003o000000?o00000_o5omL01?l0003o`_gQol;mhOl00003okgjj`04o`000?nelo?o]O?co`00
00?oZnOj00Go0000oigHo?nMf?coWMSlo`000004ohk4nP03o`000?mn/?CoO[3d00CoO[3d1?l00003
odZ;j`04o`000?lZLn7o0000o`0000;o9WkW0_l00003oaIah@;o000000?o47SSo`000?l000000_l0
0002obeji@03o`000?l^PnWo;X?Y00?o00000_laS>h3o`0000?o=9Ka00?o0000ogBNjomdW^/01?md
W^/2o`0000OoO:K^0ol00007oh>^l003o`000?nSZM[o000000WoZ:kL1Ol00008ojfcg@;o00001?na
]mh00ol0003o`kW@o`000003ol>id0;o00002_o5_=42o`0002Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo
000Zooooo`;o00006Oooool00ol0003oooooooooo`0aooooo`;o000000GoS^Rao`000?n5hZco0000
ogcNZP02o`000004olOod?l0003oaOoGo`0000;o`_gQ00Go0000okgjjonmn^_o_O[[o`000002okGc
l`03o`000?n[io[o000000So00000_n>a?X00ol0003oO[3dogj`m004ogj`m004o`000?m_W>coKic/
o`0000GoBX_[00?o0000obYchOlZLn401?l000000olLJ]co5W7QoaIah@02oaIah@05o`000?l@N>?o
47SSoa1hhol000000ol]N^D2o`0000?o;X?Y0_l00003oc6<kPCo000000?oKIKXo`000?mdW^/01Omd
W^/2o`0000SoO:K^0ol00004oh>^l004o`000?nSZM[oXjWJoj>YfP;o00001OnX[]`6o`0000[o[K?M
0ol000001Ona]mko0000ol>id?o3^M3o000000Co`kW@0_l0000:olFld@;o00009oooool00ol0003o
ooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05oooo
o`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02kooooo2?l00003olOod003
o`000?o5omOo000000?o`_gQ00?o0000okgjjonmn^/01_l00002olGGj005o`000?ngc>Wo]lcYokO<
jOl000000_nX_^T3o`0000GoO[3d00?o0000ofnLk?m_W>`00_m_W>`00ol0003oBX_[odZ;j`03odZ;
j`03o`000?lZLn7o:W?Q00;o:W?Q0_l00002oaaZg003o`000?lFLN7o5W7Q00;o000000?o47SSo`00
0?l]L^001?l]N^D2o`0000?o;X?Y0_l00004oc6<kP04o`000?m]U^SoKIKXoffFj0;o00001OmdW^/3
o`0000SoO:K^1?l00006oj>YfP03o`000?nX[]co000000;o00001_nX[]`2o`0000_o[K?M00?o0000
ol>id?o3^M000_o3^M000ol0003o`kW@ol>id003ol>id0;o00002_o5_=42o`0002Kooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_oo
ool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0/ooooo`09o`000?nIk[[o
0000o`000?n5hZco0000ogcNZ_o:ol[o000000;oaoo@00?o0000olGoeol000000oo2oN400ol0003o
_O[[o`000002o`0000;od>7T00?o0000olGGj?o5enP00_o5enP01Ol0003o]lcYokO<jOngc>Wo0000
00?oZ;kY0_nH[^H3o`000003ogj`m?l0003oKic/00CoKic/2?l00005obYch@03o`000?lLJ]co76[L
00;o00000_lFLN43o`000003obebh?l0003o;G[U00?o;G[U00?o0000obj3jOl^PnT00_l^PnT2o`00
00;o<Hc^00?o0000ofJ>i?m]U^P00om]U^P2o`0000KoM9k[0_l00009ogbVkP03o`000?nSZM[oXjWJ
00?oXjWJ1?l0000:ojR^g0;o00002On]/md00ol0003o`KK?o`000003ol>id003o`000?o3^M3o`kW@
00Co`kW@0_l0000:olFld@03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3
o`0001cooooo00?o0000ooooooooool0:_ooool02Ol0003oVNjjo`000?l0003oQN:/o`000?mlgZ[o
b_o:o`000003olOod003o`000?o5omOo000000;o`_gQ0ol000000ooHj>3o0000om3Qi002om3Qi005
o`000?o5enSoaMOXolGGj?l000001?ngc>T01Ol0003oZ;kYojRnjOnX_^Wo000000CoV:kV0_l00004
ofnLk005o`000?mRR^?oHX[Sof::hol000000om5O>800ol0003o;F[JobeZfP03o`000003obYchOl0
003o76[L00;o76[L0_l00002oaIah@04o`000?l]L^3o;G;Pobebh0;o00000_l]N^D2o`0000Co;X?Y
0ol00003ofJ>i004o`000?m]U^SoKIKXoffFj0;o00001_mdW^/2o`0000OoO:K^00?o0000oijTfOnS
ZMX00ol00004oj>YfP;o00002_nX[]`2o`0000Ko[K?M00Co0000ol6fcoo1]/oo`KK?0_l000000oo3
^M3o0000ol>id007ol>id003o`000?o5_=7oaKcA00SoaKcA0_l0000Tooooo`03o`000?oooooooooo
00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Wooooo000Yoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool01Ol0003oVNjjo`000?l0003o
QN:/00;o00000_o:olX01ol0003oaoo@olOod?l0003oaOoGo`000?o2oN400_l00004omSXh005o`00
0?o@hNCod>7Tom3Qi?l000000oo5enP00ol0003o]lcYokO<j@02okO<j@05o`000?nX_^WoZ;kYojRn
jOl000001?nH[^H2ohNNhP;o000000?oKic/o`000?mRR^<01?mRR^<01Ol0003oAGcRodElh_m5O>;o
000000Co;F[J0ol000002?lRHmOo0000oaaZg?lLJ]co0000oaIahOl0003o;V_K1?l]L^001?l0003o
;G[UobejiOl]N^D2o`0000Co;X?Y00?o0000ofJ>i?mVS^@00_mVS^@2o`0000?oKIKX0_l00006ogBN
j`?o00000omlY^h4o`000003oijTfOl0003oXjWJ00KoXjWJ0_l0000:ojR^g0;o00000on]/md00ol0
003o`KK?ol6fc`04ol6fc`03o`000?o3^M3o000000So`kW@0_l0000:olFld@03o`000?oooooooooo
023ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09
ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00[o0000oiW^
^_l0003o0000ohGR[?l0003oc?k7o`000?o:ol[o00000_o7om000ol0003oaOoGo`000002o`000003
omk]fol0003of>SP00?of>SP00Go0000om3Qi?o@hNCod>7To`000003olGGj005o`000?ngc>Wo]lcY
okO<jOl000001?nX_^T00ol0003oV:kVoiR^iP02oiR^iP04o`000?n7W^;oQikRohNNhP;o00001OmR
R^<6o`0000Ko;F[J00Go0000ob9Seol0003o0000oaaZg003o`000003obi[fol0003o;G;P00;o;G;P
0_l00003obeji@06o`000?l^PnWo;X?Yobj3jOl0003oH8KP1OmVS^@2o`0000?oKIKX0_l00007ogBN
j`Co00001OnNY=T2o`0000OoXjWJ0_l0000:ojR^g0;o000000?o[K?Mo`000?o1]/l01_o1]/l3o`00
00Wo`kW@0_l00008olFld@;o00008oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo02Cooooo00Go0000oiW^^_l0003o0000ohGR[002olcna`03o`00
0?o:ol[o000000;oaoo@0ol00004omk]f`05o`000?oHj>3of>SPomSXh?l000001?o@hN@01Ol0003o
aMOXolGGj?o5enSo000000?o]lcY00Go0000ojRnjOnX_^WoZ;kYo`000004oiR^iP03o`000?n7W^;o
QikR00;oQikR0_mgS]d01ol0003oHX[Sof::homRR^?o0000oeMjf_l000000om1KmT2o`0000Go;F[J
00Co0000obMNd_lRHmOo8V?G0_l000000olLJ]co0000obi[f`02obi[f`05o`000?l]L^3o;G;Pobeb
h?l000000ol]N^D3o`0000?oH8KP00?o0000ofJ>i?mVS^@00omVS^@00ol0003oKIKXoffFj002offF
j0;o00000omdW^/3o`000003ogBNjol0003oWZCI00OoWZCI0_l00007oj>YfP;o00002_nX[]`00ol0
003o`KK?ol6fc`08ol6fc`;o00002_o3^M02o`0000GoaKcA00Co0000omK7booFal_o00008oooool0
0ol0003oooooooooo`0Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`?o00008Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?nIk[[oS^Ra00;o00000_o<o/L01?l0003ob_o:ol[o
b_l00002olOod003o`000?oSl=Oo000000Cog^gK00Go0000omSXh?oHj>3of>SPo`000003om3Qi003
o`000?o5enSoaMOX00;oaMOX00Go0000okO<jOngc>Wo]lcYo`000003ojRnj@03o`000?nH[^KoV:kV
00;oV:kV00?o0000ohNNh_n7W^800_n7W^801_l0003oMhkMogN>gOl0003oHX[So`0000?oEg[J00?o
0000od5_fOm1KmT00_m1KmT4o`0000;o;F[J00?o0000obMNd_l000000_lRHmL2o`000004obmUe_l^
Jm_o;V_Kobi[f`;o00000_l]L^02o`0000?o;G[U00?o0000of26h?mPQ^000omPQ^000ol0003oIXkT
ofJ>i002ofJ>i0;o00001?m]U^P3o`0000CoM9k[00?o0000oiRNf?nNY=T02?nNY=T00ol0003oXjWJ
oj>YfP06oj>YfP;o00002?nX[]`00ol0003o_[;>ol6fc`09ol6fc`;o00002oo3^M001Ol0003oaKcA
olFldOo5_=7o000000Coe/O;00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`00
1?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Oooooo`;o
000000GoVNjjohkX/Ol0003oc_o6o`000002olcna`03o`000?o:ol[o000000;oaoo@00Co0000on?`
eooSl=Oo00001?oNkM/01Ol0003of>SPomSXh?oHj>3o000000?od>7T00Go0000olGGj?o5enSoaMOX
o`000004okO<j@05o`000?nX_^WoZ;kYojRnjOl000001?nH[^H00ol0003oQikRohNNhP02ohNNhP05
o`000?mgS]goMhkMogN>gOl000001OmGN]X00ol0003o@FoIod5_f@02od5_f@03o`000?l`H]?o<6;C
00?o00000olWG]801_l0003o8V?Go`000?l0003o;fGFo`0000?o;V_K00Co0000obebh?l]L^3o;G;P
0_l000000ol]N^Go0000oeYng005of26h0;o00001?mVS^@5o`000003offFj?l0003o000000?oM9k[
00?o0000oiRNf?nHW]P00_l00007oijTf@;o00002?nSZMX00ol0003oZ:kLojR^g004ojR^g004o`00
0?nn//ko_[;>okjbcP;o00002?o1]/l2o`0000_o`kW@0_l000000oo5_=7o0000omK7b`04omK7b`03
o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool000Kooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00Co0000oiW^^_nIk[[oS^Ra0_o>olH01?l0
003oc?k7olcnaol00002ol[obP?o00000ooSl=L00ol0003og^gKomk]f`02omk]f`05o`000?oHj>3o
f>SPomSXh?l000000oo@hN@00ol0003oaMOXolGGj00=o`000003oiR^i_l0003oQikR00?oQikR00?o
0000ogN>gOmgS]d00_mgS]d00omXOmOo0000oeMjfP04oeMjfP03o`000?m1KmWo@FoI00;o@FoI00?o
0000oc1Rdol`H]<00_l`H]<01Ol0003o9ekBobMNd_lWG];o000000;o8V?G00Co0000obmUe_l_IMKo
00000_l^Jm/2o`0000?o;G;P0_l00002oeYng003o`000?mPQ^3oH8KP00?oH8KP00?o0000ofJ>i?mV
S^@01?l00005offFj0?o00001OnHW]P2o`0000OoWZCI0_l00007oj>YfP;o00000onX[]`00ol0003o
_[;>okjbcP04okjbcP03o`000?o1]/oo`KK?00Ko`KK?0ol0000;ol>id003o`000?oFal_oe/O;00Go
e/O;00?o0000ooooooooool08?ooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`0Tooooo`;o00007?ooool01?l0003oVNjjoiW^^_l00002olkoaP04o`000?o<o/Oo
c?k7o`0000;ob_o:0_l000000ooVl]?o0000on?`e`02on?`e`05o`000?oNkM_og^gKomk]fol00000
1?oHj>001?l0003od>7Tom3Qi?o@hN@3o`000003ol?0eonh^=Wo^;SI00?o^;SI1?n/[]T3oijSf@Go
000000?oQikRo`000?mgS]d00omgS]d00ol0003oJ7oGo`000004oeMjfPOo00000ol`H]<00ol0003o
:e[=obMNdP02obMNdP?o000000Co<63AobmUe_l_IMKo00000ol^Jm/01Ol0003o;G;Pobebh?l]L^3o
000000?oFWkL0_l00003of26h0?o00001?mVS^@2o`0000GoKIKX00?o0000oiRNf?nHW]P01OnHW]P0
0ol0003oWZCIoijTf@06oijTf@03o`000?nSZM[oXjWJ00KoXjWJ0_l000000onX[]co0000okjbcP06
okjbcP03o`000?o1]/oo`KK?00Ko`KK?00?o0000ol6fcol000002_o3^M000ol0003oe/O;omK7b`06
omK7b`03o`000?oooooooooo01kooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2
o`0002Oooooo00?o0000ooooooooool06?ooool01Ol0003oVNjjoiW^^_oAolOo000000;oc_o600Go
0000olcnaoo<o/Oo0000ol[obP02o`0000;oi_;C00Go0000on?`eooSl=Ooho3Go`000003omk]f`05
o`000?oHj>3of>SPomSXh?l000000oo@hN@2o`0000?o`l3G00?o0000okRhfOnh^=T00_nh^=T01Ol0
003o[:kIojb^fOn/[]Wo000000?oWZ?I1?n?UmL3o`0000?oMhkM00Go0000ofQoeomXOmOo0000oeMj
fP02o`000003odi]d_l0003o?VGA00?o?VGA00?o0000oc9LcOl000000_l`H]<00ol0003o:e[=o`00
0003obMNdP;o000000?o<63Ao`000?l_IMH00_l00002obi[f`;o000000?o;G;Po`000?mDMmP01?mJ
O]`3o`0000?oH8KP00?o0000ofJ>i?mVS^@00omVS^@2o`0000?oKIKX00?o0000oi6HeonHW]P01_nH
W]P2o`0000OoWZCI0_l00008oj>YfP03o`000?nn//ko_[;>00Oo_[;>0_l00006ol6fc`03o`000?o1
]/oo`KK?00;o00001oo3^M000ol0003oeLC9o`000008omK7b`03o`000?oooooooooo01oooooo00?o
0000ooooooooool06oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool05_ooool01Ol0003oVNjjoiW^^_oAolOo000000;oc_o600Co0000olcnaoo<
o/Oo00000_o:olX01Ol0003oi_;ConKbdooVl]?o000000?oho3G00Go0000omk]fooNkM_og^gKo`00
0003omSXh0Co000000?ocLOEo`000?o3`=L00_o3`=L00ol0003o^;SIokRhf@02okRhf@03o`000?n/
[]Wo[:kI00;o[:kI00Co0000oijSfOnNXmWo00001?n?UmL2ogn;e003o`000?mgS]go000000CoJ7oG
0_l00003odi]dP03o`000?lnIM7o?VGA00;o?VGA00?o0000oc9LcOl000000_l00002ob]Jc@;o0000
0_lWG]801?l0003o<63Aoc1PdOl00002obmUeP04o`000?l^Jm_o;V_Kobi[f`;o00000_mDMmP3o`00
0003oeYng?l0003o000000CoH8KP00?o0000ofJ>i?mVS^@01?mVS^@00ol0003oKIKXo`000003oi6H
e`03o`000?nHW]SoV9kH00GoV9kH00?o0000oijTfOnNY=T01_nNY=T2o`0000KoXjWJ00?o0000okZ^
c_nn//h02Onn//h00ol0003o`KK?ol6fc`04ol6fc`05o`000?o1]/oo`KK?ol6fcol000001Oo3^M00
1Ol0003oeLC9omG4bOoEa<Wo000000Soe/O;00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo
0ol00002om7oa`07o`000?o>olKoc_o6o`000?o<o/Oo0000ol[obP02o`0000?oi_;C00Go0000on?`
eooSl=Ooho3Go`000004omk]f`03o`000?oHj>3of>SP00;o00001?o=amD00ol0003o`l3Gol?0e`02
ol?0e`03o`000?nh^=Wo^;SI00;o^;SI00Go0000ojb^fOn/[]Wo[:kIo`000003oijSf@05o`000?n?
UmOoSiOGohnGeol000000_moRm@2o`0000CoJ7oG0_mKL]401Ol0003oCVgBodi]d_m>KM;o000000Co
?VGA00Co0000oc9LcOlbG<go00001?l[F/d01?l0003o9ekBo`000?laFld2oc1Pd@03o`000?l_IMKo
;fGF00;o00000_l^Jm/3o`000003oeAgf?l0003o000000?oFWkL00?o0000of26h?mPQ^000_mPQ^02
o`0000GoIXkT00?o0000oi6HeonAV=L01?nAV=L00ol0003oV9kHoiRNf004oiRNf0;o00002?nNY=T0
0ol0003oXjWJoj>YfP02oj>YfP05o`000?nj[/ko^Zk>okZ^c_l000002Onn//h2o`0000Go`KK?00Co
0000ol6fcoo1]/oo`KK?0_l00003ol>id003o`000?oEa<WoeLC900;oeLC900?o0000omK7booFal/0
1_oFal/00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Wooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool04_ooool2o`000004om?ob_l0003odOo7o`0000;oc_o6
00?o0000olcnaoo<o/L00_l000000ooXlm3o0000onKbd`02onKbd`05o`000?oSl=Ooho3Gon?`eol0
00001?oNkM/3o`000003omC=d_l0003ocLOE00?ocLOE00?o0000ol?0eoo3`=L00_o3`=L00ol0003o
^;SIokRhf@02okRhf@05o`000?n/[]Wo[:kIojb^fOl000000onNXmT01Ol0003oSiOGohnGeon?UmOo
000000?oOh_D0_l00003ofQoe`04o`000?mKL]7oFg;Ao`0000?oCVgB1Ol00003oc9Lc@03o`000?l[
F/go:e[=00;o:e[=0_l00002oc5Kc@;o<63A0_l000000ol_IMKo0000o`000002o`000003odm`e?mD
MmSoE7OH00;oE7OH00Go0000oeYng?mJO]coFWkLo`000005of26h003o`000?mVS^CoIXkT00;oIXkT
00?o0000oh^BeOnAV=L01OnAV=L00ol0003oV9kHoiRNf005oiRNf003o`000?nNY=WoWZCI00KoWZCI
0_l000000onSZM[o0000okZ^cP04okZ^cP;o00002Onn//h00ol0003o`KK?ol6fc`02ol6fc`03o`00
0?o1]/oo`KK?00?o`KK?00?o0000ol>id?l000001_oEa<T00ol0003oe/O;omK7b`06omK7b`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool06Oooool002Oooooo0_l0000/ooooo`03o`000?oo
oooooooo013ooooo00Co0000om?ob_oCol[o00000_oAolL00ol0003oc_o6o`000002olcna`05o`00
0?oXlm3oj??@onScd?l000000ooVl]<01Ol0003oho3Gon?`eooSl=Oo000000?og^gK0_l00003omC=
dP03o`000?o=amGocLOE00?ocLOE00Go0000ol?0eoo3`=Oo`l3Go`000004okRhf@05o`000?n/[]Wo
[:kIojb^fOl000000onNXmT01Ol0003oSiOGohnGeon?UmOo000000?oOh_D0_maO]400ol0003oJ7oG
o`000004oe]bd@04o`000?m>KM;o0000o`0000?o>eg;0_l00002oc9Lc@03o`000?l^E/Wo000000?o
:e[=0_l00002oc5Kc@Co00000_l_IMH2o`0000;oCg3D00Go0000oeAgf?mDMmSoE7OHo`000003oeYn
g0;o00001?mPQ^02o`0000;oIXkT00Co0000oh^BeOn;T]Go00001OnAV=L2o`0000KoV9kH0_l00008
oijTf@03o`000?nj[/ko^Zk>00Ko^Zk>00?o0000okjbc_nn//h01onn//h2o`0000?o`KK?00?o0000
ol6fcoo1]/l00oo1]/l00ol0003oeLC9omG4b@06omG4b@03o`000?oFal_oe/O;00Koe/O;00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00kooooo00Oo0000om?ob_oCol[odoo:o`000?oAolOo000000;oc_o60ol0
0004onScd005o`000?oVl]?oi_;ConKbdol000000ooSl=L01_l0003og^gKomk]fol0003of]7@o`00
00Coe<gB00?o0000olg7eOo=amD00_o=amD01Ol0003o`l3Gol?0eoo3`=Oo000000Co^;SI00Go0000
ojb^fOn/[]Wo[:kIo`000003oijSf@03o`000?n?UmOoSiOG00;oSiOG00Co0000ogn;e?moRmCo0000
0_maO]42o`0000GoFg;A00Co0000odISc?m6Hlco00000olkGL/00ol0003o<eO8o`000002o`000003
obiFbOl0003o:e[=00;o:e[=1Ol00002oc1Pd@04o`000?l_IMKo;fGFo`0000?oCg3D00Co0000oeAg
f?mDMmSoE7OH0_l00003oeYng003o`000?mPQ^3oH8KP00?oH8KP0_l00004oh^Be@03o`000?nAV=Oo
TISG00CoTISG00?o0000oiRNf?nHW]P01OnHW]P2o`0000KoWZCI00?o0000okFZcOnj[/h01onj[/h0
0ol0003o_[;>okjbcP08okjbcP05o`000?o1]/oo`KK?ol6fcol000001?o1]/l00ol0003oeLC9omG4
b@07omG4b@03o`000?oFal_oe/O;00Koe/O;00?o0000ooooooooool07?ooool2o`0001[ooooo000W
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool01?l0003odoo:om?ob_l0
0002om7oa`06o`000?o>olKo0000o`000?oYllko00000ooXlm000ol0003oi_;ConKbd`02onKbd`07
o`000?oSl=Ooho3Gon?`eol0003og^gKo`000002om[Ad003o`000?oDcM;oe<gB00;oe<gB00?o0000
olg7eOo=amD00_o=amD01Ol0003o`l3Gol?0eoo3`=Oo000000Co^;SI00?o0000ojb^fOn/[]T00_n/
[]T01?l0003oWZ?IoijSfOl00004ohnGe`04o`000?moRmCoOh_Do`0000?oLGkA0_l00004oe]bd@05
o`000?m6HlcoAV?<odISc?l000000olkGL/01?l0003o<eO8oc=Gb?l00002obiFb@Go00000olaFld0
1ol0003o<63Aoc1PdOl0003o;fGFo`000?m;J]000om?L=@00ol0003oE7OHoeAgf002oeAgf004o`00
0?mJO]coFWkLoeYng0;o00001?mPQ^000ol0003oRi;Eoh^Be@03oh^Be@03o`000?nAV=OoTISG00Co
TISG0_l00007oiRNf003o`000?nNY=WoWZCI00;oWZCI00Go0000okFZcOneZ/go]J[=o`000007okZ^
cP;o00002Onn//h01Ol0003o`KK?ol6fcoo1]/oo000000;o`KK?00?o0000om?1bOl000002OoEa<T0
0ol0003oe/O;omK7b`06omK7b`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool0
02Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`04o`000?oCol[odoo:
o`0000;odOo700Co0000olkoa_o>olKo00000_oYllh01Ol0003oj??@onScd?oXlm3o000000Coi_;C
00Co0000on?`eooSl=Ooho3G0_l00004om[Ad005o`000?oDcM;oe<gBomC=d_l000001?o=amD01Ol0
003o`l3Gol?0eoo3`=Oo000000Go^;SI00Go0000ojb^fOn/[]Wo[:kIo`000003oijSf@05o`000?n?
UmOoSiOGohnGeol000000_moRm@01?l0003oLGkAog5ndOmaO]42of=bc@;o00000_mKL]42o`0000;o
AV?<00Go0000oc]MbolkGL_o>eg;o`000003oc=Gb0?o000000Go;UK9o`000?l0003o<US9o`000003
oc5Kc@03o`000?l`H=7o<63A00;o00000_m;J]03odm`e003o`000?mDMmSoE7OH00;oE7OH00?o0000
oeYng?mJO]`00_mJO]`01_l0003oH8KPof26h?mPQ^3o0000ohB<e0GoRi;E0_l00006oi6He`03o`00
0?nHW]SoV9kH00GoV9kH0_l00002oijTf@03o`000?neZ/go]J[=00;o]J[=00?o0000okZ^c_nj[/h0
1_nj[/h00ol0003o_[;>okjbcP07okjbcP;o000000Co`KK?o`000?o1]/oo00000ooC`LT00ol0003o
eLC9omG4b@07omG4b@03o`000?oFal_oe/O;00Koe/O;00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Fooooo`009oooool2o`00033ooooo00?o0000ooooooooool02_ooool01_l0003odoo:
om?ob_l0003odOo7o`0000;oc_o600Go0000onWcc_oYllkojO?>o`000003onScd003o`000?oVl]?o
i_;C00;oi_;C00?o0000on?`eooSl=L00_l00005om[Ad005o`000?oDcM;oe<gBomC=d_l000001?o=
amD00ol0003o`l3Gol?0e`02ol?0e`03o`000?nh^=Wo^;SI00;o^;SI00?o0000ojb^fOl000002?l0
00000on?UmOo0000ogn;e002ogn;e004o`000?maO]7oLGkAo`0000?oHg;=00GoFg;Ao`000?m@Il_o
D6O;o`000002odISc004o`000?lkGL_o>eg;oc]Mb`Co000000Co<E?5o`000?l^E/Wo;UK90_l00000
0olbF<Wo0000oc5Kc@02oc5Kc@04o`000?l`H=7o<63Ao`0000?oBf[@0om?L=@00ol0003oE7OHoeAg
f002oeAgf003o`000?mJO]coFWkL00;oFWkL00?o0000of26h?l000000on4S=@00ol0003oRi;Eoh^B
e@03oh^Be@03o`000?nAV=OoTISG00CoTISG0_l00007oiRNf003o`000?nNY=Wo000000Go]J[=00?o
0000okZ^c_nj[/h01_nj[/h00ol0003o_[;>okjbcP08okjbcP03o`000?o1]/oo000000Godl7900?o
0000omG4bOoEa<T01ooEa<T00ol0003oe/O;omK7b`06omK7b`03o`000?oooooooooo01cooooo00?o
0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08
ooooo`04o`000?oCol[odoo:o`0000;odOo700?o0000olkoa_l000001?oYllh01Ol0003oj??@onSc
d?oXlm3o000000?oi_;C00Ko0000on?`eol0003o0000omoDcOl00005om[Ad003o`000?oDcM;oe<gB
00;oe<gB00Go0000olg7eOo=amGocLOEo`000004ol?0e`03o`000?nh^=Wo^;SI00Co00000_nUWll4
oiVGc`?oS8g?0ol00002ogn;e005o`000?maO]7oLGkAog5ndOl000000omSL/d01_l0003oD6O;oe1W
bom@Il_o0000odISc0Go00000olcElP00ol0003o<E?5o`000002obiFb@04o`000?lbF<Wo<US9o`00
00?o<E_=00?o0000oc1PdOl000001?m;J]001?l0003oCg3Dodm`e?l00004oeAgf0;o00000omJO]`0
0ol0003oQ8cDohB<e003ohB<e003o`000?n;T]GoRi;E00?oRi;E00?o0000oi6HeonAV=L01OnAV=L0
0ol0003oV9kHoiRNf005oiRNf003o`000?neZ/go]J[=00Go]J[=0_l00007okZ^cP;o00002Onn//h0
0ol0003odl79o`000005om?1b@03o`000?oEa<WoeLC900OoeLC900?o0000omK7booFal/01_oFal/0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo000Vooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool01oooool01ol0003odoo:om?ob_l0003odOo7o`000?o>olH00_l0
0003onWccP03o`000?oXlm3oj??@00;oj??@00Co0000onKbdooVl]?oi_;C0_l00003omoDc@03o`00
0?oJdM3of]7@00?of]7@00?o0000omC=d_oDcM800_oDcM800ol0003ocLOEolg7e@02olg7e@03o`00
0?o3`=Oo`l3G00Co00000_n`Y/h5ojFOc`CoVIO?0on<SLl2ogn3cP03o`000?moRmCo000000?oLGkA
00Ko0000of=bcOmSL/goHg;=oeIXbOl00003oe1Wb`?o00000_ljElD3o`000007oc=Gb?l0003o<E?5
oc5CaOl0003o;UK9o`000003oc9Hb@04o`000?laFlgo<E_=oc5Kc@?o00001?m;J]001?l0003oCg3D
odm`e?l00005oeAgf005o`000?mJO]coFWkLo`000?mlQ]801On4S=@00ol0003oRi;Eoh^Be@03oh^B
e@03o`000?nAV=OoTISG00GoTISG00?o0000oiRNf?nHW]P01?nHW]P00ol0003o/:G=okFZc@07okFZ
c@03o`000?nj[/ko^Zk>00Ko^Zk>00?o0000okjbc_nn//h01_nn//h01?l0003odl79om?1bOl00005
om?1b@03o`000?oEa<WoeLC900OoeLC900?o0000omK7booFal/01OoFal/00ol0003oooooooooo`0L
ooooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`04o`000?oCol[odoo:o`0000;odOo70_l000000ooZm<co0000onWccP02onWccP03o`000?oXlm3o
j??@00;oj??@00?o0000onKbdooVl]<00_l00005omoDc@03o`000?oJdM3of]7@00;of]7@00?o0000
omC=d_oDcM800_oDcM800ol0003ocLOEolg7e@02olg7e@?o000000?o^Jg=ok2Vc_n`Y/h01?n`Y/h4
ojFOc`05o`000?nIUlooVIO?oiVGcol000000on<SLl3ogn3cP;o00000_maO]401_l0003oHg;=of=b
cOmSL/go0000oeIXb@Co00000_m1FlH01Ol0003o>UO5ocYGaOl0003o=E?400?o00000_laDlD3o`00
00?o<US900Oo0000oc5KcOlaFlgo<E_=o`000?m7ILgo000000CoBf[@00Co0000odm`e?m?L=Co0000
1OmDMmP2o`0000?oO8KB1On4S=@00ol0003oRi;Eoh^Be@03oh^Be@03o`000?nAV=OoTISG00GoTISG
0_l00003oiRNf005o`000?n`YLgo/:G=ok2UcOl000001oneZ/d00ol0003o^Zk>okZ^cP06okZ^cP03
o`000?nn//ko_[;>00Co_[;>00Go0000om6nb?l0003odl79o`000006om?1b@03o`000?oEa<WoeLC9
00OoeLC900?o0000omK7booFal/00ooFal/00ol0003oi][8o`00000Nooooo`03o`000?oooooooooo
01Cooooo000Vooooo`?o0000=?ooool00ol0003oooooooooo`04ooooo`05o`000?oCol[odoo:o`00
0?oAolL00_l00002on[dc005o`000?oYllkojO?>onWcc_l000001?oXlm001Ol0003oi_;Co`000?oR
el_o000000GogmC=00?o0000om[Ad?oJdM000ooJdM001Ol0003oe<gBomC=d_oDcM;o000000?ocLOE
0_l00004okV]c@Go/:K>00Go0000ojFOconUWlooYIo?o`000003oiVGc`05o`000?n<SLooS8g?ohb=
col000000_moPlh2og5ic0;o000000?oLGkAo`000?mSL/d00ol000001OmFJ<WoD6O;o`000?m7G/Ko
000000;o@E_600Co0000ocYGaOljElGo00000_leDl@01?l0003o<E?5oc5CaOlaDlD3o`0000?o<US9
00Co0000oc5KcOlaFlgo00000_m7ILd00ol0003oBf[@od]Zd002od]Zd004o`000?m?L=CoCg3Do`00
00GoE7OH00?o0000ogb6d_mlQ]800_mlQ]800ol0003oQ8cDohB<e002ohB<e003o`000?n;T]GoRi;E
00?oRi;E00?o0000oi6HeonAV=L01_nAV=L00ol0003oV9kHo`000005ok2Uc@03o`000?neZ/go]J[=
00Go]J[=00?o0000okZ^c_nj[/h01_nj[/h2o`0000Co_[;>00Ko0000om6nb?oA_/So0000om?1bOl0
0006om?1b@03o`000?oEa<WoeLC900OoeLC900Go0000omK7booFal_oe/O;o`000002onKJb003o`00
0?oooooooooo01gooooo00?o0000ooooooooool04oooool002Kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?oCol[odoo:o`0000;odOo700Go0000on[dc?oZm<co
j_C<o`000003onWccP07o`000?oXlm3oj??@onScd?l0003oi_;Co`000002on;Gb`03o`000?oOe<go
gmC=00?ogmC=00?o0000om[Ad?oJdM000ooJdM001Ol0003oe<gBomC=d_oDcM;o000000;ocLOE00?o
0000ol6bc?ni[Ld01?ni[Ld00ol0003o/:K>ok2VcP02ok2VcP03o`000?nUWlooYIo?00;oYIo?00Go
0000oiVGconIUlooVIO?o`000002ohb=c`04o`000?moPlkoOh?>ogn3cP?oLGW<0ol00002of=bc@04
o`000?mFJ<WoEVS9o`0000;oAek600?o0000od5Ka_l000000oljElD01?l0003o=E?4ocECa?l00003
oc5Ca@03o`000?lcELKo000000?o<US900Co0000oc5KcOl0003o00000_m7ILd00ol0003oBf[@od]Z
d002od]Zd004o`000?m?L=CoCg3Do`0000CoE7OH00?o0000ogb6d_mlQ]800omlQ]800ol0003oQ8cD
ohB<e002ohB<e0;o00001?n;T]D2o`0000OoTISG00?o0000ok2UcOn`YLd01On`YLd00ol0003o]J[=
okFZc@05okFZc@03o`000?nj[/ko^Zk>00Oo^Zk>00Co0000okjbc_nn//ko00001?oA_/P00ol0003o
dl79o`000006om?1b@03o`000?oEa<WoeLC900OoeLC900?o0000omK7bol000000ooVf/P00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000?odoo:0ol00003on[d
c003o`000?oYllkojO?>00;ojO?>00Co0000onScd?oXlm3oj??@0_l00004on;Gb`03o`000?oOe<go
gmC=00;ogmC=00?o0000om[Ad?oJdM000ooJdM000ol0003oe<gBomC=dP02omC=dP;o00000oo1//`5
okV]c@03o`000?n`Y/ko/:K>00;o/:K>00Go0000ojFOconUWlooYIo?o`000003oiVGc`05o`000?n<
SLooS8g?ohb=col000000_moPlh3o`000006og5ic?mTL<WoI739o`000?mSL/go00000_mFJ<T01?m<
GlGo0000odMNa_l00002od5KaP04o`000?ljElGo>UO5o`0000;o=E?40_l00002oc5Ca@04o`000?lc
ELKo<eG6o`0000?o<US90_l000001Om4H<Wo0000odMUcOm7ILgo000000CoBf[@00Co0000odm`e?m?
L=Co00000_mDMmP00ol0003oMH3@o`000005ogb6dP03o`000?n4S=CoQ8cD00?oQ8cD00?o0000oh^B
eOn;T]D00on;T]D00ol0003oTISGoi6He`04oi6He`;o00001on`YLd00ol0003o]J[=okFZc@05okFZ
c@03o`000?nj[/ko^Zk>00Oo^Zk>00?o0000okjbc_l000001OoA_/P00ol0003odl79o`000006om?1
b@03o`000?oEa<WoeLC900OoeLC900?o0000onKJb?oVf/P00ooVf/P00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01;ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`0hooooo`?o00000_oColX2o`000003on[dc?l0003oj_C<00;oj_C<00?o0000onWc
c_oYllh00_oYllh01Ol0003oj??@onScd?oXlm3o000000Goh]O;00?o0000omoDcOoOe<d00_oOe<d0
0ol0003of]7@om[Ad003om[Ad004o`000?oDcM;oe<gBomC=dP;o00001?o1//`00ol0003o^Jg=okV]
c@02okV]c@03o`000?n`Y/ko/:K>00;o/:K>00?o0000ojFOconUWll00_nUWll01?l0003oVIO?oiVG
col00003ohb=c`?o000000GoOh?>og5ic?maNLcoLGW<o`000003ofA`b@09o`000?mFJ<WoEVS9o`00
0?m<GlGo0000odMNa_l0003o@E_600Ko000000Co=E?4o`000?l0003o<E?50_l00002oc=EaP05o`00
0?lbF<Wo<US9oc9HbOl000000_m4H<T01?l0003oAfG=odMUcOl00004od]Zd006o`000?m?L=CoCg3D
o`000?mDMmSo00000_meP=000ol0003oO8KBogb6dP03ogb6dP03o`000?n4S=CoQ8cD00?oQ8cD00?o
0000oh^BeOn;T]D00on;T]D00ol0003oTISGoi6He`02oi6He`04o`000?n[XLgoZj7=o`0000Oo/:G=
00?o0000okFZcOneZ/d01OneZ/d2o`0000So^Zk>00?o0000om6nb?oA_/P01OoA_/P2o`0000Oodl79
00?o0000omG4bOoEa<T01_oEa<T00ol0003oi][8onKJb003onKJb003o`000?oooooooooo01kooooo
00?o0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?oo
ooooooooooooool@41001Oooool3o`0003Wooooo00?o0000om?ob_oColX00_l00002on[dc005o`00
0?oZm<coj_C<on[dc?l000001?oYllh00ol0003oj??@onScd002o`0000Goh]O;00?o0000omoDcOoO
e<d00ooOe<d00ol0003of]7@om[Ad002om[Ad005o`000?oDcM;oe<gBo`000?o7]lX01_o1//`01Ol0
003o^Jg=okV]cOni[Lgo000000Go/:K>00Go0000ojFOconUWlooYIo?o`000003oiVGc`Co00000omo
Plh01Ol0003oLGW<og5ic?maNLco000000;oI73900CoF6K6o`000?mFJ<Wo00000_m<GlD01Ol0003o
Aek6o`000?llEL;o000000;o>E?200Oo0000ocI@`Ol0003o0000oc=A`_l0003o<E?500;o00000_lc
ELH01?l0003o<US9oc9HbOl00003odAPb@04o`000?m7ILgoAfG=o`0000CoBf[@00Co0000odm`e?m?
L=Co00001?meP=000ol0003oO8KBogb6dP03ogb6dP03o`000?n4S=CoQ8cD00?oQ8cD00?o0000oh^B
eOn;T]D00on;T]D01?l0003oTISGoi6Heol00004oj^Qc@03o`000?n`YLgo/:G=00Go/:G=00?o0000
okFZcOneZ/d01_neZ/d00ol0003o^Zk>okZ^cP05okZ^cP03o`000?oA_/SodKk800KodKk80_l00007
om?1b@03o`000?oEa<WoeLC900CoeLC900?o0000onKHaol000001OoVf/P00ol0003oooooooooo`0L
ooooo`?o00002_ooool00ol0003oooooooooo`05ooooo`006oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0>Oooool01?l0003odoo:om?ob_l00003on[dc005o`000?oZ
m<coj_C<on[dc?l000000ooYllh01_l0003oj??@onScd?l0003oiMW:o`0000Goh]O;00?o0000omoD
cOoOe<d00ooOe<d00ol0003of]7@om[Ad003om[Ad0;o00000oo7]lX5ol6bc003o`000?ni[Lgo^Jg=
00;o^Jg=00?o0000ok2Vc_n`Y/h00_n`Y/h01?l0003oYIo?ojFOconUWll5o`0000?oS8g?00Co0000
ogn3c_moPlko00000omaNL`02?l0003oI739ofA`bOl0003oF6K6o`000?mFJ<Wo00000_m<GlD01Om7
G/Ko0000ocaE`_llEL;o000000;o>E?200?o0000ocI@`Ol000000_lcDL82o`000004ocAB`ol0003o
<eG6oc=EaP;o000000?o@E_7o`000?m4H<T00_m4H<T01?l0003oAfG=odMUcOl00004od]Zd003o`00
0?m?L=Co000000GoMH3@00?o0000ogb6d_mlQ]800omlQ]800ol0003oQ8cDohB<e003ohB<e003o`00
0?n;T]GoRi;E00?oRi;E00?o0000oi6Heol000001On[XLd00ol0003o/:G=ok2Uc@05ok2Uc@03o`00
0?neZ/go]J[=00Ko]J[=00?o0000okZ^c_nj[/h00onj[/h00ol0003ocK_8o`000008om6nb0;o0000
1ooC`LT00ol0003oeLC9omG4b@02omG4b@04o`000?oVf<Ooi]S7o`0000Goi][800?o0000oooooooo
ool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0hooooo`04o`000?oCol[o0000o`00
00Coj_C<00Go0000on[dc?oZm<coj_C<o`000003onWccP03o`000?oXlm3o000000?oiMW:00?o0000
on;GbooRel/00ooRel/00ol0003ogmC=omoDc@02omoDc@03o`000?oJdM3of]7@00;of]7@0_l00004
olNgbP03o`000?o1//co`K;<00;o`K;<00?o0000okV]cOni[Ld00_ni[Ld00ol0003o/:K>ok2VcP02
ok2VcP03o`000?nUWloo000000?o00000_nIUll01Ol0003oS8g?ohb=con<SLoo000000?oOh?>00Co
0000og5ic?maNLco00000omTL<T01?l0003oF6K6oeIXbOl00003odaOa@;o00000_llEL800ol0003o
>E?2o`000002ocI@`@04o`000?lcDL;o<e72o`0000;o=5;300Co0000oc=Ea_lcELKo00000_m1FlL0
1Ol0003oA639odAPbOm4H<Wo000000;oAfG=00?o0000od]Zd?m;J]000_m;J]000ol0003oKGW>o`00
0005ogF0d003o`000?mlQ];oO8KB00?oO8KB00?o0000ohB<e?n4S=@00on4S=@00ol0003oRi;Eoh^B
e@03oh^Be@03o`000?n[XLgoZj7=00GoZj7=00?o0000ok2UcOn`YLd01On`YLd00ol0003o]J[=okFZ
c@06okFZc@05o`000?nj[/ko^Zk>okZ^c_l000000oo=^lP00ol0003odKk8om6nb006om6nb0;o0000
1ooC`LT01Ol0003oeLC9omG4bOoEa<Wo000000;oi]S700?o0000onKJb?oVf/P01?oVf/P00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Sooooo0_l000000ooZllgo
0000on[dc002on[dc003o`000?oZm<coj_C<00;oj_C<00Co0000onWcc_oYllkojO?>0_l00004onGI
bP03o`000?oRel_oh]O;00?oh]O;00?o0000omoDcOoOe<d00_oOe<d01ol0003of]7@om[Ad?oJdM3o
0000olfkb?l000001Oo7]lX00ol0003o`K;<ol6bc002ol6bc003o`000?ni[Lgo^Jg=00;o^Jg=00?o
0000ok2Vc_n`Y/h00ol00003ojFOc`05o`000?nIUlooVIO?oiVGcol000000_n<SLl01Ol0003oOh?>
ogn3c_moPlko000000;oLGW<00Go0000ofA`bOmTL<WoI739o`000002oeQVaP;o00000_m<GlD01Ol0
003o@5O2o`000?llEL;o000000;o>E?200Go0000ocI@`Ol0003o0000oc=A`P02o`0000;o=5;300?o
0000oc=Ea_l000000om1FlL01?l0003oA639odAPbOl00003odMUc@05o`000?m;J]3oBf[@od]Zd?l0
00000_m]NLh00ol0003oMH3@ogF0d003ogF0d003o`000?mlQ];oO8KB00?oO8KB00?o0000ohB<e?n4
S=@00on4S=@01ol0003oRi;Eoh^BeOn;T]Go0000ojBLcOl000001on[XLd00ol0003o/:G=ok2Uc@05
ok2Uc@03o`000?neZ/go]J[=00Ko]J[=00?o0000okZ^c_l000001Oo=^lP00ol0003odKk8om6nb005
om6nb0;o00002?oC`LT00ol0003oeLC9o`000004onKHa`03o`000?oVf/Soi][800?oi][800?o0000
ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Koooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0003Sooooo0_l00002on[cc@05o`000?oZm<co
j_C<on[dc?l000001?oZm<`01Ol0003ojO?>onWcc_oYllko000000GoiMW:00?o0000on;GbooRel/0
0ooRel/00ol0003ogmC=omoDc@02omoDc@04o`000?oJdM3of]7@o`0000?ocK_800?o0000olNgb_o7
]lX00_o7]lX00ol0003o`K;<ol6bc002ol6bc003o`000?ni[Lgo^Jg=00;o^Jg=0ol00002ok2VcP05
o`000?nUWlooYIo?ojFOcol000000_nIUll:o`000003og5ic?l0003oI73900;oI73900?o0000oeQV
a_mHI/H00_m=G/<02_l0003oC5o5o`000?l0003o@5O2o`000?llEL;o0000ocUC`_l00002ocI@`@?o
000000Co=U31o`000?ldD/?o=5;30ol00003od5Ka`04o`000?m4H<WoA639o`0000?oAfG=00Go0000
od]Zd?l0003oIW?<o`000002ofeicP03o`000?meP=3oMH3@00?oMH3@00?o0000ogb6d_mlQ]800oml
Q]800ol0003oQ8cDohB<e003ohB<e003o`000?n;T]Go000000?oY9c=00?o0000oj^QcOn[XLd01On[
XLd00ol0003o/:G=ok2Uc@05ok2Uc@03o`000?neZ/go]J[=00Ko]J[=00?o0000olfkb?o=^lP01Oo=
^lP00ol0003odKk8om6nb005om6nb0;o00002?oC`LT00ol0003oi]S7onKHa`03onKHa`03o`000?oV
f/Soi][800?oi][800?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`0gooooo`05o`000?oZllgoj_?=on[ccOl000000ooZm<`00ol0003oj_C<on[dc002on[dc003o`00
0?oYllkojO?>00;o00001OoUfLX00ol0003oh]O;on;Gb`04on;Gb`03o`000?oOe<gogmC=00;ogmC=
0_l00004olfkb003o`000?o7]l[oakO:00?oakO:00?o0000ol6bc?o1//`00_o1//`4o`000003okV]
cOl0003o/:K>00;o/:K>00?o0000ojFOconUWll01?l000000on>Rl_oPh?:oh>3bP02oh>3bPCoMg_9
0_m/L/P01OmaNLco0000ofA`bOmTL<Wo000000?oF6K60_m=G/<00om<GlGo0000od=G`P02od1G`P;o
?5G20_l00002ocI@`@06o`000?leCkoo0000o`000?lfD<7o00000_ldD/<00ol0003o?US4o`000003
od5Ka`04o`000?m4H<WoA639o`0000?oAfG=00Go0000ofIcc?mVLlcoIW?<o`000002ofeicP03o`00
0?meP=3oMH3@00?oMH3@00?o0000ogb6d_mlQ]800omlQ]800ol0003oQ8cDohB<e003ohB<e003o`00
0?nTW<goY9c=00?oY9c=00?o0000oj^QcOn[XLd01On[XLd00ol0003o/:G=ok2Uc@05ok2Uc@03o`00
0?neZ/go]J[=00Go]J[=00?o0000olfkb?o=^lP01Oo=^lP00ol0003odKk8om6nb006om6nb0;o0000
1ooC`LT00ol0003oi]S7onKHa`04onKHa`03o`000?oVf/Soi][800?oi][800?o0000ooooooooool0
7_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool002Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oj_?=on[cc@02on[cc@05o`000?oZm<coj_C<on[dc?l000000ooZm<`01?l0003ojO?>
onWcc_l00002onKJb@03o`000?oUfL[oiMW:00?oiMW:00?o0000on;GbooRel/00ooRel/00ol0003o
gmC=omoDc@02omoDc@03o`000?o=^lSocK_800CocK_800?o0000olNgb_o7]lX00_o7]lX00ol0003o
`K;<ol6bc003o`0000Co^Jg=00Co0000ok2Vc_n`Y/ko/:K>0ol00002oiVAb`CoSX_;1?n3PlX4ogMk
b@;oK7;80ol000001OmTL<Wo0000oeQVa_mHI/Ko000000;oCEk300?o0000od=G`_l000000_m0El82
o`000004ocQ?_ol0003o0000o`0000;o=Dno00Ko0000ocI@`OlfD<7o0000ocAB`ol00002ociHa004
o`000?m1FlOo@E_7o`0000?oA63900Co0000odMUcOm7ILgo00001?mVLl`01?l0003oKGW>ofeic_l0
0005ogF0d003o`000?mlQ];oO8KB00?oO8KB00?o0000ohB<e?n4S=@00_n4S=@00ol0003oY9c=ojBL
c@04ojBLc@03o`000?n[XLgoZj7=00GoZj7=00?o0000ok2UcOn`YLd01On`YLd00ol0003o]J[=okFZ
c@03okFZc@03o`000?o9]lSo000000OocK_800?o0000om6nb?oA_/P01_oA_/P2o`0000Godl7900?o
0000onGFaol000001OoVf<L00ol0003oi][8onKJb003onKJb003o`000?oooooooooo01gooooo00?o
0000ooooool000001Oooool00omEEEGoIVIVo`000007ooooo`009?ooool00ol0003oooooooooo`0g
ooooo`05o`000?oZllgoj_?=on[ccOl000001?oZm<`01ol0003oj_C<on[dc?oZm<co0000onWcc_l0
00000ooVf/T00ol0003oiMW:onGIbP03onGIbP03o`000?oRel_oh]O;00?oh]O;00Co0000omoDcOoO
e<gogmC=0_l00006olfkb003o`000?o7]l[oakO:00?oakO:0_l00003ol6bc006o`000?ni[Lgo^Jg=
okV]cOl0003o/:K>0_l000000onRV<[oVI7;oiVAb`03oiVAb`?oSX_;00Go0000oh>3b_n3Pl[oPh?:
o`000003ogMkb@03o`000?m/L/SoH6_600;oH6_60ol000001OmHI/Ko0000odeN`om=G/?o000000;o
@eO20_m0El801Ol0003o>E2oo`000?l0003o=Tjn00;o000000?o=Dnoo`000?lfD<400_lfD<43o`00
00;o?US400Co0000od5Kaom1FlOo00000om4H<T2o`000003oei]b_l0003oIW?<00?oIW?<00Co0000
ofeic_m]NLko00001OmeP=000ol0003oO8KBogb6dP03ogb6dP06o`000?n4S=CoQ8cDo`000?nMU/go
00001_nTW<d00ol0003oZj7=oj^Qc@05oj^Qc@03o`000?n`YLgo/:G=00Go/:G=00Go0000okFZcOne
Z/go]J[=o`000003olVgb003o`000?o=^lSocK_800GocK_800?o0000om6nb?oA_/P01_oA_/P00ol0
003odl79om?1b@02om?1b@04o`000?oUe/OoiMK7o`0000Koi]S700?o0000onKJb?oVf/P00ooVf/P0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo000Tooooo`;o0000>?ooool01Ol0
003oj_?=on[ccOoZllgo000000Coj_C<00Co0000on[dc?oZm<coj_C<0_l00004onKJb@03o`000?oU
fL[oiMW:00?oiMW:00?o0000on;GbooRel/00ooRel/01?l0003ogmC=omoDcOl00002om6na`03o`00
0?o=^lSocK_800CocK_800?o0000olNgb_l000000ol00004ol6bc004o`000?ni[Lgo^Jg=okV]c@;o
00001?nRV<X4oiVAb`05o`000?n>Rl_oSX_;ohj;bol000000on3PlX01?l0003oMg_9ogMkbOl00002
ofabb0?oH6_60_mEHl@00ol0003oF6K6o`000002odeN``07o`000?m3El;o@eO2o`000?lkDKoo0000
ocU@_`02o`000003ocI>__l0003o=Dno00;o00000olfD<400ol0003o?5C2o`000002ociHa004o`00
0?m1FlOo@E_7o`0000?oA63900Co0000oei]b_mNKL[o00000omVLl`01Ol0003oKGW>ofeic_m]NLko
000000GoMH3@00?o0000ogb6d_mlQ]800omlQ]800ol0003oQ8cDo`000002oifFc@03o`000?nTW<go
Y9c=00CoY9c=00?o0000oj^QcOn[XLd01On[XLd00ol0003o/:G=ok2Uc@05ok2Uc@03o`000?neZ/go
000000GobKO800?o0000olfkb?o=^lP01Oo=^lP00ol0003odKk8om6nb006om6nb005o`000?oC`LWo
dl79om?1bOl000000_oUe/L00ol0003oi]S7onKHa`04onKHa`03o`000?oVf/Soi][800?oi][800?o
0000ooooooooool07_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo03Oooooo00Go0000
on[ccOoZllgoj_?=o`000004on[dc005o`000?oZm<coj_C<on[dc?l000001_oVf/T00ol0003oiMW:
onGIbP03onGIbP03o`000?oRel_oh]O;00?oh]O;0_l00003om6na`03o`000?o=^lSocK_800?ocK_8
0ol00004olNgbP06o`000?o1//co`K;<ol6bc?l0003o^Jg=0_l000000on[WLWo0000oj:HbP03oj:H
bP03o`000?nITL_oVI7;00;oVI7;00Co0000ohj;bon>Rl_o00000on3PlX01ol0003oMg_9ogMkbOmg
NlWo0000ofabb?l000000omPJlH3oeESa0;o000000GoCEk3o`000?l0003o@eO2o`000002oc]A_`?o
000000Co=Tjno`000?l0003o=Dno0_l00002ocI@`@04o`000?llE<;o?5C2o`0000;o?US400Go0000
od5Kaom1FlOo0000odAPb@02o`0000?oGVg:00Go0000ofIcc?mVLlcoIW?<o`000003ofeicP03o`00
0?meP=3oMH3@00?oMH3@00?o0000ogb6d_mlQ]800omlQ]800ol0003oWIK=oifFc@02oifFc@03o`00
0?nTW<goY9c=00CoY9c=00?o0000oj^QcOn[XLd01On[XLd00ol0003o/:G=ok2Uc@05ok2Uc@03o`00
0?o9]lSobKO800CobKO800?o0000olfkb?o=^lP01_o=^lP00ol0003odKk8om6nb006om6nb003o`00
0?oC`LWo000000CoiMK700?o0000onKHaooVf<L00ooVf<L00ol0003oi][8onKJb003onKJb003o`00
0?oooooooooo01_ooooo0ol00002ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oo
oooooooo03Oooooo00Go0000on[ccOoZllgoj_?=o`000004on[dc003o`000?oZm<coj_C<00;o0000
1_oVf/T00ol0003oiMW:onGIbP03onGIbP03o`000?oRel_oh]O;00;oh]O;0_l00005om6na`03o`00
0?o=^lSo000000;o00000_o=^lP00ol0003oakO:olNgbP02olNgbP03o`000?o1//co`K;<00;o`K;<
00?o0000oj^MbOn[WLT00_n[WLT00ol0003oXYS:oj:HbP02oj:HbP05o`000?nITL_oVI7;oiVAbol0
00000on>Rl/01Ol0003oPh?:oh>3b_n3Pl[o000000;oMg_900Co0000ofabb?m/L/So00000_mPJlH0
0ol0003oEF?4oeESa002od]L`P04odeN`ol0003oA5O1od=G`P;o000000Ko>e6oo`000?liD;oo>4no
o`000?lfC[h3o`000003ocI?_ol0003o=U3100;o00000_llE<801?l0003o?US4ociHa?l00002od5K
a`04o`000?mGIlSoEfO8o`0000?oGVg:00Go0000ofIcc?mVLlcoIW?<o`000003ofeicP03o`000?me
P=3oMH3@00?oMH3@00Co0000ogb6d_mlQ];oO8KB0_l00005oifFc@03o`000?nTW<goY9c=00CoY9c=
00?o0000oj^QcOn[XLd01On[XLd00ol0003o/:G=ok2Uc@04ok2Uc@03o`000?o9]lSobKO800GobKO8
00?o0000olfkb?o=^lP01_o=^lP00ol0003odKk8om6nb006om6nb003o`000?oUe/OoiMK700?oiMK7
00?o0000onKHaooVf<L01?oVf<L00ol0003oi][8onKJb003onKJb003o`000?oooooooooo01Oooooo
0ol00005ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Kooooo00?o
0000on[ccOoZlld00_oZlld01Ol0003oj_C<on[dc?oZm<co000000;oj_C<00Co0000onOLb?oWg<So
00001OoVf/T00ol0003oiMW:onGIbP03onGIbP07o`000?oRel_oh]O;on;Gbol0003oeL76o`000004
om6na`?o00001Oo=^lP00ol0003oakO:olNgbP03olNgbP03o`000?o1//co`K;<00;o00001On[WLT0
0ol0003oXYS:oj:HbP02oj:HbP05o`000?nITL_oVI7;oiVAbol000000on>Rl/01?l0003oPh?:oh>3
b_l00003ogMkb@03o`000?m/L/So000000?oH6_60omEHl@2od]L`P03odeN`ol0003oA5O100?o0000
00So>e6oocU@_oliD;oo0000ocI>__l0003o=Tjno`0000;o=Tno0_l000001OljD/3o0000ocaD`_ll
E<;o000000;o?US400?o0000od5Kaol000000omGIlP01?l0003oGVg:oei]b_l00004ofIcc005o`00
0?m]NLkoKGW>ofeic_l000001OmeP=000ol0003oO8KBo`000002oiFAc003o`000?nMU/goWIK=00?o
WIK=00?o0000ojBLcOnTW<d01?nTW<d00ol0003oZj7=oj^Qc@05oj^Qc@03o`000?n`YLgo/:G=00;o
/:G=00?o0000olFcbOl000001oo9]lP00ol0003ocK_8olfkb005olfkb003o`000?oA_/SodKk800Go
dKk80_l00006onGFa`03o`000?oVf<Ooi]S700?oi]S700?o0000onKJb?oVf/P00ooVf/P00ol0003o
ooooooooo`0Cooooo`Co00002?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0003Oooooo
00?o0000on[ccOoZlld00_oZlld01ol0003oj_C<on[dc?oZm<co0000on[dc?l000000ooWg<P00ol0
003oi][9onKJb@04onKJb@03o`000?oUfL[oiMW:00;oiMW:00Co0000on;GbooRel_o00000ooE`LH4
o`0000;odKk700?o0000olfkb?o=^lP01?o=^lP00ol0003oakO:olNgbP02olNgbP03o`000?o1//co
000000;o/Z?800?o0000oj^MbOn[WLT00_n[WLT00ol0003oXYS:oj:HbP02oj:HbP03o`000?nITL_o
VI7;00;oVI7;00Co0000ohj;bon>Rl_o00000on3PlX01?l0003oMg_9ogMkbOl00002ofabb004o`00
0?mPJlKoH6_6o`0000;oEF?400?o0000od]L`_m;G<800_l00002oceB_P03o`000?lkDKoo>e6o00Co
000000?o=Tjno`000?l000000_lfCkl01?l0003o>U;0ocYB`?l00002ocaD`P06o`000?lnF<Co?US4
o`000?mAH/Ko00000omGIlP01?l0003oGVg:oei]b_l00004ofIcc005o`000?m]NLkoKGW>ofeic_l0
00001OmeP=000ol0003oUI7<oiFAc002oiFAc003o`000?nMU/goWIK=00?oWIK=00?o0000ojBLcOnT
W<d01?nTW<d00ol0003oZj7=oj^Qc@05oj^Qc@04o`000?n`YLgo/:G=o`0000?oaK?900?o0000olVg
b?o9]lP01Oo9]lP00ol0003ocK_8olfkb005olfkb003o`000?oA_/SodKk800?odKk800Co0000on?C
aooSdlOo00001OoUe/L00ol0003oi]S7onKHa`04onKHa`04o`000?oVf/Soi][8onKJb0;o00004_oo
ool3o`0000gooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool0
0ol0003oj_?=on[cc@02on[cc@04o`000?oZm<coj_C<on[dc0;o00001?oWg<P00ol0003oi][9onKJ
b@04onKJb@03o`000?oUfL[oiMW:00?oiMW:0_l00002omG1aP?o00001_oA_/L00ol0003ocK_8olfk
b003olfkb003o`000?o7]l[oakO:00;oakO:0_l00004ok:Sb003o`000?n[WLWoZig900;oZig900?o
0000oj:Hb_nRV<X00_nRV<X01Ol0003oVI7;oiVAbonITL_o000000?oSX_;00Co0000oh>3b_n3Pl[o
00000omgNlT00ol0003oK7;8o`000002of1[aP04o`000?mEHlCoEF?4o`0000;oBec20_m3E/001?m4
El7o?E:noceB__lmD[l2o`000003ocQ>_Ol0003o=dfm00;o000000Co=djmo`000?lfCkoo00000_lj
D/001ol0003o?5C2ocaD`_llE<;o0000ociHa?l000000_mAH/H01?l0003oEfO8oeMWb?l00003oei]
bP03o`000?mVLlcoIW?<00;oIW?<00Go0000ofeic_m]NLkoKGW>o`000003ogF0d0;o00001OnETL`0
0ol0003oWIK=oifFc@03oifFc@03o`000?nTW<goY9c=00CoY9c=00?o0000oj^QcOn[XLd01On[XLd0
0ol0003o/:G=o`000004olFcb@03o`000?o9]lSobKO800GobKO800?o0000olfkb?o=^lP01Oo=^lP0
1Ol0003odKk8om6nb?oA_/So000000?ohm?70_l00005onGFa`03o`000?oVf<Ooi]S700?oi]S700Ko
0000onKJb?oVf/So0000onoba?l0000?ooooo`?o00004?ooool00ol0003oooooooooo`0:ooooo`00
8oooool00ol0003oooooooooo`0gooooo`03o`000?oZllgoj_?=00;oj_?=00Go0000on[dc?oZm<co
j_C<o`000006onOLb003o`000?oVf/Woi][900?oi][900?o0000onGIb_oUfLX00ooUfLX4o`0000?o
eL7600?o0000om6naooA_/L00ooA_/L00ol0003ocK_8olfkb004olfkb006o`000?o7]l[oakO:o`00
0?nhYlSo00001?nbXlP00ol0003oZig9oj^Mb@03oj^Mb@05o`000?nRV<[oXYS:oj:Hb_l000001?nI
TL/01?l0003oSX_;ohj;bol00003oh>3bP04o`000?mgNlWoMg_9o`0000;oK7;800Co0000of1[a_mP
JlKo00000_mEHl@00ol0003oBec2od]L`P02od=F`005o`000?lmD[ko?E:no`000?lhC[d01?l00000
0olfC[ko0000ocM>_@03o`0000;o>U;000Oo0000ocaD`_llE<;o?5C2o`000?m;GLCo000000;oDF;6
00Co0000oeMWb?mGIlSo00000omNKLX01Ol0003oIW?<ofIcc?mVLlco000000CoKGW>00?o0000ogF0
d?l000000_n=Rl`00ol0003oUI7<oiFAc003oiFAc003o`000?nMU/goWIK=00?oWIK=00?o0000ojBL
cOnTW<d01?nTW<d00ol0003oZj7=oj^Qc@05oj^Qc@03o`000?o5/lWoaK?900?oaK?900?o0000olVg
b?o9]lP01Oo9]lP00ol0003ocK_8olfkb006olfkb003o`000?oA_/So000000Gohm?70_l00004onGF
a`03o`000?oVf<Ooi]S700?oi]S700?o0000onKJb?l000000_o_l/@00ol0003oooooooooo`09oooo
o`Co00004oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03
o`000?oZllgoj_?=00;oj_?=00?o0000on[dc?oZm<`00_l00006onOLb003o`000?oVf/Woi][900Co
i][900?o0000onGIb_oUfLX00ol00006omG1aP03o`000?oA_/OodKk700CodKk700?o0000olfkb?o=
^lP00oo=^lP00ol0003oakO:o`000003okRWb003o`000?nbXlSo/Z?800;o/Z?800?o0000oj^MbOn[
WLT00_n[WLT00ol0003oXYS:oj:HbP02oj:HbP05o`000?nITL_oVI7;oiVAbol000000on>Rl/01?l0
003oPh?:oh>3b_l00002ogMkb@04o`000?m/L/SoK7;8o`0000;oH6_600Co0000oeESa?mEHlCo0000
0_m;G<801?l0003o@eK0od=F`?l00002oceB_P05o`000?lhC[go0000o`000?lgCKd00_l00002ocM>
_@03o`000?liD;ko000000;o>U;000?o0000ocaD`_l000000om;GL@00ol0003oDF;6o`000003oeMW
b005o`000?mNKL[oGVg:oei]b_l000000omVLl`00ol0003oKGW>ofeicP02ofeicP03o`000?n=Rlco
SH_<00;oSH_<00?o0000oiFAc?nETL`00onETL`00ol0003oWIK=oifFc@02oifFc@03o`000?nTW<go
Y9c=00GoY9c=00?o0000oj^QcOn[XLd00on[XLd2o`0000KoaK?900?o0000olVgb?o9]lP01Oo9]lP0
0ol0003ocK_8olfkb006olfkb003o`000?oSdlOohm?700Cohm?70_l00004onGFa`03o`000?oVf<Oo
i]S700Coi]S700Go0000onoba?o_l/Coko;4o`000008ooooo`?o00005oooool00ol0003ooooooooo
o`0:ooooo`008oooool3o`0003Oooooo00Go0000on[ccOoZllgoj_?=o`000002on[dc004o`000?oX
gLWoj=g9o`0000Goimc800?o0000onKJbOoVf/T01?oVf/T3o`000004onGIb_l0003of<?5o`0000Ko
eL7600?o0000om6naooA_/L00ooA_/L00ol0003ocK_8olfkb004olfkb003o`000?nhYlSo^:O800?o
^:O800?o0000ok:Sb?nbXlP00_nbXlP00ol0003oZig9oj^Mb@02oj^Mb@05o`000?nRV<[oXYS:oj:H
b_l000001?nITL/01?l0003oSX_;ohj;bol00002oh>3bPgo00000om;G<801Ol0003o@eK0o`000?lm
DKko?E:n00?o000000Co>4jmocM=_Ol0003o00000_lgC[d01?l0003o>E2nocU@__l00002ocYB`003
o`000?m5FL;oAEW200;oBeg400Co0000oe5Ra_mAH/Ko00000omGIlP01?l0003oGVg:oei]b_l00004
ofIcc005o`000?m]NLkoKGW>ofeic_l000001On=Rl`00ol0003oUI7<oiFAc002oiFAc003o`000?nM
U/goWIK=00?oWIK=00?o0000ojBLcOnTW<d01OnTW<d01Ol0003oZj7=oj^QcOn[XLgo000000;o_jo:
00?o0000olFcbOo5/lT01?o5/lT00ol0003obKO8olVgb005olVgb003o`000?o=^lSocK_800GocK_8
00?o0000on?CaooSdlL01?oSdlL00ol0003oiMK7o`000004onGFa`03o`000?oVf<Ooi]S700?oi]S7
00Go0000onoba?o_l/Coko;4o`000005ooooo`?o00006_ooool00ol0003oooooooooo`0:ooooo`00
8oooool00ol0003oooooooooo`0gooooo`07o`000?oZllgoj_?=on[ccOl0003oj_C<o`000003onSM
b@03o`000?oWg<Soimc800Coimc800?o0000onKJbOoVf/T01?l00002onGIbP05o`000?oH`lGof<?5
omS3aOl000001OoE`LH00ol0003odKk7om6na`04om6na`03o`000?o=^lSocK_800;ocK_80_l00005
okRWb003o`000?nbXlSo/Z?800;o/Z?800?o0000oj^MbOn[WLT00_n[WLT00ol0003oXYS:oj:HbP02
oj:HbP05o`000?nITL_oVI7;oiVAbol000000_n>Rl/3o`000005ogAhbOl0003oJg78of]ab?l00000
0_mQJlH01?l0003oEfC4oeMTa?l00002odmN``Co00000_m3E/000ol0003o?E6noceB_P02o`000003
ocQ>_Ol0003o000000;o000000?o=djmo`000?l000000_liD;h00ol0003o>U;0odEI`P02odEI`P04
o`000?m;GLCoBeg4o`0000;oDF;600Go0000oeMWb?mGIlSoEfO8o`000002oei]bP03o`000?mVLlco
IW?<00;oIW?<00Go0000ofeic_l0003oQ8C;o`000004ohf;c003o`000?nETLcoUI7<00?oUI7<00?o
0000oifFcOnMU/d00onMU/d00ol0003oY9c=ojBLc@05ojBLc@03o`000?n[XLgo000000Co_jo:00?o
0000olFcbOo5/lT01?o5/lT00ol0003obKO8olVgb005olVgb003o`000?o=^lSocK_800?ocK_800?o
0000on3@b?l000001_oSdlL00ol0003oiMK7o`000003onGFa`03o`000?oVf<Ooi]S700;oi]S70_l0
0003onoba003o`000?oooooooooo00?o00007Oooool00ol0003oooooooooo`0:ooooo`0000Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@04ooooo`03o`000?oooooooooo03Sooooo00Co0000on[ccOoZllgoj_?=0_l00004onSMb@03
o`000?oWg<Soimc800Coimc80ol00004onKJb@;o00001?oH`lD00ol0003oeL76omG1aP04omG1aP03
o`000?oA_/OodKk700CodKk700Co0000olfkb?o=^lSo00000_nnZlL00ol0003o^:O8okRWb003okRW
b003o`000?nbXlSo/Z?800;o/Z?800?o0000oj^MbOn[WLT00_n[WLT00ol0003oXYS:oj:HbP02oj:H
bP03o`000?nITL_oVI7;00?o000000?oOWo:o`000?mdN<T00_mdN<T01?l0003oJg78of]ab?l00002
of5[aP06o`000?mGI<CoEfC4o`000?m?G/?o00000_m7F<42o`00000;od=F`?l0003o?E6noceA__l0
003o>DjmocQ>_Ol0003o=dfmo`000?lgCK`00_l000001_lhC[go0000ocU@__liD;ko0000od5E`0?o
AEW200Co0000od]Ma?m;GLCo00000_mAH/H01?l0003oEfO8oeMWb?l00003oei]bP04o`000?mVLlco
IW?<ofIcc0;o00000on4Q</00ol0003oSH_<ohf;c002ohf;c003o`000?nETLcoUI7<00?oUI7<00?o
0000oifFcOnMU/d00onMU/d00ol0003oY9c=ojBLc@05ojBLc@03o`000?no[l[o_jo:00?o_jo:00?o
0000olFcbOo5/lT01Oo5/lT00ol0003obKO8olVgb004olVgb003o`000?o=^lSocK_800;ocK_800Co
0000on3@b?oPd<So00001_oSdlL00ol0003oiMK7o`000004onGFa`06o`000?oVf<Ooi]S7o`000?o`
lL?o00000oo_l/@3o`00023ooooo00?o0000ooooooooool02_ooool00005ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0>?ooool00ol0003oj_?=on[cc@02o`0000Koj=g900?o0000
onOLb?oWg<P01?l00006onKJb@03o`000?oH`lGof<?500Cof<?500?o0000omG1a_oE`LH01?oE`LH0
0ol0003odKk7om6na`03om6na`03o`000?o=^lSo000000Co_Z_700?o0000okRWb?nhYlP00onhYlP0
0ol0003o/Z?8ok:Sb002ok:Sb003o`000?n[WLWoZig900;oZig900Wo0000oj:Hb_nRV<[oXYS:o`00
0?nITL_o0000ohN5bol000000omnOlX01Ol0003oM7S9ogAhbOmdN<Wo000000;oJg7800?o0000of5[
a_l000000omGI<@00ol0003oCek3o`000002odMH`@03o`000?m1E;oo000000;o?E6n0_l000000oli
C[go0000o`000002o`000007ocM=_?l0003o>4jmocQ>_Ol0003o>E2no`000002od5E`0;oAEW200Co
0000od]Ma?m;GLCo00000omAH/H01?l0003oEfO8oeMWb?l00003oei]bP05o`000?mVLlco0000og]n
b_l000001?n4Q</00ol0003oSH_<ohf;c002ohf;c003o`000?nETLcoUI7<00?oUI7<00?o0000oifF
cOnMU/d00onMU/d00ol0003oY9c=ojBLc@03ojBLc@;o00001_no[lX00ol0003oaK?9olFcb@04olFc
b@03o`000?o9]lSobKO800GobKO800Go0000olfkb?o=^lSocK_8o`000002on3@b003o`000?oSdlOo
hm?700Gohm?700?o0000onGFaol000000ooUe/L01_l0003oi]S7onKHaol0003ol?73o`0000?oko;4
00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0003Sooooo
00Ko0000on[ccOoZllgo0000onOMbOl00006onSMb@?o00001?oWg<P00ol0003oi][9onKJb@02onKJ
b@;o00001_oH`lD00ol0003oeL76omG1aP04omG1aP03o`000?oA_/OodKk700CodKk700?o0000okj[
aonnZlL01?nnZlL00ol0003o^:O8okRWb002okRWb003o`000?nbXlSo/Z?800;o/Z?800?o0000oj^M
bOn[WLT00_n[WLT01?l0003oXYS:oj:Hb_nRV<X2o`0000?oQhG;00Go0000ogiob_mnOl[oOWo:o`00
0002ogAhb@04o`000?m[LLSoJg78o`0000;oHF_600Co0000oeMTa?mGI<Co00000_m?G/<01Ol0003o
AeS1odMH`Ol0003o@EBo00Co000000?o>Djmo`000?l000000_l000000olgCKco0000ocQ>_@02ocQ>
_@05o`000?lmD[ko0000od5E`?l000000_m5FL801?l0003oBeg4od]Ma?l00002oe5RaP05o`000?mG
IlSoEfO8oeMWb?l000000_mNKLX2o`0000?oNgk:00Go0000ohB4bon4Q<_oQ8C;o`000005ohf;c003
o`000?nETLcoUI7<00?oUI7<00?o0000oifFcOnMU/d00onMU/d01Ol0003oY9c=ojBLcOnTW<go0000
00;o^J[;00?o0000okn_b_no[lX01?no[lX00ol0003oaK?9olFcb@04olFcb@03o`000?o9]lSobKO8
00GobKO800?o0000olfkb?l000001?oPd<P00ol0003ohm?7on?Ca`04on?Ca`04o`000?oUe/OoiMK7
o`0000;oiMK700?o0000onKHaol000000_o`lL<01Ol0003oko;4onoba?o_l/Co000002?ooooo00?o
0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003oj_?=o`00
0003onOMb@04o`000?oXgLWoj=g9onSMb@?o00001_oWg<P01Ol0003oi][9onKJbOoVf/Wo000000;o
f/G500?o0000omS3aOoH`lD01?oH`lD00ol0003oeL76omG1aP04omG1aP03o`000?oA_/OodKk700?o
dKk700?o0000okj[aonnZlL01?nnZlL00ol0003o^:O8okRWb003okRWb003o`000?nbXlSo/Z?800;o
/Z?800?o0000oj^MbOn[WLT00_n[WLT01Ol0003oXYS:o`000?n@S<_o000000CoQhG;00Co0000ogio
b_mnOl[o00000omdN<T01_l0003oJg78of]ab?l0003oHF_6o`0000?oEfC400?o0000odmN`ol00000
0_m7F<400ol0003o@EBoo`000002oca@_PWo000000Go>4jmo`000?lmD[ko?E:no`000002od5E`004
o`000?m5FL;oAEW2o`0000;oBeg400Co0000oe5Ra_mAH/Ko00000omGIlP2o`000003og9gbOl0003o
Ngk:00?oNgk:00Go0000ohB4bon4Q<_oQ8C;o`000005ohf;c003o`000?nETLcoUI7<00;oUI7<00?o
0000oifFcOnMU/d01?nMU/d00ol0003oY9c=o`000004okVZb`03o`000?no[l[o_jo:00Co_jo:00?o
0000olFcbOo5/lT01?o5/lT00ol0003obKO8olVgb005olVgb003o`000?oPd<Soh=3800?oh=3800?o
0000on?CaooSdlL01OoSdlL01?l0003oiMK7onGFaol00002onGFa`05o`000?o`lL?ol?73oo3a`ol0
00000oo_l/@00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0=oooool2o`0000Coimg91?l00003onSMb@03o`000?oWg<Soimc8
00?oimc800Co0000onKJbOoVf/Wo00001?oJaLD00ol0003of<?5omS3a@04omS3a@03o`000?oE`LKo
eL7600?oeL7600?o0000om6naooA_/L00_oA_/L00ol0003o`Zk6o`000006okj[a`03o`000?nhYlSo
^:O800?o^:O800?o0000ok:Sb?nbXlP00_nbXlP00ol0003oZig9oj^Mb@02oj^Mb@05o`000?n@S<_o
T8c;oi2<bol000001?n7QL/01?l0003oOWo:ogiob_l00002ogAhb@07o`000?m[LLSoJg78of]ab?l0
003oHF_6o`000002oeMTa004o`000?m?G/?oCek3o`0000;oAeS100Ko0000od5D_ol0003o?52no`00
0?lhC[d6o`000004ocM=_?l0003o>TnmocY?_@;o?E:n00Ko0000od5E`?m1EL3o0000odEI`_l00002
od]Ma007o`000?mAH/KoDF;6oe5Ra_l0003oEfO8o`000004og9gb@03o`000?mkO/[oNgk:00;oNgk:
00Go0000ohB4bon4Q<_oQ8C;o`000004ohf;c003o`000?nETLcoUI7<00?oUI7<00?o0000oifFcOnM
U/d01?nMU/d00ol0003o^J[;okVZb`03okVZb`03o`000?no[l[o_jo:00Co_jo:00?o0000olFcbOo5
/lT01Oo5/lT00ol0003obKO8olVgb004olVgb003o`000?oPd<Soh=3800Coh=3800?o0000on?CaooS
dlL01?oSdlL01?l0003oiMK7onGFaol00002onGFa`05o`000?o`lL?ol?73oo3a`ol000000oo_l/@0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03Oooooo00Co0000onOMbOoWgLWoimg90ol00006onSMb@03o`000?oWg<Soimc800Coimc80_l0
0005om[5a@03o`000?oH`lGof<?500Cof<?500?o0000omG1a_oE`LH01?oE`LH01?l0003odKk7om6n
aol00003ol:^aP03o`000?nnZlOo_Z_700Co_Z_700?o0000okRWb?nhYlP00_nhYlP00ol0003o/Z?8
ok:Sb002ok:Sb004o`000?n[WLWoZig9oj^Mb@;o00001?n@S</01Ol0003oQhG;ohN5bon7QL_o0000
00?oOWo:00Co0000ogAhbOmdN<Wo00000_m[LLP01?l0003oHF_6of5[a_l00002oeMTa003o`000?m?
G/?o000000;oAeS100?o0000od5D_ol000000_llD;h00ol0003o>4jmo`000004o`000007ocM=_?l0
003o>TnmocY?_Ol0003o?E:no`000002od5E`004o`000?m5FL;oAEW2o`0000;oBeg400?o0000oe5R
a_mAH/H00_l00002ofQ`b0CoLWO900Go0000og]nb_mkO/[oNgk:o`000004ohB4b`03o`000?n=Rlco
SH_<00;oSH_<00?o0000oiFAc?nETL`00onETL`00ol0003oWIK=oifFc@03oifFc@03o`000?niZ/_o
^J[;00Co^J[;00?o0000okn_b_no[lX01?no[lX00ol0003oaK?9olFcb@04olFcb@03o`000?o9]lSo
bKO800?obKO800?o0000omg=bOl000001OoPd<P00ol0003ohm?7on?Ca`04on?Ca`04o`000?oUe/Oo
iMK7onGFa`?o00000oo`lL<01Ol0003oko;4onoba?o_l/Co000002?ooooo00?o0000ooooooooool0
2Oooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01_ooool2o`0003Sooooo1?l00003onOMb@03o`000?oXgLWoj=g900Co
j=g900?o0000onOLb?oWg<P00ooWg<P00ol0003of/G5om[5a@05om[5a@03o`000?oH`lGof<?500Co
f<?500?o0000omG1a_oE`LH00ooE`LH00ol0003odKk7o`000005ol:^aP03o`000?nnZlOo_Z_700Co
_Z_700?o0000okRWb?nhYlP00_nhYlP00ol0003o/Z?8ok:Sb002ok:Sb003o`000?n[WLWo000000;o
V97;00?o0000oi2<bon@S</00_n@S</01Ol0003oQhG;ohN5bon7QL_o000000?oOWo:00Co0000ogAh
bOmdN<Wo00000_m[LLP00ol0003oHF_6o`000003oeMTa007o`000?m?G/?o0000odMH`Ol0003o@EBo
o`000002oca@_P04o`000?lhC[go0000ocM<_0Co000000Oo>4flo`000?ljCkgo>Tnmo`000?lmD[ko
000000;o@EG000?o0000odEI`_l000000_m;GL@3o`000003oemZa_mXL<SoJ73800;oJ7380ombMlT0
0ol0003oNgk:og]nbP02og]nbP05o`000?n4Q<_oQ8C;ohB4bol000001On=Rl`00ol0003oUI7<oiFA
c003oiFAc007o`000?nMU/goWIK=oifFcOl0003o/JG;o`000006okVZb`03o`000?no[l[o_jo:00Co
_jo:00?o0000olFcbOo5/lT01?o5/lT01Ol0003obKO8olVgb?o9]lSo000000;ogLg900?o0000on3@
b?oPd<P01?oPd<P00ol0003ohm?7on?Ca`04on?Ca`03o`000?oUe/OoiMK700?o00000oo`lL<01Ol0
003oko;4onoba?o_l/Co000002?ooooo00?o0000ooooooooool02Oooool00005onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`;o0000=ooo
ool4o`0000Goimg900?o0000onSMbOoXgLT01?oXgLT00ol0003oimc8onOLb003onOLb003o`000?oJ
aLGof/G500Gof/G500?o0000omS3aOoH`lD01?oH`lD00ol0003oeL76omG1aP04omG1aP03o`000?o2
[/Ko`Zk600Go`Zk600?o0000okj[aonnZlL00onnZlL00ol0003o^:O8okRWb003okRWb003o`000?nb
XlSo/Z?800;o/Z?800?o0000oiRAbonHTL/00_nHTL/00ol0003oT8c;oi2<b`02oi2<b`05o`000?n7
QL_oQhG;ohN5bol000000_mnOlX01?l0003oM7S9ogAhbOl00002of]ab004o`000?mQJlKoHF_6o`00
00;oEfC400?o0000odmN`ol000004?l00002ocY?_@03o`000?lmD[ko000000;o@EG01Ol000000omF
HlCoGf[6oemZaP02oemZaP?oJ73800Go0000og9gbOmbMlWoLWO9o`000004og]nbP05o`000?n4Q<_o
Q8C;ohB4bol000001On=Rl`00ol0003oUI7<oiFAc003oiFAc003o`000?nMU/go000000?o/JG;00?o
0000okVZboniZ//00oniZ//00ol0003o_jo:okn_bP04okn_bP03o`000?o5/lWoaK?900GoaK?900?o
0000olVgb?l000001?oMcLT00ol0003oh=38on3@b003on3@b003o`000?oSdlOohm?700Cohm?700?o
0000onGFaol000000_o`l<<01Ol0003ol?73oo3a`oo`lL?o000000?oko;400?o0000ooooooooool0
8Oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`0cooooo`?o00000ooo
ool00ol0003oimg9onOMb@03onOMb@03o`000?oXgLWoj=g900Coj=g900?o0000onOLb?oWg<P00_oW
g<P00ol0003og<O5o`000007om[5a@03o`000?oH`lGof<?500Cof<?500?o0000omG1a_oE`LH00_oE
`LH2o`0000Oo`Zk600?o0000okj[aonnZlL01?nnZlL00ol0003o^:O8okRWb002okRWb004o`000?nb
XlSo/Z?8ok:Sb0;o00001OnHTL/01Ol0003oT8c;oi2<bon@S<_o000000?oQhG;00Go0000ogiob_mn
Ol[oOWo:o`000002ogAhb@06o`000?m[LLSoJg78o`000?mQJlKo00000_mGI<@2o`000006odII`_l0
003o@EG0o`000?lmD[ko00000_ljCkd01?l0003o>4flo`000?lgC;`4o`000003ocQ>_Ol0003o0000
00Go000000?oAUS1odiM`om>GL<01?mFHl@4oemZaP?oJ73800Go0000og9gbOmbMlWoLWO9o`000004
og]nbP05o`000?n4Q<_oQ8C;ohB4bol000001?n=Rl`00ol0003oUI7<oiFAc003oiFAc0;o00001?na
YL/00ol0003o^J[;okVZb`04okVZb`03o`000?no[l[o_jo:00Co_jo:00?o0000olFcbOo5/lT01Oo5
/lT00ol0003ogLg9omg=b@03omg=b@03o`000?oPd<Soh=3800?oh=3800?o0000on?CaooSdlL01OoS
dlL01Ol0003ol?33oo3``oo`l<?o000000?ol?7300Go0000onoba?o_l/Coko;4o`00000Tooooo`03
o`000?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo033ooooo0ol00006ooooo`03o`00
0?oWgLWoimg900Coimg900?o0000onSMbOoXgLT01?oXgLT01?l0003oimc8onOLb?l00003omc7a@03
o`000?oJaLGof/G500Gof/G500?o0000omS3aOoH`lD01?oH`lD01?l0003oeL76omG1a_l00002olJa
a@03o`000?o2[/Ko`Zk600Go`Zk600?o0000okj[aonnZlL01?nnZlL00ol0003o^:O8okRWb002okRW
b003o`000?nbXlSo000000;oWiK;00?o0000oiRAbonHTL/00_nHTL/00ol0003oT8c;oi2<b`02oi2<
b`05o`000?n7QL_oQhG;ohN5bol000000omnOlX00ol0003oM7S9o`000003of]ab0Co000000WoBeg4
o`000?m6FL;oAUW2o`000?m1EL3o0000oceB__l000000_ljCkd01?l0003o>4flo`000?lgC;`5o`00
00;o>e2n0_m0E;l01?l0003oAUS1odIH`Om6F<42odiM``?oEV?400Go0000oemZa_mOJ/KoGf[6o`00
0002ofQ`b005o`000?mbMlWoLWO9og9gbOl000001?mkO/X00ol0003oQ8C;ohB4b`02ohB4b`03o`00
0?n=RlcoSH_<00;oSH_<00Oo0000oiFAc?nETLcoUI7<o`000?nYW/co000000Go/JG;00?o0000okVZ
boniZ//01?niZ//00ol0003o_jo:okn_bP04okn_bP03o`000?o5/lWoaK?900CoaK?900?o0000omg=
bOoMcLT00ooMcLT00ol0003oh=38on3@b004on3@b003o`000?oSdlOohm?700Cohm?700Co0000oo3`
`oo`l<?ol?330_l00002oo3a``05o`000?o_l/Coko;4onoba?l000009?ooool00ol0003ooooooooo
o`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`03o`000?oWgLWoimg900?oimg900?o0000
onSMbOoXgLT01?oXgLT01?l0003oimc8onOLb?l00004omc7a@03o`000?oJaLGof/G500Cof/G500?o
0000omS3aOoH`lD01?oH`lD00ol0003oeL76o`000004olJaa@03o`000?o2[/Ko`Zk600Go`Zk600?o
0000okj[aonnZlL00onnZlL00ol0003o^:O8okRWb003okRWb003o`000?nOU/_oWiK;00;oWiK;00?o
0000oiRAbonHTL/00_nHTL/00ol0003oT8c;oi2<b`02oi2<b`05o`000?n7QL_oQhG;ohN5bol00000
0_mnOlX01Ol0003oM7S9ogAhbOl0003oJg7800;o000000?oDV?6o`000?m;GL@00_m;GL@01Ol0003o
AUW2o`000?m1EL3o000000;o?E:n00Co0000ocY?_Ol0003o>4fl0_l000000olgC;co0000o`000002
ocU>_@03o`000?lkD;ko>e2n00;o@5Bo00Co0000odIH`Om6F<7o00000_m>GL<3oeISa005o`000?mO
J/KoGf[6oemZa_l000000_mXL<P01Ol0003oLWO9og9gbOmbMlWo000000CoNgk:00Go0000ohB4bon4
Q<_oQ8C;o`000005ohf;c003o`000?nETLco000000?oZIk<00?o0000ok6UbonaYL/00onaYL/00ol0
003o^J[;okVZb`03okVZb`03o`000?no[l[o_jo:00Go_jo:00?o0000olFcbOo5/lT00_o5/lT00ol0
003of<S;o`000005omg=b@03o`000?oPd<Soh=3800?oh=3800?o0000on?CaooSdlL00ooSdlL2o`00
00?ol?3300Go0000oo3a`ol0003ol?73o`000003onoba003o`000?oooooooooo02;ooooo00?o0000
ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3o`0000gooooo00?o0000onOM
bOoWgLT01?oWgLT00ol0003oj=g9onSMb@03onSMb@03o`000?oWg<So000000Gog<O500?o0000om[5
aOoJaLD01OoJaLD00ol0003of<?5omS3a@04omS3a@03o`000?o6/LGoa[7500Coa[7500?o0000ol:^
a_o2[/H01Oo2[/H00ol0003o_Z_7okj[a`03okj[a`04o`000?nhYlSo^:O8okRWb0;o00001OnOU//0
0ol0003oV97;oiRAb`02oiRAb`03o`000?n@S<_oT8c;00;oT8c;00Go0000ohN5bon7QL_oQhG;o`00
0002ogiobP04o`000?mdN<Wo0000o`0000;oFFS800?o0000oe9Sa_l000000om;GL@01Ol0003oAUW2
o`000?m1EL3o000000;o?E:n00Co0000ocY?_Ol0003o=dfl1_l000001_liC[go0000o`000?lkD;ko
@5Boo`0000?oAUS100?o0000odiM`ol000000omFHl@01?l0003oGf[6oemZa_l00003ofQ`b005o`00
0?mbMlWoLWO9og9gbOl000001?mkO/X01Ol0003oQ8C;ohB4bon4Q<_o000000CoSH_<0_l00004ojVN
c003o`000?naYL_o/JG;00?o/JG;00?o0000okVZboniZ//01?niZ//00ol0003o_jo:okn_bP04okn_
bP05o`000?o5/lWoaK?9olFcbOl000000_oHb</00ol0003ogLg9omg=b@03omg=b@03o`000?oPd<So
h=3800Coh=3800Oo0000on?CaooSdlOohm?7o`000?o_klGo000000?ol?3300?o0000oo3a`oo`lL<0
0_l00002onoba003o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0027ooooo00?o
0000ooooooooool09oooool3o`00013ooooo00?o0000onOMbOoWgLT01?oWgLT00ol0003oj=g9onSM
b@04onSMb@03o`000?oLalGog<O500Gog<O500?o0000om[5aOoJaLD01?oJaLD00ol0003of<?5omS3
a@04omS3a@;o00001_o6/LD00ol0003o`Zk6ol:^aP05ol:^aP03o`000?nnZlOo_Z_700?o_Z_700?o
0000okRWb?l000000_nVVl/00ol0003oWiK;oinFb`03oinFb`03o`000?nHTL_oV97;00;oV97;00Go
0000oi2<bon@S<_oT8c;o`000003ohN5b`07o`000?mnOl[oOWo:ogiob_l0003oH6k:o`000003oeUX
b003o`000?mBHlKo000000;oBeg400Ko0000odII`_m6FL;o0000od5E`?l00002oceB_P;o000000?o
=dflo`000?lgCK`00ol000001?liC[go0000oceA__lmDKh2o`000003od1D_ol0003oAUS100;oAUS1
00?o0000odiM`ol000000_mFHl@01Ol0003oGf[6oemZa_mOJ/Ko000000;oJ73800Go0000og9gbOmb
MlWoLWO9o`000004og]nbP03o`000?n4Q<_oQ8C;00;oQ8C;00Ko0000ohf;c?l0003o0000oj2Hc?l0
0005ojVNc003o`000?naYL_o/JG;00?o/JG;00?o0000okVZboniZ//00oniZ//00ol0003o_jo:okn_
bP05okn_bP03o`000?o5/lWo000000Cof<S;00?o0000omg=bOoMcLT00ooMcLT00ol0003oh=38on3@
b003on3@b004o`000?oSdlOohm?7o`0000;okno500Go0000oo3``oo`l<?ol?33o`000002oo3a``;o
000000?oko;4o`000?l000009Oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003ooooo
ooooo`0Uooooo`?o00005?ooool00ol0003oimg9onOMb@03onOMb@03o`000?oXgLWoj=g900?oj=g9
0_l00008omc7a@03o`000?oJaLGof/G500Cof/G500?o0000omS3aOoH`lD00_oH`lD01?l0003obKC5
olVdaOl00006olJaa@03o`000?o2[/Ko`Zk600Co`Zk600?o0000okj[aonnZlL01?nnZlL00ol0003o
YY_;ojJKb`02ojJKb`03o`000?nOU/_oWiK;00?oWiK;00Go0000oiRAbonHTL_oV97;o`000004oi2<
b`06o`000?n7QL_oQhG;ohN5bol0003oOWo:0_l00002of1^bP07o`000?mIJ<SoFFS8oeUXb?l0003o
DV?6o`000002od]Ma006o`000?m6FL;o0000od5E`?l0003o?E:n0_l000001?lhC[go0000o`000?lg
CK`3o`000003ocQ>_OliC[go000000?o?E6n0ol00002odIH`@03o`000?m>GL?o000000?oEV?400Go
0000oemZa_mOJ/KoGf[6o`000002ofQ`b005o`000?mbMlWoLWO9og9gbOl000001?mkO/X01?l0003o
Q8C;ohB4bon4Q</2o`0000CoX9S<00?o0000ojVNc?nYW/`00onYW/`00ol0003o/JG;ok6Ub`03ok6U
b`03o`000?niZ/_o^J[;00?o^J[;00?o0000okn_b_no[lX01?no[lX2o`0000Gof<S;00?o0000omg=
bOoMcLT00ooMcLT00ol0003oh=38on3@b003on3@b003o`000?oSdlOo000000?okno500Go0000oo3`
`oo`l<?ol?33o`000003oo3a``?o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0
003oooooooooo`0Rooooo`?o00005oooool00ol0003oimg9onOMb@04onOMb@05o`000?oXgLWoj=g9
onSMbOl000000_oLbLH00ol0003og<O5omc7a@06omc7a@03o`000?oJaLGof/G500Cof/G500Co0000
omS3aOoH`lGo00001?o9]<D00ol0003oa[75olJaa@04olJaa@03o`000?o2[/Ko`Zk600Co`Zk600?o
0000okj[aonnZlL00onnZlL00ol0003oYY_;ojJKb`03ojJKb`03o`000?nOU/_oWiK;00?oWiK;00Go
0000oiRAbonHTL_oV97;o`000004oi2<b`05o`000?n7QL_oQhG;ohN5bol000000_mWM<`01?l0003o
H6k:of1^b_l00002oeUXb004o`000?mBHlKoDV?6o`0000;oBeg400Go0000odII`_l0003o@EG0o`00
0002ocU@_P04o`000?lhC[go0000ocM=_0Co000000?o>4jmocU>_Ol000000_lmDKh2od=F`007o`00
0?m6F<7oAUS1odIH`Ol0003oCUg3o`000002oeISa005o`000?mOJ/KoGf[6oemZa_l000000_mXL<P0
0ol0003oLWO9og9gb@02og9gb@03o`000?mkO/[oNgk:00;oNgk:00Co0000ohB4bol0003oUY7<1OnP
V<`00ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o/JG;00?o/JG;00?o0000okVZboniZ//01?ni
Z//00ol0003o_jo:okn_bP02okn_bP03o`000?oBa<co000000Gof<S;00?o0000omg=bOoMcLT01?oM
cLT00ol0003oh=38on3@b003on3@b003o`000?o_klGokno500;okno500Go0000oo3``oo`l<?ol?33
o`000003oo3a``?o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`00027ooooo0_l0
000Jooooo`03o`000?oWgLWoimg900Coimg900Co0000onSMbOoXgLWo00001?oLbLH00ol0003og<O5
omc7a@05omc7a@03o`000?oJaLGof/G500Cof/G500?o0000omS3aOl000001_o9]<D00ol0003oa[75
olJaa@04olJaa@03o`000?o2[/Ko`Zk600Co`Zk600Oo0000okj[aonnZlOo_Z_7o`000?n/Wl_o0000
00GoYY_;00?o0000oinFbonOU//00_nOU//00ol0003oV97;oiRAb`02oiRAb`03o`000?n@S<_oT8c;
00;oT8c;00Co0000ohN5bol0003o00000omWM<`01?l0003oH6k:of1^b_l00002oeUXb003o`000?mB
HlKo000000;oBeg400Go0000odII`_l0003o@EG0o`000003ocU@_P?o000000?o=dflocM=_Ol00000
0_l000001OlhC[go>Djmo`000?l0003o?E6n00;o@eK01?l00002odiM``04o`000?mFHlCoEV?4o`00
00?oGf[600Co0000ofQ`b?mXL<So00000ombMlT00ol0003oNgk:og]nbP02og]nbP;o00000onFTL`5
oj2Hc003o`000?nYW/coZIk<00?oZIk<00?o0000ok6UbonaYL/00onaYL/00ol0003o^J[;okVZb`03
okVZb`05o`000?no[l[o_jo:okn_b_l000000ooBa<`00ol0003of<S;omS8b`03omS8b`03o`000?oM
cLWogLg900?ogLg900?o0000on3@b?oPd<P00ooPd<P00ol0003okno5ono_a@02ono_a@05o`000?o`
l<?ol?33oo3``ol000000oo`lL<00ol0003odoVZo`00000Wooooo`03o`000?oooooooooo00Oooooo
000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?oWgLWoimg900?oimg900?o
0000onSMbOl000001_oLbLH00ol0003og<O5omc7a@05omc7a@03o`000?oJaLGof/G500Cof/G500?o
0000olVdaOo9]<D01_o9]<D00ol0003oa[75olJaa@04olJaa@03o`000?o2[/Ko`Zk600Co`Zk600?o
0000okj[aol000000on/Wl/00ol0003oYY_;ojJKb`03ojJKb`03o`000?nOU/_oWiK;00;oWiK;00Go
0000oiRAbonHTL_oV97;o`000005oi2<b`04o`000?m_N/koKg[>o`0000?oIgC<00?o0000of1^b_l0
00000omIJ<P00ol0003oDV?6o`000002od]Ma005o`000?m6FL;o0000ocYB`?l000000_liD;h2o`00
0005ocM>_Ol0003o=dfmocM=_Ol000000olhC[d2oceB_P;o000000Co@eK0od]K`_m;Fl;oBe_21?l0
0003oeISa004o`000?mOJ/KoGf[6o`0000?oJ73800Ko0000og9gbOmbMlWoLWO9o`000?mkO/X2o`00
0003oh^9c?nFTLcoUY7<00;oUY7<00?o0000oj2Hc?nPV<`00onPV<`00ol0003oZIk<ojVNc002ojVN
c003o`000?naYL_o/JG;00?o/JG;00?o0000okVZboniZ//01?niZ//00ol0003o_jo:o`000004om;4
c003o`000?oHb<_of<S;00?of<S;00?o0000omg=bOoMcLT00ooMcLT00ol0003oh=38on3@b002on3@
b0;o00001?o_klD01Ol0003ol?33oo3``oo`l<?o000000;ol?7300Co0000om?iZ_l0003o00009ooo
ool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o00008?ooool0
0ol0003oimg9onOMb@04onOMb@03o`000?oLbLKog<W600Kog<W600?o0000omc7aOoLalD01OoLalD0
0ol0003of/G5om[5a@03om[5a@03o`000?o<]lGobKC500OobKC500?o0000olJaaOo6/LD01?o6/LD0
0ol0003o`Zk6ol:^aP04ol:^aP03o`000?n/Wl_o[9o;00?o[9o;00?o0000ojJKbonVVl/00onVVl/0
0ol0003oWiK;oinFb`02oinFb`05o`000?nHTL_oV97;oiRAbol000000on@S</2o`0000?oKg[>00Co
0000ofMdc?mWM<co00000_mPK/X01ol0003oFFS8oeUXb?mIJ<So0000oe9Sa_l000000_m;GL@2o`00
00;o>U;000Co0000ocU@__liD;ko00000_lgC[d4o`0000?o>4jm0_lmD[h00ol0003o@eK0od=F`003
od]K`P?oE6;41?l00003oemZaP04o`000?mXL<SoJ738o`0000;oLWO90ol00004oh^9c0CoUY7<00?o
0000oj2Hc?nPV<`00_nPV<`00ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o/JG;00?o/JG;00?o
0000okVZboniZ//01?niZ//00ol0003od/C<om;4c003om;4c003o`000?oHb<_of<S;00Cof<S;00?o
0000omg=bOoMcLT00ooMcLT01_l0003oh=38on3@b?l0003ok^g7o`0000Cokno500Ko0000oo3``oo`
l<?ol?33o`000?o`lL<2o`000004om?iZ_l0003oooooo`0002Kooooo00?o0000ooooooooool01ooo
ool0023ooooo0ol0000Gooooo`?o00008oooool00ol0003oimg9onOMb@03onOMb@;o00002?oLbLH0
0ol0003og<O5omc7a@05omc7a@03o`000?oJaLGof/G500;of/G500Go0000olbgaOo<]lGoc;O5o`00
0007olVda@03o`000?o6/LGoa[7500Coa[7500?o0000ol:^a_o2[/H00oo2[/H00ol0003o/J?:ojbO
b`04ojbOb`03o`000?nVVl_oYY_;00?oYY_;00?o0000oinFbonOU//00_nOU//01ol0003oV97;oiRA
bonHTL_o0000oi2<bol000000_mgPM001Ol0003oKg[>ofmjc_m_N/ko000000;oIgC<00Co0000of1^
b_mPK/[o00000_mIJ<P02?l0003oDV?6oe9Sa_l0003oBeg4o`000?llE<;o00000_ljD/001Ol0003o
>E2no`000?l0003o=djm00;o000000?o=dfmo`000?lhC[d00_lhC[d00ol0003o?E:noceB_P03o`00
00?oBe_20_mDH/@3oeiYaP[o00000_n0P//5oh^9c003o`000?nFTLcoUY7<00;oUY7<00?o0000oj2H
c?nPV<`00_nPV<`00ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o/JG;00?o/JG;00?o0000okVZ
boniZ//00_niZ//2o`0000Kod/C<00?o0000omS8booHb</00ooHb</00ol0003ogLg9omg=b@03omg=
b@03o`000?oPd<So000000;ok^g700?o0000ono_aOo_klD00_o_klD01?l0003ol?33oo3``oo`l<<3
o`000003om?iZ_l0003ooooo00;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`007oooool2o`0001Kooooo0ol0000Wooooo`05o`000?oWgLWoimg9onOMbOl000000_oMblL0
0ol0003og<W6omc9aP06omc9aP03o`000?oLalGog<O500Gog<O500Co0000om[5aOoJaLGo00001Oo<
]lD00ol0003obKC5olVda@05olVda@03o`000?o6/LGoa[7500Coa[7500Go0000ol:^a_o2[/Ko`Zk6
o`000003ok6SbPGo[9o;00?o0000ojJKbonVVl/00onVVl/00ol0003oWiK;oinFb`02oinFb`05o`00
0?nHTL_oV97;oiRAbol000001?mgPM001Ol0003oKg[>ofmjc_m_N/ko000000;oIgC<00Co0000of1^
b_mPK/[o00000_mIJ<P02?l0003oDV?6oe9Sa_l0003o?US4o`000?llE<;o00000_ljD/02o`000006
ocI?_ol0003o0000ocI>__l0003o=dfm0olhC[d2o`000003oceB__m4El7oA5O100;o00000_m;Fl80
0ol0003oE6;4oeARa003oeiYaPCoJG780omdNLX5oh22b`GoRhW<00Go0000oiJAc?nFTLcoUY7<o`00
0004oj2Hc003o`000?nYW/coZIk<00?oZIk<00?o0000ok6UbonaYL/00onaYL/01Ol0003o^J[;okVZ
boniZ/_o000000;obkk>00?o0000om;4c?oBa<`00ooBa<`00ol0003of<S;omS8b`04omS8b`03o`00
0?oMcLWogLg900?ogLg900Go0000onk]aoo^kLOok^g7o`000004ono_a@09o`000?o`l<?ol?33oo3`
`ol0003od_NVo`000?oCnJ[o000000Cooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`07ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`?o0000:_ooool01?l0003oimg9
onOMbOl00004omg;a`03o`000?oLbLKog<W600Kog<W600?o0000omc7aOoLalD01OoLalD00ol0003o
f/G5o`000006olbga@03o`000?o9]<GobKC500GobKC500?o0000olJaaOo6/LD01?o6/LD00ol0003o
`Zk6o`000005ok6SbP03o`000?n/Wl_o[9o;00;o[9o;00?o0000ojJKbonVVl/00onVVl/00ol0003o
WiK;oinFb`02oinFb`05o`000?nHTL_o0000ogj7dOl000001?mgPM001?l0003oKg[>ofmjc_l00003
ofMdc003o`000?mPK/[o000000?oFFS800?o0000oe9Sa_l000000_lnF<@00ol0003o?5C2o`000002
ocYB`003o`000?lfCkoo=Tno00?o000000So=dfmocQ>_OlhC[go>4jmo`000?llD[oo?E:no`0000;o
A5O100Co0000od]K`_m;Fl;o00000_mDH/@01?l0003oGVW6oeiYa_mNJLH4ofUab0?oM7W:1?n0P//0
0ol0003oRhW<oh^9c002oh^9c003o`000?nFTLcoUY7<00;oUY7<00?o0000oj2Hc?nPV<`00_nPV<`0
0ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o/JG;00?o/JG;00?o0000okVZbol000000oo;_/h0
0ol0003od/C<om;4c003om;4c003o`000?oHb<_of<S;00Cof<S;00?o0000omg=bOoMcLT00ooMcLT0
1Ol0003ok^g7onk]aoo^kLOo000000Cokno500Co0000oo3``oo`l<?ol?330_l000000ooCnJ[o0000
ooooo`04ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00oooooo0ol0000]ooooo`03o`000?oWgLWo000000KogL_700?o0000omc9a_oLbLH0
1_oLbLH00ol0003og<O5omc7a@05omc7a@03o`000?o<]lGoc;O500Koc;O500?o0000olVdaOo9]<D0
1Oo9]<D00ol0003oa[75olJaa@04olJaa@03o`000?naXl[o/J?:00Go/J?:00?o0000ojbObon/Wl/0
0_n/Wl/00ol0003oYY_;ojJKb`03ojJKb`03o`000?nOU/_oWiK;00;oWiK;00Go0000ogj7dOmnQm7o
OXOAo`000004ogN1d004o`000?m_N/koKg[>o`0000?oIgC<00?o0000of1^b_l000000omIJ<P00ol0
003o@5_7o`000002ociHa005o`000?llE<;o0000ocYB`?l000000olfCkl00ol0003o=Tjno`000004
o`0000;o?5:o00Go?E:no`000?m4El7oA5O1o`000002od]K`P04o`000?mDH/CoE6;4o`0000;oGVW6
00Go0000ofUab?mYLLSoJG78o`000002ogAibP03o`000?n0P/_oP8;;00;oP8;;00?o0000oh^9c?n;
RL`00_n;RL`01Ol0003oUY7<oiJAc?nFTLco000000CoX9S<00?o0000ojVNc?nYW/`00onYW/`00ol0
003o/JG;ok6Ub`04ok6Ub`03o`000?o;_/kobkk>00?obkk>00?o0000om;4c?oBa<`00ooBa<`00ol0
003of<S;omS8b`03omS8b`03o`000?oMcLWogLg900;ogLg90_l00003onk]a`03o`000?o_klGokno5
00;okno500So0000oo3``oo`l<?o0000om;gY_l0003odoVZo`0000Kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Oooool00ol0003ogL_7
omg;a`06omg;a`03o`000?oLbLKog<W600Gog<W600?o0000omc7aOoLalD01OoLalD00ol0003oc[W6
olbga@07olbga@03o`000?o9]<GobKC500GobKC500?o0000olJaaOo6/LD00oo6/LD00ol0003o]ZO:
ok6SbP06ok6SbP03o`000?n/Wl_o[9o;00;o[9o;00?o0000ojJKbonVVl/00onVVl/01?l0003oWiK;
oinFbonOU//2o`0000?oOXOA00?o0000ogN1d?mgPM000_mgPM001?l0003oKg[>ofmjc_l00002ofMd
c005o`000?mPK/[oH6k:o`000?mIJ<P00_l00002od1Ka`05o`000?lnF<Co?US4o`000?llE<800ol0
0002ocI?_`03o`000?lfC[ko000000?o000000Go>e6oo`000?llD[oo?5:oo`000002odAG`@;oC5g3
00GoBe_2o`000?mDH/CoE6;4o`000003oeiYaP04o`000?mYLLSoJG78o`0000?oM7W:00Go0000oh22
bon0P/_oP8;;o`000004oh^9c003o`000?nFTLcoUY7<00;oUY7<00?o0000oj2Hc?nPV<`00_nPV<`0
0ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o/JG;00;o/JG;0_l00005ol^ncP03o`000?oBa<co
d/C<00?od/C<00?o0000omS8booHb</01?oHb</01_l0003ogLg9omg=bOl0003ojn_;o`0000Cok^g7
00Ko0000ono_aOo_klGokno5o`000?o`l<<3o`0000;odoVZ00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00?o0000omg;
aooMblL01_oMblL00ol0003og<W6omc9aP06omc9aP03o`000?oLalGog<O500?og<O500Go0000olji
a_o>^LKoc[W6o`000007olbga@03o`000?o9]<GobKC500GobKC500Go0000olJaaOo6/LGoa[75o`00
0003okJWbP03o`000?naXl[o/J?:00Co/J?:00?o0000ojbObon/Wl/00_n/Wl/00ol0003oYY_;ojJK
b`03ojJKb`03o`000?nOU/_o000000;oQXgC00Go0000ogj7dOmnQm7oOXOAo`000004ogN1d004o`00
0?m_N/koKg[>o`0000;oIgC<00Co0000of1^b_mPK/[o00000_m3GlT01_l0003o@5_7od1Kaol0003o
?US4o`0000;o?5C200Co0000ocE@`Ol0003o=Tno0ol000002OlfC[ko0000o`000?l0003o>e6oo`00
0?llD[oo@UO2o`000002odAG`@;oC5g300Go0000oeARa?mDH/CoE6;4o`000002oeiYaP05o`000?mY
LLSoJG78ofUab?l000000_mdNLX00ol0003oP8;;oh22b`02oh22b`03o`000?n;RLcoRhW<00;oRhW<
00Go0000oiJAc?nFTLcoUY7<o`000004oj2Hc003o`000?nYW/coZIk<00CoZIk<00Co0000ok6Ubona
YL_o00000_o3^=000ol0003obkk>ol^ncP02ol^ncP03o`000?oBa<cod/C<00Cod/C<00?o0000omS8
booHb</00ooHb</00ol0003ogLg9o`000002on_[b`03o`000?o^kLOok^g700;ok^g700Co0000ono_
aOo_klGokno50ol000001?oBmjKo0000om?iZ_l00009ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01_ooool000Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`?o0000>?ooool00ol0003ogL_7
omg;a`06omg;a`03o`000?oLbLKog<W600Kog<W600Go0000omc7aOoLalGog<O5o`000005oljiaP03
o`000?o<]lGoc;O500Goc;O500?o0000olVdaOo9]<D01Oo9]<D00ol0003oa[75o`000005okJWbP03
o`000?naXl[o/J?:00Co/J?:00?o0000ojbObon/Wl/00_n/Wl/00ol0003oYY_;ojJKb`03ojJKb`;o
00000on6SM<01Ol0003oOXOAogj7dOmnQm7o000000?oMh7@00Co0000ofmjc_m_N/ko00000omWM<`0
0ol0003oH6k:o`000003od=Ob@08o`000?m0FlOo@5_7o`000?lnF<Co0000ocaD`_l00002ocE@`@05
o`000?lfCkoo0000o`000?lfC[h00_l000000oliD;oo0000oc]A_`02o`000004od9G`_l0003oA5O1
o`0000;oC5g30_l000000omDH/Co0000oeiYaP02oeiYaP04o`000?mYLLSoJG78o`0000?oM7W:00Go
0000oh22bon0P/_oP8;;o`000004oh^9c003o`000?nFTLcoUY7<00;oUY7<00?o0000oj2Hc?nPV<`0
0_nPV<`00ol0003oZIk<ojVNc003ojVNc003o`000?naYL_o000000?o`kS@00?o0000ol^nc_o;_/h0
0oo;_/h00ol0003od/C<om;4c003om;4c003o`000?oHb<_of<S;00Cof<S;00Go0000on_[boo[jl_o
jn_;o`000004onk]a`0;o`000?o_klGokno5ono_aOl0003odONVo`000?oBmjKo0000om?iZ_l00000
2Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
0ol0000looooo`03o`000?oMblOogL_700KogL_700?o0000omc9a_oLbLH01_oLbLH00ol0003og<O5
o`000007oljiaP03o`000?o<]lGoc;O500Goc;O500?o0000olVdaOo9]<D01Oo9]<D00ol0003o]ZO:
okJWbP05okJWbP03o`000?naXl[o/J?:00Co/J?:00?o0000ojbObon/Wl/00_n/Wl/00ol0003oYY_;
ojJKb`02ojJKb`03o`000?n=TmCo000000?oQXgC00Go0000ogj7dOmnQm7oOXOAo`000003ogN1d004
o`000?m_N/koKg[>o`0000?oIgC<00?o0000odITcOl000000om3GlT00ol0003o@5_7o`000002ociH
a0?o00000_leD<42o`000009ocA?_ol0003o0000ocM?_ol0003o>E2oo`000?lkDKoo?5:o00;o@UO2
00CoA5O1o`000?m<GL?oC5g30_mFILH00ol0003oE6;4o`000002oeiYaP05o`000?mYLLSoJG78ofUa
b?l000000omdNLX01Ol0003oP8;;oh22bon0P/_o000000CoRhW<00Go0000oiJAc?nFTLcoUY7<o`00
0005oj2Hc003o`000?nYW/coZIk<00;oZIk<0_l00004ol>hd003o`000?o;_/kobkk>00?obkk>00?o
0000om;4c?oBa<`00ooBa<`00ol0003of<S;omS8b`03omS8b`;o00000oo[jl/00ol0003ok^g7onk]
a`02onk]a`04o`000?o_klGokno5ono_a@;o000000Cod_NVo`000?oCnJ[o00002oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o0000@?ooool00ol0
003ogL_7omg;a`06omg;a`03o`000?oLbLKog<W600Kog<W600?o0000oljia_o>^LH01oo>^LH00ol0
003oc;O5olbga@05olbga@03o`000?o9]<GobKC500CobKC500?o0000okV[bonfYlX01_nfYlX00ol0
003o/J?:ok6SbP04ok6SbP03o`000?n/Wl_o[9o;00;o[9o;00Co0000ojJKbonVVl_o00000on=Tm@0
1Ol0003oQXgCohJ=don6SM?o000000?oOXOA00Go0000ogN1d?mgPM3oMh7@o`000002ofmjcP04o`00
0?mWM<coIgC<o`0000;oAVC=00Oo0000od=ObOm3GlWo@eo9o`000?m0FlOo000000;o?US400?o0000
oc=B`ol000000_leD<401_l0003o=4noo`000?leD<7o0000ocM?_`;o>E2o0_lkDKl01Ol0003o@UO2
od9G`_m4El7o000000;oC5g30omFILH01?l0003oGVW6oeiYa_l00003ofUab005o`000?mdNL[oM7W:
ogAib_l000000on0P//00ol0003oRhW<oh^9c002oh^9c003o`000?nFTLcoUY7<00;oUY7<00?o0000
oj2Hc?nPV<`00_nPV<`00ol0003oZIk<o`000002o`000003okVadOl0003o`kS@00Co`kS@00?o0000
ol^nc_o;_/h00oo;_/h00ol0003od/C<om;4c003om;4c007o`000?oHb<_of<S;omS8bol0003oinO?
o`000003on_[b`03o`000?o^kLOok^g700;ok^g700Oo0000ono_aOo_klGo0000om7gY_l0003od_NV
00;o00003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo0004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014ooooo`03o`000?oMblOogL_7
00KogL_700?o0000omc9a_oLbLH01OoLbLH00ol0003od;_6oljiaP08oljiaP03o`000?o<]lGoc;O5
00Goc;O500?o0000olVdaOo9]<D00_o9]<D01Ol0003o^J_;okV[boniZl_o000000Ko]ZO:00?o0000
ok6Sb_naXlX01?naXlX00ol0003o[9o;ojbOb`02ojbOb`03o`000?nVVl_o000000CoSI?D00Go0000
ohJ=don6SM?oQXgCo`000003ogj7d@05o`000?mgPM3oMh7@ogN1d?l000000_m_N/h2o`000005odUY
d?l0003oAVC=odITcOl000000om3GlT01Ol0003o@5_7o`000?lnF<Co000000;o<e;300So0000ocE@
`Ol0003o0000ocA?_ol0003o=E31o`0000;o>E2o0ol00003od9G`P;o000000?oC5g3o`000?mFILH0
0_mFILH2o`000003oeiYa_l0003oJG7800;oJG7800Go0000ogAib_mdNL[oM7W:o`000003oh22b`03
o`000?n;RLcoRhW<00;oRhW<00?o0000oiJAc?nFTL`00_nFTL`01?l0003oX9S<oj2Hc?nPV<`2o`00
00Go^K7A00?o0000ol>hd?o3^=000_o3^=000ol0003obkk>ol^ncP03ol^ncP03o`000?oBa<cod/C<
00?od/C<00Co0000omS8booHb<_o00000_oWill01Ol0003ojn_;on_[boo[jl_o000000Cok^g700?o
0000ono_aOl000000_l000000ooBmjKo0000o`00000?ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool001kooooo0_l00017ooooo`03o`000?oMblOogL_700GogL_700?o0000
omc9a_oLbLH01?oLbLH01Ol0003od;_6om2ka_o@^lKo000000Soc[W600?o0000olbgaOo<]lD01Oo<
]lD01?l0003obKC5olVdaOl00005okV[b`;o00001OnfYlX2o`0000Go/J?:00?o0000ojbObon/Wl/0
0_n/Wl/2o`0000GoSI?D00Go0000ohJ=don6SM?oQXgCo`000003ogj7d@05o`000?mgPM3oMh7@ogN1
d?l000000_m_N/h01?l0003oBFW@odUYd?l00002odITc@04o`000?m3GlWo@eo9o`0000;o@5_70ol0
0002oc=B``;o000000_o<U32o`000?l0003o=E31o`000?lhD/7o0000ocaD`_l0003o?eK2o`000002
od9G`P;oBUk500?o0000odaM`omFILH00_mFILH2of9^b@;o00000omYLLP01Ol0003oM7W:ogAib_md
NL[o000000?oP8;;00?o0000oh^9c?n;RL`00_n;RL`00ol0003oUY7<oiJAc002oiJAc006o`000?nP
V<co0000o`000?n_ZM;o00001Oni/M400ol0003o`kS@ol>hd002ol>hd003o`000?o;_/kobkk>00Co
bkk>00?o0000om;4c?oBa<`00_oBa<`00ol0003of<S;o`000003onOWc`05o`000?o[jl_ojn_;on_[
bol000001?o^kLL3o`000004om7gY_l0003od_NVo`00013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`06ooooo`008?ooool00ol0003oooooooooo`15ooooo`03o`000?oMblOogL_7
00GogL_700?o0000omc9a_oLbLH00_oLbLH00ol0003od;_6om2kaP03om2kaP03o`000?o>^LKoc[W6
00Koc[W600?o0000olbgaOo<]lD01Oo<]lD00ol0003obKC5o`000007okV[b`03o`000?nfYl[o]ZO:
00Co]ZO:00?o0000ok6Sb_naXlX00onaXlX01ol0003o[9o;ojbObon/Wl_o0000oiBHeOl000001On=
Tm@01Ol0003oQXgCohJ=don6SM?o000000?oOXOA00Ko0000ogN1d?mgPM3oMh7@o`000?m_N/h2o`00
00;oBFW@00Co0000odITcOm6I<go00000_m3GlT01_l0003o@5_7od1Kaol0003o<UC5o`0000;o<e;3
0_l000001?lbD<;o0000ocE@`OleD<42o`0000;o?5C200Go0000ocmF`_l0003o@UO2o`000002odYN
a@05odaM`ol0003oEVG6oeIUa_l000000omRK/T4o`0000CoM7W:00Go0000oh22bon0P/_oP8;;o`00
0004oh^9c004o`000?nFTLcoUY7<oiJAc0;o00001?n_ZM800ol0003o^K7AokVad@02okVad@03o`00
0?o3^=3o`kS@00?o`kS@00?o0000ol^nc_o;_/h00oo;_/h00ol0003od/C<om;4c003om;4c003o`00
0?oWilooinO?00;oinO?00Go0000on_[boo[jl_ojn_;o`000004onk]a`04o`000?oBn:Wo0000om7g
YP;o00004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo04Gooooo00?o0000omg;aooMblL01OoMblL01Ol0003og<W6omc9a_oLbLKo0000
00Kod;_60_l00007oljiaP03o`000?o<]lGoc;O500Goc;O500?o0000okV[boniZl/01oniZl/00ol0
003o]ZO:okJWbP04okJWbP03o`000?naXl[o/J?:00?o/J?:00?o0000ojbObol000000onDV=D00ol0
003oSI?DohfCe003ohfCe005o`000?n6SM?oQXgCohJ=dol000000omnQm401Ol0003oMh7@ogN1d?mg
PM3o000000;oCFoD00Ko0000odUYd?m9JM3o0000odITcOl00003od=Ob@03o`000?m0FlOo000000;o
<UC500Co0000oc=B`olcD/?o00000_lbD<83o`000004ocQB`Ol0003o?5C2o`0000;o?eK200?o@UO2
o`000?m:G/D00_m:G/D01Ol0003oEVG6oeIUa_mFILKo000000;oHVk90om^N<`6o`0000?oP8;;00?o
0000oh^9c?n;RL`00_n;RL`01Ol0003oUY7<o`000?l0003oXj3B00Go[jWB00?o0000okVadOni/M40
0oni/M400ol0003o`kS@ol>hd002ol>hd003o`000?o;_/kobkk>00?obkk>00?o0000om;4c?oBa<`0
0_oBa<`2o`0000CoinO?00Go0000on_[boo[jl_ojn_;o`000003onk]a`;o000000God_RYo`000?l0
003od_NVo`00000Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool002;o
oooo00?o0000ooooooooool0A?ooool00ol0003ogL_7omg;a`06omg;a`03o`000?oLbLKo000000Wo
d;_600?o0000oljia_o>^LH01Oo>^LH00ol0003oc;O5olbga@04olbga@03o`000?nm[/_o^J_;00So
^J_;0_l00005okJWbP03o`000?naXl[o/J?:00?o/J?:00?o0000oiBHeOnDV=D00onDV=D2o`0000Co
SI?D00Go0000ohJ=don6SM?oQXgCo`000003ogj7d@03o`000?mgPM3oMh7@00;o00000_m=Km@01_l0
003oBFW@odUYd?l0003oAVC=o`0000?o@eo90ol00002oc9Da@03o`000?lcD/?o000000;o<U3200?o
0000oc=Ba?l000000_l00002ocaD`P04o`000?loE/;o?eK2o`0000CoBUk500Co0000oeIUa_mFILKo
00000omRK/T3ofihc0CoNh;?2ol00004oj>PdPCo[jWB00?o0000okVadOni/M400oni/M400ol0003o
`kS@ol>hd003ol>hd003o`000?o;_/kobkk>00?obkk>00Ko0000om;4c?oBa<co0000on;Re?l00004
onOWc`05o`000?o[jl_ojn_;on_[bol000000_o^kLL2o`000005om;hZOl0003odONVo`000?oBmjH0
5Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000Sooooo`;o0000AOoo
ool00ol0003ogL_7omg;a`06omg;a`03o`000?o@^lKod;_600Wod;_600?o0000oljia_o>^LH01Oo>
^LH00ol0003oc;O5olbga@02olbga@04o`000?nm[/_o_Jk;okf^b`;o00002?niZl/00ol0003o]ZO:
okJWbP03okJWbP03o`000?naXl[o/J?:00;o/J?:00?o0000oiZNe_nDV=D01OnDV=D00ol0003oSI?D
ohfCe002ohfCe005o`000?n6SM?oQXgCohJ=dol000000omnQm42o`0000;oDWKH00Co0000ode_e?m=
KmCo00000_m9JM000ol0003oAVC=o`000003od=Ob@03o`000?l_E/So000000;o<UC50ol00002oc9@
`P05o`000?lcD/Co0000ocQB`Ol000000_llE<82ocmF`P03o`000?m:G/GoBUk500;oBUk500CoE6O9
o`000?mFILKo00000omRK/T01?l0003oKWS<ofihc?m^N<`4og^2c`CoRHc@1OnFUm85oj>PdP03o`00
0?n_ZM;o[jWB00;o[jWB00?o0000okVadOni/M400_ni/M400ol0003o`kS@ol>hd003ol>hd003o`00
0?o;_/kobkk>00?obkk>00?o0000om;4c?l000000_oRh]@00ol0003oinO?onOWc`02onOWc`0:o`00
0?o[jl_ojn_;on_[bol0003ok^g7o`000?oDn[3o0000om;hZ@;o000000?od_NVooooooooool05?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000Uooooo`03o`000?oooooo
oooo04?ooooo00?o0000omg;aooMblL01OoMblL00ol0003odKg8om2kaP0:om2kaP03o`000?o>^LKo
c[W600Goc[W600Co0000olbgaOo<]lGo00001_nm[//00ol0003o^J_;okV[b`06okV[b`03o`000?nf
Yl[o]ZO:00?o]ZO:00Co0000ok6Sb_naXl[o00000onJW]H00ol0003oU9SEoiBHe@03oiBHe@03o`00
0?n=TmCoSI?D00;oSI?D00Go0000ohJ=don6SM?oQXgCo`000003ogj7d@;o00000_mBM]P01_l0003o
CFoDode_e?l0003oBFW@o`0000;oAVC=00Co0000od=ObOm3GlWo00000_l_E/P00ol0003o<UC5oc9D
a@03o`000004oc9@`_l0003o<e;4oc=Ba0;o00000_llE<801?loE/;o0000odIMa_l00003odYNa@04
o`000?mDIlWoEVG6o`0000?oHVk900Go0000ofihc?m^N<coKWS<o`000004og^2c`?oRHc@00?o0000
oiJGd_nFUm800_nFUm800ol0003oXj3Boj>PdP02oj>PdP03o`000?n_ZM;o[jWB00;o[jWB00?o0000
okVadOni/M400oni/M400ol0003o`kS@ol>hd002ol>hd003o`000?o;_/kobkk>00?obkk>0_l00003
on;Re003o`000?oWilooinO?00;oinO?00Co0000on_[boo[jl_ojn_;0_l000001_oDn[3o0000om;h
ZOl0003odONVo`0001Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`00
9_ooool00ol0003oooooooooo`13ooooo`03o`000?oMblOogL_700?ogL_700Go0000om6mb?oA_LSo
dKg8o`00000:om2kaP03o`000?o>^LKoc[W600Goc[W600?o0000olbgaOl000001onm[//00ol0003o
^J_;okV[b`06okV[b`03o`000?nfYl[o]ZO:00?o]ZO:00?o0000ok6Sb_l000001OnJW]H00ol0003o
U9SEoiBHe@02oiBHe@;o00000on=Tm@01ol0003oQXgCohJ=don6SM?o0000ogj7dOl000000_mGOM`0
1?l0003oDWKHoe9ff?l00002ode_e003o`000?m9JM3o000000;oAVC=0_l000001Ol/FLco0000obmF
b?l_E/So000000;o<UC500Co0000obmBaOl0003o00000_lcD/@01?l0003o>5K5o`000?llE<82o`00
00;oAUg600Co0000odYNaOm:G/Go00000_mDIlT00omFILKo0000of9^b@02of9^b@04o`000?m^N<co
KWS<o`0000CoNh;?00Go0000ohV<d?n9S=3oRHc@o`000004oiJGdP03o`000?nSX=;oXj3B00;oXj3B
00?o0000ojnYd_n_ZM800_n_ZM800ol0003o^K7AokVad@02okVad@03o`000?o3^=3o`kS@00?o`kS@
00Oo0000ol^nc_o;_/kobkk>o`000?oJg=So000000?oh^;D00?o0000onOWcooWill00_oWill01Ol0
003ojn_;on_[boo[jl_o000000;oe?Z`00Co0000om;hZOl0003o00006_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Go0000
omg;aooMblOogL_7o`000005om6mb0;o00002Oo@^lH2o`0000Koc[W600?o0000okf^bonm[//01onm
[//2o`0000Oo^J_;0_l00004okJWbP03o`000?nJW]KoVYkF00GoVYkF00?o0000oiBHeOnDV=D00onD
V=D01Ol0003oSI?DohfCe?n=TmCo000000?oQXgC0_l00003oeMmg004o`000?mBM]SoDWKHo`0000;o
CFoD00?o0000odUYd?l000000_m6I<d2o`000006obaIc?l0003o;eK8obmFb?l0003o<UC50_l00000
0ol_D/Go0000o`000002oc=Ba005o`000?lhE/Go0000ocmJa_l000000om6GLH00ol0003oBUk5o`00
0003oeAWb@;o00000_mRK/T01Ol0003oKWS<ofihc?m^N<co000000?oNh;?00Go0000ohV<d?n9S=3o
RHc@o`000004oiJGdP03o`000?nSX=;oXj3B00;oXj3B00?o0000ojnYd_n_ZM800_n_ZM800ol0003o
^K7AokVad@02okVad@03o`000?o3^=3o`kS@00?o`kS@00Co0000ol^nc_o;_/ko00000_oJg=P01Ol0
003oh^;Don;Re?oRh]Co000000CoinO?00_o0000on_[boo[jl_ojn_;o`000?oDn[3o0000om;hZOl0
003odONVo`00000Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002So
oooo0_l00014ooooo`03o`000?oMblOo000000SodKg800?o0000om2ka_o@^lH02?o@^lH00ol0003o
c[W6oljiaP03oljiaP03o`000?no/Lco_Jk;00Wo_Jk;00?o0000okV[boniZl/01_niZl/01_l0003o
]ZO:okJWb_nfYl[o0000oj2Se`OoVYkF0_l00004oiBHe@05o`000?n=TmCoSI?DohfCe?l000000_n6
SM<00ol0003oG8CQo`000003oeMmg004o`000?mBM]SoDWKHo`0000;oCFoD00Wo0000odUYd?l0003o
AVC=o`000?lYG=3o0000obaIc?l000000_l_E/P2o`000003ob]Db?l0003o;e;500;o000000Co<e;4
o`000?lhE/Go00000_loF/H01_l0003oAUg6odIMa_m6GLKoBUk5o`0000?oE6O90_mOLLd00ol0003o
HVk9o`000003ofihc003o`000?mkP/ooNh;?00;oNh;?00Co0000ohV<d?n9S=3o00001?nFUm800ol0
003oXj3Boj>PdP02oj>PdP03o`000?n_ZM;o[jWB00;o[jWB00?o0000okVadOni/M400oni/M400ol0
003o`kS@ol>hd002ol>hd003o`000?o;_/ko000000?of]cH00Go0000on;Re?oRh]Coh^;Do`000004
onOWc`04o`000?o[jl_ojn_;o`0000;oe?Z`00Co0000om;hZOl0003o00007?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooooooo04;ooooo00?o
0000om6mb?oA_LP02?oA_LP00ol0003od;_6om2kaP08om2kaP05o`000?o>^LKoc[W6oljia_l00000
0ono/L`2o`0000So_Jk;0_l00007okV[b`03o`000?nfYl[o000000?oX:?G0_l00006oiZNeP03o`00
0?nDV=GoU9SE00;oU9SE0_l00002ohfCe0;o00000omLQ>401Ol0003oEggLoeMmg?mGOMco000000;o
DWKH00Go0000ode_e?m=KmCo0000odUYd002o`0000;o:Ec@00?o0000obaIc?l000000_l_E/P2o`00
0004ob]Db?l0003o0000oc5Fa`?o000000Go>5K5o`000?loF/Ko?e[6o`000003odIMaP;o00000_mD
IlT01_l0003oGg7=oemacOmOLLgoHVk9o`0000;oKWS<00?o0000og^2comkP/l00_mkP/l01Ol0003o
RHc@ohV<d?n9S=3o000000CoUYOB00?o0000oj>Pd_nSX=800_nSX=800ol0003o[jWBojnYdP02ojnY
dP03o`000?ni/M7o^K7A00;o^K7A00?o0000ol>hd?o3^=000_o3^=02o`0000Cof]cH00?o0000on;R
e?oRh]@00_oRh]@01_l0003oinO?onOWcooWiloo0000on_[b`;o00000_oDn[000ol0003od_RYo`00
000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000
ooooooooool0@oooool:om6mb0;o00002Oo@^lH00ol0003oc[W6o`000006oknac0;o00002?nm[//0
0ol0003o^J_;okV[b`05okV[b`03o`000?nPXmOoX:?G00CoX:?G0_l00005oiZNeP;o00001?nDV=D0
0ol0003oSI?DohfCe002o`0000?oG8CQ0_l00002oeMmg004o`000?mBM]SoDWKHo`0000;oCFoD00Co
0000odUYd?l0003o00000_lYG=000ol0003o;5W<o`000002obmFb0;o000000?o:eC8o`000?l00000
0_laE/L01?l0003o>5K5ocQFaOl00002ocmJaP03o`000?m6GLKoAUg600;oCFK;00?o0000oeAWbOl0
00001?mOLLd2o`0000;oKWS<00Go0000og^2comkP/ooNh;?o`000003ohV<d003o`000?nFUm;oUYOB
00;oUYOB00?o0000oj>Pd_nSX=800_nSX=800ol0003o[jWBojnYdP02ojnYdP03o`000?ni/M7o^K7A
00;o^K7A00?o0000ol>hd?o3^=000_l000000ooAe=_o0000om[Lf003om[Lf003o`000?oRh]Coh^;D
00;oh^;D00Co0000onOWcooWilooinO?0_l000001_oFoK[o0000omCj/?l0003od_RYo`00023ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`00;?ooool00ol0003ooooooooo
o`13ooooo`;o00002OoA_LP00ol0003od;_6om2kaP07om2kaP03o`000?no/Lco_k7<00Oo_k7<00?o
0000okf^bonm[//01_nm[//00ol0003o^J_;okV[b`04okV[b`03o`000?nUZ=SoX:?G00KoX:?G00?o
0000oiZNe_nJW]H01?nJW]H00ol0003oU9SEoiBHe@02oiBHe@05o`000?n=TmCo0000of:=iOl00000
1?mLQ>400ol0003oEggLoeMmg002o`000004oe9ff?l0003oCFoDode_e0;o000000co9F3Do`000?lY
G=3o:Ec@o`000?l/FLco0000obmFb?l0003o9EK<o`000?l[E<P2o`0000;o<EK70ol00003ocmJaP03
odIMa_l0003oCFK;00;oCFK;00?o0000oeAWbOl000000omOLLd2ofemdP03o`000?m^N<co000000Co
Nh;?00Co0000ohV<d?n9S=3o00001?nFUm800ol0003oXj3Boj>PdP02oj>PdP03o`000?n_ZM;o[jWB
00?o[jWB00?o0000okVadOni/M400_ni/M42o`0000?odMCK00?o0000om[Lf?oJg=P00_oJg=P00ol0
003oh^;Don;Re002on;Re007o`000?oWilooinO?onOWcol0003oe_fjo`000002omCj/0;o00008Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000]ooooo`;o0000AOooool0
0ol0003odKg8om6mb007om6mb003o`000?o@^lKod;_600Kod;_600?o0000ol:dcOl000002?no/L`2
o`0000Oo_Jk;0_l00003okV[b`03o`000?nUZ=SoYJSH00;oYJSH00?o0000oj2SeonPXmL00onPXmL2
o`0000GoVYkF00?o0000oiBHeOnDV=D00_nDV=D2o`0000;oHXgU0_l00003oeb4h@07o`000?mGOMco
EggLoeMmg?l0003oDWKHo`000002ode_e0;o000000Ko9F3Do`000?lYG=3o:Ec@o`000?l/FL`2o`00
00;o9EK<00?o0000ob]Db?l000000_laE/L01?l0003o>5_:o`000?l00002ocmJaP;o00001?m=I//0
0omDIlWo0000oemac@02oemac@05o`000?m]OM;oKGgBofemd_l000001?mkP/l01Ol0003oRHc@ohV<
d?n9S=3o000000CoUYOB00?o0000oj>Pd_nSX=800_nSX=800ol0003o[jWBojnYdP02ojnYdP04o`00
0?ni/M7o^K7AokVad@;o00001?oAe=/00ol0003of]cHom[Lf002om[Lf003o`000?oRh]Coh^;D00;o
h^;D00?o0000onOWcooWill00_l000000ooFoK[o0000omCj/002o`0002?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`04ooooo`00;oooool00ol0003oooooooooo`13ooooo`03o`00
0?oA_LSodKg800OodKg80_l00005om2kaP03o`000?o2]<go`[C=00;o`[C=00?o0000oknac?no/L`0
1_no/L`2o`0000Oo_Jk;00?o0000okV[bol000001_nUZ=P2o`0000GoX:?G0_l00004oiZNeP;o0000
0_nDV=D00ol0003oJIGYo`000003of:=i@04o`000?mLQ>7oG8CQoeb4h@;o00000_mGOM`02Ol0003o
DWKHo`000?m=KmCo0000ob1Uf?l0003o9F3Do`000002obULd004o`000?l/FLco0000o`0000;o9EK<
00Ko0000ob]Db?l0003o0000oc5Faol00002ocQKbP;o00000_m3H/`00ol0003oCFK;odeVb`02odeV
b`;o00000_mOLLd00ol0003oKGgBofemdP02ofemdP;o00000_mkP/l01Ol0003oRHc@ohV<d?n9S=3o
000000CoUYOB00?o0000oj>Pd_nSX=800_nSX=800ol0003o[jWBojnYdP02ojnYdP06o`000?ni/M7o
0000o`000?o5b]ko00001?oAe=/00ol0003of]cHom[Lf002om[Lf003o`000?oRh]Coh^;D00;oh^;D
00Ko0000onOWcol0003o0000omKm^_l00002omCj/003o`000?oooooooooo02?ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`13ooooo`;o
00002OoA_LP01Ol0003od;_6om2ka_o@^lKo000000Ko`[C=0_l00008oknac003o`000?nm[/_o_Jk;
00Go_Jk;00?o0000ojFXf?nUZ=P01onUZ=P2o`0000GoX:?G00?o0000oiZNe_nJW]H00onJW]H2o`00
00?oJIGY0_l00002of:=i@;o00000omLQ>401Ol0003oEggLoeMmg?l0003oDWKH00;o00000_lPIMP0
0ol0003o9F3Do`000002obULd004o`000?l/FLco0000o`0000;o9EK<0_l000001_l]FLco0000oc5F
aol0003o>5_:o`0000Co@f;<00Co0000odeVbom=I/_oCFK;0_mGL=401?l0003oGg7=oemacOl00003
ofemdP;oNhWF0_l000001OmkP/oo0000ohV<d?n9S=3o000000CoUYOB00?o0000oj>Pd_nSX=800_nS
X=801?l0003o[jWBojnYd_n_ZM83o`0000?oaL[N00?o0000om7DfooAe=/00_oAe=/00ol0003of]cH
om[Lf002om[Lf003o`000?oRh]Coh^;D00;oh^;D0_l000001_oGolGo0000omKm^_l0003oe?Z`o`00
02Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`0004Go
oooo00?o0000om6mb?oA_LP01ooA_LP00ol0003od;_6o`000009ol:dc@;o00001ono/L`2o`0000Go
_Jk;00?o0000ojV/fOl000002OnUZ=P2o`0000CoX:?G0_l00004oiZNeP;o00001?mYUNT2o`0000;o
HXgU0_l00002oeb4h@05o`000?mGOMcoEggLo`000?mBM]P00_l00002ob1Uf005o`000?lUH=Co0000
o`000?lYG=000_l000001?lMFM3o0000obEFc?lUE/`2o`000003obeIc?l0003o000000;o>5_:00?o
0000od=Rc?m3H/`00_m3H/`01?l0003oCFK;odeVbol00002oeM`d@03o`000?mOLLgo000000?oKGgB
00?o0000og^9e_mkRMH00_mkRMH3o`000003ohV<d?l0003oUYOB00?oUYOB00?o0000oj>Pd_nSX=80
1Ol00002okRng`05o`000?o5b]koaL[NolG:g_l000001?oAe=/00ol0003of]cHom[Lf002om[Lf004
o`000?oRh]Coh^;Don;Re0;o000000Ooeoo5o`000?oFoK[oe_fjo`000?oDn[3o000002Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00<oooool00ol0003oooooooooo`13
ooooo`;o00002?oA_LP00ol0003o`[C=ol:dc@0:ol:dc@;o00001ono/L`2o`0000;o_Jk;00?o0000
ojV/fOnY[=T00_nY[=T2o`0000SoYJSH00?o0000oj2SeonPXmL00onPXmL2o`0000;oVYkF00Co0000
og2MkOl0003o00001?mYUNT01Ol0003oHXgUof:=iOmRSNGo000000;oG8CQ0_l000001OmGOMco0000
o`000?lKJ]co000000;o86GH00Go0000obEPe?lUH=Co0000obULd002o`000005oaeId?l0003o9EK<
obEFc?l000000ol]FL`01?l0003o>5_:ocQKb_l00004od=Rc003odeVbol0003oEg3A00?oEg3A00?o
Gg7=o`000?m]OM800_m]OM800ol0003oNhWFog^9eP02og^9eP?oRYOJ2Ol00002ojVbgP03o`000?nh
_]oo^;kO00;o^;kO00Go0000olG:g_o5b]koaL[No`000005om7Df`05o`000?oJg=Sof]cHom[Lf?l0
00000_oRh]@02Ol0003oeooBo`000?oGolGo0000omKm^_l0003oe?Z`o`00000Yooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000ooooooooool0A?ooool0
0ol0003odKg8om6mb005om6mb003o`000?o4]lko000000co`[C=00?o0000oknac?no/L`01_no/L`0
0ol0003o_Jk;o`000006ojV/f@;o00001onUZ=P2o`0000GoX:?G0_l00004og2Mk@;o00000omYUNT2
o`0000;oHXgU0_l00002oeb4h@05o`000?mGOMco0000o`000?lKJ]`00_l000001_lPIMSo0000o`00
0?lUH=Co0000obULd0;o000000Co7EW@o`000?l0003o9EK<0_l00002obeIc0Co00000_m3H/`3o`00
00GoEg3A0_l00002ofemdP03o`000?mkRMKoNhWF00;oNhWF00Co0000ohZGf_n:Um[oRYOJ1OnJY=d0
0ol0003oZK;NojVbgP02ojVbgP03o`000?nh_]oo^;kO00;o^;kO00Go0000olG:g_o5b]koaL[No`00
0005om7Df`0;o`000?oJg=Sof]cHom[Lf?l0003oh^;Do`000?oGom;o0000omOoaOl000000_oFoKX2
o`0002_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0
003oooooooooo`14ooooo`03o`000?oA_LSodKg800?odKg800?o0000olBgc_o4]lh00_o4]lh2o`00
00[o`[C=0_l00007oknac003o`000?nY[=WoZJcI00OoZJcI0_l00007ojFXf0;o00001?nPXmL2o`00
00GoL9g]0_l00003ofVEj@;o00000_mRSND00ol0003oG8CQoeb4h@02o`000005oaI_h?l0003o6f[L
oa]Zg?l000000_lPIMP01_l0003o9F3Do`000?l0003o4ecDo`0000;o7EW@0_l000001?lWG];o0000
obeIc?l00002ocQRd0?o00000_m8Jm800ol0003oEg3AoeM`d@03oeM`d@;oHggG00Co0000ofemd_m]
OM;o00000omkRMH01Ol0003oRYOJohZGf_n:Um[o000000CoVZCM00?o0000ojVbg_nY/]h00_nY/]h0
0ol0003o^;kOokRng`02okRng`05o`000?o5b]koaL[NolG:g_l000001OoAe=/01?l0003of]cHom[L
f?oJg=P2o`0000;oeooB00?o0000omOoaOl000000_oFoKX00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool003Kooooo0_l00015ooooo`;o00000_oA
_LP00ol0003oa;O>olBgcP05olBgcP;o00002_o2]<d2o`0000Go_k7<00?o0000ojjaf_l000002OnY
[=T3o`0000KoYJSH00Ko0000oj2SeonPXmOoX:?Go`000?mgY_02o`0000GoL9g]0_l00003ofVEj@03
o`000?mRSNGoHXgU00;o000000CoG8CQo`000?l0003o5VoP0_l000001_lKJ]co0000ob1Uf?lPIMSo
0000obEPe0;o000000Co4ecDo`000?lMFM3o7EW@0_l000001?lWG];o0000o`000?l00002ocQRd003
o`000?m8Jm;oB6_B00;oB6_B00Go0000oeM`dOmGL=7oEg3Ao`000003of=me`03o`000?m]OM;o0000
00?oNhWF00Go0000ohZGf_n:Um[oRYOJo`000004oiZTg@03o`000?nY/]koZK;N00;oZK;N00?o0000
okRngonh_]l00_nh_]l00ol0003oaL[NolG:gP02olG:gP03o`000?oAe=_odMCK00;odMCK00?o0000
om[Lf?oJg=P00_l00002omOodP03o`000?oGolGoeoo500?o0000;_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00?ooooo000hooooo`03o`000?oooooooooo04Cooooo00?o0000om6m
b?l000002Oo4]lh2o`0000[o`[C=00Go0000oknac?no/Lco_k7<o`000005ojjafP;o00002?nY[=T2
o`0000GoYJSH0ol00004ogNVl0;o00001Om`WNd01?l0003oJIGYofVEjOmYUNT2o`0000;oHXgU0_l0
00001_lAM^;o0000oaI_h?lFKn3o0000oa]Zg0;o000000?o86GHo`000?lUH=@00_l000001OlCG=Co
0000oaeId?lMFM3o000000?o9ekB0_l00002ocQRd003o`000?m8Jm;oB6_B00;oB6_B00Co0000oeM`
dOmGL=7o00001?mSOML00om]OM;o0000og^9eP02og^9eP05o`000?n:Um[oRYOJohZGf_l000001?nJ
Y=d00ol0003oZK;NojVbgP02ojVbgP03o`000?nh_]oo^;kO00;o^;kO00?o0000olG:g_o5b]h00_o5
b]h00ol0003odMCKom7Df`02om7Df`05o`000?oJg=So0000omClgol000000_oGom801?l0003oeoo5
o`000?l0000aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool003Wooooo
00?o0000ooooooooool0A?ooool00ol0003oa;O>olBgcP0:olBgcP?o00002?o2]<d2o`000003okna
c?l0003o[[7J00Ko[[7J0ol00007ojV/f@;o00001OnUZ=P2o`0000GoMjK`0_l00004og2Mk@;o0000
0omYUNT2o`000004of:=iOl0003o0000oa5fhP;o000000Ko5VoPo`000?l0003o6f[Lo`000?lPIMP2
o`000003o`IOe_l0003o4ecD00;o000000?o7EW@o`000?l000000_lWG]801Ol0003o>6;@ocQRd?lh
H]3o000000CoB6_B00?o0000oeM`dOl000001OmSOML2o`0000;oNhWF00?o0000ohZGf_n:UmX00_n:
UmX01Ol0003oVZCMoiZTgOnJY=go000000GoZK;N00?o0000okRngonh_]l00_nh_]l01Ol0003oaL[N
olG:g_o5b]ko000000CodMCK0_l000001OoDo=oo0000omOod_oGom;o000000;oeoo500?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000jooooo`03
o`000?oooooooooo04Gooooo00?o0000olBgc_o4]lh02oo4]lh2o`0000So`[C=00?o0000ojjaf_n^
/MX02On^/MX2o`0000OoZJcI0_l00003ojFXf003o`000?mn[_;o000000;o00001?mgY_03o`0000?o
L9g]0_l00003ofVEj@;o000000Co3GcSo`000?l0003o4GKR0_l000000olFKn3o0000oa]Zg004o`00
0004o`IOe_l0003o4ecDoa=Le0;o000000Co7fCHo`000?lWG];o9ekB1Ol00002odQ[dPCo00001OmS
OML2og2<g`03o`000?mkRMKo000000CoRYOJ00?o0000oiZTgOnJY=d00_nJY=d00ol0003oZK;NojVb
gP02ojVbgP03o`000?nh_]oo^;kO00;o^;kO00Go0000olG:g_o5b]koaL[No`000003om7Df`;o0000
0_oDo=l01_l0003oeooBomOod_l0003oeoo5o`0003Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`00>oooool2o`0004Sooooo0_l0000;olBgcP;o00001_o2]<d00ol0003o
/KGKo`00000;ojjafP;o00001onY[=T3o`0000GoOZkb0_l00005ogNVl0;o00000om`WNd2o`0000;o
JIGY0_l00002o`elh`;o000000?o4GKRo`000?lFKn000_l000001OlKJ]co0000o`000?l0003o1UoF
00;o000000Co4ecDo`000?l0003o7fCH0ol00003ocQ[f0?o00001?m?MmX01Ol0003oHggGof=meomS
OMOo000000?oL8cO00?oNhWFo`000?n:UmX00on:UmX00ol0003oVZCMoiZTg@02oiZTg@03o`000?nY
/]koZK;N00;oZK;N00?o0000okRngonh_]l00_nh_]l01?l0003oaL[NolG:g_o5b]h4o`000005olgd
j_l0003oe?cOomClgol000000_oGom82o`0003Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`00?Oooool00ol0003oooooooooo`17ooooo`?o00002_o4]lh2o`0000?o`[C=
00?o0000ok6efona]M/00ona]M/3o`0000So[[7J0ol00006ojV/f@?o00001Omn[_83o`0000CoMjK`
0_l00003og2Mk@?o000000?o2X?Ro`000?l000000_l=O><4o`000006oaI_h?l0003o6f[Lo`000?l0
HMKo00000_l6GmH00ol0003o4ecDo`000003oamTf0;o00000olhJmP00ol0003oCgOJodmgfP04odmg
fP04o`000?mSOMOoHggGo`0000CoL8cO1?l000000on:Um[o0000oiZTg@03oiZTg@03o`000?nY/]ko
ZK;N00;oZK;N00?o0000okRngonh_]l00_nh_]l00ol0003oaL[NolG:gP02o`0000?ocOCZ00Co0000
omClgooDo=oo00000_oGom82o`0003Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`00?_ooool00ol0003oooooooooo`19ooooo`;o00002_o4]lh2o`000003ol:dcOl0003o
/KGK00Oo/KGK0ol00008ojjafP;o00001?nY[=T00ol0003oQ[KdohJfm003o`0000GoOZkb0_l00004
ogNVl0;o00000om`WNd2o`0000;o2X?R0_l00002o`elh`?o000000?o5VoPo`000?l000001?l00000
0ol6GmKo0000o`000002o`0000?o7fCH00Go0000ocQ[f?lhJmSo>6_Ho`000006odmgfP03o`000?mS
OMOo000000CoL8cO1?moWNH5o`000003oiZTgOl0003oZK;N00?oZK;N00?o0000okRngonh_]l00_nh
_]l3o`000003ol;XlOl0003ocOCZ00;ocOCZ00Co0000omClgooDo=oo00000_oGom800ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003oooooo00?o
0000ooooooooool0B_ooool2o`0000[oa;O>00?o0000ok6efona]M/02_na]M/2o`0000So[[7J1?l0
0006ohJfm0?o00001?mn[_83o`0000?oMjK`0_l000000om`WNgo0000o`Z:h@03o`000003o`Z3h_l0
003o000000;o3GcS0ol000001_lFKn3o0000o`1Qcol0003o067Fo`0000;o1UoF00Co0000oaEZgOl0
003o00000_lOI=P3o`000003ocQ[f?l0003oCgOJ00CoCgOJ0ol00003og2<g`03o`000?moWNKoOigV
00?oOigV00Co0000oi2akOn@/NgoT;7]3?l00002ol;Xl@05o`000?o=m>[ocOCZolgdj_l000000_oD
o=l01?l0003oeooBo`000?l0000looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool0043ooooo0_l0001<ooooo`?o00001oo4]lh01?l0003o];WLokBig?l0000;ok6ef`?o0000
2?n^/MX00ol0003oQ[KdohJfm007ohJfm0?o00001?mn[_82o`0000?oMjK`0ol00003o`Z:h@;o0000
00Co2X?Ro`000?l0003o3GcS2_l000001?l6GmKo0000oaEZgOlEJ]d3o`0000;o=gKQ0ol000001?m?
Mm[o0000o`000?l00003oeN6i004o`000?m`S=ooL8cOo`0000GoOigV00?o0000oi2akOn@/Nd00_n@
/Nd00ol0003oX/Caoj;4l@02oj;4l@03o`000?ncf??o/mSc00;o/mSc00Co0000ol;XlOo2j?7o0000
0oo=m>X00ol0003oe?cOomClg`02o`0003kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`00@_ooool00ol0003oooooooooo`1<ooooo`;o00001?o4]lh00ol0003o];WLokBi
g004okBig0?o00002Ona]M/3o`0000Go[[7J00Co0000ohflm_n=_?Ko00002On6]_@3o`0000?oOZkb
1?l00002o`bAgP?o00000_l:R^42o`000004o`Z3h_l0003o0000o`elh`?o000000?o05k0o`000?l0
00000ol000000ol6GmKo0000o`000002oaEZg@;o00001?lgM^42o`0000KoEhKT00?o0000og2<gol0
00001?moWNH00ol0003oT;7]oi2ak@02oi2ak@03o`000?nRa?7oX/Ca00;oX/Ca00?o0000ok?Hlonc
f?<00_ncf?<01?l0003o`^Saol;XlOl00004olgdjP04o`000?oDo=ooe?cOo`00043ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`1=oooo
o`?o000000?oa;O>o`000?nd^M`02?nd^M`4o`0000So/KGK0ol000000on^/M[o0000ohflmP06ohfl
mP;o00001on6]_@3o`0000?oOZkb0ol00003o`bAgP?o000000?o2X[Qo`000?l000000ol000001Ol=
O>?o0000o`000?l0003o05k000Go000000Co1VoNo`000?l0003o5F[M0_l00005ocMfh@03o`000?mG
Q^CoEhKT00?oEhKT0ol00004ognMiP03o`000?n@/NgoT;7]00;oT;7]00?o0000oj;4lOnRa?400_nR
a?400ol0003o/mScok?Hl`02ok?Hl`04o`000?o2j?7o`^Sao`0000?ocOCZ00Co0000omClgol0003o
0000@_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`00
0?oooooooooo04oooooo00?o0000okBig?nd^M`03?nd^M`3o`0000So/KGK00?o0000ohflm_n=_?H0
2On=_?H4o`0000GoQ[Kd1?l00002oa:Jg@Co00000_l<TMh8o`000005o`elhol0003o0000o`000?l0
G/001?l00002o`I_gP;o000000?o5F[Mo`000?l000000ol000000olgM^7o0000oeN6i003o`0000?o
HIW_0_l00002ognMiP05o`000?n@/NgoT;7]oi2akOl000001OnRa?401Ol0003o/mScok?Hloncf??o
000000?o`^Sa00Co0000olgdj_o=m>[ocOCZ0ol00014ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00Oooool004Gooooo0_l0001Booooo`;o00003Ond^M`3o`0000Go/KGK00Go0000
oiC2monD`_OoU<;go`00000;ohflmPCo00001?n6]_@4o`0000?o4Y[M1Ol000000ol<TMko0000o`00
0004o`000005odL00?l0FJ_o0000o`000?l0G/001?l00002o`I_gP?o00000oldQ>X4o`0000OoHIW_
00?oOigVo`000?n@/Nd00on@/Nd00ol0003oX/Caoj;4l@02oj;4l@03o`000?ncf??o/mSc00;o/mSc
00Co0000ol;XlOo2j?7o00000_o=m>X4o`0004Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`1Dooooo`Go00002?nd^M`3o`000003ok6e
fol0003oU<;g00WoU<;g0ol00007ohflmP?o000000?oQ[Kdo`000?lKXmd00_lKXmd5o`0000?o4Y[M
2?l00003odL000So000000?o1VoNo`000?l000001_ldQ>X00ol0003oHIW_of6Ik`04of6Ik`Co0000
0_n@/Nd00ol0003oX/Caoj;4l@02oj;4l@05o`000?ncf??o/mScok?Hlol000000oo2j?45o`0004So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00B?ooool00ol0003ooooo
ooooo`1Hooooo`Go00001_nd^M`2o`00013oU<;g1Ol00002ohflmPSo00000_lKXmd6o`000003oa:J
gOl0003o000000?o000000GoC@00odL00?m7003oA`00o`1IZ`0=o`0000;o=8CZ00?o0000of6IkomQ
VNl00ol00004ofb_n@Go00000_nRa?401?l0003o/mScok?Hloncf?<7o`0004_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`01ooooo`00BOooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo00;ooooo1Ol00002okBig003o`000?nJaoOoV/Og00;oV/Og2Ol00009oiC2maWo
00000om=00000om7003o05V[o`000008o`0000;o<9?`1Ol00005ofb_n@;o00001Omgaol8o`000003
oh7Xe?l0003o000004kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
B_ooool2o`0005Oooooo00?o0000ooooooooool01oooool2o`0000koV/Og2?l00003oiC2m`03o`00
0?lh^^Co>;[T00[o>;[T3?l00003odl00006odd00?m7003o0000o`000?lc003o06o22Ol000001?l`
To3o0000o`000?m/[oT2o`0000GoMlOo0_l00002oh3Ko@;o000000?oQ>S^o`000?l000000ol0001?
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004cooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`0=ooooo`Wo00002OnJaoLMo`0000?o9P000_ooool00om=
003o0000oc<00002oc<00004o`1_`_l0003o0000o`0000?o::3^1Ol00005ogO7o`06o`000?n0fogo
P=_moh3KoOl0003oQ>S^0_l000000on1j=Co0000o`00001Booooo`03o`000?oooooooooo00Sooooo
0Ol00001ooooo`7ooooo001=ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool05_oo
ool9o`0000?oV/Og00?o0000od[6j_m:a^X01?m:a^X=o`0000oooooo00GoC@00oc<00?lc003o<`00
o`1_`P06o`0000;o::3^0_l000000omgaooo0000o`000002oh3Ko@;o000000?oQ>S^o`000?l00000
0_l0001Eooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001>ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool07oooool:o`00027ooooo00?o0000oc<00?l000004?l0
001Hooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001?ooooo`;o0000D_ooool0
0ol0003oooooooooo`1?ooooo`03ocl00?l0003o3inh00;o3inh0ol0001Oooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool0]oooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00D_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool005?ooooo0_l0001>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool005Gooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00E_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool00oooool1o`00007ooooo001Goooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`02oooo
o`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo0;_ooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
_?ooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool0_Oooool01?l0003oooooooooool00001ooooo`00G?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooool000000Oooool005gooooo0_l0
0014ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool00Ol0000005oooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`2oooooo`7o00000Oooool1o`000000H?ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo0_l00000067ooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000?oooool00ol0003ooooo
ooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2c
ooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`oooo
o`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:cooooo1?l0000Booooo`00
JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0000Fooooo`00J_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000Jooooo`00Joooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000Nooooo`00K?ooool2o`00
03Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool00ol0003ooooooooo
o`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2>
ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:oooo
o`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co
0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0000mooooo`00Mooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l00011ooooo`00N?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015ooooo`00NOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019ooooo`00N_ooool2o`0002Ko
oooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0003oooooooooo`1Soooo
o`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Oooooo`Co
0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`Co0000
I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000J?oo
ool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/ooooo`00Q_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`ooooo`00Qoooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00R?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROooool2o`0001Oooooo00?o
0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003oooooooooo`0dooooo`Co0000
Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`Co0000Sooo
ool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`?o0000Toooool0
09;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00U?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2o`0000Sooooo00?o0000
ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000]_oo
ool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002Oooooo`03o`000?oooooo
000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o000000;o0000`Oooool00:7o
oooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65751 m .51694 .65827 L .43899 .65168 L p .089 .636 .833 r
F P
0 g
s
.59281 .65659 m .59527 .65394 L .51826 .6582 L p .308 0 0 r
F P
0 g
s
.51826 .6582 m .51694 .65827 L p .51938 .65822 L .308 0 0 r
F P
0 g
s
.59281 .65659 m .51826 .6582 L .51938 .65822 L .308 0 0 r
F
.51694 .65827 m .51723 .65751 L .59281 .65659 L p F P
0 g
s
.59032 .65947 m .59281 .65659 L .51723 .65751 L p .358 0 0 r
F P
0 g
s
.51723 .65751 m .51753 .65687 L .58823 .65939 L p .358 0 0 r
F P
0 g
s
.58823 .65939 m .59032 .65947 L p .58629 .65936 L .358 0 0 r
F P
0 g
s
.58629 .65936 m .51723 .65751 L .58823 .65939 L .358 0 0 r
F
.59527 .65394 m .59281 .65659 L .6652 .64467 L p .338 0 0 r
F P
0 g
s
.6652 .64467 m .67023 .63881 L .59527 .65394 L p .338 0 0 r
F P
0 g
s
.44219 .6475 m .43899 .65168 L .36521 .63435 L p .547 .77 .98 r
F P
0 g
s
.43899 .65168 m .44219 .6475 L .51723 .65751 L p .089 .636 .833 r
F P
0 g
s
.51753 .65687 m .51723 .65751 L .44219 .6475 L p .034 .591 .813 r
F P
0 g
s
.36521 .63435 m .37138 .62695 L .44219 .6475 L p .547 .77 .98 r
F P
0 g
s
.44541 .64333 m .44219 .6475 L .37138 .62695 L p .528 .746 .975 r
F P
0 g
s
.44219 .6475 m .44541 .64333 L .51753 .65687 L p .034 .591 .813 r
F P
0 g
s
.59281 .65659 m .59032 .65947 L .6601 .65085 L p .373 0 .01 r
F P
0 g
s
.6601 .65085 m .6652 .64467 L .59281 .65659 L p .373 0 .01 r
F P
0 g
s
.51783 .65621 m .51753 .65687 L .44541 .64333 L p 0 .558 .81 r
F P
0 g
s
.58779 .66237 m .59032 .65947 L .51753 .65687 L p .392 0 0 r
F P
0 g
s
.51753 .65687 m .51783 .65621 L .58779 .66237 L p .392 0 0 r
F P
0 g
s
.67023 .63881 m .6652 .64467 L .73061 .62201 L p .224 0 .004 r
F P
0 g
s
.73061 .62201 m .73799 .61332 L .67023 .63881 L p .224 0 .004 r
F P
0 g
s
.37138 .62695 m .37758 .61947 L .44541 .64333 L p .528 .746 .975 r
F P
0 g
s
.44867 .63911 m .44541 .64333 L .37758 .61947 L p .509 .719 .967 r
F P
0 g
s
.44541 .64333 m .44867 .63911 L .51783 .65621 L p 0 .558 .81 r
F P
0 g
s
.37138 .62695 m .36521 .63435 L .29943 .6068 L p .7 .744 .885 r
F P
0 g
s
.59032 .65947 m .58779 .66237 L .65493 .65712 L p .398 0 .024 r
F P
0 g
s
.65493 .65712 m .6601 .65085 L .59032 .65947 L p .398 0 .024 r
F P
0 g
s
.51813 .6554 m .51783 .65621 L .44867 .63911 L p 0 .535 .821 r
F P
0 g
s
.58522 .66511 m .58779 .66237 L .51783 .65621 L p .413 0 0 r
F P
0 g
s
.51783 .65621 m .51813 .6554 L .57509 .66364 L p .413 0 0 r
F P
0 g
s
.57948 .66435 m .51783 .65621 L .57509 .66364 L .413 0 0 r
F
.57509 .66364 m .58522 .66511 L p .57948 .66435 L F P
0 g
s
.58261 .66747 m .58522 .66511 L .51813 .6554 L p .422 0 0 r
F P
0 g
s
.51813 .6554 m .51844 .65432 L .56994 .66487 L p .422 0 0 r
F P
0 g
s
.56994 .66487 m .58261 .66747 L p .57511 .66606 L .422 0 0 r
F P
0 g
s
.57511 .66606 m .51813 .6554 L .56994 .66487 L .422 0 0 r
F
.57996 .66924 m .58261 .66747 L .52286 .65523 L p .418 0 0 r
F P
0 g
s
.57996 .66924 m .52286 .65523 L .52082 .6549 L .418 0 0 r
F
.52286 .65523 m .51844 .65432 L p .52082 .6549 L F P
0 g
s
.51844 .65432 m .51875 .65284 L .56504 .66524 L p .418 0 0 r
F P
0 g
s
.56504 .66524 m .57996 .66924 L p .5707 .667 L .418 0 0 r
F P
0 g
s
.5707 .667 m .51844 .65432 L .56504 .66524 L .418 0 0 r
F
.57725 .67023 m .57996 .66924 L .52499 .65451 L p .394 0 0 r
F P
0 g
s
.57725 .67023 m .52499 .65451 L .52226 .65388 L .394 0 0 r
F
.52499 .65451 m .51875 .65284 L p .52226 .65388 L F P
0 g
s
.51875 .65284 m .51907 .65081 L .56033 .66458 L p .394 0 0 r
F P
0 g
s
.56033 .66458 m .57725 .67023 L p .56621 .66694 L .394 0 0 r
F P
0 g
s
.56621 .66694 m .51875 .65284 L .56033 .66458 L .394 0 0 r
F
.5745 .67023 m .57725 .67023 L .52695 .65344 L p .343 0 0 r
F P
0 g
s
.57169 .66907 m .5745 .67023 L .52876 .65189 L p 0 .324 .661 r
F P
0 g
s
.52876 .65189 m .5194 .64813 L p .5252 .65046 L 0 .324 .661 r
F P
0 g
s
.57169 .66907 m .52876 .65189 L .5252 .65046 L 0 .324 .661 r
F
.52695 .65344 m .51907 .65081 L p .52371 .65244 L .343 0 0 r
F P
0 g
s
.5745 .67023 m .52695 .65344 L .52371 .65244 L .343 0 0 r
F
.29943 .6068 m .30852 .59661 L .37138 .62695 L p .7 .744 .885 r
F P
0 g
s
.37758 .61947 m .37138 .62695 L .30852 .59661 L p .69 .726 .877 r
F P
0 g
s
.37758 .61947 m .38383 .61195 L .44867 .63911 L p .509 .719 .967 r
F P
0 g
s
.45195 .6348 m .44867 .63911 L .38383 .61195 L p .493 .69 .956 r
F P
0 g
s
.44867 .63911 m .45195 .6348 L .51813 .6554 L p 0 .535 .821 r
F P
0 g
s
.6652 .64467 m .6601 .65085 L .72313 .63112 L p .255 0 .035 r
F P
0 g
s
.72313 .63112 m .73061 .62201 L .6652 .64467 L p .255 0 .035 r
F P
0 g
s
.30852 .59661 m .31764 .58629 L .37758 .61947 L p .69 .726 .877 r
F P
0 g
s
.38383 .61195 m .37758 .61947 L .31764 .58629 L p .679 .707 .869 r
F P
0 g
s
.38383 .61195 m .39012 .60441 L .45195 .6348 L p .493 .69 .956 r
F P
0 g
s
.45528 .63035 m .45195 .6348 L .39012 .60441 L p .478 .661 .941 r
F P
0 g
s
.45195 .6348 m .45528 .63035 L .51844 .65432 L p 0 .522 .843 r
F P
0 g
s
.51844 .65432 m .51813 .6554 L .45195 .6348 L p 0 .522 .843 r
F P
0 g
s
.58779 .66237 m .58522 .66511 L .64967 .6632 L p .415 0 .022 r
F P
0 g
s
.64967 .6632 m .65493 .65712 L .58779 .66237 L p .415 0 .022 r
F P
0 g
s
.31764 .58629 m .32679 .57594 L .38383 .61195 L p .679 .707 .869 r
F P
0 g
s
.39012 .60441 m .38383 .61195 L .32679 .57594 L p .665 .687 .861 r
F P
0 g
s
.6601 .65085 m .65493 .65712 L .71555 .64035 L p .275 0 .048 r
F P
0 g
s
.71555 .64035 m .72313 .63112 L .6601 .65085 L p .275 0 .048 r
F P
0 g
s
.32679 .57594 m .33596 .56568 L .39012 .60441 L p .665 .687 .861 r
F P
0 g
s
.39645 .59689 m .39012 .60441 L .33596 .56568 L p .651 .666 .852 r
F P
0 g
s
.39012 .60441 m .39645 .59689 L .45528 .63035 L p .478 .661 .941 r
F P
0 g
s
.45863 .62571 m .45528 .63035 L .39645 .59689 L p .466 .631 .925 r
F P
0 g
s
.45528 .63035 m .45863 .62571 L .51875 .65284 L p .015 .515 .869 r
F P
0 g
s
.51875 .65284 m .51844 .65432 L .45528 .63035 L p .015 .515 .869 r
F P
0 g
s
.73799 .61332 m .73061 .62201 L .78517 .58934 L p 0 0 0 r
F P
0 g
s
.78517 .58934 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.58522 .66511 m .58261 .66747 L .64431 .66884 L p .426 0 .001 r
F P
0 g
s
.64431 .66884 m .64967 .6632 L .58522 .66511 L p .426 0 .001 r
F P
0 g
s
.33596 .56568 m .34514 .55563 L .39645 .59689 L p .651 .666 .852 r
F P
0 g
s
.40281 .58941 m .39645 .59689 L .34514 .55563 L p .635 .645 .843 r
F P
0 g
s
.39645 .59689 m .40281 .58941 L .45863 .62571 L p .466 .631 .925 r
F P
0 g
s
.30852 .59661 m .29943 .6068 L .24558 .56996 L p .777 .752 .831 r
F P
0 g
s
.46203 .62082 m .45863 .62571 L .40281 .58941 L p .455 .602 .907 r
F P
0 g
s
.45863 .62571 m .46203 .62082 L .51907 .65081 L p .053 .509 .891 r
F P
0 g
s
.51907 .65081 m .51875 .65284 L .45863 .62571 L p .053 .509 .891 r
F P
0 g
s
.24558 .56996 m .25736 .55765 L .30852 .59661 L p .777 .752 .831 r
F P
0 g
s
.31764 .58629 m .30852 .59661 L .25736 .55765 L p .771 .739 .823 r
F P
0 g
s
.65493 .65712 m .64967 .6632 L .70783 .6494 L p .287 0 .046 r
F P
0 g
s
.70783 .6494 m .71555 .64035 L .65493 .65712 L p .287 0 .046 r
F P
0 g
s
.34514 .55563 m .35433 .54587 L .40281 .58941 L p .635 .645 .843 r
F P
0 g
s
.40922 .58202 m .40281 .58941 L .35433 .54587 L p .618 .624 .834 r
F P
0 g
s
.40281 .58941 m .40922 .58202 L .46203 .62082 L p .455 .602 .907 r
F P
0 g
s
.25736 .55765 m .26914 .54519 L .31764 .58629 L p .771 .739 .823 r
F P
0 g
s
.32679 .57594 m .31764 .58629 L .26914 .54519 L p .763 .724 .817 r
F P
0 g
s
.73061 .62201 m .72313 .63112 L .77559 .60083 L p .003 0 0 r
F P
0 g
s
.77559 .60083 m .78517 .58934 L .73061 .62201 L p .003 0 0 r
F P
0 g
s
.26914 .54519 m .28091 .53274 L .32679 .57594 L p .763 .724 .817 r
F P
0 g
s
.33596 .56568 m .32679 .57594 L .28091 .53274 L p .752 .709 .811 r
F P
0 g
s
.58261 .66747 m .57996 .66924 L .63885 .67376 L p .43 0 0 r
F P
0 g
s
.63885 .67376 m .64431 .66884 L .58261 .66747 L p .43 0 0 r
F P
0 g
s
.46546 .61565 m .46203 .62082 L .40922 .58202 L p .446 .574 .889 r
F P
0 g
s
.46203 .62082 m .46546 .61565 L .5194 .64813 L p .101 .502 .904 r
F P
0 g
s
.5194 .64813 m .51907 .65081 L .46203 .62082 L p .101 .502 .904 r
F P
0 g
s
.28091 .53274 m .29265 .5205 L .33596 .56568 L p .752 .709 .811 r
F P
0 g
s
.34514 .55563 m .33596 .56568 L .29265 .5205 L p .74 .693 .806 r
F P
0 g
s
.35433 .54587 m .36353 .53653 L .40922 .58202 L p .618 .624 .834 r
F P
0 g
s
.41566 .57474 m .40922 .58202 L .36353 .53653 L p .601 .602 .825 r
F P
0 g
s
.40922 .58202 m .41566 .57474 L .46546 .61565 L p .446 .574 .889 r
F P
0 g
s
.29265 .5205 m .30435 .50864 L .34514 .55563 L p .74 .693 .806 r
F P
0 g
s
.35433 .54587 m .34514 .55563 L .30435 .50864 L p .726 .677 .802 r
F P
0 g
s
.30435 .50864 m .31601 .49735 L .35433 .54587 L p .726 .677 .802 r
F P
0 g
s
.36353 .53653 m .35433 .54587 L .31601 .49735 L p .71 .659 .797 r
F P
0 g
s
.36353 .53653 m .37274 .52769 L .41566 .57474 L p .601 .602 .825 r
F P
0 g
s
.42214 .56759 m .41566 .57474 L .37274 .52769 L p .583 .581 .816 r
F P
0 g
s
.41566 .57474 m .42214 .56759 L .46892 .61014 L p .439 .548 .87 r
F P
0 g
s
.46892 .61014 m .46546 .61565 L .41566 .57474 L p .439 .548 .87 r
F P
0 g
s
.64967 .6632 m .64431 .66884 L .69996 .65795 L p .292 0 .026 r
F P
0 g
s
.69996 .65795 m .70783 .6494 L .64967 .6632 L p .292 0 .026 r
F P
0 g
s
.51907 .65081 m .5194 .64813 L .5745 .67023 L p .343 0 0 r
F P
0 g
s
.46546 .61565 m .46892 .61014 L .51972 .64468 L p .15 .492 .904 r
F P
0 g
s
.51972 .64468 m .5194 .64813 L .46546 .61565 L p .15 .492 .904 r
F P
0 g
s
.72313 .63112 m .71555 .64035 L .76588 .61246 L p .018 0 0 r
F P
0 g
s
.76588 .61246 m .77559 .60083 L .72313 .63112 L p .018 0 0 r
F P
0 g
s
.31601 .49735 m .32762 .48678 L .36353 .53653 L p .71 .659 .797 r
F P
0 g
s
.37274 .52769 m .36353 .53653 L .32762 .48678 L p .692 .641 .793 r
F P
0 g
s
.57996 .66924 m .57725 .67023 L .63327 .67768 L p .425 0 0 r
F P
0 g
s
.63327 .67768 m .63885 .67376 L .57996 .66924 L p .425 0 0 r
F P
0 g
s
.32762 .48678 m .33919 .47709 L .37274 .52769 L p .692 .641 .793 r
F P
0 g
s
.38196 .51944 m .37274 .52769 L .33919 .47709 L p .673 .621 .789 r
F P
0 g
s
.37274 .52769 m .38196 .51944 L .42214 .56759 L p .583 .581 .816 r
F P
0 g
s
.42866 .56059 m .42214 .56759 L .38196 .51944 L p .565 .559 .806 r
F P
0 g
s
.42214 .56759 m .42866 .56059 L .47243 .60428 L p .433 .524 .851 r
F P
0 g
s
.47243 .60428 m .46892 .61014 L .42214 .56759 L p .433 .524 .851 r
F P
0 g
s
.33919 .47709 m .3507 .46839 L .38196 .51944 L p .673 .621 .789 r
F P
0 g
s
.39119 .51185 m .38196 .51944 L .3507 .46839 L p .652 .601 .785 r
F P
0 g
s
.38196 .51944 m .39119 .51185 L .42866 .56059 L p .565 .559 .806 r
F P
0 g
s
.46892 .61014 m .47243 .60428 L .52006 .64037 L p .198 .48 .894 r
F P
0 g
s
.52006 .64037 m .51972 .64468 L .46892 .61014 L p .198 .48 .894 r
F P
0 g
s
.5194 .64813 m .51972 .64468 L .57169 .66907 L p 0 .324 .661 r
F P
0 g
s
.43522 .55377 m .42866 .56059 L .39119 .51185 L p .547 .539 .797 r
F P
0 g
s
.42866 .56059 m .43522 .55377 L .47597 .59802 L p .428 .503 .834 r
F P
0 g
s
.47597 .59802 m .47243 .60428 L .42866 .56059 L p .428 .503 .834 r
F P
0 g
s
.64431 .66884 m .63885 .67376 L .69193 .66569 L p .29 0 0 r
F P
0 g
s
.69193 .66569 m .69996 .65795 L .64431 .66884 L p .29 0 0 r
F P
0 g
s
.3507 .46839 m .36217 .46082 L .39119 .51185 L p .652 .601 .785 r
F P
0 g
s
.40043 .50498 m .39119 .51185 L .36217 .46082 L p .63 .581 .781 r
F P
0 g
s
.39119 .51185 m .40043 .50498 L .43522 .55377 L p .547 .539 .797 r
F P
0 g
s
.79464 .57831 m .78517 .58934 L .82503 .5479 L p 0 0 0 r
F P
0 g
s
.8137 .56112 m .82503 .5479 L .78517 .58934 L p 0 0 0 r
F P
0 g
s
.82503 .5479 m .8137 .56112 L .81395 .56055 L p .848 .987 .712 r
F P
0 g
s
.83578 .53563 m .79464 .57831 L p .82503 .5479 L 0 0 0 r
F P
0 g
s
.81395 .56055 m .83398 .51385 L p .82503 .5479 L .848 .987 .712 r
F P
0 g
s
.82503 .5479 m .83625 .53514 L .83578 .53563 L p 0 0 0 r
F P
0 g
s
.71555 .64035 m .70783 .6494 L .756 .62392 L p .02 0 0 r
F P
0 g
s
.756 .62392 m .76588 .61246 L .71555 .64035 L p .02 0 0 r
F P
0 g
s
.57725 .67023 m .5745 .67023 L .5989 .67489 L p .407 0 0 r
F P
0 g
s
.62177 .68156 m .62758 .68036 L .5745 .67023 L p .364 0 0 r
F P
0 g
s
.5745 .67023 m .57169 .66907 L .59067 .6738 L p .364 0 0 r
F P
0 g
s
.59067 .6738 m .62177 .68156 L p .59047 .67406 L .364 0 0 r
F P
0 g
s
.59047 .67406 m .5745 .67023 L .59067 .6738 L .364 0 0 r
F
.61584 .68107 m .62177 .68156 L .5915 .67401 L p .281 0 0 r
F P
0 g
s
.6098 .67872 m .61584 .68107 L .59098 .67342 L p 0 .424 .739 r
F P
0 g
s
.60252 .67531 m .57725 .67023 L .5989 .67489 L .407 0 0 r
F
.62758 .68036 m .63327 .67768 L .57725 .67023 L p F P
0 g
s
.59098 .67342 m .56883 .66659 L p .59116 .6732 L 0 .424 .739 r
F P
0 g
s
.6098 .67872 m .59098 .67342 L .59116 .6732 L 0 .424 .739 r
F
.5915 .67401 m .57169 .66907 L p .58861 .67367 L .281 0 0 r
F P
0 g
s
.61584 .68107 m .5915 .67401 L .58861 .67367 L .281 0 0 r
F
.5989 .67489 m .62758 .68036 L p .60252 .67531 L .407 0 0 r
F P
0 g
s
.47243 .60428 m .47597 .59802 L .52039 .63511 L p .24 .468 .877 r
F P
0 g
s
.52039 .63511 m .52006 .64037 L .47243 .60428 L p .24 .468 .877 r
F P
0 g
s
.36217 .46082 m .37361 .45445 L .40043 .50498 L p .63 .581 .781 r
F P
0 g
s
.4097 .49887 m .40043 .50498 L .37361 .45445 L p .607 .56 .776 r
F P
0 g
s
.40043 .50498 m .4097 .49887 L .44182 .54713 L p .53 .519 .788 r
F P
0 g
s
.44182 .54713 m .43522 .55377 L .40043 .50498 L p .53 .519 .788 r
F P
0 g
s
.27682 .45841 m .29038 .44645 L .31601 .49735 L p .795 .729 .791 r
F P
0 g
s
.31601 .49735 m .30435 .50864 L .27682 .45841 L p .795 .729 .791 r
F P
0 g
s
.32762 .48678 m .31601 .49735 L .29038 .44645 L p .78 .713 .789 r
F P
0 g
s
.29038 .44645 m .30381 .4355 L .32762 .48678 L p .78 .713 .789 r
F P
0 g
s
.33919 .47709 m .32762 .48678 L .30381 .4355 L p .762 .695 .788 r
F P
0 g
s
.43522 .55377 m .44182 .54713 L .47955 .59134 L p .425 .484 .817 r
F P
0 g
s
.47955 .59134 m .47597 .59802 L .43522 .55377 L p .425 .484 .817 r
F P
0 g
s
.26315 .47115 m .27682 .45841 L .30435 .50864 L p .808 .745 .793 r
F P
0 g
s
.30435 .50864 m .29265 .5205 L .26315 .47115 L p .808 .745 .793 r
F P
0 g
s
.30381 .4355 m .31712 .42574 L .33919 .47709 L p .762 .695 .788 r
F P
0 g
s
.3507 .46839 m .33919 .47709 L .31712 .42574 L p .741 .675 .787 r
F P
0 g
s
.24937 .48445 m .26315 .47115 L .29265 .5205 L p .819 .758 .796 r
F P
0 g
s
.29265 .5205 m .28091 .53274 L .24937 .48445 L p .819 .758 .796 r
F P
0 g
s
.31712 .42574 m .33031 .41732 L .3507 .46839 L p .741 .675 .787 r
F P
0 g
s
.36217 .46082 m .3507 .46839 L .33031 .41732 L p .718 .654 .785 r
F P
0 g
s
.23551 .49808 m .24937 .48445 L .28091 .53274 L p .827 .771 .799 r
F P
0 g
s
.28091 .53274 m .26914 .54519 L .23551 .49808 L p .827 .771 .799 r
F P
0 g
s
.51972 .64468 m .52006 .64037 L .56883 .66659 L p 0 .384 .78 r
F P
0 g
s
.56883 .66659 m .57169 .66907 L .51972 .64468 L p 0 .384 .78 r
F P
0 g
s
.22157 .51179 m .23551 .49808 L .26914 .54519 L p .833 .782 .804 r
F P
0 g
s
.26914 .54519 m .25736 .55765 L .22157 .51179 L p .833 .782 .804 r
F P
0 g
s
.33031 .41732 m .3434 .41041 L .36217 .46082 L p .718 .654 .785 r
F P
0 g
s
.37361 .45445 m .36217 .46082 L .3434 .41041 L p .693 .631 .783 r
F P
0 g
s
.20758 .52532 m .22157 .51179 L .25736 .55765 L p .836 .793 .811 r
F P
0 g
s
.25736 .55765 m .24558 .56996 L .20758 .52532 L p .836 .793 .811 r
F P
0 g
s
.37361 .45445 m .38502 .44936 L .4097 .49887 L p .607 .56 .776 r
F P
0 g
s
.41899 .49355 m .4097 .49887 L .38502 .44936 L p .583 .539 .771 r
F P
0 g
s
.4097 .49887 m .41899 .49355 L .44847 .54069 L p .513 .5 .779 r
F P
0 g
s
.44847 .54069 m .44182 .54713 L .4097 .49887 L p .513 .5 .779 r
F P
0 g
s
.3434 .41041 m .35638 .4051 L .37361 .45445 L p .693 .631 .783 r
F P
0 g
s
.38502 .44936 m .37361 .45445 L .35638 .4051 L p .665 .607 .78 r
F P
0 g
s
.44182 .54713 m .44847 .54069 L .48316 .58423 L p .422 .467 .802 r
F P
0 g
s
.48316 .58423 m .47955 .59134 L .44182 .54713 L p .422 .467 .802 r
F P
0 g
s
.47597 .59802 m .47955 .59134 L .52074 .62884 L p .275 .455 .857 r
F P
0 g
s
.52074 .62884 m .52039 .63511 L .47597 .59802 L p .275 .455 .857 r
F P
0 g
s
.63885 .67376 m .63327 .67768 L .68373 .67229 L p .278 0 0 r
F P
0 g
s
.68373 .67229 m .69193 .66569 L .63885 .67376 L p .278 0 0 r
F P
0 g
s
.78517 .58934 m .77559 .60083 L .8137 .56112 L p 0 0 0 r
F P
0 g
s
.35638 .4051 m .36928 .40149 L .38502 .44936 L p .665 .607 .78 r
F P
0 g
s
.39642 .44559 m .38502 .44936 L .36928 .40149 L p .637 .582 .776 r
F P
0 g
s
.38502 .44936 m .39642 .44559 L .41899 .49355 L p .583 .539 .771 r
F P
0 g
s
.70783 .6494 m .69996 .65795 L .74595 .63485 L p .011 0 0 r
F P
0 g
s
.74595 .63485 m .756 .62392 L .70783 .6494 L p .011 0 0 r
F P
0 g
s
.42831 .48904 m .41899 .49355 L .39642 .44559 L p .56 .518 .766 r
F P
0 g
s
.41899 .49355 m .42831 .48904 L .45516 .53445 L p .497 .483 .771 r
F P
0 g
s
.45516 .53445 m .44847 .54069 L .41899 .49355 L p .497 .483 .771 r
F P
0 g
s
.52006 .64037 m .52039 .63511 L .56593 .66267 L p 0 .425 .854 r
F P
0 g
s
.56593 .66267 m .56883 .66659 L .52006 .64037 L p 0 .425 .854 r
F P
0 g
s
.36928 .40149 m .38211 .39962 L .39642 .44559 L p .637 .582 .776 r
F P
0 g
s
.40781 .44317 m .39642 .44559 L .38211 .39962 L p .607 .556 .772 r
F P
0 g
s
.39642 .44559 m .40781 .44317 L .42831 .48904 L p .56 .518 .766 r
F P
0 g
s
.44847 .54069 m .45516 .53445 L .48682 .57667 L p .42 .452 .788 r
F P
0 g
s
.48682 .57667 m .48316 .58423 L .44847 .54069 L p .42 .452 .788 r
F P
0 g
s
.47955 .59134 m .48316 .58423 L .52108 .62151 L p .305 .443 .836 r
F P
0 g
s
.52108 .62151 m .52074 .62884 L .47955 .59134 L p .305 .443 .836 r
F P
0 g
s
.43767 .48534 m .42831 .48904 L .40781 .44317 L p .536 .497 .76 r
F P
0 g
s
.42831 .48904 m .43767 .48534 L .4619 .5284 L p .483 .466 .763 r
F P
0 g
s
.4619 .5284 m .45516 .53445 L .42831 .48904 L p .483 .466 .763 r
F P
0 g
s
.38211 .39962 m .3949 .39954 L .40781 .44317 L p .607 .556 .772 r
F P
0 g
s
.41923 .44209 m .40781 .44317 L .3949 .39954 L p .577 .531 .767 r
F P
0 g
s
.40781 .44317 m .41923 .44209 L .43767 .48534 L p .536 .497 .76 r
F P
0 g
s
.33622 .36362 m .34995 .35987 L .35638 .4051 L p .742 .694 .805 r
F P
0 g
s
.35638 .4051 m .3434 .41041 L .33622 .36362 L p .742 .694 .805 r
F P
0 g
s
.36928 .40149 m .35638 .4051 L .34995 .35987 L p .709 .663 .802 r
F P
0 g
s
.32232 .36926 m .33622 .36362 L .3434 .41041 L p .772 .722 .806 r
F P
0 g
s
.3434 .41041 m .33031 .41732 L .32232 .36926 L p .772 .722 .806 r
F P
0 g
s
.34995 .35987 m .36355 .35811 L .36928 .40149 L p .709 .663 .802 r
F P
0 g
s
.38211 .39962 m .36928 .40149 L .36355 .35811 L p .675 .631 .798 r
F P
0 g
s
.30825 .37667 m .32232 .36926 L .33031 .41732 L p .798 .747 .806 r
F P
0 g
s
.33031 .41732 m .31712 .42574 L .30825 .37667 L p .798 .747 .806 r
F P
0 g
s
.57169 .66907 m .56883 .66659 L .61584 .68107 L p .281 0 0 r
F P
0 g
s
.63327 .67768 m .62758 .68036 L .67535 .67746 L p .252 0 0 r
F P
0 g
s
.67535 .67746 m .68373 .67229 L .63327 .67768 L p .252 0 0 r
F P
0 g
s
.77559 .60083 m .76588 .61246 L .80224 .57449 L p 0 0 0 r
F P
0 g
s
.80224 .57449 m .8137 .56112 L .77559 .60083 L p 0 0 0 r
F P
0 g
s
.52039 .63511 m .52074 .62884 L .56297 .6572 L p .096 .443 .879 r
F P
0 g
s
.56297 .6572 m .56593 .66267 L .52039 .63511 L p .096 .443 .879 r
F P
0 g
s
.29399 .3857 m .30825 .37667 L .31712 .42574 L p .821 .77 .805 r
F P
0 g
s
.31712 .42574 m .30381 .4355 L .29399 .3857 L p .821 .77 .805 r
F P
0 g
s
.45516 .53445 m .4619 .5284 L .4905 .56867 L p .418 .44 .776 r
F P
0 g
s
.4905 .56867 m .48682 .57667 L .45516 .53445 L p .418 .44 .776 r
F P
0 g
s
.36355 .35811 m .37703 .35841 L .38211 .39962 L p .675 .631 .798 r
F P
0 g
s
.3949 .39954 m .38211 .39962 L .37703 .35841 L p .639 .598 .792 r
F P
0 g
s
.3949 .39954 m .40766 .40123 L .41923 .44209 L p .577 .531 .767 r
F P
0 g
s
.43067 .44233 m .41923 .44209 L .40766 .40123 L p .548 .506 .761 r
F P
0 g
s
.41923 .44209 m .43067 .44233 L .44709 .48243 L p .514 .478 .754 r
F P
0 g
s
.44709 .48243 m .43767 .48534 L .41923 .44209 L p .514 .478 .754 r
F P
0 g
s
.43767 .48534 m .44709 .48243 L .4687 .52256 L p .469 .451 .756 r
F P
0 g
s
.4687 .52256 m .4619 .5284 L .43767 .48534 L p .469 .451 .756 r
F P
0 g
s
.48316 .58423 m .48682 .57667 L .52143 .61311 L p .329 .433 .816 r
F P
0 g
s
.52143 .61311 m .52108 .62151 L .48316 .58423 L p .329 .433 .816 r
F P
0 g
s
.69996 .65795 m .69193 .66569 L .73569 .64492 L p 0 0 0 r
F P
0 g
s
.73569 .64492 m .74595 .63485 L .69996 .65795 L p 0 0 0 r
F P
0 g
s
.27953 .39614 m .29399 .3857 L .30381 .4355 L p .84 .79 .803 r
F P
0 g
s
.30381 .4355 m .29038 .44645 L .27953 .39614 L p .84 .79 .803 r
F P
0 g
s
.37703 .35841 m .39042 .3608 L .3949 .39954 L p .639 .598 .792 r
F P
0 g
s
.40766 .40123 m .3949 .39954 L .39042 .3608 L p .603 .565 .784 r
F P
0 g
s
.26488 .40779 m .27953 .39614 L .29038 .44645 L p .855 .807 .802 r
F P
0 g
s
.29038 .44645 m .27682 .45841 L .26488 .40779 L p .855 .807 .802 r
F P
0 g
s
.39042 .3608 m .40374 .36525 L .40766 .40123 L p .603 .565 .784 r
F P
0 g
s
.42043 .40466 m .40766 .40123 L .40374 .36525 L p .568 .533 .776 r
F P
0 g
s
.40766 .40123 m .42043 .40466 L .43067 .44233 L p .548 .506 .761 r
F P
0 g
s
.4619 .5284 m .4687 .52256 L .49422 .56024 L p .416 .429 .765 r
F P
0 g
s
.49422 .56024 m .4905 .56867 L .4619 .5284 L p .416 .429 .765 r
F P
0 g
s
.44215 .44383 m .43067 .44233 L .42043 .40466 L p .52 .482 .755 r
F P
0 g
s
.43067 .44233 m .44215 .44383 L .45655 .48028 L p .493 .459 .749 r
F P
0 g
s
.45655 .48028 m .44709 .48243 L .43067 .44233 L p .493 .459 .749 r
F P
0 g
s
.52074 .62884 m .52108 .62151 L .55997 .6501 L p .184 .444 .872 r
F P
0 g
s
.55997 .6501 m .56297 .6572 L .52074 .62884 L p .184 .444 .872 r
F P
0 g
s
.56883 .66659 m .56593 .66267 L .6098 .67872 L p 0 .424 .739 r
F P
0 g
s
.44709 .48243 m .45655 .48028 L .47554 .51689 L p .456 .438 .749 r
F P
0 g
s
.47554 .51689 m .4687 .52256 L .44709 .48243 L p .456 .438 .749 r
F P
0 g
s
.25004 .42041 m .26488 .40779 L .27682 .45841 L p .867 .822 .801 r
F P
0 g
s
.27682 .45841 m .26315 .47115 L .25004 .42041 L p .867 .822 .801 r
F P
0 g
s
.48682 .57667 m .4905 .56867 L .52179 .60363 L p .349 .424 .798 r
F P
0 g
s
.52179 .60363 m .52143 .61311 L .48682 .57667 L p .349 .424 .798 r
F P
0 g
s
.62758 .68036 m .62177 .68156 L .6668 .68092 L p .203 0 0 r
F P
0 g
s
.6668 .68092 m .67535 .67746 L .62758 .68036 L p .203 0 0 r
F P
0 g
s
.76588 .61246 m .756 .62392 L .79061 .58767 L p 0 0 0 r
F P
0 g
s
.79061 .58767 m .80224 .57449 L .76588 .61246 L p 0 0 0 r
F P
0 g
s
.40374 .36525 m .41702 .37174 L .42043 .40466 L p .568 .533 .776 r
F P
0 g
s
.43321 .40976 m .42043 .40466 L .41702 .37174 L p .534 .502 .767 r
F P
0 g
s
.42043 .40466 m .43321 .40976 L .44215 .44383 L p .52 .482 .755 r
F P
0 g
s
.23503 .43372 m .25004 .42041 L .26315 .47115 L p .876 .834 .801 r
F P
0 g
s
.26315 .47115 m .24937 .48445 L .23503 .43372 L p .876 .834 .801 r
F P
0 g
s
.36845 .32201 m .38169 .32458 L .37703 .35841 L p .692 .685 .838 r
F P
0 g
s
.37703 .35841 m .36355 .35811 L .36845 .32201 L p .692 .685 .838 r
F P
0 g
s
.39042 .3608 m .37703 .35841 L .38169 .32458 L p .649 .639 .827 r
F P
0 g
s
.35505 .32165 m .36845 .32201 L .36355 .35811 L p .734 .729 .847 r
F P
0 g
s
.36355 .35811 m .34995 .35987 L .35505 .32165 L p .734 .729 .847 r
F P
0 g
s
.38169 .32458 m .3948 .32939 L .39042 .3608 L p .649 .639 .827 r
F P
0 g
s
.40374 .36525 m .39042 .3608 L .3948 .32939 L p .608 .595 .813 r
F P
0 g
s
.4687 .52256 m .47554 .51689 L .49798 .55139 L p .415 .419 .756 r
F P
0 g
s
.49798 .55139 m .49422 .56024 L .4687 .52256 L p .415 .419 .756 r
F P
0 g
s
.69193 .66569 m .68373 .67229 L .72522 .65378 L p 0 0 0 r
F P
0 g
s
.72522 .65378 m .73569 .64492 L .69193 .66569 L p 0 0 0 r
F P
0 g
s
.45371 .44651 m .44215 .44383 L .43321 .40976 L p .494 .46 .748 r
F P
0 g
s
.44215 .44383 m .45371 .44651 L .46609 .47883 L p .473 .443 .743 r
F P
0 g
s
.46609 .47883 m .45655 .48028 L .44215 .44383 L p .473 .443 .743 r
F P
0 g
s
.34147 .32344 m .35505 .32165 L .34995 .35987 L p .773 .771 .851 r
F P
0 g
s
.34995 .35987 m .33622 .36362 L .34147 .32344 L p .773 .771 .851 r
F P
0 g
s
.45655 .48028 m .46609 .47883 L .48244 .51139 L p .445 .425 .743 r
F P
0 g
s
.48244 .51139 m .47554 .51689 L .45655 .48028 L p .445 .425 .743 r
F P
0 g
s
.52108 .62151 m .52143 .61311 L .55693 .64135 L p .249 .439 .852 r
F P
0 g
s
.55693 .64135 m .55997 .6501 L .52108 .62151 L p .249 .439 .852 r
F P
0 g
s
.3948 .32939 m .40782 .33644 L .40374 .36525 L p .608 .595 .813 r
F P
0 g
s
.41702 .37174 m .40374 .36525 L .40782 .33644 L p .568 .554 .798 r
F P
0 g
s
.4905 .56867 m .49422 .56024 L .52215 .59311 L p .365 .416 .782 r
F P
0 g
s
.52215 .59311 m .52179 .60363 L .4905 .56867 L p .365 .416 .782 r
F P
0 g
s
.32769 .32729 m .34147 .32344 L .33622 .36362 L p .808 .81 .852 r
F P
0 g
s
.33622 .36362 m .32232 .36926 L .32769 .32729 L p .808 .81 .852 r
F P
0 g
s
.41702 .37174 m .4303 .38019 L .43321 .40976 L p .534 .502 .767 r
F P
0 g
s
.44604 .41644 m .43321 .40976 L .4303 .38019 L p .504 .474 .757 r
F P
0 g
s
.43321 .40976 m .44604 .41644 L .45371 .44651 L p .494 .46 .748 r
F P
0 g
s
.21985 .44747 m .23503 .43372 L .24937 .48445 L p .882 .845 .803 r
F P
0 g
s
.24937 .48445 m .23551 .49808 L .21985 .44747 L p .882 .845 .803 r
F P
0 g
s
.56593 .66267 m .56297 .6572 L .60365 .67436 L p .008 .488 .87 r
F P
0 g
s
.60365 .67436 m .6098 .67872 L .56593 .66267 L p .008 .488 .87 r
F P
0 g
s
.40782 .33644 m .42076 .34567 L .41702 .37174 L p .568 .554 .798 r
F P
0 g
s
.4303 .38019 m .41702 .37174 L .42076 .34567 L p .532 .516 .784 r
F P
0 g
s
.31369 .33305 m .32769 .32729 L .32232 .36926 L p .838 .843 .849 r
F P
0 g
s
.32232 .36926 m .30825 .37667 L .31369 .33305 L p .838 .843 .849 r
F P
0 g
s
.83625 .53514 m .82503 .5479 L .84656 .49963 L p .841 .987 .716 r
F P
0 g
s
.84656 .49963 m .85906 .48583 L .83625 .53514 L p .841 .987 .716 r
F P
0 g
s
.65806 .68243 m .6668 .68092 L .62177 .68156 L p .118 0 0 r
F P
0 g
s
.62177 .68156 m .61584 .68107 L .65806 .68243 L p .118 0 0 r
F P
0 g
s
.47554 .51689 m .48244 .51139 L .50176 .54214 L p .414 .411 .747 r
F P
0 g
s
.50176 .54214 m .49798 .55139 L .47554 .51689 L p .414 .411 .747 r
F P
0 g
s
.20453 .46135 m .21985 .44747 L .23551 .49808 L p .885 .854 .806 r
F P
0 g
s
.23551 .49808 m .22157 .51179 L .20453 .46135 L p .885 .854 .806 r
F P
0 g
s
.46533 .45029 m .45371 .44651 L .44604 .41644 L p .471 .44 .742 r
F P
0 g
s
.45371 .44651 m .46533 .45029 L .4757 .47803 L p .456 .427 .738 r
F P
0 g
s
.4757 .47803 m .46609 .47883 L .45371 .44651 L p .456 .427 .738 r
F P
0 g
s
.52143 .61311 m .52179 .60363 L .55385 .63096 L p .296 .43 .828 r
F P
0 g
s
.55385 .63096 m .55693 .64135 L .52143 .61311 L p .296 .43 .828 r
F P
0 g
s
.756 .62392 m .74595 .63485 L .77879 .60032 L p 0 0 0 r
F P
0 g
s
.77879 .60032 m .79061 .58767 L .756 .62392 L p 0 0 0 r
F P
0 g
s
.46609 .47883 m .4757 .47803 L .4894 .50603 L p .435 .415 .738 r
F P
0 g
s
.4894 .50603 m .48244 .51139 L .46609 .47883 L p .435 .415 .738 r
F P
0 g
s
.49422 .56024 m .49798 .55139 L .52251 .58158 L p .377 .41 .768 r
F P
0 g
s
.52251 .58158 m .52215 .59311 L .49422 .56024 L p .377 .41 .768 r
F P
0 g
s
.4303 .38019 m .44359 .39048 L .44604 .41644 L p .504 .474 .757 r
F P
0 g
s
.45894 .42456 m .44604 .41644 L .44359 .39048 L p .477 .45 .749 r
F P
0 g
s
.44604 .41644 m .45894 .42456 L .46533 .45029 L p .471 .44 .742 r
F P
0 g
s
.42076 .34567 m .43366 .35701 L .4303 .38019 L p .532 .516 .784 r
F P
0 g
s
.44359 .39048 m .4303 .38019 L .43366 .35701 L p .501 .483 .77 r
F P
0 g
s
.29944 .34057 m .31369 .33305 L .30825 .37667 L p .862 .871 .843 r
F P
0 g
s
.30825 .37667 m .29399 .3857 L .29944 .34057 L p .862 .871 .843 r
F P
0 g
s
.68373 .67229 m .67535 .67746 L .71453 .66111 L p 0 0 0 r
F P
0 g
s
.71453 .66111 m .72522 .65378 L .68373 .67229 L p 0 0 0 r
F P
0 g
s
.18911 .47507 m .20453 .46135 L .22157 .51179 L p .885 .861 .812 r
F P
0 g
s
.22157 .51179 m .20758 .52532 L .18911 .47507 L p .885 .861 .812 r
F P
0 g
s
.56297 .6572 m .55997 .6501 L .5974 .66792 L p .142 .504 .91 r
F P
0 g
s
.5974 .66792 m .60365 .67436 L .56297 .6572 L p .142 .504 .91 r
F P
0 g
s
.48244 .51139 m .4894 .50603 L .50558 .53253 L p .413 .405 .741 r
F P
0 g
s
.50558 .53253 m .50176 .54214 L .48244 .51139 L p .413 .405 .741 r
F P
0 g
s
.43366 .35701 m .44656 .37032 L .44359 .39048 L p .501 .483 .77 r
F P
0 g
s
.45694 .40247 m .44359 .39048 L .44656 .37032 L p .474 .455 .757 r
F P
0 g
s
.44359 .39048 m .45694 .40247 L .45894 .42456 L p .477 .45 .749 r
F P
0 g
s
.39609 .30047 m .40802 .3075 L .3948 .32939 L p .624 .671 .875 r
F P
0 g
s
.3948 .32939 m .38169 .32458 L .39609 .30047 L p .624 .671 .875 r
F P
0 g
s
.40782 .33644 m .3948 .32939 L .40802 .3075 L p .581 .614 .85 r
F P
0 g
s
.40802 .3075 m .41982 .31677 L .40782 .33644 L p .581 .614 .85 r
F P
0 g
s
.42076 .34567 m .40782 .33644 L .41982 .31677 L p .543 .563 .825 r
F P
0 g
s
.47706 .45502 m .46533 .45029 L .45894 .42456 L p .451 .423 .736 r
F P
0 g
s
.46533 .45029 m .47706 .45502 L .48539 .47778 L p .441 .414 .734 r
F P
0 g
s
.48539 .47778 m .4757 .47803 L .46533 .45029 L p .441 .414 .734 r
F P
0 g
s
.28496 .34964 m .29944 .34057 L .29399 .3857 L p .881 .893 .836 r
F P
0 g
s
.29399 .3857 m .27953 .39614 L .28496 .34964 L p .881 .893 .836 r
F P
0 g
s
.52179 .60363 m .52215 .59311 L .55074 .61895 L p .33 .422 .805 r
F P
0 g
s
.55074 .61895 m .55385 .63096 L .52179 .60363 L p .33 .422 .805 r
F P
0 g
s
.38402 .29568 m .39609 .30047 L .38169 .32458 L p .669 .733 .898 r
F P
0 g
s
.38169 .32458 m .36845 .32201 L .38402 .29568 L p .669 .733 .898 r
F P
0 g
s
.49798 .55139 m .50176 .54214 L .52287 .56911 L p .387 .404 .756 r
F P
0 g
s
.52287 .56911 m .52251 .58158 L .49798 .55139 L p .387 .404 .756 r
F P
0 g
s
.83398 .51385 m .84656 .49963 L .82503 .5479 L p .848 .987 .712 r
F P
0 g
s
.61584 .68107 m .6098 .67872 L .64915 .68178 L p .013 .586 .752 r
F P
0 g
s
.64915 .68178 m .65806 .68243 L .61584 .68107 L p .013 .586 .752 r
F P
0 g
s
.47193 .43397 m .45894 .42456 L .45694 .40247 L p .455 .429 .741 r
F P
0 g
s
.45894 .42456 m .47193 .43397 L .47706 .45502 L p .451 .423 .736 r
F P
0 g
s
.41982 .31677 m .43154 .32823 L .42076 .34567 L p .543 .563 .825 r
F P
0 g
s
.43366 .35701 m .42076 .34567 L .43154 .32823 L p .51 .519 .802 r
F P
0 g
s
.4757 .47803 m .48539 .47778 L .49641 .5008 L p .427 .406 .733 r
F P
0 g
s
.49641 .5008 m .4894 .50603 L .4757 .47803 L p .427 .406 .733 r
F P
0 g
s
.37178 .29313 m .38402 .29568 L .36845 .32201 L p .715 .797 .915 r
F P
0 g
s
.36845 .32201 m .35505 .32165 L .37178 .29313 L p .715 .797 .915 r
F P
0 g
s
.43154 .32823 m .4432 .34178 L .43366 .35701 L p .51 .519 .802 r
F P
0 g
s
.44656 .37032 m .43366 .35701 L .4432 .34178 L p .482 .483 .782 r
F P
0 g
s
.55997 .6501 m .55693 .64135 L .59106 .65935 L p .235 .492 .895 r
F P
0 g
s
.59106 .65935 m .5974 .66792 L .55997 .6501 L p .235 .492 .895 r
F P
0 g
s
.74595 .63485 m .73569 .64492 L .76676 .6121 L p .548 .853 .543 r
F P
0 g
s
.76676 .6121 m .77879 .60032 L .74595 .63485 L p .548 .853 .543 r
F P
0 g
s
.44656 .37032 m .45947 .38546 L .45694 .40247 L p .474 .455 .757 r
F P
0 g
s
.47035 .41598 m .45694 .40247 L .45947 .38546 L p .452 .432 .746 r
F P
0 g
s
.45694 .40247 m .47035 .41598 L .47193 .43397 L p .455 .429 .741 r
F P
0 g
s
.35934 .29273 m .37178 .29313 L .35505 .32165 L p .757 .857 .924 r
F P
0 g
s
.35505 .32165 m .34147 .32344 L .35934 .29273 L p .757 .857 .924 r
F P
0 g
s
.27022 .36003 m .28496 .34964 L .27953 .39614 L p .894 .91 .828 r
F P
0 g
s
.27953 .39614 m .26488 .40779 L .27022 .36003 L p .894 .91 .828 r
F P
0 g
s
.4894 .50603 m .49641 .5008 L .50943 .52259 L p .413 .399 .735 r
F P
0 g
s
.50943 .52259 m .50558 .53253 L .4894 .50603 L p .413 .399 .735 r
F P
0 g
s
.52215 .59311 m .52251 .58158 L .5476 .60542 L p .355 .414 .785 r
F P
0 g
s
.5476 .60542 m .55074 .61895 L .52215 .59311 L p .355 .414 .785 r
F P
0 g
s
.67535 .67746 m .6668 .68092 L .70361 .6666 L p 0 0 0 r
F P
0 g
s
.70361 .6666 m .71453 .66111 L .67535 .67746 L p 0 0 0 r
F P
0 g
s
.50176 .54214 m .50558 .53253 L .52324 .55579 L p .395 .4 .746 r
F P
0 g
s
.52324 .55579 m .52287 .56911 L .50176 .54214 L p .395 .4 .746 r
F P
0 g
s
.4432 .34178 m .45483 .35732 L .44656 .37032 L p .482 .483 .782 r
F P
0 g
s
.45947 .38546 m .44656 .37032 L .45483 .35732 L p .46 .453 .764 r
F P
0 g
s
.48888 .46058 m .47706 .45502 L .47193 .43397 L p .434 .409 .731 r
F P
0 g
s
.47706 .45502 m .48888 .46058 L .49517 .47801 L p .428 .404 .73 r
F P
0 g
s
.49517 .47801 m .48539 .47778 L .47706 .45502 L p .428 .404 .73 r
F P
0 g
s
.48503 .44449 m .47193 .43397 L .47035 .41598 L p .436 .412 .734 r
F P
0 g
s
.47193 .43397 m .48503 .44449 L .48888 .46058 L p .434 .409 .731 r
F P
0 g
s
.48539 .47778 m .49517 .47801 L .50349 .49566 L p .42 .399 .729 r
F P
0 g
s
.50349 .49566 m .49641 .5008 L .48539 .47778 L p .42 .399 .729 r
F P
0 g
s
.6098 .67872 m .60365 .67436 L .64008 .6788 L p .16 .651 .918 r
F P
0 g
s
.64008 .6788 m .64915 .68178 L .6098 .67872 L p .16 .651 .918 r
F P
0 g
s
.34669 .2944 m .35934 .29273 L .34147 .32344 L p .792 .908 .921 r
F P
0 g
s
.34147 .32344 m .32769 .32729 L .34669 .2944 L p .792 .908 .921 r
F P
0 g
s
.8137 .56112 m .80224 .57449 L .82129 .52819 L p .859 .988 .72 r
F P
0 g
s
.82129 .52819 m .83398 .51385 L .8137 .56112 L p .859 .988 .72 r
F P
0 g
s
.55693 .64135 m .55385 .63096 L .58464 .64865 L p .296 .472 .864 r
F P
0 g
s
.58464 .64865 m .59106 .65935 L .55693 .64135 L p .296 .472 .864 r
F P
0 g
s
.45483 .35732 m .46645 .37467 L .45947 .38546 L p .46 .453 .764 r
F P
0 g
s
.47243 .40222 m .45947 .38546 L .46645 .37467 L p .442 .43 .75 r
F P
0 g
s
.45947 .38546 m .47243 .40222 L .47035 .41598 L p .452 .432 .746 r
F P
0 g
s
.48386 .43079 m .47035 .41598 L .47243 .40222 L p .434 .414 .737 r
F P
0 g
s
.47035 .41598 m .48386 .43079 L .48503 .44449 L p .436 .412 .734 r
F P
0 g
s
.52251 .58158 m .52287 .56911 L .54443 .59046 L p .373 .407 .768 r
F P
0 g
s
.54443 .59046 m .5476 .60542 L .52251 .58158 L p .373 .407 .768 r
F P
0 g
s
.25524 .3715 m .27022 .36003 L .26488 .40779 L p .903 .923 .822 r
F P
0 g
s
.26488 .40779 m .25004 .42041 L .25524 .3715 L p .903 .923 .822 r
F P
0 g
s
.50558 .53253 m .50943 .52259 L .52361 .54172 L p .401 .396 .739 r
F P
0 g
s
.52361 .54172 m .52324 .55579 L .50558 .53253 L p .401 .396 .739 r
F P
0 g
s
.49641 .5008 m .50349 .49566 L .51331 .51236 L p .412 .395 .73 r
F P
0 g
s
.51331 .51236 m .50943 .52259 L .49641 .5008 L p .412 .395 .73 r
F P
0 g
s
.43922 .30778 m .44886 .32076 L .43154 .32823 L p .488 .55 .846 r
F P
0 g
s
.43154 .32823 m .41982 .31677 L .43922 .30778 L p .488 .55 .846 r
F P
0 g
s
.4432 .34178 m .43154 .32823 L .44886 .32076 L p .467 .506 .815 r
F P
0 g
s
.73569 .64492 m .72522 .65378 L .75451 .62267 L p .607 .909 .638 r
F P
0 g
s
.75451 .62267 m .76676 .6121 L .73569 .64492 L p .607 .909 .638 r
F P
0 g
s
.42948 .29684 m .43922 .30778 L .41982 .31677 L p .513 .604 .881 r
F P
0 g
s
.41982 .31677 m .40802 .3075 L .42948 .29684 L p .513 .604 .881 r
F P
0 g
s
.3338 .298 m .34669 .2944 L .32769 .32729 L p .816 .948 .908 r
F P
0 g
s
.32769 .32729 m .31369 .33305 L .3338 .298 L p .816 .948 .908 r
F P
0 g
s
.44886 .32076 m .45844 .33569 L .4432 .34178 L p .467 .506 .815 r
F P
0 g
s
.45483 .35732 m .4432 .34178 L .45844 .33569 L p .45 .471 .789 r
F P
0 g
s
.50083 .4668 m .48888 .46058 L .48503 .44449 L p .422 .398 .727 r
F P
0 g
s
.48888 .46058 m .50083 .4668 L .50505 .47861 L p .419 .396 .727 r
F P
0 g
s
.50505 .47861 m .49517 .47801 L .48888 .46058 L p .419 .396 .727 r
F P
0 g
s
.55385 .63096 m .55074 .61895 L .57815 .63589 L p .335 .452 .832 r
F P
0 g
s
.57815 .63589 m .58464 .64865 L .55385 .63096 L p .335 .452 .832 r
F P
0 g
s
.6668 .68092 m .65806 .68243 L .69248 .67 L p .321 .803 .754 r
F P
0 g
s
.69248 .67 m .70361 .6666 L .6668 .68092 L p .321 .803 .754 r
F P
0 g
s
.49825 .45591 m .48503 .44449 L .48386 .43079 L p .423 .4 .729 r
F P
0 g
s
.48503 .44449 m .49825 .45591 L .50083 .4668 L p .422 .398 .727 r
F P
0 g
s
.46645 .37467 m .47808 .39363 L .47243 .40222 L p .442 .43 .75 r
F P
0 g
s
.48546 .42038 m .47243 .40222 L .47808 .39363 L p .429 .412 .739 r
F P
0 g
s
.47243 .40222 m .48546 .42038 L .48386 .43079 L p .434 .414 .737 r
F P
0 g
s
.60365 .67436 m .5974 .66792 L .63086 .67341 L p .271 .639 .965 r
F P
0 g
s
.63086 .67341 m .64008 .6788 L .60365 .67436 L p .271 .639 .965 r
F P
0 g
s
.41963 .288 m .42948 .29684 L .40802 .3075 L p .542 .669 .92 r
F P
0 g
s
.40802 .3075 m .39609 .30047 L .41963 .288 L p .542 .669 .92 r
F P
0 g
s
.52287 .56911 m .52324 .55579 L .54124 .57422 L p .386 .402 .754 r
F P
0 g
s
.54124 .57422 m .54443 .59046 L .52287 .56911 L p .386 .402 .754 r
F P
0 g
s
.49517 .47801 m .50505 .47861 L .51063 .49058 L p .415 .393 .726 r
F P
0 g
s
.51063 .49058 m .50349 .49566 L .49517 .47801 L p .415 .393 .726 r
F P
0 g
s
.45844 .33569 m .46797 .35246 L .45483 .35732 L p .45 .471 .789 r
F P
0 g
s
.46645 .37467 m .45483 .35732 L .46797 .35246 L p .437 .444 .769 r
F P
0 g
s
.49748 .44666 m .48386 .43079 L .48546 .42038 L p .422 .4 .73 r
F P
0 g
s
.48386 .43079 m .49748 .44666 L .49825 .45591 L p .423 .4 .729 r
F P
0 g
s
.24003 .38374 m .25524 .3715 L .25004 .42041 L p .908 .933 .817 r
F P
0 g
s
.25004 .42041 m .23503 .43372 L .24003 .38374 L p .908 .933 .817 r
F P
0 g
s
.50943 .52259 m .51331 .51236 L .52398 .52702 L p .405 .393 .732 r
F P
0 g
s
.52398 .52702 m .52361 .54172 L .50943 .52259 L p .405 .393 .732 r
F P
0 g
s
.40965 .28126 m .41963 .288 L .39609 .30047 L p .573 .743 .957 r
F P
0 g
s
.39609 .30047 m .38402 .29568 L .40965 .28126 L p .573 .743 .957 r
F P
0 g
s
.80224 .57449 m .79061 .58767 L .80845 .54233 L p .871 .991 .738 r
F P
0 g
s
.80845 .54233 m .82129 .52819 L .80224 .57449 L p .871 .991 .738 r
F P
0 g
s
.46797 .35246 m .47747 .3709 L .46645 .37467 L p .437 .444 .769 r
F P
0 g
s
.47808 .39363 m .46645 .37467 L .47747 .3709 L p .428 .424 .753 r
F P
0 g
s
.50349 .49566 m .51063 .49058 L .51721 .5019 L p .411 .391 .727 r
F P
0 g
s
.51721 .5019 m .51331 .51236 L .50349 .49566 L p .411 .391 .727 r
F P
0 g
s
.55074 .61895 m .5476 .60542 L .5716 .62117 L p .361 .436 .803 r
F P
0 g
s
.5716 .62117 m .57815 .63589 L .55074 .61895 L p .361 .436 .803 r
F P
0 g
s
.52324 .55579 m .52361 .54172 L .53804 .55688 L p .396 .397 .743 r
F P
0 g
s
.53804 .55688 m .54124 .57422 L .52324 .55579 L p .396 .397 .743 r
F P
0 g
s
.32065 .30338 m .3338 .298 L .31369 .33305 L p .831 .975 .886 r
F P
0 g
s
.31369 .33305 m .29944 .34057 L .32065 .30338 L p .831 .975 .886 r
F P
0 g
s
.47808 .39363 m .48975 .41397 L .48546 .42038 L p .429 .412 .739 r
F P
0 g
s
.49857 .43968 m .48546 .42038 L .48975 .41397 L p .419 .399 .731 r
F P
0 g
s
.48546 .42038 m .49857 .43968 L .49748 .44666 L p .422 .4 .73 r
F P
0 g
s
.5974 .66792 m .59106 .65935 L .6215 .66554 L p .335 .592 .939 r
F P
0 g
s
.6215 .66554 m .63086 .67341 L .5974 .66792 L p .335 .592 .939 r
F P
0 g
s
.39951 .27661 m .40965 .28126 L .38402 .29568 L p .601 .82 .984 r
F P
0 g
s
.38402 .29568 m .37178 .29313 L .39951 .27661 L p .601 .82 .984 r
F P
0 g
s
.47747 .3709 m .48696 .39083 L .47808 .39363 L p .428 .424 .753 r
F P
0 g
s
.48975 .41397 m .47808 .39363 L .48696 .39083 L p .42 .408 .74 r
F P
0 g
s
.51291 .47349 m .50083 .4668 L .49825 .45591 L p .414 .391 .725 r
F P
0 g
s
.50083 .4668 m .51291 .47349 L .51503 .47947 L p .413 .39 .724 r
F P
0 g
s
.51503 .47947 m .50505 .47861 L .50083 .4668 L p .413 .39 .724 r
F P
0 g
s
.65806 .68243 m .64915 .68178 L .68114 .67109 L p .427 .862 .923 r
F P
0 g
s
.68114 .67109 m .69248 .67 L .65806 .68243 L p .427 .862 .923 r
F P
0 g
s
.51161 .46798 m .49825 .45591 L .49748 .44666 L p .414 .391 .725 r
F P
0 g
s
.49825 .45591 m .51161 .46798 L .51291 .47349 L p .414 .391 .725 r
F P
0 g
s
.51331 .51236 m .51721 .5019 L .52436 .51181 L p .408 .39 .728 r
F P
0 g
s
.52436 .51181 m .52398 .52702 L .51331 .51236 L p .408 .39 .728 r
F P
0 g
s
.72522 .65378 m .71453 .66111 L .74202 .6317 L p .669 .961 .746 r
F P
0 g
s
.74202 .6317 m .75451 .62267 L .72522 .65378 L p .669 .961 .746 r
F P
0 g
s
.5476 .60542 m .54443 .59046 L .56501 .60465 L p .378 .422 .781 r
F P
0 g
s
.56501 .60465 m .5716 .62117 L .5476 .60542 L p .378 .422 .781 r
F P
0 g
s
.50505 .47861 m .51503 .47947 L .51784 .48553 L p .412 .389 .724 r
F P
0 g
s
.51784 .48553 m .51063 .49058 L .50505 .47861 L p .412 .389 .724 r
F P
0 g
s
.22459 .39648 m .24003 .38374 L .23503 .43372 L p .91 .94 .814 r
F P
0 g
s
.23503 .43372 m .21985 .44747 L .22459 .39648 L p .91 .94 .814 r
F P
0 g
s
.51123 .46332 m .49748 .44666 L .49857 .43968 L p .414 .391 .725 r
F P
0 g
s
.49748 .44666 m .51123 .46332 L .51161 .46798 L p .414 .391 .725 r
F P
0 g
s
.52361 .54172 m .52398 .52702 L .53482 .53862 L p .402 .394 .735 r
F P
0 g
s
.53482 .53862 m .53804 .55688 L .52361 .54172 L p .402 .394 .735 r
F P
0 g
s
.51063 .49058 m .51784 .48553 L .52115 .49125 L p .41 .389 .724 r
F P
0 g
s
.52115 .49125 m .51721 .5019 L .51063 .49058 L p .41 .389 .724 r
F P
0 g
s
.48696 .39083 m .49646 .41202 L .48975 .41397 L p .42 .408 .74 r
F P
0 g
s
.50147 .43543 m .48975 .41397 L .49646 .41202 L p .415 .397 .731 r
F P
0 g
s
.48975 .41397 m .50147 .43543 L .49857 .43968 L p .419 .399 .731 r
F P
0 g
s
.3892 .27398 m .39951 .27661 L .37178 .29313 L p .619 .888 .989 r
F P
0 g
s
.37178 .29313 m .35934 .29273 L .3892 .27398 L p .619 .888 .989 r
F P
0 g
s
.51179 .45981 m .49857 .43968 L .50147 .43543 L p .413 .391 .726 r
F P
0 g
s
.49857 .43968 m .51179 .45981 L .51123 .46332 L p .414 .391 .725 r
F P
0 g
s
.59106 .65935 m .58464 .64865 L .61204 .65522 L p .37 .542 .894 r
F P
0 g
s
.61204 .65522 m .6215 .66554 L .59106 .65935 L p .37 .542 .894 r
F P
0 g
s
.54443 .59046 m .54124 .57422 L .55839 .58652 L p .39 .412 .762 r
F P
0 g
s
.55839 .58652 m .56501 .60465 L .54443 .59046 L p .39 .412 .762 r
F P
0 g
s
.30725 .31032 m .32065 .30338 L .29944 .34057 L p .836 .991 .859 r
F P
0 g
s
.29944 .34057 m .28496 .34964 L .30725 .31032 L p .836 .991 .859 r
F P
0 g
s
.79061 .58767 m .77879 .60032 L .79545 .55596 L p .882 .992 .764 r
F P
0 g
s
.79545 .55596 m .80845 .54233 L .79061 .58767 L p .882 .992 .764 r
F P
0 g
s
.4785 .33937 m .48521 .35625 L .46797 .35246 L p .415 .45 .789 r
F P
0 g
s
.46797 .35246 m .45844 .33569 L .4785 .33937 L p .415 .45 .789 r
F P
0 g
s
.47747 .3709 m .46797 .35246 L .48521 .35625 L p .413 .43 .768 r
F P
0 g
s
.47175 .32405 m .4785 .33937 L .45844 .33569 L p .416 .477 .815 r
F P
0 g
s
.45844 .33569 m .44886 .32076 L .47175 .32405 L p .416 .477 .815 r
F P
0 g
s
.48521 .35625 m .49189 .37455 L .47747 .3709 L p .413 .43 .768 r
F P
0 g
s
.48696 .39083 m .47747 .3709 L .49189 .37455 L p .412 .414 .752 r
F P
0 g
s
.52398 .52702 m .52436 .51181 L .53159 .51965 L p .407 .391 .729 r
F P
0 g
s
.53159 .51965 m .53482 .53862 L .52398 .52702 L p .407 .391 .729 r
F P
0 g
s
.51721 .5019 m .52115 .49125 L .52474 .49625 L p .41 .388 .725 r
F P
0 g
s
.52474 .49625 m .52436 .51181 L .51721 .5019 L p .41 .388 .725 r
F P
0 g
s
.46493 .31042 m .47175 .32405 L .44886 .32076 L p .417 .512 .848 r
F P
0 g
s
.44886 .32076 m .43922 .30778 L .46493 .31042 L p .417 .512 .848 r
F P
0 g
s
.49189 .37455 m .49854 .39411 L .48696 .39083 L p .412 .414 .752 r
F P
0 g
s
.49646 .41202 m .48696 .39083 L .49854 .39411 L p .412 .403 .74 r
F P
0 g
s
.49646 .41202 m .50598 .43422 L .50147 .43543 L p .415 .397 .731 r
F P
0 g
s
.51325 .4577 m .50147 .43543 L .50598 .43422 L p .412 .391 .726 r
F P
0 g
s
.50147 .43543 m .51325 .4577 L .51179 .45981 L p .413 .391 .726 r
F P
0 g
s
.54124 .57422 m .53804 .55688 L .55174 .567 L p .399 .403 .748 r
F P
0 g
s
.55174 .567 m .55839 .58652 L .54124 .57422 L p .399 .403 .748 r
F P
0 g
s
.64915 .68178 m .64008 .6788 L .6696 .66969 L p .488 .835 .997 r
F P
0 g
s
.6696 .66969 m .68114 .67109 L .64915 .68178 L p .488 .835 .997 r
F P
0 g
s
.45805 .29855 m .46493 .31042 L .43922 .30778 L p .417 .555 .886 r
F P
0 g
s
.43922 .30778 m .42948 .29684 L .45805 .29855 L p .417 .555 .886 r
F P
0 g
s
.20897 .40938 m .22459 .39648 L .21985 .44747 L p .909 .944 .815 r
F P
0 g
s
.21985 .44747 m .20453 .46135 L .20897 .40938 L p .909 .944 .815 r
F P
0 g
s
.52511 .48046 m .51291 .47349 L .51161 .46798 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .51503 .47947 L .51291 .47349 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .51161 .46798 L .51123 .46332 L closepath p .41 .387 .723 r
F P
0 g
s
.58464 .64865 m .57815 .63589 L .60248 .64251 L p .388 .501 .852 r
F P
0 g
s
.60248 .64251 m .61204 .65522 L .58464 .64865 L p .388 .501 .852 r
F P
0 g
s
.49854 .39411 m .50519 .41472 L .49646 .41202 L p .412 .403 .74 r
F P
0 g
s
.50598 .43422 m .49646 .41202 L .50519 .41472 L p .411 .395 .731 r
F P
0 g
s
.52511 .48046 m .51784 .48553 L .51503 .47947 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .51123 .46332 L .51179 .45981 L closepath p .41 .387 .723 r
F P
0 g
s
.71453 .66111 m .70361 .6666 L .72931 .6389 L p .719 .988 .85 r
F P
0 g
s
.72931 .6389 m .74202 .6317 L .71453 .66111 L p .719 .988 .85 r
F P
0 g
s
.52436 .51181 m .52474 .49625 L .52836 .50019 L p .409 .389 .725 r
F P
0 g
s
.52836 .50019 m .53159 .51965 L .52436 .51181 L p .409 .389 .725 r
F P
0 g
s
.37869 .27329 m .3892 .27398 L .35934 .29273 L p .621 .934 .963 r
F P
0 g
s
.35934 .29273 m .34669 .2944 L .37869 .27329 L p .621 .934 .963 r
F P
0 g
s
.53804 .55688 m .53482 .53862 L .54509 .54635 L p .404 .397 .738 r
F P
0 g
s
.54509 .54635 m .55174 .567 L .53804 .55688 L p .404 .397 .738 r
F P
0 g
s
.52511 .48046 m .52115 .49125 L .51784 .48553 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .51179 .45981 L .51325 .4577 L closepath p .41 .387 .723 r
F P
0 g
s
.45108 .28848 m .45805 .29855 L .42948 .29684 L p .414 .609 .929 r
F P
0 g
s
.42948 .29684 m .41963 .288 L .45108 .28848 L p .414 .609 .929 r
F P
0 g
s
.50519 .41472 m .51183 .43615 L .50598 .43422 L p .411 .395 .731 r
F P
0 g
s
.51553 .45713 m .50598 .43422 L .51183 .43615 L p .41 .39 .726 r
F P
0 g
s
.50598 .43422 m .51553 .45713 L .51325 .4577 L p .412 .391 .726 r
F P
0 g
s
.52511 .48046 m .52474 .49625 L .52115 .49125 L closepath p .41 .387 .723 r
F P
0 g
s
.53482 .53862 m .53159 .51965 L .53843 .52486 L p .408 .392 .73 r
F P
0 g
s
.53843 .52486 m .54509 .54635 L .53482 .53862 L p .408 .392 .73 r
F P
0 g
s
.52511 .48046 m .51325 .4577 L .51553 .45713 L closepath p .41 .387 .723 r
F P
0 g
s
.57815 .63589 m .5716 .62117 L .59286 .62756 L p .398 .469 .817 r
F P
0 g
s
.59286 .62756 m .60248 .64251 L .57815 .63589 L p .398 .469 .817 r
F P
0 g
s
.29358 .31859 m .30725 .31032 L .28496 .34964 L p .837 .998 .833 r
F P
0 g
s
.28496 .34964 m .27022 .36003 L .29358 .31859 L p .837 .998 .833 r
F P
0 g
s
.85906 .48583 m .84656 .49963 L .84676 .44728 L p .912 .938 .811 r
F P
0 g
s
.84676 .44728 m .85986 .43317 L .85906 .48583 L p .912 .938 .811 r
F P
0 g
s
.52511 .48046 m .52836 .50019 L .52474 .49625 L closepath p .41 .387 .723 r
F P
0 g
s
.77879 .60032 m .76676 .6121 L .78225 .56876 L p .89 .988 .795 r
F P
0 g
s
.78225 .56876 m .79545 .55596 L .77879 .60032 L p .89 .988 .795 r
F P
0 g
s
.64008 .6788 m .63086 .67341 L .65789 .6657 L p .503 .757 .987 r
F P
0 g
s
.65789 .6657 m .6696 .66969 L .64008 .6788 L p .503 .757 .987 r
F P
0 g
s
.53159 .51965 m .52836 .50019 L .53177 .5028 L p .409 .389 .725 r
F P
0 g
s
.53177 .5028 m .53843 .52486 L .53159 .51965 L p .409 .389 .725 r
F P
0 g
s
.51183 .43615 m .51847 .45815 L .51553 .45713 L p .41 .39 .726 r
F P
0 g
s
.52511 .48046 m .51553 .45713 L .51847 .45815 L closepath p .41 .387 .723 r
F P
0 g
s
.5716 .62117 m .56501 .60465 L .58319 .61055 L p .404 .445 .789 r
F P
0 g
s
.58319 .61055 m .59286 .62756 L .5716 .62117 L p .404 .445 .789 r
F P
0 g
s
.19318 .42214 m .20897 .40938 L .20453 .46135 L p .906 .947 .819 r
F P
0 g
s
.20453 .46135 m .18911 .47507 L .19318 .42214 L p .906 .947 .819 r
F P
0 g
s
.44401 .28023 m .45108 .28848 L .41963 .288 L p .405 .67 .968 r
F P
0 g
s
.41963 .288 m .40965 .28126 L .44401 .28023 L p .405 .67 .968 r
F P
0 g
s
.51207 .40333 m .51534 .42193 L .50519 .41472 L p .405 .398 .738 r
F P
0 g
s
.50519 .41472 m .49854 .39411 L .51207 .40333 L p .405 .398 .738 r
F P
0 g
s
.51183 .43615 m .50519 .41472 L .51534 .42193 L p .408 .393 .73 r
F P
0 g
s
.50878 .38551 m .51207 .40333 L .49854 .39411 L p .401 .405 .748 r
F P
0 g
s
.49854 .39411 m .49189 .37455 L .50878 .38551 L p .401 .405 .748 r
F P
0 g
s
.52511 .48046 m .53177 .5028 L .52836 .50019 L closepath p .41 .387 .723 r
F P
0 g
s
.51534 .42193 m .51861 .44112 L .51183 .43615 L p .408 .393 .73 r
F P
0 g
s
.51847 .45815 m .51183 .43615 L .51861 .44112 L p .41 .389 .725 r
F P
0 g
s
.50548 .36863 m .50878 .38551 L .49189 .37455 L p .396 .415 .763 r
F P
0 g
s
.49189 .37455 m .48521 .35625 L .50548 .36863 L p .396 .415 .763 r
F P
0 g
s
.51861 .44112 m .52187 .4607 L .51847 .45815 L p .41 .389 .725 r
F P
0 g
s
.52511 .48046 m .51847 .45815 L .52187 .4607 L closepath p .41 .387 .723 r
F P
0 g
s
.36797 .27441 m .37869 .27329 L .34669 .2944 L p .606 .951 .909 r
F P
0 g
s
.34669 .2944 m .3338 .298 L .36797 .27441 L p .606 .951 .909 r
F P
0 g
s
.56501 .60465 m .55839 .58652 L .57349 .5917 L p .408 .427 .768 r
F P
0 g
s
.57349 .5917 m .58319 .61055 L .56501 .60465 L p .408 .427 .768 r
F P
0 g
s
.52511 .48046 m .53531 .48147 L .53746 .48752 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53246 .47536 L .53531 .48147 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .52911 .4696 L .53246 .47536 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .52549 .4646 L .52911 .4696 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .52187 .4607 L .52549 .4646 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53473 .50389 L .53177 .5028 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53705 .50338 L .53473 .50389 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53856 .5013 L .53705 .50338 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53914 .49779 L .53856 .5013 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53877 .49309 L .53914 .49779 L closepath p .41 .387 .723 r
F P
0 g
s
.52511 .48046 m .53746 .48752 L .53877 .49309 L closepath p .41 .387 .723 r
F P
0 g
s
.50215 .35283 m .50548 .36863 L .48521 .35625 L p .388 .428 .78 r
F P
0 g
s
.48521 .35625 m .4785 .33937 L .50215 .35283 L p .388 .428 .78 r
F P
0 g
s
.70361 .6666 m .69248 .67 L .71636 .644 L p .741 .975 .924 r
F P
0 g
s
.71636 .644 m .72931 .6389 L .70361 .6666 L p .741 .975 .924 r
F P
0 g
s
.53843 .52486 m .53177 .5028 L .53473 .50389 L p .41 .39 .726 r
F P
0 g
s
.55839 .58652 m .55174 .567 L .56378 .5713 L p .409 .413 .752 r
F P
0 g
s
.56378 .5713 m .57349 .5917 L .55839 .58652 L p .409 .413 .752 r
F P
0 g
s
.54509 .54635 m .53843 .52486 L .54439 .52706 L p .411 .395 .731 r
F P
0 g
s
.53473 .50389 m .54439 .52706 L .53843 .52486 L p .41 .39 .726 r
F P
0 g
s
.52588 .44881 m .52549 .4646 L .52187 .4607 L p .409 .389 .725 r
F P
0 g
s
.52187 .4607 m .51861 .44112 L .52588 .44881 L p .409 .389 .725 r
F P
0 g
s
.55174 .567 m .54509 .54635 L .55407 .54964 L p .41 .402 .74 r
F P
0 g
s
.55407 .54964 m .56378 .5713 L .55174 .567 L p .41 .402 .74 r
F P
0 g
s
.54439 .52706 m .55407 .54964 L .54509 .54635 L p .411 .395 .731 r
F P
0 g
s
.63086 .67341 m .6215 .66554 L .64603 .65907 L p .496 .672 .943 r
F P
0 g
s
.64603 .65907 m .65789 .6657 L .63086 .67341 L p .496 .672 .943 r
F P
0 g
s
.84656 .49963 m .83398 .51385 L .83361 .4617 L p .915 .93 .806 r
F P
0 g
s
.83361 .4617 m .84676 .44728 L .84656 .49963 L p .915 .93 .806 r
F P
0 g
s
.49879 .33822 m .50215 .35283 L .4785 .33937 L p .377 .444 .803 r
F P
0 g
s
.4785 .33937 m .47175 .32405 L .49879 .33822 L p .377 .444 .803 r
F P
0 g
s
.54439 .52706 m .53473 .50389 L .53705 .50338 L p .411 .39 .726 r
F P
0 g
s
.52626 .43322 m .52588 .44881 L .51861 .44112 L p .407 .391 .729 r
F P
0 g
s
.51861 .44112 m .51534 .42193 L .52626 .43322 L p .407 .391 .729 r
F P
0 g
s
.43683 .27378 m .44401 .28023 L .40965 .28126 L p .383 .73 .99 r
F P
0 g
s
.40965 .28126 m .39951 .27661 L .43683 .27378 L p .383 .73 .99 r
F P
0 g
s
.27965 .32795 m .29358 .31859 L .27022 .36003 L p .834 1 .81 r
F P
0 g
s
.27022 .36003 m .25524 .3715 L .27965 .32795 L p .834 1 .81 r
F P
0 g
s
.53313 .45871 m .52911 .4696 L .52549 .4646 L p .41 .388 .725 r
F P
0 g
s
.52549 .4646 m .52588 .44881 L .53313 .45871 L p .41 .388 .725 r
F P
0 g
s
.76676 .6121 m .75451 .62267 L .76886 .58041 L p .89 .975 .826 r
F P
0 g
s
.76886 .58041 m .78225 .56876 L .76676 .6121 L p .89 .975 .826 r
F P
0 g
s
.49541 .3249 m .49879 .33822 L .47175 .32405 L p .363 .465 .83 r
F P
0 g
s
.47175 .32405 m .46493 .31042 L .49541 .3249 L p .363 .465 .83 r
F P
0 g
s
.53705 .50338 m .54906 .52608 L .54439 .52706 L p .411 .39 .726 r
F P
0 g
s
.54906 .52608 m .53705 .50338 L .53856 .5013 L p .413 .391 .726 r
F P
0 g
s
.52665 .41797 m .52626 .43322 L .51534 .42193 L p .403 .394 .735 r
F P
0 g
s
.51534 .42193 m .51207 .40333 L .52665 .41797 L p .403 .394 .735 r
F P
0 g
s
.53986 .47016 m .53246 .47536 L .52911 .4696 L p .41 .389 .724 r
F P
0 g
s
.52911 .4696 m .53313 .45871 L .53986 .47016 L p .41 .389 .724 r
F P
0 g
s
.55407 .54964 m .54439 .52706 L .54906 .52608 L p .414 .397 .731 r
F P
0 g
s
.6215 .66554 m .61204 .65522 L .63404 .64982 L p .481 .6 .895 r
F P
0 g
s
.63404 .64982 m .64603 .65907 L .6215 .66554 L p .481 .6 .895 r
F P
0 g
s
.53856 .5013 m .55211 .52195 L .54906 .52608 L p .413 .391 .726 r
F P
0 g
s
.55211 .52195 m .53856 .5013 L .53914 .49779 L p .414 .391 .725 r
F P
0 g
s
.54561 .48235 m .53531 .48147 L .53246 .47536 L p .412 .389 .724 r
F P
0 g
s
.53246 .47536 m .53986 .47016 L .54561 .48235 L p .412 .389 .724 r
F P
0 g
s
.52704 .40318 m .52665 .41797 L .51207 .40333 L p .398 .399 .744 r
F P
0 g
s
.51207 .40333 m .50878 .38551 L .52704 .40318 L p .398 .399 .744 r
F P
0 g
s
.69248 .67 m .68114 .67109 L .70321 .64678 L p .73 .921 .957 r
F P
0 g
s
.70321 .64678 m .71636 .644 L .69248 .67 L p .73 .921 .957 r
F P
0 g
s
.53718 .44786 m .53313 .45871 L .52588 .44881 L p .408 .39 .728 r
F P
0 g
s
.52588 .44881 m .52626 .43322 L .53718 .44786 L p .408 .39 .728 r
F P
0 g
s
.35703 .27719 m .36797 .27441 L .3338 .298 L p .58 .943 .838 r
F P
0 g
s
.3338 .298 m .32065 .30338 L .35703 .27719 L p .58 .943 .838 r
F P
0 g
s
.53914 .49779 m .55331 .51496 L .55211 .52195 L p .414 .391 .725 r
F P
0 g
s
.55331 .51496 m .53914 .49779 L .53877 .49309 L p .414 .391 .725 r
F P
0 g
s
.54995 .49444 m .53746 .48752 L .53531 .48147 L p .413 .39 .724 r
F P
0 g
s
.53531 .48147 m .54561 .48235 L .54995 .49444 L p .413 .39 .724 r
F P
0 g
s
.56378 .5713 m .55407 .54964 L .56114 .5482 L p .419 .408 .74 r
F P
0 g
s
.54906 .52608 m .56114 .5482 L .55407 .54964 L p .414 .397 .731 r
F P
0 g
s
.49199 .31294 m .49541 .3249 L .46493 .31042 L p .343 .491 .862 r
F P
0 g
s
.46493 .31042 m .45805 .29855 L .49199 .31294 L p .343 .491 .862 r
F P
0 g
s
.53877 .49309 m .55258 .50557 L .55331 .51496 L p .414 .391 .725 r
F P
0 g
s
.55258 .50557 m .53877 .49309 L .53746 .48752 L p .414 .391 .725 r
F P
0 g
s
.53746 .48752 m .54995 .49444 L .55258 .50557 L p .414 .391 .725 r
F P
0 g
s
.83398 .51385 m .82129 .52819 L .82039 .4762 L p .914 .919 .805 r
F P
0 g
s
.82039 .4762 m .83361 .4617 L .83398 .51385 L p .914 .919 .805 r
F P
0 g
s
.61204 .65522 m .60248 .64251 L .62196 .63804 L p .466 .544 .852 r
F P
0 g
s
.62196 .63804 m .63404 .64982 L .61204 .65522 L p .466 .544 .852 r
F P
0 g
s
.42951 .26909 m .43683 .27378 L .39951 .27661 L p .344 .771 .973 r
F P
0 g
s
.39951 .27661 m .3892 .27398 L .42951 .26909 L p .344 .771 .973 r
F P
0 g
s
.52743 .38896 m .52704 .40318 L .50878 .38551 L p .39 .404 .754 r
F P
0 g
s
.50878 .38551 m .50548 .36863 L .52743 .38896 L p .39 .404 .754 r
F P
0 g
s
.56114 .5482 m .54906 .52608 L .55211 .52195 L p .418 .399 .731 r
F P
0 g
s
.57349 .5917 m .56378 .5713 L .57327 .56938 L p .425 .422 .752 r
F P
0 g
s
.56114 .5482 m .57327 .56938 L .56378 .5713 L p .419 .408 .74 r
F P
0 g
s
.60248 .64251 m .59286 .62756 L .60982 .62387 L p .452 .5 .818 r
F P
0 g
s
.60982 .62387 m .62196 .63804 L .60248 .64251 L p .452 .5 .818 r
F P
0 g
s
.54734 .46484 m .53986 .47016 L .53313 .45871 L p .411 .391 .727 r
F P
0 g
s
.53313 .45871 m .53718 .44786 L .54734 .46484 L p .411 .391 .727 r
F P
0 g
s
.54127 .43708 m .53718 .44786 L .52626 .43322 L p .406 .393 .732 r
F P
0 g
s
.52626 .43322 m .52665 .41797 L .54127 .43708 L p .406 .393 .732 r
F P
0 g
s
.58319 .61055 m .57349 .5917 L .58545 .58927 L p .432 .441 .769 r
F P
0 g
s
.57327 .56938 m .58545 .58927 L .57349 .5917 L p .425 .422 .752 r
F P
0 g
s
.59286 .62756 m .58319 .61055 L .59764 .60753 L p .441 .467 .79 r
F P
0 g
s
.59764 .60753 m .60982 .62387 L .59286 .62756 L p .441 .467 .79 r
F P
0 g
s
.58545 .58927 m .59764 .60753 L .58319 .61055 L p .432 .441 .769 r
F P
0 g
s
.26547 .33811 m .27965 .32795 L .25524 .3715 L p .831 .999 .794 r
F P
0 g
s
.25524 .3715 m .24003 .38374 L .26547 .33811 L p .831 .999 .794 r
F P
0 g
s
.75451 .62267 m .74202 .6317 L .75527 .59062 L p .879 .951 .852 r
F P
0 g
s
.75527 .59062 m .76886 .58041 L .75451 .62267 L p .879 .951 .852 r
F P
0 g
s
.52782 .3754 m .52743 .38896 L .50548 .36863 L p .38 .412 .768 r
F P
0 g
s
.50548 .36863 m .50215 .35283 L .52782 .3754 L p .38 .412 .768 r
F P
0 g
s
.48852 .30238 m .49199 .31294 L .45805 .29855 L p .315 .521 .897 r
F P
0 g
s
.45805 .29855 m .45108 .28848 L .48852 .30238 L p .315 .521 .897 r
F P
0 g
s
.55211 .52195 m .56577 .54207 L .56114 .5482 L p .418 .399 .731 r
F P
0 g
s
.56577 .54207 m .55211 .52195 L .55331 .51496 L p .421 .4 .73 r
F P
0 g
s
.68114 .67109 m .6696 .66969 L .68985 .64709 L p .695 .842 .953 r
F P
0 g
s
.68985 .64709 m .70321 .64678 L .68114 .67109 L p .695 .842 .953 r
F P
0 g
s
.57327 .56938 m .56114 .5482 L .56577 .54207 L p .427 .411 .739 r
F P
0 g
s
.55601 .48299 m .54561 .48235 L .53986 .47016 L p .415 .393 .726 r
F P
0 g
s
.53986 .47016 m .54734 .46484 L .55601 .48299 L p .415 .393 .726 r
F P
0 g
s
.54538 .42643 m .54127 .43708 L .52665 .41797 L p .402 .397 .739 r
F P
0 g
s
.52665 .41797 m .52704 .40318 L .54538 .42643 L p .402 .397 .739 r
F P
0 g
s
.55331 .51496 m .56762 .53164 L .56577 .54207 L p .421 .4 .73 r
F P
0 g
s
.56762 .53164 m .55331 .51496 L .55258 .50557 L p .423 .399 .729 r
F P
0 g
s
.82129 .52819 m .80845 .54233 L .80708 .4905 L p .91 .906 .807 r
F P
0 g
s
.80708 .4905 m .82039 .4762 L .82129 .52819 L p .91 .906 .807 r
F P
0 g
s
.56257 .50102 m .54995 .49444 L .54561 .48235 L p .419 .396 .727 r
F P
0 g
s
.54561 .48235 m .55601 .48299 L .56257 .50102 L p .419 .396 .727 r
F P
0 g
s
.52822 .36259 m .52782 .3754 L .50215 .35283 L p .367 .421 .785 r
F P
0 g
s
.50215 .35283 m .49879 .33822 L .52822 .36259 L p .367 .421 .785 r
F P
0 g
s
.34585 .28143 m .35703 .27719 L .32065 .30338 L p .552 .922 .766 r
F P
0 g
s
.32065 .30338 m .30725 .31032 L .34585 .28143 L p .552 .922 .766 r
F P
0 g
s
.55489 .45937 m .54734 .46484 L .53718 .44786 L p .412 .395 .73 r
F P
0 g
s
.53718 .44786 m .54127 .43708 L .55489 .45937 L p .412 .395 .73 r
F P
0 g
s
.55258 .50557 m .56653 .51763 L .56762 .53164 L p .423 .399 .729 r
F P
0 g
s
.56653 .51763 m .55258 .50557 L .54995 .49444 L p .422 .398 .727 r
F P
0 g
s
.42206 .26607 m .42951 .26909 L .3892 .27398 L p .288 .776 .904 r
F P
0 g
s
.3892 .27398 m .37869 .27329 L .42206 .26607 L p .288 .776 .904 r
F P
0 g
s
.54995 .49444 m .56257 .50102 L .56653 .51763 L p .422 .398 .727 r
F P
0 g
s
.58545 .58927 m .57327 .56938 L .57953 .56128 L p .439 .428 .75 r
F P
0 g
s
.56577 .54207 m .57953 .56128 L .57327 .56938 L p .427 .411 .739 r
F P
0 g
s
.6696 .66969 m .65789 .6657 L .67633 .64482 L p .65 .758 .929 r
F P
0 g
s
.67633 .64482 m .68985 .64709 L .6696 .66969 L p .65 .758 .929 r
F P
0 g
s
.485 .29322 m .48852 .30238 L .45108 .28848 L p .276 .555 .928 r
F P
0 g
s
.45108 .28848 m .44401 .28023 L .485 .29322 L p .276 .555 .928 r
F P
0 g
s
.57953 .56128 m .56577 .54207 L .56762 .53164 L p .433 .413 .737 r
F P
0 g
s
.74202 .6317 m .72931 .6389 L .74147 .59911 L p .856 .915 .871 r
F P
0 g
s
.74147 .59911 m .75527 .59062 L .74202 .6317 L p .856 .915 .871 r
F P
0 g
s
.54953 .41596 m .54538 .42643 L .52704 .40318 L p .398 .401 .747 r
F P
0 g
s
.52704 .40318 m .52743 .38896 L .54953 .41596 L p .398 .401 .747 r
F P
0 g
s
.52862 .35059 m .52822 .36259 L .49879 .33822 L p .35 .432 .805 r
F P
0 g
s
.49879 .33822 m .49541 .3249 L .52862 .35059 L p .35 .432 .805 r
F P
0 g
s
.56653 .48326 m .55601 .48299 L .54734 .46484 L p .42 .399 .729 r
F P
0 g
s
.54734 .46484 m .55489 .45937 L .56653 .48326 L p .42 .399 .729 r
F P
0 g
s
.59764 .60753 m .58545 .58927 L .59336 .57924 L p .455 .451 .765 r
F P
0 g
s
.57953 .56128 m .59336 .57924 L .58545 .58927 L p .439 .428 .75 r
F P
0 g
s
.25104 .34876 m .26547 .33811 L .24003 .38374 L p .828 .999 .785 r
F P
0 g
s
.24003 .38374 m .22459 .39648 L .25104 .34876 L p .828 .999 .785 r
F P
0 g
s
.65789 .6657 m .64603 .65907 L .66267 .63993 L p .605 .681 .895 r
F P
0 g
s
.66267 .63993 m .67633 .64482 L .65789 .6657 L p .605 .681 .895 r
F P
0 g
s
.56251 .4537 m .55489 .45937 L .54127 .43708 L p .413 .399 .735 r
F P
0 g
s
.54127 .43708 m .54538 .42643 L .56251 .4537 L p .413 .399 .735 r
F P
0 g
s
.80845 .54233 m .79545 .55596 L .79365 .50432 L p .9 .889 .811 r
F P
0 g
s
.79365 .50432 m .80708 .4905 L .80845 .54233 L p .9 .889 .811 r
F P
0 g
s
.56762 .53164 m .58205 .5475 L .57953 .56128 L p .433 .413 .737 r
F P
0 g
s
.58205 .5475 m .56762 .53164 L .56653 .51763 L p .436 .412 .734 r
F P
0 g
s
.60982 .62387 m .59764 .60753 L .60724 .59561 L p .475 .479 .783 r
F P
0 g
s
.59336 .57924 m .60724 .59561 L .59764 .60753 L p .455 .451 .765 r
F P
0 g
s
.57532 .50704 m .56257 .50102 L .55601 .48299 L p .428 .404 .73 r
F P
0 g
s
.55601 .48299 m .56653 .48326 L .57532 .50704 L p .428 .404 .73 r
F P
0 g
s
.55372 .4057 m .54953 .41596 L .52743 .38896 L p .391 .407 .756 r
F P
0 g
s
.52743 .38896 m .52782 .3754 L .55372 .4057 L p .391 .407 .756 r
F P
0 g
s
.64603 .65907 m .63404 .64982 L .64889 .63244 L p .564 .615 .862 r
F P
0 g
s
.64889 .63244 m .66267 .63993 L .64603 .65907 L p .564 .615 .862 r
F P
0 g
s
.48143 .28546 m .485 .29322 L .44401 .28023 L p .222 .586 .945 r
F P
0 g
s
.44401 .28023 m .43683 .27378 L .48143 .28546 L p .222 .586 .945 r
F P
0 g
s
.59336 .57924 m .57953 .56128 L .58205 .5475 L p .449 .43 .746 r
F P
0 g
s
.56653 .51763 m .58062 .52899 L .58205 .5475 L p .436 .412 .734 r
F P
0 g
s
.58062 .52899 m .56653 .51763 L .56257 .50102 L p .434 .408 .731 r
F P
0 g
s
.41447 .26461 m .42206 .26607 L .37869 .27329 L p .227 .748 .799 r
F P
0 g
s
.37869 .27329 m .36797 .27441 L .41447 .26461 L p .227 .748 .799 r
F P
0 g
s
.52903 .33945 m .52862 .35059 L .49541 .3249 L p .329 .445 .828 r
F P
0 g
s
.49541 .3249 m .49199 .31294 L .52903 .33945 L p .329 .445 .828 r
F P
0 g
s
.56257 .50102 m .57532 .50704 L .58062 .52899 L p .434 .408 .731 r
F P
0 g
s
.62196 .63804 m .60982 .62387 L .62114 .6101 L p .499 .515 .805 r
F P
0 g
s
.60724 .59561 m .62114 .6101 L .60982 .62387 L p .475 .479 .783 r
F P
0 g
s
.72931 .6389 m .71636 .644 L .72748 .60565 L p .823 .868 .88 r
F P
0 g
s
.72748 .60565 m .74147 .59911 L .72931 .6389 L p .823 .868 .88 r
F P
0 g
s
.63404 .64982 m .62196 .63804 L .63504 .62245 L p .528 .56 .831 r
F P
0 g
s
.63504 .62245 m .64889 .63244 L .63404 .64982 L p .528 .56 .831 r
F P
0 g
s
.33444 .28691 m .34585 .28143 L .30725 .31032 L p .529 .899 .706 r
F P
0 g
s
.30725 .31032 m .29358 .31859 L .33444 .28691 L p .529 .899 .706 r
F P
0 g
s
.62114 .6101 m .63504 .62245 L .62196 .63804 L p .499 .515 .805 r
F P
0 g
s
.57714 .48303 m .56653 .48326 L .55489 .45937 L p .427 .406 .733 r
F P
0 g
s
.55489 .45937 m .56251 .4537 L .57714 .48303 L p .427 .406 .733 r
F P
0 g
s
.57019 .4478 m .56251 .4537 L .54538 .42643 L p .414 .405 .741 r
F P
0 g
s
.54538 .42643 m .54953 .41596 L .57019 .4478 L p .414 .405 .741 r
F P
0 g
s
.79545 .55596 m .78225 .56876 L .78008 .51741 L p .886 .868 .815 r
F P
0 g
s
.78008 .51741 m .79365 .50432 L .79545 .55596 L p .886 .868 .815 r
F P
0 g
s
.55794 .39568 m .55372 .4057 L .52782 .3754 L p .384 .414 .768 r
F P
0 g
s
.52782 .3754 m .52822 .36259 L .55794 .39568 L p .384 .414 .768 r
F P
0 g
s
.58205 .5475 m .59659 .56222 L .59336 .57924 L p .449 .43 .746 r
F P
0 g
s
.59659 .56222 m .58205 .5475 L .58062 .52899 L p .453 .428 .741 r
F P
0 g
s
.60724 .59561 m .59336 .57924 L .59659 .56222 L p .47 .453 .757 r
F P
0 g
s
.52944 .32918 m .52903 .33945 L .49199 .31294 L p .302 .461 .853 r
F P
0 g
s
.49199 .31294 m .48852 .30238 L .52944 .32918 L p .302 .461 .853 r
F P
0 g
s
.23638 .35959 m .25104 .34876 L .22459 .39648 L p .827 .999 .784 r
F P
0 g
s
.22459 .39648 m .20897 .40938 L .23638 .35959 L p .827 .999 .784 r
F P
0 g
s
.71636 .644 m .70321 .64678 L .71331 .61003 L p .781 .814 .879 r
F P
0 g
s
.71331 .61003 m .72748 .60565 L .71636 .644 L p .781 .814 .879 r
F P
0 g
s
.47781 .27905 m .48143 .28546 L .43683 .27378 L p .151 .603 .931 r
F P
0 g
s
.43683 .27378 m .42951 .26909 L .47781 .27905 L p .151 .603 .931 r
F P
0 g
s
.58819 .51231 m .57532 .50704 L .56653 .48326 L p .44 .414 .734 r
F P
0 g
s
.56653 .48326 m .57714 .48303 L .58819 .51231 L p .44 .414 .734 r
F P
0 g
s
.58062 .52899 m .59483 .53936 L .59659 .56222 L p .453 .428 .741 r
F P
0 g
s
.59483 .53936 m .58062 .52899 L .57532 .50704 L p .449 .422 .736 r
F P
0 g
s
.57532 .50704 m .58819 .51231 L .59483 .53936 L p .449 .422 .736 r
F P
0 g
s
.62114 .6101 m .60724 .59561 L .6112 .57549 L p .495 .48 .77 r
F P
0 g
s
.59659 .56222 m .6112 .57549 L .60724 .59561 L p .47 .453 .757 r
F P
0 g
s
.57794 .44165 m .57019 .4478 L .54953 .41596 L p .416 .412 .748 r
F P
0 g
s
.54953 .41596 m .55372 .4057 L .57794 .44165 L p .416 .412 .748 r
F P
0 g
s
.40671 .26456 m .41447 .26461 L .36797 .27441 L p .175 .702 .686 r
F P
0 g
s
.39879 .26577 m .40671 .26456 L .35703 .27719 L p 0 0 0 r
F P
0 g
s
.36797 .27441 m .35703 .27719 L .38242 .27073 L p .175 .702 .686 r
F P
0 g
s
.36797 .27441 m .38242 .27073 L .38402 .27033 L .175 .702 .686 r
F
.35703 .27719 m .34585 .28143 L .37927 .27154 L p 0 0 0 r
F P
0 g
s
.37927 .27154 m .39879 .26577 L p .38454 .26967 L 0 0 0 r
F P
0 g
s
.35703 .27719 m .37927 .27154 L .38454 .26967 L 0 0 0 r
F
.3907 .26804 m .39879 .26577 L .37964 .27144 L p F P
0 g
s
.38242 .27073 m .40671 .26456 L p .38402 .27033 L .175 .702 .686 r
F P
0 g
s
.38244 .27115 m .3907 .26804 L .36347 .27718 L p 0 0 0 r
F P
0 g
s
.36347 .27718 m .33444 .28691 L p .35615 .27978 L 0 0 0 r
F P
0 g
s
.35615 .27978 m .38244 .27115 L .36347 .27718 L 0 0 0 r
F
.37964 .27144 m .34585 .28143 L p .37761 .27195 L F P
0 g
s
.37761 .27195 m .3907 .26804 L .37964 .27144 L 0 0 0 r
F
.56221 .38593 m .55794 .39568 L .52822 .36259 L p .375 .422 .782 r
F P
0 g
s
.52822 .36259 m .52862 .35059 L .56221 .38593 L p .375 .422 .782 r
F P
0 g
s
.58785 .4822 m .57714 .48303 L .56251 .4537 L p .435 .415 .738 r
F P
0 g
s
.56251 .4537 m .57019 .4478 L .58785 .4822 L p .435 .415 .738 r
F P
0 g
s
.78225 .56876 m .76886 .58041 L .76638 .52948 L p .867 .844 .819 r
F P
0 g
s
.76638 .52948 m .78008 .51741 L .78225 .56876 L p .867 .844 .819 r
F P
0 g
s
.70321 .64678 m .68985 .64709 L .69897 .61213 L p .734 .756 .87 r
F P
0 g
s
.69897 .61213 m .71331 .61003 L .70321 .64678 L p .734 .756 .87 r
F P
0 g
s
.6112 .57549 m .59659 .56222 L .59483 .53936 L p .474 .448 .749 r
F P
0 g
s
.32279 .2934 m .33444 .28691 L .29358 .31859 L p .515 .881 .663 r
F P
0 g
s
.29358 .31859 m .27965 .32795 L .32279 .2934 L p .515 .881 .663 r
F P
0 g
s
.52986 .31982 m .52944 .32918 L .48852 .30238 L p .267 .48 .879 r
F P
0 g
s
.48852 .30238 m .485 .29322 L .52986 .31982 L p .267 .48 .879 r
F P
0 g
s
.63504 .62245 m .62114 .6101 L .62588 .58703 L p .524 .513 .786 r
F P
0 g
s
.6112 .57549 m .62588 .58703 L .62114 .6101 L p .495 .48 .77 r
F P
0 g
s
.68985 .64709 m .67633 .64482 L .6845 .61183 L p .687 .699 .856 r
F P
0 g
s
.6845 .61183 m .69897 .61213 L .68985 .64709 L p .687 .699 .856 r
F P
0 g
s
.60118 .51663 m .58819 .51231 L .57714 .48303 L p .454 .427 .738 r
F P
0 g
s
.57714 .48303 m .58785 .4822 L .60118 .51663 L p .454 .427 .738 r
F P
0 g
s
.64889 .63244 m .63504 .62245 L .64058 .5966 L p .559 .552 .803 r
F P
0 g
s
.62588 .58703 m .64058 .5966 L .63504 .62245 L p .524 .513 .786 r
F P
0 g
s
.59483 .53936 m .60915 .54851 L .6112 .57549 L p .474 .448 .749 r
F P
0 g
s
.60915 .54851 m .59483 .53936 L .58819 .51231 L p .468 .438 .742 r
F P
0 g
s
.47411 .27393 m .47781 .27905 L .42951 .26909 L p .073 .597 .873 r
F P
0 g
s
.42951 .26909 m .42206 .26607 L .47411 .27393 L p .073 .597 .873 r
F P
0 g
s
.22154 .37026 m .23638 .35959 L .20897 .40938 L p .828 .999 .792 r
F P
0 g
s
.20897 .40938 m .19318 .42214 L .22154 .37026 L p .828 .999 .792 r
F P
0 g
s
.58576 .43522 m .57794 .44165 L .55372 .4057 L p .417 .421 .756 r
F P
0 g
s
.55372 .4057 m .55794 .39568 L .58576 .43522 L p .417 .421 .756 r
F P
0 g
s
.85986 .43317 m .84676 .44728 L .82379 .39436 L p .859 .843 .827 r
F P
0 g
s
.82379 .39436 m .8366 .38074 L .85986 .43317 L p .859 .843 .827 r
F P
0 g
s
.67633 .64482 m .66267 .63993 L .66993 .60912 L p .641 .645 .839 r
F P
0 g
s
.66993 .60912 m .6845 .61183 L .67633 .64482 L p .641 .645 .839 r
F P
0 g
s
.56651 .37646 m .56221 .38593 L .52862 .35059 L p .365 .432 .797 r
F P
0 g
s
.52862 .35059 m .52903 .33945 L .56651 .37646 L p .365 .432 .797 r
F P
0 g
s
.76886 .58041 m .75527 .59062 L .75254 .54031 L p .843 .815 .822 r
F P
0 g
s
.75254 .54031 m .76638 .52948 L .76886 .58041 L p .843 .815 .822 r
F P
0 g
s
.58819 .51231 m .60118 .51663 L .60915 .54851 L p .468 .438 .742 r
F P
0 g
s
.66267 .63993 m .64889 .63244 L .65527 .60401 L p .598 .596 .821 r
F P
0 g
s
.64058 .5966 m .65527 .60401 L .64889 .63244 L p .559 .552 .803 r
F P
0 g
s
.65527 .60401 m .66993 .60912 L .66267 .63993 L p .598 .596 .821 r
F P
0 g
s
.62588 .58703 m .6112 .57549 L .60915 .54851 L p .499 .472 .758 r
F P
0 g
s
.59865 .48066 m .58785 .4822 L .57019 .4478 L p .444 .425 .743 r
F P
0 g
s
.57019 .4478 m .57794 .44165 L .59865 .48066 L p .444 .425 .743 r
F P
0 g
s
.53028 .31133 m .52986 .31982 L .485 .29322 L p .224 .498 .902 r
F P
0 g
s
.485 .29322 m .48143 .28546 L .53028 .31133 L p .224 .498 .902 r
F P
0 g
s
.84676 .44728 m .83361 .4617 L .81097 .40819 L p .856 .83 .82 r
F P
0 g
s
.81097 .40819 m .82379 .39436 L .84676 .44728 L p .856 .83 .82 r
F P
0 g
s
.75527 .59062 m .74147 .59911 L .73856 .54965 L p .814 .783 .824 r
F P
0 g
s
.73856 .54965 m .75254 .54031 L .75527 .59062 L p .814 .783 .824 r
F P
0 g
s
.64058 .5966 m .62588 .58703 L .62355 .55619 L p .528 .499 .768 r
F P
0 g
s
.60915 .54851 m .62355 .55619 L .62588 .58703 L p .499 .472 .758 r
F P
0 g
s
.62355 .55619 m .60915 .54851 L .60118 .51663 L p .49 .458 .748 r
F P
0 g
s
.59365 .42849 m .58576 .43522 L .55794 .39568 L p .419 .431 .765 r
F P
0 g
s
.55794 .39568 m .56221 .38593 L .59365 .42849 L p .419 .431 .765 r
F P
0 g
s
.61425 .51983 m .60118 .51663 L .58785 .4822 L p .471 .441 .743 r
F P
0 g
s
.58785 .4822 m .59865 .48066 L .61425 .51983 L p .471 .441 .743 r
F P
0 g
s
.31091 .30062 m .32279 .2934 L .27965 .32795 L p .511 .871 .638 r
F P
0 g
s
.27965 .32795 m .26547 .33811 L .31091 .30062 L p .511 .871 .638 r
F P
0 g
s
.57086 .3673 m .56651 .37646 L .52903 .33945 L p .353 .444 .815 r
F P
0 g
s
.52903 .33945 m .52944 .32918 L .57086 .3673 L p .353 .444 .815 r
F P
0 g
s
.60118 .51663 m .61425 .51983 L .62355 .55619 L p .49 .458 .748 r
F P
0 g
s
.83361 .4617 m .82039 .4762 L .79814 .42202 L p .85 .815 .815 r
F P
0 g
s
.79814 .42202 m .81097 .40819 L .83361 .4617 L p .85 .815 .815 r
F P
0 g
s
.60954 .47834 m .59865 .48066 L .57794 .44165 L p .455 .437 .749 r
F P
0 g
s
.57794 .44165 m .58576 .43522 L .60954 .47834 L p .455 .437 .749 r
F P
0 g
s
.47035 .27001 m .47411 .27393 L .42206 .26607 L p 0 .569 .779 r
F P
0 g
s
.46651 .26717 m .47035 .27001 L .41447 .26461 L p .057 0 0 r
F P
0 g
s
.42206 .26607 m .41447 .26461 L .45183 .26822 L p 0 .569 .779 r
F P
0 g
s
.41447 .26461 m .40671 .26456 L .45073 .26648 L p .057 0 0 r
F P
0 g
s
.45073 .26648 m .46651 .26717 L p .45612 .26666 L .057 0 0 r
F P
0 g
s
.41447 .26461 m .45073 .26648 L .45612 .26666 L .057 0 0 r
F
.43402 .26575 m .40671 .26456 L p .42733 .26483 L .092 0 0 r
F P
0 g
s
.42733 .26483 m .4626 .26528 L .43402 .26575 L .092 0 0 r
F
.40671 .26456 m .39879 .26577 L .44992 .26538 L p F P
0 g
s
.44992 .26538 m .4626 .26528 L p .455 .26518 L .092 0 0 r
F P
0 g
s
.40671 .26456 m .44992 .26538 L .455 .26518 L .092 0 0 r
F
.45861 .26418 m .4626 .26528 L .4232 .26558 L p .107 0 0 r
F P
0 g
s
.41541 .26533 m .45861 .26418 L .4232 .26558 L .107 0 0 r
F
.42206 .26607 m .45183 .26822 L .45675 .2689 L 0 .569 .779 r
F
.4232 .26558 m .39879 .26577 L p .41541 .26533 L .107 0 0 r
F P
0 g
s
.39879 .26577 m .3907 .26804 L .44948 .2647 L p .107 0 0 r
F P
0 g
s
.44948 .2647 m .45861 .26418 L p .45359 .26431 L .107 0 0 r
F P
0 g
s
.39879 .26577 m .44948 .2647 L .45359 .26431 L .107 0 0 r
F
.45455 .26369 m .45861 .26418 L .41173 .26684 L p .106 0 0 r
F P
0 g
s
.40377 .26715 m .45455 .26369 L .41173 .26684 L .106 0 0 r
F
.4626 .26528 m .46651 .26717 L .43402 .26575 L p .092 0 0 r
F P
0 g
s
.41173 .26684 m .3907 .26804 L p .40377 .26715 L .106 0 0 r
F P
0 g
s
.3907 .26804 m .38244 .27115 L .44953 .26421 L p .106 0 0 r
F P
0 g
s
.44953 .26421 m .45455 .26369 L p .452 .26387 L .106 0 0 r
F P
0 g
s
.3907 .26804 m .44953 .26421 L .452 .26387 L .106 0 0 r
F
.45041 .26363 m .45455 .26369 L .39952 .26938 L p .09 0 0 r
F P
0 g
s
.39221 .27007 m .45041 .26363 L .39952 .26938 L .09 0 0 r
F
.39952 .26938 m .38244 .27115 L p .39221 .27007 L F P
0 g
s
.38244 .27115 m .37402 .27486 L .4502 .26366 L p .09 0 0 r
F P
0 g
s
.4502 .26366 m .45041 .26363 L p .45031 .26364 L .09 0 0 r
F P
0 g
s
.38244 .27115 m .4502 .26366 L .45031 .26364 L .09 0 0 r
F
.44619 .26379 m .45041 .26363 L .38645 .27303 L p .061 0 0 r
F P
0 g
s
.3806 .27385 m .44619 .26379 L .38645 .27303 L .061 0 0 r
F
.38645 .27303 m .37402 .27486 L p .3806 .27385 L F P
0 g
s
.37402 .27486 m .36543 .27891 L .36906 .27823 L p .061 0 0 r
F P
0 g
s
.36906 .27823 m .44619 .26379 L p .38006 .27393 L .061 0 0 r
F P
0 g
s
.37402 .27486 m .36906 .27823 L .38006 .27393 L .061 0 0 r
F
.4419 .26396 m .44619 .26379 L .37235 .27762 L p .017 0 0 r
F P
0 g
s
.37002 .27804 m .4419 .26396 L .37235 .27762 L .017 0 0 r
F
.36883 .27825 m .37175 .27768 L .37002 .27804 L F
.37175 .27768 m .4419 .26396 L .37002 .27804 L F
.29881 .30829 m .31091 .30062 L .26547 .33811 L p .518 .872 .631 r
F P
0 g
s
.26547 .33811 m .25104 .34876 L .29881 .30829 L p .518 .872 .631 r
F P
0 g
s
.28649 .3161 m .29881 .30829 L .29808 .30891 L p .534 .882 .64 r
F P
0 g
s
.29808 .30891 m .25104 .34876 L p .28649 .3161 L .534 .882 .64 r
F P
0 g
s
.27399 .32374 m .28649 .3161 L .23638 .35959 L p .56 .9 .665 r
F P
0 g
s
.28649 .3161 m .27399 .32374 L .27496 .32326 L p 0 0 0 r
F P
0 g
s
.28649 .3161 m .3567 .28305 L p .30631 .30502 L 0 0 0 r
F P
0 g
s
.29881 .30829 m .28649 .3161 L p .30631 .30502 L 0 0 0 r
F P
0 g
s
.25104 .34876 m .23638 .35959 L .28649 .3161 L p .534 .882 .64 r
F P
0 g
s
.34782 .287 m .3567 .28305 L .28649 .3161 L p 0 0 0 r
F P
0 g
s
.27496 .32326 m .34782 .287 L p .28649 .3161 L 0 0 0 r
F P
0 g
s
.37235 .27762 m .36543 .27891 L p .36883 .27825 L .017 0 0 r
F P
0 g
s
.36543 .27891 m .3567 .28305 L .4419 .26396 L p .017 0 0 r
F P
0 g
s
.43754 .26392 m .4419 .26396 L .3567 .28305 L p 0 0 0 r
F P
0 g
s
.34782 .287 m .4346 .26468 L p .35682 .28302 L 0 0 0 r
F P
0 g
s
.4346 .26468 m .43754 .26392 L p .43257 .2651 L 0 0 0 r
F P
0 g
s
.35682 .28302 m .4346 .26468 L .43257 .2651 L 0 0 0 r
F
.3567 .28305 m .35632 .28322 L p .35682 .28302 L F P
0 g
s
.35632 .28322 m .34782 .287 L p .35682 .28302 L 0 0 0 r
F P
0 g
s
.45183 .26822 m .47035 .27001 L p .45675 .2689 L 0 .569 .779 r
F P
0 g
s
.74147 .59911 m .72748 .60565 L .72444 .55731 L p .782 .749 .823 r
F P
0 g
s
.72444 .55731 m .73856 .54965 L .74147 .59911 L p .782 .749 .823 r
F P
0 g
s
.65527 .60401 m .64058 .5966 L .63801 .56221 L p .56 .53 .778 r
F P
0 g
s
.62355 .55619 m .63801 .56221 L .64058 .5966 L p .528 .499 .768 r
F P
0 g
s
.53071 .30371 m .53028 .31133 L .48143 .28546 L p .172 .515 .915 r
F P
0 g
s
.48143 .28546 m .47781 .27905 L .53071 .30371 L p .172 .515 .915 r
F P
0 g
s
.82039 .4762 m .80708 .4905 L .78528 .43566 L p .84 .798 .811 r
F P
0 g
s
.78528 .43566 m .79814 .42202 L .82039 .4762 L p .84 .798 .811 r
F P
0 g
s
.63801 .56221 m .62355 .55619 L .61425 .51983 L p .515 .479 .755 r
F P
0 g
s
.72748 .60565 m .71331 .61003 L .71021 .56314 L p .746 .712 .82 r
F P
0 g
s
.71021 .56314 m .72444 .55731 L .72748 .60565 L p .746 .712 .82 r
F P
0 g
s
.6016 .42144 m .59365 .42849 L .56221 .38593 L p .422 .442 .776 r
F P
0 g
s
.56221 .38593 m .56651 .37646 L .6016 .42144 L p .422 .442 .776 r
F P
0 g
s
.66993 .60912 m .65527 .60401 L .6525 .5664 L p .595 .563 .788 r
F P
0 g
s
.63801 .56221 m .6525 .5664 L .65527 .60401 L p .56 .53 .778 r
F P
0 g
s
.57526 .35844 m .57086 .3673 L .52944 .32918 L p .339 .459 .835 r
F P
0 g
s
.52944 .32918 m .52986 .31982 L .57526 .35844 L p .339 .459 .835 r
F P
0 g
s
.62741 .52177 m .61425 .51983 L .59865 .48066 L p .489 .458 .749 r
F P
0 g
s
.59865 .48066 m .60954 .47834 L .62741 .52177 L p .489 .458 .749 r
F P
0 g
s
.71331 .61003 m .69897 .61213 L .69587 .56701 L p .709 .674 .814 r
F P
0 g
s
.69587 .56701 m .71021 .56314 L .71331 .61003 L p .709 .674 .814 r
F P
0 g
s
.61425 .51983 m .62741 .52177 L .63801 .56221 L p .515 .479 .755 r
F P
0 g
s
.34585 .28143 m .33444 .28691 L .3907 .26804 L p 0 0 0 r
F P
0 g
s
.62049 .47514 m .60954 .47834 L .58576 .43522 L p .467 .45 .756 r
F P
0 g
s
.58576 .43522 m .59365 .42849 L .62049 .47514 L p .467 .45 .756 r
F P
0 g
s
.6845 .61183 m .66993 .60912 L .66699 .56864 L p .632 .599 .798 r
F P
0 g
s
.6525 .5664 m .66699 .56864 L .66993 .60912 L p .595 .563 .788 r
F P
0 g
s
.69897 .61213 m .6845 .61183 L .68146 .56885 L p .67 .636 .807 r
F P
0 g
s
.68146 .56885 m .69587 .56701 L .69897 .61213 L p .67 .636 .807 r
F P
0 g
s
.66699 .56864 m .68146 .56885 L .6845 .61183 L p .632 .599 .798 r
F P
0 g
s
.80708 .4905 m .79365 .50432 L .77238 .4489 L p .827 .78 .808 r
F P
0 g
s
.77238 .4489 m .78528 .43566 L .80708 .4905 L p .827 .78 .808 r
F P
0 g
s
.6525 .5664 m .63801 .56221 L .62741 .52177 L p .542 .503 .762 r
F P
0 g
s
.60961 .41407 m .6016 .42144 L .56651 .37646 L p .425 .455 .788 r
F P
0 g
s
.56651 .37646 m .57086 .3673 L .60961 .41407 L p .425 .455 .788 r
F P
0 g
s
.79365 .50432 m .78008 .51741 L .75941 .46154 L p .811 .76 .805 r
F P
0 g
s
.75941 .46154 m .77238 .4489 L .79365 .50432 L p .811 .76 .805 r
F P
0 g
s
.64063 .52233 m .62741 .52177 L .60954 .47834 L p .51 .476 .755 r
F P
0 g
s
.60954 .47834 m .62049 .47514 L .64063 .52233 L p .51 .476 .755 r
F P
0 g
s
.53114 .29689 m .53071 .30371 L .47781 .27905 L p .113 .527 .913 r
F P
0 g
s
.47781 .27905 m .47411 .27393 L .53114 .29689 L p .113 .527 .913 r
F P
0 g
s
.57971 .34988 m .57526 .35844 L .52986 .31982 L p .324 .475 .857 r
F P
0 g
s
.52986 .31982 m .53028 .31133 L .57971 .34988 L p .324 .475 .857 r
F P
0 g
s
.62741 .52177 m .64063 .52233 L .6525 .5664 L p .542 .503 .762 r
F P
0 g
s
.63151 .47104 m .62049 .47514 L .59365 .42849 L p .48 .465 .763 r
F P
0 g
s
.59365 .42849 m .6016 .42144 L .63151 .47104 L p .48 .465 .763 r
F P
0 g
s
.66699 .56864 m .6525 .5664 L .64063 .52233 L p .571 .528 .769 r
F P
0 g
s
.78008 .51741 m .76638 .52948 L .74639 .47339 L p .792 .738 .803 r
F P
0 g
s
.74639 .47339 m .75941 .46154 L .78008 .51741 L p .792 .738 .803 r
F P
0 g
s
.68146 .56885 m .66699 .56864 L .65389 .52141 L p .6 .555 .775 r
F P
0 g
s
.64063 .52233 m .65389 .52141 L .66699 .56864 L p .571 .528 .769 r
F P
0 g
s
.76638 .52948 m .75254 .54031 L .73331 .48425 L p .77 .714 .801 r
F P
0 g
s
.73331 .48425 m .74639 .47339 L .76638 .52948 L p .77 .714 .801 r
F P
0 g
s
.33444 .28691 m .32279 .2934 L .38244 .27115 L p 0 0 0 r
F P
0 g
s
.61768 .40638 m .60961 .41407 L .57086 .3673 L p .43 .471 .801 r
F P
0 g
s
.57086 .3673 m .57526 .35844 L .61768 .40638 L p .43 .471 .801 r
F P
0 g
s
.65389 .52141 m .64063 .52233 L .62049 .47514 L p .531 .495 .761 r
F P
0 g
s
.62049 .47514 m .63151 .47104 L .65389 .52141 L p .531 .495 .761 r
F P
0 g
s
.69587 .56701 m .68146 .56885 L .66717 .51896 L p .631 .582 .781 r
F P
0 g
s
.65389 .52141 m .66717 .51896 L .68146 .56885 L p .6 .555 .775 r
F P
0 g
s
.64259 .46598 m .63151 .47104 L .6016 .42144 L p .495 .481 .771 r
F P
0 g
s
.6016 .42144 m .60961 .41407 L .64259 .46598 L p .495 .481 .771 r
F P
0 g
s
.75254 .54031 m .73856 .54965 L .72016 .49396 L p .745 .69 .798 r
F P
0 g
s
.72016 .49396 m .73331 .48425 L .75254 .54031 L p .745 .69 .798 r
F P
0 g
s
.5842 .34161 m .57971 .34988 L .53028 .31133 L p .308 .495 .878 r
F P
0 g
s
.53028 .31133 m .53071 .30371 L .5842 .34161 L p .308 .495 .878 r
F P
0 g
s
.53158 .29082 m .53114 .29689 L .47411 .27393 L p .052 .531 .89 r
F P
0 g
s
.47411 .27393 m .47035 .27001 L .53158 .29082 L p .052 .531 .89 r
F P
0 g
s
.73856 .54965 m .72444 .55731 L .70697 .50239 L p .719 .664 .795 r
F P
0 g
s
.70697 .50239 m .72016 .49396 L .73856 .54965 L p .719 .664 .795 r
F P
0 g
s
.71021 .56314 m .69587 .56701 L .68046 .51495 L p .661 .609 .786 r
F P
0 g
s
.66717 .51896 m .68046 .51495 L .69587 .56701 L p .631 .582 .781 r
F P
0 g
s
.72444 .55731 m .71021 .56314 L .69373 .50942 L p .69 .637 .791 r
F P
0 g
s
.69373 .50942 m .70697 .50239 L .72444 .55731 L p .69 .637 .791 r
F P
0 g
s
.68046 .51495 m .69373 .50942 L .71021 .56314 L p .661 .609 .786 r
F P
0 g
s
.66717 .51896 m .65389 .52141 L .63151 .47104 L p .554 .515 .767 r
F P
0 g
s
.63151 .47104 m .64259 .46598 L .66717 .51896 L p .554 .515 .767 r
F P
0 g
s
.62582 .39835 m .61768 .40638 L .57526 .35844 L p .435 .488 .816 r
F P
0 g
s
.57526 .35844 m .57971 .34988 L .62582 .39835 L p .435 .488 .816 r
F P
0 g
s
.65371 .45996 m .64259 .46598 L .60961 .41407 L p .51 .499 .78 r
F P
0 g
s
.60961 .41407 m .61768 .40638 L .65371 .45996 L p .51 .499 .78 r
F P
0 g
s
.68046 .51495 m .66717 .51896 L .64259 .46598 L p .577 .537 .773 r
F P
0 g
s
.58875 .3336 m .5842 .34161 L .53071 .30371 L p .29 .516 .9 r
F P
0 g
s
.53071 .30371 m .53114 .29689 L .58875 .3336 L p .29 .516 .9 r
F P
0 g
s
.64259 .46598 m .65371 .45996 L .68046 .51495 L p .577 .537 .773 r
F P
0 g
s
.37402 .27486 m .38244 .27115 L .32279 .2934 L p 0 0 0 r
F P
0 g
s
.32279 .2934 m .31091 .30062 L .37402 .27486 L p 0 0 0 r
F P
0 g
s
.69373 .50942 m .68046 .51495 L .65371 .45996 L p .601 .558 .779 r
F P
0 g
s
.53203 .28543 m .53158 .29082 L .47035 .27001 L p 0 .527 .848 r
F P
0 g
s
.47035 .27001 m .46651 .26717 L .53203 .28543 L p 0 .527 .848 r
F P
0 g
s
.23638 .35959 m .22154 .37026 L .27399 .32374 L p .56 .9 .665 r
F P
0 g
s
.63401 .39001 m .62582 .39835 L .57971 .34988 L p .441 .507 .831 r
F P
0 g
s
.57971 .34988 m .5842 .34161 L .63401 .39001 L p .441 .507 .831 r
F P
0 g
s
.66487 .45299 m .65371 .45996 L .61768 .40638 L p .527 .518 .789 r
F P
0 g
s
.61768 .40638 m .62582 .39835 L .66487 .45299 L p .527 .518 .789 r
F P
0 g
s
.70697 .50239 m .69373 .50942 L .66487 .45299 L p .624 .581 .785 r
F P
0 g
s
.65371 .45996 m .66487 .45299 L .69373 .50942 L p .601 .558 .779 r
F P
0 g
s
.8366 .38074 m .82379 .39436 L .77759 .34508 L p .784 .778 .847 r
F P
0 g
s
.77759 .34508 m .78901 .33274 L .8366 .38074 L p .784 .778 .847 r
F P
0 g
s
.82379 .39436 m .81097 .40819 L .76621 .35749 L p .778 .762 .839 r
F P
0 g
s
.76621 .35749 m .77759 .34508 L .82379 .39436 L p .778 .762 .839 r
F P
0 g
s
.72016 .49396 m .70697 .50239 L .67606 .44509 L p .647 .603 .791 r
F P
0 g
s
.66487 .45299 m .67606 .44509 L .70697 .50239 L p .624 .581 .785 r
F P
0 g
s
.81097 .40819 m .79814 .42202 L .75487 .36985 L p .769 .746 .832 r
F P
0 g
s
.75487 .36985 m .76621 .35749 L .81097 .40819 L p .769 .746 .832 r
F P
0 g
s
.59335 .32584 m .58875 .3336 L .53114 .29689 L p .273 .54 .92 r
F P
0 g
s
.53114 .29689 m .53158 .29082 L .59335 .32584 L p .273 .54 .92 r
F P
0 g
s
.79814 .42202 m .78528 .43566 L .74356 .38205 L p .757 .728 .825 r
F P
0 g
s
.74356 .38205 m .75487 .36985 L .79814 .42202 L p .757 .728 .825 r
F P
0 g
s
.73331 .48425 m .72016 .49396 L .68727 .43631 L p .669 .625 .796 r
F P
0 g
s
.67606 .44509 m .68727 .43631 L .72016 .49396 L p .647 .603 .791 r
F P
0 g
s
.78528 .43566 m .77238 .4489 L .73227 .39395 L p .743 .709 .819 r
F P
0 g
s
.73227 .39395 m .74356 .38205 L .78528 .43566 L p .743 .709 .819 r
F P
0 g
s
.74639 .47339 m .73331 .48425 L .6985 .42672 L p .69 .647 .802 r
F P
0 g
s
.68727 .43631 m .6985 .42672 L .73331 .48425 L p .669 .625 .796 r
F P
0 g
s
.77238 .4489 m .75941 .46154 L .721 .40544 L p .727 .689 .813 r
F P
0 g
s
.721 .40544 m .73227 .39395 L .77238 .4489 L p .727 .689 .813 r
F P
0 g
s
.67606 .44509 m .66487 .45299 L .62582 .39835 L p .544 .538 .798 r
F P
0 g
s
.62582 .39835 m .63401 .39001 L .67606 .44509 L p .544 .538 .798 r
F P
0 g
s
.75941 .46154 m .74639 .47339 L .70974 .4164 L p .709 .668 .807 r
F P
0 g
s
.6985 .42672 m .70974 .4164 L .74639 .47339 L p .69 .647 .802 r
F P
0 g
s
.70974 .4164 m .721 .40544 L .75941 .46154 L p .709 .668 .807 r
F P
0 g
s
.64226 .38135 m .63401 .39001 L .5842 .34161 L p .448 .529 .848 r
F P
0 g
s
.5842 .34161 m .58875 .3336 L .64226 .38135 L p .448 .529 .848 r
F P
0 g
s
.53249 .28061 m .53203 .28543 L .46651 .26717 L p 0 .519 .796 r
F P
0 g
s
.46651 .26717 m .4626 .26528 L .53249 .28061 L p 0 .519 .796 r
F P
0 g
s
.36543 .27891 m .37402 .27486 L .31091 .30062 L p 0 0 0 r
F P
0 g
s
.31091 .30062 m .29881 .30829 L .36543 .27891 L p 0 0 0 r
F P
0 g
s
.68727 .43631 m .67606 .44509 L .63401 .39001 L p .561 .559 .808 r
F P
0 g
s
.63401 .39001 m .64226 .38135 L .68727 .43631 L p .561 .559 .808 r
F P
0 g
s
.59801 .31828 m .59335 .32584 L .53158 .29082 L p .258 .565 .936 r
F P
0 g
s
.53158 .29082 m .53203 .28543 L .59801 .31828 L p .258 .565 .936 r
F P
0 g
s
.65058 .37241 m .64226 .38135 L .58875 .3336 L p .457 .552 .865 r
F P
0 g
s
.58875 .3336 m .59335 .32584 L .65058 .37241 L p .457 .552 .865 r
F P
0 g
s
.6985 .42672 m .68727 .43631 L .64226 .38135 L p .579 .58 .818 r
F P
0 g
s
.64226 .38135 m .65058 .37241 L .6985 .42672 L p .579 .58 .818 r
F P
0 g
s
.70974 .4164 m .6985 .42672 L .65058 .37241 L p .596 .602 .828 r
F P
0 g
s
.53295 .27626 m .53249 .28061 L .4626 .26528 L p 0 .513 .746 r
F P
0 g
s
.4626 .26528 m .45861 .26418 L .53295 .27626 L p 0 .513 .746 r
F P
0 g
s
.721 .40544 m .70974 .4164 L .65895 .36319 L p .614 .625 .838 r
F P
0 g
s
.65058 .37241 m .65895 .36319 L .70974 .4164 L p .596 .602 .828 r
F P
0 g
s
.3567 .28305 m .36543 .27891 L .29881 .30829 L p 0 0 0 r
F P
0 g
s
.65895 .36319 m .65058 .37241 L .59335 .32584 L p .467 .578 .882 r
F P
0 g
s
.59335 .32584 m .59801 .31828 L .65895 .36319 L p .467 .578 .882 r
F P
0 g
s
.60273 .3109 m .59801 .31828 L .53203 .28543 L p .246 .591 .948 r
F P
0 g
s
.53203 .28543 m .53249 .28061 L .60273 .3109 L p .246 .591 .948 r
F P
0 g
s
.73227 .39395 m .721 .40544 L .66738 .35373 L p .631 .647 .848 r
F P
0 g
s
.65895 .36319 m .66738 .35373 L .721 .40544 L p .614 .625 .838 r
F P
0 g
s
.74356 .38205 m .73227 .39395 L .67586 .34406 L p .647 .67 .858 r
F P
0 g
s
.66738 .35373 m .67586 .34406 L .73227 .39395 L p .631 .647 .848 r
F P
0 g
s
.66738 .35373 m .65895 .36319 L .59801 .31828 L p .478 .605 .899 r
F P
0 g
s
.75487 .36985 m .74356 .38205 L .68441 .3342 L p .662 .692 .867 r
F P
0 g
s
.67586 .34406 m .68441 .3342 L .74356 .38205 L p .647 .67 .858 r
F P
0 g
s
.59801 .31828 m .60273 .3109 L .66738 .35373 L p .478 .605 .899 r
F P
0 g
s
.53342 .27226 m .53295 .27626 L .45861 .26418 L p 0 .515 .708 r
F P
0 g
s
.45861 .26418 m .45455 .26369 L .53342 .27226 L p 0 .515 .708 r
F P
0 g
s
.76621 .35749 m .75487 .36985 L .69303 .32419 L p .676 .713 .876 r
F P
0 g
s
.68441 .3342 m .69303 .32419 L .75487 .36985 L p .662 .692 .867 r
F P
0 g
s
.60751 .30364 m .60273 .3109 L .53249 .28061 L p .24 .617 .956 r
F P
0 g
s
.53249 .28061 m .53295 .27626 L .60751 .30364 L p .24 .617 .956 r
F P
0 g
s
.77759 .34508 m .76621 .35749 L .7017 .31407 L p .688 .733 .885 r
F P
0 g
s
.69303 .32419 m .7017 .31407 L .76621 .35749 L p .676 .713 .876 r
F P
0 g
s
.67586 .34406 m .66738 .35373 L .60273 .3109 L p .492 .632 .915 r
F P
0 g
s
.78901 .33274 m .77759 .34508 L .71045 .30387 L p .698 .751 .893 r
F P
0 g
s
.7017 .31407 m .71045 .30387 L .77759 .34508 L p .688 .733 .885 r
F P
0 g
s
.60273 .3109 m .60751 .30364 L .67586 .34406 L p .492 .632 .915 r
F P
0 g
s
.71045 .30387 m .71927 .29362 L .78901 .33274 L p .698 .751 .893 r
F P
0 g
s
.68441 .3342 m .67586 .34406 L .60751 .30364 L p .506 .66 .93 r
F P
0 g
s
.5339 .26848 m .53342 .27226 L .45455 .26369 L p .059 0 0 r
F P
0 g
s
.45455 .26369 m .45041 .26363 L .5339 .26848 L p .059 0 0 r
F P
0 g
s
.61234 .29645 m .60751 .30364 L .53295 .27626 L p .242 .644 .961 r
F P
0 g
s
.53295 .27626 m .53342 .27226 L .61234 .29645 L p .242 .644 .961 r
F P
0 g
s
.60751 .30364 m .61234 .29645 L .68441 .3342 L p .506 .66 .93 r
F P
0 g
s
.69303 .32419 m .68441 .3342 L .61234 .29645 L p .522 .688 .943 r
F P
0 g
s
.7017 .31407 m .69303 .32419 L .61723 .2893 L p .539 .715 .954 r
F P
0 g
s
.61234 .29645 m .61723 .2893 L .69303 .32419 L p .522 .688 .943 r
F P
0 g
s
.61723 .2893 m .61234 .29645 L .53342 .27226 L p .253 .672 .964 r
F P
0 g
s
.53342 .27226 m .5339 .26848 L .61723 .2893 L p .253 .672 .964 r
F P
0 g
s
.53439 .2648 m .5339 .26848 L .45041 .26363 L p .029 0 0 r
F P
0 g
s
.45041 .26363 m .44619 .26379 L .53439 .2648 L p .029 0 0 r
F P
0 g
s
.71045 .30387 m .7017 .31407 L .62219 .28211 L p .556 .739 .962 r
F P
0 g
s
.61723 .2893 m .62219 .28211 L .7017 .31407 L p .539 .715 .954 r
F P
0 g
s
.62219 .28211 m .61723 .2893 L .5339 .26848 L p .275 .702 .967 r
F P
0 g
s
.71927 .29362 m .71045 .30387 L .6272 .27484 L p .575 .762 .967 r
F P
0 g
s
.62219 .28211 m .6272 .27484 L .71045 .30387 L p .556 .739 .962 r
F P
0 g
s
.5339 .26848 m .53439 .2648 L .62219 .28211 L p .275 .702 .967 r
F P
0 g
s
.53488 .26106 m .53439 .2648 L .44619 .26379 L p 0 0 0 r
F P
0 g
s
.44619 .26379 m .4419 .26396 L .53488 .26106 L p 0 0 0 r
F P
0 g
s
.6272 .27484 m .63227 .26744 L .71927 .29362 L p .575 .762 .967 r
F P
0 g
s
.6272 .27484 m .62219 .28211 L .53439 .2648 L p .307 .732 .972 r
F P
0 g
s
.53439 .2648 m .53488 .26106 L .6272 .27484 L p .307 .732 .972 r
F P
0 g
s
.53539 .25714 m .53488 .26106 L .4419 .26396 L p .083 .643 .739 r
F P
0 g
s
.4419 .26396 m .43754 .26392 L .53539 .25714 L p .083 .643 .739 r
F P
0 g
s
.63227 .26744 m .6272 .27484 L .53488 .26106 L p .348 .762 .979 r
F P
0 g
s
.53488 .26106 m .53539 .25714 L .63227 .26744 L p .348 .762 .979 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo6Ol00005oeW3nP_o0000
9Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo000]ooooo`;o00000_oo
ool00ol0003oooooooooo`1^oooooaCo000000?o5JBmo`000?l000005_l00003odjkn0Go00002?mI
`oX;o`0001[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`00;?ooool2
o`0000Cooooo00?o0000ooooooooool0J?oooolJo`000003o`23__l0003o000000go00001ol70000
0ol0003oA[?godJcm`02o`0000GoC[_h1_l0000<oeW3nPOo00004oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02kooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0I?ooool4o`000003oa/00?l0003o000000_o00000_lBV=l00ol0003o0977o`00000:o`00
00Co08>n3ol00008odJcm`Co00001?m>^oP6o`0000[oFL?j00?o0000oi?3monC`oL00ol0000@oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Pooooo`ko00001?mHaOT;o`0000?o4YSO1Ol00002o`26f@Go
00000_l0Pkh9o`0000;o@:cf0_l00009odJcm`Co00001Om>^oP6o`0000?oFL?j00?o0000oi?3monC
`oL01?nC`oL3o`0000gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00
;?ooool3o`0000Kooooo00?o0000ooooooooool0G?ooool>o`0000;oF<Gi1?l00006of:jo@04o`00
0?lhU_7o>9Kao`0000;o9Y[^1Ol000001OlBV=oo0000oab6jOl0003o3HOS00;o000000?o08KIo`00
0?l000001?l00004o`23_P?o00000_lmY?H00ol0003o@:cfod2/mP02od2/mPCo00001_m6/oL5o`00
00KoC[_h0ol0000:oi?3m`?o00002_ooool00ol0003oooooooooo`0booooo`;o0000;Oooool002co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`_o00000_nNhod01?l0003o
VM7koiWAnonIdO/2o`0000[oH[[m00?o0000ocRFlOlhU_400_lhU_44o`000004obJJk_l0003o0000
o`0000?o78KY00?o0000o`f7hol000000_l000000ol0Q]Wo0000o`000005o`000004o`23__l0003o
?Igdo`0000?o?JCf0ol00004od2/mPCo00001_m6/oL5o`0000;oC[_h00Go0000ohjmm_n>_OKoS[gf
o`00000:oi?3m`?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool;o`0000?o
W^?m0_l00005oiWAn`;o000000?oH[[mo`000?l000002?l00007ocRFl@Co000000?o;8?Zo`000?lL
Q^T00_lLQ^T2o`000004o`f7hol0003o0000o`0000;o08KI1Ol00004ocfMm0;o00000_lmY?H3o`00
00Go@:cf1Ol00006odJcm`;o00001on>_OH3o`0000SoTl?g0ol00005ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0:_ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0D_ooool8o`0000?oW^of00Go0000oikSoOnNhogoW^?mo`000005oiWAn`;o00000onB__@0
0ol0003oIj_gofN[m`07ofN[m`03o`000?m6S^go000000;o00001OlhU_42o`0000;o;8?Z0_l00002
oab6j@?o000000Co3HOSo`000?l0003o00000_l0Q]T2o`000003ocjGl_l0003o?Igd00Co?Igd0_l0
0002ocfTmPCo00001_m0[?H5o`0000;oA[?g00?o0000ohVgm?l000002?n>_OH3o`0000SoTl?g0ol0
0002ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002ooo
ool00ol0003oooooooooo`1?ooooo`Oo000000?oVo?Xo`000?nNkoH00_nNkoH01Ol0003oW^?moikS
oOnNhogo000000CoVM7k0_l00005oi:nm0;o000000?oIj_go`000?l000001ol00003odJ>k@?o0000
0olhU_400ol0003o>GoVobb3jP02obb3jP;o00000olLQ^T2o`0000;o3HOS1?l000000om2T>oo?YOb
ocjGlP02o`0000Go?Igd0ol00002ocfTmP?o00002?m0[?H2o`0000GoRKOd0_l00007ohjmmP?o0000
2?nC`oL3o`0003Kooooo00?o0000ooooooooool0:Oooool0017ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`1<ooooo`Oo00000_nKlnP4oik_mPCoW^?m1OnIdO/00ol0003oT[kdoi:nm003oi:nm0;o0000
0_n:Zn/00ol0003oJI_]ofVKk@06ofVKk@04o`000?m@QNGo0000o`0000?oAXk]0ol000001OlhU_7o
0000ocUoi_liOnKo000000;o;8?Z0ol00002oab6j@;o00000ol=Qn<01Ol0003o@Y3_od:@kom2T>oo
000000;o?YOb0_l00005ocfMm0;o00000olmY?H3o`0000Ko@:cf00?o0000ohF`lOl000001On9]o@3
o`0000OoS[gf0ol00007oi?3m`Co0000=?ooool00ol0003oooooooooo`0Xooooo`004Oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0BOooool6o`000003oiCae_l0003o000000_o00000onI
dO/00ol0003oT[kdoi:nm002oi:nm0;o00001On:Zn/00ol0003oJI_]ofVKk@06ofVKk@04o`000?m@
QNGoD8GUoe25i@?o00000_m6S^d2o`0000?o>GoV0_l00003obb3jP;o00000_lLQ^T4o`000003odF:
jom2T>oo@Y3_00;o@Y3_00?o0000ocjGl_lnUo800_l00005ocfMm0?o00000olmY?H3o`0000;o@:cf
00?o0000ohF`lOn5/?400_n5/?42o`0000GoRKOd0_l00008ohjmmP?o00001?nC`oL01?l0003oTl?g
oi?3monC`oL3o`00037ooooo0_l0000Yooooo`004Oooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000ooooooooool0A_ooool9o`0000;o
d?;X00Go0000ol[Xjoo:j>_ob^S[o`000003ol7Kk003o`000?ngc>[o]lcZ00Co00000onB__@00ol0
003oRZ_[ohZ[j`05ohZ[j`Oo00000omYVnd00ol0003oD8GUoe25i@03oe25i@;o000000?oAXk]o`00
0?m4N^401?liOnH2o`0000?o;8?Z0_l00003oab6j@05o`000?m5R^_oAH[[odF:jol000000om2T>l2
o`000004ocjGl_l0003o0000o`0000Go?Igd0ol00003ocfTmP;o00001on5/?42o`0000GoRKOd0ol0
0008ohjmmP?o000000?oTl?go`000?nC`oL00_nC`oL00ol0003o//3Tok;0i002o`0002oooooo0_l0
000Yooooo`004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo2?l000001OoDnN;o0000om3b
j?o@l^So000000?ob^S[00Go0000ol7Kk?o1fnco`M_/o`000004okO<jP03o`000?n[^nGoZk_U00?o
00001On:Zn/3o`000003oh>JhOl0003oJXkR00CoJXkR1Ol00006oe25i@?o00000_m4N^401?l0003o
>GoVocUoi_liOnH2o`0000?o;8?Z0_l000000olLQ^Wo0000odZ4iP04odF:j`04o`000?m2T>oo@Y3_
od:@k`;o00000_lnUo82o`0000Ko?Igd0ol000001?lmY?Ko0000oh6Xk_l00007ohF`l@;o00001_n9
]o@2o`0000WoS[gf0ol000000onC`oOo0000ok;0i004ok;0i003o`000?oooooooooo02kooooo00?o
0000ooooooooool09_ooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Ooo
ool00ol0003oooooooooo`0@ooooo`;o0000@_ooool6o`0000?oe?WR00Go0000om3bj?o@l^Sod?;X
o`000002ol[Xj`03o`000?o1fnco`M_/00;o`M_/00Go0000okO<j_ngc>[o]lcZo`000004oj^ki@04
o`000?nOZmoo0000o`0000;oRZ_[00?o0000oh>JhOn3V^400on3V^400ol0003oJXkRofZ>hP06ofZ>
hP03o`000?mGOMco000000;o00001Om@QND00ol0003oA7[QodAjh@02o`0000?o>GoV0_l00003obb3
jP05o`000?m:Q>KoBXCVodZ4i_l000000om5R^/2o`0000?o@Y3_00Co0000ocjGl_lnUo;o?YOb0_l0
0007ocfMm003o`000?n1Z>koPJS^00;oPJS^0_l00006ohF`l@;o00001_n9]o@2o`0000OoS[gf0_l0
00000on>_OKo0000ok;0i006ok;0i0;o0000;_ooool00ol0003oooooooooo`0Vooooo`00:_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03kooooo1Ol000000ooFoM_o0000omCihP02
omCihP04o`000?o@l^Sod?;Xo`0000?ob^S[00Go0000ol7Kk?o1fnco`M_/o`000003okO<jP03o`00
0?n[^nGoZk_U00;oZk_U00?o0000oin[gonOZml00_nOZml00ol0003oPi[Qoh>Jh@06oh>Jh@03o`00
0?mZS^;oJXkR00KoJXkR00Co0000oeMmg?mGOMcoEggL0ol00002oe25i@03o`000?m=M][oA7[Q00;o
A7[Q0_l00003ocUoiP05o`000?l/Pn[o;8?Zo`000?m>O^001?m:Q>H01?l0003oAH[[odF:jom5R^/2
o`0000;o@Y3_0_l00003ocjGlP?o00001?lmWO@00ol0003oOJ7Zoh6XkP04oh6XkP;o00001_n5/?43
o`0000GoRKOd0ol000002On>_OKo0000o`000?l0003oS[gfo`000?n>_OKo0000ok2khP08ok;0i0;o
0000;Oooool00ol0003oooooooooo`0Uooooo`00:_ooool2o`0001Gooooo00?o0000ooooooooool0
>oooool5o`0000;oe_gK00Go0000omCih_oDnN;oe?WRo`000003om3bj004o`000?o:j>_ob^S[o`00
00?o`M_/00?o0000okO<j_ngc>X00_ngc>X01Ol0003oZk_Uoj^kiOn[^nGo000000GoWj_O00?oU9gI
o`000?n3V^401_n3V^4;o`0000GoEggL1?l000000om=M][o0000odAjh@02odAjh@04o`000?liOnKo
>GoVocUoiP?o00000_m>O^001?l0003oBXCVodZ4i_m:Q>H2o`0000?oAH[[0_l00002od:@k`;o0000
1?lnUo82o`000003ocfMm?l0003oOJ7Z00?oOJ7Z00?o0000oh6Xk_n1Z>h00_n1Z>h2o`0000OoQK3a
0_l00004ohVgm0Co00001?n>_OH01?l0003o/;_Rok2kh_n`^n82o`0000Oo//3T0_l0000/ooooo`03
o`000?oooooooooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
>?ooool5o`000005omKoeOl0003oe_gKomKmfol000000_oDnN801Ol0003od?;Xom3bj?o@l^So0000
00?ob^S[00Go0000ol7Kk?o1fnco`M_/o`000003okO<jP03o`000?n[^nGoZk_U00;oZk_U00?o0000
oin[gonOZml00_nOZml01?l0003oU9gIoiBMfOl00004oh>Jh@;o000000?oO8cHo`000?mZPmT01omZ
PmT01?l0003oG7ODo`000?l00005oeMmg005o`000?m=M][oCGKJodeff_l000000_m4N^42o`0000?o
>GoV00Co0000odinh?m>O^3oCWkP0_l00003odZ4iP03o`000?m5R^_oAH[[00;oAH[[0_l00002od:@
k`;o00001?lnUo800ol0003oOJ7ZogfQjP04ogfQjP;o00001?n1Z>h2o`0000OoQK3a1?l00004ohVg
m0?o000000?oS[gfo`000?l000001?n`^n82o`0000Oo//3T0_l0000Zooooo`;o00009Oooool002[o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`Go00000_oFomD01?l0003o
e_gKomKmfol00003omCihP04o`000?o@l^Sod?;Xo`0000?ob^S[00Go0000ol7Kk?o1fnco`M_/o`00
0004okO<jP05o`000?n[^nGoZk_Uoj^kiOl000001OnOZml01_l0003oU9gIoiBMfOnDWMWo0000oh>J
h@;o00001?mlS=P00ol0003oJX?IofZ3f@06ofZ3f@03o`000?mLMmCoG7OD00;o00000omGOM`00ol0
003oE77CodeffP02odeffP;o00000_m4N^42o`000003ocUoi_l0003oDWWK00CoCWkP00Co0000odZ4
i_m:Q>KoBXCV0_l00004odF:j`04o`000?m2T>oo@Y3_od:@k`;o000000Co?YObo`000?mjV^KoNY[V
1ommXNX2o`0000CoPJS^0_l00003ohF`l@?o000000?oQK3ao`000?l000001on9]o@01?l0003o/;_R
ok2kh_l00005ok2khP03o`000?nb`>Co//3T00Ko//3T00?o0000ooooooooool09oooool2o`0000So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Oooooo000Zooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<oooool5o`00
00?oe_oE00?o0000omKmfol000000ooDnN801Ol0003od?;Xom3bj?o@l^So000000;ob^S[00?o0000
ol7Kk?o1fn`00_o1fn`01Ol0003o]lcZokO<j_ngc>[o000000CoZk_U00?o0000oin[gonOZml00_nO
Zml00ol0003oU9gIoiBMf@03oiBMf@;o00001_mlS=P00ol0003oJX?IofZ3f@05ofZ3f@03o`000?mL
MmCoG7OD00;oG7OD0_l000001OmGOMco0000oeAadomDLM?o000000?oCGKJ00Co0000odAjhOm4N^7o
A7[Q0_l00002oe9if`04o`000?m>O^3oCWkPodinh0;o00000om:Q>H00ol0003oAH[[odF:j`02odF:
j`;o00000om2T>l00ol0003oNY[VogZJiP02ogZJiP;o00001_mmXNX00ol0003oPJS^oh6XkP03oh6X
kP?o00001_n5/?42o`0000CoRKOd00Go0000ojffh?n]]^3o/;_Ro`000006ok2khP;o00001onb`>@2
o`0002Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o00006Oooool00ol0003oooooooooo`0a
ooooo`?o000000?oP]jSomGocol000000_oFomD01?l0003oe_gKomKmfol00003omCihP04o`000?o@
l^Sod?;Xo`0000?ob^S[00?o0000ol7Kk?l000002?l00002oj^ki@03o`000?nOZmooWj_O00?oWj_O
00?o0000oiBMfOnDWMT00onDWMT2oh^@d`03o`000?mlS=SoO8cH00?oO8cH1_l00002ofZ3f@03o`00
0?mLMmCoG7OD00CoG7OD0ol00002oeAad`;o00000_m=M]X01Ol0003oA7[QodAjhOm4N^7o000000?o
DWWK0_l00003odinh004o`000?m:Q>KoBXCVodZ4iP;o00001?m5R^/2o`000003od:@kol0003oMi?Q
00GoNY[V00?o0000ogfQj_mmXNX01?mmXNX5o`0000;oPJS^0_l00007ohF`l@;o000000?oRKOdo`00
0?n]]^000on]]^02o`0000Oo/;_R00?o0000ok;0i?nb`>@01_nb`>@2o`0002Oooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool0
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`;o000000GoR>6So`00
0?n2gZ?oeOo?o`000003omKoe@03o`000?oFoM_o000000?oe?WR00Co0000om3bj?o@l^Sod?;X1_l0
0002olG5f@05o`000?nk^]So^k[Hok^jf?l000000_na[mH3o`0000CoWj_O00?o0000oiBMfOnDWMT0
0onDWMT01_l0003oRi3Coh^@don;T=?o0000ogb<f0?o000000?oMh7@o`000?mZN]000omZN]04o`00
00OoG7OD00?o0000oeAadomDLM<00_mDLM<00ol0003oCGKJodeffP02o`000003odAjhOl0003oEWGE
00CoDWWK00Go0000odinh?m>O^3oCWkPo`000004odZ4iP03o`000?m5R^_oAH[[00?oAH[[00Go0000
ogNChOmgTn7oMi?Qo`000004ogZJiP;o00000ommXNX5o`0000GoPJS^0_l00007ohF`l@03o`000?n]
]^3o[KKP00Go[KKP00?o0000ok2kh_n`^n801On`^n82o`0000So//3T0_l0000Vooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo
000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool00ol0003oSnJZohSQ
X`02o`0000;oeOo?00Co0000omKoeOoFomGo00000_oFoM/01?l0003oe?WRomCih_l00002om3bj0?o
00000_o>cmX00ol0003oaLGIolG5f@02olG5f@05o`000?nk^]So^k[Hok^jf?l000000ona[mH2ojJS
d`?o000000?oWj_Oo`000?nDWMT00onDWMT00ol0003oRi3Coh^@d`03oh^@d`03o`000?mgPM3oMh7@
00?oMh7@00?o0000ofYjd?mZN]001?mZN]001?l0003oH77=o`000?l00004oeage003o`000?mIK/ko
E77C00?oE77C00Co0000odeff_m=M][oCGKJ0_l00002oeIee@05o`000?mBNM_oDWWKoe9ifol00000
0om>O^02o`0000?oBXCV0_l00003odF:j`03o`000?mdSMgoMi?Q00;oMi?Q0_l00004ogZJiP?o0000
1OmmXNX00ol0003oPJS^oh6XkP04oh6XkP;o00001?n5/?400ol0003oZK7MojVag@07ojffh0;o0000
1on`^n800ol0003o//3Tok;0i007ok;0i003o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007oooo
o`00:Oooool3o`0001cooooo00?o0000ooooooooool0:_ooool02?l0003oSnJZohSQXon4gj7oe?o;
o`000?oEoloo00000_oFomD01?l0003oe_gKomKmfol00003omCihP?o000000?oe]OIo`000?o>cmX0
0_o>cmX00ol0003oaLGIolG5f@02olG5f@05o`000?nk^]So^k[Hok^jf?l000000ona[mH5ojJSd`;o
00001?nDWMT00ol0003oRi3Coh^@d`03oh^@d`03o`000?mgPM3oMh7@00CoMh7@00?o0000ofYjd?mZ
N]001?mZN]000ol0003oH77=of1ac@02o`0000;oG7OD00Co0000oeU^c_mIK/ko00000omDLM<2o`00
00;oCGKJ00Go0000oeIeeOmFMMGoEWGEo`000003oe9if`;o00000om>O^000ol0003oBXCVodZ4iP02
odZ4iP03o`000?m5R^_o000000?oM8gM1?mgTn44o`000003ogZJi_l0003o000000KoOJ7Z0_l00006
oh6XkP;o000000?oQK3ao`000?nY/Md00onY/Md00ol0003o[KKPojffh003ojffh003o`000?n]]^3o
000000Oo/;_R0_l00008ok;0i0;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Sooooo00Ko0000ohoVZ_n8hJ?oQ=nQomCobol00002omGoc`06o`00
0?oFomGoe_oEo`000?oFoM_o00000_oDnN82o`0000Coe]OI00Go0000olk?f_o>cm[oc/oJo`000003
olG5f@05o`000?nk^]So^k[Hok^jf?l000001?na[mH00ol0003oYZ?CojJSd`02ojJSd`;oViS@0_l0
00000onDWMWo0000oh^@d`04oh^@d`03o`000?n2Q<go000000KoMh7@00?o0000ofYjd?mZN]000omZ
N]000ol0003oH77=of1ac@02of1ac@04o`000?mLMmCoG7ODo`0000;oFFk>00?o0000oeAadomDLM<0
0_mDLM<01?l0003oCGKJo`000?mJLM03oeIee@;o00000omBNM/01?l0003oCWkPodinh?m>O^02o`00
00?oBXCV00?o0000ogB=gOmdSMd00omdSMd5o`0000GoNY[V00?o0000ogfQj_mmXNX01OmmXNX2o`00
00KoPJS^00?o0000ojVagOnY/Md01?nY/Md2o`0000Co[KKP00Co0000ojffh?l0003o00001on`^n82
o`0000So//3T00?o0000ooooooooool08?ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool09_ooool01?l0003oSnJZohSQXon4gj42omCob`03o`000?oEoloo000000;oe_oE00?o
0000omKmfooFoM/00ol000000ooLg]Oo0000omKGf@03omKGf@04o`000?o>cm[oc/oJo`0000CoaLGI
00Go0000ok^jf?nk^]So^k[Ho`000004ok6_eP03o`000?nVXm?oYZ?C00;oYZ?C1?nKV=02o`0000Co
Ri3C00Go0000oh:4cOn2Q<goPXC=o`000005ogN1d0Go000000?oJW[@o`000?mPLLd01?mPLLd3o`00
00?oFFk>0_l00003oeAad`;o00000_mJLM001Ol0003oEWGEoeIeeOmFMMGo000000?oDWWK00?o0000
odinh?m>O^000_m>O^001Ol0003oBXCVodZ4i_l0003oLXOI00;oM8gM1?l00003ogNCh@;o00001?mj
V^H2o`0000OoOJ7Z00?o0000oh6Xk_n1Z>h00_n1Z>h00ol0003oYJ_KojF[f`07ojVag@03o`000?n]
]^3o[KKP00;o[KKP00Co0000ojffh?n]]^3o00002?n`^n800ol0003o//3Tok;0i004ok;0i003o`00
0?o8amSo000002?ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00008ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Tooooo`04o`000?n?iZ[oR>6So`0000;oe?o;00Co0000omGocooEoloo00000_oF
omD3o`0000Cog=kG00Go0000omKGfOoFemWoe]OIo`000003olk?fP03o`000?o5aMWoaLGI00;oaLGI
00Go0000ok^jf?nk^]So^k[Ho`000004ok6_eP05o`000?nVXm?oYZ?CojJSdol000001?nKV=02oi6=
c005o`000?n;T=?oRi3Coh^@dol000001?n2Q<d00ol0003oMh7@o`000002o`000003og=hbOl0003o
JW?900;oJW?90ol00006of1ac@03o`000?mIK/koFFk>00?oFFk>00Go0000oeAadomDLM?oE77Co`00
0003oeYad005o`000?mFMMGoEWGEoeIeeOl000000omBNM/2o`0000?oCWkP0_l000001?mbQmWo0000
o`000?l00004ogB=g@;o00000omgTn400ol0003oNY[VogZJiP03ogZJiP03o`000?mmXN[oOJ7Z00Go
OJ7Z0_l000000on1Z>ko0000ojF[f`03ojF[f`03o`000?nY/MgoZK7M00CoZK7M00?o0000ojffh?n]
]^000_n]]^000ol0003o[KKPojffh002o`0000Oo/;_R0_l00003ok;0i005o`000?o8amSob<OHolS7
f?l000008oooool00ol0003oooooooooo`0Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03
ooooo`?o00008Oooool00ol0003oooooooooo`0Rooooo`07o`000?n?iZ[oR>6Som?ob?l0003oe?o;
o`000002omGoc`03o`000?oFomGoe_oE00;o000000?ohNCFo`000?oLg]L00ooLg]L01Ol0003oe]OI
omKGfOoFemWo000000?oc/oJ00?o0000olG5fOo5aMT00_o5aMT01Ol0003o^k[Hok^jf?nk^]So0000
00?o/JoF00?o0000ojJSdonVXm<00_nVXm<00ol0003oViS@oi^Hd002oi^Hd0?oTHg<00?o0000oh^@
dol000001_n2Q<d00ol0003oLgS9og=hb@03og=hb@03o`000?mZLlWoJW?900;oJW?900Co0000of=]
aol0003o00000omPLLd00ol0003oGF_8oeU^cP04oeU^cP03o`000?mDLM?oE77C00;o00000omJLM00
1Ol0003oEWGEoeIeeOmFMMGo000000CoDWWK00Co0000odinh?m>O^3oCWkP0_l00003og:7f@03o`00
0?mdSMgoM8gM00?oM8gM00Go0000ogNChOmgTn7oMi?Qo`000005ogZJiP;o00001ommXNX00ol0003o
YJ_KojF[f`04ojF[f`03o`000?nY/MgoZK7M00CoZK7M0_l00002ojffh003o`000?n]]^3o[KKP00;o
[KKP00?o0000ok2kh_n`^n801_n`^n800ol0003o//3To`000005olS7f003o`000?oooooooooo027o
oooo00?o0000ooooooooool07Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool07oooool2o`000004ohoVZ_n8hJ?odoo8o`0000;oe?o;00Co0000omGo
cooEoloo00000_oFomD01?l0003ohNCFon7Te_l00003omcNe`03o`000?oFemWoe]OI00;oe]OI00Go
0000olk?f_o>cm[oc/oJo`000004olG5f@05o`000?nk^]So^k[Hok^jf?l000000ona[mH00ol0003o
YZ?CojJSd`02ojJSd`03o`000?nKV=3oViS@00;oViS@00Go0000oi6=c?nASLcoTHg<o`000007oh:4
c@03o`000?mcN<WoLgS900CoLgS900?o0000ofYcbOmZLlT00_mZLlT00ol0003oHfg7of=]a`02o`00
0005of1acOl0003oGF_8oee[b?l000001?mIK/h01Ol0003oE77Co`000?mMK/co000000?oFW7@00Co
0000oeIeeOmFMMGoEWGE0_l00003oe9if`?o000000?oL87Do`000?mbQmT00ombQmT00ol0003oM8gM
ogB=g@03ogB=g@04o`000?mgTn7oMi?QogNCh@;o00001OmjV^H00ol0003oOJ7ZogfQjP04ogfQjP03
o`000?nQYMWoYJ_K00GoYJ_K00?o0000ojVagOnY/Md01OnY/Md01?l0003o[KKPojffh?l00004ojff
h0;o00001on`^n800ol0003ob<OHolS7f005olS7f003o`000?oooooooooo023ooooo00?o0000oooo
ooooool07Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
01gooooo00Co0000ohoVZ_n?iZ[o00000_oColP00ol0003oe?o;o`000002omGoc`04o`000?oFomGo
0000o`0000?ohNCF00Go0000omcNeooLg]Oog=kGo`000004omKGf@05o`000?o>cm[oc/oJolk?f_l0
00001?o5aMT01Ol0003o^k[Hok^jf?nk^]So000000?o/JoF00?o0000ojJSdonVXm<00_nVXm<00ol0
003oViS@oi^Hd002oi^Hd006o`000?nASLcoTHg<oi6=c?n8Q<So00001On2Q<d00ol0003oNg_8o`00
0005og=hb@03o`000?mZLlWoJW?900;oJW?900?o0000of=]aomSKLL00_mSKLL3o`0000;oGF_800?o
0000oeU^c_mIK/h00_mIK/h2o`0000;oGFk<00Co0000oeYad?mJLM3oFW7@0_l00003oeIee@?o0000
00?oDWWKo`000?m`PM@00_m`PM@00ol0003oLXOIog:7f@02og:7f@03o`000?mdSMgoM8gM00?oM8gM
00?o0000ogNChOmgTn400_mgTn400ol0003oNY[VogZJiP03ogZJiP;o00000ommXNX01Ol0003oXJGI
oj6UfOnQYMWo000000GoYJ_K0_l00006ojVag@04o`000?n]]^3o[KKPo`0000Go[KKP00?o0000ok2k
h_n`^n801?n`^n82o`0000Oob<OH00?o0000ooooooooool08?ooool2o`0001gooooo0006ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool01ol0003oSnJZohoVZ_oC
olSo0000om?ob?l000000_oDol/00ol0003oeOo?omGoc`02o`000003onCXdol0003ohNCF00;ohNCF
00Go0000omcNeooLg]Oog=kGo`000004omKGf@05o`000?o>cm[oc/oJolk?f_l000001?o5aMT01?l0
003o^k[Hok^jf?l00004ok6_eP03o`000?nVXm?oYZ?C00;oYZ?C00Go0000oi^Hd?nKV=3oViS@o`00
0004oi6=c0;oR8C800Go0000oh:4cOn2Q<goPXC=o`000003og]kb003o`000?mcN<WoLgS900;oLgS9
1_l00006of=]a`04o`000?mMJlSoGF_8oee[b0;o00000omIK/h01Ol0003oGFk<oee^c?mMK/co0000
00CoFW7@0ol000001?mFMMGo0000oe9ifomBNM/2o`0000?oL87D00?o0000og:7fOmbQmT00_mbQmT0
0ol0003oM8gMogB=g@03ogB=g@03o`000?mgTn7oMi?Q00;oMi?Q00?o0000ogZJi_mjV^H01?mjV^H0
0ol0003oOJ7Zo`000005oj6Uf@03o`000?nUZm_oYJ_K00CoYJ_K00?o0000ojVagOnY/Md01?nY/Md2
o`000003ojffh?l0003o[KKP00Co[KKP0_l00003ok2khP04o`000?o7`mKoal?Fo`0000Oob<OH00?o
0000ooooooooool07_ooool00ol0003oooooo`00000Mooooo`001_ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o00009ooo
ool00ol0003oooooooooo`0Hooooo`07o`000?n?iZ[oSnJZom?ob?l0003odoo8o`000002omCob`03
o`000?oEolooeOo?00;o00000_oTj=<01Ol0003ohNCFon7Te_oQi=Ko000000?og=kG00?o0000omKG
fOoFemT00_oFemT01Ol0003oc/oJolk?f_o>cm[o000000?oaLGI00Go0000ok^jf?nk^]So^k[Ho`00
0004ok6_eP05o`000?nVXm?oYZ?CojJSdol000001?nKV=000ol0003oTHg<oi6=c002oi6=c006o`00
0?n8Q<SoR8C8o`000?n2Q<go00001?mkNlP00ol0003oLgS9o`000002o`000003ofmaa?l0003oJFk4
00;oJFk40_l00005of=]a`;o00001?mMJlP00ol0003oFFk>oeU^cP02o`0000?oGFk<1?l000000omJ
LM3o0000oeIee@02oeIee@;o00000_m_O=001Ol0003oL87Dog21e?m`PMCo000000CoLXOI00?o0000
ogB=gOmdSMd00omdSMd00ol0003oMi?QogNCh@02ogNCh@;o00001OmjV^H00ol0003oXJGIoj6Uf@05
oj6Uf@03o`000?nUZm_oYJ_K00CoYJ_K00?o0000ojVagOnY/Md01OnY/Md2o`0000Oo[KKP00?o0000
ok2kh_l000001?o7`mH00ol0003ob<OHolS7f005olS7f003o`000?oooooooooo01oooooo00?o0000
ooooooooool06oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool05_ooool00ol0003oSnJZohoVZP02om?ob003o`000?oColSo000000;oe?o;00Co
0000omGocooEoloo00000ooTj=<01Ol0003ohNCFon7Te_oQi=Ko000000?og=kG00?o0000omKGfOoF
emT00_oFemT01?l0003oc/oJolk?f_l00004olG5f@03o`000?nk^]So000000Wo000000?oYZ?Co`00
0?nKV=000onKV=000ol0003oTHg<oi6=c002oi6=c004o`000?n8Q<SoR8C8ohR4b0;o00001OmkNlP0
0ol0003oKg74ofmaa003ofmaa007o`000?mYK/CoJFk4ofU^a?l0003oIF[3o`000003of=]a`03o`00
0?mQJLCo000000CoGF_800Co0000oeU^c_l0003oGfc81Ol00004oeYad005o`000?mFMMGoEWGEoeIe
eOl000000om_O=001Ol0003oL87Dog21e?m`PMCo000000CoLXOI0_l00004ogB=g@;o00001?mgTn40
1Ol0003oNY[VogZJi_mjV^Ko000000;oWIoF1onQYMT00ol0003oYJ_KojF[f`04ojF[f`03o`000?nY
/MgoZK7M00GoZK7M0_l00007ojffh003o`000?o7`mKoal?F00Coal?F00?o0000olS7f?o8amP01Oo8
amP00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo0006ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool05?ooool3o`0000;odoo800?o0000om?ob?l00000
0_oDol/01?l0003oeOo?o`000?l00004onCXd`05o`000?oQi=KohNCFon7Te_l000000ooLg]L01Ol0
003oe]OIomKGfOoFemWo000000?oc/oJ00?o0000olG5fOo5aMT01?l00002okFYc@Go[:7<0onSVLX5
o`000003oi^Hd?l0003oTHg<00;oTHg<00?o0000ohR4b?n8Q<P00_n8Q<P2oh1ka@03o`000?mkNlSo
Ng_800;oNg_800?o0000ofmaa?m_LL@00om_LL@00ol0003oJFk4ofU^a002ofU^a006o`000?mUJ/?o
0000o`000?mSKLOo00000_mQJL@00ol0003oGF_8oee[b002oee[b0Go00000omMK/`00ol0003oFW7@
oeYad002oeYad004o`000?mFMMGoEWGEo`0000CoKgc@00Go0000og21e?m`PMCoL87Do`000005og:7
f@03o`000?mdSMgoM8gM00?oM8gM00?o0000ogNChOmgTn400_mgTn400ol0003oNY[Vo`000004oifO
eP03o`000?nQYMWoXJGI00CoXJGI00?o0000ojF[fonUZm/01?nUZm/00ol0003oZK7MojVag@05ojVa
g@;o00001On]]^02o`0000Ooal?F00?o0000olS7f?o8amP01Oo8amP00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01[ooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool04_ooool2o`000004om?ob_l0003odoo8o`0000;odoo800?o0000omCobol000000_l000000ooW
k=;o0000onCXd`02onCXd`05o`000?oQi=KohNCFon7Te_l000001?oLg]L01Ol0003oe]OIomKGfOoF
emWo000000;oc/oJ1?l00002okfacPCo]JW=00?o0000ojbQc?n/XL`00_n/XL`01?l0003oXiW:oj>I
b_nSVLX4oiZ@b0?o00000_nASL`00ol0003oR8C8ohR4b002ohR4b004o`000?n0NlGoP7_5o`0000;o
Ng_800?o0000ogEc`ol000001Om_LL@01Ol0003oJFk4ofU^a?mYK/Co000000?oIF[300?o0000of=]
aol000000_mQJL@00ol0003oGF_8o`000003o`0000?oGfc800Go0000oee^c?mMK/coGFk<o`000004
oeYad0;o000000?oKWS=o`000?m_O=000om_O=001Ol0003oL87Dog21e?m`PMCo000000GoLXOI00?o
0000ogB=gOmdSMd00omdSMd00ol0003oMi?QogNCh@02ogNCh@03o`000?nMWmKoWIoF00CoWIoF00?o
0000oj6UfOnQYMT01?nQYMT00ol0003oYJ_KojF[f`04ojF[f`03o`000?nY/MgoZK7M00GoZK7M0_l0
0003ojffh004o`000?o4_]Coa;kDo`0000Ooal?F00?o0000olS7f?o8amP01Oo8amP00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01Wooooo000Wooooo`;o0000;?ooool00ol0003ooooooooo
o`0@ooooo`04o`000?oCol[odoo:o`0000;odoo800?o0000om?ob?l000000_oDol/01Ol0003oincB
onO/d_oWk=;o000000?oi>SC00Go0000on7Te_oQi=KohNCFo`000003omcNe`03o`000?oFemWoe]OI
00;oe]OI0ol000000oo5^<ko0000okfacP03okfacP05o`000?neZLgo]JW=okFYcOl000001?n/XL`0
1Ol0003oXiW:oj>Ib_nSVL[o000000CoVY380_nAR<H00ol0003oTHg<o`000004ohR4b007o`000?n0
NlGoP7_5oh1kaOl0003oNg_8o`000002ogEc``03o`000?m_LLCoKg7400;oKg7400?o0000ofU^a?mY
K/@00_mYK/@01?l0003oIF[3ofEZ`omUJ/<2o`000004of5Ya?l0003o0000o`0000?oGF_800?o0000
oem/b?mOK<P00_mOK<P01Ol0003oGFk<oee^c?mMK/co000000CoFW7@00Co0000ofihcOm^N<go0000
1?m_O=001Ol0003oL87Dog21e?m`PMCo000000GoLXOI00?o0000ogB=gOmdSMd00omdSMd01?l0003o
Mi?QogNChOmgTn42o`0000KoWIoF00?o0000oj6UfOnQYMT01?nQYMT2o`0000GoYJ_K0_l00006ojVa
g@;o000000?o[KKPo`000?o4_]@00oo4_]@00ol0003oal?FolO3eP05olO3eP03o`000?o8amSob<OH
00Gob<OH00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00Oo0000om?ob_oCol[odoo:o`000?oColSo
000000;odoo80ol00004onO/dP05o`000?oTj=?oi>SConCXdol000000ooQi=H01Ol0003og=kGomcN
eooLg]Oo000000?oe]OI0_l00003olFhcP03o`000?nm/Lko_K7>00;o_K7>00?o0000okFYcOneZLd0
0_neZLd00ol0003o[:7<ojbQc002ojbQc004o`000?nSVL[oXiW:o`0000CoVY3800?o0000oi68a_nA
R<H00_l00003ohR4b003o`000?n0NlGoP7_500?oP7_500Go0000ogEc`omeLl?oMG?3o`000004ofma
a0Ko00000omUJ/<3o`0000?oHFW400?o0000oee[b?mMJlP00_l00004oem/b005o`000?mMK/coGFk<
oee^c?l000000omJLM001Ol0003oKWS=ofihcOm^N<go000000CoKgc@00Go0000og21e?m`PMCoL87D
o`000005og:7f@03o`000?mdSMgoM8gM00?oM8gM00?o0000ogNChOl000000_nHV]<00ol0003oWIoF
oifOeP04oifOeP03o`000?nQYMWoXJGI00GoXJGI00?o0000ojF[fonUZm/01?nUZm/00ol0003oZK7M
ojVag@04ojVag@;o00001_o4_]@00ol0003oal?FolO3eP05olO3eP03o`000?o8amSob<OH00Gob<OH
00?o0000ooooooooool07?ooool2o`0001[ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03Oooool01?l0003odoo:om?ob_l00002om?ob006o`000?oColSo0000o`000?oX
k]7o00001?oWk=801Ol0003oi>SConCXdooTj=?o000000?ohNCF00Co0000omcNeooLg]Oog=kG1?l0
00000oo<_lko0000olFhcP03olFhcP05o`000?nm/Lko_K7>okfac_l000001?neZLd00ol0003o[:7<
ojbQc002ojbQc005o`000?nSVL[oXiW:oj>Ib_l000000onJT<P01?l0003oTHS6oi68a_nAR<H2o`00
00;oR8C800?o0000oh1kaOn0NlD00on0NlD00ol0003oMG?3ogEc``02ogEc``06o`000?m_LLCo0000
o`000?m]K<3o00000omYJL04o`000004ofEZ`ol0003oHfO1o`0000?oHFW40_l00002of9Ya003o`00
0?mOK<SoGfc800;oGfc800Wo0000oee^c?mMK/coGFk<o`000?mJLM3o0000ofadbOl000000om^N<d0
0ol0003oKgc@ofmld002ofmld005o`000?m`PMCoL87Dog21e?l000001OmbQmT00ol0003oM8gMogB=
g@03ogB=g@03o`000?nHV]?oV9[C00;oV9[C00?o0000oifOe_nMWmH01?nMWmH00ol0003oXJGIoj6U
f@05oj6Uf@03o`000?nUZm_oYJ_K00CoYJ_K00?o0000ojVagOnY/Md00onY/Md2o`0000Ooa;kD00?o
0000olO3e_o7`mH01Oo7`mH00ol0003ob<OHolS7f005olS7f003o`000?oooooooooo01gooooo00?o
0000ooooooooool05oooool002Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;
ooooo`04o`000?oCol[odoo:o`0000;odoo800Co0000om?ob?l0003o00000_oXk]401Ol0003oincB
onO/d_oWk=;o000000Coi>SC00Go0000on7Te_oQi=KohNCFo`000002omcNe`;o00001?o<_lh00ol0
003oaKS>olFhcP02olFhcP03o`000?nm/Lko_K7>00;o_K7>00Go0000okFYcOneZLgo]JW=o`000004
ojbQc005o`000?nSVL[oXiW:oj>Ib_l000000onJT<P01?l0003oTHS6oi68a_nAR<H2ohR0a0?o0000
1On0NlD00omiM<7o0000ogEc``03ogEc``03o`000?m]K<3oKFc000;oKFc01Ol000001?mVIkoo0000
ofEZ`ol00002of=W`@05o`000?mQJLCoHFW4of5Ya?l000000omRJL@00ol0003oGfc8oem/b002oem/
b005o`000?mMK/coGFk<oee^c?l000000om/M<T01Ol0003oKWS=ofihcOm^N<go000000CoKgc@00Go
0000og21e?m`PMCoL87Do`000005og:7f@04o`000?mdSMgoM8gMogB=g@;o00001OnHV]<00ol0003o
WIoFoifOeP04oifOeP03o`000?nQYMWoXJGI00GoXJGI00?o0000ojF[fonUZm/01?nUZm/01_l0003o
ZK7MojVagOnY/Mgo0000ol6jd`;o00001oo4_]@00ol0003oal?FolO3eP05olO3eP03o`000?o8amSo
b<OH00Gob<OH00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`009oooool2o`00
033ooooo00?o0000ooooooooool02_ooool01?l0003odoo:om?ob_l00002om?ob003o`000?oColSo
000000?oj>kA00Go0000onO/d_oWk=;oincBo`000004onCXd`09o`000?oQi=KohNCFon7Te_l0003o
g=kGo`000?oBaLko000000Coc;o>00?o0000olFhc_o5^<h00_o5^<h00ol0003o_K7>okfacP02okfa
cP05o`000?neZLgo]JW=okFYcOl000001?n/XL`01Ol0003oXiW:oj>Ib_nSVL[o000000?oVY3800Go
0000oi68a_nAR<KoTHS6o`000003ohR0a0;o00001?n0NlD00ol0003oNGC1o`000003ogEc``03o`00
0?m]K<3oKFc000?o00000omYJL001_l0003oIVNoofIW_ol0003oIF[3o`0000;oHfO100Co0000of5Y
a?mQJLCo00001?mRJL@00ol0003oGfc8oem/b002oem/b004o`000?mMK/coGFk<o`0000CoK7C900Go
0000ofihcOm^N<goKWS=o`000004ofmld005o`000?m`PMCoL87Dog21e?l000001OmbQmT00ol0003o
M8gMo`000002oiBDd@03o`000?nHV]?oV9[C00?oV9[C00?o0000oifOe_nMWmH01?nMWmH00ol0003o
XJGIoj6Uf@05oj6Uf@03o`000?nUZm_oYJ_K00CoYJ_K00?o0000ojVagOl000000oo1^]<2o`0000Ko
a;kD00?o0000olO3e_o7`mH01_o7`mH00ol0003ob<OHolS7f005olS7f003o`000?oooooooooo01co
oooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`08ooooo`04o`000?oCol[odoo:o`0000;odoo800?o0000om?ob?l000001?oXk]401Ol0003o
incBonO/d_oWk=;o000000Coi>SC00Co0000on7Te_oQi=KohNCF0_l00002om;5cP03o`000?o<_lko
c;o>00?oc;o>00Go0000olFhc_o5^<koaKS>o`000004okfacP05o`000?neZLgo]JW=okFYcOl00000
1?n/XL`01Ol0003oXiW:oj>Ib_nSVL[o000000?oVY3800Go0000oi68a_nAR<KoTHS6o`000003ohR0
a0;oPGW100Co0000oh1kaOn0NlGo00000omiM<401?l0003oMG?3o`000?maK[l2o`0000?oKFc000Go
0000ofUY`?mYJL3oJFW0o`000002ofIW_`;o00000omSIl401?l0003oHFW4o`000?l00004of9Ya003
o`000?mOK<SoGfc800;oGfc80_l000000om/LLKo0000ofadb@03ofadb@05o`000?m^N<goKWS=ofih
cOl000001?m_O=001Ol0003oL87Dog21e?m`PMCo000000GoLXOI00?o0000oiBDdOnDU=400_nDU=40
0ol0003oV9[CoiRJd`03oiRJd`03o`000?nMWmKoWIoF00CoWIoF00?o0000oj6UfOnQYMT01OnQYMT0
0ol0003oYJ_KojF[f`04ojF[f`03o`000?o1^]?o`K[C00?o`K[C0_l00006olBne003o`000?o7`mKo
al?F00Koal?F00?o0000olS7f?o8amP01Oo8amP00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01Gooooo000Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01?l0
003odoo:om?ob_l00002om?ob0?o00000ooXk]400ol0003oincBonO/dP02onO/dP03o`000?oTj=?o
i>SC00;oi>SC00?o0000on7Te_oQi=H00_l00003om;5cP03o`000?o<_lkoc;o>00?oc;o>00Go0000
olFhc_o5^<koaKS>o`000004okfacP05o`000?neZLgo]JW=okFYcOl000001?n/XL`01Ol0003oXiW:
oj>Ib_nSVL[o000000CoVY3800Co0000oi68a_nAR<Ko00000on8P<@01_l0003oPGW1oh5i`Ol0003o
P7_5o`0000CoNGC10ol000000omaK[oo0000ofe/`002ofe/`005o`000?mYJL3oJFW0ofUY`?l00000
0omVIkl00ol0003oHfO1of=W`@02of=W`@;o000000?oI6S1o`000?mRJL@00omRJL@00ol0003oGfc8
oem/b002oem/b004o`000?m/LLKoK776o`0000?oK7C900Go0000ofihcOm^N<goKWS=o`000005ofml
d005o`000?m`PMCoL87Dog21e?l000000ombQmT2o`0000GoU9CA00?o0000oiRJdonHV]<00onHV]<0
0ol0003oWIoFoifOeP04oifOeP03o`000?nQYMWoXJGI00GoXJGI00?o0000ojF[fonUZm/00onUZm/0
0ol0003o`K[Col6jd`04ol6jd`;o00001_o4_]@00ol0003oal?FolO3eP06olO3eP03o`000?o8amSo
b<OH00?ob<OH0_l0000Nooooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`05ooooo`04o`000?oCol[odoo:o`0000;odoo80_l000000ooXl=3o0000onS^d@02
onS^d@03o`000?oWk=;oincB00;oincB00Go0000onCXdooTj=?oi>SCo`000002on7TeP03o`000?oG
b/go000000Cod/G>00?o0000olboc_o<_lh00_o<_lh00ol0003oaKS>olFhcP02olFhcP05o`000?nm
/Lko_K7>okfac_l000000oneZLd00ol0003o[:7<ojbQc002ojbQc005o`000?nSVL[oXiW:oj>Ib_l0
00001?nJT<P01?l0003oTHS6oi68a_l00003ohR0a007o`000?n1NL7oPGW1oh5i`On0NlGo0000ogUd
`@04o`0000?oLFjo00Go0000ofe/`?m]K<3oKFc0o`000003ofUY`004o`000?mVIkooIVNoofIW_`;o
00001?mSIl401?l0003oI6S1ofAX`Ol00004of9Ya005o`000?mOK<SoGfc8oem/b?l000000om/LLH0
1Ol0003oK7C9ofadbOm/M<Wo000000?oKWS=00?o0000ofmld?m_O=000om_O=001ol0003oL87Dog21
e?m`PMCo0000og:7fOl000000_n?Slh00ol0003oU9CAoiBDd@03oiBDd@03o`000?nHV]?oV9[C00?o
V9[C00?o0000oifOe_nMWmH01?nMWmH00ol0003oXJGIoj6Uf@05oj6Uf@07o`000?nUZm_oYJ_KojF[
fol0003o_[GAo`000005ol6jd`03o`000?o1^]?o000000Koa;kD00?o0000olO3e_o7`mH01_o7`mH0
1Ol0003ob<OHolS7f?o8amSo000000;ofmOC00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Dooooo`009_ooool3o`0003Cooooo00?o0000ooooooooool01?ooool01Ol0003odoo:om?ob_l0
003odoo800;o00000_oXl=001Ol0003oj>kAonS^dOoXk]7o000000CoincB00Oo0000onCXdooTj=?o
i>SCo`000?oQi=Ko000000;oel[=00?o0000om;5c_oBaLh00_oBaLh00ol0003oc;o>olbocP02olbo
cP03o`000?o5^<koaKS>00;oaKS>00Go0000okfac_nm/Lko_K7>o`000004okFYc@03o`000?n/XLco
[:7<00;o[:7<00Co0000oj>Ib_nSVL[o00001?nJT<P01Ol0003oTHS6oi68a_nAR<Ko000000;oR834
00Co0000oh5i`On1NL7oPGW10ol00003ogUd`@;o00000omaK[l00ol0003oKFc0ofe/`004o`000007
ofUY`?l0003oIVNoofIW_ol0003oIFJno`000003of=W`@05o`000?mTJ<7oI6S1ofAX`Ol000001?mR
JL@01Ol0003oGfc8o`000?m[K/?o000000?oK77600Go0000ofadbOm/M<WoK7C9o`000003ofihc@03
o`000?m_O=3oKgc@00?oKgc@00Go0000og21e?m`PMCoL87Do`000004ohn?cP03o`000?nDU=7oU9CA
00?oU9CA00?o0000oiRJdonHV]<00onHV]<00ol0003oWIoFoifOeP04oifOeP03o`000?nQYMWoXJGI
00GoXJGI00?o0000ojF[fol000000onn]M400ol0003o`K[Col6jd`03ol6jd`;o00001oo4_]@00ol0
003oal?FolO3eP06olO3eP03o`000?o8amSo000000?ofmOC00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;o
oooo00Co0000om?ob_oCol[o00000_oColP01Ol0003oj?3@onS`d?oXl=3o000000?oj>kA00?o0000
onO/d_oWk=800_oWk=801?l0003oi>SConCXdooTj=<2o`0000?oel[=00?o0000om;5c_oBaLh00_oB
aLh00ol0003oc;o>olbocP02olbocP03o`000?o5^<koaKS>00;oaKS>00Go0000okfac_nm/Lko_K7>
o`000004okFYc@03o`000?n/XLco[:7<00;o[:7<00Go0000oj>Ib_nSVL[oXiW:o`000003oiZ@b005
o`000?nAR<KoTHS6oi68a_l000000_n8P<@4o`000003oh5i`OmjLkoo000000?oNGC100?o0000og=^
__l000000omaK[l2o`000004of]X_Ol0003oJFNmofUW_@?o000000GoIVNoo`000?mUI[koIFJno`00
0002of=W`@;o00000omTJ<400ol0003oHVW4of9Ya002of9Ya005o`000?m[K/?oJfk3of]^`ol00000
0_m/LLH00ol0003oK7C9ofadb@02ofadb@05o`000?m^N<goKWS=ofihcOl000001Om_O=001?l0003o
L87Do`000?l00005ohn?cP03o`000?nDU=7oU9CA00;oU9CA00?o0000oiRJdonHV]<01?nHV]<00ol0
003oWIoFoifOeP04oifOeP03o`000?nQYMWoXJGI00GoXJGI00?o0000okjedOnn]M400onn]M400ol0
003o`K[Col6jd`03ol6jd`;o00001_o4_]@00ol0003oal?FolO3eP07olO3eP03o`000?oKem?ofmOC
00;ofmOC00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`006oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00003
om?obP?o00000ooXl=000ol0003oj>kAonS^d@02onS^d@05o`000?oWk=;oincBonO/d_l000000ooT
j=<2o`0000Goel[=00Go0000om;5c_oBaLkod/G>o`000005olbocP05o`000?o5^<koaKS>olFhc_l0
00001?nm/Lh01Ol0003o]JW=okFYcOneZLgo000000Co[:7<00Go0000oj>Ib_nSVL[oXiW:o`000003
oiZ@b004o`000?nAR<KoTHS6oi68aPGo00000on1NL401Ol0003oNW>oo`000?miM<7o000000;oLfjn
00Go0000og5^_omaK[ooLFjoo`000003of]X_@08o`000?mYIkgoJFNmo`000?mWIKco0000ofIW_ol0
0002ofEV_P05o`000?mSIl7o0000ofEV_ol000000omTJ<401Ol0003oHVW4of9Ya?mRJLCo000000Co
Jfk300Co0000ofaaa_m/LLKo00001?m/M<T01Ol0003oKWS=ofihcOm^N<go000000GoKgc@00Co0000
oh^9c?n;RLco00001On?Slh00ol0003oU9CAoiBDd@02oiBDd@03o`000?nHV]?oV9[C00CoV9[C00?o
0000oifOe_nMWmH01?nMWmH00ol0003oXJGIoj6Uf@03oj6Uf@;o00001_nn]M400ol0003o`K[Col6j
d`03ol6jd`;o00001_o4_]@00ol0003oal?FolO3eP05olO3eP;o00001OoKem<00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01;ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool00ol0003oooooooooo`0hooooo`?o00000_oColX2o`000003onSad?l0003oj?3@00;oj?3@00?o
0000onS^dOoXk]400_oXk]401_l0003oincBonO/d_oWk=;o0000onCXd`;o000000?of/k=o`000?oG
b/d01?oGb/d01Ol0003od/G>om;5c_oBaLko000000Goc;o>00Go0000olFhc_o5^<koaKS>o`000004
okfacP03o`000?neZLgo]JW=01?o00000on8P<@01Ol0003oPGW1oh5i`On1NL7o000000;oNW>o0_l0
0003og=^_P05o`000?maK[oo0000ofeY_Ol000000_m[J;d01?l0003oJFNmofUW_Ol00002ofMU_0;o
00000omUI[h2o`0000;oIFJo00Go0000ofAX`OmTJ<7oI6S1o`000002of9Ya0;o00000om[K/<01Ol0
003oK776ofaaa_m/LLKo000000?oK7C900?o0000ofihcOm^N<d00_m^N<d01?l0003oKgc@ofmld?m_
O=02o`0000?oRhW<00?o0000ohn?c_n?Slh00on?Slh00ol0003oU9CAoiBDd@02oiBDd@03o`000?nH
V]?oV9[C00CoV9[C00?o0000oifOe_nMWmH01?nMWmH01Ol0003oXJGIoj6UfOnQYMWo000000;o^[3@
00?o0000okjedOnn]M400onn]M400ol0003o`K[Col6jd`03ol6jd`03o`000?o1^]?o000000Koa;kD
00?o0000olO3e_o7`mH00oo7`mH01?l0003ofmCAom_DdOl00004om_Gd`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@
4?ooooooooooooooool@41001Oooool3o`0003Wooooo00?o0000om?ob_oColX00_l00002onSad005
o`000?oXl=3oj?3@onS`d?l000001?oXk]401?l0003oincBonO/d_oWk=82o`0000?of/k=00?o0000
omO:cOoGb/d00ooGb/d00ol0003od/G>om;5cP02om;5cP03o`000?o<_lkoc;o>00;oc;o>00?o0000
olFhc_o5^<h00_o5^<h01?l0003o_K7>okfac_nm/Lh3o`000003ojZKaonSU<KoXiC600?oXiC61?nK
S/D3oi>7a0?o000000CoS872o`000?l0003o00000_n8P<@01Ol0003oPGW1oh5i`On1NL7o000000?o
NW>o0_l00003og=^_P05o`000?m]JKgoKFVmofeY_Ol000000_m[J;d01?l0003oJFNmofUW_Ol00002
ofMU_003o`000?mUI[koIFJn00;oIFJn00Go0000ofEV_omUI[ooIFJoo`000003ofAX`@;o00000_mZ
Jl401Ol0003oJfk3of]^`om[K/?o000000?oK77600Go0000ofadbOm/M<WoK7C9o`000004ofihc@03
o`000?m_O=3o000000;oQXC900Go0000oh^9c?n;RLcoRhW<o`000004ohn?cP03o`000?nDU=7oU9CA
00?oU9CA00?o0000oiRJdonHV]<01?nHV]<00ol0003oWIoFoifOeP04oifOeP03o`000?nQYMWo0000
00Co^[3@00?o0000okjedOnn]M400onn]M400ol0003o`K[Col6jd`03ol6jd`03o`000?o1^]?o0000
00Koa;kD00Go0000olO3e_o7`mKoal?Fo`000003om_Dd@03o`000?oKem?ofmOC00?ofmOC00?o0000
ooooooooool07?ooool3o`0000[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo03Wooooo00Co0000om?ob_oCol[o00000ooX
lM001Ol0003oj?3@onS`d?oXl=3o000000Coj>kA00Go0000onO/d_oWk=;oincBo`000004om[>c@03
o`000?oGb/goel[=00?oel[=00?o0000om;5c_oBaLh00_oBaLh00ol0003oc;o>olbocP02olbocP03
o`000?o5^<koaKS>00;oaKS>00?o0000okfac_l000000_l00004ojZKa`CoXiC600Co0000oi^>aOnK
S/GoVhk50ol000000onCQlCo0000ohb1`P02ohb1`P;oQG_100?o0000ohR0a?l000001?n1NL400ol0
003oNW>oogYc_`02ogA]_@04o`000?mcK[koLfjno`0000?oKFVm00Co0000of]X_Om[J;go00000_mY
Ikd00ol0003oIfFlofMU_002o`0000?oIFJn00?o0000ofEV_omUI[l00_mUI[l01Ol0003oI6S1ofAX
`OmTJ<7o000000;oJV_100?o0000of]^`om[K/<00_m[K/<01Ol0003oK776ofaaa_m/LLKo000000?o
K7C900Co0000ofihcOm^N<goKWS=0_l00004ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001?n?Slh0
0ol0003oU9CAoiBDd@03oiBDd@03o`000?nHV]?oV9[C00CoV9[C00?o0000oifOe_nMWmH00onMWmH2
o`0000Ko^[3@00?o0000okjedOnn]M400onn]M400ol0003o`K[Col6jd`03ol6jd`;o00001oo4_]@0
0ol0003oal?Fo`000004om_Dd@03o`000?oKem?ofmOC00?ofmOC00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0hooooo`04o`000?oCol[o0000o`0000Coj?7@00Go
0000onS`d?oXl=3oj?3@o`000004onS^d@03o`000?oWk=;oincB00;o00001OoJc/d00ol0003oel[=
omO:c@02omO:c@03o`000?oBaLkod/G>00;od/G>00?o0000olboc_o<_lh00_o<_lh01?l0003oaKS>
olFhc_o5^<h3o`0000;o/J781OnZVlL00ol0003oXiC6oj>DaP02oj>DaP?o000000?oVhk5oi>7a?nC
Ql@00_nCQl@3ohb1`P04o`000?n5Nl7oQG_1ohEk`@;o00000on1NL401?l0003oNW>oogYc_ol00002
ogA]_@04o`000?mcK[ko0000o`0000?oKFVm00?o0000of]X_Ol000000_mYIkd01_l0003oIfFlofMU
_?l0003oIfBlo`0000;oIFJn0_l00004ofEV_`04o`000?mTJ<7oI6S1o`0000?oJV_100Go0000of]^
`om[K/?oJfk3o`000003ofaaaP03o`000?m/M<WoK7C900;oK7C900Go0000ofihcOl0003oPWo7o`00
0004ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001On?Slh00ol0003oU9CAoiBDd@03oiBDd@03o`00
0?nHV]?oV9[C00CoV9[C00Oo0000oifOe_nMWmKoWIoFo`000?neZlko000000Ko^[3@00?o0000okje
dOnn]M401?nn]M400ol0003o`K[Col6jd`03ol6jd`;o00001oo4_]@00ol0003ofmCAom_Dd@04om_D
d@03o`000?oKem?ofmOC00?ofmOC00?o0000ooooooooool07_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`0hooooo`;o000000?oio;Ao`000?oXlM000_oXlM000ol0003oj?3@onS`d002onS`
d005o`000?oXk]7oj>kAonS^dOl000000_oWk=800ol0003ogM;=o`000005om[>c@03o`000?oGb/go
el[=00?oel[=00Go0000om;5c_oBaLkod/G>o`000005olbocP04o`000?o5^<ko0000okNWb0Go/J78
1?nZVlL00ol0003oXiC6o`000003o`0000?oVhk500Go0000oi>7a?nCQlCoThO4o`000003ohb1`P?o
QG_10_mnMKl2o`000005oh5i`Ol0003oNW>oogYc_ol000000omdKKd01?mcK[ko0000ofmY_?l00003
ofeY_@Ko000000WoIfFlo`000?mWI;coIfBlo`000?mUI[ko0000ofIU_Ol000001?mUI[l2o`000003
ofYY_ol0003oJV_100;oJV_100Go0000of]^`om[K/?oJfk3o`000003ofaaaP03o`000?m/M<WoK7C9
00;oK7C900Go0000oh9oaon2OlOoPWo7o`000004ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001On?
Slh00ol0003oU9CAoiBDd@02oiBDd@03o`000?nHV]?oV9[C00GoV9[C00?o0000oifOe_l000000one
Zlh00ol0003o^[3@okZ`d004okZ`d003o`000?nn]M7o_[GA00?o_[GA00?o0000ol6jdoo1^]<00oo1
^]<00ol0003o`K[Co`000005olBne0;o00001_oKe=400ol0003ofmOCom_Gd`03om_Gd`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`006oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000hooooo`;o00000_oWl]401Ol0003oj?7@onSa
d?oXlM3o000000Coj?3@00Oo0000onS^dOoXk]7oj>kAo`000?oWk=;o000000?ogM;=00?o0000om[>
cOoJc/d00_oJc/d00ol0003oel[=omO:c@03omO:c@05o`000?oBaLkod/G>om;5c_l000001Oo<_lh2
o`0000?o]jO81?naXLP00ol0003oZY_7ojZKa`03o`0000?oXiC600Go0000oi^>aOnKS/GoVhk5o`00
0003oi>7a005o`000?n<PL;oS872ohb1`_l000000_n5Nl400ol0003oOWFoogie_`02ogie_`;o0000
0_mjLkl01Ol0003oM6fmogA]_OmdKKgo000000;oKfVl00Ko0000ofeY_Om]JKgo0000ofYU^ol00002
ofUU^`;o000000CoIfFlo`000?mWI;coIfBl0_l00002ofIU_@03o`000?mUI[ooIFJo00;oIFJo00Co
0000ofYY_omZJKoo00000omZJl401Ol0003oJfk3of]^`om[K/?o000000?oK77600Co0000ofadbOm/
M<WoK7C91On2OlL00ol0003oQXC9ohJ4b@02ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001On?Slh0
0ol0003oU9CAoiBDd@02oiBDd@03o`000?nHV]?oV9[C00GoV9[C00?o0000okF[c_neZlh00oneZlh0
0ol0003o^[3@okZ`d004okZ`d003o`000?nn]M7o_[GA00?o_[GA00?o0000ol6jdoo1^]<00oo1^]<0
0ol0003o`K[Co`000003olBne004o`000?oId=3ofM3@o`0000KofmCA00?o0000om_GdooKem<00_oK
em<00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo00Go
0000onObdOoWl]7oio;Ao`000003onSad003o`000?oXl=3oj?3@00;oj?3@00Co0000onS^dOoXk]7o
j>kA0_l00004omgBc@03o`000?oJc/gof/k=00;of/k=00?o0000omO:cOoGb/d00ooGb/d00ol0003o
d/G>om;5cP02om;5cP04o`000?o<_lkoc;o>olbocP;o00001?ngYlP01?l0003o/J78ok6Qb?naXLP3
o`0000;oZY_700Go0000oj>Da_nSU<KoXiC6o`000004oi^>a@05o`000?nCQlCoThO4oi>7a?l00000
0_n<PL801?l0003oQG_1ohEk`On5Nl44ogie_`;oN72m00?o0000ogYc_ol000000omdKKd01?l0003o
KfVlofmY_?m_JK`2o`000007of]V^ol0003oJVFko`000?mYIK_o0000ofQT^P02o`0000?oIfBl00Co
0000ofIU_OmVIKgo00001?mUI[l01?l0003oJVVoofYY_ol00003ofY[`@03o`000?m[K/?oJfk300;o
Jfk300So0000ofaaa_m/LLKoK776o`000?m/M<Wo0000ogika@CoPWo700?o0000ohJ4bOn6Q<T00_n6
Q<T00ol0003oRhW<oh^9c002oh^9c003o`000?n?SlkoSho>00?oSho>00?o0000oiBDdOnDU=400_nD
U=400ol0003oV9[CoiRJd`03oiRJd`;o00001OneZlh00ol0003o^[3@okZ`d004okZ`d003o`000?nn
]M7o_[GA00Co_[GA00?o0000ol6jdoo1^]<00oo1^]<01Ol0003o`K[Co`000?o4_]Co000000?ofM3@
00?o0000om_DdOoKe=401?oKe=400ol0003ofmOCom_Gd`03om_Gd`03o`000?oooooooooo01kooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o
0000onObdOoWl]400_oWl]401Ol0003oj?7@onSad?oXlM3o000000Coj?3@00?o0000onS^dOoXk]40
0_l00005omgBc@03o`000?oJc/gof/k=00;of/k=00?o0000omO:cOoGb/d00ooGb/d00ol0003od/G>
om;5cP02om;5cPCo000000?o_Jc9okNWb?ngYlP00ongYlP4o`000003ok6Qb?l0003oZY_700;oZY_7
00?o0000oj>Da_nSU<H00_nSU<H01Ol0003oVhk5oi^>aOnKS/Go000000?oThO400Go0000ohb1`_n<
PL;oS872o`000002ohEk`@05o`000?mnMKooOWFoogie_ol000000_mhL;d00omjLkoo0000ogA]_@02
ogA]_@;o00000om_JK`01ol0003oJfJko`000?mZIK_o0000ofUU^ol000000_mXI;X01Ol0003oIfBl
ofMT_?mWI;co000000?oIVFm00Ko0000ofEV_omUI[oo0000ofUW_Ol00002ofYY_`05o`000?mZJl7o
JV_1ofY[`Ol000000om[K/<01?l0003oK776ofaaa_m/LLH2o`0000?oOW_51?n2OlL00ol0003oQXC9
ohJ4b@02ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001On?Slh00ol0003oU9CAoiBDd@03oiBDd@05
o`000?nHV]?oV9[CoiRJdol000000_n`YLd00ol0003o]J_>okF[cP03okF[cP03o`000?nj/=3o^[3@
00Co^[3@00?o0000okjedOnn]M401?nn]M400ol0003o`K[Col6jd`03ol6jd`03o`000?o1^]?o0000
00GofM3@00?o0000om_DdOoKe=401?oKe=400ol0003ofmOCom_Gd`02om_Gd`03o`000?oooooooooo
01gooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`000007ooooo`009?ooool00ol0003o
ooooooooo`0gooooo`05o`000?oWl]7oio;AonObdOl000001?oXlM001Ol0003oj?3@onS`d?oXl=3o
000000;oj>kA00?o0000on3EcOl000001OoMd/d00ol0003of/k=om[>c@03om[>c@03o`000?oGb/go
el[=00;oel[=00Co0000om;5c_oBaLkod/G>0_l00005okf/b@?o]jO80ol00003ok6Qb003o`000?nZ
VlOoZY_700;oZY_700Go0000oj>Da_nSU<KoXiC6o`000003oi^>a@05o`000?nCQlCoThO4oi>7a?l0
00000on<PL801?l0003oQG_1ohEk`Ol00004ogie_`?oN72m0_l00002ogA]_@03o`000?m_JK_o0000
00;oKfVl00Wo0000of]V^om[I[_o0000ofYU^ol0003oJFFko`000?mXI;X00_l00002ofMT_0;o0000
0omVIKd01Ol0003oIFJoo`000?mYIkgo000000?oJVVo00Go0000ofY[`OmZJl7oJV_1o`000003of]^
``04o`000?m/LLKo0000ogYg``CoOW_500?o0000oh9oaon2OlL00_n2OlL00ol0003oQXC9ohJ4b@02
ohJ4b@05o`000?n;RLcoRhW<oh^9c?l000001On?Slh00ol0003oU9CAoiBDd@03oiBDd@03o`000?nH
V]?o000000Co/:G=00?o0000okF[c_neZlh00oneZlh00ol0003o^[3@okZ`d004okZ`d003o`000?nn
]M7o_[GA00Co_[GA00?o0000ol6jdoo1^]<00_o1^]<00ol0003o`K[Co`000005omW@d003o`000?oK
e=7ofmCA00CofmCA00?o0000om_GdooKem<00ooKem<00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00cooooo000Tooooo`;o0000>?ooool01Ol0003oio;AonObdOoWl]7o000000Coj?7@00Oo
0000onS`d?oXl=3oj?3@o`000?oXk]7o000000;oh=G=00?o0000omgBcOoMd/d01?oMd/d00ol0003o
f/k=om[>c@02om[>c@03o`000?oGb/goel[=00?oel[=00Co0000om;5c_l0003o`k791_nm[<T3o`00
00;o]jO800Go0000ok6Qb?naXLSo/J78o`000004ojZKa`05o`000?nSU<KoXiC6oj>Da_l000000onK
S/D01Ol0003oThO4oi>7a?nCQlCo000000?oS87200Go0000ohEk`On5Nl7oQG_1o`000003ogie_`03
o`000?mhL;goN72m00;oLfbl00?o0000ogA]_Ol000000_m_JK/01?m_JKco0000ofaV^_l00002of]V
^`0<ofYU^ol0003oJFFko`000?mXI;[o0000ofQT^_l0003oIfBlo`000?mWI;_o00000omVIKd01Ol0
003oJFNmofUW_OmYIkgo000000;oJVVo00Go0000ofY[`OmZJl7oJV_1o`000003of]^``;o00000omj
Ml<4ogika@05o`000?n2OlOoPWo7oh9oaol000001?n6Q<T00ol0003oRhW<oh^9c002oh^9c003o`00
0?n?SlkoSho>00?oSho>00?o0000oiBDdOnDU=400onDU=400ol0003o/:G=ok2Uc@03ok2Uc@03o`00
0?neZlko]J_>00?o]J_>00?o0000okZ`d?nj/=001Onj/=000ol0003o_[GAokjed@03okjed@03o`00
0?o1^]?o`K[C00?o`K[C00?o0000omO<col000001OoId=000ol0003ofmCAom_Dd@03om_Dd@03o`00
0?oKem?ofmOC00?ofmOC00?o0000ooooooooool07_ooool3o`0000gooooo000Tooooo`03o`000?oo
oooooooo03Oooooo00Go0000onObdOoWl]7oio;Ao`000004onSad004o`000?oXl=3oj?3@onS`d0;o
00001?oPeLd00ol0003ogM;=omgBc@03omgBc@03o`000?oJc/gof/k=00;of/k=00?o0000omO:cOoG
b/d00ooGb/d2o`0000?o`k790_nm[<T4o`0000Co]jO800?o0000ok6Qb?naXLP00_naXLP00ol0003o
ZY_7ojZKa`02ojZKa`05o`000?nSU<KoXiC6oj>Da_l000000onKS/D01Ol0003oThO4oi>7a?nCQlCo
000000?oS87200Co0000ohEk`On5Nl7o00000omnMKl01?l0003oN72mogQ`_Ol00002og=/_003ogA]
_Ol0003oKfVk00;oKfVk00Go0000ofaV^_m/I[[o0000of]V^`02o`000004ofUU^ol0003oJ6Bjo`00
00;oJ6Bj0_l00002ofMT^`04o`000?mVIKgoIVFmo`0000?oJFNm00Go0000ofYY_omZJKooJVVoo`00
0003ofY[`@04o`000?m[K/?o0000ogMc`@CoNWO300Go0000ogikaOmnNlGoOW_5o`000004oh9oa`03
o`000?n6Q<WoQXC900;oQXC900?o0000oh^9c?n;RL`00_n;RL`00ol0003oSho>ohn?cP03ohn?cP04
o`000?nDU=7oU9CAoiBDd@;o00001_n`YLd00ol0003o]J_>okF[cP03okF[cP03o`000?nj/=3o^[3@
00Co^[3@00?o0000okjedOnn]M401?nn]M401_l0003o`K[Col6jdoo1^]?o0000omO<c`;o00001OoI
d=000ol0003ofmCAom_Dd@04om_Dd@03o`000?oKem?ofmOC00;ofmOC00?o0000ooooooooool06ooo
ool3o`0000;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=oooool0
1Ol0003oio;AonObdOoWl]7o000000Coj?7@00?o0000onS`d?oXl=000_l00005on3Ec@03o`000?oM
d/gogM;=00?ogM;=00?o0000om[>cOoJc/d00_oJc/d00ol0003oel[=omO:c@02omO:c@;o00000oo3
/LT3o`0000Co_Jc900?o0000okNWb?ngYlP00_ngYlP01Ol0003o/J78ok6Qb?naXLSo000000CoZY_7
00Go0000oj>Da_nSU<KoXiC6o`000003oi^>a@05o`000?nCQlCoThO4oi>7a?l000000on<PL801?l0
003oQG_1ohEk`Ol00003ogie_`05o`000?mhL;goN72mogQ`_Ol000000_mcK;`2o`0000;oKfVk00Co
0000ofaV^_m/I[[o00000_m[I[/3o`0000;oJ6Bj00Co0000ofQT^_mXI;[o00000omWI;/2o`000003
ofUV_?l0003oJFNm00;oJFNm00Go0000ofYY_omZJKooJVVoo`000003ofY[`@04o`000?mgLl7oMg?1
ogMc`@CoNWO300Go0000ogikaOmnNlGoOW_5o`000004oh9oa`03o`000?n6Q<WoQXC900;oQXC900?o
0000oh^9c?n;RL`00_n;RL`00ol0003oSho>ohn?cP03ohn?cP03o`000?nDU=7o000000;oZio;00?o
0000ok2UcOn`YLd00on`YLd00ol0003o]J_>okF[cP04okF[cP03o`000?nj/=3o^[3@00Co^[3@00?o
0000okjedOnn]M401?nn]M400ol0003o`K[Co`000003omO<c`;o00001OoId=000ol0003ofmCAom_D
d@03om_Dd@03o`000?oKem?ofmOC00?ofmOC00?o0000ooooooooool05oooool3o`0000Gooooo00?o
0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003oio;AonObd@02
onObd@05o`000?oXlM3oj?7@onSad?l000000_oXl=000ol0003ohMS=o`000005on3Ec@03o`000?oM
d/gogM;=00?ogM;=00?o0000om[>cOoJc/d00_oJc/d01ol0003oel[=omO:cOoGb/go0000olNfbOo3
/LT00ol000000oo3/LWo0000okf/b@04okf/b@03o`000?ngYlSo]jO800;o]jO800?o0000ok6Qb?na
XLP00_naXLP01Ol0003oZY_7ojZKaonZVlOo000000?oXiC600Go0000oi^>aOnKS/GoVhk5o`000003
oi>7a005o`000?n<PL;oS872ohb1`_l000000_n5Nl401Ol0003oOWFoogie_omnMKoo000000?oN72m
00?o0000og=/_?mcK;`00_m_J;/01?l0003oKfVko`000?l00002ofaV^P05o`000?m[I[_o0000o`00
0?mXHkT00ol00002ofQT^P03o`000?mWI;_oIfBk00;oIfBk00Co0000ofUV_?mYI[co00000omYIkd0
1?l0003oJVVoofYY_ol00003ofY[`@CoMg?100?o0000ogYg`omjMl<00_mjMl<01Ol0003oOW_5ogik
aOmnNlGo000000?oPWo700?o0000ohJ4bOn6Q<T00_n6Q<T00ol0003oRhW<oh^9c002oh^9c003o`00
0?n?SlkoSho>00?oSho>0_l00004oj^Ob`03o`000?n`YLgo/:G=00?o/:G=00?o0000okF[c_neZlh0
0oneZlh00ol0003o^[3@okZ`d005okZ`d003o`000?nn]M7o_[GA00Co_[GA00?o0000omO<cooGc<l0
0_oGc<l2o`0000GofM3@00?o0000om_DdOoKe=401?oKe=401?l0003ofmOCom_GdooKem<2o`0001Go
oooo1?l00008ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000=oooool00ol0003oio;A
onObd@02onObd@07o`000?oXlM3oj?7@onSad?l0003oj?3@o`000002on7Hc@03o`000?oPeLgoh=G=
00?oh=G=00?o0000omgBcOoMd/d00ooMd/d00ol0003of/k=om[>c@03om[>c@03o`000?oGb/go0000
00?o00001Oo3/LT00ol0003o_Jc9okf/b@02okf/b@03o`000?ngYlSo]jO800;o]jO800?o0000ok6Q
b?naXLP00_naXLP00ol0003oZY_7ojZKa`02ojZKa`04o`000?nSU<KoXiC6o`0000CoVhk500Go0000
oi>7a?nCQlCoThO4o`000003ohb1`P04o`000?n5Nl7oQG_1o`0000?oOWFo00Co0000ogQ`_OmhL;go
00000_mcK;`01ol0003oKfRkofmX^om_JK_o0000ofaV^_l000000_m/I[X00ol0003oJFBio`000002
o`000004ofQS^Ol0003oJ6BjofQT^P;o00000omWI;/01Ol0003oJFJlofUV_?mYI[co000000;oJFNm
00So0000ofYY_omZJKooJVVoo`000?mZJl7o0000ogA__`CoMg?100Go0000ogYg`omjMl?oNWO3o`00
0003ogika@03o`000?n2OlOoPWo700;oPWo700?o0000ohJ4bOn6Q<T00_n6Q<T00ol0003oRhW<oh^9
c002oh^9c006o`000?n?SlkoSho>ohn?c_l0003oYI[:1On[Wl/00ol0003o/:G=ok2Uc@04ok2Uc@03
o`000?neZlko]J_>00?o]J_>00?o0000okZ`d?nj/=001?nj/=000ol0003o_[GAokjed@03okjed@;o
00001OoGc<l00ol0003ofM3@omW@d003omW@d003o`000?oKe=7ofmCA00CofmCA00Ko0000om_GdooK
em?o0000onW`col0000Booooo`?o00003Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0
003oooooooooo`0gooooo`03o`000?oWl]7oio;A00;oio;A00Co0000onSad?oXlM3oj?7@0_l00004
on7Hc@03o`000?oPeLgoh=G=00?oh=G=00?o0000omgBcOoMd/d00ooMd/d00ol0003of/k=om[>c@02
om[>c@?o00000oo7]/T00ol0003o`k79ol>ab@02ol>ab@03o`000?nm[<Wo_Jc900?o_Jc900?o0000
okNWb?ngYlP00_ngYlP01Ol0003o/J78ok6Qb?naXLSo000000CoZY_700Ko0000oj>Da_nSU<KoXiC6
o`000?nKS/D@o`000005ogie_ol0003oN72mogQ`_Ol000000omcK;`00ol0003oKfRkofmX^`02o`00
00?oK6Jj00?o0000ofUT^Ol000000_l000002omXHkWo0000o`000?mXI;[o0000ofQS^_l0003oIfBk
o`000?mYIK[o000000;oJFJl00Go0000ofUW_OmYIkgoJFNmo`000002ofYY_`;o00000_mdKkl00ol0
003oMg?1ogMc`@02ogMc`@05o`000?mjMl?oNWO3ogYg`ol000000omnNlD00ol0003oPWo7oh9oa`02
oh9oa`03o`000?n6Q<WoQXC900;oQXC900?o0000oh^9c?n;RL`00_n;RL`00ol0003oSho>o`000003
ojFJbPGoZio;00?o0000ok2UcOn`YLd00on`YLd00ol0003o]J_>okF[cP04okF[cP03o`000?nj/=3o
^[3@00Co^[3@00Go0000okjedOnn]M7o_[GAo`000002om?7cP03o`000?oGc<ooelc?00?oelc?00?o
0000omW@d?oId=000ooId=000ol0003ofmCAom_Dd@03om_Dd@03o`000?oKem?o000000;ojO3?00?o
0000ooooooooool03Oooool3o`00013ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool0=oooool00ol0003oio;AonObd@02onObd@05o`000?oXlM3oj?7@onSad?l000001OoQ
f<d00ol0003oh=G=on3Ec@03on3Ec@03o`000?oMd/gogM;=00?ogM;=00?o0000om[>cOl000000ol0
0006olNfb@03o`000?o3/LWo`k7900;o`k7900?o0000okf/bOnm[<T00_nm[<T00ol0003o]jO8okNW
b002okNWb003o`000?naXLSo/J7800;o/J7800Go0000ojZKaonZVlOoZY_7o`000002oj>DaP?o0000
0_n?Q<@4ohUo`P05o`000?n3N/7oPg[1oh=j`Ol000000_mnMKl00ol0003oNG6nogUa_P04o`000005
ogQ`_Ol0003oLfblog=/_?l000000_m_J;/2ofaU^P08o`000?m/I[[o0000ofUT^Ol0003oJFBio`00
0?mXHkT2o`000009ofQS^Ol0003o0000ofQS^_l0003oIfBko`000?mYIK[o000000?oJFJl00Oo0000
ofUW_OmYIkgo0000ofYY_ol0003oLFbn00CoM6no00Go0000ogMc`OmgLl7oMg?1o`000003ogYg``05
o`000?mnNlGoOW_5ogikaOl000001?n2OlL00ol0003oQXC9ohJ4b@02ohJ4b@03o`000?n;RLcoRhW<
00;oRhW<0_l00004ojFJbP03o`000?n[Wl_oZio;00;oZio;00?o0000ok2UcOn`YLd01?n`YLd00ol0
003o]J_>okF[cP03okF[cP03o`000?nj/=3o^[3@00Go^[3@00?o0000okjedOl000000ooCalh00ol0
003oelc?omO<c`03omO<c`;o00001?oId=000ol0003ofmCAom_Dd@04om_Dd@05o`000?oYl<oojO3?
onW`col000002oooool4o`0001?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooo
ooooool0=oooool00ol0003oio;AonObd@02onObd@03o`000?oXlM3oj?7@00;o00001OoQf<d00ol0
003oh=G=on3Ec@03on3Ec@03o`000?oMd/gogM;=00;ogM;=0ol00002om[>c@;o00001_o7]/T00ol0
003o`k79ol>ab@02ol>ab@03o`000?nm[<Wo_Jc900?o_Jc900Go0000okNWb?ngYlSo]jO8o`000004
ok6Qb004o`000?nZVlOoZY_7ojZKa`?o000000?oUHW5ohn4a?n?Q<@00on?Q<@4ohUo`P05o`000?n3
N/7oPg[1oh=j`Ol000000_mnMKl01?l0003oNG6nogUa__l00002ogA]_0?o000000?oLfblo`000?m_
J;/00_m_J;/2ofaU^P04ofaV^_l0003oJFBiofUT^@Go00000_mXHkT01?l0003oJ6>jofQS^_l00003
ofUU^P06o`000?mYI[coJFJlofUV_?l0003oJFNm0_l00003og5/_P?oM6no00?o0000ogMc`OmgLl40
0_mgLl401Ol0003oNWO3ogYg`omjMl?o000000?oOW_500?o0000oh9oaon2OlL00_n2OlL00ol0003o
QXC9ohJ4b@02ohJ4b@05o`000?n;RLco0000o`000?nOU<P01_nUV/X00ol0003oZio;oj^Ob`02oj^O
b`03o`000?n`YLgo/:G=00Co/:G=00?o0000okF[c_neZlh00oneZlh00ol0003o^[3@okZ`d004okZ`
d0;o00001?oCalh00ol0003oelc?omO<c`04omO<c`03o`000?oId=3ofM3@00?ofM3@00?o0000om_D
dOoKe=400ooKe=401Ol0003ojO3?onW`cooYl<oo000000Sooooo0ol0000Gooooo`03o`000?oooooo
oooo00[ooooo000Sooooo`?o0000=oooool01Ol0003oio;AonObdOoWl]7o000000;oj?7@00?o0000
on;Jc_l000001_oQf<d00ol0003oh=G=on3Ec@02on3Ec@03o`000?oMd/go000000;o000000GogM;=
o`000?oJc/gof/k=o`000002ol^jbP03o`000?o7]/WoakK900CoakK900?o0000ol>abOo3/LT00_o3
/LT00ol0003o_Jc9okf/b@02okf/b@03o`000?ngYlSo]jO800;o]jO800Ko0000ok6Qb?naXLSo/J78
o`000?nZVlL2o`000003oi^?a_nERLGoUHW500;oUHW51?n?Q<@01Ol0003oRGo2ohUo`_n9Ol;o0000
00?oPg[100Co0000ogie_omnMKoo00000omiLKh02?l0003oM6flogA]_?l0003oL6Vko`000?mcK;co
00000_m_J;/02?l0003oK6FjofaU^_m/I[[o0000ofUT^Ol0003oJFBi0_l000001?mXHkWo0000ofQS
^Ol00002ofQS^P03o`000?mYIK[oJFFj00;oJFFj00?o0000ofUV_?mYI[`00_l000000om_J[co0000
og5/_P02og5/_P05o`000?mdKkooM6noogA__ol000000omgLl401Ol0003oNWO3ogYg`omjMl?o0000
00CoOW_500?o0000oh9oaon2OlL00_n2OlL00ol0003oQXC9ohJ4b@02ohJ4b@03o`000?nOU<SoWiC8
00;oWiC81_nUV/X00ol0003oZio;oj^Ob`02oj^Ob`03o`000?n`YLgo/:G=00?o/:G=00?o0000okF[
c_neZlh01?neZlh00ol0003o^[3@okZ`d002okZ`d003o`000?o?`/ko000000GodlO>00?o0000omO<
cooGc<l00ooGc<l2o`0000CofM3@00?o0000om_DdOoKe=400_oKe=42o`0000?ojO3?00?o0000oooo
ooooool00oooool3o`0001[ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooooooo
ool0=oooool01ol0003oio;AonObdOoWl]7o0000onSad?l000000ooRf/h00ol0003ohMS=on7Hc@03
on7Hc@04o`000?oPeLgoh=G=on3Ec@?o00001OoMd/d2o`0000?obk[:00?o0000olNfbOo7]/T01?o7
]/T00ol0003o`k79ol>ab@02ol>ab@03o`000?nm[<Wo_Jc900;o_Jc900?o0000okNWb?ngYlP00_ng
YlP01?l0003o/J78ok6Qb?naXLP2o`0000CoVho60onERLD00ol0003oShC4ohn4a002ohn4a005o`00
0?n9Ol;oRGo2ohUo`_l000000_n3N/401?l0003oOWFoogie_ol00003ogUa_P05o`000?mdKKcoM6fl
ogA]_?l000000_m`JK/2o`000003ofmX^ol0003oK6Fj00;oK6Fj0_l00002ofUT^@05o`000?mXHkWo
J6>io`000?mXHkT00ol000000omYI;[o0000ofUU^P02ofUU^P04o`000?mYI[co0000ofeW^`?oKfZl
00Go0000og5/__maK;koLFbno`000002ogA__`03o`000?mgLl7oMg?100;oMg?100Go0000ogYg`omj
Ml?oNWO3o`000003ogika@03o`000?n2OlOoPWo700;oPWo700Go0000ohJ4bOn6Q<WoQXC9o`000005
oinDb003o`000?nUV/[oYI[:00?oYI[:00?o0000oj^Obon[Wl/00_n[Wl/00ol0003o/:G=ok2Uc@04
ok2Uc@03o`000?neZlko]J_>00?o]J_>00Go0000okZ`d?nj/=3o^[3@o`000003olo2cP03o`000?oC
alkodlO>00;odlO>00?o0000omO<cooGc<l01?oGc<l2o`0000CofM3@00Ko0000om_DdOoKe=7o0000
on[^c_l00003onW`c`03o`000?oooooooooo00?o00007Oooool00ol0003oooooooooo`0:ooooo`00
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo03Sooooo00Co0000onObdOoWl]7oio;A0_l00004
on;JcP03o`000?oQf<gohMS=00?ohMS=1?l00002on3Ec@03o`000?oMd/gogM;=00;ogM;=0_l00005
ol^jbP03o`000?o7]/WoakK900CoakK900Go0000ol>abOo3/LWo`k79o`000005okf/b@06o`000?ng
YlSo]jO8okNWb?l0003o/J780_l000000onQU<OoVho6oi^?aP03oi^?aP05o`000?nERLGoUHW5oiF9
aOl000000on?Q<@01Ol0003oRGo2ohUo`_n9Ol;o000000?oPg[100Co0000ogie_omnMKoo00000_mi
LKh01Ol0003oM6flogA]_?mdKKco000000;oL6Vk00Go0000ofeW^_l0003oKfRko`000002ofaU^P04
ofUT^Ol0003o0000ofUT^@Co000000CoJ6>io`000?mXHkWo00000_mYI;X01Ol0003oJFFjofUU^_mY
IK[o000000?oKFNk0_m_J[`00ol0003oLFbnog5/_P02og5/_P04o`000?mdKkooM6noo`0000?oMg?1
00Go0000ogYg`omjMl?oNWO3o`000004ogika@03o`000?n2OlOoPWo700;oPWo700?o0000ohJ4bOl0
00000_nIS/L5oinDb003o`000?nUV/[oYI[:00?oYI[:00?o0000oj^Obon[Wl/00_n[Wl/00ol0003o
/:G=ok2Uc@04ok2Uc@03o`000?neZlko]J_>00?o]J_>00?o0000okZ`d?l000001?o?`/h00ol0003o
dlO>om?7cP03om?7cP03o`000?oGc<ooelc?00?oelc?0_l00004omW@d003o`000?oKe=7o000000;o
j^k>00Co0000onW`cooYl<oojO3?0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00?o0000onObdOoWl]400_l00005
on;JcP04o`000?oQf<gohMS=on7Hc@Co00001?oPeLd01ol0003ogM;=omgBcOoMd/go0000oljnbol0
00001Oo;^/X00ol0003oakK9olNfb@04olNfb@03o`000?o3/LWo`k7900;o`k7900?o0000okf/bOnm
[<T00_nm[<T01?l0003o]jO8okNWb?ngYlP2o`0000CoXIC71OnKSlH01?l0003oUHW5oiF9aOl00004
ohn4a004o`000?n9Ol;oRGo2o`0000?oPg[100Co0000ogie_omnMKoo00000omiLKh01?l0003oM6fl
ogA]_?l00002og1Y^`04o`000?m]Ik[oKFNjofeW^P;o000000?oK6Fjo`000?mYI;T00_mYI;T6o`00
0003ofQS^Ol0003oJFBj00;oJFBj00Co0000ofUU^_l0003o00000om]Ik/01?l0003oKfZlofmZ_?l0
0003og5/_P05o`000?mdKkooM6noogA__ol000000omgLl401Ol0003oNWO3ogYg`omjMl?o000000?o
OW_500?o0000oh9oaon2OlL00_n2OlL2o`0000?oVHk700?o0000oinDb?nOU<P00onOU<P00ol0003o
YI[:ojFJbP02ojFJbP03o`000?n[Wl_oZio;00?oZio;00?o0000ok2UcOn`YLd00on`YLd00ol0003o
]J_>okF[cP04okF[cP03o`000?o?`/kocl;>00?ocl;>00?o0000om?7c_oCalh00ooCalh00ol0003o
elc?omO<c`04omO<c`;o00001?oId=001Ol0003oj^k>on[^c_oZk/ko000000?ojO3?00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00Ko0000onOb
dOoWl]7o0000on;Lcol00006on;JcP?o00000ooQf<d00ol0003oh=G=on3Ec@02on3Ec@04o`000?oM
d/gogM;=o`0000?oc[k;00?o0000ol^jb_o;^/X00oo;^/X00ol0003oakK9olNfb@03olNfb@03o`00
0?o3/LWo`k7900;o`k7900?o0000okf/bOnm[<T00_nm[<T01Ol0003o]jO8o`000?l0003oYYW800Go
XIC700?o0000oi^?a_nKSlH00_nKSlH01Ol0003oUHW5oiF9aOnERLGo000000?oShC400Go0000ohUo
`_n9Ol;oRGo2o`000003oh=j`@04o`000?mnMKooOWFoo`0000;oNG6n00Go0000ogA]_?mdKKcoM6fl
o`000002og1Y^`08o`000?m]Ik[oKFNjo`000?m[IK[o0000ofaU^_l00002ofUT^@Co000000?oJ6>i
o`000?mXHkT00_l00002ofUT^P;o00000_m[I[X01ol0003oKFNkofeW^om]Ik_o0000ofmZ_?l00000
1?maK;h01?l0003oM6noogA__ol00003ogMc`@03o`000?mjMl?oNWO300;oNWO300Ko0000ogikaOmn
NlGoOW_5o`000?n2OlL2o`000003oi>9aOnIS/OoVHk700?oVHk700?o0000oinDb?nOU<P00_nOU<P0
0ol0003oYI[:ojFJbP03ojFJbP03o`000?n[Wl_oZio;00;oZio;00?o0000ok2UcOn`YLd01?n`YLd0
0ol0003o]J_>okF[cP02okF[cP;o00001_o?`/h00ol0003odlO>om?7cP02om?7cP03o`000?oGc<oo
elc?00Coelc?00?o0000omW@d?l000000ooId=001Ol0003oj^k>on[^c_oZk/ko000000?ojO3?00?o
0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0gooooo`03o`000?oWl]7o000000?oh]c?00Co0000on;Jc_oRf/koh][>0ol00005on7Hc@03o`00
0?oPeLgoh=G=00?oh=G=0_l00004oljnb`03o`000?o;^/[obk[:00?obk[:00?o0000olNfbOo7]/T0
1?o7]/T00ol0003o`k79ol>ab@02ol>ab@04o`000?nm[<Wo_Jc9okf/b@;o00001?nVVLP5oj6Da`03
o`000?nKSlKoVho600;oVho600Co0000oiF9aOnERLGo00001?n?Q<@01?l0003oRGo2ohUo`_l00003
oh=j`@04o`000?mnMKooOWFoo`0000;oNG6n00Go0000ogA]_?mdKKcoM6flo`000002og1Y^`05o`00
0?m]Ik[oKFNjofeW^_l000000_m[IKX2o`000003ofUT^Ol0003o000000Go000000KoJ6>io`000?mY
I;[o0000ofYT^Ol00002of]V^P05o`000?m]Ik_oKFNkofeW^ol000000_m_J[`01Ol0003oLFbnog5/
__maK;ko000000?oM6no00Go0000ogMc`OmgLl7oMg?1o`000003ogYg``03o`000?mnNlGoOW_500?o
00001?nCRLD4oiV>a`03o`000?nOU<SoWiC800?oWiC800?o0000ojFJb_nUV/X00onUV/X00ol0003o
Zio;oj^Ob`02oj^Ob`03o`000?n`YLgo/:G=00?o/:G=00Go0000okF[c_neZlko]J_>o`000002olZl
c@03o`000?o?`/kocl;>00?ocl;>00?o0000om?7c_oCalh00ooCalh00ol0003oelc?omO<c`03omO<
c`05o`000?oId=3ofM3@o`000?oId=000_l00003on[^cP05o`000?oYl<oojO3?onW`col000008ooo
ool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo
0_l00004on;Lc`Co00000_oRf/h00ol0003ohMS=on7Hc@03on7Hc@03o`000?oPeLgoh=G=00?oh=G=
00?o0000oljnboo>_//01?o>_//00ol0003obk[:ol^jbP03ol^jbP03o`000?o7]/WoakK900?oakK9
00?o0000ol>abOo3/LT00_o3/LT01Ol0003o_Jc9okf/bOl0003o[9k900GoYYW800?o0000oj6DaonQ
U<L00onQU<L01Ol0003oVho6oi^?a_nKSlKo000000?oUHW500Go0000ohn4a?n?Q<CoShC4o`000003
ohUo`P04o`000?n3N/7oPg[1o`0000?oOWFo00Co0000ogUa__miLKko00000_mdKK`01?l0003oL6Vk
og1Y^ol00003ofeW^P05o`000?m[IK[oJfFjo`000?mYHkT00_l000000omXHkWo0000o`000003o`00
00;oJ6>i00Go0000ofYT^OmZI;WoJVBio`000002of]V^P05o`000?m]Ik_oKFNkofeW^ol000000_m_
J[`01Ol0003oLFbnog5/__maK;ko000000;oM6no00?o0000ogMc`OmgLl400_mgLl400ol0003oNWO3
ogYg``03o`0000;oSH?41OnCRLD00ol0003oVHk7oiV>a`02oiV>a`03o`000?nOU<SoWiC800;oWiC8
00?o0000ojFJb_nUV/X00onUV/X00ol0003oZio;oj^Ob`03oj^Ob`03o`000?n`YLgo/:G=00?o/:G=
00?o0000okF[c_l000000oo:_<d00ol0003ocl;>olo2cP04olo2cP03o`000?oCalkodlO>00;odlO>
00?o0000omO<cooGc<l01?oGc<l01_l0003ofM3@o`000?l0003ojN_>o`0000?oj^k>00Go0000onW`
cooYl<oojO3?o`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03Oooooo00Co0000on;LcooRg<ooh]c?0ol00006on;JcP03o`000?oQf<gohMS=00?ohMS=00?o
0000on3EcOoPeLd00_oPeLd00ol0003oc[k;oljnb`04oljnb`03o`000?o;^/[obk[:00Cobk[:00?o
0000olNfbOo7]/T00oo7]/T01ol0003o`k79ol>abOo3/LWo0000okf/bOl000000on/W/T5ojJIb003
o`000?nQU<OoXIC700;oXIC700?o0000oi^?a_nKSlH00_nKSlH01?l0003oUHW5oiF9aOl00003ohn4
a005o`000?n9Ol;oRGo2ohUo`_l000000on3N/401?l0003oOWFoogie_ol00002ogUa_P05o`000?md
KKcoM6flogA]_?l000000_m`JK/01?l0003oKFNjofeW^_l00002of]U^P04o`000?mYHkWoJF>iofUS
^@Ko000000?oJ6>io`000?l000000omZI;T01?l0003oJfJjof]V^_l00003ofeW^`04o`000?m_J[co
KfZlo`0000CoLFbn00Co0000ogA__omdKkoo00000omgLl401?l0003oNWO3o`000?n7O/85ohf3a0Go
ThW500Go0000oiV>aonIS/OoVHk7o`000005oinDb003o`000?nUV/[oYI[:00?oYI[:00?o0000oj^O
bon[Wl/00_n[Wl/00ol0003o/:G=ok2Uc@04ok2Uc@03o`000?o:_<gob[c=00;ob[c=00?o0000olo2
c_o?`/h01?o?`/h00ol0003odlO>om?7cP02om?7cP03o`000?oGc<ooelc?00Coelc?00Ko0000omW@
d?l0003o0000onW[c_l00003on[^cP05o`000?oYl<oojO3?onW`col000008oooool00ol0003ooooo
ooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001?ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool4o`0000?oh]c?00?o0000on;Jc_oR
f/h00ooRf/h00ol0003ohMS=on7Hc@03on7Hc@07o`000?oPeLgoh=G=on3EcOl0003odL;;o`000006
oljnb`03o`000?o;^/[obk[:00?obk[:00?o0000olNfbOo7]/T00oo7]/T00ol0003o`k79ol>ab@02
ol>ab@03o`000?n/W/Wo[9k900?o[9k91OnVVLP00ol0003oXIC7oj6Da`02oj6Da`05o`000?nKSlKo
Vho6oi^?a_l000000onERLD01Ol0003oShC4ohn4a?n?Q<Co000000?oRGo200Co0000oh=j`On3N/7o
00000_mnMKl01?l0003oNG6nogUa__l00002ogA]_0co00000_mYHkT00ol0003oJ6>io`000004o`00
00;oJF>i00Go0000ofYT^OmZI;WoJVBio`000002of]V^P05o`000?m]Ik_oKFNkofeW^ol000000_m_
J[`01Ol0003oLFbnog5/__maK;ko000000;oM6no00?o0000ogMc`OmgLl400ol00003ohMn`PCoSH?4
00?o0000oi>9aOnCRLD00_nCRLD00ol0003oVHk7oiV>a`02oiV>a`03o`000?nOU<SoWiC800;oWiC8
00?o0000ojFJb_nUV/X00onUV/X00ol0003oZio;oj^Ob`03oj^Ob`03o`000?n`YLgo/:G=00;o/:G=
0_l00005olZlc@03o`000?o?`/kocl;>00?ocl;>00?o0000om?7c_oCalh00ooCalh00ol0003oelc?
omO<c`04omO<c`03o`000?oYjlkojN_>00;o00000ooZk/h01Ol0003ojO3?onW`cooYl<oo000002?o
oooo00?o0000ooooooooool02Oooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`;o0000=oooool4o`0000Goh]c?00?o0000on;J
c_oRf/h00ooRf/h00ol0003ohMS=on7Hc@03on7Hc@04o`000?oPeLgoh=G=o`0000?odL;;00?o0000
oljnboo>_//00oo>_//00ol0003obk[:ol^jbP04ol^jbP03o`000?o7]/WoakK900?oakK900?o0000
ol>abOo3/LT00_l00005ojbNb@03o`000?nVVLSoYYW800;oYYW800?o0000oj6DaonQU<L00_nQU<L0
0ol0003oVho6oi^?aP02oi^?aP04o`000?nERLGoUHW5o`0000?oShC400Go0000ohUo`_n9Ol;oRGo2
o`000002oh=j`@03o`000?mnMKooOWFo00Ko000000GoKfZlo`000?m]Ik_oKFNko`000003of]V^P03
o`000?mZI;WoJVBi00[o00000_mYHkT01Ol0003oJVBiofYT^OmZI;Wo000000;oJfJj00Go0000ofeW
^om]Ik_oKFNko`000002ofmZ_003o`000?maK;koLFbn00Oo00000_n2NL44ohMn`P03o`000?n=PlCo
SH?400;oSH?400?o0000oi>9aOnCRLD00_nCRLD01Ol0003oVHk7oiV>aonIS/Oo000000GoWiC800?o
0000ojFJb_nUV/X00onUV/X00ol0003oZio;oj^Ob`02oj^Ob`05o`000?n`YLgo/:G=ok2UcOl00000
0_o5]/d00ol0003ob[c=olZlc@02olZlc@03o`000?o?`/kocl;>00Cocl;>00?o0000om?7c_oCalh0
0_oCalh00ol0003oelc?omO<c`03omO<c`;o00000ooYjlh01Ol0003oj^k>on[^c_oZk/ko000000?o
jO3?00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0cooooo`?o00000oooool00ol0003oh]c?on;Lc`03on;Lc`03o`000?oRf/koh][>00?oh][>
00?o0000on7HcOoQf<d01?oQf<d2o`0000CodL;;00?o0000oljnboo>_//01?o>_//00ol0003obk[:
ol^jbP03ol^jbP03o`000?o7]/WoakK900?oakK900?o0000ol>abOl000000_naY</00ol0003o[9k9
ojbNb@03ojbNb@03o`000?nVVLSoYYW800;oYYW800?o0000oj6DaonQU<L00_nQU<L01Ol0003oVho6
oi^?a_nKSlKo000000?oUHW500Go0000ohn4a?n?Q<CoShC4o`000002ohUo`P03o`000?n3N/7oPg[1
00?o000000GoM72oo`000?maK;koLFbno`000003ofmZ_004o`000?m]Ik_oKFNko`0000?oJfJj00?o
0000ofYT^Ol000000_mYHkT01?l0003oJ6>io`000?mXHkTFo`0000;oN72n0ommMKl5oh9i`@CoQgk2
00Go0000ohf3a?n=PlCoSH?4o`000004oi>9a@03o`000?nIS/OoVHk700;oVHk700?o0000oinDb?nO
U<P00_nOU<P00ol0003oYI[:ojFJbP03ojFJbP03o`000?n[Wl_oZio;00?oZio;00?o0000ok2UcOl0
00000oo5]/d00ol0003ob[c=olZlc@03olZlc@03o`000?o?`/kocl;>00?ocl;>00?o0000om?7c_oC
alh00ooCalh01ol0003oelc?omO<cooGc<oo0000onSWc_l000000ooYjlh01Ol0003oj^k>on[^c_oZ
k/ko000000?ojO3?00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`008Oooool0
0ol0003oooooooooo`0`ooooo`?o00001_ooool00ol0003oh]c?on;Lc`04on;Lc`03o`000?oRf/ko
h][>00?oh][>00?o0000on7HcOoQf<d00_oQf<d2o`0000KodL;;00?o0000oljnboo>_//01?o>_//0
0ol0003obk[:ol^jbP03ol^jbP03o`000?o7]/WoakK900?oakK900?o0000ok6TbonaY</00_naY</0
0ol0003o[9k9ojbNb@03ojbNb@05o`000?nVVLSoYYW8ojJIb?l000001?nQU<L00ol0003oVho6oi^?
aP02oi^?aP04o`000?nERLGoUHW5o`0000?oShC400?o0000ohUo`_n9Ol800ol000000omhLl7o0000
ogA`_`02ogA`_`04o`000?maK;koLFbno`0000;oKfZl00Co0000ofeW^om]Ik_o00000om[I[X01?l0
003oJVBiofYT^Ol00002ofUS^@03o`000?mXHkWo000000Co00000_mYHkT01?l0003oJfFjof]U^_m[
IKX3ofeW^PCoL6Vk0omdKK`5ogQ`_P?oOGFo1?n2NL401Ol0003oQgk2ohMn`_n7O/;o000000CoSH?4
00?o0000oi>9aOnCRLD00_nCRLD00ol0003oVHk7oiV>a`02oiV>a`03o`000?nOU<SoWiC800;oWiC8
00?o0000ojFJb_nUV/X00onUV/X00ol0003oZio;oj^Ob`02oj^Ob`;o00001?o5]/d00ol0003ob[c=
olZlc@03olZlc@03o`000?o?`/kocl;>00?ocl;>00?o0000om?7c_oCalh00ooCalh01?l0003oelc?
omO<col00002onSWcP04o`000?oYjlkojN_>onW[cP;o00000_oZk/h01Ol0003ojO3?onW`cooYl<oo
000002Cooooo00?o0000ooooooooool02?ooool0027ooooo0_l0000^ooooo`?o00002_ooool00ol0
003oh]c?on;Lc`03on;Lc`03o`000?oRf/koh][>00?oh][>00Oo0000on7HcOoQf<gohMS=o`000?oC
aLco000000KodL;;00?o0000oljnboo>_//01?o>_//00ol0003obk[:ol^jbP03ol^jbP03o`000?o7
]/WoakK900;oakK90_l00004ok6Tb`03o`000?n/W/Wo[9k900?o[9k900?o0000ojJIb?nVVLP00_nV
VLP00ol0003oXIC7oj6Da`02oj6Da`05o`000?nKSlKoVho6oi^?a_l000000onERLD00ol0003oShC4
ohn4a003o`000003og]g`ol0003oN7?100;oN7?100Co0000ogA`_omdL;oo00000omaK;h01?l0003o
KfZlofmZ_?l00002ofeW^`04o`000?m[I[[oJfJjo`0000;oJVBi00Go0000ofUS^Ol0003o0000ofQS
^@07o`000003ofUS^Ol0003oJfFj00;oJfFj0om]IkX3og1Y^`04o`000?mdKKcoM6flogA]_0CoN72n
00Co0000ogee_ommMKoo00000on2NL400ol0003oQgk2ohMn`P02ohMn`P05o`000?n=PlCoSH?4ohf3
a?l000001?nCRLD00ol0003oVHk7oiV>a`02oiV>a`03o`000?nOU<SoWiC800?oWiC800?o0000ojFJ
b_nUV/X00onUV/X01_l0003oZio;oj^Obol0003o_[3<o`0000GoaKK=00?o0000olZlcOo:_<d00_o:
_<d00ol0003ocl;>olo2cP04olo2cP03o`000?oCalkodlO>00;odlO>00?o0000omO<col000000ooX
ilh02Ol0003ojN_>onW[c_oYjlko0000on[^c_l0003oj^k>o`000003onW`c`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3o`0000go
oooo00?o0000on;LcooRg<l00ooRg<l00ol0003oh][>on;JcP03on;JcP04o`000?oQf<gohMS=o`00
00?odlG<00?o0000om72booA`//01?oA`//00ol0003oc[k;oljnb`04oljnb`03o`000?o;^/[obk[:
00?obk[:00Co0000olNfbOo7]/Wo00000_neZ<`00ol0003o/JC;ok6Tb`02ok6Tb`03o`000?n/W/Wo
[9k900?o[9k900?o0000ojJIb?nVVLP00_nVVLP01Ol0003oXIC7oj6DaonQU<Oo000000CoVho600So
0000oiF9aOnERLGo0000ohn4a?l0003oOg_5o`0000?oNgO300Co0000ogQc`OmhLl7o00000omdL;l0
1?l0003oLFbnog5/__l00002ofmZ_004o`000?m]Ik_oKFNko`0000?oJfJj00Co0000ofYT^Ol0003o
00000_mXHkT2o`000004ofQS^Ol0003o0000ofQS^@;oJFBi0_l00003of]U^P04o`000?m]Ik[oKFNj
o`0000?oL6Vk00Co0000ogA]_?mdKKco00000omhL;h01Ol0003oOGFoogee_ommMKoo000000?oPWW1
00Go0000ohMn`_n7O/;oQgk2o`000004ohf3a003o`000?nCRLGoThW500;oThW500?o0000oiV>aonI
S/L00_nIS/L00ol0003oWiC8oinDb002oinDb003o`000?nUV/[oYI[:00?oYI[:00?o0000oj^Obol0
00000onn/<`00ol0003oaKK=olFfc@02olFfc@03o`000?o:_<gob[c=00?ob[c=00?o0000olo2c_o?
`/h00oo?`/h00ol0003odlO>om?7cP03om?7cP03o`000?oXilkoj>O>00;oj>O>00Go0000onW[c_oY
jlkojN_>o`000002on[^cP;o00000_oYl<l00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Sooooo000Qooooo`03o`000?oooooooooo02Oooooo0ol0000@ooooo`03o`000?oRg<ooh]c?00Co
h]c?00?o0000on;Jc_oRf/h00ooRf/h2o`0000GodlG<00?o0000om72booA`//01?oA`//00ol0003o
c[k;oljnb`03oljnb`03o`000?o;^/[obk[:00?obk[:00?o0000olNfbOl000001?neZ<`00ol0003o
/JC;ok6Tb`02ok6Tb`03o`000?n/W/Wo[9k900?o[9k900Go0000ojJIb?nVVLSoYYW8o`000004oj6D
a`05o`000?nKSlKoVho6oi^?a_l000000_nERLD2o`0000?oOg_500Co0000og]g`omkMl?o00000omh
Ll401?l0003oM72oogA`_ol00003og5/_P04o`000?m_J[coKfZlo`0000;oKFNk00?o0000of]V^_m[
I[X00_l000001?mYI;[o0000ofQS^OmXHkT2o`000004ofQS^Ol0003o0000o`0000CoJFBi0_l00000
1Om[IK[o0000ofeW^_m]Ik[o000000?oL6Vk00Go0000ogA]_?mdKKcoM6flo`000003ogQ`_P04o`00
0?mmMKooOGFoo`0000?oPWW100?o0000ohMn`_n7O/800_n7O/801Ol0003oSH?4ohf3a?n=PlCo0000
00CoThW500?o0000oiV>aonIS/L00_nIS/L00ol0003oWiC8oinDb003oinDb003o`000?nUV/[oYI[:
00;oYI[:0_l00004okj`c003o`000?o5]/goaKK=00?oaKK=00?o0000olZlcOo:_<d00_o:_<d00ol0
003ocl;>olo2cP04olo2cP04o`000?oCalkodlO>om?7cP;o00001?oXilh01Ol0003ojN_>onW[c_oY
jlko000000;oj^k>0_l000000ooYl<oo0000o`00000Uooooo`03o`000?oooooooooo00Sooooo000P
ooooo`03o`000?oooooooooo02Gooooo0ol0000Dooooo`03o`000?oRg<ooh]c?00?oh]c?00?o0000
on;Jc_oRf/h00ooRf/h00ol0003odlG<om?5c004om?5c003o`000?oA`/_odL;;00CodL;;00?o0000
oljnboo>_//01?o>_//00ol0003obk[:ol^jbP03ol^jbP03o`000?neZ<co]JS<00?o]JS<00?o0000
ok6TbonaY</00_naY</00ol0003o[9k9ojbNb@03ojbNb@03o`000?nVVLSoYYW800;oYYW800?o0000
oj6DaonQU<L00_nQU<L00ol0003oVho6oi^?aP03o`000003oh=oaol0003oOg_500?oOg_500Co0000
og]g`omkMl?o00000_mhLl401Ol0003oM72oogA`_omdL;oo000000;oLFbn00Co0000ofmZ_?m_J[co
00000_m]Ik/01?l0003oJfJjo`000?l00003ofUT^P;o000000?oJ6>io`000?l000001?l00003ofUT
^@;oK6Fj0ol00002ofeW^P04o`000?m`JK_oL6Vko`0000?oM6fl00Go0000ogQ`__mhL;koN72no`00
0002ogee_`03o`000?n2NL7oPWW100;oPWW100Go0000ohMn`_n7O/;oQgk2o`000003ohf3a003o`00
0?nCRLGoThW500?oThW500?o0000oiV>aonIS/L00_nIS/L00ol0003oWiC8oinDb002oinDb003o`00
0?nUV/[o000000;o000000?o^:W;o`000?nn/<`00onn/<`00ol0003oaKK=olFfc@03olFfc@03o`00
0?o:_<gob[c=00;ob[c=00?o0000olo2c_o?`/h01?o?`/h01_l0003odlO>om?7c_l0003oi^??o`00
00Coj>O>00Go0000onW[c_oYjlkojN_>o`000003on[^cP?o00009_ooool00ol0003oooooooooo`08
ooooo`008?ooool00ol0003oooooooooo`0Rooooo`?o00005oooool00ol0003oh]c?on;Lc`03on;L
c`03o`000?oRf/koh][>00?oh][>00?o0000om?5c?oCaL`01OoCaL`00ol0003odL;;om72b`04om72
b`03o`000?o>_/_oc[k;00?oc[k;00?o0000ol^jb_o;^/X00_o;^/X2o`0000Ko]JS<00?o0000ok6T
bonaY</00_naY</00ol0003o[9k9ojbNb@03ojbNb@05o`000?nVVLSoYYW8ojJIb?l000001?nQU<L0
1Ol0003oVho6o`000?n7Q<Wo000000?oPgo700Go0000ogmkaOmoNlGoOg_5o`000003og]g``04o`00
0?mhLl7oN7?1o`0000;oM72o00Go0000og5/__maK;koLFbno`000002ofmZ_004o`000?m]Ik_oKFNk
o`0000;oJFFj00So0000ofUT^_mYI;[oJFBjo`000?mXHkWo0000ofQS^@;o000000?oJ6>io`000?mY
I;T00_mYI;T01?l0003oK6FjofaU^_m/IKX2o`000003ofeW^_l0003oL6Vk00;oL6Vk00Go0000ogA]
_?mdKKcoM6flo`000003ogQ`_P04o`000?mmMKooOGFoo`0000?oPWW100Go0000ohMn`_n7O/;oQgk2
o`000004ohf3a003o`000?nCRLGoThW500;oThW500?o0000oiV>aonIS/L00_nIS/L00ol0003oWiC8
oinDb002oinDb0;o00001OnhZL/00ol0003o_[3<okj`c002okj`c003o`000?o5]/goaKK=00;oaKK=
00?o0000olZlcOo:_<d00oo:_<d00ol0003ocl;>olo2cP03olo2cP03o`000?oCalko000000;oi^??
00?o0000onSWc_oXilh00_oXilh01Ol0003ojN_>onW[c_oYjlko000000?oj^k>0ol0000Vooooo`03
o`000?oooooooooo00Sooooo000Pooooo`;o00008Oooool2o`0001[ooooo00?o0000on;LcooRg<l0
1?oRg<l01ol0003oh][>on;Jc_oRf/ko0000omG8cOl000001ooCaL`00ol0003odL;;om72b`04om72
b`03o`000?o>_/_oc[k;00?oc[k;00Co0000ol^jb_o;^/[o00000_ni[Ld00ol0003o]JS<okFXc004
okFXc003o`000?naY<_o/JC;00;o/JC;00?o0000ojbNbOn/W/T00_n/W/T00ol0003oYYW8ojJIb002
ojJIb003o`000?nQU<OoXIC700;oXIC700Go0000ohN4bOn7Q<WoQhC9o`000003oh=oa`05o`000?mo
NlGoOg_5ogmkaOl000000_mkMl<01Ol0003oN7?1ogQc`OmhLl7o000000;oM72o00So0000og5/__ma
K;koLFbno`000?m_J[co0000ofeW^`;o00000omYIKX01ol0003oJFBjofUT^_l0003oJ6>io`000?mX
HkT01Ol00003ofUT^@03o`000?m/IK[oK6Fj00;oKfRk0_l00003og1Y^`05o`000?mdKKcoM6flogA]
_?l000000omhL;h01?l0003oOGFoogee_ol00003oh9i`@03o`000?n7O/;oQgk200;oQgk200Go0000
ohf3a?n=PlCoSH?4o`000005oi>9a@03o`000?nIS/OoVHk700;oVHk700Ko0000oinDb?nOU<So0000
ok2Sb_l00005okRYb`03o`000?nn/<co_[3<00;o_[3<00?o0000olFfcOo5]/d00oo5]/d00ol0003o
b[c=olZlc@02olZlc@03o`000?o?`/kocl;>00?ocl;>0_l00003onKSc`03o`000?oXilkoj>O>00;o
j>O>00Go0000onW[c_oYjlkojN_>o`000002on[^cP;o000000?oeobgo`000?ooool09_ooool00ol0
003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Mooooo`?o00007Oooool00ol0003o
h]c?on;Lc`03on;Lc`04o`000?oRf/koh][>o`0000?oeLS=00?o0000om?5c?oCaL`01?oCaL`00ol0
003odL;;om72b`04om72b`03o`000?o>_/_oc[k;00?oc[k;00?o0000ol^jb_l000001?ni[Ld00ol0
003o]JS<okFXc003okFXc003o`000?naY<_o/JC;00;o/JC;00?o0000ojbNbOn/W/T00on/W/T00ol0
003oYYW8ojJIb002ojJIb003o`000?nQU<OoXIC700;o00001?n7Q<T01?l0003oPgo7oh=oaol00003
ogmka@05o`000?mkMl?oNgO3og]g`ol000000_mhLl401?l0003oM72oogA`_ol00003og5/_P04o`00
0?m_J[co0000o`0000;oJFJl00Co0000ofUU^_mYIK[o00000_mYI;X3o`000004ofQS^Ol0003o0000
o`0000;oJFBi00?o0000ofUT^OmYI;T00_l000000om/IK[o0000ofmX^`02ofmX^`;o000000?oL6Vk
o`000?mdKK`00_mdKK`01Ol0003oN72nogQ`__mhL;ko000000?oOGFo00Go0000oh9i`On2NL7oPWW1
o`000003ohMn`P03o`000?n=PlCoSH?400;oSH?400?o0000oi>9aOnCRLD00_nCRLD00ol0003oVHk7
oiV>a`02oiV>a`03o`000?nOU<So000000;o/:?:00?o0000okRYbonhZL/00onhZL/00ol0003o_[3<
okj`c002okj`c003o`000?o5]/goaKK=00?oaKK=00?o0000olZlcOo:_<d00oo:_<d01ol0003ocl;>
olo2c_o?`/ko0000on;Nd?l000000ooVhll00ol0003oj>O>onSWcP02onSWcP06o`000?oYjlkojN_>
onW[c_l0003oj^k>0_l000000ooGo;Oo0000o`00000Wooooo`03o`000?oooooooooo00Oooooo000P
ooooo`03o`000?oooooooooo01[ooooo0ol0000Pooooo`03o`000?oRg<ooh]c?00?oh]c?00?o0000
on;Jc_l000001?oEb<d00ol0003odlG<om?5c005om?5c003o`000?oA`/_odL;;00CodL;;00?o0000
oljnboo>_//00_o>_//2o`0000Ko^Jg=00?o0000okFXc?neZ<`00oneZ<`00ol0003o/JC;ok6Tb`02
ok6Tb`03o`000?n/W/Wo[9k900?o[9k900Oo0000ojJIb?nVVLSoYYW8o`000?nQU<Oo000000;oS8W<
00Go0000ohN4bOn7Q<WoQhC9o`000003oh=oa`05o`000?moNlGoOg_5ogmkaOl000000_mkMl<01Ol0
003oN7?1ogQc`OmhLl7o000000;oM72o00?o0000og5/__maK;h00_l000001OmYIkgo0000ofUV_?mY
I[co000000?oJFFj0_l000001?mXHk[o0000o`000?mXHkT2o`000003ofQS^Ol0003o000000?oJFBi
0_m/I[X2ofaU^P03o`000?m_J;_oKfRk00;oLVbl0ol00003ogA]_005o`000?mhL;koN72nogQ`__l0
00000_mmMKl01Ol0003oPWW1oh9i`On2NL7o000000CoQgk200Go0000ohf3a?n=PlCoSH?4o`000005
oi>9a@04o`000?nIS/OoVHk7oiV>a`;o00001?n`XlX00ol0003o^:W;okRYb`03okRYb`03o`000?nn
/<co_[3<00;o_[3<00?o0000olFfcOo5]/d00_o5]/d00ol0003ob[c=olZlc@03olZlc@04o`000?o?
`/kocl;>o`0000;oh]k@00Go0000onKScooVhlooi^??o`000004onSWcP04o`000?oYjlkojN_>onW[
cP;o000000KofObfo`000?oGo;Oo0000ooooool0000Vooooo`03o`000?oooooooooo00Oooooo000P
ooooo`?o00005oooool3o`0002?ooooo00?o0000on;LcooRg<l00ooRg<l2o`0000KoeLS=00?o0000
om?5c?oCaL`01OoCaL`00ol0003odL;;om72b`03om72b`07o`000?o>_/_oc[k;oljnbol0003o_K7>
o`000006okV]c@03o`000?neZ<co]JS<00Co]JS<00Go0000ok6TbonaY<_o/JC;o`000005ojbNb@04
o`000?nVVLSoYYW8ojJIb0;o00001?n<RL`01Ol0003oQhC9ohN4bOn7Q<Wo000000;oPgo700?o0000
ogmkaOmoNlD00_moNlD01?l0003oNgO3og]g`ol00002ogQc`@08o`000?mdL;ooM72oo`000?maK;ko
0000ofUY_ol00002ofUW_@04o`000?mYI[coJFJlo`0000?oJFFj00?o0000ofQS^_mXHkX00_l00003
ofQS^@03o`000?mYI;WoJFBi00;oJFBi00Go0000ofaV^_m/I[[oK6Fjo`000002ofmX^`04o`000?mb
K;coLVblog9/_0Go00000omhL;h01Ol0003oOGFoogee_ommMKoo000000?oPWW100Go0000ohMn`_n7
O/;oQgk2o`000004ohf3a003o`000?nCRLGoThW500;oThW500Ko0000oiV>aol0003o0000ojVKbOl0
0004ok2SbP03o`000?nhZL_o^:W;00?o^:W;00?o0000okj`c?nn/<`00_nn/<`00ol0003oaKK=olFf
c@03olFfc@03o`000?o:_<gob[c=00;ob[c=00?o0000olo2c_l000000ooRg]001Ol0003oi^??onKS
cooVhloo000000Coj>O>00Wo0000onW[c_oYjlkojN_>o`000?oIo;Ko0000omOl]ol000000oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Oooooo`;o00005_ooool3o`00
02Oooooo00Oo0000on;LcooRg<ooh]c?o`000?oFbloo000000OoeLS=00?o0000om?5c?oCaL`01?oC
aL`00ol0003odL;;om72b`04om72b`03o`000?o>_/_o000000?o_K7>00?o0000okV]cOni[Ld01?ni
[Ld00ol0003o]JS<okFXc003okFXc003o`000?naY<_o/JC;00;o/JC;00?o0000ojbNbOn/W/T00on/
W/T01Ol0003oYYW8o`000?n@Slko000000CoS8W<00Go0000ohN4bOn7Q<WoQhC9o`000003oh=oa`05
o`000?moNlGoOg_5ogmkaOl000000_mkMl<01Ol0003oN7?1ogQc`OmhLl7o000000;oM72o00Go0000
ofUY_omYJKooJFVoo`000002ofUW_@04o`000?mYI[coJFJlo`0000;oJFFj00[o0000ofQS^_mXHk[o
0000ofQT^_l0003oJ6>io`000?mYHkWo00000omYI;T01?l0003oK6JjofaV^_m/I[X2o`0000;oKfRk
0ombK;`4ogM`_@Go00000ommMKl01Ol0003oPWW1oh9i`On2NL7o000000CoQgk200Go0000ohf3a?n=
PlCoSH?4o`000003oi>9a@?o00000onYVlT00ol0003o/:?:ok2SbP02ok2SbP03o`000?nhZL_o^:W;
00?o^:W;00?o0000okj`c?nn/<`00_nn/<`00ol0003oaKK=olFfc@03olFfc@03o`000?o:_<gob[c=
00?ob[c=00?o0000on;Nd?oRg]000_oRg]001Ol0003oi^??onKScooVhloo000000Coj>O>00Wo0000
onW[c_oYjlkojN_>o`000?oIo;Ko0000omOl]ol000001?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Oooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo0ol0000Zoooo
o`04o`000?oRg<ooh]c?o`0000?oe/_?00?o0000omG8cOoEb<d01?oEb<d00ol0003odlG<om?5c005
om?5c003o`000?oA`/_odL;;00CodL;;00?o0000okfac_nm/Lh00onm/Lh00ol0003o^Jg=okV]c@04
okV]c@03o`000?neZ<co]JS<00?o]JS<00?o0000ok6TbonaY</00_naY</00ol0003o[9k9ojbNb@02
ojbNb@;o00000on@Slh00ol0003oS8W<ohb9c002ohb9c005o`000?n7Q<WoQhC9ohN4bOl000000on3
OlL01Ol0003oOg_5ogmkaOmoNlGo000000;oNgO300Go0000ogQc`OmhLl7o0000ogA`_`02o`0000?o
JFVo00Co0000ofUW_OmYIkgo00000_mYI[`01ol0003oJFFjo`000?mWI;_o0000ofQS^_l000000_mX
I;X2o`000003ofQS^OmYHkWoJFBi00;oJFBi00Co0000ofaV^_m/I[[oK6Jj0_m_JK/00ol0003oKfRk
o`000002og9/_003o`000?mgL;goMg2m00;oMg2m0ommMKl5o`0000?oPWW100?o0000ohMn`_n7O/80
0_n7O/800ol0003oSH?4ohf3a005o`0000;oXIC71OnYVlT00ol0003o/:?:ok2SbP02ok2SbP03o`00
0?nhZL_o^:W;00?o^:W;00?o0000okj`c?nn/<`00_nn/<`00ol0003oaKK=olFfc@03olFfc@04o`00
0?o:_<gob[c=olZlc@;o00001?oRg]000ol0003oi^??onKSc`02onKSc`05o`000?oXilkoj>O>onSW
c_l000000_oYjlh01Ol0003ofObfo`000?oGo;Oo000000Gooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`07ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool3o`0002gooooo00?o0000
on;Lcol000001OoFbll00ol0003oeLS=omG8c@04omG8c@03o`000?oCaLcodlG<00GodlG<00?o0000
om72booA`//00_oA`//2o`0000Ko_K7>00?o0000okV]cOni[Ld01?ni[Ld00ol0003o]JS<okFXc002
okFXc003o`000?naY<_o/JC;00;o/JC;00Oo0000ojbNbOn/W/Wo[9k9o`000?nEU=3o000000CoT8o>
00?o0000ohb9c?n<RL`00_n<RL`01Ol0003oQhC9ohN4bOn7Q<Wo000000;oPgo700Go0000ogmkaOmo
NlGoOg_5o`000003og]g``04o`000?mhLl7oN7?1o`0000;oJV_100Go0000ofUY_omYJKooJFVoo`00
0002ofUW_@04o`000?mYI[coJFJlo`0000?oIfBk0_l00002ofQT^P;o000000OoJ6>iofUS^OmYI;Wo
JFBio`000?m[I[[o000000;oK6Jj00Go0000ofmY^om_JK_oKfRko`000003og9/_0CoMg2m00Co0000
ogee_ommMKooOGFo0on3N/4<o`0000;oVHk61OnQU<L00ol0003oZI_9ojVKb@02ojVKb@03o`000?n`
Xl[o/:?:00;o/:?:00?o0000okRYbonhZL/00onhZL/00ol0003o_[3<okj`c002okj`c003o`000?o5
]/goaKK=00?oaKK=00Ko0000olZlcOo:_<go0000omgHdOl00004on;Nd003o`000?oVhlooi^??00;o
i^??00Ko0000onSWc_oXilkoj>O>o`000?oYjlh2o`000004omWl]_l0003oeobgo`0000Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Ooo
ool00ol0003oe/_?omK;c`05omK;c`03o`000?oEb<goeLS=00CoeLS=00?o0000om?5c?oCaL`01?oC
aL`01Ol0003odL;;om72booA`/_o000000;o`;G?00?o0000okfac_nm/Lh01?nm/Lh00ol0003o^Jg=
okV]c@03okV]c@03o`000?neZ<co]JS<00?o]JS<00?o0000ok6TbonaY</00_naY</00ol0003o[9k9
o`000003oiFDd003o`000?n@SlkoT8o>00;oT8o>00Go0000ohb9c?n<RLcoS8W<o`000003ohN4b@05
o`000?n3OlOoPgo7oh=oaol000000omoNlD01Ol0003oNgO3og]g`ol0003oN7?100;o00000omZJl40
1?l0003oJFVoofUY_ol00002ofUW_@04o`000?mYI[coJFJlo`0000?oIfBk0_l00002ofQT^P03o`00
0?mXI;[o000000;oJF>i0_l00002of]V^P03o`000?m/I[[o000000?oKfVk00GoKfRko`000?mbK;co
LVblo`000003ogM`_@05o`000?mmMKooOGFoogee_ol000000on3N/44ohZ0``GoTXO41?nIS/H00ol0
003oXIC7oj6Da`03oj6Da`05o`000?nYVlWoZI_9ojVKbOl000001?n`XlX00ol0003o^:W;okRYb`03
okRYb`03o`000?nn/<co_[3<00;o_[3<00?o0000olFfcOo5]/d00oo5]/d00ol0003ob[c=o`000002
omgHd@03o`000?oRg]3oh]k@00;oh]k@00?o0000onKScooVhll00_oVhll01?l0003oj>O>onSWc_oX
ilh3o`000005omWl]_l0003oeobgomOl]ol000001oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`04ooooo`;o00002_ooool3o`0003Cooooo00?o0000omK;cooFbll01_oFbll00ol0003oeLS=
omG8c@04omG8c@03o`000?oCaLcodlG<00CodlG<00?o0000om72bol000001?o0]Ll00ol0003o_K7>
okfacP04okfacP03o`000?ni[Lgo^Jg=00?o^Jg=00?o0000okFXc?neZ<`00oneZ<`00ol0003o/JC;
ok6Tb`02ok6Tb`03o`000?nEU=3oUIC@00?oUIC@00Go0000oi2?c_n@SlkoT8o>o`000004ohb9c005
o`000?n7Q<WoQhC9ohN4bOl000000_n3OlL00ol0003oOg_5ogmka@02ogmka@04o`000?mkMl?oNgO3
o`0000;oJVg300Co0000ofY[`OmZJl7o00000omYJKl00ol0003oJFNmofUW_@02o`000003ofIU_Ol0
003oIfBk00;oIfBk0_l000001OmXI;[o0000ofQT^_l0003oJFFk00;o000000KoJfJko`000?m[I[[o
JfJjofaV^_l00004ofmY^`04o`000?mbK;coLVblo`0000CoMg2m00Co0000ogee_ommMKooOGFo0on3
N/401Ol0003oRX33ohZ0`on:P<?o000000CoTXO400?o0000oiV>a_nIS/H00_nIS/H00ol0003oXIC7
oj6Da`02oj6Da`03o`000?nYVlWoZI_900;oZI_900?o0000ok2Sb_n`XlX00_n`XlX00ol0003o^:W;
okRYb`03okRYb`03o`000?nn/<co_[3<00;o_[3<00?o0000olFfcOo5]/d00_o5]/d2o`0000?ogMSA
00?o0000on;Nd?oRg]000_oRg]000ol0003oi^??onKSc`02onKSc`0;o`000?oXilkoj>O>onSWc_l0
003ofobho`000?oIo;Ko0000omOl]ol000002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3o`0003Sooooo00?o0000omK;cooFbll0
1OoFbll00ol0003oeLS=omG8c@04omG8c@03o`000?oCaLcodlG<00GodlG<00?o0000ol2ecoo0]Ll0
1?o0]Ll00ol0003o_K7>okfacP04okfacP03o`000?ni[Lgo^Jg=00?o^Jg=00?o0000okFXc?neZ<`0
0_neZ<`01ol0003o/JC;ok6TbonaY<_o0000oiVJdol000001OnEU=001Ol0003oT8o>oi2?c_n@Slko
000000CoS8W<00Go0000ohN4bOn7Q<WoQhC9o`000002oh=oa`06o`000?moNlGoOg_5ogmkaOl0003o
NgO30_l00003ofY]``04o`000?mZJl7oJV_1o`0000?oJFVo00Co0000ofUW_OmYIkgo00000_mVIKd0
1ol0003oIfBkofMT^ol0003oIVBlo`000?mXI;X00_l000001_mYIK_o0000ofUU^ol0003oJfJko`00
00;oJfJj00?o0000ofmY^om_JK/00_m_JK/01?mcKKgo0000og9/_?l00004ogM`_@05o`000?mmMKoo
OGFoogee_ol000000on3N/44ohZ0``03o`000?nBQlCoTXO400;oTXO400Go0000oiV>a_nIS/KoVHk6
o`000004oj6Da`03o`000?nYVlWoZI_900;oZI_900?o0000ok2Sb_n`XlX00_n`XlX00ol0003o^:W;
okRYb`03okRYb`03o`000?nn/<co_[3<00;o_[3<00Oo0000olFfcOo5]/goaKK=o`000?oGd=;o0000
00?ogMSA00?o0000on;Nd?oRg]000_oRg]000ol0003oi^??onKSc`02onKSc`0;o`000?oXilkoj>O>
onSWc_l0003ofobho`000?oIo;Ko0000omOl]ol000002Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000looooo`03o`000?oFblooe/_?00Go
e/_?00?o0000omG8cOoEb<d01?oEb<d00ol0003odlG<om?5c004om?5c0;o00001_o0]Ll00ol0003o
_K7>okfacP04okfacP03o`000?ni[Lgo^Jg=00?o^Jg=00?o0000okFXc?neZ<`00_neZ<`00ol0003o
/JC;o`000003oiVJd`03o`000?nEU=3oUIC@00?oUIC@00Go0000oi2?c_n@SlkoT8o>o`000004ohb9
c004o`000?n7Q<WoQhC9o`0000?oPgo700?o0000ogmkaOmoNlD00_l00002of]`aP04o`000?mZKL?o
JVg3o`0000?oJV_100Co0000ofUY_omYJKoo00000_mYIkd01ol0003oIVFmofIU_OmVIKgo0000ofMT
^ol000000_mVI;`2o`000003ofQT^_l0003oJFFk00;o00000_m[I[/01?l0003oJfJjofiY_?l00003
ofmY^`04o`000?mcKKgo0000o`0000CoMg2m00Go0000ogee_ommMKooOGFoo`000003oh=j`@05o`00
0?n:P<?oRX33ohZ0`ol000001?nBQl@01Ol0003oVHk6oiV>a_nIS/Ko000000GoXIC700Go0000ojVK
bOnYVlWoZI_9o`000004ok2SbP03o`000?nhZL_o^:W;00?o^:W;00?o0000okj`c?nn/<`00_nn/<`0
1?l0003oaKK=olFfcOl00002omO@dP05o`000?oMf=7ogMSAomgHdOl000001?oRg]000ol0003oi^??
onKSc`02onKSc`0:o`000?oXilkoj>O>o`000?oKo;So0000omWl]_l0003oeobgo`0000_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo
00?o0000omK;cooFbll01OoFbll00ol0003oeLS=omG8c@04omG8c@03o`000?oCaLcodlG<00;odlG<
00Co0000ol>idOo3^M7o00001_o0]Ll00ol0003o_K7>okfacP03okfacP03o`000?ni[Lgo^Jg=00?o
^Jg=00?o0000okFXc?neZ<`00oneZ<`00ol0003oVI[CoiVJd`03oiVJd`03o`000?nEU=3oUIC@00;o
UIC@00?o0000oi2?c_n@Slh00_n@Slh01Ol0003oS8W<ohb9c?n<RLco000000?oQhC900So0000oh=o
aon3OlOo0000ogmkaOl0003oJg?9o`0000?oJg3600Co0000ofY]`omZKL?o00000_mZJl401_l0003o
JFVoofUY_omYJKoo0000ofUW_@;o00000omVIKd2o`0000?oIVBl00Oo0000ofQT^_l0003oJFFko`00
0?mYIK_o000000;oJfJk00CoJfJjo`000?m^JKco00000_m_JK/01Ol0003oLffmog=]_OmbK;co0000
00?oMg2m00Go0000ogee_ommMKooOGFoo`000003oh=j`@05o`000?n:P<?oRX33ohZ0`ol000001?nB
Ql@00ol0003oVHk6oiV>aP02oiV>aP03o`000?nQU<OoXIC700;oXIC700?o0000ojVKbOnYVlT00_nY
VlT00ol0003o/:?:ok2SbP02ok2SbP03o`000?nhZL_o^:W;00?o^:W;00?o0000okj`c?nn/<`00_nn
/<`2o`0000?oem3B00Go0000omgHdOoMf=7ogMSAo`000004on;Nd003o`000?oVhlooi^??00;oi^??
00Oo0000onSWc_l0003o0000om_l^?l0003ofObf00;o00003Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo1?l00014ooooo`03o`000?oFblooe/_?00Goe/_?00?o0000omG8cOoEb<d00ooEb<d01Ol0
003odlG<om?5c?oCaLco000000Co`kWA00?o0000ol2ecoo0]Ll01?o0]Ll00ol0003o_K7>okfacP03
okfacP03o`000?ni[Lgo^Jg=00?o^Jg=00Oo0000okFXc?neZ<co]JS<o`000?nNWmGo000000GoVI[C
00?o0000oiFDd?nEU=000_nEU=001Ol0003oT8o>oi2?c_n@Slko000000CoS8W<00Co0000ohN4bOn7
Q<Wo00000on3OlL01Ol0003oJg?9of]cbOm[LlWo000000;oJg3600Go0000ofY]`omZKL?oJVg3o`00
0002ofY[`@03o`000?mYJKooJFVo00;o00000_mUI[h01Ol0003oIVFmofIU_OmVIKgo000000?oIVBl
0ol00003ofUU^`05o`000?m[I[_oJfJkof]V^ol000000_m^JK`00ol0003oKfVko`000003og=]_@;o
00000_mgL;d00ol0003oOGFoogee_`02ogee_`05o`000?n3N/7oPg[1oh=j`Ol000000on:P<<01Ol0
003oTXO4oi:7a?nBQlCo000000CoVHk600?o0000oj6DaonQU<L00_nQU<L00ol0003oZI_9ojVKb@02
ojVKb@03o`000?n`Xl[o/:?:00;o/:?:00?o0000okRYbonhZL/00onhZL/01?l0003o_[3<okj`c?nn
/<`2o`0000Coem3B00Go0000omgHdOoMf=7ogMSAo`000004on;Nd003o`000?oVhlooi^??00;oi^??
0_l000001?oNoKco0000o`000?oIo;H2o`0000oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`007_ooool2o`0004Oooooo00?o0000omK;cooFbll01OoFbll00ol0003oeLS=
omG8c@03omG8c@03o`000?oCaLco000000Ko`kWA00?o0000ol2ecoo0]Ll01?o0]Ll00ol0003o_K7>
okfacP03okfacP03o`000?ni[Lgo^Jg=00?o^Jg=00?o0000okFXc?l000000onNWmD00ol0003oVI[C
oiVJd`03oiVJd`03o`000?nEU=3oUIC@00;oUIC@00Go0000oi2?c_n@SlkoT8o>o`000004ohb9c005
o`000?n7Q<WoQhC9o`000?n3OlL00_l00004of]cb@04o`000?m[L<KoJg36o`0000;oJVg300Go0000
ofY[`OmZJl7oJV_1o`000002ofUY_`05o`000?mUI[koIFJnofEV__l000000_mVIKd2o`0000;oIVBl
00?o0000ofMU_?l000001?mYIK/3of]V^`06o`000?m^JKcoKVVlofiY_?m_JK_o00000omcKKd2ogUb
_`;o000000?oMg2mo`000?mmMKl00_mmMKl01Ol0003oPg[1oh=j`On3N/7o000000?oRX3300?o0000
oi:7a?nBQl@00_nBQl@01Ol0003oVHk6oiV>a_nIS/Ko000000GoXIC700Go0000ojVKbOnYVlWoZI_9
o`000004ok2SbP03o`000?nhZL_o^:W;00?o^:W;00Ko0000okj`c?nn/<co0000om38d_l00004omO@
dP03o`000?oMf=7ogMSA00;ogMSA00Go0000on;Nd?oRg]3oh]k@o`000003onKSc`;o000000Kog_fl
o`000?oKo;So0000omWl]_l0000@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1_ooool0023ooooo00?o0000ooooooooool0AOooool00ol0003oe/_?omK;c`04omK;c`03o`000?oE
b<goeLS=00CoeLS=00?o0000ol>idOo3^M401_o3^M400ol0003o`;G?ol2ec`04ol2ec`03o`000?nm
/Lko_K7>00?o_K7>00?o0000okV]cOni[Ld00oni[Ld00ol0003oWYoEoijOe@03oijOe@03o`000?nI
V]?oVI[C00?oVI[C00?o0000oiFDd?nEU=000_nEU=001Ol0003oT8o>oi2?c_n@Slko000000?oS8W<
00Go0000ohN4bOn7Q<WoQhC9o`000002ofagc@03o`000?m[LlWoJg?900;oJg?900Co0000of]`a_m[
L<Ko00000_mZKL<01?l0003oJV_1ofY[`Ol00002ofUY_`05o`000?mUI[koIFJnofEV__l000000_mV
IKd01Ol0003oIFFno`000?mVI;co000000;oIfFl0ol000001_mYIK_o0000of]V^ol0003oKFVmo`00
00?oKVVl00Go0000og=]_OmcKKgoLffmo`000003ogUb_`03ogM`_Ol0003oOGFo00;oOGFo00Go0000
oh=j`On3N/7oPg[1o`000003ohZ0``03o`000?nBQlCoTXO400;oTXO400?o0000oiV>a_nIS/H00_nI
S/H00ol0003oXIC7oj6Da`02oj6Da`05o`000?nYVlWoZI_9ojVKbOl000001On`XlX00ol0003o^:W;
okRYb`03okRYb`;o00000_o@b=800ol0003oem3BomO@dP02omO@dP03o`000?oMf=7ogMSA00;ogMSA
00Go0000on;Nd?oRg]3oh]k@o`000002onKSc`04o`000?oQoL?o0000omkm_0;o000000?ofObfo`00
0?ooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03
o`000?oooooooooo04Gooooo00?o0000omK;cooFbll01?oFbll00ol0003oeLS=omG8c@03omG8c@03
o`000?o5_M;o`kWA00Oo`kWA00?o0000ol2ecoo0]Ll01?o0]Ll00ol0003o_K7>okfacP03okfacP05
o`000?ni[Lgo^Jg=okV]cOl000000_nRYML5oijOe@03o`000?nIV]?oVI[C00?oVI[C00?o0000oiFD
d?nEU=000_nEU=001Ol0003oT8o>oi2?c_n@Slko000000?oS8W<00Co0000ohN4bOl0003o00000om/
Mld01Ol0003oJg?9of]cbOm[LlWo000000?oJg3600Co0000ofY]`omZKL?o00000_mZJl42o`000003
of=W`Ol0003oIFJn00;oIFJn00?o0000ofIU_Ol000000_mUIKh01Ol0003oIVBlo`000?mWIKco0000
00;oJ6Jm0ol00002ofeY_@06o`000?m^JKcoKVVlofiY_?mbK[ko00000_mcKKd00ol0003oNG:oogUb
_`02ogUb_`;o00000_mmMKl00ol0003oPg[1oh=j`@02oh=j`@04o`000?n:P<?oRX33o`0000CoTXO4
00?o0000oiV>a_nIS/H00_nIS/H00ol0003oXIC7oj6Da`02oj6Da`03o`000?nYVlWoZI_900;oZI_9
00?o0000ok2Sb_n`XlX00_n`XlX00ol0003o^:W;okRYb`02okRYb`;o00000oo@b=800ol0003oem3B
omO@dP02omO@dP03o`000?oMf=7ogMSA00;ogMSA00oo0000on;Nd?oRg]3oh]k@o`000?oVhloo0000
on7m`ol0003og_flo`000?oKo;So0000omWl]_l000004oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00Gooooo000Rooooo`03o`000?oooooooooo04Cooooo00?o0000omK;cooFbll0
1OoFbll01Ol0003oeLS=omG8cOoEb<go000000?oaKgB00?o0000ol>idOo3^M401Oo3^M400ol0003o
`;G?ol2ec`04ol2ec`03o`000?nm/Lko_K7>00?o_K7>00?o0000okV]cOl000001?nRYML5oijOe@03
o`000?nIV]?oVI[C00?oVI[C00?o0000oiFDd?nEU=000_nEU=001?l0003oT8o>oi2?c_l00004ohb9
c004o`000?m/Nm7oK7_Ao`0000?oK7O=00Go0000of]cbOm[LlWoJg?9o`000002of]`aP04o`000?mZ
KL?oJVg3o`0000?oJV_100Co0000of=W`OmSIl7o00000omUI[h2o`0000?oIFFn0_l000001omWIKco
0000ofQV_OmXI[go0000of]X_Ol000000om]JKd01_l0003oKVVlofiY_?l0003oLVjno`0000;oLffm
00Co0000ogUb_omiL[ooNG:o0_moN<82o`000003ogee_ol0003oPg[100;oPg[100Go0000ohZ0`on:
P<?oRX33o`000004oi:7a005o`000?nIS/KoVHk6oiV>a_l000001?nQU<L00ol0003oZI_9ojVKb@02
ojVKb@03o`000?n`Xl[o/:?:00;o/:?:00?o0000okRYbonhZL/00_l000000oo8_m;o0000om38dP02
om38dP03o`000?oGd=;oem3B00;oem3B00?o0000omgHdOoMf=400_oMf=401?l0003oh]k@on;Nd?oR
g]02o`0000;ohOg300Ko0000omkm_?l0003ofobho`000?oIo;HEooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01Oooool002?ooooo0_l00015ooooo`03o`000?oFblooe/_?00Goe/_?
00?o0000omG8cOl000001Oo5_M800ol0003o`kWAol>id@05ol>id@03o`000?o0]Loo`;G?00Co`;G?
00?o0000okfac_nm/Lh00onm/Lh00ol0003oXZGGoj:Ue`04oj:Ue`03o`000?nNWmGoWYoE00;oWYoE
00?o0000oiVJdonIV]<00onIV]<01Ol0003oUIC@oiFDd?nEU=3o000000?oT8o>00Go0000ohb9c?n<
RLcoS8W<o`000003ofakd@05o`000?m/MlgoK7O=ofagcOl000000om[LlT01?l0003oJg36of]`a_l0
0002ofY]``04o`000?mZJl7o0000o`0000?oHfO100Go0000ofEV__mUI[koIFJno`000004ofEU_P04
o`000?mWIKcoIfFlo`0000;oJ6Jm00?o0000of]X_Ol000000om]JKd00om^JKco0000og9^_P02og9^
_P03o`000?mcKKgo000000?oNG:o00?o0000ogmh`_moN<800_moN<82o`0000;oPg[100Go0000ohZ0
`on:P<?oRX33o`000004oi:7a003o`000?nIS/KoVHk600;oVHk600?o0000oj6DaonQU<L00_nQU<L0
1Ol0003oZI_9ojVKbOnYVlWo000000Go/:?:0_l00003olRodP05o`000?o@b=;od<SBom38d_l00000
1OoGd=801Ol0003ogMSAomgHdOoMf=7o000000?oh]k@00Co0000on7m`ooQoL?o00000_oNoK`2o`00
0003omWl]_oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05oooo
o`009Oooool00ol0003oooooooooo`13ooooo`03o`000?oFblooe/_?00Goe/_?00?o0000olFmd_o5
_M801Oo5_M82o`0000Ko`kWA00?o0000ol2ecoo0]Ll01?o0]Ll01Ol0003o_K7>okfac_nm/Lko0000
00;oYZ[J1_nRYML00ol0003oWYoEoijOe@02oijOe@03o`000?nIV]?oVI[C00?oVI[C00Go0000oiFD
d?nEU=3oUIC@o`000003oi2?cP05o`000?n<RLco0000off0eOl000000om/Nm401Ol0003oK7O=ofag
cOm/Mlgo000000;oJg?900Go0000of]`a_m[L<KoJg36o`000002ofY]``04o`000?mPJ<CoH6S4o`00
00?oHfO100?o0000ofEV__mUI[h00_l00003ofEU_P;o000000GoIfFlo`000?mXI[goJ6Jmo`000002
of]X_@05o`000?m]JKgoKFVmofiY_?l000001?mbK[h00omcKKgo0000ogUb_`02ogUb_`03o`000?mo
N<;oOgS200;oOgS20_n7Ol@2o`000005oh=j`Ol0003oRX33ohZ0`ol000001?nBQl@00ol0003oVHk6
oiV>aP02oiV>aP03o`000?nQU<OoXIC700;oXIC700?o0000ojVKbOnYVlT00_nYVlT00ol0003o/:?:
ok2SbP03o`0000Cob;oB00Go0000om38d_o@b=;od<SBo`000005omO@dP05o`000?oMf=7ogMSAomgH
dOl000000_oRg]02o`0000;ohOg300Go0000omkm_?l0003ofobho`00000Hooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o0000ooooooooool0@oooool00ol0
003oe/_?omK;c`03omK;c`03o`000?o6`=Coa/3D00SoaKgB00?o0000ol>idOo3^M401?o3^M400ol0
003o`;G?ol2ec`04ol2ec`03o`000?nm/Lko000000CoYZ[J00?o0000oj:UeonRYML00onRYML00ol0
003oWYoEoijOe@02oijOe@03o`000?nIV]?oVI[C00?oVI[C00Go0000oiFDd?nEU=3oUIC@o`000003
oi2?cP05o`000?m]P=GoKH3Eoff0eOl000000om/Nm401Ol0003oK7O=ofagcOm/Mlgo000000;oJg?9
00Co0000of]`a_m[L<Ko00000_mZKL<01Ol0003oH6S4of1Xa?mPJ<Co000000?oHfO100Go0000ofEV
__l0003oHVK1o`000002ofEU_P04o`000?mVIkoo0000o`0000?oJ6Jm00?o0000of]X_Ol000000om]
JKd00ol0003oLVjnog9^_P03og9^_P;o00000_miL[l00ol0003oOgS2ogmh`P02ogmh`P03o`000?n7
OlCoQgo400;oQgo40ol000000on:P<?o0000oi:7a002oi:7a003o`000?nIS/KoVHk600;oVHk600?o
0000oj6DaonQU<L00_nQU<L01?l0003oZI_9ojVKbOnYVlT4o`0000;o_[KA00?o0000olRod_o8_m80
0_o8_m801Ol0003od<SBom38d_o@b=;o000000Goem3B00Ko0000omgHdOoMf=7ogMSAo`000?oRg]02
o`0000?ohOg300Co0000omkm_?l0003o00006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Go0000omK;cooFblooe/_?o`00
0004olK0e003o`000?o5_M;oaKgB00GoaKgB00?o0000ol>idOo3^M401?o3^M400ol0003o`;G?ol2e
c`04ol2ec`03o`000?nVZ][oYZ[J00CoYZ[J00?o0000oj:UeonRYML00onRYML00ol0003oWYoEoijO
e@02oijOe@03o`000?nIV]?oVI[C00?oVI[C00Wo0000oiFDd?nEU=3oUIC@o`000?n@Slko0000ofj6
fOl000000om]P=D01Ol0003oK7_AofakdOm/Nm7o000000;oK7O=00Go0000of]cbOm[LlWoJg?9o`00
0002of]`aP;o000000?oGF[8o`000?mPJ<@00_mPJ<@01?l0003oHfO1of=W`OmSIl42o`0000;oHVK1
00?o0000ofEU__l000000_mVIkl01Ol0003oJ6JmofQV_OmXI[go000000;oJfRm00Co0000ofeY_Ol0
003o00001OmbK[h2ogQc`@04o`000?miL[ooNG:oo`0000?oOgS200?o0000ohMoa?n7Ol@00_n7Ol@3
ohn7a`Go000000?oTXO4o`000?nIS/H00onIS/H00ol0003oXIC7oj6Da`02oj6Da`?o000000?o]Jc@
o`000?nn]]400onn]]400ol0003ob;oBolRodP02olRodP05o`000?o@b=;od<SBom38d_l000001OoG
d=801?l0003ogMSAomgHdOoMf=42o`000009on?lbol0003ohOg3on7m`ol0003og_flo`000?oKo;So
000001[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`00:?ooool2o`00
04Cooooo00?o0000omK;col000001_o6`=@2o`0000KoaKgB00?o0000ol>idOo3^M401?o3^M400ol0
003o`;G?ol2ec`03ol2ec`03o`000?nZ[mcoYZ[J00GoYZ[J00?o0000oj:UeonRYML00onRYML2o`00
00?oWYoE00?o0000oiVJdonIV]<00onIV]<01?l0003oUIC@oiFDd?nEU=02o`0000;oKXKI00Go0000
off0eOm]P=GoKH3Eo`000003ofakd@04o`000?m/MlgoK7O=o`0000?oJg?900Co0000of]`a_m[L<Ko
00000_mMJ/P01Ol0003oH6S4of1Xa?mPJ<Co000000?oHfO100Oo0000of9V`OmRI/7oHVK1o`000?mU
IKko000000;oIVNo1?l00002of]X_@;o00000_m`KKl00ol0003oLVjnog9^_P02og9^_P06o`000?mh
Ll7oN7?1o`000?miL[oo00000omoN<800ol0003oQgo4ohMoa002ohMoa004o`000?n?QlOoShO7ohn7
a`CoV9393?l00003okF/d003o`000?nn]]7o_[KA00;o_[KA00?o0000olRod_o8_m800_o8_m800ol0
003od<SBom38dP02om38dP03o`000?oGd=;oem3B00;oem3B00Go0000omgHdOoMf=7ogMSAo`000002
on?lb`05o`000?oQoL?ohOg3o`000?oNoK`00_l0000Looooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0@_ooool00ol0003oa/3DolK0e007
olK0e003o`000?o5_M;oaKgB00CoaKgB00?o0000ol>idOo3^M401?o3^M401Ol0003o`;G?ol2ecoo0
]Loo000000?oZZoL00?o0000ojJZf_nVZ]X00onVZ]X2o`0000GoXZGG00Go0000oijOeOnNWmGoWYoE
o`000005oiVJd`03o`000?nEU=3o000000;oL8cN00Co0000ofj6fOm^Q]Wo00000om]P=D01Ol0003o
K7_AofakdOm/Nm7o000000;oK7O=00Co0000of]cbOm[LlWo00000_m[L<H01Ol0003oGF[8oeeZb?mM
J/So000000?oH6S400?o0000of=W`OmSIl400_l00003of9V`@;o00000_mVIkl00ol0003oJ6W0ofQY
`003o`000003ofa/`?l0003oL6fo00;oL6fo00Go0000og9^__mbK[koLVjno`000003ogQc`@03ogUb
_ol0003oOgS200;oOgS200?o0000ohMoa?n7Ol@00_n7Ol@01Ol0003oShO7ohn7aon?QlOo000000Co
V9391OnQVL`00ol0003oZj;>oj^RcP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l000001?nn]]400ol0
003ob;oBolRodP02olRodP03o`000?o@b=;od<SB00;od<SB00?o0000omO@d_oGd=800_oGd=800ol0
003ogMSAomgHd@02o`000005on?lbol0003ohOg3on7m`ol000000_oNoK`00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000oooo
ooooool0@oooool9olK0e003o`000?o5_M;oaKgB00CoaKgB0_l00005ol>id@03o`000?o0]Loo0000
00GoZZoL0_l00005ojJZfP03o`000?nRYMOoXZGG00?oXZGG00Go0000oijOeOnNWmGoWYoEo`000005
oiVJd`;o00000om`S=h01?l0003oKXKIofj6fOl00003off0e@04o`000?m/Nm7oK7_Ao`0000?oK7O=
00?o0000of]cbOm[LlT00_l000000omIK<co0000oeeZb002oeeZb009o`000?mPJ<CoH6S4of1Xa?l0
003oHfO1o`000?mOJ<Co000000?oHVK10_l00002ofIW_`04o`000?mXJL3oJ6W0o`0000?oK6c000Oo
0000og1]_om`KKooL6foo`000?mbK[ko000000GoN7?10_l00003ogmh`P05o`000?n7OlCoQgo4ohMo
a?l000000on?QlL00ol0003oV939oiR@b@02oiR@b@03o`000?nQVLcoXIW<00;oXIW<00?o0000oj^R
c_n[X/h00_n[X/h01Ol0003o]Jc@okF/d?ne[=3o000000Co_[KA00?o0000olRod_o8_m800_o8_m80
0ol0003od<SBom38dP02om38dP03o`000?oGd=;oem3B00;oem3B00Co0000omgHdOl0003o00000_oS
o</01_l0003ohOg3on7m`ol0003og_flo`00023ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`04ooooo`00;?ooool00ol0003oooooooooo`13ooooo`;o00001oo6`=@2o`0000KoaKgB
00?o0000ol>idOo3^M400oo3^M400ol0003oZZoLojZ_g006ojZ_g003o`000?nVZ][oYZ[J00?oYZ[J
00?o0000oj:UeonRYML00onRYML01Ol0003oWYoEoijOeOnNWmGo000000?oVI[C00Co0000og:Bhomb
T^?o00000om`S=h01?l0003oKXKIofj6fOl00003off0e@04o`000?m/Nm7oK7_Ao`0000?oK7O=00Co
0000of]cbOm[LlWo00000_mIK<`01Ol0003oGF[8oeeZb?mMJ/So000000?oH6S40_l00002oemXa008
o`000?mRI/7oHVK1o`000?mSJL?o0000ofIW_ol00003ofQY`004o`000?m/K<3oK6c0o`0000CoL6fo
00?oLVjno`000?mhLl401?mhLl42ogija@04o`000?moN<;oOgS2o`0000?oQgo400Go0000ohn7aon?
QlOoShO7o`000004oiR@b@03o`000?nQVLcoXIW<00;oXIW<00?o0000oj^Rc_n[X/h00_n[X/h01Ol0
003o]Jc@okF/d?ne[=3o000000Co_[KA00?o0000olRod_o8_m800oo8_m801Ol0003od<SBom38d_o@
b=;o000000Coem3B0_l000002?oSnM?o0000on?lbooSo<_o0000on7m`ol0003og_fl0_l0000Poooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002gooooo0_l00015ooooo`03
o`000?o6`=Coa/3D00Koa/3D00?o0000olFmd_o5_M801?o5_M801Ol0003o`kWAol>idOo3^M7o0000
00;o[KCN2?nZ[m`2o`0000CoYZ[J00?o0000oj:UeonRYML00onRYML01ol0003oWYoEoijOeOnNWmGo
0000oiVJdol000001?mbT^<01Ol0003oL8cNog2<g_m`S=ko000000;oKXKI00Co0000off0eOm]P=Go
00000om/Nm401ol0003oK7O=ofagcOm/Mlgo0000of]cbOl000000omIK<`01Ol0003oGF[8oeeZb?mM
J/So000000?oH6S400Oo0000oemXa?mOJ<CoGfS4o`000?mRI/7o000000;oHfW30_l00003ofQY`005
o`000?m/K<3oK6c0ofa/`?l000001?m`KKl00ol0003oN7?1ogQc`@03ogQc`@?oOW[500?o0000ogmh
`_l000000on7Ol@01Ol0003oShO7ohn7aon?QlOo000000CoV93900?o0000oj6Ic?nQVL`00_nQVL`0
0ol0003oZj;>oj^RcP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l000001?nn]]400ol0003ob;oBolRo
dP03olRodP05o`000?o@b=;od<SBom38d_l000000ooGd=82o`0000;ohoWC00?o0000on?lbol00000
0_oQoL<3o`0002;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`00;ooo
ool00ol0003oooooooooo`13ooooo`03o`000?o6`=Coa/3D00Koa/3D00?o0000olFmd_o5_M801?o5
_M800ol0003o`kWAo`000005ojfdgP03o`000?nZ[mcoZZoL00GoZZoL00?o0000ojJZf_nVZ]X00_nV
Z]X2o`0000CoXZGG00Go0000oijOeOnNWmGoWYoEo`000006og:Bh`05o`000?m`S=koL8cNog2<g_l0
00000_m^Q]T01?l0003oKH3Eoff0eOl00003ofakd@07o`000?m/MlgoK7O=ofagcOl0003oE6k@o`00
0003oeU/c005o`000?mMJ/SoGF[8oeeZb?l000000_mPJ<@2o`0000?oGfS400?o0000of9V`Ol00000
0_mSJL<2o`0000?oJ6W000Co0000ofa/`?m/K<3oK6c00om`KKl00ol0003oM7?3o`000004ogQc`@06
o`000?mnN/GoOW[5ogijaOmoN<;o00000on7Ol@01Ol0003oShO7ohn7aon?QlOo000000CoV93900?o
0000oj6Ic?nQVL`00_nQVL`00ol0003oZj;>oj^RcP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l00000
1Onn]]400ol0003ob;oBolRodP02olRodP06o`000?o@b=;od<SBom38d_l0003oem3B0_l000001?oQ
lm[o0000on?idol00002on?lb`03o`000?oQoL?ohOg300;o00009?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l00007olK0
e0;o00001Oo5_M800ol0003o[KCNojfdgP05ojfdgP;o00001_nZ[m`00ol0003oYZ[JojJZfP03ojJZ
fP03o`000?nRYMOoXZGG00;oXZGG00?o0000oijOeOl000000_mdV^P6og:Bh`05o`000?m`S=koL8cN
og2<g_l000000_m^Q]T01?l0003oKH3Eoff0eOl00003ofakd@04o`000?m/MlgoK7O=o`0000;oE6k@
00Go0000oeU/c?mIK<coFFc<o`000003oeeZb005o`000?mPJ<Co0000oeYYb?l000000omOJ<@2o`00
00?oHfW30_l00002ofQY`007o`000?m/K<3oK6c0ofa/`?l0003oL6foo`000003ogAc``04o`000?mh
Ll7oN7?1o`0000GoOW[50_l00002ohMoa003o`000?n?QlOoShO700;oShO700Go0000oiR@bOnHT<Wo
V939o`000004oj6Ic003o`000?n[X/koZj;>00;oZj;>00Go0000okF/d?ne[=3o]Jc@o`000005okjf
d@03o`000?o8_m;ob;oB00;ob;oB00Co0000om38d_o@b=;od<SB0_l00002on7cfP04o`000?oSnM?o
hoWCo`0000;ohoc;00Co0000on7m`ol0003o00009_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Cooooo000aooooo`;o0000AOooool00ol0003oa/3DolK0e006olK0e005o`000?o5
_M;oaKgBolFmd_l000000_n`^N08ojfdgP;o00001OnZ[m`2o`0000CoYZ[J00?o0000oj:UeonRYML0
0_nRYML00ol0003oM9[XogBJj002ogBJj003o`000?mbT^?oLY;S00?oLY;S00Go0000og2<g_m`S=ko
L8cNo`000002ofj6f@04o`000?m]P=GoKH3Eo`0000?oK7_A0_l000001Om>LMKo0000oeA^d?mDK]3o
000000;oFFc<00?o0000oeeZb?mMJ/P00_mMJ/P2o`0000;oFVW800Co0000oemXa?mOJ<CoGfS40_l0
0002of=Y``03o`000?mXKLCo000000;o00000_m/K<03o`0000GoM7?300?o0000ogQc`Ol000001Omn
N/D2ohJ3b@03o`000?n7OlCo000000CoShO700Go0000oiR@bOnHT<WoV939o`000004oj6Ic003o`00
0?n[X/koZj;>00;oZj;>00?o0000okF/d?ne[=000_ne[=000ol0003o_[KAokjfd@02okjfd@03o`00
0?o8_m;ob;oB00;ob;oB00?o0000om38d_o@b=800_l00003on7cfP06o`000?oSnM?ohoWCo`000?oS
o<_o00000_oQoL<00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool003?ooooo00?o0000ooooooooool0@oooool2o`0000Ooa/3D00?o0000olFmd_l0
00001On`^N000ol0003o[KCNojfdgP05ojfdgP;o00001OnZ[m`00ol0003oYZ[JojJZfP02ojJZfP06
o`000?nRYMOoXZGGoj:Ueol0003oMj7/1OmdV^P5og:Bh`05o`000?m`S=koL8cNog2<g_l000000_m^
Q]T01?l0003oKH3Eoff0eOl00003ofakd@;o000000GoCW7Fo`000?mDK]3oE6k@o`000002oeU/c003
o`000?mMJ/SoGF[800;oGF[800Go0000oeYYb?mJJLSoFVW8o`000002oemXa003o`000?mPK<Oo0000
00;oHfW300Co0000ofQ]a?mXKLCoJ6g40_l00002ofi`a003o`000?mdLl?oM7?300CoM7?300?oN7?1
o`000?mnN/D01?mnN/D3ohJ3b@03ohMoa?l0003oShO700?oShO700?o0000oiR@bOnHT<T00_nHT<T0
0ol0003oXIW<oj6Ic002oj6Ic003o`000?n[X/koZj;>00;oZj;>00Go0000okF/d?ne[=3o]Jc@o`00
0004okjfd@03o`000?o8_m;ob;oB00;ob;oB00Go0000om38d_l0003ofn[No`000003on7cfP03o`00
0?oSnM?o000000;ohoc;00?o0000on7m`ol00000:Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00?ooooo000dooooo`03o`000?oooooooooo04Cooooo00?o0000olK0e?o6`=@01Oo6
`=@00ol0003o/;WPok2ih006ok2ih003o`000?n]]=ko[KCN00Go[KCN00?o0000ojZ_g?nZ[m`00onZ
[m`2o`0000?oYZ[J00?o0000oj:Ueol000000omgXN`00ol0003oM9[XogBJj002ogBJj003o`000?mb
T^?oLY;S00;oLY;S0_l00002og2<gP04o`000?m^Q]WoKXKIo`0000;oKH3E00?o0000ofakdOl00000
0_m6M=/00ol0003oCW7Fo`000002oeA^d004o`000?mIK<coFFc<o`0000?oGF[80_l00003oeYYb003
o`000?mOJ<Co000000;oH6c70ol00003ofQ]a003o`000?m^L<CoKW3400;oKW3400?o0000ogAc`omd
Ll<01?mdLl<00ol0003oOW[5ogija@02ogija@03o`000?n6PlWoQX?900;oQX?90_l00003ohn7a`03
o`000?nHT<WoV93900;oV93900?o0000oj6Ic?nQVL`00_nQVL`00ol0003oZj;>oj^RcP02oj^RcP05
o`000?ne[=3o]Jc@okF/d?l000001?nn]]400ol0003ob;oBolRodP02olRodP;o00000_oKj]h01?l0
003ohO?Jon7cf_l00002on?id`03o`000?oSo<_ohoc;00;o0000:oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00?ooooo000eooooo`03o`000?oooooooooo04Cooooo00?o0000olK0
e?o6`=@01?o6`=@00ol0003o/kkRok2ih007ok2ih0;o00001_n]]=h2o`0000GoZZoL00Go0000ojJZ
f_nVZ][oYZ[Jo`000006ogNQk003o`000?mdV^SoM9[X00;oM9[X00?o0000og:BhombT^<00_mbT^<0
1?l0003oL8cNog2<g_l00002ofj6f@03o`000?m]P=GoKH3E00;o00000om6M=/00ol0003oCW7Fo`00
0002oeA^d004o`000?mIK<coFFc<o`0000;oGF[800?o0000oeA/c_l000000omJJLP00ol0003oGfS4
o`000003of1/a`;o00000omXKL@00ol0003oKW34ofi`a002ofi`a003o`000?mdLl?oM7?300;oM7?3
0_l00004ogija@03o`000?n6PlWoQX?900;oQX?90_n?SLd2o`000003ohn7aol0003oV93900?oV939
00?o0000oj6Ic?nQVL`00_nQVL`00ol0003oZj;>oj^RcP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l0
00001?nn]]401?l0003ob;oBolRod_o8_m82o`0000;ofn[N00Go0000on7cf_oQlm[ohO?Jo`000002
on?id`04o`000?oSo<_o0000o`0002gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`03ooooo`00=_ooool2o`0004Gooooo0_l00003olK0e003o`000?nc_^;o/kkR00;o/kkR00?o0000
ok2ih?n`^N001On`^N02o`0000Ko[KCN0_l00004ojZ_g003o`000?nVZ][o000000;oNZW`1omgXN`0
1?l0003oM9[XogBJj?mdV^P2o`0000?oLY;S00Co0000og2<g_m`S=ko00000_m^Q]T01Ol0003oKH3E
o`000?lmMn3o000000?oAWCK00?o0000odiae_l000000_mDK]000ol0003oFFc<oeU/c002o`0000?o
E6c>00Co0000oeYYb?mJJLSoFVW80_l00004of1/a`03o`000?mXKLCoJ6g400;oJ6g400Go0000ofi`
a?m^L<CoKW34o`000003ogAc``04o`000?miN/SoNG[8o`0000?oOW[500?o0000ohJ3bOn6PlT00_n6
PlT4ohn=c@03ohn7aol0003oV93900?oV93900?o0000oj6Ic?nQVL`00_nQVL`00ol0003oZj;>oj^R
cP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l000001?nn]]44o`000005om;NhOl0003ofn[Nom_Zg_l0
00000ooQlmX01?l0003ohoWCo`000?oSo</2o`0002kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`03o`000?o6`=Co000000Oo
/kkR0_l00006ok2ih0;o00001_n]]=h00ol0003oZZoLojZ_g002ojZ_g003o`000?mjZO3oNZW`00?o
NZW`00?o0000ogNQk?mgXN`00omgXN`2o`0000?oM9[X00Go0000og:BhombT^?oLY;So`000002og2<
gP03o`000?m^Q]WoKXKI00;o00000_lmMn001ol0003oAWCKodIdfom6M=_o0000odiae_l000000_mD
K]000ol0003oFFc<oeU/c002o`0000?oE6c>00Co0000oeYYb?mJJLSoFVW80_l00004of1/a`?o0000
00?oJ6g4o`000?m^L<@00om^L<@00ol0003oM7?3o`000004ogUjb004o`000?mnN/GoOW[5o`0000Co
QX?900?o0000ohn=cOn?SLd00_n?SLd2o`0000?oV93900?o0000oj6Ic?nQVL`00_nQVL`00ol0003o
Zj;>oj^RcP02oj^RcP05o`000?ne[=3o]Jc@okF/d?l000000onn]]42o`0000Cod]kQ00Co0000om_Z
g_oKj]ko00000_oQlmX00ol0003ohoWCon?id`03o`00033ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`03ooooo`00>Oooool00ol0003oooooooooo`14ooooo`03o`000?nc_^;o/kkR
00So/kkR0_l00006ok2ih0;o00001On]]=h2o`000004ojZ_g?l0003oO[3dogj`m0KoNZW`00?o0000
ogNQk?mgXN`00omgXN`01?l0003oM9[XogBJj?mdV^P2o`0000;oLY;S00So0000og2<g_m`S=ko0000
ofj6fOl0003o<W[To`0000;o?GOP00Oo0000odIdfom6M=_oAWCKo`000?m>LMKo000000;oE6k@00Go
0000oeU/c?l0003oBfkCo`000003oeA/cP06o`000?mJJLSoFVW8o`000?mLKlgo00000omPK<L00ol0
003oIg79ofMab@03o`0000;oKW340ol00006ogUjb0;o00001On6PlT00ol0003oShg=ohn=c@02ohn=
c@;oVISB0_l000000onHT<Wo0000oj6Ic003oj6Ic003o`000?n[X/koZj;>00;oZj;>00Co0000okF/
d?ne[=3o]Jc@1?l000000oo7d>7o0000om;Nh@02om;Nh@04o`000?oKj]kofn[No`0000?ohO?J00?o
0000on?idooSnM<00_l0000booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool003[ooooo00?o0000ooooooooool0AOooool00ol0003o/kkRok>nhP08ok>nhP?o00001On`^N00
0ol0003o[KCNojfdgP04ojfdgP03o`000?mn/?CoO[3d00?oO[3d00?o0000ogZYl?mjZO000omjZO00
0ol0003oMj7/ogNQk002ogNQk0;o00000omdV^P01?l0003oLY;Sog:Bhol00002og2<gP;o00000_lb
N^@00ol0003o?GOPocegh002o`0000;oAWCK00?o0000odiae_l000000_mDK]02o`0000;oBfkC00Oo
0000oeA/c_mDK<koE6c>o`000?mJJLSo000000;oG6o=0_l00002of1/a`03o`000?mWLLWoIg7900;o
Ig790_l00002og1gbP03o`000?miN/SoNG[800GoNG[80_l00003ohJ3b@03o`000?n?SLgoShg=00?o
Shg=1OnIV=89o`000003oj^Rc_l0003o]Jc@00?o00001?o7d>401Ol0003od]kQom;NhOoBg^7o0000
00;ofn[N00Ko0000on7cf_oQlm[ohO?Jo`000?oSnM<2o`0003Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`00>oooool2o`0004Sooooo0_l00009ok>nhP;o00001?n`^N02
o`0000Co[KCN00?o0000oh:hmomn/?@01Omn/?@2o`0000CoNZW`0_l00003ogNQk004o`000?mdV^So
M9[XogBJj0;o000000KoLY;So`000?m`S=ko0000obImiol00002oc9ji0;o00000_lmMn001_l0003o
AWCKodIdfol0003oCW7Fo`0000;oE6k@0_l00002od]^d`07o`000?mDK<koE6c>oeA/c_l0003oFVW8
o`000003oea_c@?o00001?mWLLT00ol0003oL7O:og1gbP02og1gbP03o`000?miN/SoNG[800?oNG[8
00Co0000ogn3c_moPlko00000_n6PlT00ol0003oShg=ohn=c@02ohn=c@03o`000?nIV=;oVISB00?o
VISB00?o0000ojBUe_nTYMH00_nTYMH01?l0003o[k;Kojnbfon_/]/3o`0000;o^l7N00Go0000olO@
hOo7d>7oam3Qo`000004om;Nh@04o`000?oKj]kofn[No`0000;ohO?J00Co0000on?idol0003o0000
=Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000mooooo`03o`000?oo
oooooooo04Oooooo0ol00008ok>nhP;o00001?n`^N02o`000003ojfdg_l0003oP[Sg00CoP[Sg1Omn
/?@2o`0000CoNZW`0_l00002ogNQk0;o00000omdV^P01?l0003oLY;So`000?l00002obImi`;o0000
0_lbN^@01?l0003o?GOPocegh?l00002odIdf`07o`000?m>LMKo0000oeA^d?l0003o?g3Jo`000002
od]^d`;o00000_mDK<h2o`0000GoG6o=00?o0000ofMabOmWLLT00omWLLT00ol0003oL7O:og1gbP02
og1gbP05o`000?miN/SoNG[8ogUjb?l000001?moPlh00ol0003oQX?9o`000004ohn=c@03o`000?nI
V=;oVISB00?oVISB00?o0000ojBUe_nTYMH00_nTYMH00ol0003o[k;Kojnbf`02ojnbf`05o`000?nk
`Mko^l7Nok_1g_l000000oo7d>401Ol0003od]kQom;NhOoBg^7o000000?ofn[N00?o0000on7cf_oQ
lmX00ol0000gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003kooooo
00?o0000ooooooooool0BOooool2o`0000So/kkR0_l00004ok2ih003o`000?n2^?OoP[Sg00KoP[Sg
00?o0000ogj`m?mn/?@00_mn/?@3o`0000?oNZW`0_l00002ogNQk0;o00000_mdV^P2o`000003oaV0
iol0003o000000;o9WgW00Co0000oc9ji?lbN^Co00000_lmMn001Ol0003oAWCKodIdfol0003oCW7F
00;o00000_loL=X01Ol0003oBfkCod]^dom;K]?o000000;oE6c>0_l00005oea_c@;o00000omWLLT0
0ol0003oL7O:og1gbP03og1gbP03o`000?miN/So000000KoOh?>0_l00004ohn=c@03o`000?nIV=;o
VISB00;oVISB00?o0000ojBUe_nTYMH00_nTYMH00ol0003o[k;Kojnbf`03ojnbf`04o`000?nk`Mko
^l7No`0000Coam3Q00Go0000om;NhOoBg^7od]kQo`000002om_ZgP04o`000?oQlm[ohO?Jon7cfP;o
0000>Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`00
0?oooooooooo04[ooooo0_l00008ok>nhP;o000000Go/;WPo`000?n7__WoQkkio`000008oh:hm`;o
00001?mn/?@2o`0000?oNZW`0_l00002ogNQk004o`000?mdV^So0000o`f2i0;o000000Co6H3Wo`00
0?l0003o9WgW0_l000001?lbN^Co0000o`000?lmMn02o`000003odIdfol0003oCW7F00;o00000_lo
L=X2o`0000;oBfkC00Co0000oeA/c_l0003oEG?D0_l00003oea_c@03o`000?mUN=7o000000;o0000
00?oIg79o`000?m`MlX00om`MlX2o`0000SoOh?>0_l00003ohn=c@03o`000?nIV=;oVISB00;oVISB
00?o0000ojBUe_nTYMH00_nTYMH00ol0003o[k;Kojnbf`02ojnbf`05o`000?nk`Mko^l7Nok_1g_l0
00000oo7d>400ol0003od]kQom;Nh@02om;Nh@05o`000?oKj]kofn[No`000?oQlmX00ol0000koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0043ooooo0_l0001<ooooo`?o
00001onc_^800ol0003oQkkiohNnn@04ohNnn@;o00001on2^?L2o`0000?oO[3d0_l00003ogZYl0;o
000000?oMj7/o`000?l000000ol=P^@2o`000004oaV0iol0003o9WgWobImi`;o000000Ko<W[To`00
0?lmMn3o?GOPo`000?m6M=/2o`000003obmagol0003o?g3J00;o?g3J00?o0000od]^dom;K]<00_l0
0003oeEce0;o00000_mLKld01?l0003oIGSAofEhdOmUN=42o`000006og1gb_l0003o0000o`000?mc
Om7o00001omoPlh01?l0003oQhoDohN?e?l00002ohn=c@03o`000?nIV=;oVISB00;oVISB00?o0000
ojBUe_nTYMH00_nTYMH00ol0003o[k;Kojnbf`02ojnbf`05o`000?nk`Mko^l7Nok_1g_l000000oo7
d>401Ol0003od]kQom;NhOoBg^7o000000?ofn[N1?l0000looooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool004;ooooo00?o0000ooooooooool0C?ooool2o`0000Go/kkR00?o
0000ohc5n_n<aOX01on7__T3o`0000GoP[Sg0_l00003ogj`m0;o00000omjZO02o`000003o`>3g_l0
003o000000?o3H;T1?l00002obImi`03o`000?lbN^Co000000;o?GOP00Go0000odIdfol0003o0000
obmag`02o`0000;o?g3J00?o0000od]^dom;K]<00_l00004oeEce003o`000?mLKlgo000000GoIGSA
00?o0000og=odOmcOm400omcOm400ol0003oOh?>ogn3cP03ogn3cP03o`000?n7SmCoQhoD00;oQhoD
0_l00005oiVHdP05o`000?nTYMKoY:GFojBUe_l000001On_/]/01Ol0003o^l7Nok_1g_nk`Mko0000
00?oam3Q00Go0000om;NhOoBg^7od]kQo`000002om_ZgPCo0000?_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo04gooooo0ol000000onc
_^;o0000ohc5nP05ohc5nP03o`000?n7__WoQkki00CoQkki0_l00005oh:hm`?o00000_mn/?@2o`00
0003ogZYl?l0003o08GG00Go00000ol=P^@4o`000003obImiol0003o000000;o000000Go?GOPo`00
0?l0003o677Qo`000002obmag`03o`000?loL=[o?g3J00;o000000?oBfkCo`000?l000001?mELm@2
o`0000GoIGSA00?o0000og=odOmcOm401?mcOm401Ol0003oOh?>ogn3c_moPlko000000KoQhoD0_l0
0004oiVHdP05o`000?nTYMKoY:GFojBUe_l000001?n_/]/01Ol0003o^l7Nok_1g_nk`Mko000000?o
am3Q00?o0000om;NhOoBg^400_oBg^400ol0003ofn[No`000003o`00043ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`1?ooooo`03o`00
0?n<aO[oS<Gj00SoS<Gj0_l00004ohNnn@?o00001On2^?L2o`000003ogj`m?l0003o000000;o0000
0ol0QML4o`0000?o3H;T00Wo0000oaV0iol0003o0000obImiol0003o<W[To`000?lmMn000_l00000
1?lHLN7o0000o`000?l_LMl2o`0000;o?g3J0_l000000om;N=go0000o`000004oeEce0?o00000omU
N=400ol0003oLgoAog=od@04og=od@03o`000?moPlko000000OoQhoD00Ko0000oi2Mg?l0003o0000
oiVHd_l00004ojBUeP03o`000?n_/]_o[k;K00;o[k;K00Go0000ok_1g_nk`Mko^l7No`000003olO@
h@04o`000?oBg^7od]kQom;Nh@?o000000?o^?cIo`000?l00000@_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000D_ooool00ol0003oS<Gjohc5nP09ohc5
nP;o00000on7__T3o`0000CoP[Sg00?o0000o`28d_l0R=800_l0R=83o`0000;o08GG1Ol000001?l=
P^Co0000o`000?lIP>L6o`000005o`1/f_l0003o0000oaQahOl000000_l_LMl00ol0003o?g3Jocm`
fP02o`0000;oBgSM00Go0000oeEce?mELmCoEG?Do`000002of>0fPGo00000omcOm44o`0000OoQhoD
00?o0000oi2Mg?n@WM`00_n@WM`2o`0000CoY:GF00?o0000ojnbfon_/]/00_n_/]/01Ol0003o^l7N
ok_1g_nk`Mko000000?oam3Q00?o0000om;NhOoBg^400_l00002okSlf@;o0000@oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0017ooooo`03o`000?oooooooooo05Cooooo
0_l00008ohc5nP?o00000_n7__T3o`000004oh:hmol0003o08k?o`2>c`Go08SB0ol00002o`25e`Co
000000Ko3H;To`000?l0003o6H3Wo`000?lVONL3o`0000;o06cJ00Ko0000oaQahOl0003o0000obma
gol00002ocm`fP;o00000_m;N=d2o`0000;oEG?D00?o0000of>0f_mSP=X00omSP=X4o`0000CoMh_J
00?o0000ohN?e?n7Sm@00on7Sm@00ol0003oT9gLoi2Mg004oi2Mg0?o000000?oY:GFo`000?n_/]/0
1?n_/]/01Ol0003o^l7Nok_1g_nk`Mko000000;oam3Q1Ol00002okSlf@;o0000AOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo05Sooooo
1?l00004ohc5nP?o00000_n7__T00ol0003o08k?o`2>c`05o`2>c`Co08SB0ol000000ol0QMOo0000
o`000002o`000003o`f2i?l0003o000000Ko000000Co06cJo`000?l0003o677Q1Ol000000ollONGo
0000o`000002od]hg@?o00001_mSP=X00ol0003oMh_JogN;fP05ogN;fP05o`000?n7SmCoQhoDohN?
e?l000001_n@WM`01?l0003oVZkUoiZ^iOnJ[^D5o`000003ojnbfol0003o^l7N00;o^l7N00?o0000
olO@hOl000000_l00002okgik003o`000?nho=Wo^?cI00;o0000Aoooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo007ooooo0019ooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool00_ooool5o`000003ohc5n_l0003o000000Co29O@2?l0S/l3o`28dP?o000000Go08GGo`00
0?l0003o0000o`f2i003o`000003o`1BZOl0003o000000;o000000Ko06cJo`000?l0003o677Qo`00
0?l_LMl2o`0000;o?7gU0_l00002od]hg@03o`000?mSP=[oHh3J00GoHh3J00?o0000ogN;f_mgRmX0
1OmgRmX00ol0003oQhoDo`000006oi2Mg003o`000?nJ[^GoVZkU00?oVZkU00Co0000ojK2kOnV`^go
Y/;]1ol00002ok[[m003o`000?nmnNco000000;o^?cI00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000Eoooool00ol0003ooooo
ooooo`07ooooo`;o00001OlFX]D6o`RGd0Go08k?0ol0R=86o`000003o`f2i?l0003oE`0000;o05:Y
1?l000000ol0K=[o0000oaQah@04o`0000?o?7gU00?o0000od]hgOm;N=d00ol00005of>0fP03o`00
0?mgRm[oMh_J00?oMh_J1?l00005oi2Mg003o`000?nJ[^GoVZkU00?oVZkU00?o0000ojK2kOnV`^d0
0_nV`^d00ol0003o/MOcok7Gl`02ok7Gl`06o`000?njjoCo^^_do`000?nmnNco00000_nho=T00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004co
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`?o00001olFX]D3o`RGd0?o
08k?0_l0R=84o`000006of@00?mG003oE`00oeL00?l0003o05:Y1_l000000olHLN7o0000obB1j002
o`0000;o?7gU0ol00002oej:i0Ko00000_mgRmX3o`0000CoNiWU00Go0000oi2Mg?n@WMcoT9gLo`00
0005oiZ^i@03o`000?nV`^goY/;]00;oY/;]00?o0000ok7Glonaeo<00_naeo<01_l0003o^^_dok[[
m?l0003o_OW/o`0000;o^?cI00?o0000ooooooooool0Boooool00ol0003oooooooooo`08ooooo`7o
00000Oooool1ooooo`00COooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Kooooo
1ol00002oaJRe@09o`RGd?l0S/oo08SBo`000?m[003o0000of@00?mG003o000000;oE`0000?o05:Y
o`000?l000001_l000000olTPNSo0000o`000002ocami@;o00001_mNR^@3o`0000SoNiWU00?o0000
oi2Mg?l000001OnJ[^D00ol0003oY/;]ojK2k@02ojK2k@03o`000?naeo?o/MOc00;o/MOc00Ko0000
ok[[m?njjoCo0000okgik?l00002okSlf@03o`000?oooooooooo04gooooo00?o0000ooooooooool0
1oooool1o`00007ooooo0Oooool004kooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0Oooooo`Co00000om>00000om/003o0000of@00003oeL00003o`000?l0DZWo000000?o000000Co
0WcNo`000?l0003o987X0_l00002ocami@Co00001?mNR^@00ol0003oNiWUog^Ii@05og^Ii@Co0000
1?nJ[^D00ol0003oY/;]ojK2k@02ojK2k@03o`000?naeo?o/MOc00;o/MOc00Ko0000ok[[m?njjoCo
0000okgik?l00002okSlf@03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool1o`00
007ooooo0Oooool004oooooo0_l0001Booooo`03o`000?oooooooooo02_ooooo00GoI000oeL00?mG
003o0000o`1BZ@04o`000004o`9lg_l0003o0000obB1j0?o00000omEUo06o`0000;oNiWU1?l00004
ogj/l@;o000000?oVZkUo`000?nV`^d00onV`^d00ol0003o/MOcok7Gl`02ok7Gl`04o`000?njjoCo
^^_dok[[m0Go0000D_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo02kooooo00CoI000oeL00?l0003o05:Y2_l0
0007oeFGl0?o00002Omn[?44o`0000;oY/;]00?o0000ok7Glonaeo<00_naeo<01?l0003o^^_dok[[
m?njjo@4o`0005Gooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool005;ooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0aooooo`06of@00?mG003o0000o`000?m7003o
06bm2Ol00005oeFGl003o`000?mn[?7oOZca00CoOZca0ol00003oh31o0Go00000_naeo<01?l0003o
^^_dok[[m?njjo@2o`0005Wooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005?o
oooo0_l0001>ooooo`03o`000?oooooooooo03Gooooo00Go0000odL00?m7003oA`00o`1/_@04o`00
00;oAJ?g1Ol000001?mEUo3o0000ogj/lOmn[?43o`0000?oP<7l0ol00004ogcEo`Oo0000Foooool0
0ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00EOooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo03Wooooo0om700000ol0K;go0000o`00000;o`0000;oP<7l0ol00003ogcE
o`Co00000_m]g>`3o`0005kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001Fooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool0??ooool01?m7003o0000odL00?l0K;d=o`00
00;oO=Go0ol00003ofgLk0?o0000H_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool005Oo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`11ooooo`03odL00?l0003o000000co
00000_m]g>`3o`0006Kooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Hooooo`;o0000
BOooool00ol0003oooooooooo`1:ooooo`So0000JOooool00ol0003oooooooooo`02ooooo`7o0000
0Oooool005[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2looooo`05o`000?oo
ooooooooooooool000000Oooool005_ooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`2mooooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool0__ooool00ol0003oooooo`000001ooooo`00GOooool2o`0004Cooooo00?o0000
ooooooooool0__ooool00ol0003oooooooooo`01o`000000Goooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo0;oooooo0Ol00001ooooo`7o0000001Pooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool0`?ooool2o`000000HOooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo0;oooooo0ol0000006;ooooo0_l0000oooooo`03o`000?oooooooooo0;_ooooo1?l0
0003ooooo`00I?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0;Oooooo1?l00007
ooooo`00IOooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0;?ooooo1?l0000;oooo
o`00I_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0;3ooooo0ol0000?ooooo`00
Ioooool2o`0003[ooooo00?o0000ooooooooool0[?ooool4o`0001;ooooo001Yooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0Z?ooool4o`0001Kooooo001Zooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0Y?ooool4o`0001[ooooo001[ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0XOooool4o`0001kooooo001/ooooo`;o0000=?ooool00ol0003o
ooooooooo`2Mooooo`Co00008_ooool006kooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`2Iooooo`Co00009_ooool006oooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`2Eooooo`Co0000:_ooool0073ooooo0_l0000`ooooo`03o`000?oooooooooo097ooooo1?l0000^
ooooo`00L_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08kooooo0ol0000boooo
o`00Loooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08[ooooo1?l0000eooooo`00
M?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000iooooo`00MOoo
ool2o`0002_ooooo00?o0000ooooooooool0P_ooool4o`0003gooooo001gooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0O_ooool4o`00047ooooo001hooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0N_ooool4o`0004Gooooo001iooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0M_ooool4o`0004Wooooo001jooooo`;o00009_ooool00ol0003ooooo
ooooo`1booooo`Co0000COooool007cooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`1_ooooo`?o0000DOooool007gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[
ooooo`Co0000E?ooool007kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Woooo
o`Co0000F?ooool007oooooo0_l0000Qooooo`03o`000?oooooooooo06?ooooo1?l0001Looooo`00
POooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05oooooo1?l0001Pooooo`00P_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05_ooooo1?l0001Tooooo`00Poooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oooooo1?l0001Xooooo`00Q?ooool2o`00
01cooooo00?o0000ooooooooool0Doooool4o`0006cooooo0026ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0Coooool4o`00073ooooo0027ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0C?ooool3o`0007Cooooo0028ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0B?ooool4o`0007Oooooo0029ooooo`;o00005oooool00ol0003oooooooooo`14
ooooo`Co0000Noooool008_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10oooo
o`Co0000Ooooool008cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`Co
0000Poooool008gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`Co0000
Qoooool008kooooo0_l0000Booooo`03o`000?oooooooooo03Cooooo1?l0002;ooooo`00T?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo1?l0002?ooooo`00TOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo0ol0002Cooooo`00T_ooool2o`0000go
oooo00?o0000ooooooooool0:_ooool4o`0009Kooooo002Dooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool09_ooool4o`0009[ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool4o`0009kooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07_ooool4o`000:;ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Joooo
o`Co0000Y_ooool009Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co
0000Z_ooool009[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000
[_ooool009_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_oo
ool009cooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol0002fooooo`00W_ooool01?l0
003oooooooooool00009ooooo`Co0000^Oooool009oooooo00?o0000ooooool000001Oooool4o`00
0;gooooo002Pooooo`;o000000?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51722 .66131 m .51694 .65827 L .43899 .65168 L p .454 0 0 r
F P
0 g
s
.51694 .65827 m .51722 .66131 L .59287 .65961 L p .488 .013 .054 r
F P
0 g
s
.59287 .65961 m .59527 .65394 L .51694 .65827 L p .488 .013 .054 r
F P
0 g
s
.59527 .65394 m .59287 .65961 L .66528 .6467 L p .413 0 .113 r
F P
0 g
s
.66528 .6467 m .67023 .63881 L .59527 .65394 L p .413 0 .113 r
F P
0 g
s
.44208 .65182 m .43899 .65168 L .36521 .63435 L p 0 .514 .781 r
F P
0 g
s
.43899 .65168 m .44208 .65182 L .51722 .66131 L p .454 0 0 r
F P
0 g
s
.51751 .66458 m .51722 .66131 L .44208 .65182 L p .487 0 0 r
F P
0 g
s
.51722 .66131 m .51751 .66458 L .59043 .66561 L p .511 .041 .076 r
F P
0 g
s
.59043 .66561 m .59287 .65961 L .51722 .66131 L p .511 .041 .076 r
F P
0 g
s
.36521 .63435 m .37117 .63152 L .44208 .65182 L p 0 .514 .781 r
F P
0 g
s
.44521 .6521 m .44208 .65182 L .37117 .63152 L p 0 .482 .775 r
F P
0 g
s
.44208 .65182 m .44521 .6521 L .51751 .66458 L p .487 0 0 r
F P
0 g
s
.59287 .65961 m .59043 .66561 L .66027 .655 L p .432 .009 .134 r
F P
0 g
s
.66027 .655 m .66528 .6467 L .59287 .65961 L p .432 .009 .134 r
F P
0 g
s
.67023 .63881 m .66528 .6467 L .73066 .62292 L p .258 0 .06 r
F P
0 g
s
.73066 .62292 m .73799 .61332 L .67023 .63881 L p .258 0 .06 r
F P
0 g
s
.5178 .66789 m .51751 .66458 L .44521 .6521 L p .507 0 0 r
F P
0 g
s
.51751 .66458 m .5178 .66789 L .58796 .6717 L p .526 .056 .081 r
F P
0 g
s
.58796 .6717 m .59043 .66561 L .51751 .66458 L p .526 .056 .081 r
F P
0 g
s
.37117 .63152 m .36521 .63435 L .29943 .6068 L p .485 .737 .983 r
F P
0 g
s
.37117 .63152 m .37718 .62872 L .44521 .6521 L p 0 .482 .775 r
F P
0 g
s
.44837 .65237 m .44521 .6521 L .37718 .62872 L p 0 .467 .789 r
F P
0 g
s
.44521 .6521 m .44837 .65237 L .5178 .66789 L p .507 0 0 r
F P
0 g
s
.59043 .66561 m .58796 .6717 L .65517 .66343 L p .443 .02 .139 r
F P
0 g
s
.65517 .66343 m .66027 .655 L .59043 .66561 L p .443 .02 .139 r
F P
0 g
s
.29943 .6068 m .30823 .60113 L .37117 .63152 L p .485 .737 .983 r
F P
0 g
s
.37718 .62872 m .37117 .63152 L .30823 .60113 L p .475 .713 .974 r
F P
0 g
s
.66528 .6467 m .66027 .655 L .72324 .63297 L p .274 0 .08 r
F P
0 g
s
.72324 .63297 m .73066 .62292 L .66528 .6467 L p .274 0 .08 r
F P
0 g
s
.5181 .67103 m .5178 .66789 L .44837 .65237 L p .514 0 0 r
F P
0 g
s
.5178 .66789 m .5181 .67103 L .58544 .67761 L p .536 .059 .07 r
F P
0 g
s
.58544 .67761 m .58796 .6717 L .5178 .66789 L p .536 .059 .07 r
F P
0 g
s
.37718 .62872 m .38325 .6259 L .44837 .65237 L p 0 .467 .789 r
F P
0 g
s
.45157 .65249 m .44837 .65237 L .38325 .6259 L p 0 .465 .817 r
F P
0 g
s
.44837 .65237 m .45157 .65249 L .5181 .67103 L p .514 0 0 r
F P
0 g
s
.30823 .60113 m .31708 .59541 L .37718 .62872 L p .475 .713 .974 r
F P
0 g
s
.38325 .6259 m .37718 .62872 L .31708 .59541 L p .47 .688 .961 r
F P
0 g
s
.58796 .6717 m .58544 .67761 L .64998 .67167 L p .449 .02 .131 r
F P
0 g
s
.64998 .67167 m .65517 .66343 L .58796 .6717 L p .449 .02 .131 r
F P
0 g
s
.66027 .655 m .65517 .66343 L .7157 .64316 L p .281 0 .084 r
F P
0 g
s
.7157 .64316 m .72324 .63297 L .66027 .655 L p .281 0 .084 r
F P
0 g
s
.73799 .61332 m .73066 .62292 L .78515 .58903 L p 0 0 0 r
F P
0 g
s
.78515 .58903 m .79464 .57831 L .73799 .61332 L p 0 0 0 r
F P
0 g
s
.38325 .6259 m .38938 .62298 L .45157 .65249 L p 0 .465 .817 r
F P
0 g
s
.45482 .65233 m .45157 .65249 L .38938 .62298 L p 0 .473 .852 r
F P
0 g
s
.5184 .67378 m .5181 .67103 L .45157 .65249 L p .506 0 0 r
F P
0 g
s
.45157 .65249 m .45482 .65233 L .5184 .67378 L p .506 0 0 r
F P
0 g
s
.5181 .67103 m .5184 .67378 L .58287 .68305 L p .54 .049 .041 r
F P
0 g
s
.58287 .68305 m .58544 .67761 L .5181 .67103 L p .54 .049 .041 r
F P
0 g
s
.31708 .59541 m .32598 .58967 L .38325 .6259 L p .47 .688 .961 r
F P
0 g
s
.38938 .62298 m .38325 .6259 L .32598 .58967 L p .469 .662 .946 r
F P
0 g
s
.30823 .60113 m .29943 .6068 L .24558 .56996 L p .682 .754 .906 r
F P
0 g
s
.32598 .58967 m .33492 .58391 L .38938 .62298 L p .469 .662 .946 r
F P
0 g
s
.39557 .6199 m .38938 .62298 L .33492 .58391 L p .47 .637 .928 r
F P
0 g
s
.38938 .62298 m .39557 .6199 L .45482 .65233 L p 0 .473 .852 r
F P
0 g
s
.58544 .67761 m .58287 .68305 L .64468 .67941 L p .449 .009 .108 r
F P
0 g
s
.64468 .67941 m .64998 .67167 L .58544 .67761 L p .449 .009 .108 r
F P
0 g
s
.45812 .65171 m .45482 .65233 L .39557 .6199 L p .039 .485 .884 r
F P
0 g
s
.51871 .67591 m .5184 .67378 L .45482 .65233 L p .477 0 0 r
F P
0 g
s
.45482 .65233 m .45812 .65171 L .51871 .67591 L p .477 0 0 r
F P
0 g
s
.24558 .56996 m .25702 .56182 L .30823 .60113 L p .682 .754 .906 r
F P
0 g
s
.31708 .59541 m .30823 .60113 L .25702 .56182 L p .676 .735 .895 r
F P
0 g
s
.73066 .62292 m .72324 .63297 L .77554 .6002 L p 0 0 0 r
F P
0 g
s
.77554 .6002 m .78515 .58903 L .73066 .62292 L p 0 0 0 r
F P
0 g
s
.5184 .67378 m .51871 .67591 L .58025 .68775 L p .536 .025 0 r
F P
0 g
s
.58025 .68775 m .58287 .68305 L .5184 .67378 L p .536 .025 0 r
F P
0 g
s
.65517 .66343 m .64998 .67167 L .70803 .65317 L p .279 0 .072 r
F P
0 g
s
.70803 .65317 m .7157 .64316 L .65517 .66343 L p .279 0 .072 r
F P
0 g
s
.25702 .56182 m .26849 .55358 L .31708 .59541 L p .676 .735 .895 r
F P
0 g
s
.32598 .58967 m .31708 .59541 L .26849 .55358 L p .669 .714 .882 r
F P
0 g
s
.33492 .58391 m .34392 .57815 L .39557 .6199 L p .47 .637 .928 r
F P
0 g
s
.40182 .61658 m .39557 .6199 L .34392 .57815 L p .473 .612 .908 r
F P
0 g
s
.39557 .6199 m .40182 .61658 L .45812 .65171 L p .039 .485 .884 r
F P
0 g
s
.46147 .65052 m .45812 .65171 L .40182 .61658 L p .113 .495 .903 r
F P
0 g
s
.51903 .6772 m .51871 .67591 L .45812 .65171 L p .417 0 0 r
F P
0 g
s
.45812 .65171 m .46147 .65052 L .51903 .6772 L p .417 0 0 r
F P
0 g
s
.26849 .55358 m .27998 .54533 L .32598 .58967 L p .669 .714 .882 r
F P
0 g
s
.33492 .58391 m .32598 .58967 L .27998 .54533 L p .661 .693 .869 r
F P
0 g
s
.58287 .68305 m .58025 .68775 L .63926 .68632 L p .442 0 .067 r
F P
0 g
s
.63926 .68632 m .64468 .67941 L .58287 .68305 L p .442 0 .067 r
F P
0 g
s
.34392 .57815 m .35297 .5724 L .40182 .61658 L p .473 .612 .908 r
F P
0 g
s
.40814 .61298 m .40182 .61658 L .35297 .5724 L p .478 .59 .887 r
F P
0 g
s
.40182 .61658 m .40814 .61298 L .46147 .65052 L p .113 .495 .903 r
F P
0 g
s
.51871 .67591 m .51903 .6772 L .57757 .69142 L p .52 0 0 r
F P
0 g
s
.57757 .69142 m .58025 .68775 L .51871 .67591 L p .52 0 0 r
F P
0 g
s
.72324 .63297 m .7157 .64316 L .76581 .61151 L p 0 0 0 r
F P
0 g
s
.76581 .61151 m .77554 .6002 L .72324 .63297 L p 0 0 0 r
F P
0 g
s
.27998 .54533 m .29147 .53717 L .33492 .58391 L p .661 .693 .869 r
F P
0 g
s
.34392 .57815 m .33492 .58391 L .29147 .53717 L p .652 .672 .856 r
F P
0 g
s
.64998 .67167 m .64468 .67941 L .7002 .66266 L p .268 0 .043 r
F P
0 g
s
.7002 .66266 m .70803 .65317 L .64998 .67167 L p .268 0 .043 r
F P
0 g
s
.29147 .53717 m .30297 .52919 L .34392 .57815 L p .652 .672 .856 r
F P
0 g
s
.35297 .5724 m .34392 .57815 L .30297 .52919 L p .642 .65 .843 r
F P
0 g
s
.46487 .6486 m .46147 .65052 L .40814 .61298 L p .187 .5 .907 r
F P
0 g
s
.51935 .67746 m .51903 .6772 L .46147 .65052 L p .313 0 0 r
F P
0 g
s
.46147 .65052 m .46487 .6486 L .51935 .67746 L p .313 0 0 r
F P
0 g
s
.35297 .5724 m .36206 .56669 L .40814 .61298 L p .478 .59 .887 r
F P
0 g
s
.41453 .60902 m .40814 .61298 L .36206 .56669 L p .483 .569 .866 r
F P
0 g
s
.40814 .61298 m .41453 .60902 L .46487 .6486 L p .187 .5 .907 r
F P
0 g
s
.30297 .52919 m .31447 .5215 L .35297 .5724 L p .642 .65 .843 r
F P
0 g
s
.36206 .56669 m .35297 .5724 L .31447 .5215 L p .632 .629 .829 r
F P
0 g
s
.58025 .68775 m .57757 .69142 L .63372 .69208 L p .426 0 0 r
F P
0 g
s
.63372 .69208 m .63926 .68632 L .58025 .68775 L p .426 0 0 r
F P
0 g
s
.82489 .54637 m .83625 .53514 L .79464 .57831 L p .535 .842 .529 r
F P
0 g
s
.77554 .6002 m .76581 .61151 L .77328 .60285 L p .576 .865 .548 r
F P
0 g
s
.79464 .57831 m .78555 .58857 L p .82489 .54637 L .535 .842 .529 r
F P
0 g
s
.7853 .58886 m .82489 .54637 L p .78555 .58857 L .535 .842 .529 r
F P
0 g
s
.81343 .558 m .82489 .54637 L .7853 .58886 L p .547 .846 .527 r
F P
0 g
s
.78555 .58857 m .78515 .58903 L .7853 .58886 L p .535 .842 .529 r
F P
0 g
s
.7853 .58886 m .78515 .58903 L p .78536 .58879 L .547 .846 .527 r
F P
0 g
s
.81343 .558 m .7853 .58886 L .78536 .58879 L .547 .846 .527 r
F
.77554 .6002 m .81343 .558 L p .78536 .58879 L F P
0 g
s
.78515 .58903 m .77554 .6002 L p .78536 .58879 L .547 .846 .527 r
F P
0 g
s
.80185 .56975 m .81343 .558 L .77554 .6002 L p .576 .865 .548 r
F P
0 g
s
.77328 .60285 m .8017 .56992 L p .77863 .59663 L .576 .865 .548 r
F P
0 g
s
.8017 .56992 m .80185 .56975 L p .80164 .57 L .576 .865 .548 r
F P
0 g
s
.80164 .57 m .77863 .59663 L .8017 .56992 L .576 .865 .548 r
F
.77863 .59663 m .77554 .6002 L .77328 .60285 L F
.51903 .6772 m .51935 .67746 L .54199 .68414 L p .482 0 0 r
F P
0 g
s
.54133 .68384 m .51903 .6772 L .54199 .68414 L .482 0 0 r
F
.57483 .69382 m .57757 .69142 L .51903 .6772 L p F P
0 g
s
.57204 .69468 m .57483 .69382 L .51935 .67746 L p .4 0 0 r
F P
0 g
s
.51935 .67746 m .51967 .6765 L .53639 .6823 L p .4 0 0 r
F P
0 g
s
.53639 .6823 m .57204 .69468 L p .52841 .68043 L .4 0 0 r
F P
0 g
s
.52841 .68043 m .51935 .67746 L .53639 .6823 L .4 0 0 r
F
.56918 .6938 m .57204 .69468 L .5431 .68463 L p .247 0 0 r
F P
0 g
s
.54199 .68414 m .57483 .69382 L p .54133 .68384 L .482 0 0 r
F P
0 g
s
.56626 .69099 m .56918 .6938 L .54619 .68461 L p 0 .471 .847 r
F P
0 g
s
.54619 .68461 m .52001 .67413 L p .55339 .6863 L 0 .471 .847 r
F P
0 g
s
.56626 .69099 m .54619 .68461 L .55339 .6863 L 0 .471 .847 r
F
.5431 .68463 m .51967 .6765 L p .54365 .68488 L .247 0 0 r
F P
0 g
s
.56918 .6938 m .5431 .68463 L .54365 .68488 L .247 0 0 r
F
.7157 .64316 m .70803 .65317 L .75592 .62264 L p 0 0 0 r
F P
0 g
s
.75592 .62264 m .76581 .61151 L .7157 .64316 L p 0 0 0 r
F P
0 g
s
.36206 .56669 m .3712 .56103 L .41453 .60902 L p .483 .569 .866 r
F P
0 g
s
.42099 .60466 m .41453 .60902 L .3712 .56103 L p .488 .55 .846 r
F P
0 g
s
.41453 .60902 m .42099 .60466 L .46833 .64583 L p .255 .5 .897 r
F P
0 g
s
.46833 .64583 m .46487 .6486 L .41453 .60902 L p .255 .5 .897 r
F P
0 g
s
.31447 .5215 m .32596 .51418 L .36206 .56669 L p .632 .629 .829 r
F P
0 g
s
.3712 .56103 m .36206 .56669 L .32596 .51418 L p .622 .609 .816 r
F P
0 g
s
.46487 .6486 m .46833 .64583 L .51967 .6765 L p 0 .36 .769 r
F P
0 g
s
.51967 .6765 m .51935 .67746 L .46487 .6486 L p 0 .36 .769 r
F P
0 g
s
.64468 .67941 m .63926 .68632 L .6922 .67129 L p .245 0 0 r
F P
0 g
s
.6922 .67129 m .7002 .66266 L .64468 .67941 L p .245 0 0 r
F P
0 g
s
.25702 .56182 m .24558 .56996 L .20758 .52532 L p .777 .785 .86 r
F P
0 g
s
.32596 .51418 m .33746 .5073 L .3712 .56103 L p .622 .609 .816 r
F P
0 g
s
.3804 .55542 m .3712 .56103 L .33746 .5073 L p .612 .589 .804 r
F P
0 g
s
.3712 .56103 m .3804 .55542 L .42099 .60466 L p .488 .55 .846 r
F P
0 g
s
.20758 .52532 m .22124 .51532 L .25702 .56182 L p .777 .785 .86 r
F P
0 g
s
.26849 .55358 m .25702 .56182 L .22124 .51532 L p .773 .77 .85 r
F P
0 g
s
.42752 .59984 m .42099 .60466 L .3804 .55542 L p .493 .533 .826 r
F P
0 g
s
.42099 .60466 m .42752 .59984 L .47184 .64211 L p .312 .497 .878 r
F P
0 g
s
.47184 .64211 m .46833 .64583 L .42099 .60466 L p .312 .497 .878 r
F P
0 g
s
.22124 .51532 m .23488 .50517 L .26849 .55358 L p .773 .77 .85 r
F P
0 g
s
.27998 .54533 m .26849 .55358 L .23488 .50517 L p .767 .753 .84 r
F P
0 g
s
.57757 .69142 m .57483 .69382 L .62806 .6964 L p .391 0 0 r
F P
0 g
s
.62806 .6964 m .63372 .69208 L .57757 .69142 L p .391 0 0 r
F P
0 g
s
.23488 .50517 m .24848 .49506 L .27998 .54533 L p .767 .753 .84 r
F P
0 g
s
.29147 .53717 m .27998 .54533 L .24848 .49506 L p .759 .736 .831 r
F P
0 g
s
.46833 .64583 m .47184 .64211 L .52001 .67413 L p .005 .431 .862 r
F P
0 g
s
.52001 .67413 m .51967 .6765 L .46833 .64583 L p .005 .431 .862 r
F P
0 g
s
.24848 .49506 m .26202 .48516 L .29147 .53717 L p .759 .736 .831 r
F P
0 g
s
.30297 .52919 m .29147 .53717 L .26202 .48516 L p .749 .717 .822 r
F P
0 g
s
.33746 .5073 m .34895 .50095 L .3804 .55542 L p .612 .589 .804 r
F P
0 g
s
.38964 .54989 m .3804 .55542 L .34895 .50095 L p .602 .571 .792 r
F P
0 g
s
.3804 .55542 m .38964 .54989 L .42752 .59984 L p .493 .533 .826 r
F P
0 g
s
.26202 .48516 m .2755 .47564 L .30297 .52919 L p .749 .717 .822 r
F P
0 g
s
.31447 .5215 m .30297 .52919 L .2755 .47564 L p .737 .698 .813 r
F P
0 g
s
.70803 .65317 m .7002 .66266 L .74584 .63326 L p 0 0 0 r
F P
0 g
s
.74584 .63326 m .75592 .62264 L .70803 .65317 L p 0 0 0 r
F P
0 g
s
.2755 .47564 m .2889 .46666 L .31447 .5215 L p .737 .698 .813 r
F P
0 g
s
.32596 .51418 m .31447 .5215 L .2889 .46666 L p .724 .678 .805 r
F P
0 g
s
.63926 .68632 m .63372 .69208 L .68403 .67872 L p .204 0 0 r
F P
0 g
s
.68403 .67872 m .6922 .67129 L .63926 .68632 L p .204 0 0 r
F P
0 g
s
.43411 .59453 m .42752 .59984 L .38964 .54989 L p .498 .519 .808 r
F P
0 g
s
.42752 .59984 m .43411 .59453 L .4754 .63735 L p .359 .491 .856 r
F P
0 g
s
.4754 .63735 m .47184 .64211 L .42752 .59984 L p .359 .491 .856 r
F P
0 g
s
.2889 .46666 m .30223 .45837 L .32596 .51418 L p .724 .678 .805 r
F P
0 g
s
.33746 .5073 m .32596 .51418 L .30223 .45837 L p .709 .657 .796 r
F P
0 g
s
.34895 .50095 m .36044 .49519 L .38964 .54989 L p .602 .571 .792 r
F P
0 g
s
.39893 .54443 m .38964 .54989 L .36044 .49519 L p .592 .554 .78 r
F P
0 g
s
.38964 .54989 m .39893 .54443 L .43411 .59453 L p .498 .519 .808 r
F P
0 g
s
.30223 .45837 m .31548 .45091 L .33746 .5073 L p .709 .657 .796 r
F P
0 g
s
.34895 .50095 m .33746 .5073 L .31548 .45091 L p .694 .637 .788 r
F P
0 g
s
.51967 .6765 m .52001 .67413 L .56918 .6938 L p .247 0 0 r
F P
0 g
s
.47184 .64211 m .4754 .63735 L .52034 .67024 L p .154 .47 .893 r
F P
0 g
s
.52034 .67024 m .52001 .67413 L .47184 .64211 L p .154 .47 .893 r
F P
0 g
s
.31548 .45091 m .32866 .44441 L .34895 .50095 L p .694 .637 .788 r
F P
0 g
s
.36044 .49519 m .34895 .50095 L .32866 .44441 L p .678 .617 .78 r
F P
0 g
s
.57483 .69382 m .57204 .69468 L .62226 .69899 L p .323 0 0 r
F P
0 g
s
.62226 .69899 m .62806 .6964 L .57483 .69382 L p .323 0 0 r
F P
0 g
s
.36044 .49519 m .37194 .49006 L .39893 .54443 L p .592 .554 .78 r
F P
0 g
s
.40828 .53906 m .39893 .54443 L .37194 .49006 L p .583 .538 .77 r
F P
0 g
s
.39893 .54443 m .40828 .53906 L .44078 .58869 L p .503 .506 .792 r
F P
0 g
s
.44078 .58869 m .43411 .59453 L .39893 .54443 L p .503 .506 .792 r
F P
0 g
s
.43411 .59453 m .44078 .58869 L .479 .63147 L p .397 .484 .832 r
F P
0 g
s
.479 .63147 m .4754 .63735 L .43411 .59453 L p .397 .484 .832 r
F P
0 g
s
.32866 .44441 m .34176 .43895 L .36044 .49519 L p .678 .617 .78 r
F P
0 g
s
.37194 .49006 m .36044 .49519 L .34176 .43895 L p .662 .597 .772 r
F P
0 g
s
.34176 .43895 m .35481 .43464 L .37194 .49006 L p .662 .597 .772 r
F P
0 g
s
.38344 .4856 m .37194 .49006 L .35481 .43464 L p .646 .577 .764 r
F P
0 g
s
.37194 .49006 m .38344 .4856 L .40828 .53906 L p .583 .538 .77 r
F P
0 g
s
.7002 .66266 m .6922 .67129 L .73557 .64303 L p 0 0 0 r
F P
0 g
s
.73557 .64303 m .74584 .63326 L .7002 .66266 L p 0 0 0 r
F P
0 g
s
.41768 .53378 m .40828 .53906 L .38344 .4856 L p .575 .523 .76 r
F P
0 g
s
.40828 .53906 m .41768 .53378 L .4475 .5823 L p .507 .495 .778 r
F P
0 g
s
.4475 .5823 m .44078 .58869 L .40828 .53906 L p .507 .495 .778 r
F P
0 g
s
.63372 .69208 m .62806 .6964 L .67567 .68462 L p .135 0 0 r
F P
0 g
s
.67567 .68462 m .68403 .67872 L .63372 .69208 L p .135 0 0 r
F P
0 g
s
.4754 .63735 m .479 .63147 L .52069 .6647 L p .265 .484 .883 r
F P
0 g
s
.52069 .6647 m .52034 .67024 L .4754 .63735 L p .265 .484 .883 r
F P
0 g
s
.35481 .43464 m .3678 .43153 L .38344 .4856 L p .646 .577 .764 r
F P
0 g
s
.39497 .48185 m .38344 .4856 L .3678 .43153 L p .629 .559 .756 r
F P
0 g
s
.38344 .4856 m .39497 .48185 L .41768 .53378 L p .575 .523 .76 r
F P
0 g
s
.52001 .67413 m .52034 .67024 L .56626 .69099 L p 0 .471 .847 r
F P
0 g
s
.44078 .58869 m .4475 .5823 L .48266 .62442 L p .427 .478 .81 r
F P
0 g
s
.48266 .62442 m .479 .63147 L .44078 .58869 L p .427 .478 .81 r
F P
0 g
s
.76581 .61151 m .75592 .62264 L .79011 .58132 L p .62 .897 .591 r
F P
0 g
s
.79011 .58132 m .80185 .56975 L .76581 .61151 L p .62 .897 .591 r
F P
0 g
s
.42714 .5286 m .41768 .53378 L .39497 .48185 L p .567 .51 .751 r
F P
0 g
s
.41768 .53378 m .42714 .5286 L .4543 .57536 L p .511 .486 .765 r
F P
0 g
s
.4543 .57536 m .4475 .5823 L .41768 .53378 L p .511 .486 .765 r
F P
0 g
s
.61633 .69959 m .62226 .69899 L .57204 .69468 L p .191 0 0 r
F P
0 g
s
.57204 .69468 m .56918 .6938 L .61633 .69959 L p .191 0 0 r
F P
0 g
s
.3678 .43153 m .38076 .42967 L .39497 .48185 L p .629 .559 .756 r
F P
0 g
s
.40651 .47881 m .39497 .48185 L .38076 .42967 L p .614 .541 .749 r
F P
0 g
s
.39497 .48185 m .40651 .47881 L .42714 .5286 L p .567 .51 .751 r
F P
0 g
s
.32103 .38918 m .33495 .38459 L .34176 .43895 L p .739 .674 .788 r
F P
0 g
s
.34176 .43895 m .32866 .44441 L .32103 .38918 L p .739 .674 .788 r
F P
0 g
s
.35481 .43464 m .34176 .43895 L .33495 .38459 L p .717 .649 .781 r
F P
0 g
s
.30697 .39522 m .32103 .38918 L .32866 .44441 L p .759 .699 .795 r
F P
0 g
s
.32866 .44441 m .31548 .45091 L .30697 .39522 L p .759 .699 .795 r
F P
0 g
s
.33495 .38459 m .34874 .38155 L .35481 .43464 L p .717 .649 .781 r
F P
0 g
s
.3678 .43153 m .35481 .43464 L .34874 .38155 L p .695 .624 .773 r
F P
0 g
s
.29275 .40257 m .30697 .39522 L .31548 .45091 L p .778 .722 .801 r
F P
0 g
s
.31548 .45091 m .30223 .45837 L .29275 .40257 L p .778 .722 .801 r
F P
0 g
s
.34874 .38155 m .36241 .38015 L .3678 .43153 L p .695 .624 .773 r
F P
0 g
s
.38076 .42967 m .3678 .43153 L .36241 .38015 L p .673 .6 .765 r
F P
0 g
s
.27837 .41108 m .29275 .40257 L .30223 .45837 L p .795 .745 .807 r
F P
0 g
s
.30223 .45837 m .2889 .46666 L .27837 .41108 L p .795 .745 .807 r
F P
0 g
s
.4475 .5823 m .4543 .57536 L .48636 .61619 L p .45 .472 .79 r
F P
0 g
s
.48636 .61619 m .48266 .62442 L .4475 .5823 L p .45 .472 .79 r
F P
0 g
s
.479 .63147 m .48266 .62442 L .52104 .65744 L p .344 .485 .857 r
F P
0 g
s
.52104 .65744 m .52069 .6647 L .479 .63147 L p .344 .485 .857 r
F P
0 g
s
.38076 .42967 m .39369 .42907 L .40651 .47881 L p .614 .541 .749 r
F P
0 g
s
.41809 .47648 m .40651 .47881 L .39369 .42907 L p .599 .525 .742 r
F P
0 g
s
.40651 .47881 m .41809 .47648 L .43665 .5235 L p .56 .498 .743 r
F P
0 g
s
.43665 .5235 m .42714 .5286 L .40651 .47881 L p .56 .498 .743 r
F P
0 g
s
.26384 .42056 m .27837 .41108 L .2889 .46666 L p .809 .766 .813 r
F P
0 g
s
.2889 .46666 m .2755 .47564 L .26384 .42056 L p .809 .766 .813 r
F P
0 g
s
.36241 .38015 m .37599 .38044 L .38076 .42967 L p .673 .6 .765 r
F P
0 g
s
.39369 .42907 m .38076 .42967 L .37599 .38044 L p .651 .576 .758 r
F P
0 g
s
.42714 .5286 m .43665 .5235 L .46115 .56786 L p .515 .478 .754 r
F P
0 g
s
.46115 .56786 m .4543 .57536 L .42714 .5286 L p .515 .478 .754 r
F P
0 g
s
.6922 .67129 m .68403 .67872 L .72509 .65161 L p 0 0 0 r
F P
0 g
s
.72509 .65161 m .73557 .64303 L .6922 .67129 L p 0 0 0 r
F P
0 g
s
.52034 .67024 m .52069 .6647 L .56329 .68611 L p .168 .53 .922 r
F P
0 g
s
.56329 .68611 m .56626 .69099 L .52034 .67024 L p .168 .53 .922 r
F P
0 g
s
.24915 .43081 m .26384 .42056 L .2755 .47564 L p .822 .786 .819 r
F P
0 g
s
.2755 .47564 m .26202 .48516 L .24915 .43081 L p .822 .786 .819 r
F P
0 g
s
.62806 .6964 m .62226 .69899 L .66711 .68871 L p .019 0 0 r
F P
0 g
s
.66711 .68871 m .67567 .68462 L .62806 .6964 L p .019 0 0 r
F P
0 g
s
.37599 .38044 m .38949 .38243 L .39369 .42907 L p .651 .576 .758 r
F P
0 g
s
.40661 .42973 m .39369 .42907 L .38949 .38243 L p .63 .554 .75 r
F P
0 g
s
.39369 .42907 m .40661 .42973 L .41809 .47648 L p .599 .525 .742 r
F P
0 g
s
.42971 .47485 m .41809 .47648 L .40661 .42973 L p .585 .509 .736 r
F P
0 g
s
.41809 .47648 m .42971 .47485 L .44622 .51849 L p .553 .488 .736 r
F P
0 g
s
.44622 .51849 m .43665 .5235 L .41809 .47648 L p .553 .488 .736 r
F P
0 g
s
.83625 .53514 m .82489 .54637 L .8463 .49696 L p .853 .997 .812 r
F P
0 g
s
.8463 .49696 m .85906 .48583 L .83625 .53514 L p .853 .997 .812 r
F P
0 g
s
.23431 .44162 m .24915 .43081 L .26202 .48516 L p .831 .804 .825 r
F P
0 g
s
.26202 .48516 m .24848 .49506 L .23431 .44162 L p .831 .804 .825 r
F P
0 g
s
.4543 .57536 m .46115 .56786 L .49011 .60677 L p .469 .467 .773 r
F P
0 g
s
.49011 .60677 m .48636 .61619 L .4543 .57536 L p .469 .467 .773 r
F P
0 g
s
.43665 .5235 m .44622 .51849 L .46806 .55982 L p .518 .471 .744 r
F P
0 g
s
.46806 .55982 m .46115 .56786 L .43665 .5235 L p .518 .471 .744 r
F P
0 g
s
.38949 .38243 m .40293 .38613 L .40661 .42973 L p .63 .554 .75 r
F P
0 g
s
.41954 .43161 m .40661 .42973 L .40293 .38613 L p .611 .533 .742 r
F P
0 g
s
.40661 .42973 m .41954 .43161 L .42971 .47485 L p .585 .509 .736 r
F P
0 g
s
.56918 .6938 m .56626 .69099 L .61028 .698 L p .022 .58 .813 r
F P
0 g
s
.61028 .698 m .61633 .69959 L .56918 .6938 L p .022 .58 .813 r
F P
0 g
s
.75592 .62264 m .74584 .63326 L .7782 .59241 L p .676 .937 .653 r
F P
0 g
s
.7782 .59241 m .79011 .58132 L .75592 .62264 L p .676 .937 .653 r
F P
0 g
s
.48266 .62442 m .48636 .61619 L .52139 .64842 L p .398 .481 .828 r
F P
0 g
s
.52139 .64842 m .52104 .65744 L .48266 .62442 L p .398 .481 .828 r
F P
0 g
s
.21935 .45276 m .23431 .44162 L .24848 .49506 L p .838 .82 .831 r
F P
0 g
s
.24848 .49506 m .23488 .50517 L .21935 .45276 L p .838 .82 .831 r
F P
0 g
s
.36781 .33471 m .3811 .33727 L .37599 .38044 L p .704 .646 .789 r
F P
0 g
s
.37599 .38044 m .36241 .38015 L .36781 .33471 L p .704 .646 .789 r
F P
0 g
s
.38949 .38243 m .37599 .38044 L .3811 .33727 L p .676 .614 .778 r
F P
0 g
s
.44138 .47387 m .42971 .47485 L .41954 .43161 L p .573 .496 .73 r
F P
0 g
s
.42971 .47485 m .44138 .47387 L .45585 .51357 L p .548 .478 .73 r
F P
0 g
s
.45585 .51357 m .44622 .51849 L .42971 .47485 L p .548 .478 .73 r
F P
0 g
s
.35437 .33416 m .36781 .33471 L .36241 .38015 L p .732 .68 .8 r
F P
0 g
s
.36241 .38015 m .34874 .38155 L .35437 .33416 L p .732 .68 .8 r
F P
0 g
s
.20427 .46399 m .21935 .45276 L .23488 .50517 L p .841 .834 .839 r
F P
0 g
s
.23488 .50517 m .22124 .51532 L .20427 .46399 L p .841 .834 .839 r
F P
0 g
s
.3811 .33727 m .39428 .34186 L .38949 .38243 L p .676 .614 .778 r
F P
0 g
s
.40293 .38613 m .38949 .38243 L .39428 .34186 L p .649 .583 .767 r
F P
0 g
s
.40293 .38613 m .41634 .3915 L .41954 .43161 L p .611 .533 .742 r
F P
0 g
s
.43249 .43468 m .41954 .43161 L .41634 .3915 L p .592 .514 .735 r
F P
0 g
s
.41954 .43161 m .43249 .43468 L .44138 .47387 L p .573 .496 .73 r
F P
0 g
s
.52069 .6647 m .52104 .65744 L .56027 .67907 L p .303 .537 .911 r
F P
0 g
s
.56027 .67907 m .56329 .68611 L .52069 .6647 L p .303 .537 .911 r
F P
0 g
s
.34076 .33555 m .35437 .33416 L .34874 .38155 L p .76 .714 .81 r
F P
0 g
s
.34874 .38155 m .33495 .38459 L .34076 .33555 L p .76 .714 .81 r
F P
0 g
s
.46115 .56786 m .46806 .55982 L .49389 .59619 L p .484 .463 .758 r
F P
0 g
s
.49389 .59619 m .49011 .60677 L .46115 .56786 L p .484 .463 .758 r
F P
0 g
s
.39428 .34186 m .40736 .34847 L .40293 .38613 L p .649 .583 .767 r
F P
0 g
s
.41634 .3915 m .40293 .38613 L .40736 .34847 L p .625 .555 .756 r
F P
0 g
s
.44622 .51849 m .45585 .51357 L .47502 .55126 L p .52 .465 .735 r
F P
0 g
s
.47502 .55126 m .46806 .55982 L .44622 .51849 L p .52 .465 .735 r
F P
0 g
s
.18911 .47507 m .20427 .46399 L .22124 .51532 L p .842 .846 .847 r
F P
0 g
s
.22124 .51532 m .20758 .52532 L .18911 .47507 L p .842 .846 .847 r
F P
0 g
s
.32696 .3388 m .34076 .33555 L .33495 .38459 L p .787 .748 .818 r
F P
0 g
s
.33495 .38459 m .32103 .38918 L .32696 .3388 L p .787 .748 .818 r
F P
0 g
s
.68403 .67872 m .67567 .68462 L .71439 .65869 L p 0 0 0 r
F P
0 g
s
.71439 .65869 m .72509 .65161 L .68403 .67872 L p 0 0 0 r
F P
0 g
s
.62226 .69899 m .61633 .69959 L .65838 .6907 L p .159 .692 .69 r
F P
0 g
s
.65838 .6907 m .66711 .68871 L .62226 .69899 L p .159 .692 .69 r
F P
0 g
s
.82489 .54637 m .81343 .558 L .83347 .50841 L p .867 .994 .811 r
F P
0 g
s
.83347 .50841 m .8463 .49696 L .82489 .54637 L p .867 .994 .811 r
F P
0 g
s
.48636 .61619 m .49011 .60677 L .52175 .63766 L p .435 .475 .802 r
F P
0 g
s
.52175 .63766 m .52139 .64842 L .48636 .61619 L p .435 .475 .802 r
F P
0 g
s
.40736 .34847 m .42038 .35705 L .41634 .3915 L p .625 .555 .756 r
F P
0 g
s
.42975 .39847 m .41634 .3915 L .42038 .35705 L p .603 .531 .746 r
F P
0 g
s
.41634 .3915 m .42975 .39847 L .43249 .43468 L p .592 .514 .735 r
F P
0 g
s
.45311 .47352 m .44138 .47387 L .43249 .43468 L p .562 .483 .724 r
F P
0 g
s
.44138 .47387 m .45311 .47352 L .46555 .50872 L p .543 .47 .724 r
F P
0 g
s
.46555 .50872 m .45585 .51357 L .44138 .47387 L p .543 .47 .724 r
F P
0 g
s
.44549 .43886 m .43249 .43468 L .42975 .39847 L p .576 .497 .729 r
F P
0 g
s
.43249 .43468 m .44549 .43886 L .45311 .47352 L p .562 .483 .724 r
F P
0 g
s
.31295 .34378 m .32696 .3388 L .32103 .38918 L p .812 .781 .824 r
F P
0 g
s
.32103 .38918 m .30697 .39522 L .31295 .34378 L p .812 .781 .824 r
F P
0 g
s
.56626 .69099 m .56329 .68611 L .6041 .69405 L p .239 .659 .96 r
F P
0 g
s
.6041 .69405 m .61028 .698 L .56626 .69099 L p .239 .659 .96 r
F P
0 g
s
.45585 .51357 m .46555 .50872 L .48204 .5422 L p .522 .46 .728 r
F P
0 g
s
.48204 .5422 m .47502 .55126 L .45585 .51357 L p .522 .46 .728 r
F P
0 g
s
.46806 .55982 m .47502 .55126 L .49771 .58451 L p .496 .459 .746 r
F P
0 g
s
.49771 .58451 m .49389 .59619 L .46806 .55982 L p .496 .459 .746 r
F P
0 g
s
.42038 .35705 m .43336 .36754 L .42975 .39847 L p .603 .531 .746 r
F P
0 g
s
.44317 .40694 m .42975 .39847 L .43336 .36754 L p .584 .509 .736 r
F P
0 g
s
.42975 .39847 m .44317 .40694 L .44549 .43886 L p .576 .497 .729 r
F P
0 g
s
.52104 .65744 m .52139 .64842 L .5572 .66982 L p .385 .524 .874 r
F P
0 g
s
.5572 .66982 m .56027 .67907 L .52104 .65744 L p .385 .524 .874 r
F P
0 g
s
.74584 .63326 m .73557 .64303 L .76609 .6027 L p .736 .975 .726 r
F P
0 g
s
.76609 .6027 m .7782 .59241 L .74584 .63326 L p .736 .975 .726 r
F P
0 g
s
.29873 .35035 m .31295 .34378 L .30697 .39522 L p .833 .811 .829 r
F P
0 g
s
.30697 .39522 m .29275 .40257 L .29873 .35035 L p .833 .811 .829 r
F P
0 g
s
.45854 .44405 m .44549 .43886 L .44317 .40694 L p .562 .482 .723 r
F P
0 g
s
.44549 .43886 m .45854 .44405 L .4649 .47373 L p .552 .473 .72 r
F P
0 g
s
.4649 .47373 m .45311 .47352 L .44549 .43886 L p .552 .473 .72 r
F P
0 g
s
.45311 .47352 m .4649 .47373 L .47531 .50393 L p .538 .463 .719 r
F P
0 g
s
.47531 .50393 m .46555 .50872 L .45311 .47352 L p .538 .463 .719 r
F P
0 g
s
.49011 .60677 m .49389 .59619 L .52212 .62519 L p .462 .469 .779 r
F P
0 g
s
.52212 .62519 m .52175 .63766 L .49011 .60677 L p .462 .469 .779 r
F P
0 g
s
.39598 .30305 m .40792 .31004 L .39428 .34186 L p .681 .65 .812 r
F P
0 g
s
.39428 .34186 m .3811 .33727 L .39598 .30305 L p .681 .65 .812 r
F P
0 g
s
.40736 .34847 m .39428 .34186 L .40792 .31004 L p .651 .609 .793 r
F P
0 g
s
.40792 .31004 m .41974 .31922 L .40736 .34847 L p .651 .609 .793 r
F P
0 g
s
.42038 .35705 m .40736 .34847 L .41974 .31922 L p .624 .573 .776 r
F P
0 g
s
.3839 .29827 m .39598 .30305 L .3811 .33727 L p .714 .695 .831 r
F P
0 g
s
.3811 .33727 m .36781 .33471 L .3839 .29827 L p .714 .695 .831 r
F P
0 g
s
.41974 .31922 m .43147 .33054 L .42038 .35705 L p .624 .573 .776 r
F P
0 g
s
.43336 .36754 m .42038 .35705 L .43147 .33054 L p .601 .542 .76 r
F P
0 g
s
.43336 .36754 m .44632 .37981 L .44317 .40694 L p .584 .509 .736 r
F P
0 g
s
.45663 .41679 m .44317 .40694 L .44632 .37981 L p .567 .49 .728 r
F P
0 g
s
.44317 .40694 m .45663 .41679 L .45854 .44405 L p .562 .482 .723 r
F P
0 g
s
.81343 .558 m .80185 .56975 L .82055 .51993 L p .879 .988 .816 r
F P
0 g
s
.82055 .51993 m .83347 .50841 L .81343 .558 L p .879 .988 .816 r
F P
0 g
s
.28429 .35831 m .29873 .35035 L .29275 .40257 L p .851 .838 .832 r
F P
0 g
s
.29275 .40257 m .27837 .41108 L .28429 .35831 L p .851 .838 .832 r
F P
0 g
s
.47502 .55126 m .48204 .5422 L .50156 .57179 L p .505 .456 .736 r
F P
0 g
s
.50156 .57179 m .49771 .58451 L .47502 .55126 L p .505 .456 .736 r
F P
0 g
s
.46555 .50872 m .47531 .50393 L .48911 .5327 L p .524 .456 .722 r
F P
0 g
s
.48911 .5327 m .48204 .5422 L .46555 .50872 L p .524 .456 .722 r
F P
0 g
s
.43147 .33054 m .44315 .34393 L .43336 .36754 L p .601 .542 .76 r
F P
0 g
s
.44632 .37981 m .43336 .36754 L .44315 .34393 L p .581 .516 .747 r
F P
0 g
s
.37165 .29567 m .3839 .29827 L .36781 .33471 L p .747 .743 .848 r
F P
0 g
s
.36781 .33471 m .35437 .33416 L .37165 .29567 L p .747 .743 .848 r
F P
0 g
s
.61633 .69959 m .61028 .698 L .64946 .69039 L p .359 .82 .922 r
F P
0 g
s
.64946 .69039 m .65838 .6907 L .61633 .69959 L p .359 .82 .922 r
F P
0 g
s
.67567 .68462 m .66711 .68871 L .70348 .66397 L p .531 .914 .773 r
F P
0 g
s
.70348 .66397 m .71439 .65869 L .67567 .68462 L p .531 .914 .773 r
F P
0 g
s
.56329 .68611 m .56027 .67907 L .59782 .68764 L p .376 .644 .961 r
F P
0 g
s
.59782 .68764 m .6041 .69405 L .56329 .68611 L p .376 .644 .961 r
F P
0 g
s
.52139 .64842 m .52175 .63766 L .55408 .65837 L p .434 .508 .835 r
F P
0 g
s
.55408 .65837 m .5572 .66982 L .52139 .64842 L p .434 .508 .835 r
F P
0 g
s
.47166 .45013 m .45854 .44405 L .45663 .41679 L p .55 .47 .718 r
F P
0 g
s
.45854 .44405 m .47166 .45013 L .47677 .47444 L p .544 .464 .716 r
F P
0 g
s
.47677 .47444 m .4649 .47373 L .45854 .44405 L p .544 .464 .716 r
F P
0 g
s
.49389 .59619 m .49771 .58451 L .52249 .61109 L p .482 .464 .761 r
F P
0 g
s
.52249 .61109 m .52212 .62519 L .49389 .59619 L p .482 .464 .761 r
F P
0 g
s
.4649 .47373 m .47677 .47444 L .48513 .4992 L p .535 .458 .715 r
F P
0 g
s
.48513 .4992 m .47531 .50393 L .4649 .47373 L p .535 .458 .715 r
F P
0 g
s
.44315 .34393 m .45479 .35925 L .44632 .37981 L p .581 .516 .747 r
F P
0 g
s
.4593 .39371 m .44632 .37981 L .45479 .35925 L p .565 .495 .735 r
F P
0 g
s
.44632 .37981 m .4593 .39371 L .45663 .41679 L p .567 .49 .728 r
F P
0 g
s
.47015 .42786 m .45663 .41679 L .4593 .39371 L p .553 .475 .721 r
F P
0 g
s
.45663 .41679 m .47015 .42786 L .47166 .45013 L p .55 .47 .718 r
F P
0 g
s
.35921 .2952 m .37165 .29567 L .35437 .33416 L p .78 .793 .863 r
F P
0 g
s
.35437 .33416 m .34076 .33555 L .35921 .2952 L p .78 .793 .863 r
F P
0 g
s
.26962 .36745 m .28429 .35831 L .27837 .41108 L p .865 .862 .834 r
F P
0 g
s
.27837 .41108 m .26384 .42056 L .26962 .36745 L p .865 .862 .834 r
F P
0 g
s
.48204 .5422 m .48911 .5327 L .50543 .55814 L p .513 .453 .727 r
F P
0 g
s
.50543 .55814 m .50156 .57179 L .48204 .5422 L p .513 .453 .727 r
F P
0 g
s
.47531 .50393 m .48513 .4992 L .49622 .5228 L p .525 .453 .717 r
F P
0 g
s
.49622 .5228 m .48911 .5327 L .47531 .50393 L p .525 .453 .717 r
F P
0 g
s
.73557 .64303 m .72509 .65161 L .75378 .6119 L p .789 .998 .799 r
F P
0 g
s
.75378 .6119 m .76609 .6027 L .73557 .64303 L p .789 .998 .799 r
F P
0 g
s
.45479 .35925 m .46642 .37634 L .4593 .39371 L p .565 .495 .735 r
F P
0 g
s
.47232 .40908 m .4593 .39371 L .46642 .37634 L p .551 .477 .725 r
F P
0 g
s
.4593 .39371 m .47232 .40908 L .47015 .42786 L p .553 .475 .721 r
F P
0 g
s
.43942 .30044 m .44903 .31381 L .43147 .33054 L p .604 .578 .798 r
F P
0 g
s
.43147 .33054 m .41974 .31922 L .43942 .30044 L p .604 .578 .798 r
F P
0 g
s
.44315 .34393 m .43147 .33054 L .44903 .31381 L p .584 .544 .775 r
F P
0 g
s
.34655 .29675 m .35921 .2952 L .34076 .33555 L p .81 .841 .874 r
F P
0 g
s
.34076 .33555 m .32696 .3388 L .34655 .29675 L p .81 .841 .874 r
F P
0 g
s
.48487 .45698 m .47166 .45013 L .47015 .42786 L p .541 .46 .713 r
F P
0 g
s
.47166 .45013 m .48487 .45698 L .48872 .47556 L p .537 .457 .712 r
F P
0 g
s
.48872 .47556 m .47677 .47444 L .47166 .45013 L p .537 .457 .712 r
F P
0 g
s
.52175 .63766 m .52212 .62519 L .55093 .64477 L p .466 .493 .802 r
F P
0 g
s
.55093 .64477 m .55408 .65837 L .52175 .63766 L p .466 .493 .802 r
F P
0 g
s
.49771 .58451 m .50156 .57179 L .52286 .59549 L p .497 .459 .746 r
F P
0 g
s
.52286 .59549 m .52249 .61109 L .49771 .58451 L p .497 .459 .746 r
F P
0 g
s
.42972 .28923 m .43942 .30044 L .41974 .31922 L p .627 .621 .825 r
F P
0 g
s
.41974 .31922 m .40792 .31004 L .42972 .28923 L p .627 .621 .825 r
F P
0 g
s
.44903 .31381 m .45858 .32927 L .44315 .34393 L p .584 .544 .775 r
F P
0 g
s
.45479 .35925 m .44315 .34393 L .45858 .32927 L p .568 .516 .756 r
F P
0 g
s
.47677 .47444 m .48872 .47556 L .49502 .4945 L p .532 .453 .712 r
F P
0 g
s
.49502 .4945 m .48513 .4992 L .47677 .47444 L p .532 .453 .712 r
F P
0 g
s
.56027 .67907 m .5572 .66982 L .59143 .67872 L p .445 .601 .911 r
F P
0 g
s
.59143 .67872 m .59782 .68764 L .56027 .67907 L p .445 .601 .911 r
F P
0 g
s
.48374 .43998 m .47015 .42786 L .47232 .40908 L p .543 .463 .715 r
F P
0 g
s
.47015 .42786 m .48374 .43998 L .48487 .45698 L p .541 .46 .713 r
F P
0 g
s
.80185 .56975 m .79011 .58132 L .80751 .53128 L p .888 .977 .825 r
F P
0 g
s
.80751 .53128 m .82055 .51993 L .80185 .56975 L p .888 .977 .825 r
F P
0 g
s
.4199 .28024 m .42972 .28923 L .40792 .31004 L p .655 .672 .855 r
F P
0 g
s
.40792 .31004 m .39598 .30305 L .4199 .28024 L p .655 .672 .855 r
F P
0 g
s
.61028 .698 m .6041 .69405 L .64037 .68759 L p .491 .817 1 r
F P
0 g
s
.64037 .68759 m .64946 .69039 L .61028 .698 L p .491 .817 1 r
F P
0 g
s
.45858 .32927 m .46807 .34668 L .45479 .35925 L p .568 .516 .756 r
F P
0 g
s
.46642 .37634 m .45479 .35925 L .46807 .34668 L p .555 .493 .741 r
F P
0 g
s
.25472 .37755 m .26962 .36745 L .26384 .42056 L p .876 .883 .836 r
F P
0 g
s
.26384 .42056 m .24915 .43081 L .25472 .37755 L p .876 .883 .836 r
F P
0 g
s
.48911 .5327 m .49622 .5228 L .50933 .54367 L p .518 .451 .72 r
F P
0 g
s
.50933 .54367 m .50543 .55814 L .48911 .5327 L p .518 .451 .72 r
F P
0 g
s
.66711 .68871 m .65838 .6907 L .69235 .66721 L p .645 .963 .914 r
F P
0 g
s
.69235 .66721 m .70348 .66397 L .66711 .68871 L p .645 .963 .914 r
F P
0 g
s
.48513 .4992 m .49502 .4945 L .50338 .51256 L p .526 .45 .713 r
F P
0 g
s
.50338 .51256 m .49622 .5228 L .48513 .4992 L p .526 .45 .713 r
F P
0 g
s
.46642 .37634 m .47806 .39502 L .47232 .40908 L p .551 .477 .725 r
F P
0 g
s
.48539 .42569 m .47232 .40908 L .47806 .39502 L p .541 .464 .718 r
F P
0 g
s
.47232 .40908 m .48539 .42569 L .48374 .43998 L p .543 .463 .715 r
F P
0 g
s
.40995 .27349 m .4199 .28024 L .39598 .30305 L p .684 .732 .887 r
F P
0 g
s
.39598 .30305 m .3839 .29827 L .40995 .27349 L p .684 .732 .887 r
F P
0 g
s
.46807 .34668 m .47755 .36588 L .46642 .37634 L p .555 .493 .741 r
F P
0 g
s
.47806 .39502 m .46642 .37634 L .47755 .36588 L p .545 .476 .729 r
F P
0 g
s
.50156 .57179 m .50543 .55814 L .52323 .57854 L p .507 .455 .734 r
F P
0 g
s
.52323 .57854 m .52286 .59549 L .50156 .57179 L p .507 .455 .734 r
F P
0 g
s
.33366 .30019 m .34655 .29675 L .32696 .3388 L p .835 .885 .878 r
F P
0 g
s
.32696 .3388 m .31295 .34378 L .33366 .30019 L p .835 .885 .878 r
F P
0 g
s
.52212 .62519 m .52249 .61109 L .54775 .62915 L p .486 .481 .776 r
F P
0 g
s
.54775 .62915 m .55093 .64477 L .52212 .62519 L p .486 .481 .776 r
F P
0 g
s
.49818 .46443 m .48487 .45698 L .48374 .43998 L p .534 .453 .71 r
F P
0 g
s
.48487 .45698 m .49818 .46443 L .50076 .477 L p .532 .451 .71 r
F P
0 g
s
.50076 .477 m .48872 .47556 L .48487 .45698 L p .532 .451 .71 r
F P
0 g
s
.49743 .45294 m .48374 .43998 L .48539 .42569 L p .535 .454 .711 r
F P
0 g
s
.48374 .43998 m .49743 .45294 L .49818 .46443 L p .534 .453 .71 r
F P
0 g
s
.48872 .47556 m .50076 .477 L .50498 .48982 L p .53 .449 .709 r
F P
0 g
s
.50498 .48982 m .49502 .4945 L .48872 .47556 L p .53 .449 .709 r
F P
0 g
s
.5572 .66982 m .55408 .65837 L .58496 .66729 L p .481 .561 .86 r
F P
0 g
s
.58496 .66729 m .59143 .67872 L .5572 .66982 L p .481 .561 .86 r
F P
0 g
s
.49622 .5228 m .50338 .51256 L .51325 .52852 L p .522 .449 .715 r
F P
0 g
s
.51325 .52852 m .50933 .54367 L .49622 .5228 L p .522 .449 .715 r
F P
0 g
s
.23961 .38835 m .25472 .37755 L .24915 .43081 L p .882 .899 .838 r
F P
0 g
s
.24915 .43081 m .23431 .44162 L .23961 .38835 L p .882 .899 .838 r
F P
0 g
s
.72509 .65161 m .71439 .65869 L .74126 .61971 L p .824 .994 .858 r
F P
0 g
s
.74126 .61971 m .75378 .6119 L .72509 .65161 L p .824 .994 .858 r
F P
0 g
s
.47755 .36588 m .48701 .38666 L .47806 .39502 L p .545 .476 .729 r
F P
0 g
s
.48974 .41505 m .47806 .39502 L .48701 .38666 L p .538 .463 .72 r
F P
0 g
s
.47806 .39502 m .48974 .41505 L .48539 .42569 L p .541 .464 .718 r
F P
0 g
s
.39983 .26895 m .40995 .27349 L .3839 .29827 L p .714 .799 .917 r
F P
0 g
s
.3839 .29827 m .37165 .29567 L .39983 .26895 L p .714 .799 .917 r
F P
0 g
s
.49854 .4433 m .48539 .42569 L .48974 .41505 L p .534 .455 .712 r
F P
0 g
s
.48539 .42569 m .49854 .4433 L .49743 .45294 L p .535 .454 .711 r
F P
0 g
s
.50543 .55814 m .50933 .54367 L .5236 .56041 L p .515 .452 .724 r
F P
0 g
s
.5236 .56041 m .52323 .57854 L .50543 .55814 L p .515 .452 .724 r
F P
0 g
s
.49502 .4945 m .50498 .48982 L .51058 .50204 L p .527 .448 .71 r
F P
0 g
s
.51058 .50204 m .50338 .51256 L .49502 .4945 L p .527 .448 .71 r
F P
0 g
s
.6041 .69405 m .59782 .68764 L .63113 .68221 L p .543 .744 .969 r
F P
0 g
s
.63113 .68221 m .64037 .68759 L .6041 .69405 L p .543 .744 .969 r
F P
0 g
s
.52249 .61109 m .52286 .59549 L .54455 .61164 L p .5 .471 .756 r
F P
0 g
s
.54455 .61164 m .54775 .62915 L .52249 .61109 L p .5 .471 .756 r
F P
0 g
s
.79011 .58132 m .7782 .59241 L .79433 .54219 L p .891 .96 .835 r
F P
0 g
s
.79433 .54219 m .80751 .53128 L .79011 .58132 L p .891 .96 .835 r
F P
0 g
s
.47202 .30818 m .47872 .3247 L .45858 .32927 L p .554 .532 .785 r
F P
0 g
s
.45858 .32927 m .44903 .31381 L .47202 .30818 L p .554 .532 .785 r
F P
0 g
s
.46807 .34668 m .45858 .32927 L .47872 .3247 L p .546 .506 .763 r
F P
0 g
s
.47872 .3247 m .48538 .34305 L .46807 .34668 L p .546 .506 .763 r
F P
0 g
s
.47755 .36588 m .46807 .34668 L .48538 .34305 L p .54 .487 .745 r
F P
0 g
s
.46526 .29362 m .47202 .30818 L .44903 .31381 L p .563 .565 .814 r
F P
0 g
s
.44903 .31381 m .43942 .30044 L .46526 .29362 L p .563 .565 .814 r
F P
0 g
s
.32052 .30537 m .33366 .30019 L .31295 .34378 L p .852 .923 .877 r
F P
0 g
s
.31295 .34378 m .29873 .35035 L .32052 .30537 L p .852 .923 .877 r
F P
0 g
s
.48538 .34305 m .49201 .36309 L .47755 .36588 L p .54 .487 .745 r
F P
0 g
s
.48701 .38666 m .47755 .36588 L .49201 .36309 L p .536 .472 .731 r
F P
0 g
s
.48701 .38666 m .49649 .40879 L .48974 .41505 L p .538 .463 .72 r
F P
0 g
s
.50146 .43617 m .48974 .41505 L .49649 .40879 L p .532 .454 .713 r
F P
0 g
s
.48974 .41505 m .50146 .43617 L .49854 .4433 L p .534 .455 .712 r
F P
0 g
s
.65838 .6907 m .64946 .69039 L .68101 .66818 L p .695 .926 .968 r
F P
0 g
s
.68101 .66818 m .69235 .66721 L .65838 .6907 L p .695 .926 .968 r
F P
0 g
s
.50338 .51256 m .51058 .50204 L .51719 .51283 L p .525 .448 .711 r
F P
0 g
s
.51719 .51283 m .51325 .52852 L .50338 .51256 L p .525 .448 .711 r
F P
0 g
s
.55408 .65837 m .55093 .64477 L .57842 .65344 L p .5 .53 .819 r
F P
0 g
s
.57842 .65344 m .58496 .66729 L .55408 .65837 L p .5 .53 .819 r
F P
0 g
s
.45843 .28112 m .46526 .29362 L .43942 .30044 L p .574 .608 .849 r
F P
0 g
s
.43942 .30044 m .42972 .28923 L .45843 .28112 L p .574 .608 .849 r
F P
0 g
s
.51159 .47232 m .49818 .46443 L .49743 .45294 L p .529 .448 .708 r
F P
0 g
s
.49818 .46443 m .51159 .47232 L .51289 .47867 L p .529 .447 .708 r
F P
0 g
s
.51289 .47867 m .50076 .477 L .49818 .46443 L p .529 .447 .708 r
F P
0 g
s
.50933 .54367 m .51325 .52852 L .52398 .54131 L p .521 .45 .717 r
F P
0 g
s
.52398 .54131 m .5236 .56041 L .50933 .54367 L p .521 .45 .717 r
F P
0 g
s
.51121 .46652 m .49743 .45294 L .49854 .4433 L p .529 .448 .708 r
F P
0 g
s
.49743 .45294 m .51121 .46652 L .51159 .47232 L p .529 .448 .708 r
F P
0 g
s
.50076 .477 m .51289 .47867 L .51501 .48515 L p .528 .447 .708 r
F P
0 g
s
.51501 .48515 m .50498 .48982 L .50076 .477 L p .528 .447 .708 r
F P
0 g
s
.49201 .36309 m .49862 .3846 L .48701 .38666 L p .536 .472 .731 r
F P
0 g
s
.49649 .40879 m .48701 .38666 L .49862 .3846 L p .532 .461 .721 r
F P
0 g
s
.52286 .59549 m .52323 .57854 L .54133 .59246 L p .51 .463 .74 r
F P
0 g
s
.54133 .59246 m .54455 .61164 L .52286 .59549 L p .51 .463 .74 r
F P
0 g
s
.2243 .39957 m .23961 .38835 L .23431 .44162 L p .885 .913 .84 r
F P
0 g
s
.23431 .44162 m .21935 .45276 L .2243 .39957 L p .885 .913 .84 r
F P
0 g
s
.38953 .26656 m .39983 .26895 L .37165 .29567 L p .74 .866 .939 r
F P
0 g
s
.37165 .29567 m .35921 .2952 L .38953 .26656 L p .74 .866 .939 r
F P
0 g
s
.51178 .46166 m .49854 .4433 L .50146 .43617 L p .529 .448 .709 r
F P
0 g
s
.49854 .4433 m .51178 .46166 L .51121 .46652 L p .529 .448 .708 r
F P
0 g
s
.50498 .48982 m .51501 .48515 L .51783 .49132 L p .527 .446 .708 r
F P
0 g
s
.51783 .49132 m .51058 .50204 L .50498 .48982 L p .527 .446 .708 r
F P
0 g
s
.45151 .27072 m .45843 .28112 L .42972 .28923 L p .586 .662 .89 r
F P
0 g
s
.42972 .28923 m .4199 .28024 L .45151 .27072 L p .586 .662 .89 r
F P
0 g
s
.49862 .3846 m .50523 .40737 L .49649 .40879 L p .532 .461 .721 r
F P
0 g
s
.506 .43201 m .49649 .40879 L .50523 .40737 L p .53 .453 .714 r
F P
0 g
s
.49649 .40879 m .506 .43201 L .50146 .43617 L p .532 .454 .713 r
F P
0 g
s
.59782 .68764 m .59143 .67872 L .62175 .67418 L p .556 .668 .912 r
F P
0 g
s
.62175 .67418 m .63113 .68221 L .59782 .68764 L p .556 .668 .912 r
F P
0 g
s
.51325 .45808 m .50146 .43617 L .506 .43201 L p .529 .448 .709 r
F P
0 g
s
.50146 .43617 m .51325 .45808 L .51178 .46166 L p .529 .448 .709 r
F P
0 g
s
.51325 .52852 m .51719 .51283 L .52436 .52147 L p .524 .448 .712 r
F P
0 g
s
.52436 .52147 m .52398 .54131 L .51325 .52852 L p .524 .448 .712 r
F P
0 g
s
.52323 .57854 m .5236 .56041 L .5381 .57184 L p .517 .457 .728 r
F P
0 g
s
.5381 .57184 m .54133 .59246 L .52323 .57854 L p .517 .457 .728 r
F P
0 g
s
.71439 .65869 m .70348 .66397 L .72853 .62589 L p .832 .961 .893 r
F P
0 g
s
.72853 .62589 m .74126 .61971 L .71439 .65869 L p .832 .961 .893 r
F P
0 g
s
.51058 .50204 m .51783 .49132 L .52114 .49676 L p .527 .446 .708 r
F P
0 g
s
.52114 .49676 m .51719 .51283 L .51058 .50204 L p .527 .446 .708 r
F P
0 g
s
.55093 .64477 m .54775 .62915 L .57182 .63728 L p .511 .506 .787 r
F P
0 g
s
.57182 .63728 m .57842 .65344 L .55093 .64477 L p .511 .506 .787 r
F P
0 g
s
.30713 .31209 m .32052 .30537 L .29873 .35035 L p .862 .952 .869 r
F P
0 g
s
.29873 .35035 m .28429 .35831 L .30713 .31209 L p .862 .952 .869 r
F P
0 g
s
.7782 .59241 m .76609 .6027 L .781 .55242 L p .886 .936 .844 r
F P
0 g
s
.781 .55242 m .79433 .54219 L .7782 .59241 L p .886 .936 .844 r
F P
0 g
s
.50523 .40737 m .51185 .43114 L .506 .43201 L p .53 .453 .714 r
F P
0 g
s
.51553 .45601 m .506 .43201 L .51185 .43114 L p .528 .448 .709 r
F P
0 g
s
.506 .43201 m .51553 .45601 L .51325 .45808 L p .529 .448 .709 r
F P
0 g
s
.5236 .56041 m .52398 .54131 L .53485 .55003 L p .522 .453 .719 r
F P
0 g
s
.53485 .55003 m .5381 .57184 L .5236 .56041 L p .522 .453 .719 r
F P
0 g
s
.5056 .34877 m .50887 .36828 L .49201 .36309 L p .525 .476 .744 r
F P
0 g
s
.49201 .36309 m .48538 .34305 L .5056 .34877 L p .525 .476 .744 r
F P
0 g
s
.49862 .3846 m .49201 .36309 L .50887 .36828 L p .526 .465 .731 r
F P
0 g
s
.20881 .41093 m .2243 .39957 L .21935 .45276 L p .884 .923 .845 r
F P
0 g
s
.21935 .45276 m .20427 .46399 L .20881 .41093 L p .884 .923 .845 r
F P
0 g
s
.52511 .48046 m .51159 .47232 L .51121 .46652 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .51289 .47867 L .51159 .47232 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .51121 .46652 L .51178 .46166 L closepath p .527 .445 .707 r
F P
0 g
s
.50231 .33072 m .5056 .34877 L .48538 .34305 L p .523 .491 .762 r
F P
0 g
s
.48538 .34305 m .47872 .3247 L .50231 .33072 L p .523 .491 .762 r
F P
0 g
s
.50887 .36828 m .51213 .38906 L .49862 .3846 L p .526 .465 .731 r
F P
0 g
s
.50523 .40737 m .49862 .3846 L .51213 .38906 L p .527 .457 .721 r
F P
0 g
s
.52511 .48046 m .51501 .48515 L .51289 .47867 L closepath p .527 .445 .707 r
F P
0 g
s
.37903 .26623 m .38953 .26656 L .35921 .2952 L p .754 .927 .946 r
F P
0 g
s
.35921 .2952 m .34655 .29675 L .37903 .26623 L p .754 .927 .946 r
F P
0 g
s
.51719 .51283 m .52114 .49676 L .52474 .5011 L p .526 .446 .708 r
F P
0 g
s
.52474 .5011 m .52436 .52147 L .51719 .51283 L p .526 .446 .708 r
F P
0 g
s
.44448 .26243 m .45151 .27072 L .4199 .28024 L p .595 .726 .936 r
F P
0 g
s
.4199 .28024 m .40995 .27349 L .44448 .26243 L p .595 .726 .936 r
F P
0 g
s
.64946 .69039 m .64037 .68759 L .66948 .66672 L p .694 .844 .955 r
F P
0 g
s
.66948 .66672 m .68101 .66818 L .64946 .69039 L p .694 .844 .955 r
F P
0 g
s
.52511 .48046 m .51178 .46166 L .51325 .45808 L closepath p .527 .445 .707 r
F P
0 g
s
.54775 .62915 m .54455 .61164 L .56518 .61901 L p .517 .488 .763 r
F P
0 g
s
.56518 .61901 m .57182 .63728 L .54775 .62915 L p .517 .488 .763 r
F P
0 g
s
.52511 .48046 m .51783 .49132 L .51501 .48515 L closepath p .527 .445 .707 r
F P
0 g
s
.51213 .38906 m .51538 .41092 L .50523 .40737 L p .527 .457 .721 r
F P
0 g
s
.51185 .43114 m .50523 .40737 L .51538 .41092 L p .527 .451 .713 r
F P
0 g
s
.499 .31427 m .50231 .33072 L .47872 .3247 L p .52 .51 .785 r
F P
0 g
s
.47872 .3247 m .47202 .30818 L .499 .31427 L p .52 .51 .785 r
F P
0 g
s
.52511 .48046 m .51325 .45808 L .51553 .45601 L closepath p .527 .445 .707 r
F P
0 g
s
.85906 .48583 m .8463 .49696 L .8464 .44362 L p .858 .906 .865 r
F P
0 g
s
.8464 .44362 m .85986 .43317 L .85906 .48583 L p .858 .906 .865 r
F P
0 g
s
.52398 .54131 m .52436 .52147 L .53161 .52734 L p .525 .449 .713 r
F P
0 g
s
.53161 .52734 m .53485 .55003 L .52398 .54131 L p .525 .449 .713 r
F P
0 g
s
.52511 .48046 m .52114 .49676 L .51783 .49132 L closepath p .527 .445 .707 r
F P
0 g
s
.59143 .67872 m .58496 .66729 L .61225 .66353 L p .556 .608 .861 r
F P
0 g
s
.61225 .66353 m .62175 .67418 L .59143 .67872 L p .556 .608 .861 r
F P
0 g
s
.51538 .41092 m .51862 .43362 L .51185 .43114 L p .527 .451 .713 r
F P
0 g
s
.51847 .4556 m .51185 .43114 L .51862 .43362 L p .527 .447 .709 r
F P
0 g
s
.51185 .43114 m .51847 .4556 L .51553 .45601 L p .528 .448 .709 r
F P
0 g
s
.52511 .48046 m .51553 .45601 L .51847 .4556 L closepath p .527 .445 .707 r
F P
0 g
s
.49565 .29954 m .499 .31427 L .47202 .30818 L p .515 .535 .814 r
F P
0 g
s
.47202 .30818 m .46526 .29362 L .49565 .29954 L p .515 .535 .814 r
F P
0 g
s
.54455 .61164 m .54133 .59246 L .55851 .59886 L p .522 .474 .745 r
F P
0 g
s
.55851 .59886 m .56518 .61901 L .54455 .61164 L p .522 .474 .745 r
F P
0 g
s
.52511 .48046 m .52474 .5011 L .52114 .49676 L closepath p .527 .445 .707 r
F P
0 g
s
.52436 .52147 m .52474 .5011 L .52836 .50405 L p .527 .447 .709 r
F P
0 g
s
.52836 .50405 m .53161 .52734 L .52436 .52147 L p .527 .447 .709 r
F P
0 g
s
.51862 .43362 m .52187 .45689 L .51847 .4556 L p .527 .447 .709 r
F P
0 g
s
.52511 .48046 m .51847 .4556 L .52187 .45689 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .52836 .50405 L .52474 .5011 L closepath p .527 .445 .707 r
F P
0 g
s
.54133 .59246 m .5381 .57184 L .55182 .57711 L p .524 .464 .731 r
F P
0 g
s
.55182 .57711 m .55851 .59886 L .54133 .59246 L p .524 .464 .731 r
F P
0 g
s
.70348 .66397 m .69235 .66721 L .71559 .63019 L p .817 .906 .902 r
F P
0 g
s
.71559 .63019 m .72853 .62589 L .70348 .66397 L p .817 .906 .902 r
F P
0 g
s
.19318 .42214 m .20881 .41093 L .20427 .46399 L p .88 .931 .851 r
F P
0 g
s
.20427 .46399 m .18911 .47507 L .19318 .42214 L p .88 .931 .851 r
F P
0 g
s
.43733 .25624 m .44448 .26243 L .40995 .27349 L p .595 .798 .977 r
F P
0 g
s
.40995 .27349 m .39983 .26895 L .43733 .25624 L p .595 .798 .977 r
F P
0 g
s
.29347 .32011 m .30713 .31209 L .28429 .35831 L p .865 .972 .858 r
F P
0 g
s
.28429 .35831 m .26962 .36745 L .29347 .32011 L p .865 .972 .858 r
F P
0 g
s
.52626 .41925 m .52587 .43931 L .51862 .43362 L p .525 .449 .713 r
F P
0 g
s
.51862 .43362 m .51538 .41092 L .52626 .41925 L p .525 .449 .713 r
F P
0 g
s
.52187 .45689 m .51862 .43362 L .52587 .43931 L p .527 .447 .709 r
F P
0 g
s
.52664 .39982 m .52626 .41925 L .51538 .41092 L p .523 .453 .719 r
F P
0 g
s
.51538 .41092 m .51213 .38906 L .52664 .39982 L p .523 .453 .719 r
F P
0 g
s
.52587 .43931 m .52549 .45979 L .52187 .45689 L p .527 .447 .709 r
F P
0 g
s
.52511 .48046 m .52187 .45689 L .52549 .45979 L closepath p .527 .445 .707 r
F P
0 g
s
.5381 .57184 m .53485 .55003 L .54513 .55405 L p .526 .456 .721 r
F P
0 g
s
.54513 .55405 m .55182 .57711 L .5381 .57184 L p .526 .456 .721 r
F P
0 g
s
.58496 .66729 m .57842 .65344 L .60266 .65033 L p .552 .563 .819 r
F P
0 g
s
.60266 .65033 m .61225 .66353 L .58496 .66729 L p .552 .563 .819 r
F P
0 g
s
.52511 .48046 m .53529 .47574 L .53744 .48227 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53244 .46955 L .53529 .47574 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .5291 .4641 L .53244 .46955 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .52549 .45979 L .5291 .4641 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53177 .50539 L .52836 .50405 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53474 .50503 L .53177 .50539 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53705 .50299 L .53474 .50503 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53855 .49941 L .53705 .50299 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53913 .49453 L .53855 .49941 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53875 .48868 L .53913 .49453 L closepath p .527 .445 .707 r
F P
0 g
s
.52511 .48046 m .53744 .48227 L .53875 .48868 L closepath p .527 .445 .707 r
F P
0 g
s
.49227 .28661 m .49565 .29954 L .46526 .29362 L p .507 .567 .851 r
F P
0 g
s
.46526 .29362 m .45843 .28112 L .49227 .28661 L p .507 .567 .851 r
F P
0 g
s
.52702 .38121 m .52664 .39982 L .51213 .38906 L p .519 .458 .728 r
F P
0 g
s
.51213 .38906 m .50887 .36828 L .52702 .38121 L p .519 .458 .728 r
F P
0 g
s
.53161 .52734 m .52836 .50405 L .53177 .50539 L p .527 .447 .709 r
F P
0 g
s
.53485 .55003 m .53161 .52734 L .53845 .53003 L p .527 .451 .713 r
F P
0 g
s
.53845 .53003 m .54513 .55405 L .53485 .55003 L p .527 .451 .713 r
F P
0 g
s
.53177 .50539 m .53845 .53003 L .53161 .52734 L p .527 .447 .709 r
F P
0 g
s
.76609 .6027 m .75378 .6119 L .7675 .56172 L p .874 .904 .849 r
F P
0 g
s
.7675 .56172 m .781 .55242 L .76609 .6027 L p .874 .904 .849 r
F P
0 g
s
.64037 .68759 m .63113 .68221 L .65778 .66273 L p .671 .757 .915 r
F P
0 g
s
.65778 .66273 m .66948 .66672 L .64037 .68759 L p .671 .757 .915 r
F P
0 g
s
.8463 .49696 m .83347 .50841 L .8329 .45426 L p .86 .892 .857 r
F P
0 g
s
.8329 .45426 m .8464 .44362 L .8463 .49696 L p .86 .892 .857 r
F P
0 g
s
.36831 .26783 m .37903 .26623 L .34655 .29675 L p .751 .969 .93 r
F P
0 g
s
.34655 .29675 m .33366 .30019 L .36831 .26783 L p .751 .969 .93 r
F P
0 g
s
.52741 .3636 m .52702 .38121 L .50887 .36828 L p .513 .465 .74 r
F P
0 g
s
.50887 .36828 m .5056 .34877 L .52741 .3636 L p .513 .465 .74 r
F P
0 g
s
.5331 .44784 m .5291 .4641 L .52549 .45979 L p .526 .446 .708 r
F P
0 g
s
.52549 .45979 m .52587 .43931 L .5331 .44784 L p .526 .446 .708 r
F P
0 g
s
.53845 .53003 m .53177 .50539 L .53474 .50503 L p .528 .448 .709 r
F P
0 g
s
.53712 .43182 m .5331 .44784 L .52587 .43931 L p .524 .448 .712 r
F P
0 g
s
.52587 .43931 m .52626 .41925 L .53712 .43182 L p .524 .448 .712 r
F P
0 g
s
.53981 .45864 m .53244 .46955 L .5291 .4641 L p .527 .446 .708 r
F P
0 g
s
.5291 .4641 m .5331 .44784 L .53981 .45864 L p .527 .446 .708 r
F P
0 g
s
.5278 .34713 m .52741 .3636 L .5056 .34877 L p .505 .474 .756 r
F P
0 g
s
.5056 .34877 m .50231 .33072 L .5278 .34713 L p .505 .474 .756 r
F P
0 g
s
.57842 .65344 m .57182 .63728 L .593 .63473 L p .547 .529 .788 r
F P
0 g
s
.593 .63473 m .60266 .65033 L .57842 .65344 L p .547 .529 .788 r
F P
0 g
s
.53474 .50503 m .5444 .52935 L .53845 .53003 L p .528 .448 .709 r
F P
0 g
s
.5444 .52935 m .53474 .50503 L .53705 .50299 L p .529 .448 .709 r
F P
0 g
s
.54513 .55405 m .53845 .53003 L .5444 .52935 L p .529 .453 .714 r
F P
0 g
s
.48884 .27552 m .49227 .28661 L .45843 .28112 L p .493 .607 .894 r
F P
0 g
s
.45843 .28112 m .45151 .27072 L .48884 .27552 L p .493 .607 .894 r
F P
0 g
s
.54553 .47097 m .53529 .47574 L .53244 .46955 L p .527 .446 .708 r
F P
0 g
s
.53244 .46955 m .53981 .45864 L .54553 .47097 L p .527 .446 .708 r
F P
0 g
s
.54116 .4162 m .53712 .43182 L .52626 .41925 L p .521 .45 .717 r
F P
0 g
s
.52626 .41925 m .52664 .39982 L .54116 .4162 L p .521 .45 .717 r
F P
0 g
s
.53705 .50299 m .54906 .52531 L .5444 .52935 L p .529 .448 .709 r
F P
0 g
s
.54906 .52531 m .53705 .50299 L .53855 .49941 L p .529 .448 .709 r
F P
0 g
s
.57182 .63728 m .56518 .61901 L .5833 .61693 L p .542 .504 .763 r
F P
0 g
s
.5833 .61693 m .593 .63473 L .57182 .63728 L p .542 .504 .763 r
F P
0 g
s
.55182 .57711 m .54513 .55405 L .5541 .55305 L p .531 .46 .721 r
F P
0 g
s
.5444 .52935 m .5541 .55305 L .54513 .55405 L p .529 .453 .714 r
F P
0 g
s
.54987 .48398 m .53744 .48227 L .53529 .47574 L p .528 .447 .708 r
F P
0 g
s
.53529 .47574 m .54553 .47097 L .54987 .48398 L p .528 .447 .708 r
F P
0 g
s
.52819 .33192 m .5278 .34713 L .50231 .33072 L p .495 .485 .775 r
F P
0 g
s
.50231 .33072 m .499 .31427 L .52819 .33192 L p .495 .485 .775 r
F P
0 g
s
.53855 .49941 m .55208 .51818 L .54906 .52531 L p .529 .448 .709 r
F P
0 g
s
.55208 .51818 m .53855 .49941 L .53913 .49453 L p .529 .448 .708 r
F P
0 g
s
.43005 .25209 m .43733 .25624 L .39983 .26895 L p .575 .863 .996 r
F P
0 g
s
.39983 .26895 m .38953 .26656 L .43005 .25209 L p .575 .863 .996 r
F P
0 g
s
.63113 .68221 m .62175 .67418 L .64593 .65615 L p .643 .683 .872 r
F P
0 g
s
.64593 .65615 m .65778 .66273 L .63113 .68221 L p .643 .683 .872 r
F P
0 g
s
.54723 .44781 m .53981 .45864 L .5331 .44784 L p .525 .448 .711 r
F P
0 g
s
.5331 .44784 m .53712 .43182 L .54723 .44781 L p .525 .448 .711 r
F P
0 g
s
.69235 .66721 m .68101 .66818 L .70246 .63242 L p .787 .839 .892 r
F P
0 g
s
.70246 .63242 m .71559 .63019 L .69235 .66721 L p .787 .839 .892 r
F P
0 g
s
.5525 .49677 m .53875 .48868 L .53744 .48227 L p .529 .447 .708 r
F P
0 g
s
.53744 .48227 m .54987 .48398 L .5525 .49677 L p .529 .447 .708 r
F P
0 g
s
.55851 .59886 m .55182 .57711 L .56383 .57578 L p .534 .471 .731 r
F P
0 g
s
.5541 .55305 m .56383 .57578 L .55182 .57711 L p .531 .46 .721 r
F P
0 g
s
.56518 .61901 m .55851 .59886 L .57356 .59718 L p .538 .485 .745 r
F P
0 g
s
.57356 .59718 m .5833 .61693 L .56518 .61901 L p .538 .485 .745 r
F P
0 g
s
.53913 .49453 m .55326 .50844 L .55208 .51818 L p .529 .448 .708 r
F P
0 g
s
.55326 .50844 m .53913 .49453 L .53875 .48868 L p .529 .448 .708 r
F P
0 g
s
.53875 .48868 m .5525 .49677 L .55326 .50844 L p .529 .448 .708 r
F P
0 g
s
.83347 .50841 m .82055 .51993 L .81937 .46494 L p .858 .874 .85 r
F P
0 g
s
.81937 .46494 m .8329 .45426 L .83347 .50841 L p .858 .874 .85 r
F P
0 g
s
.56383 .57578 m .57356 .59718 L .55851 .59886 L p .534 .471 .731 r
F P
0 g
s
.54522 .40111 m .54116 .4162 L .52664 .39982 L p .516 .453 .724 r
F P
0 g
s
.52664 .39982 m .52702 .38121 L .54522 .40111 L p .516 .453 .724 r
F P
0 g
s
.5541 .55305 m .5444 .52935 L .54906 .52531 L p .532 .454 .713 r
F P
0 g
s
.27956 .32919 m .29347 .32011 L .26962 .36745 L p .862 .985 .845 r
F P
0 g
s
.26962 .36745 m .25472 .37755 L .27956 .32919 L p .862 .985 .845 r
F P
0 g
s
.75378 .6119 m .74126 .61971 L .75385 .56985 L p .854 .866 .849 r
F P
0 g
s
.75385 .56985 m .7675 .56172 L .75378 .6119 L p .854 .866 .849 r
F P
0 g
s
.52859 .31808 m .52819 .33192 L .499 .31427 L p .481 .499 .8 r
F P
0 g
s
.499 .31427 m .49565 .29954 L .52859 .31808 L p .481 .499 .8 r
F P
0 g
s
.55585 .46613 m .54553 .47097 L .53981 .45864 L p .527 .448 .71 r
F P
0 g
s
.53981 .45864 m .54723 .44781 L .55585 .46613 L p .527 .448 .71 r
F P
0 g
s
.35736 .27118 m .36831 .26783 L .33366 .30019 L p .729 .987 .891 r
F P
0 g
s
.33366 .30019 m .32052 .30537 L .35736 .27118 L p .729 .987 .891 r
F P
0 g
s
.54931 .38667 m .54522 .40111 L .52702 .38121 L p .509 .457 .734 r
F P
0 g
s
.52702 .38121 m .52741 .3636 L .54931 .38667 L p .509 .457 .734 r
F P
0 g
s
.55469 .43714 m .54723 .44781 L .53712 .43182 L p .523 .449 .715 r
F P
0 g
s
.53712 .43182 m .54116 .4162 L .55469 .43714 L p .523 .449 .715 r
F P
0 g
s
.54906 .52531 m .56113 .54705 L .5541 .55305 L p .532 .454 .713 r
F P
0 g
s
.56113 .54705 m .54906 .52531 L .55208 .51818 L p .534 .454 .712 r
F P
0 g
s
.48536 .2663 m .48884 .27552 L .45151 .27072 L p .468 .655 .942 r
F P
0 g
s
.45151 .27072 m .44448 .26243 L .48536 .2663 L p .468 .655 .942 r
F P
0 g
s
.56383 .57578 m .5541 .55305 L .56113 .54705 L p .537 .463 .72 r
F P
0 g
s
.62175 .67418 m .61225 .66353 L .63395 .64702 L p .618 .624 .834 r
F P
0 g
s
.63395 .64702 m .64593 .65615 L .62175 .67418 L p .618 .624 .834 r
F P
0 g
s
.56239 .48549 m .54987 .48398 L .54553 .47097 L p .529 .449 .709 r
F P
0 g
s
.54553 .47097 m .55585 .46613 L .56239 .48549 L p .529 .449 .709 r
F P
0 g
s
.55208 .51818 m .5657 .53644 L .56113 .54705 L p .534 .454 .712 r
F P
0 g
s
.5657 .53644 m .55208 .51818 L .55326 .50844 L p .534 .454 .711 r
F P
0 g
s
.68101 .66818 m .66948 .66672 L .68915 .63245 L p .75 .772 .871 r
F P
0 g
s
.68915 .63245 m .70246 .63242 L .68101 .66818 L p .75 .772 .871 r
F P
0 g
s
.82055 .51993 m .80751 .53128 L .80578 .47546 L p .851 .854 .843 r
F P
0 g
s
.80578 .47546 m .81937 .46494 L .82055 .51993 L p .851 .854 .843 r
F P
0 g
s
.55343 .37299 m .54931 .38667 L .52741 .3636 L p .5 .462 .746 r
F P
0 g
s
.52741 .3636 m .5278 .34713 L .55343 .37299 L p .5 .462 .746 r
F P
0 g
s
.57356 .59718 m .56383 .57578 L .57325 .56787 L p .544 .475 .729 r
F P
0 g
s
.56113 .54705 m .57325 .56787 L .56383 .57578 L p .537 .463 .72 r
F P
0 g
s
.56636 .50454 m .5525 .49677 L .54987 .48398 L p .532 .451 .71 r
F P
0 g
s
.54987 .48398 m .56239 .48549 L .56636 .50454 L p .532 .451 .71 r
F P
0 g
s
.55326 .50844 m .56749 .52193 L .5657 .53644 L p .534 .454 .711 r
F P
0 g
s
.56749 .52193 m .55326 .50844 L .5525 .49677 L p .534 .453 .71 r
F P
0 g
s
.56219 .42668 m .55469 .43714 L .54116 .4162 L p .519 .451 .72 r
F P
0 g
s
.54116 .4162 m .54522 .40111 L .56219 .42668 L p .519 .451 .72 r
F P
0 g
s
.5525 .49677 m .56636 .50454 L .56749 .52193 L p .534 .453 .71 r
F P
0 g
s
.61225 .66353 m .60266 .65033 L .62189 .63541 L p .596 .578 .803 r
F P
0 g
s
.62189 .63541 m .63395 .64702 L .61225 .66353 L p .596 .578 .803 r
F P
0 g
s
.52899 .30567 m .52859 .31808 L .49565 .29954 L p .461 .517 .83 r
F P
0 g
s
.49565 .29954 m .49227 .28661 L .52899 .30567 L p .461 .517 .83 r
F P
0 g
s
.56625 .46119 m .55585 .46613 L .54723 .44781 L p .526 .45 .713 r
F P
0 g
s
.54723 .44781 m .55469 .43714 L .56625 .46119 L p .526 .45 .713 r
F P
0 g
s
.42261 .24989 m .43005 .25209 L .38953 .26656 L p .524 .896 .966 r
F P
0 g
s
.38953 .26656 m .37903 .26623 L .42261 .24989 L p .524 .896 .966 r
F P
0 g
s
.57325 .56787 m .56113 .54705 L .5657 .53644 L p .541 .464 .718 r
F P
0 g
s
.5833 .61693 m .57356 .59718 L .58541 .58742 L p .553 .492 .741 r
F P
0 g
s
.57325 .56787 m .58541 .58742 L .57356 .59718 L p .544 .475 .729 r
F P
0 g
s
.74126 .61971 m .72853 .62589 L .74003 .57659 L p .828 .824 .844 r
F P
0 g
s
.74003 .57659 m .75385 .56985 L .74126 .61971 L p .828 .824 .844 r
F P
0 g
s
.60266 .65033 m .593 .63473 L .60976 .62146 L p .579 .542 .777 r
F P
0 g
s
.60976 .62146 m .62189 .63541 L .60266 .65033 L p .579 .542 .777 r
F P
0 g
s
.593 .63473 m .5833 .61693 L .59759 .60538 L p .564 .514 .757 r
F P
0 g
s
.58541 .58742 m .59759 .60538 L .5833 .61693 L p .553 .492 .741 r
F P
0 g
s
.59759 .60538 m .60976 .62146 L .593 .63473 L p .564 .514 .757 r
F P
0 g
s
.26539 .33905 m .27956 .32919 L .25472 .37755 L p .856 .993 .834 r
F P
0 g
s
.25472 .37755 m .23961 .38835 L .26539 .33905 L p .856 .993 .834 r
F P
0 g
s
.55758 .36015 m .55343 .37299 L .5278 .34713 L p .489 .467 .76 r
F P
0 g
s
.5278 .34713 m .52819 .33192 L .55758 .36015 L p .489 .467 .76 r
F P
0 g
s
.48181 .25893 m .48536 .2663 L .44448 .26243 L p .421 .704 .981 r
F P
0 g
s
.44448 .26243 m .43733 .25624 L .48181 .25893 L p .421 .704 .981 r
F P
0 g
s
.57501 .48668 m .56239 .48549 L .55585 .46613 L p .532 .453 .712 r
F P
0 g
s
.55585 .46613 m .56625 .46119 L .57501 .48668 L p .532 .453 .712 r
F P
0 g
s
.56975 .41649 m .56219 .42668 L .54522 .40111 L p .514 .454 .727 r
F P
0 g
s
.54522 .40111 m .54931 .38667 L .56975 .41649 L p .514 .454 .727 r
F P
0 g
s
.5657 .53644 m .57941 .55388 L .57325 .56787 L p .541 .464 .718 r
F P
0 g
s
.57941 .55388 m .5657 .53644 L .56749 .52193 L p .542 .463 .715 r
F P
0 g
s
.66948 .66672 m .65778 .66273 L .67568 .63018 L p .712 .71 .847 r
F P
0 g
s
.67568 .63018 m .68915 .63245 L .66948 .66672 L p .712 .71 .847 r
F P
0 g
s
.58541 .58742 m .57325 .56787 L .57941 .55388 L p .55 .477 .725 r
F P
0 g
s
.34617 .2761 m .35736 .27118 L .32052 .30537 L p .694 .982 .838 r
F P
0 g
s
.32052 .30537 m .30713 .31209 L .34617 .2761 L p .694 .982 .838 r
F P
0 g
s
.80751 .53128 m .79433 .54219 L .79211 .48563 L p .84 .83 .837 r
F P
0 g
s
.79211 .48563 m .80578 .47546 L .80751 .53128 L p .84 .83 .837 r
F P
0 g
s
.57671 .45615 m .56625 .46119 L .55469 .43714 L p .526 .453 .717 r
F P
0 g
s
.55469 .43714 m .56219 .42668 L .57671 .45615 L p .526 .453 .717 r
F P
0 g
s
.52939 .29473 m .52899 .30567 L .49227 .28661 L p .432 .539 .865 r
F P
0 g
s
.49227 .28661 m .48884 .27552 L .52939 .29473 L p .432 .539 .865 r
F P
0 g
s
.58033 .5118 m .56636 .50454 L .56239 .48549 L p .537 .456 .712 r
F P
0 g
s
.56239 .48549 m .57501 .48668 L .58033 .5118 L p .537 .456 .712 r
F P
0 g
s
.56749 .52193 m .58183 .53474 L .57941 .55388 L p .542 .463 .715 r
F P
0 g
s
.58183 .53474 m .56749 .52193 L .56636 .50454 L p .541 .46 .713 r
F P
0 g
s
.56636 .50454 m .58033 .5118 L .58183 .53474 L p .541 .46 .713 r
F P
0 g
s
.56176 .34823 m .55758 .36015 L .52819 .33192 L p .474 .474 .778 r
F P
0 g
s
.52819 .33192 m .52859 .31808 L .56176 .34823 L p .474 .474 .778 r
F P
0 g
s
.72853 .62589 m .71559 .63019 L .72605 .58177 L p .798 .78 .836 r
F P
0 g
s
.72605 .58177 m .74003 .57659 L .72853 .62589 L p .798 .78 .836 r
F P
0 g
s
.57737 .40662 m .56975 .41649 L .54931 .38667 L p .508 .457 .736 r
F P
0 g
s
.54931 .38667 m .55343 .37299 L .57737 .40662 L p .508 .457 .736 r
F P
0 g
s
.59759 .60538 m .58541 .58742 L .59317 .57018 L p .563 .493 .735 r
F P
0 g
s
.57941 .55388 m .59317 .57018 L .58541 .58742 L p .55 .477 .725 r
F P
0 g
s
.65778 .66273 m .64593 .65615 L .66209 .62557 L p .677 .656 .822 r
F P
0 g
s
.66209 .62557 m .67568 .63018 L .65778 .66273 L p .677 .656 .822 r
F P
0 g
s
.59317 .57018 m .57941 .55388 L .58183 .53474 L p .552 .474 .721 r
F P
0 g
s
.58771 .48746 m .57501 .48668 L .56625 .46119 L p .535 .458 .715 r
F P
0 g
s
.56625 .46119 m .57671 .45615 L .58771 .48746 L p .535 .458 .715 r
F P
0 g
s
.41502 .24952 m .42261 .24989 L .37903 .26623 L p .441 .878 .878 r
F P
0 g
s
.37903 .26623 m .36831 .26783 L .41502 .24952 L p .441 .878 .878 r
F P
0 g
s
.58725 .45099 m .57671 .45615 L .56219 .42668 L p .525 .457 .722 r
F P
0 g
s
.56219 .42668 m .56975 .41649 L .58725 .45099 L p .525 .457 .722 r
F P
0 g
s
.79433 .54219 m .781 .55242 L .77837 .49527 L p .826 .803 .83 r
F P
0 g
s
.77837 .49527 m .79211 .48563 L .79433 .54219 L p .826 .803 .83 r
F P
0 g
s
.60976 .62146 m .59759 .60538 L .60698 .58505 L p .578 .514 .747 r
F P
0 g
s
.59317 .57018 m .60698 .58505 L .59759 .60538 L p .563 .493 .735 r
F P
0 g
s
.4782 .25335 m .48181 .25893 L .43733 .25624 L p .34 .735 .984 r
F P
0 g
s
.43733 .25624 m .43005 .25209 L .4782 .25335 L p .34 .735 .984 r
F P
0 g
s
.64593 .65615 m .63395 .64702 L .64839 .61865 L p .646 .611 .799 r
F P
0 g
s
.64839 .61865 m .66209 .62557 L .64593 .65615 L p .646 .611 .799 r
F P
0 g
s
.25098 .3494 m .26539 .33905 L .23961 .38835 L p .848 .997 .826 r
F P
0 g
s
.23961 .38835 m .2243 .39957 L .25098 .3494 L p .848 .997 .826 r
F P
0 g
s
.58183 .53474 m .59625 .5466 L .59317 .57018 L p .552 .474 .721 r
F P
0 g
s
.59625 .5466 m .58183 .53474 L .58033 .5118 L p .55 .47 .718 r
F P
0 g
s
.5298 .28528 m .52939 .29473 L .48884 .27552 L p .389 .563 .903 r
F P
0 g
s
.48884 .27552 m .48536 .2663 L .5298 .28528 L p .389 .563 .903 r
F P
0 g
s
.59439 .51836 m .58033 .5118 L .57501 .48668 L p .543 .464 .716 r
F P
0 g
s
.57501 .48668 m .58771 .48746 L .59439 .51836 L p .543 .464 .716 r
F P
0 g
s
.62189 .63541 m .60976 .62146 L .62081 .59823 L p .597 .54 .762 r
F P
0 g
s
.60698 .58505 m .62081 .59823 L .60976 .62146 L p .578 .514 .747 r
F P
0 g
s
.63395 .64702 m .62189 .63541 L .63462 .60949 L p .62 .572 .779 r
F P
0 g
s
.63462 .60949 m .64839 .61865 L .63395 .64702 L p .62 .572 .779 r
F P
0 g
s
.58504 .39711 m .57737 .40662 L .55343 .37299 L p .5 .461 .746 r
F P
0 g
s
.55343 .37299 m .55758 .36015 L .58504 .39711 L p .5 .461 .746 r
F P
0 g
s
.566 .33727 m .56176 .34823 L .52859 .31808 L p .454 .483 .799 r
F P
0 g
s
.52859 .31808 m .52899 .30567 L .566 .33727 L p .454 .483 .799 r
F P
0 g
s
.58033 .5118 m .59439 .51836 L .59625 .5466 L p .55 .47 .718 r
F P
0 g
s
.71559 .63019 m .70246 .63242 L .71193 .58523 L p .766 .735 .824 r
F P
0 g
s
.71193 .58523 m .72605 .58177 L .71559 .63019 L p .766 .735 .824 r
F P
0 g
s
.62081 .59823 m .63462 .60949 L .62189 .63541 L p .597 .54 .762 r
F P
0 g
s
.60698 .58505 m .59317 .57018 L .59625 .5466 L p .565 .489 .728 r
F P
0 g
s
.33473 .28234 m .34617 .2761 L .30713 .31209 L p .654 .963 .78 r
F P
0 g
s
.30713 .31209 m .29347 .32011 L .33473 .28234 L p .654 .963 .78 r
F P
0 g
s
.60051 .48773 m .58771 .48746 L .57671 .45615 L p .538 .463 .719 r
F P
0 g
s
.57671 .45615 m .58725 .45099 L .60051 .48773 L p .538 .463 .719 r
F P
0 g
s
.59786 .44569 m .58725 .45099 L .56975 .41649 L p .523 .461 .728 r
F P
0 g
s
.56975 .41649 m .57737 .40662 L .59786 .44569 L p .523 .461 .728 r
F P
0 g
s
.781 .55242 m .7675 .56172 L .76453 .5042 L p .808 .775 .822 r
F P
0 g
s
.76453 .5042 m .77837 .49527 L .781 .55242 L p .808 .775 .822 r
F P
0 g
s
.70246 .63242 m .68915 .63245 L .69767 .58686 L p .734 .693 .811 r
F P
0 g
s
.69767 .58686 m .71193 .58523 L .70246 .63242 L p .734 .693 .811 r
F P
0 g
s
.59625 .5466 m .61074 .55729 L .60698 .58505 L p .565 .489 .728 r
F P
0 g
s
.61074 .55729 m .59625 .5466 L .59439 .51836 L p .561 .482 .723 r
F P
0 g
s
.62081 .59823 m .60698 .58505 L .61074 .55729 L p .581 .508 .737 r
F P
0 g
s
.60853 .52405 m .59439 .51836 L .58771 .48746 L p .551 .472 .72 r
F P
0 g
s
.58771 .48746 m .60051 .48773 L .60853 .52405 L p .551 .472 .72 r
F P
0 g
s
.59278 .38801 m .58504 .39711 L .55758 .36015 L p .49 .466 .758 r
F P
0 g
s
.55758 .36015 m .56176 .34823 L .59278 .38801 L p .49 .466 .758 r
F P
0 g
s
.59439 .51836 m .60853 .52405 L .61074 .55729 L p .561 .482 .723 r
F P
0 g
s
.57028 .3273 m .566 .33727 L .52899 .30567 L p .428 .493 .824 r
F P
0 g
s
.52899 .30567 m .52939 .29473 L .57028 .3273 L p .428 .493 .824 r
F P
0 g
s
.53022 .2773 m .5298 .28528 L .48536 .2663 L p .326 .585 .937 r
F P
0 g
s
.48536 .2663 m .48181 .25893 L .53022 .2773 L p .326 .585 .937 r
F P
0 g
s
.40725 .25081 m .41502 .24952 L .36831 .26783 L p .347 .819 .756 r
F P
0 g
s
.36831 .26783 m .35736 .27118 L .40725 .25081 L p .347 .819 .756 r
F P
0 g
s
.47452 .24949 m .4782 .25335 L .43005 .25209 L p .224 .719 .916 r
F P
0 g
s
.43005 .25209 m .42261 .24989 L .47452 .24949 L p .224 .719 .916 r
F P
0 g
s
.68915 .63245 m .67568 .63018 L .68331 .58658 L p .703 .653 .797 r
F P
0 g
s
.68331 .58658 m .69767 .58686 L .68915 .63245 L p .703 .653 .797 r
F P
0 g
s
.63462 .60949 m .62081 .59823 L .62526 .56657 L p .6 .529 .747 r
F P
0 g
s
.61074 .55729 m .62526 .56657 L .62081 .59823 L p .581 .508 .737 r
F P
0 g
s
.61338 .48741 m .60051 .48773 L .58725 .45099 L p .542 .47 .724 r
F P
0 g
s
.58725 .45099 m .59786 .44569 L .61338 .48741 L p .542 .47 .724 r
F P
0 g
s
.60855 .44025 m .59786 .44569 L .57737 .40662 L p .522 .466 .735 r
F P
0 g
s
.57737 .40662 m .58504 .39711 L .60855 .44025 L p .522 .466 .735 r
F P
0 g
s
.7675 .56172 m .75385 .56985 L .75061 .51225 L p .788 .746 .815 r
F P
0 g
s
.75061 .51225 m .76453 .5042 L .7675 .56172 L p .788 .746 .815 r
F P
0 g
s
.23636 .35991 m .25098 .3494 L .2243 .39957 L p .839 .998 .824 r
F P
0 g
s
.2243 .39957 m .20881 .41093 L .23636 .35991 L p .839 .998 .824 r
F P
0 g
s
.62526 .56657 m .61074 .55729 L .60853 .52405 L p .575 .496 .729 r
F P
0 g
s
.64839 .61865 m .63462 .60949 L .63981 .57427 L p .622 .554 .758 r
F P
0 g
s
.62526 .56657 m .63981 .57427 L .63462 .60949 L p .6 .529 .747 r
F P
0 g
s
.67568 .63018 m .66209 .62557 L .66886 .58437 L p .673 .616 .783 r
F P
0 g
s
.66886 .58437 m .68331 .58658 L .67568 .63018 L p .673 .616 .783 r
F P
0 g
s
.66209 .62557 m .64839 .61865 L .65436 .58024 L p .646 .583 .77 r
F P
0 g
s
.63981 .57427 m .65436 .58024 L .64839 .61865 L p .622 .554 .758 r
F P
0 g
s
.65436 .58024 m .66886 .58437 L .66209 .62557 L p .646 .583 .77 r
F P
0 g
s
.60059 .37933 m .59278 .38801 L .56176 .34823 L p .479 .472 .772 r
F P
0 g
s
.56176 .34823 m .566 .33727 L .60059 .37933 L p .479 .472 .772 r
F P
0 g
s
.62274 .52872 m .60853 .52405 L .60051 .48773 L p .561 .483 .724 r
F P
0 g
s
.60051 .48773 m .61338 .48741 L .62274 .52872 L p .561 .483 .724 r
F P
0 g
s
.60853 .52405 m .62274 .52872 L .62526 .56657 L p .575 .496 .729 r
F P
0 g
s
.75385 .56985 m .74003 .57659 L .73661 .51928 L p .765 .716 .806 r
F P
0 g
s
.73661 .51928 m .75061 .51225 L .75385 .56985 L p .765 .716 .806 r
F P
0 g
s
.32304 .28967 m .33473 .28234 L .29347 .32011 L p .617 .939 .73 r
F P
0 g
s
.29347 .32011 m .27956 .32919 L .32304 .28967 L p .617 .939 .73 r
F P
0 g
s
.57462 .31835 m .57028 .3273 L .52939 .29473 L p .395 .504 .852 r
F P
0 g
s
.52939 .29473 m .5298 .28528 L .57462 .31835 L p .395 .504 .852 r
F P
0 g
s
.63981 .57427 m .62526 .56657 L .62274 .52872 L p .59 .513 .736 r
F P
0 g
s
.6193 .43464 m .60855 .44025 L .58504 .39711 L p .52 .472 .744 r
F P
0 g
s
.58504 .39711 m .59278 .38801 L .6193 .43464 L p .52 .472 .744 r
F P
0 g
s
.62631 .48642 m .61338 .48741 L .59786 .44569 L p .547 .478 .73 r
F P
0 g
s
.59786 .44569 m .60855 .44025 L .62631 .48642 L p .547 .478 .73 r
F P
0 g
s
.53065 .27075 m .53022 .2773 L .48181 .25893 L p .235 .596 .95 r
F P
0 g
s
.48181 .25893 m .4782 .25335 L .53065 .27075 L p .235 .596 .95 r
F P
0 g
s
.74003 .57659 m .72605 .58177 L .72252 .52516 L p .742 .686 .797 r
F P
0 g
s
.72252 .52516 m .73661 .51928 L .74003 .57659 L p .742 .686 .797 r
F P
0 g
s
.62274 .52872 m .637 .53223 L .63981 .57427 L p .59 .513 .736 r
F P
0 g
s
.637 .53223 m .62274 .52872 L .61338 .48741 L p .571 .495 .73 r
F P
0 g
s
.61338 .48741 m .62631 .48642 L .637 .53223 L p .571 .495 .73 r
F P
0 g
s
.85986 .43317 m .8464 .44362 L .82337 .38995 L p .781 .814 .878 r
F P
0 g
s
.82337 .38995 m .8366 .38074 L .85986 .43317 L p .781 .814 .878 r
F P
0 g
s
.65436 .58024 m .63981 .57427 L .637 .53223 L p .608 .532 .743 r
F P
0 g
s
.60847 .37109 m .60059 .37933 L .566 .33727 L p .465 .479 .789 r
F P
0 g
s
.566 .33727 m .57028 .3273 L .60847 .37109 L p .465 .479 .789 r
F P
0 g
s
.22154 .37026 m .23636 .35991 L .20881 .41093 L p .831 .999 .827 r
F P
0 g
s
.20881 .41093 m .19318 .42214 L .22154 .37026 L p .831 .999 .827 r
F P
0 g
s
.47076 .24722 m .47452 .24949 L .42261 .24989 L p .095 .652 .781 r
F P
0 g
s
.42261 .24989 m .41872 .2497 L p .47076 .24722 L .095 .652 .781 r
F P
0 g
s
.43164 .24883 m .47076 .24722 L p .41872 .2497 L .095 .652 .781 r
F P
0 g
s
.46691 .24641 m .47076 .24722 L .41502 .24952 L p .013 0 0 r
F P
0 g
s
.46298 .24688 m .4659 .24653 L p .40725 .25081 L .088 0 0 r
F P
0 g
s
.4659 .24653 m .46691 .24641 L .45877 .24701 L p .088 0 0 r
F P
0 g
s
.45877 .24701 m .40725 .25081 L p .4659 .24653 L .088 0 0 r
F P
0 g
s
.41872 .2497 m .41502 .24952 L .43164 .24883 L p .095 .652 .781 r
F P
0 g
s
.3993 .25357 m .40725 .25081 L .35736 .27118 L p 0 0 0 r
F P
0 g
s
.35736 .27118 m .34617 .2761 L .3993 .25357 L p 0 0 0 r
F P
0 g
s
.72605 .58177 m .71193 .58523 L .70836 .52977 L p .718 .656 .788 r
F P
0 g
s
.70836 .52977 m .72252 .52516 L .72605 .58177 L p .718 .656 .788 r
F P
0 g
s
.8464 .44362 m .8329 .45426 L .81017 .39925 L p .778 .796 .867 r
F P
0 g
s
.81017 .39925 m .82337 .38995 L .8464 .44362 L p .778 .796 .867 r
F P
0 g
s
.63931 .48471 m .62631 .48642 L .60855 .44025 L p .553 .487 .736 r
F P
0 g
s
.60855 .44025 m .6193 .43464 L .63931 .48471 L p .553 .487 .736 r
F P
0 g
s
.66886 .58437 m .65436 .58024 L .65128 .53448 L p .627 .553 .751 r
F P
0 g
s
.637 .53223 m .65128 .53448 L .65436 .58024 L p .608 .532 .743 r
F P
0 g
s
.63013 .42888 m .6193 .43464 L .59278 .38801 L p .518 .479 .753 r
F P
0 g
s
.59278 .38801 m .60059 .37933 L .63013 .42888 L p .518 .479 .753 r
F P
0 g
s
.71193 .58523 m .69767 .58686 L .69414 .53304 L p .694 .628 .778 r
F P
0 g
s
.69414 .53304 m .70836 .52977 L .71193 .58523 L p .694 .628 .778 r
F P
0 g
s
.57901 .31038 m .57462 .31835 L .5298 .28528 L p .351 .515 .88 r
F P
0 g
s
.5298 .28528 m .53022 .2773 L .57901 .31038 L p .351 .515 .88 r
F P
0 g
s
.65128 .53448 m .637 .53223 L .62631 .48642 L p .584 .508 .736 r
F P
0 g
s
.68331 .58658 m .66886 .58437 L .66558 .5354 L p .648 .576 .76 r
F P
0 g
s
.65128 .53448 m .66558 .5354 L .66886 .58437 L p .627 .553 .751 r
F P
0 g
s
.8329 .45426 m .81937 .46494 L .79699 .40853 L p .772 .777 .856 r
F P
0 g
s
.79699 .40853 m .81017 .39925 L .8329 .45426 L p .772 .777 .856 r
F P
0 g
s
.69767 .58686 m .68331 .58658 L .67987 .53492 L p .67 .601 .769 r
F P
0 g
s
.67987 .53492 m .69414 .53304 L .69767 .58686 L p .67 .601 .769 r
F P
0 g
s
.62631 .48642 m .63931 .48471 L .65128 .53448 L p .584 .508 .736 r
F P
0 g
s
.66558 .5354 m .67987 .53492 L .68331 .58658 L p .648 .576 .76 r
F P
0 g
s
.81937 .46494 m .80578 .47546 L .78382 .41768 L p .763 .756 .846 r
F P
0 g
s
.78382 .41768 m .79699 .40853 L .81937 .46494 L p .763 .756 .846 r
F P
0 g
s
.61643 .36329 m .60847 .37109 L .57028 .3273 L p .448 .488 .807 r
F P
0 g
s
.57028 .3273 m .57462 .31835 L .61643 .36329 L p .448 .488 .807 r
F P
0 g
s
.31111 .29778 m .32304 .28967 L .27956 .32919 L p .588 .919 .693 r
F P
0 g
s
.27956 .32919 m .26539 .33905 L .31111 .29778 L p .588 .919 .693 r
F P
0 g
s
.53108 .26557 m .53065 .27075 L .4782 .25335 L p .116 .581 .917 r
F P
0 g
s
.4782 .25335 m .47452 .24949 L .53108 .26557 L p .116 .581 .917 r
F P
0 g
s
.66558 .5354 m .65128 .53448 L .63931 .48471 L p .597 .523 .743 r
F P
0 g
s
.65236 .48224 m .63931 .48471 L .6193 .43464 L p .559 .498 .743 r
F P
0 g
s
.6193 .43464 m .63013 .42888 L .65236 .48224 L p .559 .498 .743 r
F P
0 g
s
.64103 .42294 m .63013 .42888 L .60059 .37933 L p .516 .488 .764 r
F P
0 g
s
.60059 .37933 m .60847 .37109 L .64103 .42294 L p .516 .488 .764 r
F P
0 g
s
.80578 .47546 m .79211 .48563 L .77066 .4266 L p .752 .733 .835 r
F P
0 g
s
.77066 .4266 m .78382 .41768 L .80578 .47546 L p .752 .733 .835 r
F P
0 g
s
.63931 .48471 m .65236 .48224 L .66558 .5354 L p .597 .523 .743 r
F P
0 g
s
.67987 .53492 m .66558 .5354 L .65236 .48224 L p .611 .54 .75 r
F P
0 g
s
.41502 .24952 m .40725 .25081 L .46691 .24641 L p .013 0 0 r
F P
0 g
s
.79211 .48563 m .77837 .49527 L .7575 .43519 L p .739 .711 .824 r
F P
0 g
s
.7575 .43519 m .77066 .4266 L .79211 .48563 L p .739 .711 .824 r
F P
0 g
s
.58348 .30339 m .57901 .31038 L .53022 .2773 L p .293 .525 .905 r
F P
0 g
s
.53022 .2773 m .53065 .27075 L .58348 .30339 L p .293 .525 .905 r
F P
0 g
s
.39116 .25758 m .3993 .25357 L .34617 .2761 L p 0 0 0 r
F P
0 g
s
.34617 .2761 m .33473 .28234 L .39116 .25758 L p 0 0 0 r
F P
0 g
s
.66544 .47897 m .65236 .48224 L .63013 .42888 L p .566 .51 .751 r
F P
0 g
s
.63013 .42888 m .64103 .42294 L .66544 .47897 L p .566 .51 .751 r
F P
0 g
s
.69414 .53304 m .67987 .53492 L .66544 .47897 L p .627 .558 .758 r
F P
0 g
s
.65236 .48224 m .66544 .47897 L .67987 .53492 L p .611 .54 .75 r
F P
0 g
s
.77837 .49527 m .76453 .5042 L .74434 .44335 L p .725 .687 .814 r
F P
0 g
s
.74434 .44335 m .7575 .43519 L .77837 .49527 L p .725 .687 .814 r
F P
0 g
s
.62447 .35593 m .61643 .36329 L .57462 .31835 L p .429 .497 .828 r
F P
0 g
s
.57462 .31835 m .57901 .31038 L .62447 .35593 L p .429 .497 .828 r
F P
0 g
s
.65199 .41683 m .64103 .42294 L .60847 .37109 L p .513 .498 .777 r
F P
0 g
s
.60847 .37109 m .61643 .36329 L .65199 .41683 L p .513 .498 .777 r
F P
0 g
s
.76453 .5042 m .75061 .51225 L .73118 .45099 L p .709 .664 .804 r
F P
0 g
s
.73118 .45099 m .74434 .44335 L .76453 .5042 L p .709 .664 .804 r
F P
0 g
s
.70836 .52977 m .69414 .53304 L .67856 .4749 L p .643 .577 .766 r
F P
0 g
s
.66544 .47897 m .67856 .4749 L .69414 .53304 L p .627 .558 .758 r
F P
0 g
s
.75061 .51225 m .73661 .51928 L .71802 .45803 L p .693 .641 .794 r
F P
0 g
s
.71802 .45803 m .73118 .45099 L .75061 .51225 L p .693 .641 .794 r
F P
0 g
s
.72252 .52516 m .70836 .52977 L .6917 .47003 L p .659 .598 .775 r
F P
0 g
s
.67856 .4749 m .6917 .47003 L .70836 .52977 L p .643 .577 .766 r
F P
0 g
s
.73661 .51928 m .72252 .52516 L .70485 .46439 L p .676 .619 .784 r
F P
0 g
s
.70485 .46439 m .71802 .45803 L .73661 .51928 L p .676 .619 .784 r
F P
0 g
s
.6917 .47003 m .70485 .46439 L .72252 .52516 L p .659 .598 .775 r
F P
0 g
s
.67856 .4749 m .66544 .47897 L .64103 .42294 L p .574 .523 .76 r
F P
0 g
s
.53152 .26165 m .53108 .26557 L .47452 .24949 L p 0 .533 .828 r
F P
0 g
s
.47452 .24949 m .47076 .24722 L .53152 .26165 L p 0 .533 .828 r
F P
0 g
s
.64103 .42294 m .65199 .41683 L .67856 .4749 L p .574 .523 .76 r
F P
0 g
s
.29895 .30638 m .31111 .29778 L .26539 .33905 L p .571 .906 .672 r
F P
0 g
s
.26539 .33905 m .25098 .3494 L .29895 .30638 L p .571 .906 .672 r
F P
0 g
s
.66303 .41055 m .65199 .41683 L .61643 .36329 L p .511 .509 .791 r
F P
0 g
s
.61643 .36329 m .62447 .35593 L .66303 .41055 L p .511 .509 .791 r
F P
0 g
s
.58801 .29731 m .58348 .30339 L .53065 .27075 L p .222 .529 .92 r
F P
0 g
s
.53065 .27075 m .53108 .26557 L .58801 .29731 L p .222 .529 .92 r
F P
0 g
s
.6917 .47003 m .67856 .4749 L .65199 .41683 L p .582 .538 .77 r
F P
0 g
s
.6326 .34899 m .62447 .35593 L .57901 .31038 L p .407 .508 .85 r
F P
0 g
s
.57901 .31038 m .58348 .30339 L .6326 .34899 L p .407 .508 .85 r
F P
0 g
s
.40725 .25081 m .3993 .25357 L .46298 .24688 L p .088 0 0 r
F P
0 g
s
.65199 .41683 m .66303 .41055 L .6917 .47003 L p .582 .538 .77 r
F P
0 g
s
.38284 .2626 m .39116 .25758 L .33473 .28234 L p 0 0 0 r
F P
0 g
s
.33473 .28234 m .32304 .28967 L .38284 .2626 L p 0 0 0 r
F P
0 g
s
.70485 .46439 m .6917 .47003 L .66303 .41055 L p .591 .553 .781 r
F P
0 g
s
.71802 .45803 m .70485 .46439 L .67413 .4041 L p .6 .571 .793 r
F P
0 g
s
.66303 .41055 m .67413 .4041 L .70485 .46439 L p .591 .553 .781 r
F P
0 g
s
.67413 .4041 m .66303 .41055 L .62447 .35593 L p .509 .522 .806 r
F P
0 g
s
.62447 .35593 m .6326 .34899 L .67413 .4041 L p .509 .522 .806 r
F P
0 g
s
.53197 .25888 m .53152 .26165 L .47076 .24722 L p 0 .465 .703 r
F P
0 g
s
.47076 .24722 m .46691 .24641 L .53197 .25888 L p 0 .465 .703 r
F P
0 g
s
.27399 .32374 m .28657 .31514 L .23636 .35991 L p .57 .909 .681 r
F P
0 g
s
.28657 .31514 m .27399 .32374 L .27486 .32332 L p 0 0 0 r
F P
0 g
s
.2983 .30696 m .25098 .3494 L p .28657 .31514 L .565 .903 .669 r
F P
0 g
s
.25098 .3494 m .23636 .35991 L .28657 .31514 L p .565 .903 .669 r
F P
0 g
s
.27486 .32332 m .34782 .287 L p .28657 .31514 L 0 0 0 r
F P
0 g
s
.28657 .31514 m .29895 .30638 L .2983 .30696 L p .565 .903 .669 r
F P
0 g
s
.73118 .45099 m .71802 .45803 L .6853 .39749 L p .61 .589 .805 r
F P
0 g
s
.67413 .4041 m .6853 .39749 L .71802 .45803 L p .6 .571 .793 r
F P
0 g
s
.64082 .34245 m .6326 .34899 L .58348 .30339 L p .381 .521 .873 r
F P
0 g
s
.58348 .30339 m .58801 .29731 L .64082 .34245 L p .381 .521 .873 r
F P
0 g
s
.59261 .29208 m .58801 .29731 L .53108 .26557 L p .137 .524 .917 r
F P
0 g
s
.53108 .26557 m .53152 .26165 L .59261 .29208 L p .137 .524 .917 r
F P
0 g
s
.74434 .44335 m .73118 .45099 L .69655 .39073 L p .62 .609 .818 r
F P
0 g
s
.6853 .39749 m .69655 .39073 L .73118 .45099 L p .61 .589 .805 r
F P
0 g
s
.6853 .39749 m .67413 .4041 L .6326 .34899 L p .507 .537 .822 r
F P
0 g
s
.7575 .43519 m .74434 .44335 L .70785 .38383 L p .63 .63 .831 r
F P
0 g
s
.69655 .39073 m .70785 .38383 L .74434 .44335 L p .62 .609 .818 r
F P
0 g
s
.6326 .34899 m .64082 .34245 L .6853 .39749 L p .507 .537 .822 r
F P
0 g
s
.45896 .24843 m .46298 .24688 L .3993 .25357 L p .134 0 0 r
F P
0 g
s
.3993 .25357 m .39116 .25758 L .45896 .24843 L p .134 0 0 r
F P
0 g
s
.77066 .4266 m .7575 .43519 L .71923 .37679 L p .64 .651 .845 r
F P
0 g
s
.70785 .38383 m .71923 .37679 L .7575 .43519 L p .63 .63 .831 r
F P
0 g
s
.37434 .26835 m .38284 .2626 L .32304 .28967 L p 0 0 0 r
F P
0 g
s
.32304 .28967 m .31111 .29778 L .37434 .26835 L p 0 0 0 r
F P
0 g
s
.78382 .41768 m .77066 .4266 L .73068 .36964 L p .65 .673 .859 r
F P
0 g
s
.71923 .37679 m .73068 .36964 L .77066 .4266 L p .64 .651 .845 r
F P
0 g
s
.69655 .39073 m .6853 .39749 L .64082 .34245 L p .505 .554 .84 r
F P
0 g
s
.79699 .40853 m .78382 .41768 L .7422 .3624 L p .659 .695 .873 r
F P
0 g
s
.73068 .36964 m .7422 .3624 L .78382 .41768 L p .65 .673 .859 r
F P
0 g
s
.64913 .33628 m .64082 .34245 L .58801 .29731 L p .352 .534 .895 r
F P
0 g
s
.58801 .29731 m .59261 .29208 L .64913 .33628 L p .352 .534 .895 r
F P
0 g
s
.81017 .39925 m .79699 .40853 L .75379 .35506 L p .667 .717 .886 r
F P
0 g
s
.7422 .3624 m .75379 .35506 L .79699 .40853 L p .659 .695 .873 r
F P
0 g
s
.53243 .25711 m .53197 .25888 L .46691 .24641 L p .205 0 0 r
F P
0 g
s
.46691 .24641 m .46298 .24688 L .53243 .25711 L p .205 0 0 r
F P
0 g
s
.23636 .35991 m .22154 .37026 L .27399 .32374 L p .57 .909 .681 r
F P
0 g
s
.59729 .28761 m .59261 .29208 L .53152 .26165 L p .047 .508 .889 r
F P
0 g
s
.53152 .26165 m .53197 .25888 L .59729 .28761 L p .047 .508 .889 r
F P
0 g
s
.82337 .38995 m .81017 .39925 L .76545 .34767 L p .674 .738 .899 r
F P
0 g
s
.75379 .35506 m .76545 .34767 L .81017 .39925 L p .667 .717 .886 r
F P
0 g
s
.64082 .34245 m .64913 .33628 L .69655 .39073 L p .505 .554 .84 r
F P
0 g
s
.8366 .38074 m .82337 .38995 L .77719 .34022 L p .68 .758 .91 r
F P
0 g
s
.76545 .34767 m .77719 .34022 L .82337 .38995 L p .674 .738 .899 r
F P
0 g
s
.70785 .38383 m .69655 .39073 L .64913 .33628 L p .503 .573 .858 r
F P
0 g
s
.77719 .34022 m .78901 .33274 L .8366 .38074 L p .68 .758 .91 r
F P
0 g
s
.45485 .25084 m .45896 .24843 L .39116 .25758 L p .157 0 0 r
F P
0 g
s
.39116 .25758 m .38284 .2626 L .45485 .25084 L p .157 0 0 r
F P
0 g
s
.65755 .33043 m .64913 .33628 L .59261 .29208 L p .321 .548 .915 r
F P
0 g
s
.59261 .29208 m .59729 .28761 L .65755 .33043 L p .321 .548 .915 r
F P
0 g
s
.71923 .37679 m .70785 .38383 L .65755 .33043 L p .503 .593 .877 r
F P
0 g
s
.64913 .33628 m .65755 .33043 L .70785 .38383 L p .503 .573 .858 r
F P
0 g
s
.36566 .27454 m .37434 .26835 L .31111 .29778 L p 0 0 0 r
F P
0 g
s
.31111 .29778 m .29895 .30638 L .36566 .27454 L p 0 0 0 r
F P
0 g
s
.60205 .2838 m .59729 .28761 L .53197 .25888 L p 0 .483 .839 r
F P
0 g
s
.53197 .25888 m .53243 .25711 L .60205 .2838 L p 0 .483 .839 r
F P
0 g
s
.5329 .25618 m .53243 .25711 L .46298 .24688 L p .254 0 0 r
F P
0 g
s
.46298 .24688 m .45896 .24843 L .5329 .25618 L p .254 0 0 r
F P
0 g
s
.73068 .36964 m .71923 .37679 L .66606 .32485 L p .503 .615 .896 r
F P
0 g
s
.65755 .33043 m .66606 .32485 L .71923 .37679 L p .503 .593 .877 r
F P
0 g
s
.66606 .32485 m .65755 .33043 L .59729 .28761 L p .289 .563 .931 r
F P
0 g
s
.59729 .28761 m .60205 .2838 L .66606 .32485 L p .289 .563 .931 r
F P
0 g
s
.7422 .3624 m .73068 .36964 L .67467 .31949 L p .505 .638 .914 r
F P
0 g
s
.66606 .32485 m .67467 .31949 L .73068 .36964 L p .503 .615 .896 r
F P
0 g
s
.45065 .25386 m .45485 .25084 L .38284 .2626 L p .163 0 0 r
F P
0 g
s
.38284 .2626 m .37434 .26835 L .45065 .25386 L p .163 0 0 r
F P
0 g
s
.75379 .35506 m .7422 .3624 L .68339 .31428 L p .508 .662 .93 r
F P
0 g
s
.67467 .31949 m .68339 .31428 L .7422 .3624 L p .505 .638 .914 r
F P
0 g
s
.35682 .28087 m .36566 .27454 L .29895 .30638 L p 0 0 0 r
F P
0 g
s
.29895 .30638 m .28657 .31514 L .35682 .28087 L p 0 0 0 r
F P
0 g
s
.60689 .28053 m .60205 .2838 L .53243 .25711 L p 0 .457 .779 r
F P
0 g
s
.53243 .25711 m .5329 .25618 L .60689 .28053 L p 0 .457 .779 r
F P
0 g
s
.67467 .31949 m .66606 .32485 L .60205 .2838 L p .26 .578 .942 r
F P
0 g
s
.53338 .2559 m .5329 .25618 L .45896 .24843 L p .277 0 0 r
F P
0 g
s
.45896 .24843 m .45485 .25084 L .53338 .2559 L p .277 0 0 r
F P
0 g
s
.76545 .34767 m .75379 .35506 L .69221 .30916 L p .513 .686 .945 r
F P
0 g
s
.68339 .31428 m .69221 .30916 L .75379 .35506 L p .508 .662 .93 r
F P
0 g
s
.60205 .2838 m .60689 .28053 L .67467 .31949 L p .26 .578 .942 r
F P
0 g
s
.68339 .31428 m .67467 .31949 L .60689 .28053 L p .236 .593 .949 r
F P
0 g
s
.77719 .34022 m .76545 .34767 L .70113 .30406 L p .52 .71 .958 r
F P
0 g
s
.69221 .30916 m .70113 .30406 L .76545 .34767 L p .513 .686 .945 r
F P
0 g
s
.44636 .25723 m .45065 .25386 L .37434 .26835 L p .155 0 0 r
F P
0 g
s
.37434 .26835 m .36566 .27454 L .44636 .25723 L p .155 0 0 r
F P
0 g
s
.61181 .27767 m .60689 .28053 L .5329 .25618 L p 0 .437 .724 r
F P
0 g
s
.5329 .25618 m .53338 .2559 L .61181 .27767 L p 0 .437 .724 r
F P
0 g
s
.34782 .287 m .35682 .28087 L .28657 .31514 L p 0 0 0 r
F P
0 g
s
.78901 .33274 m .77719 .34022 L .71015 .2989 L p .53 .733 .967 r
F P
0 g
s
.70113 .30406 m .71015 .2989 L .77719 .34022 L p .52 .71 .958 r
F P
0 g
s
.60689 .28053 m .61181 .27767 L .68339 .31428 L p .236 .593 .949 r
F P
0 g
s
.53387 .25608 m .53338 .2559 L .45485 .25084 L p .282 0 0 r
F P
0 g
s
.45485 .25084 m .45065 .25386 L .53387 .25608 L p .282 0 0 r
F P
0 g
s
.69221 .30916 m .68339 .31428 L .61181 .27767 L p .221 .61 .952 r
F P
0 g
s
.71015 .2989 m .71927 .29362 L .78901 .33274 L p .53 .733 .967 r
F P
0 g
s
.70113 .30406 m .69221 .30916 L .61681 .27508 L p .218 .63 .954 r
F P
0 g
s
.61181 .27767 m .61681 .27508 L .69221 .30916 L p .221 .61 .952 r
F P
0 g
s
.61681 .27508 m .61181 .27767 L .53338 .2559 L p .165 0 0 r
F P
0 g
s
.53338 .2559 m .53387 .25608 L .61681 .27508 L p .165 0 0 r
F P
0 g
s
.44199 .26068 m .44636 .25723 L .36566 .27454 L p .132 0 0 r
F P
0 g
s
.36566 .27454 m .35682 .28087 L .44199 .26068 L p .132 0 0 r
F P
0 g
s
.53436 .25649 m .53387 .25608 L .45065 .25386 L p .27 0 0 r
F P
0 g
s
.45065 .25386 m .44636 .25723 L .53436 .25649 L p .27 0 0 r
F P
0 g
s
.71015 .2989 m .70113 .30406 L .62188 .27262 L p .228 .654 .957 r
F P
0 g
s
.61681 .27508 m .62188 .27262 L .70113 .30406 L p .218 .63 .954 r
F P
0 g
s
.62188 .27262 m .61681 .27508 L .53387 .25608 L p .162 0 0 r
F P
0 g
s
.53387 .25608 m .53436 .25649 L .62188 .27262 L p .162 0 0 r
F P
0 g
s
.43754 .26392 m .44199 .26068 L .35682 .28087 L p .095 0 0 r
F P
0 g
s
.35682 .28087 m .34782 .287 L .43754 .26392 L p .095 0 0 r
F P
0 g
s
.71927 .29362 m .71015 .2989 L .62704 .27012 L p .252 .681 .963 r
F P
0 g
s
.62188 .27262 m .62704 .27012 L .71015 .2989 L p .228 .654 .957 r
F P
0 g
s
.53487 .25692 m .53436 .25649 L .44636 .25723 L p .243 0 0 r
F P
0 g
s
.44636 .25723 m .44199 .26068 L .53487 .25692 L p .243 0 0 r
F P
0 g
s
.62704 .27012 m .62188 .27262 L .53436 .25649 L p .137 0 0 r
F P
0 g
s
.62704 .27012 m .63227 .26744 L .71927 .29362 L p .252 .681 .963 r
F P
0 g
s
.53436 .25649 m .53487 .25692 L .62704 .27012 L p .137 0 0 r
F P
0 g
s
.53539 .25714 m .53487 .25692 L .44199 .26068 L p .2 0 0 r
F P
0 g
s
.44199 .26068 m .43754 .26392 L .53539 .25714 L p .2 0 0 r
F P
0 g
s
.63227 .26744 m .62704 .27012 L .53487 .25692 L p .092 0 0 r
F P
0 g
s
.53487 .25692 m .53539 .25714 L .63227 .26744 L p .092 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000O?oo
ool9o`0004Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`00<Oooool2
o`0007;ooooo6ol00014ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool0
02kooooo0ol000000ooooooo0000ooooo`1^ooooobCo0000?_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo037ooooo000]ooooo`;o00001?ooool00ol0003oooooooooo`1Zooooob_o
0000>Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo000]ooooo`03o`00
0?oooooo000006gooooo1_l00002obP000Go000000?o:@00o`000?l000009ol0000`ooooo`03o`00
0?oooooooooo02gooooo0ol0000aooooo`00;Oooool01?l0003oooooooooool0001Zooooo`?o0000
00?o:000o`000?l000001?l000000olY003o0000o`00000Qo`0000?o08SC0_l000001?l<P^?o0000
o`000?lY000=o`0002Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`00
;Oooool01Ol0003ooooooooooooooooo000006Kooooo1ol00002obT001Oo00001?m[]?/01?l0003o
DiG_o`000?l00005ocbHl`;o00000_lMU>X3o`000003o`28dol0003o8hKZ00;o38;S6Ol0000Joooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool002cooooo0ol00003ooooo`03
o`000?oooooooooo067ooooo1Ol000000olY003o0000o`00000@o`0000?oV;W_00?o0000ogNWlOmg
Yo401?mgYo46o`0000?oDiG_0ol00004ocbHl`?o000000?o7ICZo`000?lSQ^X00olSQ^X00ol0003o
38;So`00000Eo`000003oaL00?l0003o000000Go00004oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02kooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
G_ooool8o`000003obL00?l0003o000000_o00001onH^Nl2o`0000[oMjOa00?o0000of>@iol00000
1?mCUNl2o`0000Go?9Sc0_l000000olhQn_o8hKZob>6jP03ob>6jP03o`000?l<P^?o000000co0000
00?o:@00o`000?l000000ol000000olS003o0000o`000002o`0000Co@:kf0ol0000@ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1JoooooaKo00001onH^Nl3o`000003oiJYhol0003oOY_T00;oOY_T1ol0
00000omgYo7o0000of>@i`02of>@i`;o00000_mCUNl3o`0000?o?9Sc00Go0000od^6iolhQn_o>8O[
o`000004ob>6jP03o`000?l<P^?o000000[o000000?o:P00o`000?l000001_l00003ocZWm003o`00
0?m0[_Ko@:kf00?o@:kf0ol0000=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
;?ooool002cooooo0ol00006ooooo`03o`000?oooooooooo05Oooooo2Ol000000olQ003o0000o`00
0006o`0000;o]/cZ00Co0000ojnkhon_^n?o00001OnH^Nl2o`0000GoUZWS00?o0000ogjKi?mnVn@0
1omnVn@3o`0000CoHi3W0ol00002oe>Ek`Co00000_m;Q^L00ol0003o>8O[ocR7j`02o`0000?o8hKZ
0_l000000ol<P^?o0000o`00000:o`0000;o:P000_l00002ocNQm003o`000?ljYoCo>ZOd00;o>ZOd
0_l00004od2^mP?o00002_ooool00ol0003oooooooooo`0booooo`;o0000;Oooool002cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Doooooa3o000000?o_Mg`o`000?nfc>X00_nf
c>X00ol0003o[k_Sojnkh`02ojnkh`03o`000?nH^NooV;W_00;o00002?nFZN<00ol0003oOY_TogjK
i008ogjKi003o`000?m^RMgo000000GoHi3W0_l00003oe>Ek`03o`000?m;Q^OoBhKW00;oBhKW00?o
0000ocR7jolhQn/00_l00003ob>6jP;o000000Co38;So`000?l0003o07_F0_l000001Ol0M<Oo0000
o`000?l0003o06ni00;o00000olhW?<01Ol0003o=j7docNQm?lgXOCo000000Co>ZOd0_l00004od2^
mP?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo000Aooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0DOooool:o`000004oaP00?l0003o
0000o`0000Co_Mg`00Go0000okK<j_nfc>[o]/cZo`000005ojnkh`?o00002OnFZN<3o`0000;oOY_T
00?o0000ogjKi?mnVn@01?mnVn@01?l0003oKXWMofj9gOm^RMd2o`0000CoHi3W1?l000000omIPn7o
BhKWod^6i`03od^6i`04o`000?lhQn_o>8O[o`0000Co8hKZ0_l000001?l<P^?o0000o`000?l0NmH3
o`000003o`1daol0003o?9Ob00;o?9Ob1?lhW?<2o`0000?o=j7d00Co0000ocZWm?ljYoCo>ZOd0ol0
0004od2^mP?o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo3?l000000oo1kO;o0000okgM
l003okgMl005o`000?nfc>[o]/cZokK<j_l000001On_^n<01Ol0003oYjcJojN/f_nW[=[o000000?o
UZWS1Ol00002oi:Kf@04o`000?n1TMWoPI7Ioh6Af@Go00000_mnVn@00ol0003oKXWMofj9g@02ofj9
g@?o00001?mST>L01?l0003oFH?QoeV3hOl00004od^6i`;o000000?o>8O[o`000?l000001?lSQ^X2
o`000004o`b2hol0003o0000o`1keP;o00000_m2To44ocbGlP04o`000?lhW??o>9ccocRLl`?o0000
0_lgXO@2o`0000?o>ZOd0ol00004od2^mP?o00000_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02[ooooo0009ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000ooooooooool0COooool9o`000003ol3h
k_l0003o`Ngb00;o`Ngb1?nmgO001Ol0003o]/cZokK<j_nfc>[o000000Go[k_S00?o0000ojN/f_nW
[=X00onW[=X3o`0000SoTY_I00?o0000oh6AfOn1TMT01On1TMT3o`0000OoKXWM0_l00002of>@i`03
o`000?mUPM[oFH?Q00;oFH?Q0_l00003od^6i`;o000000?o>8O[o`000?l000001?lSQ^X2o`000003
o`b2hol0003oBI3^00;oBI3^0om2To401?l0003o?9ObocbGl_llUo82o`0000?o>9cc0_l00003ocNQ
m0;o00000oljYo@3o`0000Co@:kf0ol0000fooooo`03o`000?oooooooooo02Wooooo000Aooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0B_ooool9o`0000;o`?S^00Co0000ol7]l_o1kO;o`Ngb1?nmgO00
1Ol0003o]/cZokK<j_nfc>[o000000Go[k_S00?o0000ojN/f_nW[=X00onW[=X2o`0000[oTY_I00?o
0000oh6AfOn1TMT01on1TMT01?l0003oMXCDo`000?l00006ofj9g@?o00000_mUPMX01Ol0003oFH?Q
oeV3hOmIPn7o000000CoBhKW00?o0000ocR7jolhQn/00_l00004ob>6jP03o`000?mBS>[oDXcZ00?o
BI3^00Go0000od:ClOm2To7o@Y?ao`000003ocbGlP;o00000olhW?<2o`0000?o=j7d0ol00003ocZW
m0;o00001?m0[_H4o`0003Cooooo00?o0000ooooooooool0:?ooool0017ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo04Oooooo2?l00002ok[li0?o`?S^1Ol00002okgMl005o`000?nfc>[o
]/cZokK<j_l000001On_^n<00ol0003oYjcJojN/fP03ojN/fP04o`000?nPW]?oX9kCo`0000SoTY_I
0ol000000on1TMWo0000o`000005oh6Af@04o`000?mfQ=CoMXCDogJ4e0;o00001_m^RMd01?l0003o
IH7JofF1f_mUPMX2o`0000;oFH?Q0_l00003od^6i`;o00000_lhQn/2o`000004ob>6j_l0003oFXSU
oeZ8i@;oDXcZ00Go0000odV@k_m9T>koBI3^o`000003od:Cl@04o`000?llUo;o?9ObocbGlP;o0000
0olhW?<2o`0000Co=j7d0ol00002ocZWm0?o000000?o@:kfo`000?m0[_H00_m0[_H3o`00037ooooo
0_l0000Yooooo`004Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04Cooooo2?l00003ok[li0Co0000
0_o?eml00ol0003oal_LolO;g007o`0000Co[k_S00?o0000ojN/f_nW[=X00onW[=X00ol0003oX9kC
oj2Nd`02oj2Nd`03o`000?nBVmWoTY_I00Go00000_n@T=001?l0003oPhS@oh>8d?n3R=05o`000003
oh6AfOl0003oMXCD00?oMXCD0_l00004ofj9g@03o`000?m]O];oIH7J00?oIH7J00Go0000oeV3hOmI
Pn7oFH?Qo`000004od^6i`;o00000_lhQn/00ol0003oFXSUoeZ8i@02oeZ8i@?oDXcZ00Go0000odV@
k_m9T>koBI3^o`000003od:Cl@;o00000_llUo82o`0000?o>9cc0_l00005ocNQm0;o00000oljYo@3
o`000003od2^m_l0003oQk_g00;oQk_g0_l0000_ooooo`;o0000:Oooool0017ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`03o`000?oooooo
oooo04;ooooo1ol000000onanmKo^_cTo`000002o`0000;oeN;P00Co0000oloGgoo?emoo00001?o7
bm`01_l0003o_kkIoknnfOno_]Wo0000okJae0;o000000?o[k_So`000?nW[=X01?nW[=X00ol0003o
X9kCoj2Nd`04oj2Nd`;o00002?n@T=000ol0003oPhS@oh>8d005oh>8d0;o00001_mfQ=@2o`0000;o
KXWM00Co0000ofend_m]O];o00000omUPMX2o`0000;oFH?Q0_l00004od^6i`04o`000?lhQn_o0000
of65g`CoFXSU00Co0000oe:<j_mBS>[o00000om9T>h2o`0000?o@Y?a00Co0000ocbGl_llUo;o?9Ob
0_l00003ocRLl`?o00001?lgXO@3o`000004ocZWm?l0003o>ZOdo`0000KoQk_g00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Vooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo013ooooo0_l00011ooooo`Ko00000_nanmH2o`000005
om[/h?l0003oeN;PomGRh?l000000oo?eml01Ol0003oal_LolO;g?o7bmco000000?o_kkI00?o0000
okJae?nf/M@00_nf/M@2o`0000CoYjcJ00?o0000oj2NdonPW]<01?nPW]<2o`0000WoT93@00?o0000
oh>8d?n3R=001_n3R=001?l0003oNgo<o`000?l00005ogJ4e0?o00000om]O]800ol0003oIH7JofF1
fP02ofF1fP04o`000?mIPn7oFH?QoeV3h@;o00000om;Q^L01?l0003oHHGOof65gomQQMl4oeZ8i@03
o`000?mBS>[oDXcZ00;o00000om9T>h2o`0000;o@Y?a0_l00003ocbGlP;o00001?lhW?<2o`0000Co
=j7d0ol00003ohFem@KoQk_g0_l0000^ooooo`03o`000?oooooooooo02Kooooo000Zooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0??ooool6o`000003ojOfaol0003o000000?of^cP
00Go0000omGRh?oEh^3oeN;Po`000002oloGg`03o`000?o7bmcoal_L00;oal_L00Go0000oknnfOno
_]Wo_kkIo`000004okJae006o`000?n^Y/oo0000o`000?nW[=[o00001_nPW]<01?l0003oVY?<oiZC
c?l00008oi2@d003o`000?n3R=3oPhS@00KoPhS@00Co0000og]oc?mkOlcoNgo<0_l00005ogJ4e003
o`000?m]O];oKGkB00;oKGkB00?o0000ofF1f_mUPMX00_mUPMX00ol0003oFH?QoeV3h@02oeV3h@03
o`000?m;Q^Oo000000;oJ8;I0omQQMl01?l0003oFXSUoeZ8iOmJR>D2o`0000;oDXcZ00?o0000odV@
k_m9T>h00_m9T>h01?l0003o@Y?aod:ClOm2To42o`0000?o?9Ob0_l00004ocRLl`Go000000?oPjoa
o`000?n5]OD01?n5]OD00ol0003oQk_gohNkm`03ohNkm`;o0000;Oooool00ol0003oooooooooo`0U
ooooo`00:_ooool2o`0001Gooooo00?o0000ooooooooool0>_ooool5o`0000;oYoK700?o0000omcc
g_l000000ooJk>001?l0003oeN;PomGRh?l00003oloGg`05o`000?o7bmcoal_LolO;g?l000001?no
_]T01Ol0003o][7DokJae?nf/MCo000000Co[ZK?0_l00005oj2Nd`03o`000?nJTlcoVY?<00;oVY?<
00?o0000oi2@d?n@T=001?n@T=05o`0000KoPhS@00?o0000og]oc?mkOl`00_mkOl`00ol0003oMXCD
ogJ4e002ogJ4e003o`000?mdNlcoKGkB00?oKGkB0_l00003ofF1fP;o00000omIPn400ol0003oJ8;I
ofR2f@02ofR2f@?oHHGO00?o0000oeZ8iOmJR>D00_mJR>D00ol0003oDXcZoe:<jP02o`0000?oBI3^
0_l00003od:Cl@;o00000ollUo82o`000003ocRLlol0003o000000;o00001?n3[o42o`0000CoQKGe
0_l00005ohNkm`;o0000;?ooool00ol0003oooooooooo`0Tooooo`00:_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo03Sooooo1?l000000onMl;[o0000o`000002omccgP05o`000?oJ
k>3of^cPom[/h?l000000ooEh^001Ol0003ocmOOoloGgoo?emoo000000?oal_L00Go0000oknnfOno
_]Wo_kkIo`000004okJae003o`000?n^Y/oo[ZK?00;o[ZK?0_nVVl/01Ol0003oX9kCoj2NdonPW]?o
000000KoVY?<00?o0000oi2@d?n@T=000ol00002ohf8b003o`000?n5P/SoQH;800Go000000?oPhS@
o`000?mkOl`01?mkOl`2o`0000;oMXCD00Co0000ogAkc?mdNlco00001?m]O]800ol0003oIH7JofF1
fP02ofF1fP03o`000?mIPn7oFH?Q00;o00001?mXP]T00ol0003oHHGOof65g`02o`0000?oFXSU00Go
0000oe:<j_mBS>[oDXcZo`000004odV@kP03o`000?m2To7o@Y?a00;o@Y?a0_l000000ollUo;o0000
o`000002o`000004ocRLlol0003oPZW^oh:YkPCoPjoa00?o0000oh>_lOl000001?n5]OD2o`0000Go
Qk_g0_l0000Zooooo`;o00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0eooooo`Co000000GoU^^aoig`^_l0003ogOSKo`000002omccgP05o`000?oJk>3of^cPom[/
h?l000000_oEh^001Ol0003ocmOOoloGgoo?emoo000000?oal_L00?o0000oknnfOno_]T00_no_]T0
1Ol0003o][7DokJae?nf/MCo000000Co[ZK?00Oo0000ojJKbonVVl_oYY_;o`000?nPW]?o000000Oo
VY?<0ol00006ohf8b003o`000?n5P/SoQH;800CoQH;80_l00007og]oc0?o00000omdNl`00ol0003o
KGkBofendP02ofendP03o`000?mUPM[oIH7J00;oIH7J0_l00002ofeod`03o`000?mXP]WoJ8;I00;o
J8;I00Go0000of65gomQQMooHHGOo`000003oeZ8i@04o`000?mBS>[oDXcZoe:<jP;o00000om9T>h2
o`0000;o@Y?a1?l00002ocbGlP;o00001?n2ZNh01ol0003oPjoaoh>_lOn3[o7o0000oh>_lOl00000
1On5]OD00ol0003oQk_gohNkm`04ohNkm`03o`000?oooooooooo02Oooooo0_l00008ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@07oooo
o`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03?ooooo0ol00002oiK[/@04
oig`^_oMn=_ogOSKo`0000;og??N00Go0000om[/h?oJk>3of^cPo`000003omGRh005o`000?o?emoo
cmOOoloGgol000000oo7bm`01Ol0003o_kkIoknnfOno_]Wo000000Co][7D00?o0000ojjVcon^Y/l0
0_n^Y/l00ol0003oYY_;ojJKb`02ojJKb`03o`000?nJTlcoVY?<00GoVY?<00?o0000oiF;a_l00000
1on=R<P00ol0003oQH;8ohF2b005ohF2b004o`000?mnO<Ko0000o`0000KoNgo<00?o0000ogAkc?md
Nl`00_mdNl`00ol0003oKGkBofendP02ofendP03o`000?mUPM[oIH7J00;oIH7J00Go0000ofeodom]
Om?oKGoCo`000004ofR2f@05o`000?mQQMooHHGOof65gol000000omJR>D00ol0003oDXcZoe:<jP02
oe:<jP04o`000?m9T>koBI3^odV@kP?o00000om2To43o`0000?oPJ?Y1On2ZNh00ol0003oPjoao`00
0002oh>_l@;o00001?n5]OD2o`0000GoQk_g0_l0000Xooooo`03o`000?oooooooooo00Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`00:_oo
ool2o`0001Wooooo00?o0000ooooooooool0<Oooool2o`000004oi;W[?nFjk7oU^^ao`0000?ogOSK
00Co0000omccg_oLlmko00000ooJk>001?l0003oeN;PomGRh?l00003oloGg`05o`000?o7bmcoal_L
olO;g?l000001?no_]T01Ol0003o][7DokJae?nf/MCo000000Go[ZK?00?o0000ojJKbonVVl/00_nV
Vl/00onOT/Ko0000oiZCc004oiZCc005o`000?nERlKoUH_6oiF;a_l000001_n=R<P00ol0003oQH;8
ohF2b005ohF2b004o`000?mnO<KoOWc6ogilaP;o00001?mkOl`00ol0003oNGW7ogAkc003ogAkc0;o
00000om]O]801Ol0003oIH7JofF1f_mUPM[o000000CoKGoC00?o0000ofR2fOmXP]T00_mXP]T01Ol0
003oHHGOof65gomQQMoo000000?oFXSU0_l00003oe:<jP?o00000om9T>h00ol0003o@Y?ao`000003
oh2Mi@CoPJ?Y00?o0000oh:Yk_n2ZNh00_n2ZNh00ol0003oPjoao`000003oh>_l@03o`000?n5]OGo
QKGe00?oQKGe0_l00005ohNkm`;o00009oooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`05ooooo`00:Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02kooooo0_l000001_n@ij_oT^N/oiK[/OnFjk7og?cHo`0000;ogOSK
00Co0000omccg_oLlmko00000ooJk>001Ol0003oeN;PomGRh?oEh^3o000000?ocmOO00Go0000olO;
g?o7bmcoal_Lo`000003oknnf@03o`000?nf/MCo][7D00;o][7D00?o0000ojjVcon^Y/l00_n^Y/l0
0ol0003oYY_;ojJKb`02ojJKb`04o`000?nOT/KoWi;6o`0000?oVY?<00?o0000oiF;a_nERlH00onE
RlH00ol0003oSHS8ohf8b003ohf8b0Co00001On5P/P00ol0003oOWc6ogilaP02ogilaP;o00000_mk
Ol`01?l0003oNGW7ogUiaol00004ogAkc009o`000?m]O];oKGkBofend_l0003oIH7Jo`000?mbO<ko
000000CoKGoC00?o0000ofR2fOmXP]T00_mXP]T01Ol0003oHHGOof65gomQQMoo000000CoFXSU0ol0
00000omBS>[o0000o`000003odV@kP;o00001On0WND4oh6Sj@03o`000?n2ZNkoPZW^00;oPZW^0ol0
0003oh>_l@;o00001On5]OD00ol0003oQk_gohNkm`04ohNkm`;o00009_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`00:Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02cooooo00Co0000oi7X[_n@ij_oT^N/
0_nFjk400ooLo=So0000omghf`02omghf`04o`000?oLlmkog??No`0000?of^cP00Co0000omGRh?oE
h^3o00000oo?eml01Ol0003oal_LolO;g?o7bmco000000Co_kkI00?o0000okJae?nf/M@00_nf/M@0
0ol0003o[ZK?ojjVc`02ojjVc`03o`000?nVVl_oYY_;00;oYY_;00Oo0000oinBa_nOT/KoWi;6o`00
0?nJTlco000000KoUH_600?o0000ohf8b?n=R<P00ol000001?n;PL?o0000ohEm`on5OL<4o`000003
ohF2b?l0003oOWc600GoOWc60ol00003ogUia`03o`000?mdNlcoM7_<00;oM7_<00Go0000ofend_m]
O];oKGkBo`000003og9lcP03o`000?m]Om?oKGoC00;oKGoC00?o0000ofR2fOmXP]T00_mXP]T01?l0
003oHHGOof65gomQQMl4o`000003oeZ8iOl0003oDXcZ00?oDXcZ00?o0000odV@k_l000000_n0Un00
0ol0003oP9gUoh2Mi@03oh2Mi@04o`000?n1XnWoPJ?Yoh6Sj@;o00001?n2ZNh2o`0000CoPjoa00?o
0000ohFemOn5]OD00on5]OD2o`0000KoQk_g00?o0000ooooooooool08oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oo
oooo000Yooooo`?o00007?ooool00ol0003oooooooooo`0Zooooo`04o`000?nAj:koT>N[oi;W[0;o
00000_oLo=P01?l0003ogOSKomghfol00002omccgP05o`000?oJk>3of^cPom[/h?l000000ooEh^00
1Ol0003ocmOOoloGgoo?emoo000000?oal_L00?o0000oknnfOno_]T00_no_]T01Ol0003o][7DokJa
e?nf/MCo000000Go[ZK?00?o0000ojJKbonVVl/00_nVVl/00ol0003oWi;6oinBaP02oinBaP03o`00
0?nERlKoUH_600GoUH_60ol00005oh^1``03o`000?n5OL?oQGg300?oQGg30_l00008ogilaP03o`00
0?miNLOoNGW700;oNGW700?o0000ogAkc?mdNl`00_mdNl`01?l0003oKGkBofend_l00004og9lcP03
o`000?m]Om?oKGoC00;oKGoC00?o0000ofR2fOmXP]T00_mXP]T4o`000003of65gol0003oFXSU00;o
FXSU00Co0000oe:<j_mBS>[oDXcZ0_l00004oh2Gh003o`000?n0WNGoP9gU00?oP9gU00?o0000oh6S
jOn1XnT00_n1XnT00ol0003oPZW^oh:YkP02oh:YkP;o00001?n3[o400ol0003oQKGeohFem@04ohFe
m@;o00001On7^oL2o`0002Cooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Xooooo`09o`000?nAj:koT>N[oi;W[?l0003ofokEo`000?oLo=So000000?ogOSK
00Co0000omccg_oLlmko00000ooJk>001?l0003oeN;PomGRh?l00004oloGg`_o00000_nf/M@00ol0
003o[ZK?ojjVc`02ojjVc`03o`000?nVVl_oYY_;00;oYY_;00?o0000oinBa_nOT/H00onOT/H00onI
R/;o0000oiF;aP04oiF;aP03o`000?nAQ<7o000000KoRh7300?o0000ohEm`on5OL<01?n5OL<00ol0
003oPGW1o`000006ogilaP03o`000?miNLOoNGW700?oNGW700?o0000ogAkc?mdNl`00_mdNl`2o`00
0003ogMjbOl0003oLWc>00?oLWc>00?o0000ofeodom]Om<00_m]Om<00ol0003oJ8;Io`000003o`00
00CoHHGO00Wo0000oeZ8iOmJR>GoFXSUo`000?mBS>[o0000oh2Bfol000001On0Un000ol0003oP9gU
oh2Mi@03oh2Mi@03o`000?n1XnWoPJ?Y00;oPJ?Y00?o0000oh:Yk_n2ZNh00_n2ZNh2o`0000CoPjoa
0_l00006ohFem@03o`000?n7^oOoQk_g00?oQk_g0_l0000Rooooo`?o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Vooooo`04o`000?nAj:koT>N[oi;W[0;ofokE00Co0000omclf?oL
o=So00000_oMn=/01Ol0003og??Nomccg_oLlmko000000;of^cP00Ko0000omGRh?oEh^3oeN;Po`00
0?o?eml4o`0000;o`[K?00?o0000ok^^c?nk[/`00_nk[/`00ol0003o]:G9okBUb@03o`0000Co[ZK?
00?o0000ojJKbonVVl/00_nVVl/00ol0003oWi;6oinBaP02oinBaP04o`000?nIR/;oVH[2o`0000?o
UH_600Go0000oi64`OnAQ<7oTHC1o`000005oh^1``03o`000?n5OL?oQGg300CoQGg300?o0000oh5i
`On1NL400_l00004ogilaP;o00001OmiNLL00ol0003oM7_<ogAkc002ogAkc004o`000?mgN/WoMg[9
o`0000CoLWc>00?o0000ofeodom]Om<00ol00004ofR2f@03o`000?mQQMooHHGO00;oHHGO00Go0000
oeZ8iOmJR>GoFXSUo`000003oh2Bf`03o`000?n0Un3oP9OP00?oP9OP00?o0000oh2MiOn0WND00on0
WND00ol0003oPJ?Yoh6Sj@02oh6Sj@;o00000on2ZNh2o`0000GoPjoa00?o0000ohFemOn5]OD01?n5
]OD2o`000003ohNkmol0003o000000;o[/;X00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Sooooo0006ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00Co0000oi7X[_n@
ij_o00000ooKo]D00ol0003og?cHo`000002omghf`05o`000?oLlmkog??Nomccg_l000000ooJk>06
o`0000;obKoA00Go0000ol:fcoo2]/oo`[K?o`000004ok^^c004o`000?ndYLWo]:G9okBUb@;o[Ig7
0ol000000on^Y/oo0000ojJKb`02ojJKb`03o`000?nOT/KoWi;600?oWi;600Oo0000oiV:`_nIR/;o
VH[2o`000?nERlKo000000GoTHC100?o0000oh^1`on;PL<00on;PL<00ol0003oQGg3ohEm``03ohEm
``03o`000?n1NL7oPGW100;oPGW10_l000001OmnO<Ko0000ogeg`_mmMl;o000000GoNGW700Go0000
ogAkc?mdNlcoM7_<o`000003ogMjb@04o`000?mbO<koLWc>og9lcP?o00000om]Om<00ol0003oJ8;I
ofR2f@02ofR2f@03o`000?mQQMooHHGO00;oHHGO00Co0000oeZ8iOl0003o00001?n0T]/00ol0003o
P9OPoh2Gh003oh2Gh003o`000?n0WNGoP9gU00?oP9gU00?o0000oh6SjOn1XnT00on1XnT01?l0003o
PZW^oh:Yk_n2ZNh3o`0000CoPjoa0_l00005ohFem@;o00001On^`^P00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo01kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Q
ooooo`03o`000?oooooooooo02;ooooo00Go0000oi7X[_n@ij_ofOoCo`000002om_ne@04o`000?oL
o=Sog?cHo`0000;ogOSK00Ko0000omccg_oLlmkog??No`000?oJk>03o`0000;oclOB00?o0000olVo
dOo9_m400_o9_m401Ol0003o`[K?ol:fcoo2]/oo000000Co^jk<00Co0000okBUbOndYLWo]:G91On]
WLL2o`0000?oYY_;00?o0000oinBa_nOT/H00_nOT/H00ol0003oVH[2oiV:`P03oiV:`P03o`000?nA
Q<7oTHC100CoTHC100Co0000oh^1`on;PL?oRh731Ol00004ohEm``03o`000?n1NL7oPGW100?oPGW1
0_l00003ogeg`P03o`000?miNLOoNGW700?oNGW700?o0000ogAkc?mdNl`00_l00003ogMjb@?o0000
0_mbO<h00ol0003oKGoCofeod`02ofeod`03o`000?mXP]WoJ8;I00;oJ8;I00Co0000of65gomQQMoo
HHGO0_l00002oh6=e`03o`000?n0T]_oP9;K00;oP9;K00?o0000oh2Gh?n0Un000on0Un000ol0003o
P9gUoh2Mi@03oh2Mi@03o`000?n1XnWoPJ?Y00?oPJ?Y00Co0000oh:Yk_n2ZNko00000_n2ZNh00ol0
003oPjoaoh>_l@03oh>_l@07o`000?n5]OGoQKGeohFemOl0003o[;cVo`000006ojk2j003o`000?oo
oooooooo027ooooo00?o0000ooooooooool07Oooool000Co00000_ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool07oooool2o`000004oi7X[_n@ij_ofOoCo`0000?ofokE
00?o0000omclf?l000000_oMn=/01?l0003og??Nomccg_oLlmh3o`000003omG?e?l0003oclOB00;o
clOB00?o0000olVodOo9_m400_o9_m401Ol0003o`[K?ol:fcoo2]/oo000000Co^jk<00Go0000okBU
bOndYLWo]:G9o`000004ojfMa`;oYYG40_l000000onVVl_o0000oinBaP03oinBaP03o`000?nIR/;o
VH[200?oVH[200?o0000oi64`OnAQ<401?nAQ<44o`0000;oRWbn00?o0000ohIi__n6NKh00ol00000
0on5OL?o0000oh5i`@05oh5i`@03o`000?mmMl;oOGO200;oOGO200?o0000ogUiaomiNLL00omiNLL2
o`0000;oNWS51Ol00004og9lcP03o`000?m]Om?oKGoC00;oKGoC00?o0000ofR2fOmXP]T00_mXP]T0
1Ol0003oHHGOo`000?n1RM;o000000?oPHgG00?o0000oh2Bfon0T]/00_n0T]/00ol0003oP9OPoh2G
h003oh2Gh003o`000?n0WNGoP9gU00?oP9gU00?o0000oh6SjOn1XnT00on1XnT01?l0003oPZW^oh:Y
k_l00002oh:YkP;o00001?n3[o400ol0003oQKGeo`000003ojbliP03o`000?n^`^So[/;X00Co[/;X
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`001_ooool01Ol0003ooooooooo
oooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool07Oooool01?l0003oTNR^oi7X[_l00002omWod`04
o`000?oKo]GofokEo`0000;og?cH00Co0000omghfooMn=_o00000ooLlmh01Ol0003oeLoDomG?e?oE
cmCo000000?oclOB00?o0000olVodOo9_m400_o9_m401Ol0003o`[K?ol:fcoo2]/oo000000?o^jk<
00?o0000okBUbOndYLT00_ndYLT00ol0003o[Ig7ojfMa`02ojfMa`CoYYG40_l00004oinBaP03o`00
0?nIR/;oVH[200;oVH[200?o0000oiB4_ol000001?nAQ<400ol0003oSWjmo`000005ohYl_P03o`00
0?n6NKkoQWVn00;oQWVn0_l00006oh5i`@;o00001?mmMl800ol0003oNGW7ogUia`03ogUia`Go0000
0omgN/T00ol0003oLWc>og9lcP02og9lcP03o`000?m]Om?oKGoC00;oKGoC00Co0000ofR2fOmXP]Wo
J8;I0_l00003oh69dP05o`000?n1SMOoPHgGoh6=eol000001?n0T]/00ol0003oP9OPoh2Gh003oh2G
h003o`000?n0WNGoP9gU00?oP9gU00?o0000oh6SjOn1XnT00on1XnT2o`000003oh:Yk_l0003oPZW^
00;oPZW^00Co0000oh>_lOn3[o7oPjoa0_l00005ojbliP03o`000?n^`^So[/;X00Co[/;X00?o0000
ooooooooool08?ooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0Tooooo`;o00007?ooool01ol0003oTNR^oi7X[_oFom;o0000omWodol000000ooKo]D01_l0003o
g?cHomclf?l0003ogOSKo`0000;og??N0_l00004omG?e005o`000?o?am;oclOBolo7d_l000000oo9
_m400ol0003o`[K?ol:fc`02ol:fc`05o`000?nk[/co^jk<ok^^c?l000001?ndYLT00ol0003o[Ig7
ojfMa`02ojfMa`CoYYG40_nOS/401?l0003oWi;6oinBa_l00005oiV:`P04o`000?nDQ;ooU8Boo`00
00;oTHC100Go0000ohin_On>O[goSWjmo`000004ohYl_P03o`000?n6NKkoQWVn00?oQWVn00?o0000
oh=g_Ol000001?n1NL400ol0003oOgJno`000004ogeg`P03o`000?miNLOoNGW700?o00001?mjN<D0
1Ol0003oMg[9ogMjbOmgN/Wo000000CoLWc>00?o0000ofeodom]Om<00_m]Om<01Ol0003oJ8;Io`00
0?n2QLko000000CoPHWB00Go0000oh6=eon1SMOoPHgGo`000004oh2Bf`03o`000?n0Un3oP9OP00?o
P9OP00?o0000oh2MiOn0WND00on0WND00ol0003oPJ?Yoh6Sj@04oh6Sj@03o`000?n2ZNko000000?o
PZW^00Go0000oh>_lOl0003oZ[ORo`000006ojbliP03o`000?n^`^So[/;X00Co[/;X00?o0000oooo
ooooool07_ooool00ol0003oooooo`00000Mooooo`001_ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o00009oooool00ol0
003oooooooooo`0Hooooo`05o`000?nAj:koTNR^omKod_l000000_oIom<01?l0003ofokEom_neOl0
0002omclf003o`000?oMn=_ogOSK00?o000000?ofMKDo`000?oEcm@00ooEcm@01Ol0003oclOBolo7
d_o?am;o000000?obKoA00?o0000ol:fcoo2]/l00_o2]/l01Ol0003o^jk<ok^^c?nk[/co000000Co
]:G900Go0000ojfMaon]WLOo[Ig7o`000004ojJEa0?oWhk100?o0000oinBa_l000001?nIR/801ol0
003oU8BooiB4_onDQ;oo0000oi64`Ol000001?n>O[d00ol0003oRWbnohYl_P03ohYl_P03o`000?n6
NKkoQWVn00;oQWVn00?o0000oh=g_On3Mkd00_l00002oh5i`@04o`000?moM[koOgJno`0000?oOGO2
0ol000001?miNLOo0000ogeg`_l00003ogYha@03o`000?mgN/WoMg[900;oMg[900?o0000og9lc_mb
O<h00_mbO<h00ol0003oKGoCofeod`02ofeod`05o`000?n2QLkoPXG>oh:5c_l000001?n1RM801Ol0
003oPHgGoh6=eon1SMOo000000CoP9;K00?o0000oh2Gh?n0Un000on0Un000ol0003oP9gUoh2Mi@03
oh2Mi@03o`000?n1XnWoPJ?Y00CoPJ?Y0_l00003oh:YkP;o00000onZ]n800ol0003o[;cVojbliP04
ojbliP03o`000?n^`^So[/;X00Co[/;X00?o0000ooooooooool07oooool00ol0003oooooooooo`0K
ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Fooooo`03o`000?nAj:koTNR^00;oe_oB00?o0000omWodol000000_oKo]D01?l0003og?cHomcl
f?oLo=P3o`0000CofMKD00Go0000omG?e?oEcmCoeLoDo`000004olo7dP05o`000?o9_m7obKoAolVo
dOl000001?o2]/l01Ol0003o^jk<ok^^c?nk[/co000000Co]:G900Go0000ojfMaon]WLOo[Ig7o`00
0004ojJEa004o`000?nOS/7oWhk1oin>`@;o00001?nIR/800ol0003oU8BooiB4_`02oiB4_`03o`00
0?n>O[goSWjm00CoSWjm00?o0000ohYl__n:O;h00_n:O;h00ol0003oQWVnohIi_P02ohIi_P03o`00
0?n3MkgoPgNm00;oPgNm00?o0000oh5i`Ol000000omoM[h3o`0000;oOGO200?o0000ogUiaol00000
0_mmMl801Ol0003oNWS5ogYhaOmjN<Go000000CoMg[900?o0000og9lc_mbO<h00_mbO<h01Ol0003o
KGoCofeodom]Om?o000000CoPXG>00?o0000oh69d_n1RM800_n1RM801Ol0003oPHgGoh6=eon1SMOo
000000CoP9;K00?o0000oh2Gh?n0Un000on0Un000ol0003oP9gUoh2Mi@03oh2Mi@03o`000?n1XnWo
PJ?Y00CoPJ?Y1?l000000onX/Moo0000ojZghP03ojZghP03o`000?n/_>Ko[;cV00Co[;cV00?o0000
ojk2j?n^`^P01?n^`^P00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0
0005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool3o`0000;oe_oB00Co
0000omWodooIom?o00000_oKo]D00ol0003og?cHomclf002o`000003omgLeOl0003ofMKD00?ofMKD
00Go0000omG?e?oEcmCoeLoDo`000004olo7dP05o`000?o9_m7obKoAolVodOl000000oo2]/l00ol0
003o^jk<ok^^c002ok^^c005o`000?ndYLWo]:G9okBUbOl000001?n]WLL01Ol0003oYYG4ojJEa?nV
ULCo000000CoWhk10_nJQkh01?l0003oVH[2oiV:`_l00005oiB4_`03o`000?n>O[goSWjm00CoSWjm
00?o0000ohYl__n:O;h00_n:O;h00ol0003oQWVnohIi_P03ohIi_P03o`000?n3MkgoPgNm00;oPgNm
1Ol000000omoM[ko0000ogeg`P03ogeg`P03o`000?mmMl;oOGO200;oOGO200Go0000ogYhaOmjN<Go
NWS5o`000004ogMjb@03o`000?mbO<koLWc>00;oLWc>00Go0000ofeodol0003oPX;:o`000004oh:5
cP05o`000?n1RM;oPHWBoh69d_l000001?n1SML00ol0003oP9;Koh2Bf`02oh2Bf`03o`000?n0Un3o
P9OP00?oP9OP00?o0000oh2MiOn0WND00on0WND00ol0003oPJ?Yoh6Sj@03oh6Sj@?o00000onX/Ml0
0ol0003oZ[ORojZghP02ojZghP03o`000?n/_>Ko[;cV00Co[;cV00?o0000ojk2j?n^`^P01?n^`^P0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01[ooooo000Wooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool04_ooool2o`000007omCodol0003oe_oBomKod_l0003ofOoCo`00
0002om_ne@05o`000?oLo=Sog?cHomclf?l000000_oMg=D00ol0003ofMKDomWFe002omWFe005o`00
0?oEcmCoeLoDomG?e?l000001?o?am801Ol0003obKoAolVodOo9_m7o000000?o`[K?00?o0000ok^^
c?nk[/`00_nk[/`01Ol0003o]:G9okBUbOndYLWo000000Co[Ig700Go0000ojJEa?nVULCoYYG4o`00
0004oin>`@?oVXNn00?o0000oiV:`_l000001OnDQ;l00on@O[co0000ohin_@04ohin_@04o`000?n:
O;koRWbnohYl_PKo000000?oQWVno`000?n3Mkd00_n3Mkd3o`0000GoOgJn00Go0000ogeg`_mmMl;o
OGO2o`000004ogeg`P03o`000?mjN<GoNWS500;oNWS500?o0000ogMjbOmgN/T00_mgN/T01?l0003o
LWc>og9lc_mbO<h2o`0000?oPX;:00Go0000oh:5c_n2QLkoPXG>o`000004oh69dP03o`000?n1SMOo
PHgG00;oPHgG00?o0000oh2Bfon0T]/00_n0T]/00ol0003oP9OPoh2Gh003oh2Gh003o`000?n0WNGo
P9gU00?oP9gU00Ko0000oh6SjOn1XnWoPJ?Yo`000?nV[=/2o`0000CoZ;7O00?o0000ojZgh_nZ]n80
0_nZ]n800ol0003o[;cVojbliP04ojbliP03o`000?n^`^So[/;X00Co[/;X00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000ooooooooool04?oo
ool01?l0003oe?oComCodol00002omKodP04o`000?oIom?ofOoCo`0000;ofokE00Co0000omclf?l0
003o00000ooMg=D01Ol0003ofMKDomWFe?oIe]Co000000CoeLoD00Go0000olo7d_o?am;oclOBo`00
0004olVod@05o`000?o2]/oo`[K?ol:fcol000001?nk[/`01Ol0003o]:G9okBUbOndYLWo000000Co
[Ig700Go0000ojJEa?nVULCoYYG4o`000004oin>`@04o`000?nJQkkoVXNnoiZ7_P;o00001?nDQ;l0
1?l0003oT7jloi1n_?l00004ohin_@Co00000_n9N;/01?l0003oQWNkohIg^on6Mk/5o`0000;oPgNm
0_l00005ogmf_P03o`000?mmMl;oOGO200;o00001?mmMl801Ol0003oNWS5ogYhaOmjN<Go000000Go
Mg[900Go0000og9lc_l0003oPgo6o`000004oh:2bP05o`000?n2QLkoPXG>oh:5c_l000001?n1RM80
1Ol0003oPHgGoh6=eon1SMOo000000GoP9;K00?o0000oh2Gh?n0Un000on0Un000ol0003oP9gUoh2M
i@03oh2Mi@03o`000?n1XnWo000000?oYZcK0_l00004ojRag`03o`000?nZ]n;oZ[OR00;oZ[OR00?o
0000ojbli_n/_>H01?n/_>H00ol0003o[/;Xojk2j004ojk2j003o`000?oooooooooo01kooooo00?o
0000ooooooooool06?ooool002Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>
ooooo`05o`000?oDom?oe?oComCodol000000_oFom800ol0003ofOoCo`000002om_ne@?o000000?o
h>;Fo`000?oMg=D00_oMg=D01Ol0003ofMKDomWFe?oIe]Co000000CoeLoD00Go0000olo7d_o?am;o
clOBo`000004olVod@05o`000?o2]/oo`[K?ol:fcol000000onk[/`00ol0003o]:G9okBUb@02okBU
b@03o`000?n]WLOo[Ig700;o[Ig700Go0000ojJEa?nVULCoYYG4o`000004oin>`@04o`000?nJQkko
VXNnoiZ7_P;oUH:l00Go0000oiB4_onDQ;ooU8Boo`000002oi1n_007o`000?n>O[goSWjmohin_Ol0
003oRgVjo`000004ohUh^`03o`000?n6Mk_oQWNk00?o000000?oQ7Fjo`000?n3Mkd00_n3Mkd00ol0
003oPWBko`000005ogmf_P;o00000_moM[h00ol0003oOGO2ogeg`P02ogeg`P05o`000?mjN<GoNWS5
ogYhaOl000001OmgN/T01Ol0003oPgo6oh=oa_n3OlKo000000?oPX;:00?o0000oh:5c_n2QLh00_n2
QLh00ol0003oPHWBoh69dP02oh69dP05o`000?n1SMOoPHgGoh6=eol000001On0T]/00ol0003oP9OP
oh2Gh003oh2Gh003o`000?n0WNGoP9gU00;oP9gU0_l00005ojJ/f`;o00001?nX/Ml00ol0003oZ[OR
ojZghP02ojZghP03o`000?n/_>Ko[;cV00?o[;cV00?o0000ojk2j?n^`^P01On^`^P00ol0003ooooo
ooooo`0Looooo`;o00006_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0=ooooo`04o`000?oDom?oe?oCo`0000;oe_oB00Co0000omWodooIom?o00000_oKo]D01Ol0003o
h>;Fon3Re_oPh]Ko000000?ogMcE00Go0000omWFe?oIe]CofMKDo`000004omG?e005o`000?o?am;o
clOBolo7d_l000001?o9_m401Ol0003o`[K?ol:fcoo2]/oo000000?o^jk<00?o0000okBUbOndYLT0
0_ndYLT00ol0003o[Ig7ojfMa`02ojfMa`05o`000?nVULCoYYG4ojJEa?l000001?nOS/401?l0003o
VXNnoiZ7__nJQkh3oiF2_004o`000?nDQ;ooU8Boo`0000?oT7jl00?o0000ohin_Ol000000on;NKX0
1?l0003oRGRkohUh^on9N;/3o`0000;oQWNk00Co0000ohAe^_n4MK[o00000_n3Mkd01?l0003oPWBk
oh9d^ol00005ogmf_P05o`000?moM[koOgJnogmf__l000001?mmMl801Ol0003oNWS5ogYhaOmjN<Go
000000?oMg[900?o0000oh=oa_n3OlH00on3OlH01Ol0003oPX;:oh:2b_n2P/[o000000?oPXG>00?o
0000oh69d_n1RM800_n1RM800ol0003oPHgGoh6=e`02oh6=e`03o`000?n0T]_oP9;K00?oP9;K00?o
0000oh2Gh?n0Un000on0Un001_l0003oP9gUo`000?l0003oXjKHo`0000KoYZcK0_l00003ojRag`03
o`000?nZ]n;oZ[OR00?oZ[OR00?o0000ojbli_n/_>H00on/_>H00ol0003o[/;Xojk2j005ojk2j003
o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool002Oooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0;ooooo`04o`000?oDom?oe?oCo`0000;oe_oB00Go0000omWodooI
om?o0000om_ne@02o`0000Coh>;F00Go0000omgLeOoMg=GogMcEo`000003omWFe003o`000?oEcmCo
eLoD00;oeLoD00Go0000olo7d_o?am;oclOBo`000003olVod@03o`000?o2]/oo`[K?00;o`[K?00Go
0000ok^^c?nk[/co^jk<o`000004okBUb@05o`000?n]WLOo[Ig7ojfMaol000001?nVUL@01Ol0003o
Whk1oin>`OnOS/7o000000CoVXNn00Co0000oiF2_?nEP[coUH:l0_l00005oi1n_003o`000?n;NK[o
RgVj00;oRgVj1?l000000on9N;_o0000ohIg^`02ohIg^`07o`000?n4MK[oQ7FjohAe^_l0003oPgNm
o`000003oh9d^`03o`000?moM[koOgJn00;oOgJn00Go0000ogmf__moM[koOgJno`000005ogeg`P07
o`000?mjN<GoNWS5ogYhaOl0003oMg[9o`000002ohAl``CoPgo600?o0000oh:2b_n2P/X00_n2P/X0
1Ol0003oPXG>oh:5c_n2QLko000000CoPHWB00?o0000oh6=eon1SML00_n1SML00ol0003oP9;Koh2B
f`03oh2Bf`03o`000?n0Un3oP9OP00?oP9OP00?o0000oj>Vf?nSY]P00_nSY]P00ol0003oYZcKojJ/
f`03ojJ/f`;o00001?nX/Ml00ol0003oZ[ORojZghP03ojZghP03o`000?n/_>Ko[;cV00?o[;cV00?o
0000ojk2j?n^`^P01On^`^P00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000W
ooooo`;o0000<?ooool00ol0003oooooooooo`0:ooooo`04o`000?oDom?oe?oCo`0000;oe_oB00?o
0000omWodooIom<00_l000000ooQi]Ko0000on3ReP03on3ReP05o`000?oMg=GogMcEomgLeOl00000
0ooIe]@00ol0003oeLoDomG?e002omG?e005o`000?o?am;oclOBolo7d_l000000oo9_m400ol0003o
`[K?ol:fc`02ol:fc`03o`000?nk[/co000000Wo000000?o[Ig7o`000?nVUL@00_nVUL@00ol0003o
Whk1oin>`@02oin>`@03o`000?nJQkkoVXNn00;oVXNn00?o0000oiF2_?nEP[`00_nEP[`00ol0003o
T7jloi1n_003oi1n_003o`000?n;NK[oRgVj00Co00000on9N;/00ol0003oQWNkohIg^`02ohIg^`04
o`000?n4MK[oQ7FjohAe^P;o00001?n2M;/01_l0003oOgJnogmf__l0003oPWBlo`0000?oOgJn00?o
0000ogeg`_mmMl800_mmMl800ol0003oNWS5ogYha@02ogYha@03o`000?n4O<?oQ7c300;oQ7c31?n3
OlH01Ol0003oPX;:oh:2b_n2P/[o000000CoPXG>00?o0000oh69d_n1RM800_n1RM800ol0003oPHgG
oh6=e`02oh6=e`03o`000?n0T]_oP9;K00?oP9;K00Co0000oh2Gh?n0Un3oP9OP0_l00005oj>Vf003
o`000?nV[=_oYZcK00?oYZcK0_l00004ojRag`03o`000?nZ]n;oZ[OR00;oZ[OR00?o0000ojbli_n/
_>H01?n/_>H00ol0003o[/;Xojk2j005ojk2j003o`000?oooooooooo01cooooo00?o0000oooooooo
ool05_ooool002Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`04o`00
0?oDom?oe?oCo`0000;oe_oB00?o0000omWodooIom<00_l00002on7VeP05o`000?oPh]Koh>;Fon3R
e_l000001?oMg=D01Ol0003ofMKDomWFe?oIe]Co000000CoeLoD00Go0000olo7d_o?am;oclOBo`00
0003olVod@03o`000?o2]/oo`[K?00Co00000_naWlD5ojbI``?oYY?21?l000000onVULCo0000oin>
`@03oin>`@03o`000?nJQkkoVXNn00;oVXNn00?o0000oiF2_?nEP[`00_nEP[`00ol0003oT7jloi1n
_002oi1n_004o`000?n=N[Wo0000o`0000?oRgVj00?o0000ohUh^on9N;/00_n9N;/01Ol0003oQWNk
ohIg^on6Mk_o000000CoQ7Fj00?o0000oh9d^on2M;/00on2M;/00ol0003oOgJno`000002oh9d_005
o`000?moM[koOgJnogmf__l000001?mmMl801Ol0003oNWS5ogYhaOmjN<Go000000CoQ7c300?o0000
oh=oa_n3OlH00_n3OlH01Ol0003oPX;:oh:2b_n2P/[o000000CoPXG>00?o0000oh69d_n1RM800_n1
RM800ol0003oPHgGoh6=e`02oh6=e`03o`000?n0T]_oP9;K00?oP9;K00?o0000oh2Gh?l000000_nQ
XM@00ol0003oXjKHoj>Vf002oj>Vf003o`000?nV[=_oYZcK00CoYZcK0_l00004ojRag`03o`000?nZ
]n;oZ[OR00;oZ[OR00?o0000ojbli_n/_>H01?n/_>H00ol0003o[/;Xojk2j004ojk2j0;o00007_oo
ool00ol0003oooooooooo`0Eooooo`009_ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Oooooo00Co0000omCodooDom?o00000_oFom801?l0003ofOoComWodol00003on7VeP05o`00
0?oPh]Koh>;Fon3Re_l000000ooMg=D00ol0003ofMKDomWFe002omWFe005o`000?oEcmCoeLoDomG?
e?l000001?o?am800ol0003obKoAo`000004o`0000;o]jK71?naWlD00ol0003o[9W3ojbI``02ojbI
``CoYY?20onQSKl3o`0000?oWhk100Go0000oiZ7__nJQkkoVXNno`000005oiF2_004oi5m^_l0003o
T7jloi1n_0?o000000?oSGZio`000?n;NKX00on;NKX7o`000003ohIg^ol0003oQ7Fj00?oQ7Fj0_l0
0005oh9d^`03o`000?n2M;coPWBl00;oPWBl00Go0000ogmf__moM[koOgJno`000004ogeg`P05o`00
0?mjN<Go0000ohAj`?l000001?n4O<<01Ol0003oPgo6oh=oa_n3OlKo000000CoPX;:00Go0000oh:5
c_n2QLkoPXG>o`000005oh69dP03o`000?n1SMOoPHgG00;oPHgG00?o0000oh2Bfon0T]/00_n0T]/2
o`0000CoXJ7D00?o0000oj>Vf?nSY]P00_nSY]P00ol0003oYZcKojJ/f`04ojJ/f`;o00000onX/Ml0
0ol0003oZ[ORojZghP03ojZghP03o`000?n/_>Ko[;cV00Co[;cV00Co0000ojk2j?n^`^So[/;X0_l0
00000oo7d>3o0000ooooo`0Mooooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`04o`000?oDom?oe?oCo`0000;oe_oB00Co0000omWodol0003o0000
1?oQi]H01Ol0003oh>;Fon3Re_oPh]Ko000000?ogMcE00?o0000omWFe?oIe]@00_oIe]@01Ol0003o
eLoDomG?e?oEcmCo000000?oclOB0ol00002okf/b@Go]jK700Go0000ok6OaOnaWlGo/Io5o`000004
ojbI``05o`000?nVTl;oYY?2ojJC`_l000000onQSKl2oib8_@Co00000onJQkh00ol0003oUH:loiF2
_003oiF2_0Co000000GoT7jlo`000?n=N[WoSGZio`000003oh]i^P;o00000on8M[P00ol0003oQWBh
ohId^003o`0000?oQ7Fj00?o0000ohAc^Ol000001?n2M;/00ol0003oPWBloh9d_002oh9d_005o`00
0?moM[koOgJnogmf__l000001OmmMl801Ol0003oQ7[0ohAj`?n4N/3o000000CoQ7c300Go0000oh=o
a_n3OlKoPgo6o`000004oh:2bP05o`000?n2QLkoPXG>oh:5c_l000001?n1RM800ol0003oPHgGoh6=
e`03oh6=e`06o`000?n0T]_o0000o`000?nNVm7o00001?nQXM@00ol0003oXjKHoj>Vf003oj>Vf003
o`000?nV[=_oYZcK00?oYZcK0_l00004ojRag`03o`000?nZ]n;oZ[OR00?oZ[OR00?o0000ojbli_n/
_>H01?n/_>H00ol0003o[/;Xo`000004olO@h003o`000?oooooooooo01cooooo00?o0000oooooooo
ool05?ooool002Kooooo0ol0000dooooo`03o`000?oooooooooo00Cooooo00Co0000omCodooDom?o
00000_oFom82o`000003on;Yeol0003ohNKF00;ohNKF00?o0000on3Re_oPh]H00_oPh]H01Ol0003o
gMcEomgLeOoMg=Go000000CofMKD00Co0000omG?e?oEcmCoeLoD1?l000000oo2//_o0000okf/b@02
okf/b@03o`000?ngY/Oo]jK700;o]jK700Go0000ok6OaOnaWlGo/Io5o`000004ojbI``05o`000?nV
Tl;oYY?2ojJC`_l000000onQSKl00ol0003oW8Rmoib8_@02oib8_@;o00000_nJQkh01?l0003oUH:l
oiF2_?nEP[`3o`0000;oTGfj0_l00004ohej^@03o`000?n;NK[o000000;oRGJh00Co0000ohQf^?n8
M[So00000on6M;P00ol0003oQG>ho`000002ohAe^P04o`000?n4LkWoQ7>io`0000?oPWBk0_l00004
oh9d_005o`000?moM[koOgJnogmf__l000000ommMl800ol0003oQ7[0ohAj`002ohAj`003o`000?n4
O<?oQ7c300;oQ7c300?o0000oh=oa_n3OlH00_n3OlH01Ol0003oPX;:oh:2b_n2P/[o000000CoPXG>
00?o0000oh69d_n1RM800_n1RM800ol0003oPHgGoh6=e`02oh6=e`;o00001?nNVm400ol0003oXJ7D
oj6Qe002oj6Qe003o`000?nSY]SoXjKH00;oXjKH00?o0000ojJ/fonV[=/01?nV[=/2o`0000CoZ;7O
00?o0000ojZgh_nZ]n800onZ]n800ol0003o[;cVojbliP03ojbliP;o00001Oo7d>000ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01?ooooo000Vooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool00_ooool01?l0003oe?oComCodol00002omKodP;o00000_oRjML01Ol0003ohNKF
on7Ve_oQi]Ko000000Coh>;F00Go0000omgLeOoMg=GogMcEo`000003omWFe004o`000?oEcmCoeLoD
omG?e0;o00001?o2///01Ol0003o_Jc9okf/bOnm[<Wo000000Co]jK700?o0000ok6OaOnaWlD00_na
WlD01Ol0003o[9W3ojbI`on/VL?o000000?oYY?200Go0000oj6=_onQSKooXHfoo`000004oib8_@;o
Uh>l1_l000000onEP[co0000oi5m^P03oi5m^P03o`000?n=N[WoSGZi00?oSGZi00Go0000ohUf^?n9
M[SoRGJho`000003ohQf^004o`000?n6M;SoQWBho`0000;oQG>h00?o0000ohAe^_l000000on4LkT0
0ol0003oPWBko`000002oh=d^P03o`000?n2M;coPWBl00;oPWBl00Oo0000ogmf__moM[koOgJno`00
0?mmMl;o000000;oQGRn1?n4N/000ol0003oQ7c3ohAl``02ohAl``05o`000?n3OlKoPgo6oh=oa_l0
00001?n2P/X01Ol0003oPXG>oh:5c_n2QLko000000GoPHWB00Go0000oh6=eol0003o0000oibFcP06
oijKd@03o`000?nQXMCoXJ7D00;oXJ7D00?o0000oj>Vf?nSY]P00_nSY]P00ol0003oYZcKojJ/f`04
ojJ/f`;o00001?nX/Ml00ol0003oZ[ORojZghP03ojZghP07o`000?n/_>Ko[;cVojbli_l0003oal_M
o`000005olO@h003o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo
00000ooDom<01?l0003oe_oBomKod_l00003on;Ye`05o`000?oQi]KohNKFon7Ve_l000001?oPh]H0
1Ol0003ogMcEomgLeOoMg=Go000000?ofMKD00Ko0000omG?e?l0003o0000olNhcOl00004ol:bb`05
o`000?nm[<Wo_Jc9okf/bOl000001OngY/L01Ol0003o/Io5ok6OaOnaWlGo000000?o[9W300Go0000
ojJC`_nVTl;oYY?2o`000003oj6=_`03o`000?nLR;goW8Rm00;oW8Rm00?o0000oiN3_?l000000ol0
0003oiF2_003o`000?nAOK[oTGfj00;oTGfj00?o0000ohej^On=N[T00on=N[T01Ol0003oRGJhohUf
^?n9M[So000000?oR7Jh00Co0000ohId^?n6M;So00000on5LkP2o`0000CoQ7>i0_l00002oh=d^P03
o`000?n2M;coPWBl00;oPWBl00?o0000ogmf__moM[h00_moM[h01Ol0003oQGRnohEh__n5N;ko0000
00?oQ7[000?o0000ohAl`on4O<<00on4O<<01Ol0003oPgo6oh=oa_n3OlKo000000CoPX;:00Go0000
oh:5c_n2QLkoPXG>o`000004oh69dP;o00001?nLU/h5oijKd@03o`000?nQXMCoXJ7D00;oXJ7D00?o
0000oj>Vf?nSY]P00onSY]P00ol0003oYZcKojJ/f`03ojJ/f`03o`000?nX/Moo000000CoZ;7O00?o
0000ojZgh_nZ]n800onZ]n800ol0003o[;cVo`000003olO;g@03o`000?o7d>3oam3P00?oam3P00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Booooo`006oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool0>?ooool3o`0000;oe?oC00Co0000omKod_l0003o0000
1?oRjML01Ol0003ohNKFon7Ve_oQi]Ko000000Coh>;F00Go0000omgLeOoMg=GogMcEo`000003omWF
e0;o00000oo7^<d00ol0003o`[;;ol:bb`02ol:bb`03o`000?nm[<Wo_Jc900;o_Jc900?o0000okNV
aongY/L00_ngY/L01Ol0003o/Io5ok6OaOnaWlGo000000?o[9W300Go0000ojJC`_nVTl;oYY?2o`00
0004oj6=_`03o`000?nLR;goW8Rm00?o00000_nGPk`2oi=o^P;o000000?oUH:lo`000?nAOKX00onA
OKX00on=NKSo0000ohej^@02ohej^@03o`000?n:M[Oo000000?oRGJh00Co0000ohQf^?n8M[So0000
0on6M;P01Ol0003oQG>hohEc^?n5LkSo000000GoQ7>i00Go0000oh=d^_n3M;[oPgBjo`000004oh9d
_004o`000?moM[koOgJnogmf_PGoQGRn00Go0000ohAj`?n4N/3oQ7[0o`000004ohAl``05o`000?n3
OlKoPgo6oh=oa_l000001?n2P/X00ol0003oPXG>oh:5cP02oh:5cP05o`000?n1RM;o0000o`000?nI
T//01OnLU/h00ol0003oWY_AoijKd@03oijKd@03o`000?nQXMCoXJ7D00;oXJ7D00?o0000oj>Vf?nS
Y]P00onSY]P00ol0003oYZcKojJ/f`03ojJ/f`;o00001?nX/Ml00ol0003oZ[ORojZghP03ojZghP;o
00001?o7bmd00ol0003oam3PolO@h003olO@h003o`000?oooooooooo01kooooo00?o0000oooooooo
ool01oooool4o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?ooooooooooooooool@
41001Oooool3o`0003Wooooo00?o0000omCodooDom<00ol000000ooRk=So0000on;Ye`02on;Ye`03
o`000?oQi]KohNKF00;ohNKF00?o0000on3Re_oPh]H00_oPh]H01Ol0003ogMcEomgLeOoMg=Go0000
00;ofMKD0_l00004olNhc@03o`000?o2//_o`[;;00?o`[;;00Go0000okf/bOnm[<Wo_Jc9o`000004
okNVa`05o`000?naWlGo/Io5ok6OaOl000000on/VL<01Ol0003oYY?2ojJC`_nVTl;o000000CoXHfo
0ol000000onLR;go0000oiN3_002oiN3_004o`000?nCOk[oTgnjoi=o^P;o00001?nAOKX00ol0003o
SGVho`000002ohej^@03o`000?n:M[Oo000000?oRGJh00Go0000ohQf^?n8M[SoR7Jho`000002ohId
^004o`000?n5LkSoQG>hohEc^0;o00001?n4LkT00ol0003oPgBjoh=d^P02oh=d^P03o`000?n2M;co
PWBl00;oPWBl00Co0000ogmf__l0003oQGNl1?n5N;h00ol0003oQ7[0ohAj`002ohAj`003o`000?n4
O<?oQ7c300;oQ7c300Go0000oh=oa_n3OlKoPgo6o`000004oh:2bP04o`000?n2QLkoPXG>oh:5cP;o
00001?nIT//5oibFcP03o`000?nNVm7oWY_A00;oWY_A00?o0000oj6Qe?nQXM@00onQXM@00ol0003o
XjKHoj>Vf002oj>Vf003o`000?nV[=_oYZcK00CoYZcK0_l00004ojRag`07o`000?nZ]n;oZ[ORojZg
h_l0003oaLKKo`000005olO;g@03o`000?o7d>3oam3P00?oam3P00?o0000ooooooooool07?ooool3
o`0000[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo03Wooooo00Co0000omCodooDom?o00000ooRk=P01Ol0003oh^WGon;Y
eooRjMOo000000CohNKF00?o0000on3Re_oPh]H00_oPh]H01?l0003ogMcEomgLeOoMg=D3o`000003
ol^nc_l0003oakS=00CoakS=00?o0000ol:bboo2///00_o2///01Ol0003o_Jc9okf/bOnm[<Wo0000
00Co]jK700Go0000ok6OaOnaWlGo/Io5o`000004ojbI``04o`000?nVTl;oYY?2ojJC`PGo00000onL
R;d01Ol0003oUh>loiN3_?nGPkco000000CoTgnj0_l00002oi5m^P07o`000?n=NKSoSGVhohei^?l0
003oSGZio`000002ohYf]`04o`000?n9M[SoRGJho`0000;oR7Jh1Ol00003ohEc^003o`000?n5LkOo
000000?oQ7>i0_l00004oh=d^P03o`000?n2M;coPWBl00;oPWBl00Co0000ohEg_?n5Mkco00001?n5
N;h01Ol0003oQ7[0ohAj`?n4N/3o000000CoQ7c300?o0000oh=oa_n3OlH00_n3OlH00ol0003oPX;:
oh:2bP02oh:2bP04o`000?n2QLko0000oiN=a`GoVI;;00?o0000oibFc_nLU/h00_nLU/h00ol0003o
WY_AoijKd@03oijKd@03o`000?nQXMCoXJ7D00?oXJ7D00?o0000oj>Vf?nSY]P00_nSY]P00ol0003o
YZcKojJ/f`04ojJ/f`;o00001?nX/Ml00ol0003oZ[ORo`000003olG6f`03o`000?o7bmgoal_M00;o
al_M00?o0000olO@h?o7d>000oo7d>000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo03Sooooo00Co0000omCodol0003o00001?oRk=P01Ol0003oh^WGon;YeooRjMOo
000000CohNKF00Go0000on3Re_oPh]Koh>;Fo`000003omgLe@;o00000oo;_/h00ol0003oakS=olNh
c@03olNhc@03o`000?o2//_o`[;;00;o`[;;00Go0000okf/bOnm[<Wo_Jc9o`000004okNVa`05o`00
0?naWlGo/Io5ok6OaOl000001?n/VL<00ol0003oYY?2o`000002o`0000?oXHfo00Go0000oib8_OnL
R;goW8Rmo`000003oiN3_003o`000?nCOk[oTgnj00;oTgnj0_n?NkT00ol0003oTGfjo`000004ohei
^003o`000?n:M[OoRWJg00;oRWJg00?o0000ohUf^?n9M[P00_l000001?n7LkKo0000ohIc]_n6LkH2
o`0000;oQG>h00Ko0000ohEc]on5LkOo0000ohAc^Ol00002ohAc^005o`000?n3M;[oPgBjoh=d^_l0
00000on2M;`00ol0003oQGNlohEg_002ohEg_005o`000?n5N;koQGRnohEh__l000001?n4N/000ol0
003oQ7c3ohAl``02ohAl``05o`000?n3OlKoPgo6oh=oa_l000001?n2P/X2o`0000?oUhg71OnIT//0
0ol0003oW9K>oibFcP02oibFcP03o`000?nNVm7oWY_A00?oWY_A00?o0000oj6Qe?nQXM@00_nQXM@0
0ol0003oXjKHoj>Vf003oj>Vf003o`000?nV[=_oYZcK00?oYZcK00?o0000ojRagol000000onX/Ml2
o`0000CoaLKK00?o0000olO;gOo7bmd00oo7bmd00ol0003oam3PolO@h003olO@h003o`000?oooooo
oooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`006oooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0>?ooool2o`000003on7^fOl0003o
h^cH00?oh^cH00Go0000on;YeooRjMOoh^WGo`000004on7VeP05o`000?oPh]Koh>;Fon3Re_l00000
0_oMg=D00ol0003oclC@o`000003ol^ncP03o`000?o7^<goakS=00?oakS=00?o0000ol:bboo2///0
0_o2///01Ol0003o_Jc9okf/bOnm[<Wo000000Co]jK700Go0000ok6OaOnaWlGo/Io5o`000003ojbI
``?o00000_nVTl801Ol0003oXHfooj6=_onQSKoo000000CoW8Rm00Co0000oiN3_?nGPkco00001?nC
OkX00ol0003oSg^iohmk^@02o`0000CoSGVh00?o0000ohYf]on:M[L00_n:M[L01?l0003oRGJho`00
0?l00002ohMc]P08o`000?n6LkKoQW>fo`000?n6L[Ko0000ohEc^?l00003ohEc]`;o00000_n4LkP0
0ol0003oPgBjoh=d^P02oh=d^P03o`000?n2M;co000000;oQGJj1?n5Mk`01Ol0003oQGRnohEh__n5
N;ko000000CoQ7[000?o0000ohAl`on4O<<00_n4O<<01_l0003oPgo6oh=oa_n3OlKo0000oh:2bP;o
000000?oU8W5oiN=aonGSLL00_nGSLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/koW9K>00?o
W9K>00?o0000oijKdOnNVm400_nNVm400ol0003oXJ7Doj6Qe003oj6Qe003o`000?nSY]SoXjKH00;o
XjKH00?o0000ojJ/fonV[=/01?nV[=/2o`0000;oZ;7O00?o0000ol?1f?l000001Oo5a]/00ol0003o
al_MolO;g@02olO;g@03o`000?o7d>3oam3P00?oam3P00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`0003Sooooo0_l00002on7^f@05o`000?oRk=Soh^cHon;/f?l000001?oRjML00ol0
003ohNKFon7VeP02on7VeP07o`000?oPh]Koh>;Fon3Re_l0003ogMcEo`000002olo4d003o`000?o;
_/kobkk>00;obkk>00?o0000olNhcOo7^<d00_o7^<d00ol0003o`[;;ol:bb`02ol:bb`05o`000?nm
[<Wo_Jc9okf/bOl000001?ngY/L01?l0003o/Io5ok6OaOnaWlD4o`000003ojbI`ol0003oYY?200;o
YY?200Go0000oj6=_onQSKooXHfoo`000004oib8_@04o`000?nGPkcoUh>lo`0000CoTgnj00Go0000
ohmk^On?NkWoSg^io`000004ohei^0;o00001?n:M[L01?l0003oR7BfohQd]_l00002ohMc]P03o`00
0?n6LkKo000000;oQW:f0_l00004ohEc]`05o`000?n4LkSoQ7>hohAc^?l000001?n3M;X01Ol0003o
QGJjohEf^_n5M[[o000000?oQGNl00?o0000ohEh__n5N;h00_n5N;h01Ol0003oQ7[0ohAj`?n4N/3o
000000CoQ7c300Co0000oh=oa_n3OlKoPgo60_l00004oiB9a@CoUhg700?o0000oiVBbonIT//00_nI
T//00ol0003oW9K>oibFcP02oibFcP03o`000?nNVm7oWY_A00?oWY_A00?o0000oj6Qe?nQXM@00onQ
XM@00ol0003oXjKHoj>Vf002oj>Vf003o`000?nV[=_oYZcK00CoYZcK0ol00003ol?1f003o`000?o5
a]_oaLKK00;oaLKK00?o0000olO;gOo7bmd00oo7bmd00ol0003oam3PolO@h002olO@h003o`000?oo
oooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`006oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0=oooool01Ol0003ohNkIon7^
fOoQk]Wo000000?oh^cH00?o0000on;YeooRjML00_oRjML01Ol0003ohNKFon7Ve_oQi]Ko000000Co
h>;F0_l00003olo4d003o`000?o;_/kobkk>00;obkk>00?o0000olNhcOo7^<d00_o7^<d00ol0003o
`[;;ol:bb`02ol:bb`05o`000?nm[<Wo_Jc9okf/bOl000001?ngY/L00ol0003o/Io5o`000002o`00
00Co[9W300Go0000ojJC`_nVTl;oYY?2o`000003oj6=_`03o`000?nLR;goW8Rm00;oW8Rm00Go0000
oiN3_?nGPkcoUh>lo`000003oi=o^P06o`000?n?NkWoSg^iohmk^On<N;Oo00000on=NKP00ol0003o
RgJgo`000003ohYf]`04o`000?n8M;KoR7Bfo`0000;oQg>f00?o0000ohIc]_l000000on6L[H00ol0
003oQG>gohEc]`02ohEc]`03o`000?n4LkSoQ7>h00;oQ7>h00Co0000oh=d^_n3M;[oPgBj1On5M[X0
1Ol0003oQGNlohEg_?n5Mkco000000?oQGRn00?o0000ohAj`?n4N/000_n4N/000ol0003oQ7c3ohAl
``02ohAl``04o`000?n3OlKo0000oi:5`PGoU8W500Go0000oiN=aonGSLOoUhg7o`000005oiVBb`03
o`000?nLU/koW9K>00;oW9K>00?o0000oijKdOnNVm400onNVm400ol0003oXJ7Doj6Qe002oj6Qe003
o`000?nSY]SoXjKH00?oXjKH00?o0000ojJ/fonV[=/00onV[=/3o`0000?o`l7H00?o0000olG6foo5
a]/00_o5a]/00ol0003oal_MolO;g@03olO;g@03o`000?o7d>3oam3P00?oam3P00?o0000oooooooo
ool07_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool002Cooooo00?o0000ooooooooool0
=oooool00ol0003ohNkIon7^f@02on7^f@05o`000?oRk=Soh^cHon;/f?l000001?oRjML01Ol0003o
hNKFon7Ve_oQi]Ko000000?oh>;F0_l00005olo4d005o`000?o;_/kobkk>ol^nc_l000001?o7^<d0
0ol0003o`[;;ol:bb`02ol:bb`05o`000?nm[<Wo_Jc9okf/bOl000000ongY/L3o`0000?o/Io500Go
0000ojbI`on/VL?o[9W3o`000003ojJC`P03o`000?nQSKooXHfo00;oXHfo00Go0000oib8_OnLR;go
W8Rmo`000003oiN3_005o`000?nCOk[oTgnjoi=o^_l000000on?NkT01Ol0003oS7Rgo`000?n=NKSo
000000?oRgJg00Go0000ohYf]ol0003oR7Bfo`000002ohQd]P05o`000?n7LkKo0000ohIc]_l00000
0on6L[H01ol0003oQG>gohEc]on5LkOo0000ohEb]ol000000on4LkP01Ol0003oPgBjoh=d^_l0003o
QWBh00CoQGJj00Go0000ohEg_?n5MkcoQGNlo`000004ohEh_P05o`000?n4N/3oQ7[0ohAj`?l00000
1?n4O<<2o`0000?oTXG21OnDRLD01Ol0003oUhg7oiN=aonGSLOo000000CoVI;;00?o0000oibFc_nL
U/h00_nLU/h00ol0003oWY_AoijKd@03oijKd@03o`000?nQXMCoXJ7D00?oXJ7D00?o0000oj>Vf?nS
Y]P00_nSY]P01?l0003oYZcKojJ/fonV[=/2o`000004ol2keOl0003o`l7Ho`0000;o`l7H00?o0000
olG6foo5a]/00oo5a]/00ol0003oal_MolO;g@02olO;g@03o`000?o7d>3oam3P00?oam3P00?o0000
ooooooooool07Oooool00ol0003oooooo`000005ooooo`03oeEEEOmVIVKo000000Oooooo000Toooo
o`03o`000?oooooooooo03Oooooo00Go0000on7^fOoQk]WohNkIo`000004on;/f003o`000?oRjMOo
h^WG00;oh^WG00Ko0000on7Ve_oQi]KohNKFo`000?oPh]H2o`000003om;9dOl0003oclC@00CoclC@
00Go0000ol^nc_o;_/kobkk>o`000005olNhc@05o`000?o2//_o`[;;ol:bbol000000onm[<T01?l0
003o]jK7o`000?l00002okNVa`05o`000?naWlGo/Io5ok6OaOl000000on/VL<01Ol0003oYY?2ojJC
`_nVTl;o000000CoXHfo00Go0000oib8_OnLR;goW8Rmo`000003oiN3_005o`000?nCOk[oTgnjoi=o
^_l000000on?NkT00ol0003oS7Rgohah]`02o`0000CoRgJg00Co0000ohQd]_n8M;Ko00000_n8M;H0
0ol0003oQg>fo`000002ohIc]P03o`000?n6L[KoQW:f00;o00000_n5LkL00ol0003oQG:go`000004
ohAc^005o`000?n3M;[o0000ohId^?l000001?n5M[X01Ol0003oQGNlohEg_?n5Mkco000000?oQGRn
00?o0000ohAj`?n4N/000_n4N/001Ol0003oQ7c3o`000?l0003oT8;000CoTXG200?o0000oiB9aOnD
RLD00_nDRLD00ol0003oUhg7oiN=a`02oiN=a`03o`000?nIT/_oVI;;00;oVI;;00?o0000oibFc_nL
U/h00_nLU/h00ol0003oWY_AoijKd@03oijKd@03o`000?nQXMCoXJ7D00?oXJ7D00?o0000oj>Vf?nS
Y]P00_nSY]P00ol0003oYZcKo`000004ol2ke@;o00000oo3`MP00ol0003oaLKKolG6f`02olG6f`03
o`000?o7bmgoal_M00?oal_M00?o0000olO@h?o7d>000oo7d>000ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00cooooo000Tooooo`;o0000>?ooool01Ol0003ohNkIon7^fOoQk]Wo000000Co
h^cH00?o0000on;YeooRjML00_oRjML01?l0003ohNKFon7Ve_oQi]H2o`0000?od/WA00?o0000olo4
d?o?a=000oo?a=001Ol0003obkk>ol^nc_o;_/ko000000GoakS=00Go0000ol:bboo2//_o`[;;o`00
0002okf/b@?o00001?ngY/L01Ol0003o/Io5ok6OaOnaWlGo000000?o[9W300?o0000ojJC`_l00000
1Ol000000onQSKoo0000oib8_@02oib8_@05o`000?nGPkcoUh>loiN3_?l000000onCOkX01Ol0003o
Sg^iohmk^On?NkWo000000?oS7Rg0_l00003oh]f]`07o`000?n8M;KoR7BfohQd]_l0003oR7Bfo`00
0002ohMc]P;oQW>f00So0000ohIb]_n6L[Ko0000ohIb]_l0003oQG>go`0000;oQG:g00?o0000ohAc
^?n4LkP00_n4LkP01Ol0003oQWBhohId^?n6M;So000000?oQGJj00Go0000ohEg_?n5MkcoQGNlo`00
0004ohEh_P04o`000?n4N/3oQ7[0ohAj`0;o00001?n@P/04oi:5`P05o`000?nDRLGoU8W5oiB9aOl0
00001?nGSLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/koW9K>00;oW9K>00?o0000oijKdOnN
Vm401?nNVm400ol0003oXJ7Doj6Qe002oj6Qe003o`000?nSY]SoXjKH00;oXjKH0_l00005ol2ke@03
o`000?o3`MSo000000;o`l7H00?o0000olG6foo5a]/00oo5a]/00ol0003oal_MolO;g@02olO;g@03
o`000?o7d>3oam3P00?oam3P00?o0000ooooooooool07_ooool3o`0000gooooo000Tooooo`03o`00
0?oooooooooo03Oooooo00Go0000on7^fOoQk]WohNkIo`000004on;/f005o`000?oRjMOoh^WGon;Y
eol000000ooQi]H2o`0000God/WA00?o0000olo4d?o?a=000_o?a=001Ol0003obkk>ol^nc_o;_/ko
000000GoakS=00Co0000ol:bboo2//_o`[;;0ol00002okf/b@03o`000?ngY/Oo]jK700;o]jK700?o
0000ok6OaOl000001ol00002oif:_`CoVHJm2?l000000onGPkco0000oi=o^P02oi=o^P03o`000?n?
NkWoSg^i00;oSg^i00?o0000ohah]on<N;L00_n:MKH00ol0003oRgJgoh]f]`02o`0000GoR7Bf1Ol0
0002ohIb]P04o`000?n6L[KoQW:fo`0000CoQG:g00?o0000ohAc^?n4LkP00_l00003ohId^005o`00
0?n5M[[oQGJjohEf^_l000001?n5Mk`01_l0003oQGRnohEh__n5N;ko0000ohAj`0;o000000?oSgnn
oi22`?n@P/000on@P/001Ol0003oTXG2oi:5`_nBQL;o000000CoU8W500?o0000oiN=aonGSLL00_nG
SLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/koW9K>00;oW9K>00?o0000oijKdOnNVm400onN
Vm400ol0003oXJ7Doj6Qe003oj6Qe006o`000?nSY]So0000o`000?nm]];o00001Oo0^mD01?l0003o
`l7Hol?1f?l00002ol?1f003o`000?o5a]_oaLKK00;oaLKK00?o0000olO;gOo7bmd00oo7bmd00ol0
003oam3PolO@h002olO@h003o`000?oooooooooo01_ooooo0ol00002ooooo`03o`000?oooooooooo
00_ooooo000Tooooo`03o`000?oooooooooo03Oooooo00Go0000on7^fOoQk]WohNkIo`000004on;/
f005o`000?oRjMOoh^WGon;Yeol000000_oQi]H00ol0003oe<gCo`000005om;9d@03o`000?o?a=3o
clC@00;oclC@00?o0000ol^nc_o;_/h00_o;_/h00ol0003oakS=olNhc@02olNhc@Co000000?o`[;;
o`000?nm[<T00_nm[<T01?l0003o]jK7okNVaongY/L3o`0000;oYI?31?nQSl44oif:_`03o`000?nI
Q[goVHJm00;oVHJm1?nEP[`3oi9n^P?o00000_nCOkX00ol0003oSg^iohmk^@02ohmk^@04o`000?n<
N;OoS7Rgo`0000;oRWFf00Go0000oh]f]ol0003oR7Bfo`000002ohQd]P06o`000?n8M;Ko0000ohMb
]Ol0003oQW:e0_l000001On6L[Ko0000ohIb]_n6L[Ko000000CoQG:g00?o0000ohAc^?l000000_n6
LkL01Ol0003oQWBhohId^?n6M;So000000?oQGJj00?o0000ohEg_?n5Mk`00_n5Mk`00ol0003oQGRn
ohEh_P02o`0000CoSgnn1?n@P/000ol0003oTXG2oi:5`P02oi:5`P05o`000?nDRLGoU8W5oiB9aOl0
00001?nGSLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/koW9K>00;oW9K>00?o0000oijKdOnN
Vm401?nNVm400ol0003oXJ7Doj6Qe002oj6Qe0;o00001?nm]]800ol0003o`;_Eol2ke@03ol2ke@06
o`000?o3`MSo`l7Ho`000?o3`MSo00001Oo5a]/00ol0003oal_MolO;g@02olO;g@03o`000?o7d>3o
am3P00;oam3P0_l0000Iooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0
003oooooooooo`0fooooo`03o`000?oQk]WohNkI00;ohNkI00?o0000on;/f?oRk=P00_oRk=P01ol0
003oh^WGon;YeooRjMOo0000on7Ve_l000000_oDcM<00ol0003od/WAom;9d@03om;9d@03o`000?o?
a=3oclC@00;oclC@00?o0000ol^nc_o;_/h00_o;_/h00ol0003oakS=olNhc@03o`0000Co`[;;00Co
0000okf/bOnm[<Wo_Jc91?l000000onYV<GoYI?3ojFC``02ojFC``05o`000?nQSl7oXHo1oj6?`Ol0
00001?nMR[l4oiV6_@05o`000?nEP[coUH:loiF2_?l000000onBO[X2ohmk^@03o`000?nCOk[o0000
00CoSg^i00Co0000ohah]on<N;Oo00000on:MKH01On;M[Oo0000ohQd]_n8M;Ko000000;oR7Bf00Oo
0000ohMb]Ol0003o0000ohIb]Ol0003oQW:e00;o00000_n6L[H2o`0000CoQG:g00Go0000ohIc]on6
LkOoQW>go`000003ohId^005o`000?n5M[[oQGJjohEf^_l000001?n5Mk`01?l0003oQGRno`000?n=
O;`5ohmo_P03o`000?n@P/3oT8;000;oT8;000Go0000oi:5`_nBQL;oTXG2o`000004oiB9a@03o`00
0?nGSLOoUhg700;oUhg700?o0000oiVBbonIT//00_nIT//00ol0003oW9K>oibFcP02oibFcP03o`00
0?nNVm7oWY_A00?oWY_A00Oo0000oj6Qe?nQXMCoXJ7Do`000?ni[m3o000000Co_KKB00?o0000ol2k
eOo0^mD00oo0^mD01_l0003o`l7Hol?1f?l0003o`l7Ho`0000GoaLKK00?o0000olO;gOo7bmd00oo7
bmd01_l0003oam3PolO@h?l0003ofnOMo`0001Gooooo1?l00008ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o0000=oooool00ol0003ohNkIon7^f@02on7^f@03o`000?oRk=Soh^cH00;oh^cH
00Co0000on;YeooRjMOoh^WG0_l00004omC=d`03o`000?oBbM7od/WA00;od/WA00?o0000olo4d?o?
a=000oo?a=001?l0003obkk>ol^nc_o;_/h3o`0000;oakS=00?o0000ol:bboo2///00_o2///00ol0
003o_Jc9o`000002o`0000CoZIS500?o0000ojFC`onUTl<00_nUTl<4oj6?`@CoWHZo00?o0000oiV6
_OnIQ[d00_nIQ[d4oiF2_0?oTWjj00Co0000ohmk^On?NkWoSg^i1?l000000on?NkWo0000ohah]`02
ohah]`05o`000?n:MKKoRWFfohYe]_l000000on8M;H01_l0003oR7Bfo`000?n7L[Go0000ohMb]@;o
00000_n6L[D01_l0003oQW:fohIb]_l0003oQW:fo`0000?oQG:g00?o0000ohIc]on6LkL00_n6LkL0
1Ol0003oQWBhohId^?n6M;So000000?oQGJj00Co0000ohEg_?n5MkcoQGNl0_l00003ohel_0CoSgnn
00?o0000oi22`?n@P/000_n@P/000ol0003oTXG2oi:5`P02oi:5`P05o`000?nDRLGoU8W5oiB9aOl0
00001?nGSLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/koW9K>00?oW9K>00?o0000oijKdOnN
Vm400onNVm400ol0003oXJ7Do`000003okV_d005o`000?nm]];o_KKBokffd_l000001Oo0^mD01ol0
003o`l7Hol?1f?o3`MSo0000ol?1f?l000001Oo5a]/00ol0003oal_MolO;g@02olO;g@03o`000?o7
d>3o000000;ofnOM00?o0000ooooooooool04?ooool3o`0000gooooo00?o0000ooooooooool02_oo
ool002?ooooo00?o0000ooooooooool0=oooool00ol0003ohNkIon7^f@02on7^f@05o`000?oRk=So
h^cHon;/f?l000000ooRjML2o`0000Goe<gC00?o0000om;9dOoBbM400_oBbM400ol0003oclC@olo4
d003olo4d0Go00001?o7^<d01?l0003o`[;;ol:bboo2///3o`0000;o[Ig71_nYV<D4ojFC``05o`00
0?nQSl7oXHo1oj6?`Ol000000onMR[l00ol0003oVHJmoiV6_@02oiV6_@05o`000?nEP[coUH:loiF2
_?l000000onBO[X3ohmk^@04o`000?n=NKSoSGVhohei^0?o00000_n<N;L01_l0003oRWFfohYe]_n:
MKKoR7>eo`0000?oR7Bf00Go0000ohMb]Ol0003o0000ohMb]@02o`0000;oQW:e00?o0000ohIb]_l0
00000_n6L[H01_l0003oQG:gohEb]ol0003oQW>fo`0000?oQW>g00Go0000ohId^?n6M;SoQWBho`00
0003ohEf^P05o`000?n5Mkco0000o`000?n<N[X01?n=O;`00ol0003oSgnnohmo_P02ohmo_P03o`00
0?n@P/3oT8;000;oT8;000Go0000oi:5`_nBQL;oTXG2o`000004oiB9a@03o`000?nGSLOoUhg700;o
Uhg700?o0000oiVBbonIT//00_nIT//00ol0003oW9K>oibFcP02oibFcP03o`000?nNVm7oWY_A00?o
WY_A0_l00004okV_d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0^mD00oo0^mD01?l0003o
`l7Hol?1f?o3`MP2o`0000GoaLKK00?o0000olO;gOo7bmd00oo7bmd01Ol0003ofnOMom_WgOoKimgo
000000oooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
03Oooooo00?o0000on7^fOoQk]T00_oQk]T01_l0003oh^cHon;/f?oRk=So0000on;Ye`;o000000?o
e]7Do`000?oDcM<01?oDcM<00ol0003od/WAom;9d@03om;9d@03o`000?o?a=3oclC@00?o00000oo;
_/h00ol0003oakS=olNhc@03olNhc@04o`000?o2//_o0000ok6Sb@Go[Ig71OnYV<D01Ol0003oYI?3
ojFC`onUTl?o000000?oXHo100?o0000oif:_onMR[l00_nMR[l01Ol0003oVHJmoiV6_OnIQ[go0000
00?oUH:l00Go0000oi9n^_nBO[[oTWjjo`000002ohmk^@03o`000?n=NKSoSGVh00;oSGVh00Go0000
oh]f]ol0003oS7Rgo`000003ohYe]P03o`000?n8LkGo000000;oR7Bf00Co0000ohMb]Ol0003oQg:e
0ol00002ohIb]@?o00000on6L[H01Ol0003oQG:go`000?n6LkKo000000?oQW>g00?o0000ohId^?n6
M;P00_n6M;P00ol0003oQGJjohEf^P02o`0000CoS7Zj0on=O;`00ol0003oSgnnohmo_P02ohmo_P03
o`000?n@P/3oT8;000;oT8;000?o0000oi:5`_nBQL800_nBQL801Ol0003oU8W5oiB9aOnDRLGo0000
00CoUhg700?o0000oiVBbonIT//00onIT//00ol0003oW9K>oibFcP02oibFcP03o`000?nNVm7oWY_A
00;o000000?o]JW=o`000?ni[m000oni[m000ol0003o_KKBokffdP02okffdP03o`000?o0^mGo`;_E
00?o`;_E00?o0000ol?1f?o3`MP00_o3`MP00ol0003oaLKKolG6f`03olG6f`03o`000?o7bmgoal_M
00;oal_M0_l00003om_Wg@03o`000?oooooooooo00Wooooo1?l0000Cooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000on7^fOoQk]T00_oQk]T01?l0003o
h^cHon;/f?oRk=P2o`0000?oe]7D00?o0000omC=dooDcM<00ooDcM<00ol0003od/WAom;9d@03om;9
d@?o00000_o?a=001Ol0003obkk>ol^nc_o;_/ko000000GoakS=0_l00003ok6Sb@Co[Ig700?o0000
ojVHaOnYV<D00_nYV<D00ol0003oYI?3ojFC``02ojFC``05o`000?nQSl7oXHo1oj6?`Ol000000onM
R[l01Ol0003oVHJmoiV6_OnIQ[go000000?oUH:l00Go0000oi9n^_nBO[[oTWjjo`000003ohmk^@05
o`000?n=NKSoSGVhohei^?l000000on;M[L2o`0000;oRWFf00So0000ohQc]On8LkGoR7Bfo`000?n7
L[Go0000ohMb]@?o000000KoQW:eo`000?n6L[Go0000ohIb]Ol00004ohIb]P05o`000?n6LkKoQW>f
ohIc]_l000000on6LkL02?l0003oQWBhohId^?n6M;So0000ohEf^_l0003oRWRi1On<N[X01Ol0003o
SGblohel_?n=O;co000000CoSgnn00?o0000oi22`?n@P/000_n@P/001Ol0003oTXG2oi:5`_nBQL;o
000000CoU8W500?o0000oiN=aonGSLL00_nGSLL00ol0003oVI;;oiVBb`02oiVBb`03o`000?nLU/ko
W9K>00;oW9K>00?o0000oijKdOl000000oneZLd00ol0003o^Jo@okV_d003okV_d005o`000?nm]];o
_KKBokffd_l000001_o0^mD01?l0003o`l7Hol?1f?o3`MP2o`0000GoaLKK00Ko0000olO;gOo7bmgo
0000omcTfol00003om_Wg@03o`000?oooooooooo00Kooooo0ol0000Gooooo`03o`000?oooooooooo
00[ooooo000Sooooo`?o0000=oooool01Ol0003ohNkIon7^fOoQk]Wo000000?oh^cH0_l00005omKA
e003o`000?oDcM?oe<gC00;oe<gC00?o0000om;9dOoBbM401?l00004olo4d003o`000?o;_/kobkk>
00;obkk>00Co0000olNhcOo7^<goakS=0_l00004ok6Sb@Co[Ig700?o0000ojVHaOnYV<D00onYV<D0
1Ol0003oYI?3ojFC`onUTl?o000000?oXHo100Go0000oif:_onMR[ooWHZoo`000003oiV6_@05o`00
0?nEP[coUH:loiF2_?l000000onBO[X01Ol0003oSg^iohmk^On?NkWo000000CoSGVh00So0000oh]f
]on;M[Oo0000ohUd]_l0003oRWFfo`0000?oR7>e00go0000ohMb]On7L[Go0000ohMb]Ol0003oQg:e
ohIb]Ol0003oQW:eo`000?n6L[Go000000?oQW:f0_l00003ohIc]P05o`000?n6LkOoQW>gohIc]ol0
00000_n6M;P3o`0000?oRWRi1?n<N[X01Ol0003oSGblohel_?n=O;co000000CoSgnn00?o0000oi22
`?n@P/000_n@P/001Ol0003oTXG2oi:5`_nBQL;o000000CoU8W500?o0000oiN=aonGSLL00onGSLL0
0ol0003oVI;;oiVBb`02oiVBb`04o`000?nLU/koW9K>oibFcP;o00001OneZLd00ol0003o^Jo@okV_
d002okV_d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0^mD00oo0^mD00ol0003o`l7Hol?1
f002ol?1f003o`000?o5a]_oaLKK00?oaLKK00?o0000olO;gOl000000_oLi=/01Ol0003ofnOMom_W
gOoKimgo000000Gooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oo
oooooooo03Oooooo00Go0000on7^fOoQk]WohNkIo`000002on;/f003o`000?oGeMKo000000Goe]7D
00?o0000omC=dooDcM<00_oDcM<3o`0000?od/WA00?o0000olo4d?o?a=000_o?a=000ol0003obkk>
ol^ncP02ol^ncPCo000000?o]JS;ok6SbOnaXlT00onaXlT00ol0003o[Ig7ojfMa`02ojfMa`03o`00
0?nYV<GoZIS500;oZIS500Go0000ojFC`onUTl?oYI?3o`000003oj6?`@03o`000?nMR[ooWHZo00;o
WHZo00Go0000oiV6_OnIQ[goVHJmo`000003oiF2_005o`000?nBO[[oTWjjoi9n^_l000000_n?NkT0
0ol0003oSGVhohei^002ohei^004o`000?n;M[OoRgJgo`0000;oRGBf00?oRWFfo`000?n8LkD00_n8
LkD01On7L[Go0000ohMb]Ol0003oQg:e00Co000000?oQW:eo`000?n6L[D00_l000001On6L[Ko0000
ohIb]On6L[Go000000?oQW>f00?o0000ohIc]on6LkL00ol00002ohUf^0CoRWRi00?o0000ohaj^_n<
N[X00_n<N[X01Ol0003oSGblohel_?n=O;co000000?oSgnn00?o0000oi22`?n@P/000_n@P/000ol0
003oTXG2oi:5`P02oi:5`P03o`000?nDRLGoU8W500;oU8W500?o0000oiN=aonGSLL00_nGSLL00ol0
003oVI;;oiVBb`02oiVBb`06o`000?nLU/ko0000o`000?naY<_o00001OneZLd00ol0003o^Jo@okV_
d002okV_d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0^mD00oo0^mD00ol0003o`l7Hol?1
f003ol?1f003o`000?o5a]_oaLKK00;oaLKK0_l00003omcTf`05o`000?oKimgofnOMom_WgOl00000
0_ooool3o`0001gooooo00?o0000ooooooooool02_ooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`0hooooo`07o`000?oQk]WohNkIon7^fOl0003oh^cHo`000002omOEeP03o`000?oFdMCo
e]7D00?oe]7D00?o0000omC=dol000000_l000000ooDcM?o0000om;9d@04om;9d@05o`000?o?a=3o
clC@olo4d?l000000oo;_/h2o`0000Go]JS;1OnaXlT01Ol0003o[Ig7ojfMaon]WLOo000000CoZIS5
00Go0000ojFC`onUTl?oYI?3o`000004oj6?`@05o`000?nMR[ooWHZooif:_ol000000onIQ[d01Ol0
003oUH:loiF2_?nEP[co000000?oTWjj00Go0000ohmk^On?NkWoSg^io`000003ohei^005o`000?n;
M[OoRgJgoh]f]ol000000_n9M;H2o`0000;oR7>e00?o0000ohMb]Ol000000on7L[D6o`0000;oQW:e
00Go0000ohIb]On6L[GoQW:eo`000003ohIc]P04o`000?n6LkOo0000ohQe]`GoRGJh1?n:N;T01Ol0
003oS7Zjohaj^_n<N[[o000000?oSGbl00?o0000ohmo__n?Okh00_n?Okh00ol0003oT8;0oi22`002
oi22`005o`000?nBQL;oTXG2oi:5`_l000001?nDRLD00ol0003oUhg7oiN=a`03oiN=a`04o`000?nI
T/_oVI;;oiVBb`;o00001?naY</00ol0003o]JW=okFYc@02okFYc@03o`000?ni[m3o^Jo@00?o^Jo@
00?o0000okffd_nm]]800_nm]]800ol0003o`;_Eol2ke@03ol2ke@03o`000?o3`MSo`l7H00;o`l7H
00?o0000olG6foo5a]/00_l000000ooKgmWo0000omcTf`02omcTf`04o`000?oKimgofnOMom_Wg@?o
00008?ooool00ol0003oooooooooo`0:ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0hooooo`04o`000?oQk]WohNkIon7^f@;o00001?oGeMH01?l0003oe]7DomKAe?oF
dM@3o`0000Coe<gC00?o0000om;9dOoBbM400ooBbM400ol0003oclC@olo4d002olo4d004o`000?o;
_/ko0000okV]cPKo]JS;00?o0000ok6SbOnaXlT00_naXlT01Ol0003o[Ig7ojfMaon]WLOo000000Co
ZIS500?o0000ojFC`onUTl<00_nUTl<01Ol0003oXHo1oj6?`OnQSl7o000000?oWHZo00Go0000oiV6
_OnIQ[goVHJmo`000003oiF2_005o`000?nBO[[oTWjjoi9n^_l000000on?NkT01Ol0003oSGVhohei
^?n=NKSo000000?oRgJg00Go0000ohUd]_n9M;Ko0000ohQc]@02o`000005ohQc]Ol0003oQg:eo`00
0?n7L[D01?l000000on6LKCo0000o`000002ohIb]@03o`000?n6L[GoQW:e00;oQW:e00?o0000ohIc
]_n6LkH00_l00003ohQe]`CoRGJh00Go0000ohYh^On:N;WoRWRio`000004ohaj^P05o`000?n=O;co
SGblohel_?l000000on?Okh00ol0003oT8;0oi22`002oi22`003o`000?nBQL;oTXG200;oTXG200Go
0000oiB9aOnDRLGoU8W5o`000005oiN=a`06o`000?nIT/_o0000o`000?n]W/So00001?naY</00ol0
003o]JW=okFYc@03okFYc@03o`000?ni[m3o^Jo@00;o^Jo@00?o0000okffd_nm]]800_nm]]800ol0
003o`;_Eol2ke@03ol2ke@03o`000?o3`MSo`l7H00;o`l7H0ol00003om_Of@05o`000?oLi=_og>CK
omcTfol000000ooKimd00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02
ooooo`;o0000>?ooool01?l0003ohNkIon7^fOoQk]T2o`0000GoemGF00Co0000omKAe?l0003o0000
0_oFdM@00ol0003oe<gComC=d`02omC=d`03o`000?oBbM7od/WA00?od/WA00?o0000olo4d?o?a=00
0_o?a=02o`0000?o^Jg>1OneZ</00ol0003o/J?9ok6Sb@02ok6Sb@03o`000?n]WLOo[Ig700;o[Ig7
00?o0000ojVHaOnYV<D00_nYV<D01Ol0003oYI?3ojFC`onUTl?o000000?oXHo100Go0000oif:_onM
R[ooWHZoo`000003oiV6_@05o`000?nEP[coUH:loiF2_?l000000onBO[X01Ol0003oSg^iohmk^On?
NkWo000000?oSGVh00Go0000oh]f]on;M[OoRgJgo`000003ohUd]P04o`000?n8LkGoR7>eohQc]@;o
00000_n7L[D01Ol0003oQW6do`000?l0003oQW6d00;o000000CoQW:eo`000?n6L[Go00000on6L[D0
1?l0003oQW>fo`000?n8LkH4ohQe]`05o`000?n9M[SoRGJhohUf^?l000000on:N;T00ol0003oS7Zj
ohaj^P02ohaj^P05o`000?n=O;coSGblohel_?l000000on?Okh00ol0003oT8;0oi22`003oi22`005
o`000?nBQL;oTXG2oi:5`_l000001?nDRLD00ol0003oUhg7oiN=a`02oiN=a`;o00000on]W/P00ol0
003o/JC;ok6Tb`02ok6Tb`03o`000?neZLgo]JW=00?o]JW=00?o0000okV_d?ni[m000_ni[m000ol0
003o_KKBokffdP02okffdP03o`000?o0^mGo`;_E00?o`;_E00?o0000ol?1f?o3`MP00oo3`MP2o`00
00?ofmoI00Go0000omcTfooLi=_og>CKo`000003om_Wg@03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=oooool01_l0003ohNkIo`000?l0
003oemSHo`0000CoemGF0ol00004omKAe003o`000?oDcM?oe<gC00?oe<gC00?o0000om;9dOoBbM40
0_oBbM401?l0003oclC@olo4d?o?a=02o`0000Co^Jg>00?o0000okFXboneZ</00oneZ</00ol0003o
/J?9ok6Sb@02ok6Sb@05o`000?n]WLOo[Ig7ojfMaol000001?nYV<D01Ol0003oYI?3ojFC`onUTl?o
000000?oXHo100?o0000oif:_onMR[l00_nMR[l01?l0003oVHJmoiV6_Ol00003oiF2_005o`000?nB
O[[oTWjjoi9n^_l000000on?NkT00ol0003oSGVhohei^002ohei^004o`000?n;M[OoRgJgo`0000?o
RGBf00Go0000ohQc]On8LkGoR7>eo`000003ohMb]@Oo000000CoQW:eo`000?n6L[Go00000_n6L[D3
o`0000?oR7>f0on8MKL00ol0003oRGJhohUf^002ohUf^005o`000?n:N;WoRWRiohYh^Ol000000on<
N[X01Ol0003oSGblohel_?n=O;co000000CoSgnn00?o0000oi22`?n@P/000_n@P/000ol0003oTXG2
oi:5`P02oi:5`P06o`000?nDRLGoU8W5oiB9aOl0003oUhg70ol000000onXVLKo0000ojfNb003ojfN
b003o`000?naY<_o/JC;00;o/JC;00?o0000okFYcOneZLd00_neZLd00ol0003o^Jo@okV_d003okV_
d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0^mD00oo0^mD01?l0003o`l7Hol?1f?o3`MP2
o`000005om_OfOl0003ofmoIom_OfOl000000ooLi=/01Ol0003ofnOMom_WgOoKimgo000002?ooooo
00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0gooooo`;o
00001?oGf=P4o`0000;oemGF00?o0000omKAe?oFdM@00ooFdM@00ol0003oe<gComC=d`02omC=d`03
o`000?oBbM7od/WA00;od/WA00Go0000olo4d?o?a=3o0000okbbd006okV]cP03o`000?neZ<_o]JS;
00;o]JS;00?o0000ok6SbOnaXlT00_naXlT01Ol0003o[Ig7ojfMaon]WLOo000000CoZIS500Go0000
ojFC`onUTl?oYI?3o`000004oj6?`@05o`000?nMR[ooWHZooif:_ol000000onIQ[d01Ol0003oUH:l
oiF2_?nEP[co000000?oTWjj00Go0000ohmk^On?NkWoSg^io`000003ohei^005o`000?n;M[OoRgJg
oh]f]ol000000_n9M;H01Ol0003oR7>eohQc]On8LkGo000000?oQg:e00?o0000ohIa]?l000001Ol0
0002ohIb]@?o00000_n7L[D01Ol0003oR7>fohQc]_n8LkKo000000?oR7Fg00Go0000ohUf^?n9M[So
RGJho`000003ohYh^@03o`000?n<N[[oS7Zj00;oS7Zj00Go0000ohel_?n=O;coSGblo`000003ohmo
_P03o`000?n@P/3oT8;000?oT8;000Go0000oi:5`_nBQL;oTXG2o`000002oiB9a@?o00001?nXVLH0
0ol0003o[Ik8ojfNb002ojfNb003o`000?naY<_o/JC;00;o/JC;00?o0000okFYcOneZLd00oneZLd0
0ol0003o^Jo@okV_d002okV_d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0^mD00oo0^mD0
2?l0003o`l7Hol?1f?l0003ofM[Go`000?oKgmWo00000_oKgmT01Ol0003og>CKomcTfooLi=_o0000
00?ofnOM00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0gooooo`04o`000?oGf=SoemSHomOHf0?o00001OoGeMH00ol0003oe]7DomKAe003
omKAe003o`000?oDcM?oe<gC00;oe<gC00?o0000om;9dOoBbM400ooBbM42o`0000?o_;;@1Oni[Lh0
0ol0003o]JS;okFXb`03okFXb`03o`000?naXlWo/J?900;o/J?900Go0000ojfMaon]WLOo[Ig7o`00
0003ojVHa@03o`000?nUTl?oYI?300;oYI?300Go0000oj6?`OnQSl7oXHo1o`000003oif:_`06o`00
0?nIQ[goVHJmoiV6_Ol0003oUH:l5Ol000000on9M;Ko0000ohQc]@02ohQc]@03o`000?n7L[GoQg:e
00;o000000[oQW6do`000?l0003o0000ohIa]?l0003oQW:eo`000?n7L[Go00001?n7L[D01?l0003o
R7>fohQc]_l00003ohQe]`05o`000?n9M[SoRGJhohUf^?l000001?n:N;T01Ol0003oS7Zjohaj^_n<
N[[o000000?oSGbl00?o0000ohmo__n?Okh00_n?Okh00ol0003oT8;0oi22`002oi22`004o`000?nB
QL;oTXG2oi:5`P?o00000_nTTl@6ojRIaP05o`000?n]W/So[Ik8ojfNb?l000001?naY</00ol0003o
]JW=okFYc@03okFYc@03o`000?ni[m3o^Jo@00;o^Jo@00?o0000okffd_nm]]800_nm]]800ol0003o
`;_Eol2ke@03ol2ke@03o`000?o3`MSo000000;ofM[G00Ko0000om_OfOoKgmWo0000om_OfOl00003
omcTf`05o`000?oKimgofnOMom_WgOl000008oooool00ol0003oooooooooo`09ooooo`0000GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`06ooooo`;o0000>?ooool4o`0000;oemSH00?o0000omOEe_oGeMH00ooGeMH00ol0003oe]7D
omKAe003omKAe003o`000?oDcM?oe<gC00;oe<gC00?o0000om;9dOoBbM400_oBbM42o`0000Co_;;@
00?o0000okV]c_ni[Lh00_ni[Lh00ol0003o]JS;okFXb`03okFXb`03o`000?naXlWo/J?900;o/J?9
00Go0000ojfMaon]WLOo[Ig7o`000004ojVHa@05o`000?nUTl?oYI?3ojFC`ol000000onQSl400ol0
003oWHZooif:_`02oif:_`03o`000?nIQ[go000000;o00000_n=O;`01Ol0003oS7Zjohaj^_n<N[[o
000000?oRgRi00Go0000ohUf^?n9M[SoRGJho`000003ohQe]`03o`000?n8LkKoR7>f00Wo000000?o
QW6do`000?l000001Ol00003ohMb]@05o`000?n7L[GoQg:eohMb]Ol000000on8LkH01?l0003oR7Fg
ohQe]ol00004ohUf^005o`000?n:N;WoRWRiohYh^Ol000001?n<N[X01Ol0003oSGblohel_?n=O;co
000000?oSgnn00?o0000oi22`?n@P/000_n@P/001Ol0003oTXG2o`000?l0003oX8k200CoY9?400?o
0000ojRIa_nXVLH00onXVLH00ol0003o[Ik8ojfNb002ojfNb003o`000?naY<_o/JC;00;o/JC;00?o
0000okFYcOneZLd00_neZLd00ol0003o^Jo@okV_d003okV_d003o`000?nm]];o_KKB00;o_KKB00?o
0000ol2keOo0^mD00_o0^mD2o`0000?ofM[G00Co0000om_OfOoKgmWofmoI0_l00003omcTf`05o`00
0?oKimgofnOMom_WgOl000008oooool00ol0003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000oooo
ooooool0=_ooool4o`0000GoemSH00?o0000omOEe_oGeMH00ooGeMH00ol0003oe]7DomKAe002omKA
e003o`000?oDcM?oe<gC00;oe<gC00?o0000om;9dOoBbM400_l000000ono]m;o_;;@okbbd004okbb
d003o`000?ni[Lko^Jg>00;o^Jg>00?o0000okFXboneZ</00_neZ</00ol0003o/J?9ok6Sb@02ok6S
b@05o`000?n]WLOo[Ig7ojfMaol000001?nYV<D01Ol0003oYI?3ojFC`onUTl?o000000CoXHo100?o
0000oif:_ol000000ol000000on?Okko0000ohel_003ohel_005o`000?n<N[[oS7Zjohaj^_l00000
0on;N;T01?l0003oRGJhohUf^?l00003ohQe]`05o`000?n8LkKoR7>fohQc]_l000000on7L[D00ol0
003oQg:eohMb]@09o`0000?oQg:e00Go0000ohMb]On7L[GoQg:eo`000003ohQc]P05o`000?n8MKOo
R7FgohQe]ol000000on9M[P00ol0003oRWRiohYh^@02ohYh^@05o`000?n<N[[oS7Zjohaj^_l00000
0on=O;`01Ol0003oSgnnohmo__n?Okko000000?oT8;00ol00003oj2>`P03o`000?nTTlCoY9?400;o
Y9?41OnXVLH00ol0003o[Ik8ojfNb002ojfNb003o`000?naY<_o/JC;00;o/JC;00?o0000okFYcOne
ZLd00_neZLd00ol0003o^Jo@okV_d003okV_d003o`000?nm]];o_KKB00;o_KKB00?o0000ol2keOo0
^mD00_l000000ooGe=Ko0000omWJe`02omWJe`03o`000?oKgmWofmoI00;ofmoI00Go0000omcTfooL
i=_og>CKo`000003om_Wg@03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool0027o
oooo00?o0000ooooooooool0<oooool3o`0000?ooooo00?o0000omOHf?oGf=P00ooGf=P00ol0003o
emGFomOEeP03omOEeP03o`000?oFdMCoe]7D00?oe]7D00?o0000omC=dooDcM<00_oDcM<2o`0000Co
_kOB1Onl/]000ol0003o^Jg>okV]cP02okV]cP03o`000?neZ<_o]JS;00?o]JS;00?o0000ok6SbOna
XlT00_naXlT01Ol0003o[Ig7ojfMaon]WLOo000000?oZIS500?o0000ojFC`onUTl<00_nUTl<00ol0
003oXHo1o`000003o`0000;oTH;000Go0000ohmo__n?OkkoSgnno`000003ohel_005o`000?n<N[[o
S7Zjohaj^_l000000on;N;T01Ol0003oRGJhohUf^?n9M[So000000?oR7Fg00Go0000ohQc]_n8LkKo
R7>fo`000002ohMb]@04o`000?n7L[GoQg:eohMb]@?o000000?oQW6do`000?n6LK@02Ol000001On7
L[Go0000ohQc]_n8LkKo000000?oR7Fg00Go0000ohUf^?n9M[SoRGJho`000004ohYh^@05o`000?n<
N[[oS7Zjohaj^_l000000on=O;`00ol0003oSgnnohmo_P05o`0000;oW8Zo1OnPS/84ojBCa003o`00
0?nXVLKoZ9W600;oZ9W600?o0000ojfNb?n]W/P00_n]W/P00ol0003o/JC;ok6Tb`02ok6Tb`03o`00
0?neZLgo]JW=00?o]JW=00?o0000okV_d?ni[m000_ni[m000ol0003o_KKBokffdP02okffdP03o`00
0?o0^mGo000000?oemCF00Go0000omWJeooIf]OofM[Go`000004om_Of@05o`000?oLi=_og>CKomcT
fol000000ooKimd00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`03
o`000?oooooooooo033ooooo0ol00006ooooo`03o`000?oGf=SoemSH00?oemSH00?o0000omOEe_oG
eMH00ooGeMH00ol0003oe]7DomKAe003omKAe004o`000?oDcM?oe<gComC=d`;o00001Ono]m800ol0
003o_;;@okbbd002okbbd003o`000?ni[Lko^Jg>00?o^Jg>00?o0000okFXboneZ</00_neZ</00ol0
003o/J?9ok6Sb@02ok6Sb@05o`000?n]WLOo[Ig7ojfMaol000001?nYV<D00ol0003oYI?3o`000003
o`0000;oThG21OnAP/001?l0003oSgnnohmo__l00003ohel_005o`000?n<N[[oS7Zjohaj^_l00000
0on;N;T01Ol0003oRGJhohUf^?n9M[So000000?oR7Fg00Go0000ohQc]_n8LkKoR7>fo`000003ohMb
]@04o`000?n7L[Go0000o`0000;oQW6d0ol000000on6LKCo0000o`000003ohMb]@?oR7>e2Ol00004
ohUf^005o`000?n:N;WoRWRiohYh^Ol000000_n<N[X8o`0000;oV8Fn1OnLR[l00ol0003oX8k2oj2>
`P02oj2>`P05o`000?nTTlCoY9?4ojBCa?l000001OnXVLH00ol0003o[Ik8ojfNb002ojfNb003o`00
0?naY<_o/JC;00;o/JC;00?o0000okFYcOneZLd00_neZLd00ol0003o^Jo@okV_d003okV_d004o`00
0?nm]];o_KKBokffdP;o00001?oGe=H01Ol0003ofM[GomWJeooIf]Oo000000CofmoI0_l00002omcT
f`05o`000?oKimgofnOMom_WgOl000009?ooool00ol0003oooooooooo`08ooooo`008Oooool2o`00
02kooooo0ol0000:ooooo`03o`000?oGf=SoemSH00?oemSH00?o0000omOEe_oGeMH00_oGeMH00ol0
003oe]7DomKAe003omKAe006o`000?oDcM?oe<gCo`000?o2_=Co00001_no]m800ol0003o_;;@okbb
d002okbbd003o`000?ni[Lko^Jg>00;o^Jg>00?o0000okFXboneZ</00_neZ</00ol0003o/J?9ok6S
b@02ok6Sb@05o`000?n]WLOo[Ig7ojfMaol000000onYV<D3o`0000;oUHW51OnCQL84oi62`004o`00
0?n?OkkoSgnno`0000CoSGbl00Go0000ohaj^_n<N[[oS7Zjo`000003oh]h^@04o`000?n9M[SoRGJh
o`0000?oR7Fg00Go0000ohQc]_n8LkKoR7>fo`000002ohMb]@?o000000?oQW:eo`000?n6LK@01Ol0
00000on6LKCo0000o`000002ohMb]@04o`000?n8LkGoR7>eohQc]@CoRGBf0on;M[L<o`0000;oTWjj
1?nEP[`4oiR5_P03o`000?nLR[ooW8Zo00?oW8Zo1?nPS/800ol0003oY9?4ojBCa002ojBCa003o`00
0?nXVLKoZ9W600;oZ9W600?o0000ojfNb?n]W/P00_n]W/P00ol0003o/JC;ok6Tb`02ok6Tb`03o`00
0?neZLgo]JW=00;o]JW=00?o0000okV_d?ni[m000oni[m001_l0003o_KKBokffd_l0003odlgDo`00
00CoemCF00Go0000omWJeooIf]OofM[Go`000004om_Of@05o`000?oLi=_o0000omcTfol000000_oK
imd2o`0002Cooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3
o`0000gooooo00?o0000omOHf?oGf=P00ooGf=P00ol0003oemGFomOEeP03omOEeP03o`000?oFdMCo
e]7D00?oe]7D0_l00003ol:le003o`000?no]m;o_kOB00?o_kOB00?o0000okbbd?nl/]000_nl/]00
0ol0003o^Jg>okV]cP03okV]cP03o`000?neZ<_o]JS;00;o]JS;00?o0000ok6SbOnaXlT00_naXlT0
1?l0003o[Ig7ojfMaon]WLL3o`000003oiN=aonERLGoUHW500?oUHW51?nCQL801Ol0003oTH;0oi62
`?nAP/3o000000?oSgnn00Go0000ohel_?n=O;coSGblo`000003ohaj^P05o`000?n;N;WoRgRioh]h
^Ol000000on9M[P01?l0003oR7FgohQe]ol00004ohQc]P;o000000?oQW:eo`000?n6L[D00_n6L[D0
0ol0003oQW6do`000004o`0000;oQg:e0_l000001On7L[Go0000ohQc]On8LkGo000000?oRGBf00Co
0000oh]f]on;M[OoRgJg1?n=N;P5ohmk^@CoTWjj00Go0000oiF2_?nEP[coUH:lo`000004oiR5_PGo
W8Zo00Go0000oj2>`_nPS/;oX8k2o`000004ojBCa003o`000?nXVLKoZ9W600;oZ9W600?o0000ojfN
b?n]W/P00_n]W/P00ol0003o/JC;ok6Tb`02ok6Tb`03o`000?neZLgo]JW=00?o]JW=00?o0000okV_
d?ni[m000_ni[m000ol0003o_KKBo`000002om?=e003o`000?oGe=KoemCF00;oemCF00Go0000omWJ
eooIf]OofM[Go`000004om_Of@03o`000?oLi=_og>CK00;o000000?ofnOMo`000?l000009Oooool0
0ol0003oooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?o00004?ooool00ol0
003oemSHomOHf003omOHf003o`000?oGeMKoemGF00?oemGF00?o0000omKAe?oFdM@00_oFdM@2o`00
00Co`[cD00?o0000okngd_no]m801?no]m800ol0003o_;;@okbbd002okbbd003o`000?ni[Lko^Jg>
00;o^Jg>00?o0000okFXboneZ</00_neZ</00ol0003o/J?9ok6Sb@02ok6Sb@03o`000?n]WLOo[Ig7
00;o00001?nGSLL4oiF9a@05o`000?nCQL;oThG2oi>5`_l000001?nAP/001?l0003oSgnnohmo__l0
0004ohel_005o`000?n<N[[oS7Zjohaj^_l000000_n;N;T01Ol0003oRGJhohUf^?n9M[So000000?o
R7Fg00?o0000ohQc]_l000000_l00003ohIb]@03o`000?n6L[GoQW:e00?o000000?oQW6do`000?l0
00000_l00003ohMb]@;o00000_n8LkD00ol0003oRGBfohUd]P02ohUd]P?oRgJg00Go0000oheh^?n=
N;SoSGRho`000004ohmk^@03o`000?nBO[[oTWjj00;oTWjj1?nEP[`4oiR5_P03o`000?nLR[ooW8Zo
00;oW8Zo00?o0000oj2>`_nPS/800_nPS/801Ol0003oY9?4ojBCa?nTTlCo000000CoZ9W600?o0000
ojfNb?n]W/P00_n]W/P00ol0003o/JC;ok6Tb`03ok6Tb`03o`000?neZLgo]JW=00;o]JW=00?o0000
okV_d?ni[m000_ni[m02o`0000?odlgD00?o0000omODe_oGe=H00_oGe=H00ol0003ofM[GomWJe`02
omWJe`05o`000?oKgmWofmoIom_OfOl000000_oLi=/3o`000003om[ocol0003ooooo02Cooooo00?o
0000ooooooooool02?ooool0023ooooo00?o0000ooooooooool09Oooool3o`0001Cooooo00?o0000
omOHf?oGf=P00ooGf=P00ol0003oemGFomOEeP02omOEeP03o`000?oFdMCoe]7D00;o000000?oa<3G
o`000?o2_=@01?o2_=@00ol0003o_kOBokngdP03okngdP03o`000?nl/]3o_;;@00;o_;;@00?o0000
okV]c_ni[Lh00oni[Lh00ol0003o]JS;okFXb`02okFXb`08o`000?naXlWo/J?9ok6SbOl0003o[Ig7
o`000?nJT/X5oiN=a`03o`000?nERLGoUHW500;oUHW51?nCQL801Ol0003oTH;0oi62`?nAP/3o0000
00?oSgnn00Go0000ohel_?n=O;coSGblo`000003ohaj^P05o`000?n;N;WoRgRioh]h^Ol000000_n9
M[P00ol0003oR7FgohQe]`03o`0000;oQW>f00So0000ohIb]On6L[GoQW:eo`000?n6L[Go0000ohIb
]@;o000000CoQW6do`000?l0003oQW6d1On7L[D2o`0000;oR7>e00Go0000ohUd]_n9M;KoRGBfo`00
0003oh]f]`CoSGRh00?o0000ohmk^On?NkT00_n?NkT4oi9n^P05o`000?nEP[coUH:loiF2_?l00000
0onHQKh00ol0003oW8Zooib:_`02oib:_`03o`000?nPS/;oX8k200;oX8k200?o0000ojBCa?nTTl@0
0_nTTl@00ol0003oZ9W6ojRIaP02ojRIaP03o`000?n]W/So[Ik800;o[Ik800?o0000ok6TbonaY</0
0_naY</00ol0003o]JW=okFYc@02okFYc@03o`000?ni[m3o^Jo@00;o000000?oc/KBo`000?oCcM@0
0_oCcM@00ol0003oemCFomODeP02omODeP03o`000?oIf]OofM[G00;ofM[G00Go0000om_OfOoKgmWo
fmoIo`000002omcTf`;o000000?of_o?o`000?ooool09Oooool00ol0003oooooooooo`08ooooo`00
8?ooool2o`0002?ooooo0ol0000Gooooo`03o`000?oGf=SoemSH00?oemSH00?o0000omOEe_oGeMH0
0ooGeMH2o`0000Coa<3G00?o0000ol:le?o2_=@00oo2_=@00ol0003o_kOBokngdP03okngdP03o`00
0?nl/]3o_;;@00;o_;;@00?o0000okV]c_ni[Lh00_ni[Lh00ol0003o]JS;okFXb`02okFXb`04o`00
0?naXlWo/J?9ok6Sb@;o00000onJT/X5oiN=a`CoUHW500Go0000oi>5`_nCQL;oThG2o`000003oi62
`005o`000?n?OkkoSgnnohmo__l000000on=O;`01Ol0003oS7Zjohaj^_n<N[[o000000?oRgRi00Co
0000ohUf^?n9M[SoRGJh0_l000000on6LkOo0000ohIc]P03ohIc]P05o`000?n6L[GoQW:eohIb]Ol0
00000_n6L[D5o`000003ohIa]?l0003oQg:e00?oQg:e0_n8LkD3o`0000?oRGBf00Go0000oh]f]on;
M[OoRgJgo`000003oheh^003o`000?n?NkWoSg^i00;oSg^i00Go0000oi9n^_nBO[[oTWjjo`000003
oiF2_003o`000?nHQKkoV8Fn00;oV8Fn00Go0000oib:_onLR[ooW8Zoo`000004oj2>`P03o`000?nT
TlCoY9?400;oY9?400?o0000ojRIa_nXVLH00_nXVLH00ol0003o[Ik8ojfNb002ojfNb003o`000?na
Y<_o/JC;00;o/JC;00?o0000okFYcOneZLd00oneZLd2o`0000?oc/KB00Go0000om?=e?oCcMCodlgD
o`000004omODeP03o`000?oIf]OofM[G00;ofM[G00So0000om_OfOoKgmWofmoIo`000?oLi=_o0000
omgnc`?o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Poooo
o`;o00006_ooool00ol0003oemSHomOHf003omOHf003o`000?oGeMKoemGF00?oemGF00?o0000olC0
eoo4`=L00oo4`=L00ol0003o`[cDol:le003ol:le003o`000?no]m;o_kOB00Co_kOB00Go0000okbb
d?nl/]3o_;;@o`000004okV]cP03o`000?neZ<_o]JS;00;o]JS;00Go0000ok6SbOl0003o0000oibF
c@04oiZBbP03o`000?nGSLOoUhg700;oUhg700Go0000oiF9aOnERLGoUHW5o`000004oi>5`P05o`00
0?nAP/3oTH;0oi62`?l000000_n?Okh00ol0003oSGblohel_002ohel_005o`000?n<N[[oS7Zjohaj
^_l000000_n;N;T00ol0003oRGJhohUf^002o`0000?oQW>g00Go0000ohIc]_n6LkKoQW>fo`000003
ohIb]@03o`000?n6L[GoQW:e00;o000000CoQW:eo`000?l0003o00001On7L[D01?l0003oR7>eohQc
]On8LkD2o`0000;oRGBf00Go0000oh]f]on;M[OoRgJgo`000003oheh^003o`000?n?NkWoSg^i00;o
Sg^i00Go0000oi9n^_nBO[[oTWjjo`000003oiF2_003o`000?nHQKkoV8Fn00;oV8Fn00?o0000oib:
_onLR[l00_nLR[l01Ol0003oX8k2oj2>`_nPS/;o000000CoY9?400?o0000ojRIa_nXVLH00_nXVLH0
0ol0003o[Ik8ojfNb002ojfNb003o`000?naY<_o/JC;00?o/JC;00Co0000okFYcOneZLgo]JW=0_l0
0004olk6dP05o`000?oCcMCodlgDom?=e?l000001?oGe=H00ol0003ofM[GomWJe`02omWJe`04o`00
0?oKgmWofmoIom_Of@;o000000GogOk?o`000?oJoloof_o?o`00000Wooooo`03o`000?oooooooooo
00Oooooo000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?oGf=SoemSH00?o
emSH00Co0000omOEe_oGeMKoemGF0_l00006olC0e`03o`000?o2_=Co`[cD00?o`[cD00?o0000okng
d_no]m800ono]m800ol0003o_;;@okbbd002okbbd003o`000?ni[Lko^Jg>00;o^Jg>00Co0000okFX
boneZ<_o]JS;0_l00004oibFc@CoVY;:00?o0000oiN=aonGSLL00_nGSLL01Ol0003oUHW5oiF9aOnE
RLGo000000?oThG200Go0000oi62`?nAP/3oTH;0o`000003ohmo_P05o`000?n=O;coSGblohel_?l0
00000on<N[X01?l0003oRgRioh]h^On;N;T2o`000003ohId^?l0003oQW>g00;oQW>g00Go0000ohIc
]_n6LkKoQW>fo`000002ohIb]@07o`000?n6L[Ko0000o`000?n6L[Go0000ohIb]@03o`000003ohMb
]Ol0003oQg:e00;oQg:e00Co0000ohQc]On8LkGoR7>e0_n:MKH3o`0000?oRgJg00Go0000oheh^?n=
N;SoSGRho`000004ohmk^@05o`000?nBO[[oTWjjoi9n^_l000001?nEP[`01Ol0003oV8FnoiR5__nH
QKko000000CoW8Zo00?o0000oj2>`_nPS/800_nPS/800ol0003oY9?4ojBCa002ojBCa005o`000?nX
VLKoZ9W6ojRIa_l000001On]W/P00ol0003o/JC;ok6Tb`02ok6Tb`06o`000?neZLgo]JW=o`000?o9
_]3o00001?o>a]801Ol0003odlgDom?=e?oCcMCo000000CoemCF00?o0000omWJeooIf]L00_oIf]L0
1Ol0003ofmoIom_OfOoKgmWo000000;ogOk?00Co0000om[ocol0003o00009oooool00ol0003ooooo
ooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o00008?ooool00ol0003oemSHomOH
f003omOHf004o`000?oGeMKoemGFo`0000;oaLGI00?o0000olC0eoo4`=L01?o4`=L00ol0003o`[cD
ol:le002ol:le003o`000?no]m;o_kOB00Co_kOB00Go0000okbbd?nl/]3o_;;@o`000004okV]cP05
o`000?neZ<_o0000o`000?nOVm001OnLU/d00ol0003oVY;:oiZBbP02oiZBbP05o`000?nGSLOoUhg7
oiN=aol000000onERLD00ol0003oThG2oi>5`P02oi>5`P05o`000?nAP/3oTH;0oi62`?l000000_n?
Okh00ol0003oSGblohel_002ohel_004o`000?n<N[[oS7Zjo`0000;oRgRi0_l00003ohId^005o`00
0?n6LkOoQW>gohIc]ol000000on6LkH2o`0000;oQW:f0_l000000on6L[Go0000ohIb]@02o`000003
ohMb]Ol0003oQg:e00?oQg:e00Go0000ohQc]On8LkGoR7>eo`000003ohYe]P;o00000_n;M[L00ol0
003oSGRhoheh^002oheh^003o`000?n?NkWoSg^i00;oSg^i00Go0000oi9n^_nBO[[oTWjjo`000003
oiF2_003o`000?nHQKkoV8Fn00;oV8Fn00Go0000oib:_onLR[ooW8Zoo`000004oj2>`P03o`000?nT
TlCoY9?400;oY9?400?o0000ojRIa_nXVLH00_nXVLH00ol0003o[Ik8ojfNb002ojfNb003o`000?na
Y<_o/JC;00;o/JC;00?o0000okFYcOl000000_o9_]000ol0003oc/KBolk6dP02olk6dP05o`000?oC
cMCodlgDom?=e?l000001?oGe=H00ol0003ofM[GomWJe`02omWJe`03o`000?oKgmWofmoI00;o0000
00OogOk?o`000?oJoloof_o?o`000?oooooo000002Kooooo00?o0000ooooooooool01oooool0023o
oooo0ol0000Gooooo`?o00008oooool00ol0003oemSHomOHf003omOHf003o`000?oGeMKo000000Co
aLGI00?o0000olC0eoo4`=L00oo4`=L00ol0003o`[cDol:le003ol:le003o`000?no]m;o_kOB00?o
_kOB00Go0000okbbd?nl/]3o_;;@o`000004okV]cP;o00001?nOVm05oibFc@05o`000?nJT/[oVY;:
oiZBb_l000001?nGSLL01Ol0003oUHW5oiF9aOnERLGo000000?oThG200Go0000oi62`?nAP/3oTH;0
o`000003ohmo_P05o`000?n=O;coSGblohel_?l000000_n<N[X3o`000003ohEe^_l0003oQWBh00;o
QWBh00Go0000ohIc]on6LkOoQW>go`000003ohIc]P03o`000?n6L[KoQW:f00;oQW:f00So0000ohIb
]Ol0003oQW:eo`000?n6L[GoQg:eo`0000CoQg:e0_l00002ohQc]@03o`000?n:MKKoRWFf00;oRWFf
0_l00002oh]f]`05o`000?n=N;SoSGRhoheh^?l000001?n?NkT01Ol0003oTWjjoi9n^_nBO[[o0000
00?oUH:l00?o0000oiR5__nHQKh00_nHQKh01Ol0003oW8Zooib:_onLR[oo000000CoX8k200?o0000
ojBCa?nTTl@00_nTTl@00ol0003oZ9W6ojRIaP02ojRIaP03o`000?n]W/So[Ik800;o[Ik800?o0000
ok6TbonaY</00_naY</2o`0000?obKk@00?o0000olk6d_o>a]800_o>a]801Ol0003odlgDom?=e?oC
cMCo000000CoemCF00?o0000omWJeooIf]L00_oIf]L01?l0003ofmoIo`000?l00002omgnc`03o`00
0?oJoloo000000?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`007ooo
ool2o`0001Kooooo0ol0000Wooooo`03o`000?oGf=SoemSH00;oemSH0_l00005olG5f@03o`000?o4
`=Ooa<3G00Coa<3G00?o0000ol:le?o2_=@00oo2_=@00ol0003o_kOBokngdP03okngdP05o`000?nl
/]3o_;;@okbbd?l000000_ni[Lh00ol0003oXJ7DoinKd005oinKd0GoW9K=00Go0000oiZBb_nJT/[o
VY;:o`000003oiN=a`05o`000?nERLGoUHW5oiF9aOl000000onCQL801Ol0003oTH;0oi62`?nAP/3o
000000?oSgnn00Wo0000ohel_?n=O;coSGblo`000?n<N[[o0000ohEg_?l000000on5MKX01Ol0003o
QWBhohId^?n6M;So000000?oQW>g00Co0000ohIc]_n6LkKo00001?n6L[H01_l0003oQW:eo`000?n6
L[Go0000ohIb]@;oQg:e00Co0000ohMb]On7L[Go00000_n8M;H00ol0003oR7>eo`000004ohYe]P;o
S7Rg0ol00003oheh^003o`000?n?NkWoSg^i00;oSg^i00Go0000oi9n^_nBO[[oTWjjo`000003oiF2
_003o`000?nHQKkoV8Fn00;oV8Fn00?o0000oib:_onLR[l00_nLR[l01Ol0003oX8k2oj2>`_nPS/;o
000000GoY9?400Go0000ojRIa_nXVLKoZ9W6o`000005ojfNb0Co000000?o`kO>o`000?o9_]000_o9
_]000ol0003oc/KBolk6dP02olk6dP03o`000?oCcMCodlgD00;odlgD00Go0000omODe_oGe=KoemCF
o`000004omWJe`;o000000OohOc@o`000?oMo/oogOk?o`000?oJoloo000000Cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0B
ooooo`?o0000:_ooool00ol0003oemSHomOHf002o`000003olK8g?l0003oaLGI00GoaLGI00?o0000
olC0eoo4`=L00oo4`=L00ol0003o`[cDol:le003ol:le003o`000?no]m;o_kOB00?o_kOB00Oo0000
okbbd?nl/]3o_;;@o`000?ni[Lko000000?oXJ7D1OnOVm000ol0003oW9K=oibFc@02oibFc@05o`00
0?nJT/[oVY;:oiZBb_l000001?nGSLL01Ol0003oUHW5oiF9aOnERLGo000000?oThG200Go0000oi62
`?nAP/3oTH;0o`000002ohmo_P03o`000?n=O;coSGbl00?o00000on5Mk`01?l0003oQGFjohEe^_l0
0004ohId^008o`000?n6LkOoQW>go`000?n6LkKo0000ohEb]ol00003ohIb]P?o00000on6L[D00ol0
003oQg:eohMb]@02ohMb]@06o`000?n8M;KoR7BfohQd]_n8LkGo00001?n:MKH01?l0003oS7Rgohah
]on<N;L2o`0000;oSGRh00?o0000ohmk^On?NkT00_n?NkT01Ol0003oTWjjoi9n^_nBO[[o000000Co
UH:l00Go0000oiR5__nHQKkoV8Fno`000004oib:_`03o`000?nPS/;oX8k200;oX8k200?o0000ojBC
a?nTTl@00_nTTl@01Ol0003oZ9W6ojRIa_nXVLKo000000Co[Ik80_l00004ol>gcP05o`000?o9_]3o
bKk@olVnd?l000001?o>a]800ol0003odlgDom?=e002om?=e005o`000?oGe=KoemCFomODe_l00000
0ooIf]L2o`0000;ohOc@00Go0000omgncol0003of_o?o`000005ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0ol0000]ooooo`03
o`000?oGf=So000000Coa/SL00?o0000olG5fOo5aMT01?o5aMT00ol0003oa<3GolC0e`03olC0e`03
o`000?o2_=Co`[cD00?o`[cD00?o0000okngd_no]m800ono]m800ol0003o_;;@okbbd002o`0000Go
XJ7D1OnOVm000ol0003oW9K=oibFc@02oibFc@05o`000?nJT/[oVY;:oiZBb_l000000onGSLL01Ol0
003oUHW5oiF9aOnERLGo000000?oThG200Go0000oi62`?nAP/3oTH;0o`000002ohmo_P?o00000_n4
N;h01Ol0003oQGNlohEg_?n5Mkco000000?oQGFj00Go0000ohId^?n6M;SoQWBho`000003ohIc]`07
o`000?n5L[OoQG:gohEb]ol0003oQW:fo`000002ohIb]P;o00000_n6L[D01_l0003oQg:eohMb]Ol0
003oQg:eo`0000CoR7Bf0_l00003ohYe]P04o`000?n<N;OoS7Rgohah]`;oSg^i1?l00003ohmk^@05
o`000?nBO[[oTWjjoi9n^_l000001?nEP[`00ol0003oV8FnoiR5_P02oiR5_P05o`000?nLR[ooW8Zo
oib:_ol000001?nPS/800ol0003oY9?4ojBCa002ojBCa003o`000?nXVLKoZ9W600;oZ9W61?l00000
0onm[lco0000ol>gcP03ol>gcP05o`000?o9_]3obKk@olVnd?l000001?o>a]800ol0003odlgDom?=
e002om?=e005o`000?oGe=KoemCFomODe_l000000_oIf]L01Ol0003oho[Co`000?oQo=3o000000;o
gOk?00?o0000om[ocol000001_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oo
oooo0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00cooooo0ol0000aooooo`03o`000?o6b=coa/SL00Coa/SL00?o0000olG5fOo5
aMT00oo5aMT00ol0003oa<3GolC0e`04olC0e`03o`000?o2_=Co`[cD00;o`[cD00?o0000okngd_no
]m800ono]m801Ol0003o_;;@o`000?nTY]Oo000000GoXJ7D00?o0000oinKd?nOVm000_nOVm000ol0
003oW9K=oibFc@02oibFc@05o`000?nJT/[oVY;:oiZBb_l000001?nGSLL01Ol0003oUHW5oiF9aOnE
RLGo000000?oThG200So0000oi62`?nAP/3o0000ohmo__l0003oPg[1o`0000CoQ7Rn00Go0000ohEg
_?n5MkcoQGNlo`000002ohEe^P03o`000?n6M;SoQWBh00;oQWBh00Co0000ohIc]on6LkOo00001?n5
L[L2o`0000;oQW:f00Go0000ohIb]_l0003oQW:eo`000003ohMb]@03o`000?n8M;Ko000000?oR7Bf
0_n:M[L01?l0003oRWFfohYe]_l00003ohah]`03o`000?n?NkWoSg^i00;oSg^i1?l000000on?NkWo
0000oi9n^P02oi9n^P05o`000?nEP[coUH:loiF2_?l000001?nHQKh01Ol0003oW8Zooib:_onLR[oo
000000CoX8k200?o0000ojBCa?nTTl@00onTTl@00ol0003oZ9W6o`000002o`0000Co_Jo<00?o0000
ol>gc_o3]lh00_o3]lh01Ol0003obKk@olVnd?o9_]3o000000Goc/KB00Go0000om?=e?oCcMCodlgD
o`000003omODeP05o`000?oIf]Oo0000on?jdol000000_oQo=000ol0003ogOk?o`000002om[oc`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`00
1?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool2o`0000[o
oooo0ol0000dooooo`03o`000?o6b=coa/SL00Goa/SL00?o0000olG5fOo5aMT00oo5aMT00ol0003o
a<3GolC0e`03olC0e`03o`000?o2_=Co`[cD00?o`[cD00?o0000okngd_no]m800_no]m82o`0000?o
Y:KG00?o0000oj6Qe?nQXM@00onQXM@00ol0003oWi_@oinKd002oinKd003o`000?nLU/goW9K=00;o
W9K=00Go0000oiZBb_nJT/[oVY;:o`000003oiN=a`05o`000?nERLGoUHW5oiF9aOl000000onCQL80
0ol0003oTH;0oi62`002o`0000?oPg[100Go0000ohAh__n4N;koQ7Rno`000003ohEg_005o`000?n5
MK[oQGFjohEe^_l000000on6M;P01Ol0003oQW>go`000?n4LkSo000000CoQG:g00Co0000ohIb]_n6
L[Ko00000_n6L[H2o`000004ohMb]Ol0003o0000o`0000;oR7Bf00Co0000ohQd]_n8M;Ko00000_n:
M[L00ol0003oRWFfo`000003ohah]`03o`000?n?NkWoSg^i00;oSg^i1?nCO[X4o`000003oi9n^_l0
003oUH:l00;oUH:l00?o0000oiR5__nHQKh00_nHQKh01Ol0003oW8Zooib:_onLR[oo000000CoX8k2
00?o0000ojBCa?nTTl@00_nTTl@3o`0000;o]jO900?o0000okf_c?nm[l`00_nm[l`00ol0003o`kO>
ol>gcP02ol>gcP05o`000?o9_]3obKk@olVnd?l000001Oo>a]801Ol0003odlgDom?=e?oCcMCo0000
00?oemCF0_l00002on?jd`03o`000?oQo=3o000000;ogOk?00?o0000om[ocol000002Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3
o`0003Sooooo00?o0000olK8g?o6b=`01?o6b=`00ol0003oaLGIolG5f@04olG5f@03o`000?o4`=Oo
a<3G00?oa<3G00?o0000ol:le?o2_=@00oo2_=@01_l0003o_kOBokngd_l0003oYZcKo`0000CoY:KG
00?o0000oj6Qe?nQXM@00onQXM@00ol0003oWi_@oinKd002oinKd005o`000?nLU/goW9K=oibFcOl0
00000onJT/X00ol0003oUhg7oiN=a`02oiN=a`04o`000?nERLGoUHW5o`0000?oThG200Go0000oi62
`?l0003oPWc3o`000004oh=j`@05o`000?n4N;koQ7RnohAh__l000000on5Mk`01?l0003oQGFjohEe
^_l00004ohId^004o`000?n4LkSoQ7>ho`0000CoQG:g00Co0000ohIb]_n6L[Ko00000_n6L[H01ol0
003oQW>fo`000?n7LkKo0000ohQd]_l000000_n8M;H00ol0003oR7Bfo`000003ohYf]`03ohYe]_l0
003oS7Rg00;oS7Rg00?o0000ohmk^On?NkT00_n?NkT00ol0003oTgjjoi=n^P02oi=n^P?oUh>l1Ol0
00000onEP[co0000oiR5_P03oiR5_P05o`000?nLR[ooW8Zooib:_ol000001?nPS/84o`000003ok6P
aol0003o]jO900;o]jO900?o0000okf_c?nm[l`00_nm[l`00ol0003o`kO>ol>gcP02ol>gcP05o`00
0?o9_]3obKk@olVnd?l000001Oo>a]801Ol0003odlgDom?=e?oCcMCo000000?oemCF00Wo0000on?j
dooSn]?oho[Co`000?oQo=3o0000omgncol000000_oJoll00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0003cooooo
00?o0000olK8g?o6b=`01?o6b=`00ol0003oaLGIolG5f@04olG5f@03o`000?o4`=Ooa<3G00;oa<3G
00?o0000ol:le?o2_=@00oo2_=@00ol0003o_kOBo`000003ojJ/f`03o`000?nTY]OoY:KG00;oY:KG
00?o0000oj6Qe?nQXM@00_nQXM@00ol0003oWi_@oinKd002oinKd003o`000?nLU/goW9K=00;oW9K=
00Go0000oiZBb_nJT/[oVY;:o`000003oiN=a`05o`000?nERLGoUHW5oiF9aOl000000_nCQL82o`00
00?oPWc300Go0000oh=j`On3N/7oPg[1o`000003ohAh_P05o`000?n5MkcoQGNlohEg_?l000000_n5
MKX00ol0003oQWBhohId^002ohId^005o`000?n4LkSoQ7>hohAc^?l000000_n5L[L01Ol0003oQG>g
o`000?n6L[Ko000000;oQW:f00?o0000ohIc]_l000000_n7LkH2o`0000CoR7Bf00?o0000ohYf]on:
M[L00_n:M[L2o`0000?oS7Rg00Go0000ohmk^On?NkWoSg^io`000004oi=n^P04o`000?nGPkcoUh>l
oiN3_0CoVhRn4?l00004ok6Pa`05o`000?ngYlWo]jO9okNWbOl000001?nm[l`00ol0003o`kO>ol>g
cP02ol>gcP03o`000?o9_]3obKk@00;obKk@00?o0000olk6d_o>a]800_o>a]801Ol0003odlgDom?=
e?oCcMCo000000;oemCF0_l00002on?jd`03o`000?oQo=3o000000;ogOk?00?o0000om[ocol00000
2oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o
0000@?ooool00ol0003oa/SLolK8g004olK8g003o`000?o5aMWoaLGI00?oaLGI00?o0000olC0eoo4
`=L00oo4`=L00ol0003o`[cDol:le002ol:le0;o00001OnV[=/00ol0003oY:KGojBVe`02ojBVe`03
o`000?nQXMCoXJ7D00;oXJ7D00?o0000oinKd?nOVm000_nOVm001Ol0003oW9K=oibFcOnLU/go0000
00CoVY;:00Go0000oiN=aonGSLOoUhg7o`000002oiF9a@05o`000?nCQL;o0000oh5naol000001?n2
O<<01Ol0003oPg[1oh=j`On3N/7o000000?oQ7Rn00Co0000ohEg_?n5Mkco00000on5MKX01_l0003o
QWBhohId^?l0003oPg>jo`0000?oQ7>h00?o0000ohEb]ol000000_n5LkL2o`0000;oQW:f00?o0000
ohIc]_l000000_n7LkH00ol0003oR7Bfo`000003ohQd]P03o`000?n:M[OoRWJg00;oRWJg0_n=NKP0
1?l0003oS7Rgohah]ol00003ohmk^@03o`000?nCO[[oTgjj00;oTgjj00Go0000oiN3_?nGPkcoUh>l
o`000004oi^8_PGoX8g01?nUTl800ol0003oZiW4oj^Ia002oj^Ia003o`000?naX<Oo/J3700;o/J37
00Go0000okNWbOngYlWo]jO9o`000004okf_c003o`000?o3]lko`kO>00;o`kO>00?o0000olVnd?o9
_]000_o9_]000ol0003oc/KBolk6dP02olk6dP09o`000?oCcMCodlgDom?=e?l0003oemCFo`000?oT
mMGo000000;oho[C00?o0000on7ld?l000000_oMo/l2o`0000gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`06ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`Co0000A?ooool00ol0003oa/SLolK8g004olK8g003o`000?o5aMWoaLGI00?oaLGI00?o
0000olC0eoo4`=L00oo4`=L01_l0003o`[cDol:le?l0003oZK7No`0000KoYZcK00Go0000ojBVeonT
Y]OoY:KGo`000005oj6Qe005o`000?nOVm3oWi_@oinKd?l000001?nLU/d01Ol0003oVY;:oiZBb_nJ
T/[o000000?oUhg700?o0000oiF9aOnERLD00_l00003oh5na`05o`000?n2O<?oPWc3oh9l`ol00000
0on3N/400ol0003oQ7RnohAh_P02ohAh_P04o`000?n5MkcoQGNlo`0000;oQGFj00?o0000ohId^?l0
00000_n3LkX01ol0003oQ7>hohAc^?n4LkSo0000ohEb]ol000000on5LkL2o`0000;oQW:f00Go0000
ohIc]_l0003oQg>fo`000005ohQd]P03o`000?n:M[OoRWJg00;oRWJg00Ko0000ohei^?n=NKSo0000
ohah]ol00003ohmk^@03o`000?nCO[[oTgjj00;oTgjj00Go0000oiN3_?nGPkcoUh>lo`000004oi^8
_P03o`000?nPSL3oX8g000;oX8g01?nUTl800ol0003oZiW4oj^Ia002oj^Ia003o`000?naX<Oo/J37
00;o/J3700Go0000okNWbOngYlWo]jO9o`000004okf_c003o`000?o3]lko`kO>00;o`kO>00?o0000
olVnd?o9_]000_o9_]000ol0003oc/KBolk6dP02olk6dP04o`000?oCcMCodlgDom?=e0;o000000Go
i?GEo`000?oSn]?oho[Co`000002on7ld004o`000?oMo/oo0000o`0000oooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`007_ooool2o`0004Oooooo00?o0000olK8g?o6b=`0
0oo6b=`00ol0003oaLGIolG5f@04olG5f@03o`000?o4`=Ooa<3G00;oa<3G00?o0000ol:le?l00000
0onY/Mh00ol0003oYZcKojJ/f`04ojJ/f`05o`000?nTY]OoY:KGojBVeol000001?nQXM@00ol0003o
Wi_@oinKd002oinKd003o`000?nLU/goW9K=00;oW9K=00Go0000oiZBb_nJT/[oVY;:o`000002oiN=
a`?o000000?oP87:o`000?n1O/L00on1O/L01Ol0003oPWc3oh9l`on2O<?o000000?oPg[100Go0000
ohAh__n4N;koQ7Rno`000002ohEg_005o`000?n5MK[oQGFjohEe^_l000001?n3LkX01Ol0003oQ7>h
ohAc^?n4LkSo000000CoQG>g00Oo0000ohEc^?l0003oQW:fo`000?n6LkKo000000;oQg>f0_n8M;H0
1Ol0003oR7Bfo`000?n:M[Oo000000?oRWJg00Ko0000ohei^?n=NKSoSGVhohah]ol00004ohmk^@05
o`000?nCO[[oTgjjoi=n^_l000000onGPk`00ol0003oVhRnoi^8_P02oi^8_P03o`000?nPSL3oX8g0
00;oX8g000Go0000ojFC`_nUTl;oYI?2o`000004oj^Ia003o`000?naX<Oo/J3700;o/J3700?o0000
okNWbOngYlT00_ngYlT01Ol0003o_Jo<okf_c?nm[lco000000Go`kO>00Go0000olVnd?o9_]3obKk@
o`000004olk6dP03o`000?oCcMCodlgD00;o00000_oTmMD01_l0003oho[Con?jdol0003ohOc@o`00
00;ogOk?00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Kooooo000Pooooo`03o`000?oooooooooo04Gooooo00?o0000olK8g?o6b=`00oo6b=`00ol0003o
aLGIolG5f@03olG5f@03o`000?o4`=Ooa<3G00;oa<3G0_l00005ojVagP03o`000?nV[=_oYZcK00?o
YZcK00?o0000ojBVeonTY]L00_nTY]L00ol0003oXJ7Doj6Qe002oj6Qe003o`000?nOVm3oWi_@00;o
Wi_@00Go0000oibFcOnLU/goW9K=o`000003oiZBbP05o`000?nGSLOo0000ogn4c_l000000on0PLX0
1Ol0003oPGk7oh5naon1O/Oo000000?oPWc300?o0000oh=j`On3N/400_n3N/401Ol0003oQ7RnohAh
__n4N;ko000000;oQGNl00Co0000ohEe^_n5MK[o00001On3LkX01?l0003oQ7>hohAc^?l00004ohEc
]`04o`000?n5LkSoQG>ho`0000;oQW>f00?o0000ohMc]_n7LkH00on8M;H01ol0003oRWJgohYf]on:
M[Oo0000ohYf]ol000001On=NKP2o`0000?oSg^i00Go0000oi=n^_nCO[[oTgjjo`000003oiN3_003
o`000?nKR;koVhRn00;oVhRn00?o0000oj2=`?nPSL000_nPSL001Ol0003oYI?2ojFC`_nUTl;o0000
00CoZiW400?o0000ok6PaonaX<L00_naX<L00ol0003o]jO9okNWb@02okNWb@05o`000?nm[lco_Jo<
okf_c?l000001Oo3]lh01Ol0003obKk@olVnd?o9_]3o000000Coc/KB00Go0000om?=e?l0003oh^oH
o`000002onCee@03o`000?oSn]?o000000;ohOc@00?o0000omgncol000004_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o
0000olK8g?o6b=`00oo6b=`00ol0003oaLGIolG5f@03olG5f@04o`000?o4`=Oo0000o`0000?oZkKQ
1OnY/Mh00ol0003oYZcKojJ/f`03ojJ/f`03o`000?nTY]OoY:KG00;oY:KG00?o0000oj6Qe?nQXM@0
0_nQXM@01Ol0003oWi_@oinKd?nOVm3o000000CoW9K=00?o0000oiZBb_nJT/X00_l00003ogn4cP05
o`000?n0PL[oP87:oh21b_l000000on1O/L01Ol0003oPWc3oh9l`on2O<?o000000?oPg[100Go0000
ohAh__n4N;koQ7Rno`000002ohEg_005o`000?n5MK[o0000oh5d_?l000001?n3LkX00ol0003oQ7>h
ohAc^002o`0000?oQG>g00Co0000ohEc^?n5LkSoQG>h0ol00002ohMc]P04o`000?n8M;Ko0000o`00
00GoRWJg00?o0000ohei^?n=NKP00on=NKP2oi1m^P;o000000?oSg^io`000?nCO[X00_nCO[X01Ol0
003oUh>loiN3_?nGPkco000000CoVhRn00?o0000oj2=`?nPSL000_nPSL001Ol0003oYI?2ojFC`_nU
Tl;o000000CoZiW400?o0000ok6PaonaX<L00_naX<L00ol0003o]jO9okNWb@02okNWb@03o`000?nm
[lco_Jo<00;o_Jo<00?o0000ol>gc_o3]lh00_o3]lh01Ol0003obKk@olVnd?o9_]3o000000Coc/KB
0_l00002on;_f003o`000?oTmMGo000000;oho[C00Co0000on7ld?l0003ogOk?0_l0000Cooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool002;ooooo00?o0000ooooooooool0
A?ooool00ol0003oa/SLolK8g003olK8g003o`000?o5aMWoaLGI00?oaLGI0_l00006oj^fh@GoZK7N
00?o0000ojJ/fonV[=/00onV[=/00ol0003oY:KGojBVe`02ojBVe`05o`000?nQXMCoXJ7Doj6Qe?l0
00001?nOVm002Ol0003oW9K=oibFcOnLU/go0000oiZBb_l0003oOXSCo`000004ogn4cP04o`000?n0
PL[oP87:o`0000?oPGk700?o0000oh9l`on2O<<00_n2O<<01Ol0003oPg[1oh=j`On3N/7o000000?o
Q7Rn00Co0000ohEg_?n5Mkco00000on1M;`00ol0003oPg>joh=c^P02oh=c^P;o00000_n3LkT01?l0
003oQG>gohEc]ol00003ohEc^003o`000?n6M;SoQWBh00Co00000_n9M[P00ol0003oRWJgohYf]`02
ohYf]`03o`000?n=NKSoSGVh00?oSGVh1?n@OKX00on?NkWo0000oi=n^P02oi=n^P05o`000?nGPkco
Uh>loiN3_?l000001?nKR;h00ol0003oX8g0oj2=`002oj2=`005o`000?nUTl;oYI?2ojFC`_l00000
1?n[VL@00ol0003o/J37ok6Pa`02ok6Pa`03o`000?ngYlWo]jO900;o]jO900?o0000okf_c?nm[l`0
0_nm[l`00ol0003o`kO>ol>gcP02ol>gcP05o`000?o9_]3obKk@olVnd?l000000oo>a]82o`0000;o
h^oH00Co0000onCeeOoTmMGo00000_oSn]<00ol0003ohOc@o`000002o`0001Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`05ooooo`008oooool2o`0004Gooooo00?o0000olK8g?o6
b=`00oo6b=`01Ol0003oaLGIolG5fOo5aMWo000000?o[KcU1_n[]^400ol0003oZK7NojVagP02ojVa
gP03o`000?nV[=_oYZcK00?oYZcK00?o0000ojBVeonTY]L00_nTY]L01Ol0003oXJ7Doj6Qe?nQXMCo
000000?oWi_@00Co0000oibFcOnLU/goW9K=0_l00003ogj8d`05o`000?moQ<koOhC>ogn4c_l00000
0on0PLX01Ol0003oPGk7oh5naon1O/Oo000000?oPWc300Go0000oh=j`On3N/7oPg[1o`000003ohAh
_P04o`000?n5Mkco0000o`0000CoPGBl00Co0000oh=c^_n3Lk[oPg>j0_l00003oh=c^@03o`000?n5
LkOo000000?oQG>h00Co0000ohId^?n6M;So00000_n7MKP01?l0003oRGJhohUf^?l00004ohYf]`03
o`000?n=NKSoSGVh00?oSGVh00?o0000oi1m^_n@OKX00_n@OKX01Ol0003oTgjjoi=n^_nCO[[o0000
00CoUh>l00Go0000oi^8__nKR;koVhRno`000004oj2=`005o`000?nUTl;oYI?2ojFC`_l000001?n[
VL@00ol0003o/J37ok6Pa`02ok6Pa`03o`000?ngYlWo]jO900;o]jO900?o0000okf_c?nm[l`00_nm
[l`00ol0003o`kO>ol>gcP02ol>gcP06o`000?o9_]3obKk@olVnd?l0003oc/KB0_l000001OoOimWo
0000on;_f?oRkmSo000000;oi?GE00?o0000on?jdol000000_oQo=02o`0001Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`05ooooo`009Oooool00ol0003oooooooooo`13ooooo`03
o`000?o6b=coa/SL00?oa/SL00?o0000olG5fOl000001On]_>D6oj^fh@03o`000?nY/MkoZK7N00;o
ZK7N00?o0000ojJ/fonV[=/00onV[=/01Ol0003oY:KGojBVeonTY]Oo000000CoXJ7D00Wo0000oinK
d?nOVm3oWi_@o`000?nLU/go0000ogb<f?l000001?mnR=<01Ol0003oOhC>ogn4c_moQ<ko000000?o
P87:00Go0000oh5naon1O/OoPGk7o`000003oh9l``05o`000?n3N/7oPg[1oh=j`Ol000000on4N;h0
1?l0003oOWFnogie__l00004oh5d_005o`000?n3Lk[oPg>joh=c^_l000001?n3LkT2o`0000?oQG>h
00Co0000ohId^?n6M;So00000on7MKP01?l0003oRGJhohUf^?l00002ohYf]`03o`000?n<N[Wo0000
00CoSGVh00?o0000oi1m^_n@OKX00_n@OKX01OnDP[co0000oi=n^_nCO[[o000000CoUh>l00?o0000
oi^8__nKR;h00_nKR;h01Ol0003oX8g0oj2=`?nPSL3o000000?oYI?200?o0000oj^Ia?n[VL@00_n[
VL@00ol0003o/J37ok6Pa`03ok6Pa`05o`000?ngYlWo]jO9okNWbOl000001?nm[l`00ol0003o`kO>
ol>gcP02ol>gcP04o`000?o9_]3obKk@olVnd0;o00000ooOimT01_l0003oh^oHon;_f?l0003oi?GE
o`0000;oho[C00Co0000on7ld?l0003o00006?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo000Vooooo`03o`000?oooooooooo04?ooooo00?o0000olK8g?o6b=`00oo6b=`0
0ol0003o[KcUojfli@05ojfli@03o`000?n[]^7oZkKQ00?oZkKQ00?o0000ojVag_nY/Mh00_nY/Mh0
0ol0003oYZcKojJ/f`03ojJ/f`05o`000?nTY]OoY:KGojBVeol000000onQXM@01?l0003oWi_@oinK
d?nOVm02o`0000?oO8cH00?o0000ogj8domnR=<00_mnR=<01Ol0003oOhC>ogn4c_moQ<ko000000;o
P87:00Go0000oh5naon1O/OoPGk7o`000003oh9l``03o`000?n3N/7oPg[100;oPg[100Co0000ohAh
__n4N;ko00000omnMKh01Ol0003oPGBloh5d_?n1M;co000000?oPg>j0_l00004oh=c^@;o00000on5
LkP01?l0003oQWBhohId^?l00002ohMe^007o`000?n9M[SoRGJhohUf^?l0003oRWJgo`000002ohaj
^@04o`000?n=NKSoSGVho`0000GoT7fj0_nDP[`00ol0003oTgjjo`000004oiN3_003o`000?nKR;ko
VhRn00;oVhRn00?o0000oj2=`?nPSL000_nPSL001Ol0003oYI?2ojFC`_nUTl;o000000CoZiW400?o
0000ok6PaonaX<L00_naX<L01Ol0003o]jO9okNWbOngYlWo000000Co_Jo<00?o0000ol>gc_o3]lh0
0_o3]lh00ol0003obKk@olVnd002o`0000?ognOI00Co0000on;_f?oRkmSo00000_oTmMD01?l0003o
ho[Co`000?oQo=02o`0001[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05oooo
o`009oooool00ol0003oooooooooo`13ooooo`05o`000?o6b=coa/SLolK8g?l000000_n^`NL7ojfl
i@03o`000?n[]^7oZkKQ00?oZkKQ00?o0000ojVag_nY/Mh00_nY/Mh00ol0003oYZcKojJ/f`02ojJ/
f`03o`000?nTY]OoY:KG00;oY:KG00Wo0000oj6Qe?nQXMCoXJ7Do`000?nOVm3o0000og^AgOl00000
1?mlS=P01Ol0003oOXSCogj8domnR=?o000000CoOhC>00Co0000oh21b_n0PL[o00000on1O/L01Ol0
003oPWc3oh9l`on2O<?o000000?oPg[100Go0000ohAh__l0003oNgK2o`000003ogie_P05o`000?n1
M;coPGBloh5d_?l000000_n3LkX00ol0003oPGBko`000003oh=c^@06o`000?n4M;[o0000o`000?n5
LkSo00000_n6M;P01?l0003oQgFhohMe^?l00003ohUf^003o`000?n:M[Oo000000?oS7Zi00?o0000
ohei^?l000001?n@OKX01_l0003oU8:loiB2_?nDP[coTgjjo`0000CoUh>l00?o0000oi^8__nKR;h0
0_nKR;h00ol0003oX8g0oj2=`002oj2=`005o`000?nUTl;oYI?2ojFC`_l000001?n[VL@00ol0003o
/J37ok6Pa`02ok6Pa`05o`000?ngYlWo]jO9okNWbOl000001?nm[l`00ol0003o`kO>ol>gcP02ol>g
cP05o`000?o9_]3o0000om[MfOl000000ooOimT01?l0003oh^oHon;_f?l00002onCee@03o`000?oS
n]?o000000;o00006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000X
ooooo`;o0000A?ooool00ol0003oa/SLo`000004ojk1i`03o`000?n]_>Go[KcU00Co[KcU00?o0000
oj^fhOn[]^400on[]^400ol0003oZK7NojVagP02ojVagP03o`000?nV[=_oYZcK00;oYZcK00?o0000
ojBVeonTY]L00_nTY]L00ol0003oXJ7Doj6Qe002o`0000?oNi7M00?o0000ogb<f?mlS=P00_mlS=P0
1Ol0003oOXSCogj8domnR=?o000000?oOhC>00Go0000oh21b_n0PL[oP87:o`000003oh5na`05o`00
0?n2O<?oPWc3oh9l`ol000000_n3N/42o`0000?oNgK200Go0000ogie__mnMKkoOWFno`000003oh5d
_0;o00000on1M;/01?l0003oPg>ioh=c^Ol00003ohAd^P;o00000_n6M;P01Ol0003oQgFhohMe^?n7
MKSo000000?oRGJh00?o0000ohaj^On<N[T00on<N[T2o`0000CoT7fj00?o0000oiB2_?nDP[`00_nD
P[`2o`0000?oUh>l00?o0000oi^8__nKR;h00_nKR;h00ol0003oX8g0oj2=`002oj2=`005o`000?nU
Tl;oYI?2ojFC`_l000001?n[VL@00ol0003o/J37ok6Pa`02ok6Pa`05o`000?ngYlWo]jO9okNWbOl0
00001?nm[l`00ol0003o`kO>ol>gcP02ol>gcP;o00000_oJgMT01Ol0003ognOIomoWfOoOimWo0000
00;oh^oH00?o0000onCeeOl000000_oSn]<2o`0001gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`12ooooo`03o`000?n^`NOo[/7W00Co
[/7W0_l00005ojfli@03o`000?n[]^7oZkKQ00?oZkKQ00?o0000ojVag_nY/Mh00_nY/Mh00ol0003o
YZcKojJ/f`02ojJ/f`04o`000?nTY]OoY:KGojBVe`?o00000_mjUn<01Ol0003oNi7Mog^AgOmkTMgo
000000CoO8cH00Go0000ogj8domnR=?oOXSCo`000003ogn4cP05o`000?n0PL[oP87:oh21b_l00000
0_n1O/L02Ol0003oPWc3oh9l`on2O<?o0000oh=j`Ol0003oN7O5o`000003og]f`P05o`000?mnMKko
OWFnogie__l000001?n1M;`00ol0003oPGBkoh5d^`02oh5d^`03o`000?n3LkWo000000CoQ7Bj0_l0
00000on6M;So0000ohMe^002ohMe^003o`000?n9M[SoRGJh00;o00001_n<N[T00ol0003oT7fjoi1m
^P02oi1m^P03o`000?nDP[coU8:l00;oU8:l0_nIQkl4o`0000CoVhRn00?o0000oj2=`?nPSL000_nP
SL001Ol0003oYI?2ojFC`_nUTl;o000000CoZiW400?o0000ok6PaonaX<L00_naX<L00ol0003o]jO9
okNWb@02okNWb@05o`000?nm[lco_Jo<okf_c?l000000oo3]lh2o`0000;of]gI00Go0000omoWfOoO
imWognOIo`000002on;_f005o`000?oTmMGoi?GEo`000?oSn]<00_l0000Oooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@oooool7ojk1
i`03o`000?n]_>Go[KcU00?o[KcU0_l00004oj^fh@03o`000?nY/MkoZK7N00;oZK7N00?o0000ojJ/
fonV[=/00_nV[=/00ol0003oY:KGo`000003ogVLj0?oNYOS00Go0000og^AgOmkTMgoNi7Mo`000003
ogb<f003o`000?mnR=?oOXSC00;oOXSC00Go0000ogn4c_moQ<koOhC>o`000002oh21bP05o`000?n1
O/OoPGk7oh5naol000000on2O<<01Ol0003oN7O5ogQgaOmhMlGo000000?oNgK200Go0000ogie__mn
MKkoOWFno`000003oh5d_003o`000?n1M;_oPGBk00?oPGBk0_l00004ohAd^P04o`000?n6M[_o0000
o`0000?oQgFh00?o0000ohUf^?l000000_n;NKX00ol0003oS7Ziohaj^@03ohaj^@03o`000?n@OK[o
T7fj00;oT7fj00?o0000oiB2_?nDP[`00_nDP[`5oiV7_`;o00000onKR;h00ol0003oX8g0oj2=`002
oj2=`005o`000?nUTl;oYI?2ojFC`_l000001?n[VL@00ol0003o/J37ok6Pa`02ok6Pa`03o`000?ng
YlWo]jO900;o]jO900Co0000okf_c?nm[lco_Jo<1?l000001OoCd]So0000om[MfOoJgMWo000000?o
gnOI00Co0000on;_f?oRkmSo00000_oTmMD3o`00027ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`04ooooo`00;?ooool00ol0003oooooooooo`13ooooo`03o`000?n^`NOo[/7W00Co
[/7W00?o0000ojfliOn]_>D01?n]_>D00ol0003oZkKQoj^fh@02oj^fh@03o`000?nY/MkoZK7N00;o
ZK7N00Co0000ojJ/fonV[=_oYZcK0_l00005ogVLj0?oNYOS00Go0000og^AgOmkTMgoNi7Mo`000003
ogb<f005o`000?mnR=?oOXSCogj8dol000000omoQ<h01Ol0003oP87:oh21b_n0PL[o000000;oPGk7
00Go0000oh9l`on2O<?oPWc3o`000004ogQga@05o`000?mkM/;oNgK2og]f`_l000000omnMKh00ol0
003oPGBloh5d_002o`0000GoPGBk0_l00003ohAd^P04o`000?n6M[_oQWJkohIf^`Go00001?n;NKX0
1ol0003oS7Ziohaj^On<N[Wo0000oi1n_?l000000on@OKX00ol0003oU8:loiB2_002oiB2_003o`00
0?nIQkooVHNo00;oVHNo0_nOSL82o`000003oi^8__l0003oX8g000?oX8g000Go0000ojFC`_nUTl;o
YI?2o`000004oj^Ia003o`000?naX<Oo/J3700;o/J3700?o0000okNWbOngYlT00_ngYlT00ol0003o
_Jo<okf_c002o`0000Codm;H00Co0000om[MfOoJgMWo00000ooOimT01Ol0003oh^oHon;_f?l0003o
i?GE00?o00008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000]oooo
o`;o0000AOooool00ol0003o[/7Wojk1i`03ojk1i`;o00001On]_>D00ol0003oZkKQoj^fh@02oj^f
h@03o`000?nY/MkoZK7N00;oZK7N00?o0000ojJ/fol000000omhXnd5ogVLj0?oNYOS00Go0000og^A
gOmkTMgoNi7Mo`000003ogb<f005o`000?mnR=?oOXSCogj8dol000000omoQ<h01Ol0003oP87:oh21
b_n0PL[o000000;oPGk700Go0000oh9l`ol0003oLgS:o`000003ogQga@05o`000?mkM/;oNgK2og]f
`_l000001?mnMKh2o`0000;oOgFn00?o0000oh5d^on1M;/00_n1M;/00ol0003oPWJmo`000002ohAd
^P05o`000?n6M[_oQWJkohIf^ol000000on8N;/00ol0003oRgVjoh]i^P02oh]i^P04o`000?n<N[Wo
S7Zio`0000?oT7jl00?o0000oi1m^_l000001OnDP[`00ol0003oVHNooiV7_`02oiV7_`GoWhg21?l0
00000onPSL3o0000ojFC`P02ojFC`P03o`000?n[VLCoZiW400;oZiW400?o0000ok6PaonaX<L00_na
X<L00ol0003o]jO9okNWb@02okNWb@?o000000?oc<OFo`000?oCd]P00_oCd]P01Ol0003of]gIom[M
fOoJgMWo000000;ognOI00Co0000on;_f?oRkmSo00000_oTmMD2o`0002Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`04ooooo`00;oooool00ol0003oooooooooo`13ooooo`03o`00
0?n^`NOo[/7W00Co[/7W00?o0000ojfliOn]_>D00on]_>D00ol0003oZkKQoj^fh@02oj^fh@04o`00
0?nY/MkoZK7NojVagP;o00001OmhXnd5ogVLj004o`000?mjUn?oNYOSo`0000?oNi7M00Go0000ogb<
f?mlS=SoO8cHo`000003ogj8d`05o`000?moQ<koOhC>ogn4c_l000000_n0PLX01Ol0003oPGk7oh5n
aon1O/Oo000000?oLgS:00Go0000ogQgaOmhMlGoN7O5o`000003og]f`P03o`000?mnMKkoOWFn00;o
OWFn00Go0000ogme__moMKkoOgFno`000003oh5d^`04o`000?n2M[goPWJmo`0000;oQ7Bj00Go0000
ohIf^on6M[_oQWJko`000003ohQh^`03o`000?n;NK[oRgVj00;oRgVj00?o0000ohaj^Ol000001?n@
O[`2o`0000GoU8:l00?o0000oiV7_onIQkl00_nIQkl00ol0003oWhg2oin=`P02oin=`PCoYIG51?l0
00000onUTl;o0000oj^Ia003oj^Ia003o`000?naX<Oo/J3700;o/J3700?o0000okNWbOngYlT00ol0
0003olc7eP05o`000?oCd]Sodm;Hom?Bf?l000000_oJgMT01Ol0003ognOIomoWfOoOimWo000000;o
h^oH00?o0000onCeeOl000000_l0000Uooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01?ooool0033ooooo00?o0000ooooooooool0@oooool2o`0000Go[/7W00?o0000ojfliOn]_>D0
0on]_>D00ol0003oZkKQoj^fh@02oj^fh@03o`000?nY/Mko000000?oN:Wb1OmhXnd00ol0003oNIcX
ogVLj002ogVLj004o`000?mjUn?oNYOSo`0000?oNi7M00Go0000ogb<f?mlS=SoO8cHo`000003ogj8
d`05o`000?moQ<koOhC>ogn4c_l000000_n0PLX01?l0003oPGk7o`000?l00004og=hbP05o`000?mh
MlGoN7O5ogQgaOl000000omkM/801Ol0003oOWFnogie__mnMKko000000CoOgFn00Co0000oh5d^on1
M;_o00000on2M[d00ol0003oQ7Bjo`000003ohIf^`05o`000?n8N;_oR7RkohQh^ol000001On;NKX0
0ol0003oT7jloi1n_004oi1n_0;o00000onDP[`00ol0003oVHNooiV7_`03oiV7_`03o`000?nOSL;o
Whg200;oWhg21OnUULD00ol0003o[9g8ojbMb00>o`0000;oa;cB00Co0000olc7e_o<amKo00001?oC
d]P01?l0003of]gIom[MfOl00003omoWf@03o`000?oRkmSoh^oH00Co00009oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Cooooo000aooooo`;o0000AOooool00ol0003o[/7Wojk1
i`03ojk1i`03o`000?n]_>Go[KcU00?o[KcU00Co0000oj^fhOn[]^7oZkKQ0_l00005ogRYlP03o`00
0?mhXngoN:?]00;oN:?]00?o0000ogVLj?miW>P00_miW>P01?l0003oNYOSogZGhol00003og^Ag@05
o`000?mlS=SoO8cHogb<f?l000000_mnR=<01Ol0003oOhC>ogn4c_moQ<ko000000?oP87:00Co0000
ofejcom]N/oo00001?mcN<X01Ol0003oN7O5ogQgaOmhMlGo000000;oNgK200Ko0000ogie__mnMKko
0000og]f`_l00004ogme_P03o`000?n1M;_o000000CoPWJm0_l00004ohIf^`05o`000?n8N;_oR7Rk
ohQh^ol000000on;NKX2o`0000KoT7jl0_nCPkl01?l0003oU8:loiB2_?l00005oiV7_`03o`000?nO
SL;oWhg200;oWhg200?o0000ojFEaOnUULD00_nUULD01Ol0003o[9g8ojbMb?n/WLSo000000Co/jO<
00?o0000ok^aconk/Ll00_nk/Ll00ol0003oa;cBolBldP02olBldP04o`000?o<amKoc<OFo`0000Co
dm;H00Co0000om[MfOoJgMWo00000_oOimT00ol0003oh^oHon;_f004o`0002Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`03ooooo`00<oooool00ol0003oooooooooo`13ooooo`;o
00001?n^`NL2o`0000Co[KcU00?o0000oj^fhOl000000omh/?H5ogRYlP03o`000?mhXngoN:?]00;o
N:?]0_l00003ogVLj004o`000?mjUn?oNYOSo`0000?oNi7M00Co0000ogb<f?mlS=So00000omnR=<0
1_l0003oOhC>ogn4c_moQ<ko0000oh21bP;o00000om]N/l01Ol0003oLgS:og=hb_mcN<[o000000?o
N7O500Oo0000og]f`_mkM/;oNgK2o`000?mnMKko000000;oNgK200?o0000ogme__moMKh00_moMKh2
o`0000GoPWJm0ol00002ohIf^`05o`000?n8N;_oR7RkohQh^ol000000_n;NKX01?l0003oSGfmohem
_Ol00004oi1n_007o`000?nCPkooTh>ooi>3_ol0003oU8:lo`000005oiV7_`05o`000?nOSL;oWhg2
oin=`_l000001OnUULD01Ol0003o[9g8ojbMb?n/WLSo000000Co/jO<00?o0000ok^aconk/Ll00_nk
/Ll01Ol0003oa;cBolBld_o4_=;o000000?oc<OF00Go0000om?Bf?oCd]Sodm;Ho`000003om[Mf@05
o`000?oOimWognOIo`000?oRkmP01?l0000Zooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003o[/7Wojk1i`03ojk1i`04
o`000?n]_>Go[KcUojfli@;o00001Omh/?H00ol0003oN:WbogRYlP03ogRYlP03o`000?mhXngoN:?]
00;oN:?]00Go0000ogVLj?miW>SoNIcXo`000002ogZGh`05o`000?mkTMgoNi7Mog^AgOl000000_ml
S=P01Ol0003oOXSCogj8domnR=?o000000;oOhC>0_l00002ofEke005o`000?m]N/ooKG[?ofejcol0
00000omcN<X01Ol0003oN7O5ogQgaOmhMlGo000000?oNgK200?o0000og]f`_mkM/800_mkM/800ol0
003oOgFnogme_P02ogme_P;o00001?n2M[d00ol0003oQGVnohEi_P03o`0000?oR7Rk00?o0000oh]i
^_l000001?n=OKd01Ol0003oT7jloi1n_?n@O[co000000CoTh>o0_l00004oiV7_`03o`000?nOSL;o
Whg200;oWhg200?o0000ojFEaOnUULD00_nUULD00ol0003o[9g8ojbMb002ojbMb005o`000?ncYlco
/jO<ok>Wc?l000001?nk/Ll00ol0003oa;cBolBldP02olBldP05o`000?o<amKoc<OFolc7e_l00000
0ooCd]P01?l0003of]gIom[MfOl00003omoWf@;o000000?o_?Vio`000?l00000;?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000eooooo`03o`000?oooooooooo04Cooooo
00?o0000ojk1ion^`NL00on^`NL00ol0003o[KcUo`000003ogVfn@KoN;3f00?o0000ogRYl_mhZO80
0_mhZO82o`0000?oN:?]00Go0000ogVLj?miW>SoNIcXo`000002ogZGh`05o`000?mkTMgoNi7Mog^A
gOl000000_mlS=P01?l0003oOXSCogj8domnR=<2o`000003oe]mfol0003oIG_D00;oIG_D00Go0000
ofejcom]N/ooKG[?o`000003og=hbP05o`000?mhMlGoN7O5ogQgaOl000000_mkM/82o`0000CoNgK2
00Oo0000ogme__moMKkoOgFno`000?moN<7o000000?oPWJm00?o0000ohEi__n5NKh00on5NKh5o`00
00GoSGfm00Co0000oi1n_?n@O[co00001_nCPkl2o`0000?oVHNo00?o0000oin=`_nOSL800_nOSL80
0ol0003oYIG5ojFEa@02ojFEa@05o`000?n/WLSo[9g8ojbMb?l000001?ncYl`00ol0003o^k7?ok^a
c`02ok^ac`03o`000?o4_=;oa;cB00;oa;cB00Co0000olc7e_o<amKo00001?oCd]P01?l0003of]gI
om[MfOl00002omoWf@;o000000?o_?Vio`000?l00000;_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo000fooooo`;o0000AOooool2o`0000?o[/7W0_l00006ogVfn@KoN;3f
00?o0000ogRYl_mhZO800_mhZO801Ol0003oN:?]ogRSkOmhXngo000000?oNIcX00Co0000ogZGhomj
Un?o00000omkTMd01_l0003oO8cHogb<f?l0003oOXSCo`0000;oCgoP00?o0000oe]mfol000000omU
Nm@01Ol0003oKG[?ofejcom]N/oo000000?oLgS:00Co0000ogQgaOmhMlGo00000_mkM/800ol0003o
MWS7o`000004og]f`P04o`000?moMKkoOgFno`0000;oOgS10_l000000on2M[go0000ohEi_P04ohEi
_P05o`000?n9O;koRGbnohUl__l000001_n=OKd00ol0003oT7jlo`000006oi>3_`;oV8[300Co0000
oiV7_onIQkoo00001?nOSL800ol0003oYIG5ojFEa@02ojFEa@05o`000?n/WLSo[9g8ojbMb?l00000
1?ncYl`00ol0003o^k7?ok^ac`02ok^ac`03o`000?o4_=;oa;cB00;oa;cB00Co0000olc7e_o<amKo
00001?oCd]P01Ol0003of]gIom[MfOl0003ognOI00;o000000?o_?Vio`000?l00000;oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000hooooo`03o`000?oooooooooo04Co
oooo00?o0000ojk1iol000000oml_?/7ogVfn@03o`000?mh/?KoN;3f00;oN;3f0_l00003ogRYlP04
o`000?mhXngoN:?]ogRSk@;o00000_miW>P01?l0003oNYOSogZGhol00003og^Ag@03o`000?mlS=So
000000;o00000om?On000ol0003oFggKo`000003ofEke005o`000?m]N/ooKG[?ofejcol000000_mc
N<X01?l0003oN7O5ogQgaOmhMlD2o`0000?oMWS700?o0000og]f`_mkM/800_mkM/800ol0003oOgFn
o`000004ogmh`@03o`000?n2M[go000000CoQGVn00?o0000ohUl__n9O;h00_n9O;h00ol0003oSGfm
ohem_@04ohem_@03o`000?nCPkooTh>o00CoTh>o00Oo0000oiR:`onHR/?oV8[3o`000?nIQkoo0000
00CoWhg200?o0000ojFEaOnUULD00_nUULD01Ol0003o[9g8ojbMb?n/WLSo000000Co/jO<00?o0000
ok^aconk/Ll00_nk/Ll01Ol0003oa;cBolBld_o4_=;o000000?oc<OF00Go0000om?Bf?oCd]Sodm;H
o`000003om[Mf@;o000000CobOo<o`000?l0003o0000<Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo00?o0000ogblnoml_?/0
1?ml_?/00ol0003oNKKiogVfn@03ogVfn@;o00001?mh/?H01?l0003oN:WbogRYl_mhZO82o`0000?o
N:?]00Co0000ogVLj?miW>So00000_mjUn<01?l0003oNi7Mog^AgOmkTMd2o`0000;o@GoU00Oo0000
odmoh?m?On3oCgoPo`000?mKOM_o000000?oIG_D00Co0000ofejcom]N/oo00000omcN<X01Ol0003o
N7O5ogQgaOmhMlGo000000CoMWS700?o0000og]f`_mkM/800_mkM/82o`0000GoOgS10_l00005ohEi
_P03o`000?n9O;koRGbn00;oRGbn00?o0000ohem_On=OKd00_n=OKd2o`0000KoTh>o00?o0000oiR:
`onHR/<00_nHR/<2o`0000CoWhg200?o0000ojFEaOnUULD00_nUULD01Ol0003o[9g8ojbMb?n/WLSo
000000Co/jO<00?o0000ok^aconk/Ll00_nk/Ll01Ol0003oa;cBolBld_o4_=;o000000?oc<OF00Go
0000om?Bf?oCd]Sodm;Ho`000002om[Mf@;o000000CobOo<o`000?l0003o0000<oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo04Gooooo
00?o0000ogblnoml_?/01?ml_?/00ol0003oNKKiogVfn@03ogVfn@;o00000omh/?H2o`0000?oN:Wb
00Go0000ogRSkOmhXngoN:?]o`000002ogVLj006o`000?mjUn?oNYOSo`000?mkTMgo00000_l_OnP0
1?l0003o@GoUod5oiOl00003odmoh003o`000?mKOM_o000000?oIG_D00Co0000ofejcom]N/oo0000
0omcN<X00ol0003oN7O5ogQga@02o`0000CoMWS700?o0000og]f`_mkM/800_mkM/82o`0000GoOgS1
0_l00004ohEi_P03o`000?n9O;koRGbn00;oRGbn00Go0000ohem_On=OKgoSGfmo`000002oi23`@03
o`000?nCPkooTh>o00;oTh>o00?o0000oiR:`onHR/<01?nHR/<2o`0000?oWhg200?o0000ojFEaOnU
ULD00_nUULD01Ol0003o[9g8ojbMb?n/WLSo000000?o/jO<00?o0000ok^aconk/Ll00_nk/Ll00ol0
003oa;cBolBldP02olBldP04o`000?o<amKoc<OFo`0000Codm;H00Go0000om[MfOl0003o0000olWo
c003o`0003Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00>oooool2
o`0004Sooooo00?o0000ogblnoml_?/00oml_?/2o`0000CoNKKi0_l00003ogR`mP04o`000?mhZO;o
N:WbogRYlP;o00000_mhXnd01Ol0003oNIcXogVLj?l0003oNYOS00;o00001?l_OnP01?l0003o@GoU
od5oiOl00003odmoh003o`000?mKOM_o000000;oIG_D00Go0000ofejcom]N/ooKG[?o`000003og=h
bP;o00000_m_NLd00ol0003oMWS7ogIha`02ogIha`07o`000?mkM/;oNgK2og]f`_l0003oO7_6o`00
0004ogmh`@03o`000?n4O<?o000000;o000000?oQGVno`000?n9O;h01?n9O;h00ol0003oSGfmo`00
0004oi23`@05o`000?nCPkooTh>ooi>3_ol000001_nHR/<01Ol0003oWY;7o`000?nOSL;o000000Go
YIG500Go0000ojbMb?n/WLSo[9g8o`000003ok>Wc003o`000?nk/Loo^k7?00;o^k7?00Go0000olBl
d_o4_=;oa;cBo`000003olc7eP03o`000?oCd]Sodm;H00;odm;H0_l000000ooBo]_o0000o`000002
o`0003Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00?Oooool00ol0
003oooooooooo`17ooooo`;o00001?ml_?/3o`0000?oNKKi0_l00002ogR`mP;o00000omhZO801Ol0
003oN:?]ogRSkOl0003oNIcX00;o00000olLO^L4obmoj0;o000000?o@GoUo`000?m?On000_m?On00
0ol0003oFggKo`000002ofEke005o`000?m]N/ooKG[?ofejcol000000omcN<X2o`0000;oKgW=00?o
0000ogIhaomfN<L00_mfN<L01?l0003oNgK2og]f`_l00002ogakaP05o`000?moN<7oOgS1ogmh`Ol0
00001?n4O<<3o`0000;oRGbn1?l00005oi23`@04o`000?nCPkooTh>oo`0000KoV8[300Co0000oijB
aonNT/OoWY;70_l00004ojFEa@03o`000?n/WLSo[9g800;o[9g800Go0000ok>Wc?ncYlco/jO<o`00
0004ok^ac`05o`000?o4_=;oa;cBolBld_l000000oo<amH01?l0003odm;Hom?Bf?oCd]P2o`000003
om;nfol0003obOo<00;o0000>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000nooooo`03o`000?oooooooooo04Wooooo0_l00004ogbln`;o00000omi]_T01?l0003oN;3f
ogR`m_mh/?H2o`0000;oN:Wb00Co0000ogRSkOl0003o00000ol9O>83oaani`03o`000?l_OnSo;goX
00;o;goX00?o0000od5oiOl000000om?On000ol0003oFggKo`000002ofEke005o`000?m]N/ooKG[?
ofejcol000000_mcN<X00ol0003oIG_Co`000002ofmic@03o`000?mfN<OoMWS700;oMWS700?o0000
og]f`_l000000omlNlH2o`000003ogmh`Ol0003oQ7c300GoQ7c30ol00003ohZ1``03o`000?n@Pl7o
T8?100CoT8?100?o0000oi>3_ol000001OnHR/<00ol0003oWY;7oijBa`03oijBa`;o00000onUULD0
1Ol0003o[9g8ojbMb?n/WLSo000000Co/jO<00?o0000ok^aconk/Ll00_nk/Ll01Ol0003oa;cBolBl
d_o4_=;o000000?oc<OF00?o0000om?Bf?oCd]P00_l000000ooBo]_o0000olWoc002o`0003[ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00?oooool00ol0003ooooooooo
o`1:ooooo`;o00001?ml_?/2o`0000;oNKKi0_l00003ogR`mP04o`000?mhZO;o0000o`0000?o07WJ
0ol9O>801?l0003o77kWoaaniolLO^L4obmoj003o`000?m1OnGo000000?oCgoP00?o0000oe]mfol0
00000_mUNm@01?l0003oKG[?ofejcom]N/l2o`0000?oIG_C00Co0000ofmicOm_NLgo00001?mfN<L2
o`0000GoO7_600?o0000ogmh`Ol000001On4O<<00ol0003oRX73ohZ1``04ohZ1``03o`000?n@Pl7o
T8?100?oT8?10_l00006oiR:``03o`000?nNT/OoWY;700?oWY;700?o0000ojFLc?l000000ol00003
ojbMb003o`000?ncYlco/jO<00;o/jO<00?o0000ok^aconk/Ll00_nk/Ll01Ol0003oa;cBolBld_o4
_=;o000000;oc<OF1?l000001?oDm^Co0000o`000?o9ol`2o`0003cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`00@?ooool2o`0004cooooo0ol00003ogbln`;o00000_mi
]_T2o`000003ogR`m_l0003o000000?o07OA1?l0NMX3o`UlhP04o`000?lLO^Oo77kWo`0000?o;goX
1?l00002odmoh003o`000?mKOM_o000000;oIG_D00Co0000ofejcom]N/ooKG[?0_l00003ofEkd`04
o`000?m_NLgoKgW=o`0000CoMWS70_l00005ogakaP;o00001_n4O<<00ol0003oRX73ohZ1``03ohZ1
``03o`000?n@Pl7oT8?100;oT8?100Co0000oiB:a_nDR/Ko00001?nHR/<00ol0003oWY;7oijBa`03
oijBa`03o`000?nUW<coYIc<00?oYIc<0ol000000on/WLSo0000ok>Wc002ok>Wc003o`000?nk/Loo
^k7?00;o^k7?00Ko0000olBld_o4_=;oa;cBo`000?o<amH3o`0000?oe?KT00Go0000om;nfol0003o
bOo<o`00000mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool004;ooooo
00?o0000ooooooooool0C?ooool2o`0000?oO;ck0_l000000omi]_Wo0000o`000003o`1gb@Co07OA
0ol0NMX01?l0003o2GcRo`Ulh_l9O>83oaani`07o`000?l_OnSo;goXobmoj?l0003o@GoUo`000002
odmoh003o`000?mKOM_o000000;oIG_D00?o0000ofejcol000000_mHO=/01Ol0003oIG_CofEkdomU
Nm?o000000;oKgW=00Oo0000ogIhaomfN<OoMWS7o`000?mgO/go000000GoO7_60_l00005ohAl``03
o`000?n:PL?oRX7300CoRX7300Co0000oi23`On@Pl7o00001?nDR/H01Ol0003oV8[3oiR:`onHR/?o
000000GoWY;700?o0000ojFLc?nUW<`00onUW<`00ol0003o[JOBojfWdP04o`000003ok>Wc?l0003o
^k7?00?o^k7?00?o0000olBld_l000000ol00002om7WiP08o`000?oDm^Coe?KTo`000?oBo]_o0000
olWoc?l0000oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool004?ooooo
00?o0000ooooooooool0COooool3o`000003ogblnol0003o000000?o07_61Ol0MlT3o`1gd@?o07WJ
00Co0000o`Ulh_l9O>;o00000_lLO^L2o`0000;o;goX00?o0000od5oiOl000000_m?On000ol0003o
FggKo`000002ofEke0;o00000omHO=/01Ol0003oIG_CofEkdomUNm?o000000;oKgW=00Co0000ogIh
aomfN<Oo00000_mgO/d2o`0000?oO7_600?o0000oh:1bOl000000_l00002ohAl``03o`000?n:PL?o
RX7300CoRX7300?o0000oi23`Ol000001_nDR/H00ol0003oV8[3o`000005oijBa`03o`000?nUW<co
YIc<00?oYIc<00?o0000ojfWd_n]Ym800_n]Ym800ol0003o][GHokJef008o`0000;obMKT00Co0000
om7Wi_oAinKo00000ooDm^@2o`000003olWoc?l0003ooooo043ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`1?ooooo`03o`000?l0PlOo
08?700;o08?71?l0NlH4o`1gb@?o07OA0ol0NMX01?l0003o2GcRo`Ulh_l00002oaani`06o`000?l_
OnSo;goXo`000?m1OnGo00000_m?On001ol0003oFggKo`000?mUNmCo0000od=kh_l000000omHO=/0
1Ol0003oIG_CofEkdomUNm?o000000;oKgW=0_l00005ogMnc@04o`000?mlNlKoO7_6o`0000CoPX79
1?l00003ohZ1``Co00001onDR/H2o`0000GoWY;700?o0000ojFLc?nUW<`00onUW<`00ol0003o[JOB
ojfWdP02ojfWdP03o`000?nf]MSo][GH00;o][GH00?o0000oko5g_noaMh00_noaMh01?l0003obMKT
olWFi?l00002om7WiP04o`000?oDm^Coe?KTomCfi0;o000000?obOo<o`000?l00000@_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000D_ooool5o`23a`Co
07_60ol0MlT00ol0003o07OAo`1gd@03o`1ifP05o`000?l9O>;o0000o`000?lLO^L00_l000001?l_
OnSo0000o`000?l00002odmoh004o`000?mKOM_o0000o`0000;o@g_R00Go0000oeQlfomHO=_oF7cK
o`000003ofEkd`03o`000?m_NLgoKgW=00;o00001OmgO/d2o`000003ogaka_l0003oPX7900GoPX79
1?l00003ohb7b@03o`000?nDR/KoU8[600CoU8[600Co0000oiRCcOnHTlgo00001?nNT/L00ol0003o
YIc<ojFLc003ojFLc003o`000?n]Ym;o[JOB00;o[JOB00Go0000okJef?nf]MSo][GHo`000004oko5
gP04o`000?o9e^CobMKTo`0000?odNOV00?o0000omCfi?oDm^@00_l00002olWoc003o`000?oooooo
oooo047ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00Aoooool00ol0
003oooooooooo`1Cooooo`Co08?700Co0000o`1ka_l0NlKo07_60ol0MlT2o`1gd@03o`000?l0NM[o
000000;o2GcR00Co0000oaaniolLO^Oo00000_l_OnP2o`0000;oCgoP0_l000001OlWN>Co0000od=k
h_m3Nn;o000000?oF7cK0_l00002ofEkd`05o`000?m_NLgo0000ofn2eOl000001_mgO/d2o`0000Ko
PX7900?o0000ohb7bOn<QlT01On<QlT00ol0003oU8[6oiB:aP02oiB:aP03o`000?nHTlgoV9?=00;o
V9?=00Co0000oijBaonNT/Oo00001OnUW<`00ol0003o[JOBojfWdP02ojfWdP03o`000?nf]MSo][GH
00;o][GH00?o0000oko5g_noaMh00_noaMh01?l0003obMKTolWFi?l00002om7WiP08o`000?oDm^Co
e?KTo`000?oBo]_o0000olWoc?l00015ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00Oooool004Sooooo00?o0000ooooooooool0E_ooool4o`23a`;o07_600?o0000o`1gbOl0MlT0
0_l0Mm401?l0003o07WJo`000?l9O>82o`000004oaaniol0003o0000obmoj0;o000000KoCgoPo`00
0?l1K]co0000obMhi?l00002od=khP;o00000omHO=/00ol0003oIG_CofEkd`02o`0000;oKh;E0_l0
0005ogMnc@?o00001On2PLT00ol0003oS8O9ohb7b@05ohb7b@04o`000?nDR/KoU8[6o`0000KoV9?=
00?o0000oijBaol000001OnUW<`00ol0003o[JOBojfWdP02ojfWdP05o`000?nf]MSo][GHokJef?l0
00001?noaMh01?l0003obMKTolWFi?l00003om7WiP03o`000?oDm^Coe?KT00Co0000Aoooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0019ooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool00_l0PlL2o`1kaP08o`000?l0MlWo0000o`1gdOl0003o07WJo`000?l9
O>82o`000003oaaniol0003o;goX00?o00000_l1K]`4o`0000;o@g_R00Go0000oeQlfomHO=_oF7cK
o`000002ofEkd`;o00000om_P]D2o`0000?oMgk=00?o0000ogn7dOmoQm400ol00002oh:1b@03o`00
0?n<QlWoS8O900GoS8O900?o0000oiB:a_l000001onHTld3o`0000CoYIc<00?o0000ojfWd_n]Ym80
0_n]Ym800ol0003o][GHokJef002okJef005o`000?noaMko_lGNoko5g_l000000oo9e^@01?l0003o
dNOVom7Wi_l00002omCfi0?o0000B_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo001:ooooo`;o0000Eoooool00ol0003oooooooooo`04ooooo`06o`23aol0003o07_6o`00
0?l0MlWo07OA0ol000001?l9O>;o0000oaaniol00002oe0000?o00000_l1K]`00ol0003o9gSTo`00
0002od=khP08o`000?mHO=_oF7cKoeQlfol0003oIG_Co`000?mRQ]l2o`0000?oKh;E00Co0000ogMn
cOmgO/go00001OmoQm43o`0000CoS8O91Ol00007oiRCc@05o`000?nNWmGoWYoEoijOeOl000000_nU
W<`00ol0003o[JOBojfWdP02ojfWdP03o`000?nf]MSo][GH00;o][GH00?o0000oko5g_noaMh00_no
aMh01?l0003obMKTolWFi?l00002om7WiP03o`000?oDm^Coe?KT00;o0000C?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo007ooooo001<ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool02?ooool00ol0003o07_6o`000005o`0000;oJP000om@0002o`0000;o0FkL1?l0
00000om3Nn;o0000o`000002oeQlf`;o00000omRQ]l01?l0003oKh;Eofn2eOm_P]D2o`000003ogMn
cOl0003oOhOA00KoOhOA1?l00004ohf@d@03o`000?nHTlgoV9?=00?oV9?=0_l00005oijOe@03o`00
0?nUW<co000000Co[JOB00Go0000okJef?nf]MSo][GHo`000004oko5gP04o`000?o9e^CobMKTo`00
00?odNOV00Co0000omCfi?oDm^Co0000C_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1
ooooo`00COooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00gooooo00CoP@00oh<0
0?n1003oNP000omZ0003oe0000;o00000_l1K]`00ol0003o9gSTo`000002od=khP03o`000?mHO=_o
F7cK00;o00000omRQ]l2o`0000?oKh;E0_l00007ogn7d@03o`000?n=T=7oSI3A00KoSI3A00Go0000
oiRCcOnHTlgoV9?=o`000007oijOe@?o00000on]Ym800ol0003o][GHokJef002okJef003o`000?no
aMko_lGN00;o_lGN00Co0000olWFi?o9e^Co00000_oAinH01?l0003oe?KTomCfi?l0001@ooooo`03
o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001>ooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool04_ooool01?n1003oNP00ofX00?mZ0002oe0000?o000000Co0FkLo`000?lW
N>Co00000_m3Nn801?l0003oF7cKo`000?m=RNT2o`0000?oHXKO0_l00002ofn2e@?o00001_moQm40
0ol0003oSI3Aohf@d@06ohf@d@03o`000?nHTlgo000000OoWYoE00Co0000ojB^gonT[]ooY:kO0_l0
00000on]Ym;o0000okJef002okJef003o`000?noaMko_lGN00;o_lGN00Co0000olWFi?o9e^Co0000
0ooAinH3o`00057ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004oooooo0_l0
001Booooo`03o`000?oooooooooo01Gooooo00?oP@00ofX00?mZ00000_m@0002o`000003o`5^g?l0
003o000000;o000000?o@g_Ro`000?l000000om=RNT2o`0000?oHXKO00?o0000ofn2eOl000000_mk
Sm`3o`0000?oOhOA00?o0000ohf@dOn=T=401On=T=43o`0000OoWYoE00?o0000ojB^gonT[]l00onT
[]l4o`0000;o][GH00Go0000oko5g_noaMko_lGNo`000003olWFi003o`000?oAinKodNOV00;o0000
E?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo01Sooooo00CoP@00ofX00?mZ003oD0000_l000001Ol1K]co0000
obMhi?l0003o@g_R00;o00001?m=RNT2o`0000;oHXKO0ol00004og^?g0Co00000_n=T=45o`0000;o
SY_L00?o0000oijOeOnNWmD00onNWmD2o`0000GoY:kO00?o0000oj_1j_n[`NX00_n[`NX4o`0000;o
_lGN00?o0000olWFi?o9e^@01Ol0001Fooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo001Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06oooool2ofX00003oe00
0?l0003o000000Co000000?o:hO/o`000?l000001?m=RNT01?l0003oHXKOof:6gomRQ]l3o`0000Go
NhoL0ol00008ohjKg005o`000?nNWmGoWYoEoijOeOl000001_nT[]l00ol0003oZl7Zoj_1jP02oj_1
jP03o`000?naf?Co/MSd00;o/MSd2?l0001Iooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`7ooooo001Cooooo`;o0000C_ooool00ol0003oooooooooo`0Nooooo`04ofX00?m@003o0000o`5^
g0?o00000_l[Qn`2o`0000?oCHWY0_l000001?mRQ]oo0000og6IjOmaVNT4o`0000;oNhoL00?o0000
ohjKg?n>Vm`02?n>Vm`00ol0003oWYoEo`000005ojB^g`;o00000on[`NX2o`0000Co/MSd00Go0000
ok7]monakOOo0000ojGfj@02o`0005_ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Ooo
ool005Gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Pooooo`05ofX00?l0003o
0000o`000?l0N=P00ol000000ol[Qnco0000o`000003odf9j@?o00001OmaVNT4o`0000GoSY_L1_l0
0005ojB^g`03o`000?n[`N[oZl7Z00;oZl7Z00?o0000ok7Hm?naf?@00_naf?@2o`000004ok7]mol0
003o0000ojGfj@;o0000GOooool00ol0003oooooooooo`04ooooo`7o00000Oooool005Kooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Sooooo`03o`000?lo003o000000;o07SH0_l0
00000ol[Qnco0000o`000003odf9j@?o00001_maVNT6o`0000KoSZ_Y00Go0000ojB^gonT[]ooY:kO
o`000004oj_1jP04o`000?naf?Co/MSdok7Hm0;o000000Co/Nggo`000?l0003oYOKY0_l0001Poooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Eoooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo02Gooooo00GoIP00ocl00?lo003o0000o`1hf005o`000004odf9jOl0003oH:Cf
of2TmPCo00000omaVNT00ol0003oSZ_Yohj[j@09ohj[j@03o`000?nT[]oo000000?oZl7Z0_l00003
ok7Hm004o`000?nakOOo/Nggo`0000;oYOKY00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo02Sooooo00Go0000
ocl00?lo003o0000o`1hf005o`0000GoH:Cf1Ol00006ohj[j@So000000?oZl7Zo`000?naf?@00_na
f?@2o`000004ok7]mol0003o0000ojGfj@;o0000I?ooool00ol0003oooooooooo`02ooooo`7o0000
0Oooool005[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0[ooooo`03o`000?lo
003o000000Oo00001_mPY?H7o`0000GoRkkh1_l000001Onaf?Co0000ok7]monakOOo000000;oYOKY
00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0;_ooool00ol0003o?`00o`00000;o`000003of2T
m_l0003oRkkh00;oRkkh1_l00004oggAo`Wo0000JOooool01?l0003oooooooooool00001ooooo`00
G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo037ooooo00?o0000ocl00?l00000
1ol000000olmZ?Go0000o`000003o`0000KoOM7o2_l0001]ooooo`03o`000?oooooo0000007ooooo
001Mooooo`;o0000A?ooool00ol0003oooooooooo`0dooooo`04o`000?l`003o<000oc0000Wo0000
0_mmdOl9o`0007;ooooo00?o0000ooooooooool00Ol0000005oooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0looooo`?o<0002?l0001hooooo`7o00000Oooool1o`000000H?ooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo0_l00000067ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000?oooool00ol0003o
ooooooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2cooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`
ooooo`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:cooooo1?l0000Boooo
o`00JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0000Fooooo`00
J_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000Jooooo`00Jooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000Nooooo`00K?ooool2
o`0003Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool00ol0003ooooo
ooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`2>ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:
ooooo`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26oooo
o`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0000mooooo`00
Moooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l00011ooooo`00N?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015ooooo`00NOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019ooooo`00N_ooool2o`00
02Kooooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0003oooooooooo`1S
ooooo`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Ooooo
o`Co0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`Co
0000I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000
J?ooool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/ooooo`00Q_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`ooooo`00Qoooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00R?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROooool2o`0001Oooooo
00?o0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003oooooooooo`0dooooo`Co
0000Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`Co0000
Soooool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`?o0000Tooo
ool009;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00U?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2o`0000Sooooo00?o
0000ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000
]_ooool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002Oooooo`03o`000?oo
oooo000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o000000;o0000`Oooool0
0:7ooooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03003 .28261 -24 -2.73565 ]
[.03003 .28261 0 6.26435 ]
[.02107 .33874 -30 -2.78353 ]
[.02107 .33874 0 6.21647 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00213 .45746 -24 -2.88536 ]
[.00213 .45746 0 6.11464 ]
[-0.0079 .5203 -18 -2.93958 ]
[-0.0079 .5203 0 6.06042 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04225 .27781 m
.04836 .27542 L
s
[(-0.5)] .03003 .28261 1 -0.39208 Mshowa
.03334 .33406 m
.03947 .33172 L
s
[(-0.25)] .02107 .33874 1 -0.38144 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01448 .45303 m
.02066 .45081 L
s
[(0.25)] .00213 .45746 1 -0.35881 Mshowa
.00451 .516 m
.01071 .51384 L
s
[(0.5)] -0.0079 .5203 1 -0.34676 Mshowa
.125 Mabswid
.04049 .2889 m
.04416 .28747 L
s
.03872 .30007 m
.0424 .29864 L
s
.03694 .31131 m
.04062 .3099 L
s
.03515 .32265 m
.03882 .32124 L
s
.03151 .34556 m
.0352 .34416 L
s
.02968 .35715 m
.03336 .35576 L
s
.02783 .36882 m
.03152 .36744 L
s
.02597 .38058 m
.02966 .3792 L
s
.0222 .40436 m
.02589 .403 L
s
.02029 .41639 m
.02399 .41504 L
s
.01837 .42851 m
.02207 .42716 L
s
.01643 .44072 m
.02014 .43938 L
s
.01252 .46543 m
.01623 .4641 L
s
.01054 .47792 m
.01425 .47661 L
s
.00854 .49051 m
.01226 .48921 L
s
.00653 .50321 m
.01025 .50191 L
s
.04399 .26681 m
.04766 .26536 L
s
.04573 .25588 m
.04939 .25443 L
s
.00246 .52889 m
.00619 .5276 L
s
.0004 .54188 m
.00413 .5406 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51722 .66416 m .51694 .65827 L .43899 .65168 L p .592 .108 .075 r
F P
0 g
s
.51694 .65827 m .51722 .66416 L .5929 .66145 L p .538 .102 .161 r
F P
0 g
s
.5929 .66145 m .59527 .65394 L .51694 .65827 L p .538 .102 .161 r
F P
0 g
s
.59527 .65394 m .5929 .66145 L .66531 .6474 L p .431 .016 .148 r
F P
0 g
s
.66531 .6474 m .67023 .63881 L .59527 .65394 L p .431 .016 .148 r
F P
0 g
s
.44199 .6555 m .43899 .65168 L .36521 .63435 L p .543 0 0 r
F P
0 g
s
.43899 .65168 m .44199 .6555 L .51722 .66416 L p .592 .108 .075 r
F P
0 g
s
.5175 .67039 m .51722 .66416 L .44199 .6555 L p .608 .129 .091 r
F P
0 g
s
.51722 .66416 m .5175 .67039 L .5905 .66937 L p .55 .12 .176 r
F P
0 g
s
.5905 .66937 m .5929 .66145 L .51722 .66416 L p .55 .12 .176 r
F P
0 g
s
.5929 .66145 m .5905 .66937 L .66032 .65643 L p .441 .03 .163 r
F P
0 g
s
.66032 .65643 m .66531 .6474 L .5929 .66145 L p .441 .03 .163 r
F P
0 g
s
.36521 .63435 m .37098 .63578 L .44199 .6555 L p .543 0 0 r
F P
0 g
s
.44503 .65958 m .44199 .6555 L .37098 .63578 L p .566 0 0 r
F P
0 g
s
.44199 .6555 m .44503 .65958 L .5175 .67039 L p .608 .129 .091 r
F P
0 g
s
.67023 .63881 m .66531 .6474 L .73063 .62241 L p .24 0 .03 r
F P
0 g
s
.73063 .62241 m .73799 .61332 L .67023 .63881 L p .24 0 .03 r
F P
0 g
s
.37098 .63578 m .36521 .63435 L .29943 .6068 L p 0 .436 .783 r
F P
0 g
s
.51778 .67672 m .5175 .67039 L .44503 .65958 L p .619 .138 .089 r
F P
0 g
s
.5175 .67039 m .51778 .67672 L .58806 .67741 L p .557 .126 .178 r
F P
0 g
s
.58806 .67741 m .5905 .66937 L .5175 .67039 L p .557 .126 .178 r
F P
0 g
s
.37098 .63578 m .37681 .63738 L .44059 .65813 L p .566 0 0 r
F P
0 g
s
.44252 .65877 m .37098 .63578 L .44059 .65813 L .566 0 0 r
F
.44059 .65813 m .44503 .65958 L p .44252 .65877 L F P
0 g
s
.44811 .66371 m .44503 .65958 L .37681 .63738 L p .575 .004 0 r
F P
0 g
s
.37681 .63738 m .3827 .63899 L .44811 .66371 L p .575 .004 0 r
F P
0 g
s
.45125 .66766 m .44811 .66371 L .38282 .63904 L p .567 0 0 r
F P
0 g
s
.38282 .63904 m .3827 .63899 L p .38277 .63902 L .567 0 0 r
F P
0 g
s
.45125 .66766 m .38282 .63904 L .38277 .63902 L .567 0 0 r
F
.44503 .65958 m .44811 .66371 L .51778 .67672 L p .619 .138 .089 r
F P
0 g
s
.5905 .66937 m .58806 .67741 L .65525 .6656 L p .444 .033 .164 r
F P
0 g
s
.65525 .6656 m .66032 .65643 L .5905 .66937 L p .444 .033 .164 r
F P
0 g
s
.66531 .6474 m .66032 .65643 L .72318 .63194 L p .245 0 .044 r
F P
0 g
s
.72318 .63194 m .73063 .62241 L .66531 .6474 L p .245 0 .044 r
F P
0 g
s
.29943 .6068 m .30793 .60571 L .37098 .63578 L p 0 .436 .783 r
F P
0 g
s
.37681 .63738 m .37098 .63578 L .30793 .60571 L p 0 .418 .789 r
F P
0 g
s
.51808 .68286 m .51778 .67672 L .44811 .66371 L p .624 .135 .071 r
F P
0 g
s
.51778 .67672 m .51808 .68286 L .58557 .68526 L p .56 .123 .166 r
F P
0 g
s
.58557 .68526 m .58806 .67741 L .51778 .67672 L p .56 .123 .166 r
F P
0 g
s
.44811 .66371 m .45125 .66766 L .51808 .68286 L p .624 .135 .071 r
F P
0 g
s
.30793 .60571 m .31651 .60468 L .37681 .63738 L p 0 .418 .789 r
F P
0 g
s
.3827 .63899 m .37681 .63738 L .31651 .60468 L p 0 .418 .811 r
F P
0 g
s
.58806 .67741 m .58557 .68526 L .65008 .67458 L p .441 .025 .152 r
F P
0 g
s
.65008 .67458 m .65525 .6656 L .58806 .67741 L p .441 .025 .152 r
F P
0 g
s
.73799 .61332 m .73063 .62241 L .78502 .58733 L p 0 0 0 r
F P
0 g
s
.77529 .59674 m .78502 .58733 L .73063 .62241 L p 0 0 0 r
F P
0 g
s
.78502 .58733 m .77529 .59674 L .77569 .59627 L p .695 .969 .75 r
F P
0 g
s
.79407 .57866 m .73799 .61332 L p .78502 .58733 L 0 0 0 r
F P
0 g
s
.77569 .59627 m .81294 .5523 L p .78502 .58733 L .695 .969 .75 r
F P
0 g
s
.78502 .58733 m .79464 .57831 L .79407 .57866 L p 0 0 0 r
F P
0 g
s
.66032 .65643 m .65525 .6656 L .71562 .6416 L p .239 0 .04 r
F P
0 g
s
.71562 .6416 m .72318 .63194 L .66032 .65643 L p .239 0 .04 r
F P
0 g
s
.51837 .68853 m .51808 .68286 L .45125 .66766 L p .622 .118 .032 r
F P
0 g
s
.51808 .68286 m .51837 .68853 L .58303 .69261 L p .558 .108 .14 r
F P
0 g
s
.58303 .69261 m .58557 .68526 L .51808 .68286 L p .558 .108 .14 r
F P
0 g
s
.30793 .60571 m .29943 .6068 L .24558 .56996 L p .435 .691 .972 r
F P
0 g
s
.31651 .60468 m .32515 .60365 L .3827 .63899 L p 0 .418 .811 r
F P
0 g
s
.38868 .64046 m .3827 .63899 L .32515 .60365 L p 0 .43 .842 r
F P
0 g
s
.3827 .63899 m .38868 .64046 L .45125 .66766 L p .567 0 0 r
F P
0 g
s
.45444 .67121 m .45125 .66766 L .38868 .64046 L p .538 0 0 r
F P
0 g
s
.45125 .66766 m .45444 .67121 L .51837 .68853 L p .622 .118 .032 r
F P
0 g
s
.73063 .62241 m .72318 .63194 L .77529 .59674 L p 0 0 0 r
F P
0 g
s
.58557 .68526 m .58303 .69261 L .64481 .68305 L p .43 .003 .124 r
F P
0 g
s
.64481 .68305 m .65008 .67458 L .58557 .68526 L p .43 .003 .124 r
F P
0 g
s
.24558 .56996 m .25665 .56641 L .30793 .60571 L p .435 .691 .972 r
F P
0 g
s
.31651 .60468 m .30793 .60571 L .25665 .56641 L p .438 .67 .96 r
F P
0 g
s
.65525 .6656 m .65008 .67458 L .70792 .65107 L p .221 0 .016 r
F P
0 g
s
.70792 .65107 m .71562 .6416 L .65525 .6656 L p .221 0 .016 r
F P
0 g
s
.32515 .60365 m .33387 .60252 L .38868 .64046 L p 0 .43 .842 r
F P
0 g
s
.39474 .64161 m .38868 .64046 L .33387 .60252 L p .025 .45 .873 r
F P
0 g
s
.38868 .64046 m .39474 .64161 L .45444 .67121 L p .538 0 0 r
F P
0 g
s
.45768 .67411 m .45444 .67121 L .39474 .64161 L p .477 0 0 r
F P
0 g
s
.45444 .67121 m .45768 .67411 L .51868 .69343 L p .61 .084 0 r
F P
0 g
s
.51868 .69343 m .51837 .68853 L .45444 .67121 L p .61 .084 0 r
F P
0 g
s
.51837 .68853 m .51868 .69343 L .58043 .69912 L p .549 .08 .095 r
F P
0 g
s
.58043 .69912 m .58303 .69261 L .51837 .68853 L p .549 .08 .095 r
F P
0 g
s
.25665 .56641 m .26777 .56285 L .31651 .60468 L p .438 .67 .96 r
F P
0 g
s
.32515 .60365 m .31651 .60468 L .26777 .56285 L p .447 .65 .946 r
F P
0 g
s
.72318 .63194 m .71562 .6416 L .76543 .60626 L p 0 0 0 r
F P
0 g
s
.76543 .60626 m .77529 .59674 L .72318 .63194 L p 0 0 0 r
F P
0 g
s
.33387 .60252 m .34267 .60122 L .39474 .64161 L p .025 .45 .873 r
F P
0 g
s
.40089 .64229 m .39474 .64161 L .34267 .60122 L p .11 .472 .894 r
F P
0 g
s
.39474 .64161 m .40089 .64229 L .45768 .67411 L p .477 0 0 r
F P
0 g
s
.58303 .69261 m .58043 .69912 L .63941 .69065 L p .41 0 .076 r
F P
0 g
s
.63941 .69065 m .64481 .68305 L .58303 .69261 L p .41 0 .076 r
F P
0 g
s
.26777 .56285 m .27894 .55928 L .32515 .60365 L p .447 .65 .946 r
F P
0 g
s
.33387 .60252 m .32515 .60365 L .27894 .55928 L p .459 .631 .928 r
F P
0 g
s
.65008 .67458 m .64481 .68305 L .70007 .66004 L p .187 0 0 r
F P
0 g
s
.70007 .66004 m .70792 .65107 L .65008 .67458 L p .187 0 0 r
F P
0 g
s
.461 .67615 m .45768 .67411 L .40089 .64229 L p .369 0 0 r
F P
0 g
s
.45768 .67411 m .461 .67615 L .51899 .69728 L p .581 .025 0 r
F P
0 g
s
.51899 .69728 m .51868 .69343 L .45768 .67411 L p .581 .025 0 r
F P
0 g
s
.51868 .69343 m .51899 .69728 L .57777 .70446 L p .529 .032 .02 r
F P
0 g
s
.57777 .70446 m .58043 .69912 L .51868 .69343 L p .529 .032 .02 r
F P
0 g
s
.27894 .55928 m .29016 .55569 L .33387 .60252 L p .459 .631 .928 r
F P
0 g
s
.34267 .60122 m .33387 .60252 L .29016 .55569 L p .474 .612 .908 r
F P
0 g
s
.79464 .57831 m .78502 .58733 L .82464 .54357 L p .664 .958 .741 r
F P
0 g
s
.82464 .54357 m .83625 .53514 L .79464 .57831 L p .664 .958 .741 r
F P
0 g
s
.34267 .60122 m .35156 .59965 L .40089 .64229 L p .11 .472 .894 r
F P
0 g
s
.40713 .64233 m .40089 .64229 L .35156 .59965 L p .197 .489 .9 r
F P
0 g
s
.40089 .64229 m .40713 .64233 L .461 .67615 L p .369 0 0 r
F P
0 g
s
.71562 .6416 m .70792 .65107 L .75544 .6156 L p 0 0 0 r
F P
0 g
s
.75544 .6156 m .76543 .60626 L .71562 .6416 L p 0 0 0 r
F P
0 g
s
.58043 .69912 m .57777 .70446 L .63388 .69705 L p .373 0 0 r
F P
0 g
s
.63388 .69705 m .63941 .69065 L .58043 .69912 L p .373 0 0 r
F P
0 g
s
.29016 .55569 m .30143 .55208 L .34267 .60122 L p .474 .612 .908 r
F P
0 g
s
.35156 .59965 m .34267 .60122 L .30143 .55208 L p .489 .596 .887 r
F P
0 g
s
.64481 .68305 m .63941 .69065 L .69205 .66817 L p .131 0 0 r
F P
0 g
s
.69205 .66817 m .70007 .66004 L .64481 .68305 L p .131 0 0 r
F P
0 g
s
.46437 .67709 m .461 .67615 L .40713 .64233 L p 0 .308 .741 r
F P
0 g
s
.51931 .69981 m .51899 .69728 L .461 .67615 L p .515 0 0 r
F P
0 g
s
.461 .67615 m .46437 .67709 L .51931 .69981 L p .515 0 0 r
F P
0 g
s
.25665 .56641 m .24558 .56996 L .20758 .52532 L p .656 .751 .92 r
F P
0 g
s
.51899 .69728 m .51931 .69981 L .57504 .70834 L p .487 0 0 r
F P
0 g
s
.57504 .70834 m .57777 .70446 L .51899 .69728 L p .487 0 0 r
F P
0 g
s
.81294 .5523 m .82464 .54357 L .78502 .58733 L p .695 .969 .75 r
F P
0 g
s
.35156 .59965 m .36054 .59774 L .40713 .64233 L p .197 .489 .9 r
F P
0 g
s
.41347 .6416 m .40713 .64233 L .36054 .59774 L p .277 .501 .892 r
F P
0 g
s
.40713 .64233 m .41347 .6416 L .46437 .67709 L p 0 .308 .741 r
F P
0 g
s
.20758 .52532 m .22084 .51961 L .25665 .56641 L p .656 .751 .92 r
F P
0 g
s
.26777 .56285 m .25665 .56641 L .22084 .51961 L p .656 .732 .906 r
F P
0 g
s
.30143 .55208 m .31274 .54846 L .35156 .59965 L p .489 .596 .887 r
F P
0 g
s
.36054 .59774 m .35156 .59965 L .31274 .54846 L p .504 .581 .865 r
F P
0 g
s
.70792 .65107 m .70007 .66004 L .74527 .62447 L p 0 0 0 r
F P
0 g
s
.67549 .68064 m .68386 .67514 L .63388 .69705 L p 0 0 0 r
F P
0 g
s
.68386 .67514 m .67549 .68064 L .6766 .67961 L p .69 .98 .822 r
F P
0 g
s
.75544 .6156 m .70792 .65107 L p .73927 .62874 L 0 0 0 r
F P
0 g
s
.63941 .69065 m .63388 .69705 L .68386 .67514 L p .041 0 0 r
F P
0 g
s
.68386 .67514 m .69205 .66817 L .63941 .69065 L p .041 0 0 r
F P
0 g
s
.6766 .67961 m .71366 .64536 L p .69144 .66757 L .69 .98 .822 r
F P
0 g
s
.69144 .66757 m .68386 .67514 L .6766 .67961 L .69 .98 .822 r
F
.74527 .62447 m .75505 .61593 L p .73927 .62874 L 0 0 0 r
F P
0 g
s
.75505 .61593 m .75544 .6156 L p .73927 .62874 L 0 0 0 r
F P
0 g
s
.22084 .51961 m .23411 .51382 L .26777 .56285 L p .656 .732 .906 r
F P
0 g
s
.27894 .55928 m .26777 .56285 L .23411 .51382 L p .655 .712 .89 r
F P
0 g
s
.46782 .67674 m .46437 .67709 L .41347 .6416 L p 0 .403 .848 r
F P
0 g
s
.51963 .70077 m .51931 .69981 L .46437 .67709 L p .379 0 0 r
F P
0 g
s
.46437 .67709 m .46782 .67674 L .51963 .70077 L p .379 0 0 r
F P
0 g
s
.57777 .70446 m .57504 .70834 L .62822 .70194 L p .307 0 0 r
F P
0 g
s
.62822 .70194 m .63388 .69705 L .57777 .70446 L p .307 0 0 r
F P
0 g
s
.23411 .51382 m .24738 .50804 L .27894 .55928 L p .655 .712 .89 r
F P
0 g
s
.29016 .55569 m .27894 .55928 L .24738 .50804 L p .654 .692 .873 r
F P
0 g
s
.31274 .54846 m .3241 .54482 L .36054 .59774 L p .504 .581 .865 r
F P
0 g
s
.36961 .59541 m .36054 .59774 L .3241 .54482 L p .519 .567 .844 r
F P
0 g
s
.36054 .59774 m .36961 .59541 L .41347 .6416 L p .277 .501 .892 r
F P
0 g
s
.4199 .63994 m .41347 .6416 L .36961 .59541 L p .346 .507 .875 r
F P
0 g
s
.41347 .6416 m .4199 .63994 L .46782 .67674 L p 0 .403 .848 r
F P
0 g
s
.77529 .59674 m .76543 .60626 L .80113 .56111 L p .735 .984 .773 r
F P
0 g
s
.80113 .56111 m .81294 .5523 L .77529 .59674 L p .735 .984 .773 r
F P
0 g
s
.51931 .69981 m .51963 .70077 L .57225 .71047 L p .399 0 0 r
F P
0 g
s
.57225 .71047 m .57504 .70834 L .51931 .69981 L p .399 0 0 r
F P
0 g
s
.24738 .50804 m .26063 .50234 L .29016 .55569 L p .654 .692 .873 r
F P
0 g
s
.30143 .55208 m .29016 .55569 L .26063 .50234 L p .652 .672 .857 r
F P
0 g
s
.3241 .54482 m .33552 .54116 L .36961 .59541 L p .519 .567 .844 r
F P
0 g
s
.37878 .5926 m .36961 .59541 L .33552 .54116 L p .532 .555 .824 r
F P
0 g
s
.36961 .59541 m .37878 .5926 L .4199 .63994 L p .346 .507 .875 r
F P
0 g
s
.26063 .50234 m .27387 .49681 L .30143 .55208 L p .652 .672 .857 r
F P
0 g
s
.31274 .54846 m .30143 .55208 L .27387 .49681 L p .649 .653 .84 r
F P
0 g
s
.73493 .63258 m .74527 .62447 L .71479 .64846 L p .44 .813 .559 r
F P
0 g
s
.71479 .64846 m .70007 .66004 L p .71402 .64905 L .44 .813 .559 r
F P
0 g
s
.73493 .63258 m .71479 .64846 L .71402 .64905 L .44 .813 .559 r
F
.70007 .66004 m .69205 .66817 L .73493 .63258 L p F P
0 g
s
.69205 .66817 m .68386 .67514 L .71091 .65144 L p .57 .913 .696 r
F P
0 g
s
.71091 .65144 m .72439 .63963 L p .71168 .65085 L .57 .913 .696 r
F P
0 g
s
.71168 .65085 m .69205 .66817 L .71091 .65144 L .57 .913 .696 r
F
.42644 .63724 m .4199 .63994 L .37878 .5926 L p .403 .51 .853 r
F P
0 g
s
.4199 .63994 m .42644 .63724 L .47132 .67492 L p .157 .466 .89 r
F P
0 g
s
.47132 .67492 m .46782 .67674 L .4199 .63994 L p .157 .466 .89 r
F P
0 g
s
.46782 .67674 m .47132 .67492 L .51997 .69992 L p 0 .388 .771 r
F P
0 g
s
.51997 .69992 m .51963 .70077 L .46782 .67674 L p 0 .388 .771 r
F P
0 g
s
.27387 .49681 m .28709 .49153 L .31274 .54846 L p .649 .653 .84 r
F P
0 g
s
.3241 .54482 m .31274 .54846 L .28709 .49153 L p .646 .634 .824 r
F P
0 g
s
.57504 .70834 m .57225 .71047 L .62243 .705 L p .185 0 0 r
F P
0 g
s
.62243 .705 m .62822 .70194 L .57504 .70834 L p .185 0 0 r
F P
0 g
s
.76543 .60626 m .75544 .6156 L .7892 .56975 L p .777 .996 .804 r
F P
0 g
s
.7892 .56975 m .80113 .56111 L .76543 .60626 L p .777 .996 .804 r
F P
0 g
s
.63388 .69705 m .62822 .70194 L .67549 .68064 L p 0 0 0 r
F P
0 g
s
.33552 .54116 m .34698 .5375 L .37878 .5926 L p .532 .555 .824 r
F P
0 g
s
.38803 .58924 m .37878 .5926 L .34698 .5375 L p .544 .545 .806 r
F P
0 g
s
.37878 .5926 m .38803 .58924 L .42644 .63724 L p .403 .51 .853 r
F P
0 g
s
.56939 .71058 m .57225 .71047 L .51963 .70077 L p .216 0 0 r
F P
0 g
s
.51963 .70077 m .51997 .69992 L .56939 .71058 L p .216 0 0 r
F P
0 g
s
.28709 .49153 m .30028 .48658 L .3241 .54482 L p .646 .634 .824 r
F P
0 g
s
.33552 .54116 m .3241 .54482 L .30028 .48658 L p .642 .616 .809 r
F P
0 g
s
.43306 .6334 m .42644 .63724 L .38803 .58924 L p .448 .51 .83 r
F P
0 g
s
.42644 .63724 m .43306 .6334 L .4749 .67148 L p .292 .498 .886 r
F P
0 g
s
.4749 .67148 m .47132 .67492 L .42644 .63724 L p .292 .498 .886 r
F P
0 g
s
.30028 .48658 m .31346 .48202 L .33552 .54116 L p .642 .616 .809 r
F P
0 g
s
.34698 .5375 m .33552 .54116 L .31346 .48202 L p .639 .6 .794 r
F P
0 g
s
.47132 .67492 m .4749 .67148 L .52031 .69709 L p .109 .51 .908 r
F P
0 g
s
.52031 .69709 m .51997 .69992 L .47132 .67492 L p .109 .51 .908 r
F P
0 g
s
.34698 .5375 m .35849 .53381 L .38803 .58924 L p .544 .545 .806 r
F P
0 g
s
.39738 .58529 m .38803 .58924 L .35849 .53381 L p .555 .536 .789 r
F P
0 g
s
.38803 .58924 m .39738 .58529 L .43306 .6334 L p .448 .51 .83 r
F P
0 g
s
.72439 .63963 m .73493 .63258 L .69205 .66817 L p .57 .913 .696 r
F P
0 g
s
.31346 .48202 m .32661 .47791 L .34698 .5375 L p .639 .6 .794 r
F P
0 g
s
.35849 .53381 m .34698 .5375 L .32661 .47791 L p .635 .585 .781 r
F P
0 g
s
.75544 .6156 m .74527 .62447 L .77711 .57799 L p .816 .999 .836 r
F P
0 g
s
.77711 .57799 m .7892 .56975 L .75544 .6156 L p .816 .999 .836 r
F P
0 g
s
.6165 .70599 m .62243 .705 L .57225 .71047 L p 0 0 0 r
F P
0 g
s
.57225 .71047 m .56939 .71058 L .6165 .70599 L p 0 0 0 r
F P
0 g
s
.83625 .53514 m .82464 .54357 L .84593 .49323 L p .823 .956 .902 r
F P
0 g
s
.84593 .49323 m .85906 .48583 L .83625 .53514 L p .823 .956 .902 r
F P
0 g
s
.51997 .69992 m .52031 .69709 L .56647 .70847 L p .069 .588 .878 r
F P
0 g
s
.56647 .70847 m .56939 .71058 L .51997 .69992 L p .069 .588 .878 r
F P
0 g
s
.43978 .62835 m .43306 .6334 L .39738 .58529 L p .483 .509 .808 r
F P
0 g
s
.43306 .6334 m .43978 .62835 L .47853 .66631 L p .386 .51 .861 r
F P
0 g
s
.47853 .66631 m .4749 .67148 L .43306 .6334 L p .386 .51 .861 r
F P
0 g
s
.67549 .68064 m .62822 .70194 L p .65861 .68815 L .303 .774 .659 r
F P
0 g
s
.66694 .68437 m .67026 .68292 L p .65861 .68815 L .303 .774 .659 r
F P
0 g
s
.67026 .68292 m .67549 .68064 L p .65861 .68815 L .303 .774 .659 r
F P
0 g
s
.6165 .70599 m .6582 .6861 L p .6301 .70095 L .519 .917 .883 r
F P
0 g
s
.62243 .705 m .62027 .70536 L p .6301 .70095 L .519 .917 .883 r
F P
0 g
s
.62027 .70536 m .6165 .70599 L p .6301 .70095 L .519 .917 .883 r
F P
0 g
s
.62822 .70194 m .62243 .705 L .66694 .68437 L p .303 .774 .659 r
F P
0 g
s
.35849 .53381 m .37005 .53011 L .39738 .58529 L p .555 .536 .789 r
F P
0 g
s
.40681 .58071 m .39738 .58529 L .37005 .53011 L p .564 .528 .774 r
F P
0 g
s
.39738 .58529 m .40681 .58071 L .43978 .62835 L p .483 .509 .808 r
F P
0 g
s
.32661 .47791 m .33974 .47431 L .35849 .53381 L p .635 .585 .781 r
F P
0 g
s
.37005 .53011 m .35849 .53381 L .33974 .47431 L p .632 .571 .769 r
F P
0 g
s
.4749 .67148 m .47853 .66631 L .52065 .69212 L p .301 .554 .923 r
F P
0 g
s
.52065 .69212 m .52031 .69709 L .4749 .67148 L p .301 .554 .923 r
F P
0 g
s
.33974 .47431 m .35286 .47126 L .37005 .53011 L p .632 .571 .769 r
F P
0 g
s
.38167 .52639 m .37005 .53011 L .35286 .47126 L p .629 .559 .757 r
F P
0 g
s
.37005 .53011 m .38167 .52639 L .40681 .58071 L p .564 .528 .774 r
F P
0 g
s
.41632 .57547 m .40681 .58071 L .38167 .52639 L p .572 .522 .76 r
F P
0 g
s
.40681 .58071 m .41632 .57547 L .44659 .62202 L p .512 .507 .787 r
F P
0 g
s
.44659 .62202 m .43978 .62835 L .40681 .58071 L p .512 .507 .787 r
F P
0 g
s
.71366 .64536 m .72439 .63963 L .68386 .67514 L p .69 .98 .822 r
F P
0 g
s
.82464 .54357 m .81294 .5523 L .83276 .50082 L p .835 .944 .894 r
F P
0 g
s
.83276 .50082 m .84593 .49323 L .82464 .54357 L p .835 .944 .894 r
F P
0 g
s
.43978 .62835 m .44659 .62202 L .48223 .65932 L p .451 .513 .831 r
F P
0 g
s
.48223 .65932 m .47853 .66631 L .43978 .62835 L p .451 .513 .831 r
F P
0 g
s
.35286 .47126 m .36597 .46879 L .38167 .52639 L p .629 .559 .757 r
F P
0 g
s
.39333 .52265 m .38167 .52639 L .36597 .46879 L p .626 .548 .747 r
F P
0 g
s
.38167 .52639 m .39333 .52265 L .41632 .57547 L p .572 .522 .76 r
F P
0 g
s
.24788 .44549 m .26236 .4386 L .27387 .49681 L p .753 .737 .838 r
F P
0 g
s
.27387 .49681 m .26063 .50234 L .24788 .44549 L p .753 .737 .838 r
F P
0 g
s
.28709 .49153 m .27387 .49681 L .26236 .4386 L p .745 .716 .825 r
F P
0 g
s
.26236 .4386 m .27673 .43222 L .28709 .49153 L p .745 .716 .825 r
F P
0 g
s
.30028 .48658 m .28709 .49153 L .27673 .43222 L p .736 .695 .813 r
F P
0 g
s
.2333 .45274 m .24788 .44549 L .26063 .50234 L p .759 .757 .851 r
F P
0 g
s
.26063 .50234 m .24738 .50804 L .2333 .45274 L p .759 .757 .851 r
F P
0 g
s
.27673 .43222 m .291 .4265 L .30028 .48658 L p .736 .695 .813 r
F P
0 g
s
.31346 .48202 m .30028 .48658 L .291 .4265 L p .725 .675 .8 r
F P
0 g
s
.74527 .62447 m .73493 .63258 L .76487 .58559 L p .843 .987 .861 r
F P
0 g
s
.76487 .58559 m .77711 .57799 L .74527 .62447 L p .843 .987 .861 r
F P
0 g
s
.21864 .46019 m .2333 .45274 L .24738 .50804 L p .763 .777 .864 r
F P
0 g
s
.24738 .50804 m .23411 .51382 L .21864 .46019 L p .763 .777 .864 r
F P
0 g
s
.2039 .46769 m .21864 .46019 L .23411 .51382 L p .764 .794 .877 r
F P
0 g
s
.23411 .51382 m .22084 .51961 L .2039 .46769 L p .764 .794 .877 r
F P
0 g
s
.291 .4265 m .30515 .42155 L .31346 .48202 L p .725 .675 .8 r
F P
0 g
s
.32661 .47791 m .31346 .48202 L .30515 .42155 L p .715 .654 .788 r
F P
0 g
s
.18911 .47507 m .2039 .46769 L .22084 .51961 L p .764 .81 .89 r
F P
0 g
s
.22084 .51961 m .20758 .52532 L .18911 .47507 L p .764 .81 .89 r
F P
0 g
s
.56939 .71058 m .56647 .70847 L .61044 .70466 L p .312 .785 .928 r
F P
0 g
s
.61044 .70466 m .6165 .70599 L .56939 .71058 L p .312 .785 .928 r
F P
0 g
s
.30515 .42155 m .3192 .4175 L .32661 .47791 L p .715 .654 .788 r
F P
0 g
s
.33974 .47431 m .32661 .47791 L .3192 .4175 L p .704 .635 .777 r
F P
0 g
s
.52031 .69709 m .52065 .69212 L .56349 .70397 L p .32 .663 .974 r
F P
0 g
s
.56349 .70397 m .56647 .70847 L .52031 .69709 L p .32 .663 .974 r
F P
0 g
s
.3192 .4175 m .33315 .41442 L .33974 .47431 L p .704 .635 .777 r
F P
0 g
s
.35286 .47126 m .33974 .47431 L .33315 .41442 L p .693 .616 .766 r
F P
0 g
s
.6582 .6861 m .66694 .68437 L .62243 .705 L p .519 .917 .883 r
F P
0 g
s
.42592 .56956 m .41632 .57547 L .39333 .52265 L p .579 .516 .748 r
F P
0 g
s
.41632 .57547 m .42592 .56956 L .45347 .61439 L p .534 .505 .77 r
F P
0 g
s
.45347 .61439 m .44659 .62202 L .41632 .57547 L p .534 .505 .77 r
F P
0 g
s
.47853 .66631 m .48223 .65932 L .52101 .68491 L p .417 .557 .888 r
F P
0 g
s
.52101 .68491 m .52065 .69212 L .47853 .66631 L p .417 .557 .888 r
F P
0 g
s
.33315 .41442 m .34701 .41242 L .35286 .47126 L p .693 .616 .766 r
F P
0 g
s
.36597 .46879 m .35286 .47126 L .34701 .41242 L p .682 .599 .756 r
F P
0 g
s
.36597 .46879 m .37907 .46692 L .39333 .52265 L p .626 .548 .747 r
F P
0 g
s
.40505 .5189 m .39333 .52265 L .37907 .46692 L p .623 .538 .738 r
F P
0 g
s
.39333 .52265 m .40505 .5189 L .42592 .56956 L p .579 .516 .748 r
F P
0 g
s
.34701 .41242 m .36079 .41153 L .36597 .46879 L p .682 .599 .756 r
F P
0 g
s
.37907 .46692 m .36597 .46879 L .36079 .41153 L p .671 .582 .747 r
F P
0 g
s
.44659 .62202 m .45347 .61439 L .48597 .65049 L p .496 .512 .803 r
F P
0 g
s
.48597 .65049 m .48223 .65932 L .44659 .62202 L p .496 .512 .803 r
F P
0 g
s
.81294 .5523 m .80113 .56111 L .81952 .50844 L p .842 .927 .887 r
F P
0 g
s
.81952 .50844 m .83276 .50082 L .81294 .5523 L p .842 .927 .887 r
F P
0 g
s
.36079 .41153 m .3745 .41179 L .37907 .46692 L p .671 .582 .747 r
F P
0 g
s
.39218 .46566 m .37907 .46692 L .3745 .41179 L p .661 .567 .739 r
F P
0 g
s
.37907 .46692 m .39218 .46566 L .40505 .5189 L p .623 .538 .738 r
F P
0 g
s
.41682 .51514 m .40505 .5189 L .39218 .46566 L p .62 .53 .73 r
F P
0 g
s
.40505 .5189 m .41682 .51514 L .43559 .56299 L p .586 .511 .738 r
F P
0 g
s
.43559 .56299 m .42592 .56956 L .40505 .5189 L p .586 .511 .738 r
F P
0 g
s
.42592 .56956 m .43559 .56299 L .46043 .60548 L p .552 .503 .754 r
F P
0 g
s
.46043 .60548 m .45347 .61439 L .42592 .56956 L p .552 .503 .754 r
F P
0 g
s
.3745 .41179 m .38816 .41323 L .39218 .46566 L p .661 .567 .739 r
F P
0 g
s
.4053 .46501 m .39218 .46566 L .38816 .41323 L p .652 .554 .731 r
F P
0 g
s
.39218 .46566 m .4053 .46501 L .41682 .51514 L p .62 .53 .73 r
F P
0 g
s
.67549 .68064 m .66694 .68437 L .70273 .6495 L p .769 .986 .9 r
F P
0 g
s
.70273 .6495 m .71366 .64536 L .67549 .68064 L p .769 .986 .9 r
F P
0 g
s
.52065 .69212 m .52101 .68491 L .56045 .69696 L p .458 .647 .94 r
F P
0 g
s
.56045 .69696 m .56349 .70397 L .52065 .69212 L p .458 .647 .94 r
F P
0 g
s
.73493 .63258 m .72439 .63963 L .75246 .59231 L p .854 .958 .875 r
F P
0 g
s
.75246 .59231 m .76487 .58559 L .73493 .63258 L p .854 .958 .875 r
F P
0 g
s
.48223 .65932 m .48597 .65049 L .52137 .67542 L p .485 .548 .846 r
F P
0 g
s
.52137 .67542 m .52101 .68491 L .48223 .65932 L p .485 .548 .846 r
F P
0 g
s
.56647 .70847 m .56349 .70397 L .60426 .70086 L p .502 .803 .999 r
F P
0 g
s
.60426 .70086 m .61044 .70466 L .56647 .70847 L p .502 .803 .999 r
F P
0 g
s
.42864 .51135 m .41682 .51514 L .4053 .46501 L p .618 .522 .723 r
F P
0 g
s
.41682 .51514 m .42864 .51135 L .44533 .55576 L p .591 .507 .729 r
F P
0 g
s
.44533 .55576 m .43559 .56299 L .41682 .51514 L p .591 .507 .729 r
F P
0 g
s
.38816 .41323 m .40178 .41584 L .4053 .46501 L p .652 .554 .731 r
F P
0 g
s
.41844 .46496 m .4053 .46501 L .40178 .41584 L p .643 .541 .724 r
F P
0 g
s
.4053 .46501 m .41844 .46496 L .42864 .51135 L p .618 .522 .723 r
F P
0 g
s
.45347 .61439 m .46043 .60548 L .48977 .63981 L p .528 .509 .779 r
F P
0 g
s
.48977 .63981 m .48597 .65049 L .45347 .61439 L p .528 .509 .779 r
F P
0 g
s
.36661 .3583 m .38001 .36083 L .3745 .41179 L p .708 .623 .76 r
F P
0 g
s
.3745 .41179 m .36079 .41153 L .36661 .3583 L p .708 .623 .76 r
F P
0 g
s
.38816 .41323 m .3745 .41179 L .38001 .36083 L p .692 .601 .749 r
F P
0 g
s
.35309 .35737 m .36661 .3583 L .36079 .41153 L p .725 .646 .77 r
F P
0 g
s
.36079 .41153 m .34701 .41242 L .35309 .35737 L p .725 .646 .77 r
F P
0 g
s
.38001 .36083 m .39331 .365 L .38816 .41323 L p .692 .601 .749 r
F P
0 g
s
.40178 .41584 m .38816 .41323 L .39331 .365 L p .677 .581 .74 r
F P
0 g
s
.43559 .56299 m .44533 .55576 L .46745 .5953 L p .566 .501 .741 r
F P
0 g
s
.46745 .5953 m .46043 .60548 L .43559 .56299 L p .566 .501 .741 r
F P
0 g
s
.6165 .70599 m .61044 .70466 L .64929 .68559 L p .652 .925 .975 r
F P
0 g
s
.64929 .68559 m .6582 .6861 L .6165 .70599 L p .652 .925 .975 r
F P
0 g
s
.33942 .35802 m .35309 .35737 L .34701 .41242 L p .742 .671 .782 r
F P
0 g
s
.34701 .41242 m .33315 .41442 L .33942 .35802 L p .742 .671 .782 r
F P
0 g
s
.39331 .365 m .40652 .37078 L .40178 .41584 L p .677 .581 .74 r
F P
0 g
s
.41538 .41958 m .40178 .41584 L .40652 .37078 L p .663 .563 .731 r
F P
0 g
s
.40178 .41584 m .41538 .41958 L .41844 .46496 L p .643 .541 .724 r
F P
0 g
s
.4316 .46547 m .41844 .46496 L .41538 .41958 L p .636 .53 .718 r
F P
0 g
s
.41844 .46496 m .4316 .46547 L .44051 .50755 L p .616 .515 .717 r
F P
0 g
s
.44051 .50755 m .42864 .51135 L .41844 .46496 L p .616 .515 .717 r
F P
0 g
s
.80113 .56111 m .7892 .56975 L .80619 .51593 L p .844 .904 .878 r
F P
0 g
s
.80619 .51593 m .81952 .50844 L .80113 .56111 L p .844 .904 .878 r
F P
0 g
s
.42864 .51135 m .44051 .50755 L .45513 .54792 L p .595 .504 .721 r
F P
0 g
s
.45513 .54792 m .44533 .55576 L .42864 .51135 L p .595 .504 .721 r
F P
0 g
s
.3256 .36015 m .33942 .35802 L .33315 .41442 L p .759 .698 .793 r
F P
0 g
s
.33315 .41442 m .3192 .4175 L .3256 .36015 L p .759 .698 .793 r
F P
0 g
s
.40652 .37078 m .41967 .37816 L .41538 .41958 L p .663 .563 .731 r
F P
0 g
s
.42897 .42441 m .41538 .41958 L .41967 .37816 L p .651 .547 .723 r
F P
0 g
s
.41538 .41958 m .42897 .42441 L .4316 .46547 L p .636 .53 .718 r
F P
0 g
s
.3116 .36367 m .3256 .36015 L .3192 .4175 L p .776 .724 .805 r
F P
0 g
s
.3192 .4175 m .30515 .42155 L .3116 .36367 L p .776 .724 .805 r
F P
0 g
s
.46043 .60548 m .46745 .5953 L .4936 .62733 L p .551 .506 .759 r
F P
0 g
s
.4936 .62733 m .48977 .63981 L .46043 .60548 L p .551 .506 .759 r
F P
0 g
s
.4448 .46651 m .4316 .46547 L .42897 .42441 L p .629 .521 .712 r
F P
0 g
s
.4316 .46547 m .4448 .46651 L .45243 .50373 L p .614 .51 .712 r
F P
0 g
s
.45243 .50373 m .44051 .50755 L .4316 .46547 L p .614 .51 .712 r
F P
0 g
s
.48597 .65049 m .48977 .63981 L .52173 .66365 L p .526 .537 .809 r
F P
0 g
s
.52173 .66365 m .52137 .67542 L .48597 .65049 L p .526 .537 .809 r
F P
0 g
s
.44533 .55576 m .45513 .54792 L .47453 .58392 L p .578 .499 .73 r
F P
0 g
s
.47453 .58392 m .46745 .5953 L .44533 .55576 L p .578 .499 .73 r
F P
0 g
s
.41967 .37816 m .43278 .38705 L .42897 .42441 L p .651 .547 .723 r
F P
0 g
s
.44257 .43027 m .42897 .42441 L .43278 .38705 L p .64 .533 .717 r
F P
0 g
s
.42897 .42441 m .44257 .43027 L .4448 .46651 L p .629 .521 .712 r
F P
0 g
s
.52101 .68491 m .52137 .67542 L .55736 .68739 L p .524 .613 .883 r
F P
0 g
s
.55736 .68739 m .56045 .69696 L .52101 .68491 L p .524 .613 .883 r
F P
0 g
s
.44051 .50755 m .45243 .50373 L .46499 .53949 L p .599 .501 .715 r
F P
0 g
s
.46499 .53949 m .45513 .54792 L .44051 .50755 L p .599 .501 .715 r
F P
0 g
s
.40738 .32414 m .41928 .33282 L .40652 .37078 L p .692 .608 .757 r
F P
0 g
s
.40652 .37078 m .39331 .365 L .40738 .32414 L p .692 .608 .757 r
F P
0 g
s
.41967 .37816 m .40652 .37078 L .41928 .33282 L p .674 .583 .745 r
F P
0 g
s
.66694 .68437 m .6582 .6861 L .6916 .65184 L p .796 .939 .922 r
F P
0 g
s
.6916 .65184 m .70273 .6495 L .66694 .68437 L p .796 .939 .922 r
F P
0 g
s
.41928 .33282 m .43109 .3434 L .41967 .37816 L p .674 .583 .745 r
F P
0 g
s
.43278 .38705 m .41967 .37816 L .43109 .3434 L p .659 .561 .733 r
F P
0 g
s
.39538 .31741 m .40738 .32414 L .39331 .365 L p .712 .636 .771 r
F P
0 g
s
.39331 .365 m .38001 .36083 L .39538 .31741 L p .712 .636 .771 r
F P
0 g
s
.29742 .36844 m .3116 .36367 L .30515 .42155 L p .791 .751 .816 r
F P
0 g
s
.30515 .42155 m .291 .4265 L .29742 .36844 L p .791 .751 .816 r
F P
0 g
s
.56349 .70397 m .56045 .69696 L .59796 .69446 L p .58 .74 .952 r
F P
0 g
s
.59796 .69446 m .60426 .70086 L .56349 .70397 L p .58 .74 .952 r
F P
0 g
s
.72439 .63963 m .71366 .64536 L .73987 .59794 L p .851 .916 .876 r
F P
0 g
s
.73987 .59794 m .75246 .59231 L .72439 .63963 L p .851 .916 .876 r
F P
0 g
s
.43109 .3434 m .44283 .35582 L .43278 .38705 L p .659 .561 .733 r
F P
0 g
s
.44588 .39736 m .43278 .38705 L .44283 .35582 L p .646 .543 .724 r
F P
0 g
s
.43278 .38705 m .44588 .39736 L .44257 .43027 L p .64 .533 .717 r
F P
0 g
s
.38324 .31265 m .39538 .31741 L .38001 .36083 L p .733 .668 .786 r
F P
0 g
s
.38001 .36083 m .36661 .3583 L .38324 .31265 L p .733 .668 .786 r
F P
0 g
s
.45804 .46803 m .4448 .46651 L .44257 .43027 L p .623 .513 .708 r
F P
0 g
s
.4448 .46651 m .45804 .46803 L .46441 .4999 L p .613 .505 .707 r
F P
0 g
s
.46441 .4999 m .45243 .50373 L .4448 .46651 L p .613 .505 .707 r
F P
0 g
s
.45619 .43705 m .44257 .43027 L .44588 .39736 L p .631 .521 .711 r
F P
0 g
s
.44257 .43027 m .45619 .43705 L .45804 .46803 L p .623 .513 .708 r
F P
0 g
s
.45513 .54792 m .46499 .53949 L .48166 .57143 L p .587 .498 .721 r
F P
0 g
s
.48166 .57143 m .47453 .58392 L .45513 .54792 L p .587 .498 .721 r
F P
0 g
s
.46745 .5953 m .47453 .58392 L .49747 .61315 L p .568 .504 .743 r
F P
0 g
s
.49747 .61315 m .4936 .62733 L .46745 .5953 L p .568 .504 .743 r
F P
0 g
s
.7892 .56975 m .77711 .57799 L .79278 .52311 L p .84 .877 .869 r
F P
0 g
s
.79278 .52311 m .80619 .51593 L .7892 .56975 L p .84 .877 .869 r
F P
0 g
s
.45243 .50373 m .46441 .4999 L .4749 .53054 L p .602 .499 .709 r
F P
0 g
s
.4749 .53054 m .46499 .53949 L .45243 .50373 L p .602 .499 .709 r
F P
0 g
s
.44283 .35582 m .45455 .36995 L .44588 .39736 L p .646 .543 .724 r
F P
0 g
s
.45898 .40897 m .44588 .39736 L .45455 .36995 L p .635 .528 .716 r
F P
0 g
s
.44588 .39736 m .45898 .40897 L .45619 .43705 L p .631 .521 .711 r
F P
0 g
s
.28306 .37433 m .29742 .36844 L .291 .4265 L p .805 .778 .827 r
F P
0 g
s
.291 .4265 m .27673 .43222 L .28306 .37433 L p .805 .778 .827 r
F P
0 g
s
.37094 .30984 m .38324 .31265 L .36661 .3583 L p .755 .702 .802 r
F P
0 g
s
.36661 .3583 m .35309 .35737 L .37094 .30984 L p .755 .702 .802 r
F P
0 g
s
.61044 .70466 m .60426 .70086 L .64021 .6827 L p .694 .85 .958 r
F P
0 g
s
.64021 .6827 m .64929 .68559 L .61044 .70466 L p .694 .85 .958 r
F P
0 g
s
.48977 .63981 m .4936 .62733 L .5221 .64967 L p .553 .526 .78 r
F P
0 g
s
.5221 .64967 m .52173 .66365 L .48977 .63981 L p .553 .526 .78 r
F P
0 g
s
.46986 .44464 m .45619 .43705 L .45898 .40897 L p .623 .511 .706 r
F P
0 g
s
.45619 .43705 m .46986 .44464 L .47133 .46997 L p .618 .506 .704 r
F P
0 g
s
.47133 .46997 m .45804 .46803 L .45619 .43705 L p .618 .506 .704 r
F P
0 g
s
.45804 .46803 m .47133 .46997 L .47644 .49605 L p .611 .501 .703 r
F P
0 g
s
.47644 .49605 m .46441 .4999 L .45804 .46803 L p .611 .501 .703 r
F P
0 g
s
.43931 .30452 m .44894 .31767 L .43109 .3434 L p .673 .597 .763 r
F P
0 g
s
.43109 .3434 m .41928 .33282 L .43931 .30452 L p .673 .597 .763 r
F P
0 g
s
.44283 .35582 m .43109 .3434 L .44894 .31767 L p .657 .571 .746 r
F P
0 g
s
.44894 .31767 m .4585 .33284 L .44283 .35582 L p .657 .571 .746 r
F P
0 g
s
.45455 .36995 m .44283 .35582 L .4585 .33284 L p .644 .549 .733 r
F P
0 g
s
.52137 .67542 m .52173 .66365 L .55423 .67528 L p .559 .582 .833 r
F P
0 g
s
.55423 .67528 m .55736 .68739 L .52137 .67542 L p .559 .582 .833 r
F P
0 g
s
.45455 .36995 m .46624 .38566 L .45898 .40897 L p .635 .528 .716 r
F P
0 g
s
.47211 .42173 m .45898 .40897 L .46624 .38566 L p .626 .516 .709 r
F P
0 g
s
.45898 .40897 m .47211 .42173 L .46986 .44464 L p .623 .511 .706 r
F P
0 g
s
.42959 .29346 m .43931 .30452 L .41928 .33282 L p .692 .63 .782 r
F P
0 g
s
.41928 .33282 m .40738 .32414 L .42959 .29346 L p .692 .63 .782 r
F P
0 g
s
.46499 .53949 m .4749 .53054 L .48883 .55793 L p .594 .497 .713 r
F P
0 g
s
.48883 .55793 m .48166 .57143 L .46499 .53949 L p .594 .497 .713 r
F P
0 g
s
.4585 .33284 m .46802 .34989 L .45455 .36995 L p .644 .549 .733 r
F P
0 g
s
.46624 .38566 m .45455 .36995 L .46802 .34989 L p .633 .532 .721 r
F P
0 g
s
.2685 .38115 m .28306 .37433 L .27673 .43222 L p .817 .803 .838 r
F P
0 g
s
.27673 .43222 m .26236 .4386 L .2685 .38115 L p .817 .803 .838 r
F P
0 g
s
.35847 .30892 m .37094 .30984 L .35309 .35737 L p .778 .739 .817 r
F P
0 g
s
.35309 .35737 m .33942 .35802 L .35847 .30892 L p .778 .739 .817 r
F P
0 g
s
.46441 .4999 m .47644 .49605 L .48486 .52113 L p .605 .497 .705 r
F P
0 g
s
.48486 .52113 m .4749 .53054 L .46441 .4999 L p .605 .497 .705 r
F P
0 g
s
.47453 .58392 m .48166 .57143 L .50137 .59739 L p .581 .501 .73 r
F P
0 g
s
.50137 .59739 m .49747 .61315 L .47453 .58392 L p .581 .501 .73 r
F P
0 g
s
.41975 .28455 m .42959 .29346 L .40738 .32414 L p .713 .668 .804 r
F P
0 g
s
.40738 .32414 m .39538 .31741 L .41975 .28455 L p .713 .668 .804 r
F P
0 g
s
.46802 .34989 m .4775 .36867 L .46624 .38566 L p .633 .532 .721 r
F P
0 g
s
.47794 .40275 m .46624 .38566 L .4775 .36867 L p .624 .518 .712 r
F P
0 g
s
.46624 .38566 m .47794 .40275 L .47211 .42173 L p .626 .516 .709 r
F P
0 g
s
.56045 .69696 m .55736 .68739 L .59156 .68541 L p .606 .674 .889 r
F P
0 g
s
.59156 .68541 m .59796 .69446 L .56045 .69696 L p .606 .674 .889 r
F P
0 g
s
.48357 .45294 m .46986 .44464 L .47211 .42173 L p .617 .504 .702 r
F P
0 g
s
.46986 .44464 m .48357 .45294 L .48468 .47227 L p .614 .501 .701 r
F P
0 g
s
.48468 .47227 m .47133 .46997 L .46986 .44464 L p .614 .501 .701 r
F P
0 g
s
.4936 .62733 m .49747 .61315 L .52247 .63359 L p .571 .518 .757 r
F P
0 g
s
.52247 .63359 m .5221 .64967 L .4936 .62733 L p .571 .518 .757 r
F P
0 g
s
.47133 .46997 m .48468 .47227 L .48853 .49218 L p .61 .498 .7 r
F P
0 g
s
.48853 .49218 m .47644 .49605 L .47133 .46997 L p .61 .498 .7 r
F P
0 g
s
.6582 .6861 m .64929 .68559 L .68028 .65219 L p .789 .867 .907 r
F P
0 g
s
.68028 .65219 m .6916 .65184 L .6582 .6861 L p .789 .867 .907 r
F P
0 g
s
.48527 .43547 m .47211 .42173 L .47794 .40275 L p .619 .506 .703 r
F P
0 g
s
.47211 .42173 m .48527 .43547 L .48357 .45294 L p .617 .504 .702 r
F P
0 g
s
.71366 .64536 m .70273 .6495 L .72711 .60228 L p .835 .866 .867 r
F P
0 g
s
.72711 .60228 m .73987 .59794 L .71366 .64536 L p .835 .866 .867 r
F P
0 g
s
.4749 .53054 m .48486 .52113 L .49604 .54355 L p .599 .495 .707 r
F P
0 g
s
.49604 .54355 m .48883 .55793 L .4749 .53054 L p .599 .495 .707 r
F P
0 g
s
.25376 .38872 m .2685 .38115 L .26236 .4386 L p .826 .826 .848 r
F P
0 g
s
.26236 .4386 m .24788 .44549 L .25376 .38872 L p .826 .826 .848 r
F P
0 g
s
.77711 .57799 m .76487 .58559 L .77926 .52982 L p .831 .846 .857 r
F P
0 g
s
.77926 .52982 m .79278 .52311 L .77711 .57799 L p .831 .846 .857 r
F P
0 g
s
.34579 .3098 m .35847 .30892 L .33942 .35802 L p .8 .778 .832 r
F P
0 g
s
.33942 .35802 m .3256 .36015 L .34579 .3098 L p .8 .778 .832 r
F P
0 g
s
.47644 .49605 m .48853 .49218 L .49487 .51134 L p .606 .495 .701 r
F P
0 g
s
.49487 .51134 m .48486 .52113 L .47644 .49605 L p .606 .495 .701 r
F P
0 g
s
.48166 .57143 m .48883 .55793 L .5053 .5802 L p .59 .499 .719 r
F P
0 g
s
.5053 .5802 m .50137 .59739 L .48166 .57143 L p .59 .499 .719 r
F P
0 g
s
.4775 .36867 m .48699 .38898 L .47794 .40275 L p .624 .518 .712 r
F P
0 g
s
.48967 .42103 m .47794 .40275 L .48699 .38898 L p .618 .507 .705 r
F P
0 g
s
.47794 .40275 m .48967 .42103 L .48527 .43547 L p .619 .506 .703 r
F P
0 g
s
.47211 .30277 m .47879 .3197 L .4585 .33284 L p .643 .571 .759 r
F P
0 g
s
.4585 .33284 m .44894 .31767 L .47211 .30277 L p .643 .571 .759 r
F P
0 g
s
.46802 .34989 m .4585 .33284 L .47879 .3197 L p .633 .548 .741 r
F P
0 g
s
.47879 .3197 m .48543 .33855 L .46802 .34989 L p .633 .548 .741 r
F P
0 g
s
.4775 .36867 m .46802 .34989 L .48543 .33855 L p .626 .53 .727 r
F P
0 g
s
.40978 .27781 m .41975 .28455 L .39538 .31741 L p .736 .712 .828 r
F P
0 g
s
.39538 .31741 m .38324 .31265 L .40978 .27781 L p .736 .712 .828 r
F P
0 g
s
.52173 .66365 m .5221 .64967 L .55105 .6607 L p .578 .557 .795 r
F P
0 g
s
.55105 .6607 m .55423 .67528 L .52173 .66365 L p .578 .557 .795 r
F P
0 g
s
.60426 .70086 m .59796 .69446 L .63098 .67731 L p .693 .765 .907 r
F P
0 g
s
.63098 .67731 m .64021 .6827 L .60426 .70086 L p .693 .765 .907 r
F P
0 g
s
.48543 .33855 m .49205 .35917 L .4775 .36867 L p .626 .53 .727 r
F P
0 g
s
.48699 .38898 m .4775 .36867 L .49205 .35917 L p .62 .517 .715 r
F P
0 g
s
.46537 .28791 m .47211 .30277 L .44894 .31767 L p .655 .6 .781 r
F P
0 g
s
.44894 .31767 m .43931 .30452 L .46537 .28791 L p .655 .6 .781 r
F P
0 g
s
.49735 .46177 m .48357 .45294 L .48527 .43547 L p .613 .498 .699 r
F P
0 g
s
.48357 .45294 m .49735 .46177 L .49809 .47484 L p .611 .497 .698 r
F P
0 g
s
.49809 .47484 m .48468 .47227 L .48357 .45294 L p .611 .497 .698 r
F P
0 g
s
.49849 .44998 m .48527 .43547 L .48967 .42103 L p .613 .499 .699 r
F P
0 g
s
.48527 .43547 m .49849 .44998 L .49735 .46177 L p .613 .498 .699 r
F P
0 g
s
.49747 .61315 m .50137 .59739 L .52284 .61557 L p .584 .511 .739 r
F P
0 g
s
.52284 .61557 m .52247 .63359 L .49747 .61315 L p .584 .511 .739 r
F P
0 g
s
.48468 .47227 m .49809 .47484 L .50067 .48829 L p .61 .495 .698 r
F P
0 g
s
.50067 .48829 m .48853 .49218 L .48468 .47227 L p .61 .495 .698 r
F P
0 g
s
.48486 .52113 m .49487 .51134 L .50327 .52846 L p .604 .495 .703 r
F P
0 g
s
.50327 .52846 m .49604 .54355 L .48486 .52113 L p .604 .495 .703 r
F P
0 g
s
.49205 .35917 m .49865 .38136 L .48699 .38898 L p .62 .517 .715 r
F P
0 g
s
.49648 .41059 m .48699 .38898 L .49865 .38136 L p .615 .506 .707 r
F P
0 g
s
.48699 .38898 m .49648 .41059 L .48967 .42103 L p .618 .507 .705 r
F P
0 g
s
.45856 .27519 m .46537 .28791 L .43931 .30452 L p .669 .637 .809 r
F P
0 g
s
.43931 .30452 m .42959 .29346 L .45856 .27519 L p .669 .637 .809 r
F P
0 g
s
.50143 .44025 m .48967 .42103 L .49648 .41059 L p .613 .5 .7 r
F P
0 g
s
.48967 .42103 m .50143 .44025 L .49849 .44998 L p .613 .499 .699 r
F P
0 g
s
.48883 .55793 m .49604 .54355 L .50924 .56179 L p .597 .497 .711 r
F P
0 g
s
.50924 .56179 m .5053 .5802 L .48883 .55793 L p .597 .497 .711 r
F P
0 g
s
.23884 .39683 m .25376 .38872 L .24788 .44549 L p .831 .847 .858 r
F P
0 g
s
.24788 .44549 m .2333 .45274 L .23884 .39683 L p .831 .847 .858 r
F P
0 g
s
.48853 .49218 m .50067 .48829 L .50491 .50123 L p .608 .494 .698 r
F P
0 g
s
.50491 .50123 m .49487 .51134 L .48853 .49218 L p .608 .494 .698 r
F P
0 g
s
.55736 .68739 m .55423 .67528 L .58507 .67373 L p .614 .624 .837 r
F P
0 g
s
.58507 .67373 m .59156 .68541 L .55736 .68739 L p .614 .624 .837 r
F P
0 g
s
.39965 .27321 m .40978 .27781 L .38324 .31265 L p .761 .762 .854 r
F P
0 g
s
.38324 .31265 m .37094 .30984 L .39965 .27321 L p .761 .762 .854 r
F P
0 g
s
.3329 .31236 m .34579 .3098 L .3256 .36015 L p .82 .816 .846 r
F P
0 g
s
.3256 .36015 m .3116 .36367 L .3329 .31236 L p .82 .816 .846 r
F P
0 g
s
.49865 .38136 m .50525 .40486 L .49648 .41059 L p .615 .506 .707 r
F P
0 g
s
.50599 .43324 m .49648 .41059 L .50525 .40486 L p .612 .499 .701 r
F P
0 g
s
.49648 .41059 m .50599 .43324 L .50143 .44025 L p .613 .5 .7 r
F P
0 g
s
.5221 .64967 m .52247 .63359 L .54785 .64376 L p .589 .539 .767 r
F P
0 g
s
.54785 .64376 m .55105 .6607 L .5221 .64967 L p .589 .539 .767 r
F P
0 g
s
.50137 .59739 m .5053 .5802 L .52322 .59582 L p .593 .505 .725 r
F P
0 g
s
.52322 .59582 m .52284 .61557 L .50137 .59739 L p .593 .505 .725 r
F P
0 g
s
.50568 .33679 m .50892 .35787 L .49205 .35917 L p .614 .525 .729 r
F P
0 g
s
.49205 .35917 m .48543 .33855 L .50568 .33679 L p .614 .525 .729 r
F P
0 g
s
.49865 .38136 m .49205 .35917 L .50892 .35787 L p .612 .513 .717 r
F P
0 g
s
.50241 .3174 m .50568 .33679 L .48543 .33855 L p .617 .54 .745 r
F P
0 g
s
.48543 .33855 m .47879 .3197 L .50241 .3174 L p .617 .54 .745 r
F P
0 g
s
.49487 .51134 m .50491 .50123 L .51054 .51279 L p .606 .494 .699 r
F P
0 g
s
.51054 .51279 m .50327 .52846 L .49487 .51134 L p .606 .494 .699 r
F P
0 g
s
.51119 .47101 m .49735 .46177 L .49849 .44998 L p .61 .494 .697 r
F P
0 g
s
.49735 .46177 m .51119 .47101 L .51157 .4776 L p .61 .494 .696 r
F P
0 g
s
.51157 .4776 m .49809 .47484 L .49735 .46177 L p .61 .494 .696 r
F P
0 g
s
.51177 .46506 m .49849 .44998 L .50143 .44025 L p .61 .495 .697 r
F P
0 g
s
.49849 .44998 m .51177 .46506 L .51119 .47101 L p .61 .494 .697 r
F P
0 g
s
.49604 .54355 m .50327 .52846 L .5132 .54237 L p .602 .495 .705 r
F P
0 g
s
.5132 .54237 m .50924 .56179 L .49604 .54355 L p .602 .495 .705 r
F P
0 g
s
.64929 .68559 m .64021 .6827 L .66879 .65041 L p .765 .794 .876 r
F P
0 g
s
.66879 .65041 m .68028 .65219 L .64929 .68559 L p .765 .794 .876 r
F P
0 g
s
.49809 .47484 m .51157 .4776 L .51286 .48439 L p .609 .493 .696 r
F P
0 g
s
.51286 .48439 m .50067 .48829 L .49809 .47484 L p .609 .493 .696 r
F P
0 g
s
.50892 .35787 m .51216 .38044 L .49865 .38136 L p .612 .513 .717 r
F P
0 g
s
.50525 .40486 m .49865 .38136 L .51216 .38044 L p .611 .504 .708 r
F P
0 g
s
.45166 .26467 m .45856 .27519 L .42959 .29346 L p .685 .683 .842 r
F P
0 g
s
.42959 .29346 m .41975 .28455 L .45166 .26467 L p .685 .683 .842 r
F P
0 g
s
.49912 .29986 m .50241 .3174 L .47879 .3197 L p .62 .56 .766 r
F P
0 g
s
.47879 .3197 m .47211 .30277 L .49912 .29986 L p .62 .56 .766 r
F P
0 g
s
.51325 .46016 m .50143 .44025 L .50599 .43324 L p .61 .495 .697 r
F P
0 g
s
.50143 .44025 m .51325 .46016 L .51177 .46506 L p .61 .495 .697 r
F P
0 g
s
.70273 .6495 m .6916 .65184 L .71419 .60514 L p .812 .814 .851 r
F P
0 g
s
.71419 .60514 m .72711 .60228 L .70273 .6495 L p .812 .814 .851 r
F P
0 g
s
.76487 .58559 m .75246 .59231 L .76563 .5359 L p .818 .812 .845 r
F P
0 g
s
.76563 .5359 m .77926 .52982 L .76487 .58559 L p .818 .812 .845 r
F P
0 g
s
.50067 .48829 m .51286 .48439 L .51499 .49091 L p .608 .493 .696 r
F P
0 g
s
.51499 .49091 m .50491 .50123 L .50067 .48829 L p .608 .493 .696 r
F P
0 g
s
.22376 .40525 m .23884 .39683 L .2333 .45274 L p .834 .866 .868 r
F P
0 g
s
.2333 .45274 m .21864 .46019 L .22376 .40525 L p .834 .866 .868 r
F P
0 g
s
.51216 .38044 m .5154 .40425 L .50525 .40486 L p .611 .504 .708 r
F P
0 g
s
.51185 .42942 m .50525 .40486 L .5154 .40425 L p .61 .498 .701 r
F P
0 g
s
.50525 .40486 m .51185 .42942 L .50599 .43324 L p .612 .499 .701 r
F P
0 g
s
.59796 .69446 m .59156 .68541 L .62161 .66937 L p .68 .695 .858 r
F P
0 g
s
.62161 .66937 m .63098 .67731 L .59796 .69446 L p .68 .695 .858 r
F P
0 g
s
.51553 .45663 m .50599 .43324 L .51185 .42942 L p .61 .495 .697 r
F P
0 g
s
.50599 .43324 m .51553 .45663 L .51325 .46016 L p .61 .495 .697 r
F P
0 g
s
.5053 .5802 m .50924 .56179 L .5236 .57458 L p .599 .501 .714 r
F P
0 g
s
.5236 .57458 m .52322 .59582 L .5053 .5802 L p .599 .501 .714 r
F P
0 g
s
.50327 .52846 m .51054 .51279 L .51717 .52218 L p .606 .494 .7 r
F P
0 g
s
.51717 .52218 m .5132 .54237 L .50327 .52846 L p .606 .494 .7 r
F P
0 g
s
.4958 .28429 m .49912 .29986 L .47211 .30277 L p .622 .587 .793 r
F P
0 g
s
.47211 .30277 m .46537 .28791 L .4958 .28429 L p .622 .587 .793 r
F P
0 g
s
.50491 .50123 m .51499 .49091 L .51782 .49674 L p .608 .493 .697 r
F P
0 g
s
.51782 .49674 m .51054 .51279 L .50491 .50123 L p .608 .493 .697 r
F P
0 g
s
.52247 .63359 m .52284 .61557 L .54463 .62468 L p .596 .525 .745 r
F P
0 g
s
.54463 .62468 m .54785 .64376 L .52247 .63359 L p .596 .525 .745 r
F P
0 g
s
.55423 .67528 m .55105 .6607 L .57851 .65949 L p .616 .587 .798 r
F P
0 g
s
.57851 .65949 m .58507 .67373 L .55423 .67528 L p .616 .587 .798 r
F P
0 g
s
.38935 .27068 m .39965 .27321 L .37094 .30984 L p .785 .817 .878 r
F P
0 g
s
.37094 .30984 m .35847 .30892 L .38935 .27068 L p .785 .817 .878 r
F P
0 g
s
.85906 .48583 m .84593 .49323 L .84595 .43919 L p .763 .838 .908 r
F P
0 g
s
.84595 .43919 m .85986 .43317 L .85906 .48583 L p .763 .838 .908 r
F P
0 g
s
.5154 .40425 m .51863 .42907 L .51185 .42942 L p .61 .498 .701 r
F P
0 g
s
.51847 .45473 m .51185 .42942 L .51863 .42907 L p .609 .494 .697 r
F P
0 g
s
.51185 .42942 m .51847 .45473 L .51553 .45663 L p .61 .495 .697 r
F P
0 g
s
.31978 .31646 m .3329 .31236 L .3116 .36367 L p .837 .853 .857 r
F P
0 g
s
.3116 .36367 m .29742 .36844 L .31978 .31646 L p .837 .853 .857 r
F P
0 g
s
.50924 .56179 m .5132 .54237 L .52398 .55213 L p .603 .498 .706 r
F P
0 g
s
.52398 .55213 m .5236 .57458 L .50924 .56179 L p .603 .498 .706 r
F P
0 g
s
.52511 .48046 m .51119 .47101 L .51177 .46506 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .51157 .4776 L .51119 .47101 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .51177 .46506 L .51325 .46016 L closepath p .609 .492 .695 r
F P
0 g
s
.52701 .36492 m .52663 .38633 L .51216 .38044 L p .605 .507 .717 r
F P
0 g
s
.51216 .38044 m .50892 .35787 L .52701 .36492 L p .605 .507 .717 r
F P
0 g
s
.5154 .40425 m .51216 .38044 L .52663 .38633 L p .607 .501 .708 r
F P
0 g
s
.52511 .48046 m .51286 .48439 L .51157 .4776 L closepath p .609 .492 .695 r
F P
0 g
s
.52739 .34483 m .52701 .36492 L .50892 .35787 L p .603 .516 .729 r
F P
0 g
s
.50892 .35787 m .50568 .33679 L .52739 .34483 L p .603 .516 .729 r
F P
0 g
s
.52511 .48046 m .51325 .46016 L .51553 .45663 L closepath p .609 .492 .695 r
F P
0 g
s
.51054 .51279 m .51782 .49674 L .52114 .50146 L p .608 .493 .697 r
F P
0 g
s
.52114 .50146 m .51717 .52218 L .51054 .51279 L p .608 .493 .697 r
F P
0 g
s
.44464 .25638 m .45166 .26467 L .41975 .28455 L p .702 .739 .88 r
F P
0 g
s
.41975 .28455 m .40978 .27781 L .44464 .25638 L p .702 .739 .88 r
F P
0 g
s
.52663 .38633 m .52625 .40884 L .5154 .40425 L p .607 .501 .708 r
F P
0 g
s
.51863 .42907 m .5154 .40425 L .52625 .40884 L p .608 .497 .701 r
F P
0 g
s
.52511 .48046 m .51499 .49091 L .51286 .48439 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .51553 .45663 L .51847 .45473 L closepath p .609 .492 .695 r
F P
0 g
s
.52284 .61557 m .52322 .59582 L .54138 .60366 L p .601 .515 .729 r
F P
0 g
s
.54138 .60366 m .54463 .62468 L .52284 .61557 L p .601 .515 .729 r
F P
0 g
s
.20853 .41376 m .22376 .40525 L .21864 .46019 L p .833 .881 .878 r
F P
0 g
s
.21864 .46019 m .2039 .46769 L .20853 .41376 L p .833 .881 .878 r
F P
0 g
s
.52778 .32624 m .52739 .34483 L .50568 .33679 L p .599 .527 .744 r
F P
0 g
s
.50568 .33679 m .50241 .3174 L .52778 .32624 L p .599 .527 .744 r
F P
0 g
s
.49244 .27078 m .4958 .28429 L .46537 .28791 L p .625 .621 .827 r
F P
0 g
s
.46537 .28791 m .45856 .27519 L .49244 .27078 L p .625 .621 .827 r
F P
0 g
s
.5132 .54237 m .51717 .52218 L .52436 .52875 L p .606 .495 .701 r
F P
0 g
s
.52436 .52875 m .52398 .55213 L .5132 .54237 L p .606 .495 .701 r
F P
0 g
s
.52511 .48046 m .51782 .49674 L .51499 .49091 L closepath p .609 .492 .695 r
F P
0 g
s
.52625 .40884 m .52587 .43221 L .51863 .42907 L p .608 .497 .701 r
F P
0 g
s
.52187 .45457 m .51863 .42907 L .52587 .43221 L p .609 .494 .697 r
F P
0 g
s
.51863 .42907 m .52187 .45457 L .51847 .45473 L p .609 .494 .697 r
F P
0 g
s
.52511 .48046 m .51847 .45473 L .52187 .45457 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .52114 .50146 L .51782 .49674 L closepath p .609 .492 .695 r
F P
0 g
s
.51717 .52218 m .52114 .50146 L .52473 .50476 L p .608 .493 .697 r
F P
0 g
s
.52473 .50476 m .52436 .52875 L .51717 .52218 L p .608 .493 .697 r
F P
0 g
s
.55105 .6607 m .54785 .64376 L .5719 .64284 L p .616 .559 .768 r
F P
0 g
s
.5719 .64284 m .57851 .65949 L .55105 .6607 L p .616 .559 .768 r
F P
0 g
s
.64021 .6827 m .63098 .67731 L .65714 .6464 L p .738 .729 .843 r
F P
0 g
s
.65714 .6464 m .66879 .65041 L .64021 .6827 L p .738 .729 .843 r
F P
0 g
s
.52587 .43221 m .52549 .45618 L .52187 .45457 L p .609 .494 .697 r
F P
0 g
s
.52511 .48046 m .52187 .45457 L .52549 .45618 L closepath p .609 .492 .695 r
F P
0 g
s
.52322 .59582 m .5236 .57458 L .53813 .58101 L p .604 .507 .717 r
F P
0 g
s
.53813 .58101 m .54138 .60366 L .52322 .59582 L p .604 .507 .717 r
F P
0 g
s
.59156 .68541 m .58507 .67373 L .61213 .6589 L p .665 .642 .817 r
F P
0 g
s
.61213 .6589 m .62161 .66937 L .59156 .68541 L p .665 .642 .817 r
F P
0 g
s
.75246 .59231 m .73987 .59794 L .75189 .5412 L p .802 .778 .831 r
F P
0 g
s
.75189 .5412 m .76563 .5359 L .75246 .59231 L p .802 .778 .831 r
F P
0 g
s
.52817 .30929 m .52778 .32624 L .50241 .3174 L p .594 .541 .765 r
F P
0 g
s
.50241 .3174 m .49912 .29986 L .52817 .30929 L p .594 .541 .765 r
F P
0 g
s
.84593 .49323 m .83276 .50082 L .83205 .44528 L p .766 .82 .895 r
F P
0 g
s
.83205 .44528 m .84595 .43919 L .84593 .49323 L p .766 .82 .895 r
F P
0 g
s
.52511 .48046 m .52473 .50476 L .52114 .50146 L closepath p .609 .492 .695 r
F P
0 g
s
.6916 .65184 m .68028 .65219 L .7011 .60639 L p .786 .763 .832 r
F P
0 g
s
.7011 .60639 m .71419 .60514 L .6916 .65184 L p .786 .763 .832 r
F P
0 g
s
.53707 .41833 m .53308 .43866 L .52587 .43221 L p .607 .495 .701 r
F P
0 g
s
.52587 .43221 m .52625 .40884 L .53707 .41833 L p .607 .495 .701 r
F P
0 g
s
.52549 .45618 m .52587 .43221 L .53308 .43866 L p .608 .493 .697 r
F P
0 g
s
.54107 .39868 m .53707 .41833 L .52625 .40884 L p .604 .498 .706 r
F P
0 g
s
.52625 .40884 m .52663 .38633 L .54107 .39868 L p .604 .498 .706 r
F P
0 g
s
.53308 .43866 m .5291 .45945 L .52549 .45618 L p .608 .493 .697 r
F P
0 g
s
.52511 .48046 m .52549 .45618 L .5291 .45945 L closepath p .609 .492 .695 r
F P
0 g
s
.5236 .57458 m .52398 .55213 L .53487 .55702 L p .607 .501 .708 r
F P
0 g
s
.53487 .55702 m .53813 .58101 L .5236 .57458 L p .607 .501 .708 r
F P
0 g
s
.52511 .48046 m .53527 .46998 L .53742 .47653 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53243 .46415 L .53527 .46998 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .5291 .45945 L .53243 .46415 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .52836 .5064 L .52473 .50476 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53177 .50628 L .52836 .5064 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53474 .50439 L .53177 .50628 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53704 .50087 L .53474 .50439 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53853 .49595 L .53704 .50087 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53911 .48997 L .53853 .49595 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53873 .48335 L .53911 .48997 L closepath p .609 .492 .695 r
F P
0 g
s
.52511 .48046 m .53742 .47653 L .53873 .48335 L closepath p .609 .492 .695 r
F P
0 g
s
.54509 .37992 m .54107 .39868 L .52663 .38633 L p .6 .501 .714 r
F P
0 g
s
.52663 .38633 m .52701 .36492 L .54509 .37992 L p .6 .501 .714 r
F P
0 g
s
.52436 .52875 m .52473 .50476 L .52836 .5064 L p .609 .494 .697 r
F P
0 g
s
.52398 .55213 m .52436 .52875 L .53162 .53204 L p .608 .497 .701 r
F P
0 g
s
.53162 .53204 m .53487 .55702 L .52398 .55213 L p .608 .497 .701 r
F P
0 g
s
.52836 .5064 m .53162 .53204 L .52436 .52875 L p .609 .494 .697 r
F P
0 g
s
.37884 .27015 m .38935 .27068 L .35847 .30892 L p .804 .872 .898 r
F P
0 g
s
.35847 .30892 m .34579 .3098 L .37884 .27015 L p .804 .872 .898 r
F P
0 g
s
.53976 .44798 m .53243 .46415 L .5291 .45945 L p .608 .493 .697 r
F P
0 g
s
.5291 .45945 m .53308 .43866 L .53976 .44798 L p .608 .493 .697 r
F P
0 g
s
.19318 .42214 m .20853 .41376 L .2039 .46769 L p .828 .894 .888 r
F P
0 g
s
.2039 .46769 m .18911 .47507 L .19318 .42214 L p .828 .894 .888 r
F P
0 g
s
.54785 .64376 m .54463 .62468 L .56524 .62396 L p .615 .539 .746 r
F P
0 g
s
.56524 .62396 m .5719 .64284 L .54785 .64376 L p .615 .539 .746 r
F P
0 g
s
.30643 .32192 m .31978 .31646 L .29742 .36844 L p .85 .887 .865 r
F P
0 g
s
.29742 .36844 m .28306 .37433 L .30643 .32192 L p .85 .887 .865 r
F P
0 g
s
.48903 .2594 m .49244 .27078 L .45856 .27519 L p .624 .665 .869 r
F P
0 g
s
.45856 .27519 m .45166 .26467 L .48903 .2594 L p .624 .665 .869 r
F P
0 g
s
.54912 .36222 m .54509 .37992 L .52701 .36492 L p .594 .506 .725 r
F P
0 g
s
.52701 .36492 m .52739 .34483 L .54912 .36222 L p .594 .506 .725 r
F P
0 g
s
.53162 .53204 m .52836 .5064 L .53177 .50628 L p .609 .494 .697 r
F P
0 g
s
.43751 .25027 m .44464 .25638 L .40978 .27781 L p .715 .804 .92 r
F P
0 g
s
.40978 .27781 m .39965 .27321 L .43751 .25027 L p .715 .804 .92 r
F P
0 g
s
.52856 .29412 m .52817 .30929 L .49912 .29986 L p .586 .559 .791 r
F P
0 g
s
.49912 .29986 m .4958 .28429 L .52856 .29412 L p .586 .559 .791 r
F P
0 g
s
.54712 .43211 m .53976 .44798 L .53308 .43866 L p .606 .494 .7 r
F P
0 g
s
.53308 .43866 m .53707 .41833 L .54712 .43211 L p .606 .494 .7 r
F P
0 g
s
.54546 .45955 m .53527 .46998 L .53243 .46415 L p .608 .493 .697 r
F P
0 g
s
.53243 .46415 m .53976 .44798 L .54546 .45955 L p .608 .493 .697 r
F P
0 g
s
.53177 .50628 m .53845 .53181 L .53162 .53204 L p .609 .494 .697 r
F P
0 g
s
.53845 .53181 m .53177 .50628 L .53474 .50439 L p .61 .495 .697 r
F P
0 g
s
.53487 .55702 m .53162 .53204 L .53845 .53181 L p .61 .498 .701 r
F P
0 g
s
.54978 .47257 m .53742 .47653 L .53527 .46998 L p .608 .493 .696 r
F P
0 g
s
.53527 .46998 m .54546 .45955 L .54978 .47257 L p .608 .493 .696 r
F P
0 g
s
.5545 .41671 m .54712 .43211 L .53707 .41833 L p .603 .496 .705 r
F P
0 g
s
.53707 .41833 m .54107 .39868 L .5545 .41671 L p .603 .496 .705 r
F P
0 g
s
.58507 .67373 m .57851 .65949 L .60256 .64598 L p .652 .601 .785 r
F P
0 g
s
.60256 .64598 m .61213 .6589 L .58507 .67373 L p .652 .601 .785 r
F P
0 g
s
.54463 .62468 m .54138 .60366 L .55855 .60311 L p .613 .524 .73 r
F P
0 g
s
.55855 .60311 m .56524 .62396 L .54463 .62468 L p .613 .524 .73 r
F P
0 g
s
.83276 .50082 m .81952 .50844 L .81814 .45138 L p .765 .799 .881 r
F P
0 g
s
.81814 .45138 m .83205 .44528 L .83276 .50082 L p .765 .799 .881 r
F P
0 g
s
.55318 .34574 m .54912 .36222 L .52739 .34483 L p .586 .512 .738 r
F P
0 g
s
.52739 .34483 m .52778 .32624 L .55318 .34574 L p .586 .512 .738 r
F P
0 g
s
.53474 .50439 m .54439 .52807 L .53845 .53181 L p .61 .495 .697 r
F P
0 g
s
.54439 .52807 m .53474 .50439 L .53704 .50087 L p .61 .495 .697 r
F P
0 g
s
.55241 .48615 m .53873 .48335 L .53742 .47653 L p .609 .493 .696 r
F P
0 g
s
.53742 .47653 m .54978 .47257 L .55241 .48615 L p .609 .493 .696 r
F P
0 g
s
.53813 .58101 m .53487 .55702 L .54515 .5567 L p .611 .504 .708 r
F P
0 g
s
.53845 .53181 m .54515 .5567 L .53487 .55702 L p .61 .498 .701 r
F P
0 g
s
.63098 .67731 m .62161 .66937 L .64536 .64013 L p .713 .676 .813 r
F P
0 g
s
.64536 .64013 m .65714 .6464 L .63098 .67731 L p .713 .676 .813 r
F P
0 g
s
.55569 .44926 m .54546 .45955 L .53976 .44798 L p .606 .494 .699 r
F P
0 g
s
.53976 .44798 m .54712 .43211 L .55569 .44926 L p .606 .494 .699 r
F P
0 g
s
.53704 .50087 m .54902 .52107 L .54439 .52807 L p .61 .495 .697 r
F P
0 g
s
.54902 .52107 m .53704 .50087 L .53853 .49595 L p .61 .495 .697 r
F P
0 g
s
.54138 .60366 m .53813 .58101 L .55185 .58059 L p .612 .512 .717 r
F P
0 g
s
.55185 .58059 m .55855 .60311 L .54138 .60366 L p .612 .512 .717 r
F P
0 g
s
.55318 .49936 m .53911 .48997 L .53873 .48335 L p .61 .494 .696 r
F P
0 g
s
.53873 .48335 m .55241 .48615 L .55318 .49936 L p .61 .494 .696 r
F P
0 g
s
.54515 .5567 m .55185 .58059 L .53813 .58101 L p .611 .504 .708 r
F P
0 g
s
.53853 .49595 m .55202 .51127 L .54902 .52107 L p .61 .495 .697 r
F P
0 g
s
.55202 .51127 m .53853 .49595 L .53911 .48997 L p .61 .494 .697 r
F P
0 g
s
.53911 .48997 m .55318 .49936 L .55202 .51127 L p .61 .494 .697 r
F P
0 g
s
.56191 .40191 m .5545 .41671 L .54107 .39868 L p .598 .497 .711 r
F P
0 g
s
.54107 .39868 m .54509 .37992 L .56191 .40191 L p .598 .497 .711 r
F P
0 g
s
.73987 .59794 m .72711 .60228 L .73804 .54558 L p .783 .744 .817 r
F P
0 g
s
.73804 .54558 m .75189 .5412 L .73987 .59794 L p .783 .744 .817 r
F P
0 g
s
.54515 .5567 m .53845 .53181 L .54439 .52807 L p .612 .499 .701 r
F P
0 g
s
.68028 .65219 m .66879 .65041 L .68787 .60591 L p .76 .717 .812 r
F P
0 g
s
.68787 .60591 m .7011 .60639 L .68028 .65219 L p .76 .717 .812 r
F P
0 g
s
.52895 .28079 m .52856 .29412 L .4958 .28429 L p .574 .583 .824 r
F P
0 g
s
.4958 .28429 m .49244 .27078 L .52895 .28079 L p .574 .583 .824 r
F P
0 g
s
.55727 .3306 m .55318 .34574 L .52778 .32624 L p .576 .52 .755 r
F P
0 g
s
.52778 .32624 m .52817 .30929 L .55727 .3306 L p .576 .52 .755 r
F P
0 g
s
.5622 .46859 m .54978 .47257 L .54546 .45955 L p .608 .494 .698 r
F P
0 g
s
.54546 .45955 m .55569 .44926 L .5622 .46859 L p .608 .494 .698 r
F P
0 g
s
.57851 .65949 m .5719 .64284 L .59292 .63074 L p .641 .571 .761 r
F P
0 g
s
.59292 .63074 m .60256 .64598 L .57851 .65949 L p .641 .571 .761 r
F P
0 g
s
.56597 .43919 m .55569 .44926 L .54712 .43211 L p .604 .495 .703 r
F P
0 g
s
.54712 .43211 m .5545 .41671 L .56597 .43919 L p .604 .495 .703 r
F P
0 g
s
.56935 .38786 m .56191 .40191 L .54509 .37992 L p .591 .5 .719 r
F P
0 g
s
.54509 .37992 m .54912 .36222 L .56935 .38786 L p .591 .5 .719 r
F P
0 g
s
.54439 .52807 m .55408 .55115 L .54515 .5567 L p .612 .499 .701 r
F P
0 g
s
.55408 .55115 m .54439 .52807 L .54902 .52107 L p .613 .5 .7 r
F P
0 g
s
.48557 .25014 m .48903 .2594 L .45166 .26467 L p .618 .72 .919 r
F P
0 g
s
.45166 .26467 m .44464 .25638 L .48557 .25014 L p .618 .72 .919 r
F P
0 g
s
.55185 .58059 m .54515 .5567 L .55408 .55115 L p .615 .506 .707 r
F P
0 g
s
.81952 .50844 m .80619 .51593 L .80421 .45738 L p .762 .777 .866 r
F P
0 g
s
.80421 .45738 m .81814 .45138 L .81952 .50844 L p .762 .777 .866 r
F P
0 g
s
.56617 .48879 m .55241 .48615 L .54978 .47257 L p .61 .495 .698 r
F P
0 g
s
.54978 .47257 m .5622 .46859 L .56617 .48879 L p .61 .495 .698 r
F P
0 g
s
.29284 .32853 m .30643 .32192 L .28306 .37433 L p .857 .916 .87 r
F P
0 g
s
.28306 .37433 m .2685 .38115 L .29284 .32853 L p .857 .916 .87 r
F P
0 g
s
.36812 .27149 m .37884 .27015 L .34579 .3098 L p .814 .923 .908 r
F P
0 g
s
.34579 .3098 m .3329 .31236 L .36812 .27149 L p .814 .923 .908 r
F P
0 g
s
.54902 .52107 m .56106 .54074 L .55408 .55115 L p .613 .5 .7 r
F P
0 g
s
.56106 .54074 m .54902 .52107 L .55202 .51127 L p .613 .499 .699 r
F P
0 g
s
.5719 .64284 m .56524 .62396 L .58324 .61338 L p .632 .548 .741 r
F P
0 g
s
.58324 .61338 m .59292 .63074 L .5719 .64284 L p .632 .548 .741 r
F P
0 g
s
.62161 .66937 m .61213 .6589 L .63346 .63162 L p .69 .633 .787 r
F P
0 g
s
.63346 .63162 m .64536 .64013 L .62161 .66937 L p .69 .633 .787 r
F P
0 g
s
.55855 .60311 m .55185 .58059 L .5638 .57329 L p .619 .516 .715 r
F P
0 g
s
.55408 .55115 m .5638 .57329 L .55185 .58059 L p .615 .506 .707 r
F P
0 g
s
.56732 .50843 m .55318 .49936 L .55241 .48615 L p .611 .497 .698 r
F P
0 g
s
.55241 .48615 m .56617 .48879 L .56732 .50843 L p .611 .497 .698 r
F P
0 g
s
.43023 .24631 m .43751 .25027 L .39965 .27321 L p .718 .873 .954 r
F P
0 g
s
.39965 .27321 m .38935 .27068 L .43023 .24631 L p .718 .873 .954 r
F P
0 g
s
.57628 .42943 m .56597 .43919 L .5545 .41671 L p .6 .496 .707 r
F P
0 g
s
.5545 .41671 m .56191 .40191 L .57628 .42943 L p .6 .496 .707 r
F P
0 g
s
.55202 .51127 m .56558 .52616 L .56106 .54074 L p .613 .499 .699 r
F P
0 g
s
.56558 .52616 m .55202 .51127 L .55318 .49936 L p .613 .498 .699 r
F P
0 g
s
.55318 .49936 m .56732 .50843 L .56558 .52616 L p .613 .498 .699 r
F P
0 g
s
.57467 .4646 m .5622 .46859 L .55569 .44926 L p .607 .495 .701 r
F P
0 g
s
.55569 .44926 m .56597 .43919 L .57467 .4646 L p .607 .495 .701 r
F P
0 g
s
.56524 .62396 m .55855 .60311 L .57352 .59413 L p .625 .53 .727 r
F P
0 g
s
.57352 .59413 m .58324 .61338 L .56524 .62396 L p .625 .53 .727 r
F P
0 g
s
.5638 .57329 m .57352 .59413 L .55855 .60311 L p .619 .516 .715 r
F P
0 g
s
.57684 .37467 m .56935 .38786 L .54912 .36222 L p .583 .502 .729 r
F P
0 g
s
.54912 .36222 m .55318 .34574 L .57684 .37467 L p .583 .502 .729 r
F P
0 g
s
.5614 .31691 m .55727 .3306 L .52817 .30929 L p .562 .53 .777 r
F P
0 g
s
.52817 .30929 m .52856 .29412 L .5614 .31691 L p .562 .53 .777 r
F P
0 g
s
.5638 .57329 m .55408 .55115 L .56106 .54074 L p .617 .507 .705 r
F P
0 g
s
.72711 .60228 m .71419 .60514 L .72408 .54891 L p .764 .711 .802 r
F P
0 g
s
.72408 .54891 m .73804 .54558 L .72711 .60228 L p .764 .711 .802 r
F P
0 g
s
.66879 .65041 m .65714 .6464 L .67451 .60364 L p .735 .676 .793 r
F P
0 g
s
.67451 .60364 m .68787 .60591 L .66879 .65041 L p .735 .676 .793 r
F P
0 g
s
.52936 .26937 m .52895 .28079 L .49244 .27078 L p .554 .613 .866 r
F P
0 g
s
.49244 .27078 m .48903 .2594 L .52936 .26937 L p .554 .613 .866 r
F P
0 g
s
.57998 .49117 m .56617 .48879 L .5622 .46859 L p .61 .498 .7 r
F P
0 g
s
.5622 .46859 m .57467 .4646 L .57998 .49117 L p .61 .498 .7 r
F P
0 g
s
.80619 .51593 m .79278 .52311 L .79027 .46321 L p .755 .753 .851 r
F P
0 g
s
.79027 .46321 m .80421 .45738 L .80619 .51593 L p .755 .753 .851 r
F P
0 g
s
.58665 .42005 m .57628 .42943 L .56191 .40191 L p .595 .497 .713 r
F P
0 g
s
.56191 .40191 m .56935 .38786 L .58665 .42005 L p .595 .497 .713 r
F P
0 g
s
.56106 .54074 m .57313 .55957 L .5638 .57329 L p .617 .507 .705 r
F P
0 g
s
.57313 .55957 m .56106 .54074 L .56558 .52616 L p .618 .506 .703 r
F P
0 g
s
.61213 .6589 m .60256 .64598 L .62148 .62093 L p .671 .598 .765 r
F P
0 g
s
.62148 .62093 m .63346 .63162 L .61213 .6589 L p .671 .598 .765 r
F P
0 g
s
.57352 .59413 m .5638 .57329 L .57313 .55957 L p .624 .517 .712 r
F P
0 g
s
.5872 .46059 m .57467 .4646 L .56597 .43919 L p .605 .497 .705 r
F P
0 g
s
.56597 .43919 m .57628 .42943 L .5872 .46059 L p .605 .497 .705 r
F P
0 g
s
.58153 .51703 m .56732 .50843 L .56617 .48879 L p .614 .501 .701 r
F P
0 g
s
.56617 .48879 m .57998 .49117 L .58153 .51703 L p .614 .501 .701 r
F P
0 g
s
.58439 .36243 m .57684 .37467 L .55318 .34574 L p .572 .506 .742 r
F P
0 g
s
.55318 .34574 m .55727 .3306 L .58439 .36243 L p .572 .506 .742 r
F P
0 g
s
.56558 .52616 m .57919 .54038 L .57313 .55957 L p .618 .506 .703 r
F P
0 g
s
.57919 .54038 m .56558 .52616 L .56732 .50843 L p .617 .504 .702 r
F P
0 g
s
.56732 .50843 m .58153 .51703 L .57919 .54038 L p .617 .504 .702 r
F P
0 g
s
.60256 .64598 m .59292 .63074 L .60943 .60818 L p .655 .571 .748 r
F P
0 g
s
.60943 .60818 m .62148 .62093 L .60256 .64598 L p .655 .571 .748 r
F P
0 g
s
.58324 .61338 m .57352 .59413 L .58523 .57728 L p .632 .531 .722 r
F P
0 g
s
.57313 .55957 m .58523 .57728 L .57352 .59413 L p .624 .517 .712 r
F P
0 g
s
.48204 .243 m .48557 .25014 L .44464 .25638 L p .596 .782 .969 r
F P
0 g
s
.44464 .25638 m .43751 .25027 L .48204 .243 L p .596 .782 .969 r
F P
0 g
s
.56557 .30474 m .5614 .31691 L .52856 .29412 L p .542 .541 .804 r
F P
0 g
s
.52856 .29412 m .52895 .28079 L .56557 .30474 L p .542 .541 .804 r
F P
0 g
s
.65714 .6464 m .64536 .64013 L .66104 .59954 L p .712 .64 .775 r
F P
0 g
s
.66104 .59954 m .67451 .60364 L .65714 .6464 L p .712 .64 .775 r
F P
0 g
s
.59292 .63074 m .58324 .61338 L .59734 .59356 L p .642 .548 .733 r
F P
0 g
s
.58523 .57728 m .59734 .59356 L .58324 .61338 L p .632 .531 .722 r
F P
0 g
s
.59734 .59356 m .60943 .60818 L .59292 .63074 L p .642 .548 .733 r
F P
0 g
s
.58523 .57728 m .57313 .55957 L .57919 .54038 L p .625 .515 .709 r
F P
0 g
s
.59708 .4111 m .58665 .42005 L .56935 .38786 L p .588 .499 .721 r
F P
0 g
s
.56935 .38786 m .57684 .37467 L .59708 .4111 L p .588 .499 .721 r
F P
0 g
s
.59386 .49321 m .57998 .49117 L .57467 .4646 L p .611 .501 .703 r
F P
0 g
s
.57467 .4646 m .5872 .46059 L .59386 .49321 L p .611 .501 .703 r
F P
0 g
s
.71419 .60514 m .7011 .60639 L .71003 .55112 L p .745 .68 .788 r
F P
0 g
s
.71003 .55112 m .72408 .54891 L .71419 .60514 L p .745 .68 .788 r
F P
0 g
s
.27901 .33607 m .29284 .32853 L .2685 .38115 L p .859 .94 .873 r
F P
0 g
s
.2685 .38115 m .25376 .38872 L .27901 .33607 L p .859 .94 .873 r
F P
0 g
s
.79278 .52311 m .77926 .52982 L .77631 .46878 L p .747 .729 .836 r
F P
0 g
s
.77631 .46878 m .79027 .46321 L .79278 .52311 L p .747 .729 .836 r
F P
0 g
s
.59979 .45656 m .5872 .46059 L .57628 .42943 L p .603 .499 .709 r
F P
0 g
s
.57628 .42943 m .58665 .42005 L .59979 .45656 L p .603 .499 .709 r
F P
0 g
s
.35717 .27452 m .36812 .27149 L .3329 .31236 L p .812 .963 .907 r
F P
0 g
s
.3329 .31236 m .31978 .31646 L .35717 .27452 L p .812 .963 .907 r
F P
0 g
s
.57919 .54038 m .59284 .55368 L .58523 .57728 L p .625 .515 .709 r
F P
0 g
s
.59284 .55368 m .57919 .54038 L .58153 .51703 L p .623 .511 .706 r
F P
0 g
s
.4228 .24439 m .43023 .24631 L .38935 .27068 L p .699 .931 .965 r
F P
0 g
s
.38935 .27068 m .37884 .27015 L .4228 .24439 L p .699 .931 .965 r
F P
0 g
s
.59579 .52499 m .58153 .51703 L .57998 .49117 L p .618 .506 .704 r
F P
0 g
s
.57998 .49117 m .59386 .49321 L .59579 .52499 L p .618 .506 .704 r
F P
0 g
s
.59199 .35122 m .58439 .36243 L .55727 .3306 L p .557 .509 .758 r
F P
0 g
s
.55727 .3306 m .5614 .31691 L .59199 .35122 L p .557 .509 .758 r
F P
0 g
s
.58153 .51703 m .59579 .52499 L .59284 .55368 L p .623 .511 .706 r
F P
0 g
s
.52976 .25986 m .52936 .26937 L .48903 .2594 L p .52 .648 .915 r
F P
0 g
s
.48903 .2594 m .48557 .25014 L .52976 .25986 L p .52 .648 .915 r
F P
0 g
s
.59734 .59356 m .58523 .57728 L .59284 .55368 L p .634 .527 .716 r
F P
0 g
s
.64536 .64013 m .63346 .63162 L .64748 .59363 L p .691 .609 .76 r
F P
0 g
s
.64748 .59363 m .66104 .59954 L .64536 .64013 L p .691 .609 .76 r
F P
0 g
s
.60757 .40265 m .59708 .4111 L .57684 .37467 L p .58 .501 .73 r
F P
0 g
s
.57684 .37467 m .58439 .36243 L .60757 .40265 L p .58 .501 .73 r
F P
0 g
s
.60779 .49483 m .59386 .49321 L .5872 .46059 L p .613 .505 .707 r
F P
0 g
s
.5872 .46059 m .59979 .45656 L .60779 .49483 L p .613 .505 .707 r
F P
0 g
s
.7011 .60639 m .68787 .60591 L .69589 .55211 L p .726 .651 .775 r
F P
0 g
s
.69589 .55211 m .71003 .55112 L .7011 .60639 L p .726 .651 .775 r
F P
0 g
s
.77926 .52982 m .76563 .5359 L .76233 .47401 L p .737 .705 .821 r
F P
0 g
s
.76233 .47401 m .77631 .46878 L .77926 .52982 L p .737 .705 .821 r
F P
0 g
s
.60943 .60818 m .59734 .59356 L .60651 .56584 L p .645 .543 .724 r
F P
0 g
s
.59284 .55368 m .60651 .56584 L .59734 .59356 L p .634 .527 .716 r
F P
0 g
s
.61243 .45251 m .59979 .45656 L .58665 .42005 L p .6 .502 .715 r
F P
0 g
s
.58665 .42005 m .59708 .4111 L .61243 .45251 L p .6 .502 .715 r
F P
0 g
s
.63346 .63162 m .62148 .62093 L .63386 .58597 L p .673 .583 .746 r
F P
0 g
s
.63386 .58597 m .64748 .59363 L .63346 .63162 L p .673 .583 .746 r
F P
0 g
s
.60651 .56584 m .59284 .55368 L .59579 .52499 L p .63 .521 .711 r
F P
0 g
s
.5698 .29413 m .56557 .30474 L .52895 .28079 L p .513 .555 .836 r
F P
0 g
s
.52895 .28079 m .52936 .26937 L .5698 .29413 L p .513 .555 .836 r
F P
0 g
s
.62148 .62093 m .60943 .60818 L .62019 .57666 L p .658 .561 .734 r
F P
0 g
s
.60651 .56584 m .62019 .57666 L .60943 .60818 L p .645 .543 .724 r
F P
0 g
s
.62019 .57666 m .63386 .58597 L .62148 .62093 L p .658 .561 .734 r
F P
0 g
s
.61009 .53214 m .59579 .52499 L .59386 .49321 L p .623 .513 .708 r
F P
0 g
s
.59386 .49321 m .60779 .49483 L .61009 .53214 L p .623 .513 .708 r
F P
0 g
s
.59579 .52499 m .61009 .53214 L .60651 .56584 L p .63 .521 .711 r
F P
0 g
s
.59967 .34109 m .59199 .35122 L .5614 .31691 L p .539 .514 .777 r
F P
0 g
s
.5614 .31691 m .56557 .30474 L .59967 .34109 L p .539 .514 .777 r
F P
0 g
s
.47844 .23791 m .48204 .243 L .43751 .25027 L p .541 .836 .999 r
F P
0 g
s
.43751 .25027 m .43023 .24631 L .47844 .23791 L p .541 .836 .999 r
F P
0 g
s
.68787 .60591 m .67451 .60364 L .68168 .55185 L p .708 .625 .763 r
F P
0 g
s
.68168 .55185 m .69589 .55211 L .68787 .60591 L p .708 .625 .763 r
F P
0 g
s
.76563 .5359 m .75189 .5412 L .74832 .47883 L p .726 .682 .807 r
F P
0 g
s
.74832 .47883 m .76233 .47401 L .76563 .5359 L p .726 .682 .807 r
F P
0 g
s
.62019 .57666 m .60651 .56584 L .61009 .53214 L p .639 .532 .717 r
F P
0 g
s
.62177 .49596 m .60779 .49483 L .59979 .45656 L p .614 .51 .712 r
F P
0 g
s
.59979 .45656 m .61243 .45251 L .62177 .49596 L p .614 .51 .712 r
F P
0 g
s
.26495 .34428 m .27901 .33607 L .25376 .38872 L p .855 .958 .874 r
F P
0 g
s
.25376 .38872 m .23884 .39683 L .26495 .34428 L p .855 .958 .874 r
F P
0 g
s
.61813 .39473 m .60757 .40265 L .58439 .36243 L p .57 .503 .741 r
F P
0 g
s
.58439 .36243 m .59199 .35122 L .61813 .39473 L p .57 .503 .741 r
F P
0 g
s
.62513 .44844 m .61243 .45251 L .59708 .4111 L p .596 .505 .721 r
F P
0 g
s
.59708 .4111 m .60757 .40265 L .62513 .44844 L p .596 .505 .721 r
F P
0 g
s
.61009 .53214 m .62442 .53835 L .62019 .57666 L p .639 .532 .717 r
F P
0 g
s
.62442 .53835 m .61009 .53214 L .60779 .49483 L p .628 .521 .712 r
F P
0 g
s
.60779 .49483 m .62177 .49596 L .62442 .53835 L p .628 .521 .712 r
F P
0 g
s
.67451 .60364 m .66104 .59954 L .6674 .55032 L p .691 .602 .751 r
F P
0 g
s
.6674 .55032 m .68168 .55185 L .67451 .60364 L p .691 .602 .751 r
F P
0 g
s
.63386 .58597 m .62019 .57666 L .62442 .53835 L p .65 .546 .724 r
F P
0 g
s
.34599 .27906 m .35717 .27452 L .31978 .31646 L p .795 .987 .891 r
F P
0 g
s
.31978 .31646 m .30643 .32192 L .34599 .27906 L p .795 .987 .891 r
F P
0 g
s
.53018 .25225 m .52976 .25986 L .48557 .25014 L p .461 .685 .962 r
F P
0 g
s
.48557 .25014 m .48204 .243 L .53018 .25225 L p .461 .685 .962 r
F P
0 g
s
.75189 .5412 m .73804 .54558 L .73428 .48316 L p .715 .659 .793 r
F P
0 g
s
.73428 .48316 m .74832 .47883 L .75189 .5412 L p .715 .659 .793 r
F P
0 g
s
.66104 .59954 m .64748 .59363 L .65309 .54752 L p .676 .581 .741 r
F P
0 g
s
.65309 .54752 m .6674 .55032 L .66104 .59954 L p .676 .581 .741 r
F P
0 g
s
.64748 .59363 m .63386 .58597 L .63876 .54351 L p .662 .562 .732 r
F P
0 g
s
.62442 .53835 m .63876 .54351 L .63386 .58597 L p .65 .546 .724 r
F P
0 g
s
.4152 .24438 m .4228 .24439 L .37884 .27015 L p .646 .956 .936 r
F P
0 g
s
.37884 .27015 m .36812 .27149 L .4152 .24438 L p .646 .956 .936 r
F P
0 g
s
.63876 .54351 m .65309 .54752 L .64748 .59363 L p .662 .562 .732 r
F P
0 g
s
.63579 .49655 m .62177 .49596 L .61243 .45251 L p .616 .515 .717 r
F P
0 g
s
.61243 .45251 m .62513 .44844 L .63579 .49655 L p .616 .515 .717 r
F P
0 g
s
.57408 .28509 m .5698 .29413 L .52936 .26937 L p .472 .57 .873 r
F P
0 g
s
.52936 .26937 m .52976 .25986 L .57408 .28509 L p .472 .57 .873 r
F P
0 g
s
.63876 .54351 m .62442 .53835 L .62177 .49596 L p .635 .53 .718 r
F P
0 g
s
.63789 .44436 m .62513 .44844 L .60757 .40265 L p .592 .508 .729 r
F P
0 g
s
.60757 .40265 m .61813 .39473 L .63789 .44436 L p .592 .508 .729 r
F P
0 g
s
.60743 .33208 m .59967 .34109 L .56557 .30474 L p .515 .519 .798 r
F P
0 g
s
.56557 .30474 m .5698 .29413 L .60743 .33208 L p .515 .519 .798 r
F P
0 g
s
.62177 .49596 m .63579 .49655 L .63876 .54351 L p .635 .53 .718 r
F P
0 g
s
.62877 .38737 m .61813 .39473 L .59199 .35122 L p .558 .506 .753 r
F P
0 g
s
.59199 .35122 m .59967 .34109 L .62877 .38737 L p .558 .506 .753 r
F P
0 g
s
.73804 .54558 m .72408 .54891 L .72023 .48694 L p .703 .638 .781 r
F P
0 g
s
.72023 .48694 m .73428 .48316 L .73804 .54558 L p .703 .638 .781 r
F P
0 g
s
.65309 .54752 m .63876 .54351 L .63579 .49655 L p .643 .541 .724 r
F P
0 g
s
.72408 .54891 m .71003 .55112 L .70615 .49014 L p .692 .618 .769 r
F P
0 g
s
.70615 .49014 m .72023 .48694 L .72408 .54891 L p .692 .618 .769 r
F P
0 g
s
.64983 .49655 m .63579 .49655 L .62513 .44844 L p .618 .522 .723 r
F P
0 g
s
.62513 .44844 m .63789 .44436 L .64983 .49655 L p .618 .522 .723 r
F P
0 g
s
.25067 .35291 m .26495 .34428 L .23884 .39683 L p .848 .97 .875 r
F P
0 g
s
.23884 .39683 m .22376 .40525 L .25067 .35291 L p .848 .97 .875 r
F P
0 g
s
.63579 .49655 m .64983 .49655 L .65309 .54752 L p .643 .541 .724 r
F P
0 g
s
.6674 .55032 m .65309 .54752 L .64983 .49655 L p .651 .553 .731 r
F P
0 g
s
.71003 .55112 m .69589 .55211 L .69207 .49272 L p .681 .599 .758 r
F P
0 g
s
.69207 .49272 m .70615 .49014 L .71003 .55112 L p .681 .599 .758 r
F P
0 g
s
.47477 .23479 m .47844 .23791 L .43023 .24631 L p .434 .846 .966 r
F P
0 g
s
.43023 .24631 m .4228 .24439 L .47477 .23479 L p .434 .846 .966 r
F P
0 g
s
.65071 .44025 m .63789 .44436 L .61813 .39473 L p .588 .513 .737 r
F P
0 g
s
.61813 .39473 m .62877 .38737 L .65071 .44025 L p .588 .513 .737 r
F P
0 g
s
.68168 .55185 m .6674 .55032 L .6639 .49592 L p .66 .567 .739 r
F P
0 g
s
.64983 .49655 m .6639 .49592 L .6674 .55032 L p .651 .553 .731 r
F P
0 g
s
.69589 .55211 m .68168 .55185 L .67799 .49464 L p .67 .582 .748 r
F P
0 g
s
.67799 .49464 m .69207 .49272 L .69589 .55211 L p .67 .582 .748 r
F P
0 g
s
.6639 .49592 m .67799 .49464 L .68168 .55185 L p .66 .567 .739 r
F P
0 g
s
.63949 .38059 m .62877 .38737 L .59967 .34109 L p .543 .509 .768 r
F P
0 g
s
.59967 .34109 m .60743 .33208 L .63949 .38059 L p .543 .509 .768 r
F P
0 g
s
.6639 .49592 m .64983 .49655 L .63789 .44436 L p .62 .53 .73 r
F P
0 g
s
.63789 .44436 m .65071 .44025 L .6639 .49592 L p .62 .53 .73 r
F P
0 g
s
.5306 .24648 m .53018 .25225 L .48204 .243 L p .359 .704 .985 r
F P
0 g
s
.48204 .243 m .47844 .23791 L .5306 .24648 L p .359 .704 .985 r
F P
0 g
s
.61529 .3242 m .60743 .33208 L .5698 .29413 L p .483 .524 .823 r
F P
0 g
s
.5698 .29413 m .57408 .28509 L .61529 .3242 L p .483 .524 .823 r
F P
0 g
s
.33457 .28488 m .34599 .27906 L .30643 .32192 L p .766 .995 .863 r
F P
0 g
s
.30643 .32192 m .29284 .32853 L .33457 .28488 L p .766 .995 .863 r
F P
0 g
s
.57844 .27762 m .57408 .28509 L .52976 .25986 L p .41 .583 .911 r
F P
0 g
s
.52976 .25986 m .53018 .25225 L .57844 .27762 L p .41 .583 .911 r
F P
0 g
s
.40743 .24612 m .4152 .24438 L .36812 .27149 L p .559 .935 .86 r
F P
0 g
s
.36812 .27149 m .35717 .27452 L .40743 .24612 L p .559 .935 .86 r
F P
0 g
s
.67799 .49464 m .6639 .49592 L .65071 .44025 L p .623 .538 .738 r
F P
0 g
s
.66359 .43613 m .65071 .44025 L .62877 .38737 L p .582 .518 .748 r
F P
0 g
s
.62877 .38737 m .63949 .38059 L .66359 .43613 L p .582 .518 .748 r
F P
0 g
s
.65071 .44025 m .66359 .43613 L .67799 .49464 L p .623 .538 .738 r
F P
0 g
s
.69207 .49272 m .67799 .49464 L .66359 .43613 L p .626 .548 .747 r
F P
0 g
s
.23619 .36166 m .25067 .35291 L .22376 .40525 L p .837 .978 .878 r
F P
0 g
s
.22376 .40525 m .20853 .41376 L .23619 .36166 L p .837 .978 .878 r
F P
0 g
s
.6503 .37439 m .63949 .38059 L .60743 .33208 L p .526 .513 .784 r
F P
0 g
s
.60743 .33208 m .61529 .3242 L .6503 .37439 L p .526 .513 .784 r
F P
0 g
s
.70615 .49014 m .69207 .49272 L .67653 .43199 L p .629 .559 .757 r
F P
0 g
s
.66359 .43613 m .67653 .43199 L .69207 .49272 L p .626 .548 .747 r
F P
0 g
s
.67653 .43199 m .66359 .43613 L .63949 .38059 L p .576 .524 .759 r
F P
0 g
s
.72023 .48694 m .70615 .49014 L .68953 .42783 L p .632 .571 .769 r
F P
0 g
s
.67653 .43199 m .68953 .42783 L .70615 .49014 L p .629 .559 .757 r
F P
0 g
s
.62324 .31743 m .61529 .3242 L .57408 .28509 L p .442 .529 .851 r
F P
0 g
s
.57408 .28509 m .57844 .27762 L .62324 .31743 L p .442 .529 .851 r
F P
0 g
s
.63949 .38059 m .6503 .37439 L .67653 .43199 L p .576 .524 .759 r
F P
0 g
s
.47101 .23351 m .47477 .23479 L .4228 .24439 L p .282 .783 .846 r
F P
0 g
s
.4228 .24439 m .4152 .24438 L .47101 .23351 L p .282 .783 .846 r
F P
0 g
s
.73428 .48316 m .72023 .48694 L .70259 .42365 L p .635 .585 .781 r
F P
0 g
s
.68953 .42783 m .70259 .42365 L .72023 .48694 L p .632 .571 .769 r
F P
0 g
s
.58287 .27166 m .57844 .27762 L .53018 .25225 L p .319 .587 .94 r
F P
0 g
s
.53018 .25225 m .5306 .24648 L .58287 .27166 L p .319 .587 .94 r
F P
0 g
s
.74832 .47883 m .73428 .48316 L .71571 .41944 L p .639 .6 .794 r
F P
0 g
s
.70259 .42365 m .71571 .41944 L .73428 .48316 L p .635 .585 .781 r
F P
0 g
s
.53103 .24247 m .5306 .24648 L .47844 .23791 L p .203 .676 .937 r
F P
0 g
s
.47844 .23791 m .47477 .23479 L .53103 .24247 L p .203 .676 .937 r
F P
0 g
s
.85986 .43317 m .84595 .43919 L .82291 .38512 L p .656 .751 .92 r
F P
0 g
s
.82291 .38512 m .8366 .38074 L .85986 .43317 L p .656 .751 .92 r
F P
0 g
s
.84595 .43919 m .83205 .44528 L .80929 .38948 L p .656 .732 .906 r
F P
0 g
s
.80929 .38948 m .82291 .38512 L .84595 .43919 L p .656 .732 .906 r
F P
0 g
s
.76233 .47401 m .74832 .47883 L .72889 .41522 L p .642 .616 .809 r
F P
0 g
s
.71571 .41944 m .72889 .41522 L .74832 .47883 L p .639 .6 .794 r
F P
0 g
s
.83205 .44528 m .81814 .45138 L .79573 .39382 L p .655 .712 .89 r
F P
0 g
s
.79573 .39382 m .80929 .38948 L .83205 .44528 L p .655 .712 .89 r
F P
0 g
s
.81814 .45138 m .80421 .45738 L .78224 .39815 L p .654 .692 .873 r
F P
0 g
s
.78224 .39815 m .79573 .39382 L .81814 .45138 L p .654 .692 .873 r
F P
0 g
s
.3229 .29174 m .33457 .28488 L .29284 .32853 L p .73 .99 .83 r
F P
0 g
s
.29284 .32853 m .27901 .33607 L .3229 .29174 L p .73 .99 .83 r
F P
0 g
s
.77631 .46878 m .76233 .47401 L .74213 .41098 L p .646 .634 .824 r
F P
0 g
s
.72889 .41522 m .74213 .41098 L .76233 .47401 L p .642 .616 .809 r
F P
0 g
s
.80421 .45738 m .79027 .46321 L .76881 .40245 L p .652 .672 .857 r
F P
0 g
s
.76881 .40245 m .78224 .39815 L .80421 .45738 L p .652 .672 .857 r
F P
0 g
s
.79027 .46321 m .77631 .46878 L .75544 .40673 L p .649 .653 .84 r
F P
0 g
s
.74213 .41098 m .75544 .40673 L .77631 .46878 L p .646 .634 .824 r
F P
0 g
s
.75544 .40673 m .76881 .40245 L .79027 .46321 L p .649 .653 .84 r
F P
0 g
s
.68953 .42783 m .67653 .43199 L .6503 .37439 L p .57 .53 .772 r
F P
0 g
s
.66122 .36878 m .6503 .37439 L .61529 .3242 L p .505 .517 .802 r
F P
0 g
s
.61529 .3242 m .62324 .31743 L .66122 .36878 L p .505 .517 .802 r
F P
0 g
s
.22154 .37026 m .23619 .36166 L .20853 .41376 L p .825 .982 .882 r
F P
0 g
s
.20853 .41376 m .19318 .42214 L .22154 .37026 L p .825 .982 .882 r
F P
0 g
s
.40743 .24612 m .35717 .27452 L p .39672 .25104 L .458 .877 .757 r
F P
0 g
s
.35717 .27452 m .34599 .27906 L .39947 .2494 L p .458 .877 .757 r
F P
0 g
s
.39132 .25401 m .39947 .2494 L .38952 .25492 L p .365 .806 .654 r
F P
0 g
s
.38952 .25492 m .34599 .27906 L p .37356 .26382 L .365 .806 .654 r
F P
0 g
s
.37356 .26382 m .39132 .25401 L .38952 .25492 L .365 .806 .654 r
F
.3229 .29174 m .33715 .28414 L p .33459 .28487 L 0 0 0 r
F P
0 g
s
.33715 .28414 m .38298 .25968 L p .35321 .27518 L 0 0 0 r
F P
0 g
s
.34599 .27906 m .33457 .28488 L .39132 .25401 L p .365 .806 .654 r
F P
0 g
s
.33459 .28487 m .33715 .28414 L .35321 .27518 L 0 0 0 r
F
.33457 .28488 m .33456 .28489 L p .33459 .28487 L F P
0 g
s
.33456 .28489 m .3229 .29174 L p .33459 .28487 L 0 0 0 r
F P
0 g
s
.39947 .2494 m .4005 .24898 L p .39672 .25104 L .458 .877 .757 r
F P
0 g
s
.4005 .24898 m .40743 .24612 L p .39672 .25104 L .458 .877 .757 r
F P
0 g
s
.6503 .37439 m .66122 .36878 L .68953 .42783 L p .57 .53 .772 r
F P
0 g
s
.70259 .42365 m .68953 .42783 L .66122 .36878 L p .563 .538 .786 r
F P
0 g
s
.63131 .31174 m .62324 .31743 L .57844 .27762 L p .388 .531 .878 r
F P
0 g
s
.57844 .27762 m .58287 .27166 L .63131 .31174 L p .388 .531 .878 r
F P
0 g
s
.71571 .41944 m .70259 .42365 L .67224 .36372 L p .555 .548 .801 r
F P
0 g
s
.66122 .36878 m .67224 .36372 L .70259 .42365 L p .563 .538 .786 r
F P
0 g
s
.67224 .36372 m .66122 .36878 L .62324 .31743 L p .481 .521 .822 r
F P
0 g
s
.46715 .2339 m .47101 .23351 L .4152 .24438 L p 0 0 0 r
F P
0 g
s
.4152 .24438 m .40743 .24612 L .46715 .2339 L p 0 0 0 r
F P
0 g
s
.62324 .31743 m .63131 .31174 L .67224 .36372 L p .481 .521 .822 r
F P
0 g
s
.58739 .26715 m .58287 .27166 L .5306 .24648 L p .191 .57 .938 r
F P
0 g
s
.5306 .24648 m .53103 .24247 L .58739 .26715 L p .191 .57 .938 r
F P
0 g
s
.53148 .24011 m .53103 .24247 L .47477 .23479 L p .022 .585 .8 r
F P
0 g
s
.47477 .23479 m .47101 .23351 L .53148 .24011 L p .022 .585 .8 r
F P
0 g
s
.311 .29936 m .3229 .29174 L .27901 .33607 L p .694 .978 .8 r
F P
0 g
s
.27901 .33607 m .26495 .34428 L .311 .29936 L p .694 .978 .8 r
F P
0 g
s
.72889 .41522 m .71571 .41944 L .68337 .3592 L p .546 .558 .818 r
F P
0 g
s
.67224 .36372 m .68337 .3592 L .71571 .41944 L p .555 .548 .801 r
F P
0 g
s
.68337 .3592 m .67224 .36372 L .63131 .31174 L p .452 .526 .843 r
F P
0 g
s
.6395 .30708 m .63131 .31174 L .58287 .27166 L p .319 .529 .901 r
F P
0 g
s
.58287 .27166 m .58739 .26715 L .6395 .30708 L p .319 .529 .901 r
F P
0 g
s
.74213 .41098 m .72889 .41522 L .69462 .35517 L p .538 .57 .836 r
F P
0 g
s
.68337 .3592 m .69462 .35517 L .72889 .41522 L p .546 .558 .818 r
F P
0 g
s
.63131 .31174 m .6395 .30708 L .68337 .3592 L p .452 .526 .843 r
F P
0 g
s
.75544 .40673 m .74213 .41098 L .70599 .35158 L p .529 .584 .854 r
F P
0 g
s
.69462 .35517 m .70599 .35158 L .74213 .41098 L p .538 .57 .836 r
F P
0 g
s
.59199 .26398 m .58739 .26715 L .53103 .24247 L p .035 .519 .881 r
F P
0 g
s
.53103 .24247 m .53148 .24011 L .59199 .26398 L p .035 .519 .881 r
F P
0 g
s
.69462 .35517 m .68337 .3592 L .6395 .30708 L p .42 .532 .865 r
F P
0 g
s
.46321 .23578 m .46715 .2339 L .40743 .24612 L p 0 0 0 r
F P
0 g
s
.40743 .24612 m .39947 .2494 L .46321 .23578 L p 0 0 0 r
F P
0 g
s
.29887 .30744 m .311 .29936 L .26495 .34428 L p .662 .965 .776 r
F P
0 g
s
.26495 .34428 m .25067 .35291 L .29887 .30744 L p .662 .965 .776 r
F P
0 g
s
.53193 .23925 m .53148 .24011 L .47101 .23351 L p .133 0 0 r
F P
0 g
s
.47101 .23351 m .46715 .2339 L .53193 .23925 L p .133 0 0 r
F P
0 g
s
.76881 .40245 m .75544 .40673 L .71748 .34836 L p .52 .599 .873 r
F P
0 g
s
.70599 .35158 m .71748 .34836 L .75544 .40673 L p .529 .584 .854 r
F P
0 g
s
.64782 .30337 m .6395 .30708 L .58739 .26715 L p .234 .519 .913 r
F P
0 g
s
.58739 .26715 m .59199 .26398 L .64782 .30337 L p .234 .519 .913 r
F P
0 g
s
.6395 .30708 m .64782 .30337 L .69462 .35517 L p .42 .532 .865 r
F P
0 g
s
.38298 .25968 m .39132 .25401 L .33457 .28488 L p 0 0 0 r
F P
0 g
s
.78224 .39815 m .76881 .40245 L .7291 .34545 L p .512 .615 .892 r
F P
0 g
s
.71748 .34836 m .7291 .34545 L .76881 .40245 L p .52 .599 .873 r
F P
0 g
s
.70599 .35158 m .69462 .35517 L .64782 .30337 L p .383 .537 .885 r
F P
0 g
s
.79573 .39382 m .78224 .39815 L .74084 .34278 L p .504 .633 .91 r
F P
0 g
s
.7291 .34545 m .74084 .34278 L .78224 .39815 L p .512 .615 .892 r
F P
0 g
s
.59669 .26204 m .59199 .26398 L .53148 .24011 L p 0 .439 .772 r
F P
0 g
s
.53148 .24011 m .53193 .23925 L .59669 .26204 L p 0 .439 .772 r
F P
0 g
s
.27399 .32374 m .28653 .31568 L .23619 .36166 L p .625 .95 .767 r
F P
0 g
s
.28653 .31568 m .27399 .32374 L .27477 .32336 L p 0 0 0 r
F P
0 g
s
.29828 .308 m .25067 .35291 L p .28653 .31568 L .638 .955 .765 r
F P
0 g
s
.25067 .35291 m .23619 .36166 L .28653 .31568 L p .638 .955 .765 r
F P
0 g
s
.27477 .32336 m .34782 .287 L p .28653 .31568 L 0 0 0 r
F P
0 g
s
.28653 .31568 m .29887 .30744 L .29828 .308 L p .638 .955 .765 r
F P
0 g
s
.64782 .30337 m .65627 .30053 L .70599 .35158 L p .383 .537 .885 r
F P
0 g
s
.65627 .30053 m .64782 .30337 L .59199 .26398 L p .136 .499 .907 r
F P
0 g
s
.71748 .34836 m .70599 .35158 L .65627 .30053 L p .344 .542 .903 r
F P
0 g
s
.80929 .38948 m .79573 .39382 L .75271 .34026 L p .499 .652 .927 r
F P
0 g
s
.74084 .34278 m .75271 .34026 L .79573 .39382 L p .504 .633 .91 r
F P
0 g
s
.45917 .23891 m .46321 .23578 L .39947 .2494 L p .074 0 0 r
F P
0 g
s
.39947 .2494 m .39132 .25401 L .45917 .23891 L p .074 0 0 r
F P
0 g
s
.53239 .23971 m .53193 .23925 L .46715 .2339 L p .238 0 0 r
F P
0 g
s
.46715 .2339 m .46321 .23578 L .53239 .23971 L p .238 0 0 r
F P
0 g
s
.59199 .26398 m .59669 .26204 L .65627 .30053 L p .136 .499 .907 r
F P
0 g
s
.82291 .38512 m .80929 .38948 L .76469 .3378 L p .496 .672 .942 r
F P
0 g
s
.75271 .34026 m .76469 .3378 L .80929 .38948 L p .499 .652 .927 r
F P
0 g
s
.37445 .26613 m .38298 .25968 L .3229 .29174 L p 0 0 0 r
F P
0 g
s
.3229 .29174 m .311 .29936 L .37445 .26613 L p 0 0 0 r
F P
0 g
s
.7291 .34545 m .71748 .34836 L .66486 .29843 L p .305 .548 .918 r
F P
0 g
s
.65627 .30053 m .66486 .29843 L .71748 .34836 L p .344 .542 .903 r
F P
0 g
s
.8366 .38074 m .82291 .38512 L .7768 .33533 L p .497 .692 .955 r
F P
0 g
s
.76469 .3378 m .7768 .33533 L .82291 .38512 L p .496 .672 .942 r
F P
0 g
s
.66486 .29843 m .65627 .30053 L .59669 .26204 L p .034 .47 .88 r
F P
0 g
s
.23619 .36166 m .22154 .37026 L .27399 .32374 L p .625 .95 .767 r
F P
0 g
s
.60148 .26116 m .59669 .26204 L .53193 .23925 L p .243 0 0 r
F P
0 g
s
.53193 .23925 m .53239 .23971 L .60148 .26116 L p .243 0 0 r
F P
0 g
s
.7768 .33533 m .78901 .33274 L .8366 .38074 L p .497 .692 .955 r
F P
0 g
s
.59669 .26204 m .60148 .26116 L .66486 .29843 L p .034 .47 .88 r
F P
0 g
s
.45503 .24306 m .45917 .23891 L .39132 .25401 L p .124 0 0 r
F P
0 g
s
.39132 .25401 m .38298 .25968 L .45503 .24306 L p .124 0 0 r
F P
0 g
s
.74084 .34278 m .7291 .34545 L .67358 .29696 L p .268 .554 .929 r
F P
0 g
s
.66486 .29843 m .67358 .29696 L .7291 .34545 L p .305 .548 .918 r
F P
0 g
s
.53286 .24128 m .53239 .23971 L .46321 .23578 L p .301 0 0 r
F P
0 g
s
.46321 .23578 m .45917 .23891 L .53286 .24128 L p .301 0 0 r
F P
0 g
s
.36574 .27305 m .37445 .26613 L .311 .29936 L p 0 0 0 r
F P
0 g
s
.311 .29936 m .29887 .30744 L .36574 .27305 L p 0 0 0 r
F P
0 g
s
.67358 .29696 m .66486 .29843 L .60148 .26116 L p 0 .435 .834 r
F P
0 g
s
.75271 .34026 m .74084 .34278 L .68245 .29596 L p .237 .562 .936 r
F P
0 g
s
.67358 .29696 m .68245 .29596 L .74084 .34278 L p .268 .554 .929 r
F P
0 g
s
.60637 .26118 m .60148 .26116 L .53239 .23971 L p .325 0 0 r
F P
0 g
s
.53239 .23971 m .53286 .24128 L .60637 .26118 L p .325 0 0 r
F P
0 g
s
.60148 .26116 m .60637 .26118 L .67358 .29696 L p 0 .435 .834 r
F P
0 g
s
.45079 .24794 m .45503 .24306 L .38298 .25968 L p .151 0 0 r
F P
0 g
s
.38298 .25968 m .37445 .26613 L .45079 .24794 L p .151 0 0 r
F P
0 g
s
.76469 .3378 m .75271 .34026 L .69146 .29529 L p .215 .573 .941 r
F P
0 g
s
.68245 .29596 m .69146 .29529 L .75271 .34026 L p .237 .562 .936 r
F P
0 g
s
.53335 .24374 m .53286 .24128 L .45917 .23891 L p .336 0 0 r
F P
0 g
s
.45917 .23891 m .45503 .24306 L .53335 .24374 L p .336 0 0 r
F P
0 g
s
.68245 .29596 m .67358 .29696 L .60637 .26118 L p 0 .403 .783 r
F P
0 g
s
.35686 .28012 m .36574 .27305 L .29887 .30744 L p 0 0 0 r
F P
0 g
s
.29887 .30744 m .28653 .31568 L .35686 .28012 L p 0 0 0 r
F P
0 g
s
.7768 .33533 m .76469 .3378 L .7006 .29479 L p .207 .588 .945 r
F P
0 g
s
.69146 .29529 m .7006 .29479 L .76469 .3378 L p .215 .573 .941 r
F P
0 g
s
.61136 .2619 m .60637 .26118 L .53286 .24128 L p .372 0 0 r
F P
0 g
s
.53286 .24128 m .53335 .24374 L .61136 .2619 L p .372 0 0 r
F P
0 g
s
.60637 .26118 m .61136 .2619 L .68245 .29596 L p 0 .403 .783 r
F P
0 g
s
.69146 .29529 m .68245 .29596 L .61136 .2619 L p 0 .381 .737 r
F P
0 g
s
.44646 .25325 m .45079 .24794 L .37445 .26613 L p .16 0 0 r
F P
0 g
s
.37445 .26613 m .36574 .27305 L .44646 .25325 L p .16 0 0 r
F P
0 g
s
.78901 .33274 m .7768 .33533 L .70987 .29429 L p .213 .609 .95 r
F P
0 g
s
.7006 .29479 m .70987 .29429 L .7768 .33533 L p .207 .588 .945 r
F P
0 g
s
.53384 .24683 m .53335 .24374 L .45503 .24306 L p .351 0 0 r
F P
0 g
s
.45503 .24306 m .45079 .24794 L .53384 .24683 L p .351 0 0 r
F P
0 g
s
.34782 .287 m .35686 .28012 L .28653 .31568 L p 0 0 0 r
F P
0 g
s
.61136 .2619 m .61645 .26312 L .69146 .29529 L p 0 .381 .737 r
F P
0 g
s
.61645 .26312 m .61136 .2619 L .53335 .24374 L p .394 0 0 r
F P
0 g
s
.7006 .29479 m .69146 .29529 L .61645 .26312 L p 0 .374 .706 r
F P
0 g
s
.70987 .29429 m .71927 .29362 L .78901 .33274 L p .213 .609 .95 r
F P
0 g
s
.53335 .24374 m .53384 .24683 L .61645 .26312 L p .394 0 0 r
F P
0 g
s
.44204 .25869 m .44646 .25325 L .36574 .27305 L p .154 0 0 r
F P
0 g
s
.36574 .27305 m .35686 .28012 L .44204 .25869 L p .154 0 0 r
F P
0 g
s
.53435 .25028 m .53384 .24683 L .45079 .24794 L p .351 0 0 r
F P
0 g
s
.45079 .24794 m .44646 .25325 L .53435 .25028 L p .351 0 0 r
F P
0 g
s
.70987 .29429 m .7006 .29479 L .62163 .2646 L p 0 .383 .694 r
F P
0 g
s
.61645 .26312 m .62163 .2646 L .7006 .29479 L p 0 .374 .706 r
F P
0 g
s
.62163 .2646 m .61645 .26312 L .53384 .24683 L p .396 0 0 r
F P
0 g
s
.53384 .24683 m .53435 .25028 L .62163 .2646 L p .396 0 0 r
F P
0 g
s
.71927 .29362 m .70987 .29429 L .6269 .26612 L p 0 .411 .704 r
F P
0 g
s
.6269 .26612 m .70987 .29429 L p .62272 .26497 L 0 .383 .694 r
F P
0 g
s
.6269 .26612 m .63227 .26744 L .71927 .29362 L p 0 .411 .704 r
F P
0 g
s
.6269 .26612 m .53486 .25381 L p .63108 .26727 L .352 0 0 r
F P
0 g
s
.63227 .26744 m .6269 .26612 L p .63108 .26727 L .352 0 0 r
F P
0 g
s
.62163 .2646 m .6269 .26612 L p .62272 .26497 L 0 .383 .694 r
F P
0 g
s
.43754 .26392 m .44204 .25869 L .35686 .28012 L p .133 0 0 r
F P
0 g
s
.35686 .28012 m .34782 .287 L .43754 .26392 L p .133 0 0 r
F P
0 g
s
.53486 .25381 m .53435 .25028 L .44646 .25325 L p .338 0 0 r
F P
0 g
s
.44646 .25325 m .44204 .25869 L .53486 .25381 L p .338 0 0 r
F P
0 g
s
.6269 .26612 m .62163 .2646 L .53435 .25028 L p .382 0 0 r
F P
0 g
s
.53435 .25028 m .53486 .25381 L .6269 .26612 L p .382 0 0 r
F P
0 g
s
.53539 .25714 m .53486 .25381 L .44204 .25869 L p .312 0 0 r
F P
0 g
s
.44204 .25869 m .43754 .26392 L .53539 .25714 L p .312 0 0 r
F P
0 g
s
.53486 .25381 m .53539 .25714 L .63227 .26744 L p .352 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`0007Kooooo2Ol00015ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@02cooooo
000kooooo`;o0000M?oooolHo`0003_ooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00>?ooool3o`000003ooooool0003ooooo06kooooo5_l0
00000om=003o0000o`00000;o`0003Cooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooo
ool00004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003Kooooo0_l0001_ooooobco0000
<Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000KOoo
ool6o`000003oa800?l0003o000000Ko000000?o9P00o`000?mI00003OmI000Do`0002kooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`00<Oooool2o`0006gooooo1?l00002
oa8000So00000_lV000Zo`0002[ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`00;_ooool3o`000003ooooool0003ooooo06[ooooo3?l00002obH000Co00000_lX00000ol0
003oF@00oeT0000;oeT001go00009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
037ooooo000]ooooo`;o00001?ooool00ol0003oooooooooo`1Wooooo`Co000000?o7`00o`000?l0
00000_l00002obH000Co00000olX000ao`0002Cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0`ooooo`00;Oooool00ol0003oooooo`00001[ooooo`Oo000000?o9P00o`000?l00000
0ol00002obP001Go00001om?000Oo`0001oooooo00?o0000ooooooooool0;Oooool3o`00037ooooo
000]ooooo`04o`000?ooooooooooo`0006Sooooo1Ol000000olV003o0000o`000002o`0000?o:000
1ol00002ob800003o`000?m?003oC`0000CoC`004?l00005ohFUjP;o00001?mXUNT2o`000003oe6F
l?l0003o000001?o00006oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo
000]ooooo`05o`000?ooooooooooooooool00000I_ooool7o`0000;o:0002?l00003ob8000go0000
1_nOZ]h00ol0003oSIcMohfLg@05o`0000GoQJGZ00?o0000ogRAgomXUNT01?mXUNT2o`0000?oDIK`
0_l00002oc2Al13o00006?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1Qooooo`Go00000_lX0008o`0000?o8P001?l0
0004ok>mh@03o`000?n_[]Oo000000goWj[N00?o0000ohfLgOn=W=d01?n=W=d4o`000003ohFUj_l0
003oN97O00;oN97O00?o0000ofREjOmXUNT00_mXUNT2o`0000?oDIK`0_l00003oc2Al005o`000?lk
Q>Wo>hCYoc^4jOlROnP01?l8N>400ol0KmGo0000o`000006o`0001?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05kooooo3Ol00004ob8000?o000000?o]lg[o`000?nc_N400onc_N42o`0000?o[jkG00?o
0000oinZg_nOZ]h01onOZ]h4o`0000[oSIcM0_l00005ogRAg`;o00000omXUNT2o`0000?oDIK`0_l0
00000ol`TO3o0000oe67iP03oc^4j@03o`000?lROnSo27SQ00;o27SQ00Ko0000o`1_eOl0IlSo06O8
o`000?l0Gk@2o`1Y]0?o00004?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02go
oooo000/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G?ooool5o`000003obL0
0?l0003o000000;o00001?lR0004o`0000?o]lg[00?o0000ok>mhOnc_N400_nc_N400ol0003o[jkG
ojn^e`04ojn^e`04o`000?nOZ]koWj[NoinZgPGo00000onOW]<00ol0003oTYGBoi:EdP03o`0000Ko
SIcM00?o0000oh>>e_l000001OmhTMl00ol0003oJ9GYofREj@02ofREj@03o`000?mAU_3oDIK`00;o
DIK`00Go0000oe67i_mAQnKoDHOVo`000002oc^4j@03o`000?lROnSo000000?o27SQ0_l00002o`1W
b0;o000000?o05ndo`1Y]?l0JK@00ol0000=ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0;?ooool002cooooo0ol00006ooooo`03o`000?oooooooooo05Wooooo2?l00004ob8000Go
000000?o`/?Jo`000?l000000_ngcN/5ok>mh@03o`000?n_[]Oo[jkG00Go[jkG1?l00008oinNd`03
o`000?nBUM;oTYGB00?oTYGB0ol00003ohfLg@03o`000?n3S]KoPhkF00;o00001?mhTMl2o`0000?o
J9GY0_l000001?mAU_3o0000of>7h?mSQn03oe67iP07o`000?lkQ>Wo>hCYoc^4jOl0003o8WoXo`00
0003o`Qhh@;o00000_l0IlP2o`000004o`1O]?l0003o06Vdo`1Y]0?o00002_ooool00ol0003ooooo
ooooo`0booooo`;o0000;Oooool002cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Fooooo`Ko00001?lR0004o`0000?ob=7P00?o0000ol;3f_o2`mX00_o2`mX2o`0000Co/kgQ00?o
0000ojn^eon_[]L01?n_[]L2o`000003oj^Scol0003oWikC00[oWikC00?o0000oi:Ed_nBUM801OnB
UM84o`0000CoPhkF0_l00004ogRAg`;o00000omXUNT00ol0003oHhOPof>7h002of>7h0CoDHOV00?o
0000oc^4jOlkQ>T00_l000001?lROnSo0000o`QhhOl8N>43o`0000;o06O800Co0000o`1Q_?l0003o
05nd0_l000001?l0JKCo0000o`000?l00007ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0:oooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1C
ooooo`Ko00000olR0003o`0000;ocMoU00Go0000olSAh?o8dN3ob=7Po`000005ol;3fP03o`000?nl
]]?o000000;o/kgQ1on_[]L00ol0003oZj??oj^Sc`02oj^Sc`03o`000?nOW]?oWikC00SoWikC00?o
0000oi:Ed_nBUM802?nBUM800ol0003oPhkFoh>>eP04oh>>eP03o`000?mhTMooN97O00?oN97O0_l0
00000omXUNWo0000og67f@04of>7h005o`000?mAQnKoDHOVoe67i_l000000olkQ>T01?l0003o8WoX
o`000?l00002o`Qhh@03o`000?l0KmGo000000?o000000?o066lo`000?l000000ol000001?l0JKCo
0000o`000?l00005ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool;o`000003om3/j?l0003ocMoU
00;ocMoU00Co0000olSAh?o8dN3o00001Oo2`mX01Ol0003o_;KCokbfdonl]]?o000000Ko[jkG0_l0
0005oj^Sc`03o`000?nOW]?oWikC00?oWikC1_l0000:oi:EdP03o`000?n:R/go000000GoPhkF0_l0
0005ogRAg`04o`000?maQmWoLHOIog67f@CoHhOP00Co0000oe67i_mAQnKoDHOV0_l00002oc^4j@03
o`000?lROnSo8WoX00;o00000_l8N>400ol0003o06oEo`000003o`0000;o066l1Ol000001?l0JKCo
0000o`000?l00002ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wo
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02oooo
o`?o00002oooool00ol0003oooooooooo`1=ooooo`Wo000000GocoKXo`000?o@k>Sod>cXo`000003
olgOi@05o`000?o8dN3ob=7PolSAh?l000001?o2`mX00ol0003o_;KCokbfd`02okbfd`;o00000on_
[]L2o`0000OoZj??1_l00005oinFb`03o`000?nFSl[oUXo:00Co00001?nBUM800ol0003oRX[=ohZ:
c@02o`0000GoPhkF0_l00003ogRAg`;o00000omaQmT01Ol0003oHhOPof>7h?mSQn3o000000CoDHOV
00?o0000oc^4jOlkQ>T00_l00002ob9oj003o`000?l8N>7o27SQ00;o000000?o06oEo`000?l0IlP0
0_l00002o`1Q_0;o000000?o05ndo`000?l000001Ol0000fooooo`03o`000?oooooooooo02Wooooo
000Aooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0B_ooool9o`0000;ocoKX00Co0000om3/j?o@k>So
00000oo=gnD01Ol0003ob=7PolSAh?o8dN3o000000Co`/?J00?o0000okbfdonl]]<00_nl]]<01?l0
003o]Z_=okJ[cOl00002ojn^e`OoZj??0_l000000onWVLOo0000oinFb`08oinFb`03o`000?nFSl[o
UXo:00CoUXo:0ol000000onBUM;o0000ohZ:c@03ohZ:c@03o`000?n3S]KoPhkF00CoPhkF00?o0000
ogRAgol000000_mkQ]801Ol0003oLHOIog67fOmaQmWo000000?oHhOP0_l00003oe67iP05o`000?lk
Q>Wo>hCYoc^4jOl000000_lROnP2o`0000;o27SQ1?l000000ol0IlSo0000o`000002o`1Q_0_o0000
=?ooool00ol0003oooooooooo`0Xooooo`004Oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0B?ooool7o`000005ol_li?l0003ocoKXolofj?l000000oo@k>P01?l0003ocMoUolgOiOl00003
olSAh003o`000?o2`m[o`/?J00;o`/?J00?o0000okbfdonl]]<00_nl]]<00ol0003o]Z_=okJ[c@02
okJ[c@03o`000?n[XlooZj??00CoZj??0_l00004ojNIa`03o`000?nOU/_oWiK;00OoWiK;00?o0000
oiJ?b_nFSlX01_nFSlX2o`0000GoRX[=0_l00005oh>>eP03o`000?mkQ];oNhKB00;oNhKB00Go0000
og67fOmaQmWoLHOIo`000004of>7h005o`000?mAQnKoDHOVoe67i_l000000olkQ>T2o`0000;o8WoX
0_l00002o`Qhh@05o`000?l0KmGo0000o`000?l0IlP00_l00002o`1Q_0co0000<Oooool2o`0002Wo
oooo000Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool7o`000005ol_li?l0003ocoKXolof
j?l000000oo@k>P01?l0003ocMoUolgOiOl00003olSAh003o`000?o2`m[o`/?J00;o`/?J00?o0000
okbfdonl]]<00_nl]]<00ol0003o]Z_=okJ[c@03okJ[c@;o00001?n[Xll00ol0003oYiW7ojNIa`04
ojNIa`03o`000?nOU/_oWiK;00OoWiK;00?o0000oiJ?b_nFSlX01onFSlX00ol0003oShO6o`000005
ohZ:c@03o`000?n3S]KoPhkF00;oPhkF0_l00004og^6dP04o`000?maQmWoLHOIog67f@;o00000omS
Qn001?l0003oDHOVoe67i_mAQnH2o`0000?o>hCY00Ko0000ob9oj?lROnSo8WoXo`000?l8N>49o`00
00?o?8o_0_lgT_001?l0003o=9KaocBFlOldU_43ocJKl`;o0000;oooool2o`0002Wooooo000Aoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00004?ooool0
0ol0003oooooooooo`13ooooo`Ko000000Coa?kLo`000?o;o>Co00000_o?m^P01Ol0003od>cXom3/
j?o@k>So000000?ocMoU00Go0000olSAh?o8dN3ob=7Po`000004ol;3fP03o`000?nl]]?o_;KC00;o
_;KC00?o0000okJ[cOnfZld00_nfZld01?l0003o/J78ok6Qb?l00002oj^Sc`03o`000?nWVLOoYiW7
00GoYiW700?o0000oinFbonOU//00onOU//5o`0000WoUXo:00Co0000ohn7a_n?QlKo00001On:R/d2
o`0000;oPhkF00?o0000oh>4c?l000001?mkQ]800ol0003oLHOIog67f@02og67f@05o`000?mSQn3o
HhOPof>7h?l000001?mAQnH01Ol0003o>hCYoc^4jOlkQ>Wo000000;o8WoX0_l00003oeR:i`?oCXc[
0om4SNd4ocb?k`;o000000Go=i;`o`000?ldU_7o=9Kao`000003ocJKl`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool09_ooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0@ooooo`;o0000@Oooool6o`0000;oa?kL00?o0000ol_li?l0
00000_o?m^P01Ol0003od>cXom3/j?o@k>So000000?ocMoU00Go0000olSAh?o8dN3ob=7Po`000004
ol;3fP03o`000?nl]]?o_;KC00;o_;KC00?o0000okJ[cOnfZld00_nfZld00ol0003o/J78ok6Qb002
ok6Qb003o`000?nWVLOoYiW700OoYiW71_l00004oij?a003o`000?nHR/?oV8[300?o00001?nFSlX0
1Ol0003oShO6ohn7a_n?QlKo000000KoRX[=0_l00003oh>4c003o`000?mkQ];oNhKB00;oNhKB00?o
0000og67fOmaQmT00_maQmT01Ol0003oHhOPof>7h?mSQn3o000000CoDHOV00?o0000oc^4jOlkQ>T0
0ol000000omRRN;o0000oeR:i`03oeR:i`?oCXc[0om4SNd3ocb?k`;o00000olgT_03ocBFl@03o`00
0?lfVo?o=Y_c00;o0000;_ooool00ol0003oooooooooo`0Vooooo`00:_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo03cooooo1ol00002olCng003o`000?o;o>Co000000;ocoKX00Go
0000om3/j?o@k>Sod>cXo`000003olgOi@05o`000?o8dN3ob=7PolSAh?l000001?o2`mX00ol0003o
_;KCokbfd`02okbfd`03o`000?nfZlgo]Z_=00?o]Z_=00?o0000ok6Qb?naXLP00_naXLP00ol0003o
YiW7ojNIa`06ojNIa`03o`000?nTT/;o000000SoWXo400?o0000oiR:`onHR/<00onHR/<3o`000003
oiJ?b_l0003oShO600?oShO60_l00005ohZ:c@03o`000?n3Q<coPhC<00;oPhC<00?o0000og^6d_mk
Q]800_mkQ]800ol0003oLHOIog67f@02og67f@05o`000?mSQn3oHhOPof>7h?l000000omAQnH3o`00
0003of^8gOl0003oHXWR00;oHXWR00?o0000oeR:iomHR^L00_mHR^L3odj<j`03o`000?m4SNgo0000
00;o000000Co?8o_o`000?llSnoo00000_lgT_001Ol0003o=9KaocBFlOldU_7o000000;o=Y_c0_l0
000]ooooo`03o`000?oooooooooo02Gooooo000Zooooo`;o00005Oooool00ol0003oooooooooo`0j
ooooo`Oo00000_o4o]`00ol0003obocTol_li003olofj003om3/j?l0003o000000_o00000_o2`mX0
0ol0003o_;KCokbfd`03okbfd`03o`000?nfZlgo]Z_=00;o]Z_=00?o0000ok6Qb?naXLP00_naXLP0
0ol0003o[9S3o`000005ojNIa`;o00000onTT/800ol0003oWXo4oij?a005oij?a003o`000?nHR/?o
V8[300KoV8[30_l00006ohn7aP03o`000?n:R/goRX[=00;oRX[=0_l00004oh>4c003o`000?mkQ];o
NhKB00;oNhKB00?o0000og67fOmaQmT00_maQmT02Ol0003oHhOPof>7h?mSQn3o0000oe67i_l0003o
LhKGo`000003of^8g@05o`000?mRRN;oHXWRof:9h_l000001?mHR^L4o`0000;oA8g]0_l000001?ll
Snoo0000ocb?kol00003ocNBl003o`000?ldU_7o=9Ka00;o00000_lfVo<2o`0002cooooo00?o0000
ooooooooool09?ooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0hoooo
o`Co000000?o/O[<o`000?l000000_o4o]`00ol0003obocTol_li005o`0000;odM3H00Go0000olc7
e?o<amCoc<ODo`000003olNmd@03o`000?o1/lgo`K?=00?o00001?nl]]<00ol0003o]Z_=okJ[c@02
okJ[c@03o`000?naXLSo/J7800;o/J7800Go0000ojbH`on/V<?o[9S3o`000003ojNIa`03o`000?nT
T/;oY9;200?oY9;200?o0000oij?a?nNSl@01_nNSl@00ol0003oV8[3oiR:``06oiR:``03o`000?nC
QL7o000000GoShO600Co0000ohZ:cOn:R/go00000_n9PlH00ol0003oPhC<oh>4c002oh>4c003o`00
0?mkQ];oNhKB00;oNhKB00?o0000og67fOmaQmT00_maQmT01Ol0003oHhOPof>7h?mSQn3o000000?o
LhKG00Go0000of^8gOm[R=goJhSMo`000003of:9hP03o`000?mHR^Oo000000?o00000_m>S>/2o`00
00;oA8g]00Co0000ocb?kol0003o?8o_0_l00002ocNBl0;o00000_ldU_401?l0003o=Y_cocJKlolf
Vo<2o`0002[ooooo0_l0000Uooooo`00:_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo03Gooooo1Ol000000onan/co0000ok[me003olCng0?o00000_oFf]/01Ol0003odM3Hom7@f?oA
d=So000000?oc<OD00Go0000olNmdOo7_M7oakgAo`000004ol6cc@06o`000?nkZlWo0000o`000?nl
]]?o00001?nfZld00ol0003o/J78ok6Qb003ok6Qb003o`000?n/V<?o[9S300;o[9S300?o0000ojNI
aol000001_nTT/800ol0003oWXo4oij?a006oij?a003o`000?nHR/?oV8[300KoV8[300Co0000oi>5
`OnCQL7o00001On?QlH00ol0003oRX[=o`000003ohV3aP03o`000?n3Q<coPhC<00;oPhC<00?o0000
og^6d_mkQ]800_mkQ]800ol0003oLHOIog67f@02og67f@04o`000?mSQn3o0000o`0000CoLhKG00Ko
0000of^8gOm[R=goJhSMo`000?mRRN83o`0000CoF8[W00Go0000odj<jom>S>_oCXc[o`000002odB=
k@03o`000?llSnoo000000;o?8o_00Go0000ocNBl?lgT_3o=i;`o`000002ocBFl@;o00000olfVo<0
0ol0003oooooooooo`0Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0cooooo`?o000000GoZOO6o`000?nan/co0000ok[me003olCng003o`00
0?oIhmgo000000;oe][K00?o0000om7@f?oAd=P00_oAd=P01Ol0003oc<ODolc7e?o<amCo000000?o
akgA00Go0000ol6ccOo1/lgo`K?=o`000004ok^[b@;o00001?nfZld00ol0003o/J78ok6Qb002ok6Q
b003o`000?n/V<?o[9S300Co[9S300?o0000ojBB`_nTT/801OnTT/8:o`0000SoV8[300Co0000oi>5
`OnCQL7oThG10_l00004ohn7aP03o`000?n9PlKoRH?600?oRH?600?o0000oh>4c?n3Q<`00_n3Q<`0
0ol0003oNhKBog^6dP02og^6dP04o`000?maQmWoLHOIog67f@;o00000_mkQM800ol0003oLhKGog>6
e`02og>6e`03o`000?m[R=go000000;o00000omRRN800ol0003oF8[WoeR:i`02oeR:i`05o`000?m>
S>_oCXc[odj<jol000000_m4SNd2o`0000?o?8o_00Co0000ocNBl?lgT_3o=i;`0_l00002ocBFl@04
o`000?lfVo?o=Y_cocJKl`;o0000:?ooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01_ooool002[ooooo0_l0000Ioooo
o`03o`000?oooooooooo037ooooo0ol000001_nYmlKo0000ok7jc?l0003o^_gDolCng0;o00000_oI
hmd01Ol0003oe][KomKJfooFf]_o000000CodM3H00Go0000olc7e?o<amCoc<ODo`000003olNmd@05
o`000?o1/lgo`K?=ol6ccOl000001?nkZlT01_l0003o]Z;5o`000?l0003o]Z_=o`0000Go/J7800?o
0000ojbH`on/V<<01?n/V<<00ol0003oY9;2ojBB`P04ojBB`P03o`000?nRS;go000000OoWHZn00?o
0000oiV6__l000000_l00003oiR:``03o`000?nCQL7oThG100CoThG100Co0000ohn7a_n?QlKoShO6
0_l00005ohV3aP03o`000?n3Q<coPhC<00;oPhC<00?o0000og^6d_mkQ]800_mkQ]801Ol0003oLHOI
o`000?n1Q<go000000?oNhGB00?o0000og>6eomcQ]L00ol00003of^8g@05o`000?mRRN;oHXWRof:9
h_l000001?mHR^L01Ol0003oCXc[odj<jom>S>_o000000?oA8g]00Co0000ocb?kollSnoo?8o_0_l0
0003ocNBl003o`000?ldU_7o=9Ka00;o00000olfVo<2o`0002Oooooo00?o0000ooooooooool01Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool002Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`;o000000CoXoC3o`000?nYmlKo0000
0_nan/`01OnjoMCo0000o`000?oKj]ko000000;ofN?M00Go0000omKJfooFf]_oe][Ko`000003om7@
f005o`000?o<amCoc<ODolc7e?l000000oo7_M400ol0003o`K?=ol6cc@02ol6cc@05o`000?nkZlWo
^j_9ok^[bOl000001?nfX/D2o`0000Co/J7800?o0000ojbH`on/V<<01?n/V<<00ol0003oZ9:no`00
0004ojBB`P05o`000?nRS;goXXbmoj:<_Ol000001_nMR[h00ol0003oVHJnoiV6_P02oiV6_PCo0000
1onCQL401_l0003oShO6ohn7a_l0003oSX;2o`0000GoRH?600?o0000oh>4c?n3Q<`00_n3Q<`00ol0
003oNhKBog^6dP02og^6dP05o`000?n1Q<goPHC=oh64cOl000000_mkQM83o`0000?oLhKG00Go0000
of^8gOm[R=goJhSMo`000003of:9hP03o`000?mHR^OoF8[W00;oF8[W00Go0000odj<jom>S>_oCXc[
o`000003odB=k@03o`000?llSnoo?8o_00;o?8o_00Co0000ocNBl?lgT_3o=i;`0_l00002ocBFl@;o
00000olfVo<2o`0002Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0/ooooo`06o`000?nOllCoXoC3o`000?nYmlKo00000_nan/`01Ol0003ofn[Nom_Zg_oK
j]ko000000?ofN?M00Co0000omKJfooFf]_o00001?oAd=P01Ol0003oc<ODolc7e?o<amCo000000?o
akgA00Go0000ol6ccOo1/lgo`K?=o`000004ok^[b@03o`000?nfX/Go]Z;500;o]Z;500?o0000ok6K
`Ol000000_naXLP00ol0003o[9S3ojbH``04ojbH``05o`000?nXT[koZ9:nojRB__l000000_nTT/80
0ol0003oXXbmoj:<_@02oj:<_@03o`000?nMR[koWHZn00CoWHZn00?o0000oiV6__nIQ[h01OnIQ[h0
0ol0003oThG1oi>5`@06oi>5`@;o00000on>P/800ol0003oRH?6ohV3aP03ohV3aP03o`000?n3Q<co
PhC<00;oPhC<00Go0000og^6d_mkQ];oNhKBo`000003oh64c@?o00000_mkQM800ol0003oLhKGog>6
e`02og>6e`05o`000?m[R=goJhSMof^8gOl000000omRRN800ol0003oF8[WoeR:i`02oeR:i`05o`00
0?m>S>_oCXc[odj<jol000000om4SNd00ol0003o?8o_ocb?k`02ocb?k`03o`000?lgT_3o=i;`00;o
=i;`00Go0000ocBFlOldU_7o=9Kao`000004ocJKl`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c007ooooo`00:Oooool3o`0001cooooo00?o0000ooooooooool0:_ooool01_l0003oWo?4oj?d`ol0
003oZOO6o`0000;o/O[<00?ofo3Oo`000?oKj]h00_oKj]h01?l0003ofN?MomWSgOl00003omKJf`05
o`000?oAd=SodM3Hom7@f?l000001?o<am@01Ol0003oakgAolNmdOo7_M7o000000?o`K?=00?o0000
ok^[bOnkZlT00_nkZlT01Ol0003o]Z;5okJRaOnfX/Go000000?o/I_100?o0000ok6Qb?l000001On/
V<<00ol0003oZ9:nojRB_P02ojRB_P03o`000?nTT/;o000000KoXXbm00?o0000oif:__nMR[h01?nM
R[h00ol0003oVHJnoiV6_P04oiV6_P03o`000?nFPkco000000OoThG100?o0000ohj2`_n>P/800_n>
P/800ol0003oRH?6ohV3aP03ohV3aP03o`000?n3Q<coPhC<00;oPhC<00Co0000og^6d_l0003oQX?8
0ol000000on1Q<go0000og^5dP03og^5dP03o`000?mcQ]OoLhKG00;oLhKG00Go0000of^8gOm[R=go
JhSMo`000003of:9hP03o`000?mHR^OoF8[W00;oF8[W00Co0000odj<jom>S>_oCXc[0_l000001?m4
SNgo0000o`000?l00003ocb?k`;o00000olgT_02o`0000;o=9Ka0_l00003ocJKl`;o00009?ooool0
0ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000
oioca?nSm<<00onYmlH2ok7jc003om_`gol0003ofn[N00;ofn[N00Go0000omWSgOoIhmgofN?Mo`00
0002omKJf`03o`000?oAd=SodM3H00;odM3H00Go0000olc7e?o<amCoc<ODo`000003olNmd@05o`00
0?o1/lgo`K?=ol6ccOl000001?nkZlT00ol0003o]Z;5okJRa@02okJRa@03o`000?naVl7o/I_100;o
/I_10_l00005ojbH``03o`000?nXT[koZ9:n00?oZ9:n00?o0000oj:<_OnRS;d01OnRS;d00ol0003o
WHZnoif:_P04oif:_P03o`000?nIQ[koVHJn00CoVHJn00?o0000oiJ3_?nFPk`00_l00005oi>5`@03
o`000?n>P/;oSX;200?oSX;200?o0000ohV3a_n9PlH00on9PlH01?l0003oPhC<oh>4c?n3Q<`4o`00
0003ohJ3b?l0003oPHC=00;oPHC=00Go0000og^5d_mkQM;oNhGBo`000005og>6e`04o`000?m[R=go
JhSMo`0000CoHXWR00?o0000oeR:iomHR^L00_mHR^L00ol0003oCXc[odj<j`02odj<j`05o`000?m4
SNgo0000odB=kOl000001?llSnl00ol0003o=i;`ocNBl002ocNBl005o`000?ldU_7o=9KaocBFlOl0
00000_lfVo<3o`0002;ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Ko
oooo00?o0000oioca?nSm<<00onYmlH2o`0000;ofo3O00Go0000om_Zg_oKj]kofn[No`000002omWS
g@05o`000?oFf]_oe][KomKJfol000000ooAd=P00ol0003oc<ODolc7e002olc7e005o`000?o7_M7o
akgAolNmdOl000000oo1/ld00ol0003o^j_9ok^[b@02ok^[b@03o`000?nfX/Go]Z;500;o]Z;500?o
0000ok6K`OnaVl400_naVl42ojbE_P05o`000?n/V<?o[9S3ojbH`ol000001_nXT[h00ol0003oXXbm
oj:<_@05oj:<_@04o`000?nMR[koWHZnoif:_PGo00001OnIQ[h00ol0003oUX>loiJ3_002oiJ3_003
o`000?nCQL7oThG100;oThG10_l00005ohj2`P03o`000?n9PlKoRH?600?oRH?61Ol00004ohJ3b005
o`000?n1Q<goPHC=oh64cOl000000omkQM800ol0003oLhKGog>6e`02og>6e`05o`000?m[R=goJhSM
of^8gOl000001?mRRN800ol0003oF8[WoeR:i`02oeR:i`03o`000?m>S>_oCXc[00;oCXc[00Go0000
odB=kOl0003oA8g]o`000004ocb?k`03o`000?lgT_3o=i;`00So00000omo/O@00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
2?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool09?ooool00ol0003oWo?4oj?d``03ojWgaP05o`000?oJmMoo0000om_`gol000000ooKj]h01Ol0
003ofN?MomWSgOoIhmgo000000;oe][K00?o0000om7@f?oAd=P00_oAd=P01Ol0003oc<ODolc7e?o<
amCo000000?oakgA00?o0000ol6ccOo1/ld00_o1/ld00ol0003o^j_9ok^[b@02ok^[b@05o`000?nf
X/Go]Z;5okJRaOl000001?naVl401ol0003o[9FnojbE__n/UKko0000ojbH`ol000001_nXT[h00ol0
003oY8bko`000006oj:<_@Co00000onMQ[X00ol0003oVXBjo`000002o`0000;oVHJn00?o0000oiJ3
_?nFPk`00onFPk`2o`000005oi>5`Ol0003oTX6moi:1_Ol000001On>P/800ol0003oRH?6ohV3aP04
o`0000?oRh;400Go0000ohJ3b?n6PlSoQX?8o`000004oh64c@05o`000?mkQM;oNhGBog^5d_l00000
1?mcQ]L01Ol0003oJhSMof^8gOm[R=go000000CoHXWR00?o0000oeR:iomHR^L00_mHR^L00ol0003o
CXc[odj<j`02odj<j`05o`000?m4SNgo0000odB=kOl000000_llSnl4o`0000;oOjK]00Go0000ogj/
lOmn[?7oOZcao`000005ognam003o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`00027ooooo00?o0000ooooooooool08_oo
ool00ol0003oWo?4oj?d``03ojWgaP;of_GO00Co0000om_`gooKl=oo00000ooKj]h01?l0003ofN?M
omWSgOl00003omKJf`03o`000?oAd=SodM3H00;odM3H00Go0000olc7e?o<amCoc<ODo`000003olNm
d@05o`000?o1/lgo`K?=ol6ccOl000001?nkZlT00ol0003o]Z;5okJRa@02okJRa@03o`000?naVl7o
/I_100;o/I_100?o0000ojbE__n/UKh00_n/UKh00ol0003oZ9:nojRB_P04ojRB_P05o`000?nTS;_o
Y8bkojB<^ol000000onRS;d2o`000003oj27^_l0003oWHJj00CoWHJj00?o0000oiZ4^_nJQ;X00_nJ
Q;X3o`0000OoUX>l0_l00003oi:1_@03o`000?n>P/;oSX;200?oSX;20_l00003ohV3aP03o`000?n;
P/CoRh;400;oRh;400Go0000ohJ3b?n6PlSoQX?8o`000003oh64c@03o`000?mkQM;oNhGB00;oNhGB
00?o0000og>6eomcQ]L00_mcQ]L01Ol0003oJhSMof^8gOm[R=go000000CoHXWR00?o0000oeR:iomH
R^L00_mHR^L00ol0003oCXc[odj<j`02odj<j`;o000000CoA8g]o`000?l0003o00000_n1X^P00ol0
003oOjK]ognVk@02ognVk@05o`000?mn[?7oOZcaogj/lOl000001Omo/O@00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01oooooo0_l000000onOllCoXoC3ojWgaP02o`0000?of_GO00Co0000
om_`gooKl=oo00000_oKj]h01Ol0003ofN?MomWSgOoIhmgo000000?oe][K00Go0000om7@f?oAd=So
dM3Ho`000004olc7e005o`000?o7_M7oakgAolNmdOl000000oo1/ld00ol0003o^j_9ok^[b@02ok^[
b@05o`000?nfX/Go]Z;5okJRaOl000001OnaVl400ol0003o[9FnojbE_P02ojbE_P03ojR?^ol0003o
Z9:n00?oZ9:n00?o0000ojB<^onTS;/00_nTS;/01?l0003oXXbmo`000?l00004oj27^P03o`000?nM
Q[[oWHJj00;oWHJj00?o0000oiZ4^_nJQ;X01?nJQ;X00ol0003oUX>loiJ3_006oiJ3_003o`000?nB
PKgoTX6m00;oTX6m00?o0000ohj2`_l000000_l000001on>P/;o0000ohV3a_n9PlKo0000ohj1`?l0
00000on;P/@00ol0003oQX?8ohJ3b002ohJ3b005o`000?n1Q<goPHC=oh64cOl000001?mkQM800ol0
003oLhKGog>6e`02og>6e`05o`000?m[R=goJhSMof^8gOl000001?mRRN800ol0003oF8[WoeR:i`02
oeR:i`03o`000?m>S>_oCXc[00Co000000?oPigTo`000?n1X^P00on1X^P00ol0003oOjK]ognVk@02
ognVk@05o`000?mn[?7oOZcaogj/lOl000001Omo/O@00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Mooooo`04o`000?nOllCoWo?4oj?d``;o000000GofOSOo`000?oJmMoof_GOo`000002om_`g`05
o`000?oKj]kofn[Nom_Zg_l000000ooIhmd01?l0003oe][KomKJfol00004om7@f005o`000?o<amCo
c<ODolc7e?l000000oo7_M401Ol0003o`K?=ol6ccOo1/lgo000000Go^j_900Go0000okJRaOnfX/Go
]Z;5o`000004ok6K`@03o`000?n/UKko[9Fn00;o[9Fn00Co0000ojR?^onXSk_o00000onXT[h00ol0
003oY8bkojB<^`03ojB<^`03o`000?nPQk[oX8Nj00CoX8Nj00?o0000oif6^_nMQ[X00onMQ[X00ol0
003oVXBjoiZ4^P03oiZ4^P03o`000?nHPKWo000000KoUX>l00Co0000oi:1_OnBPKgoTX6m0ol00005
ohj2`P03o`000?n9PlKo000000;oSX7000Go0000oh^2a?n;P/CoRh;4o`000004ohJ3b005o`000?n1
Q<goPHC=oh64cOl000000omkQM800ol0003oLhKGog>6e`03og>6e`05o`000?m[R=goJhSMof^8gOl0
00001?mRRN800ol0003oF8[WoeR:i`04o`0000;oQIWO00Go0000oh>Mi?l0003oPigTo`000004oh6R
j003o`000?moY^goOjK]00;oOjK]00Go0000ogj/lOmn[?7oOZcao`000005ognam003o`000?oooooo
oooo023ooooo0_l0000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09?oo
ool2o`0001cooooo00Co0000oioca?nOllCo00000ooIn=l01Ol0003of_GOom[egooJmMoo000000;o
fo3O00Go0000om_Zg_oKj]kofn[No`000002omWSg@05o`000?oFf]_oe][KomKJfol000000ooAd=P0
0ol0003oc<ODolc7e002olc7e005o`000?o7_M7oakgAolNmdOl000000oo1/ld00ol0003o^j_9ok^[
b@02ok^[b@03o`000?nfX/Go]Z;500;o]Z;500?o0000ok6K`OnaVl400_naVl400ol0003o[9FnojbE
_P02ojbE_P07o`000?nXSk_oZ8nkojR?^ol0003oZ9:no`000006ojB<^`03o`000?nPQk[oX8Nj00Co
X8Nj00?o0000oif6^_nMQ[X00onMQ[X00ol0003oVXBjoiZ4^P03oiZ4^P03o`000?nHPKWoV86i00;o
00000onFPk`00ol0003oUH2jo`000002o`0000?oTX6m00?o0000ohj2`_n>P/800on>P/801Ol0003o
SX70ohj1`?n>PL3o000000CoRh;400Go0000ohJ3b?n6PlSoQX?8o`000003oh64c@03o`000?mkQM;o
NhGB00;oNhGB00?o0000og>6eomcQ]L00omcQ]L01Ol0003oJhSMof^8gOm[R=go000000;oHXWR1?l0
0002ohNEfPGoQIWO00Go0000oh>Mi?l0003oPigTo`000004oh6Rj003o`000?moY^goOjK]00;oOjK]
00Go0000ogj/lOmn[?7oOZcao`000005ognam003o`000?oooooooooo01kooooo00?o0000ooooool0
00007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool2o`0002Oooooo00?o0000ooooooooool06?ooool01Ol0003o
Wo?4oioca?oFn^3o000000?ofOSO00Co0000om[egooJmMoo00000_oKl=l01Ol0003ofn[Nom_Zg_oK
j]ko000000?ofN?M00Co0000omKJfooFf]_o00001?oAd=P00ol0003oc<ODolc7e002olc7e005o`00
0?o7_M7oakgAolNmdOl000000oo1/ld00ol0003o^j_9ok^[b@02ok^[b@05o`000?nfX/Go]Z;5okJR
aOl000001OnaVl400ol0003o[9FnojbE_P02ojbE_P03o`000?nXSk_oZ8nk00;oZ8nk00?o0000ojB<
^onTS;/01?nTS;/00ol0003oXXRho`000006oj27^P03o`000?nMQ[[oWHJj00;oWHJj00?o0000oiZ4
^_nJQ;X00onJQ;X00ol0003oV86ioiR1^@02oiR1^@03o`000?nFPkco000000;o000000?oUH2jo`00
0?nBPKd01?nBPKd01?l0003oSX;2ohj2`_n>P/82o`0000CoSX7000Go0000oh^2a?n;P/CoRh;4o`00
0004ohJ3b005o`000?n1Q<goPHC=oh64cOl000001?mkQM800ol0003oLhKGog>6e`03og>6e`03o`00
0?m[R=goJhSM00?o00000_n9TMH5ohNEfPGoQIWO0_l00002oh>Mi003o`000?n1X^SoPJ;X00;oPJ;X
00?o0000ognVkOmoY^d00_moY^d01Ol0003oOZcaogj/lOmn[?7o000000GoOk7d00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Fooooo`05o`000?nOllCoWo?4omKjh?l000000ooIn=l0
1Ol0003of_GOom[egooJmMoo000000;ofo3O00Go0000om_Zg_oKj]kofn[No`000002omWSg@05o`00
0?oFf]_oe][KomKJfol000001?oAd=P00ol0003oc<ODo`00000=o`0000;o^j_900Go0000okJRaOnf
X/Go]Z;5o`000004ok6K`@03o`000?n/UKko[9Fn00;o[9Fn00?o0000ojR?^onXSk/00onXSk/00ol0
003oY8bkojB<^`03ojB<^`04o`000?nRR;SoXXRho`0000GoX8Nj2Ol00003oiZ4^P04o`000?nHPKWo
V86ioiR1^@?o000000?oUX>lo`000?nEP;X00_nEP;X00ol0003oTX6moi:1_@03oi:1_@03o`000?n>
P/;o000000;oTH2m00Go0000ohj1`?n>PL3oSX70o`000004oh^2a003o`000?n6PlSoQX?800;oQX?8
00Go0000oh64cOn1Q<goPHC=o`000004og^5dP03o`000?mcQ]OoLhKG00;oLhKG0ol000000on;S]7o
RI7FohVAeP03ohVAePGoQiGJ1?n5VMl00ol0003oPigTo`000002oh>Mi005o`000?n1X^SoPJ;Xoh6R
j?l000001OmoY^d01Ol0003oOZcaogj/lOmn[?7o000000GoOk7d00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Cooooo0ol00002omKjh005o`000?oIn=oofOSOomWhgol000000_oJmMl01?l0003ofo3O
om_`gol00003om_ZgP05o`000?oIhmgofN?MomWSgOl000000ooFf]/00ol0003odM3Ho`000004o`00
00;o`[;;00Go0000okf[b?nmZlSo_J_8o`000003okVUa@04o`000?neWl;o]Io2okFO`PCo00000_nf
X/D00ol0003o/I_1ok6K`@02ok6K`@03o`000?n/UKko[9Fn00;o[9Fn00?o0000ojR?^onXSk/00_nX
Sk/00ol0003oYH^io`000003ojB<^`03o`000?nRR;SoXXRh00;oXXRh00Oo0000oj27^_nPQk[oX8Nj
o`000?nNQ;Oo000000CoW8>g00?o0000oiZ1]onJPKL01ol00003oiR1^@03o`000?nEP;[oUH2j00?o
UH2j00?o0000oi:1_OnBPKd00onBPKd01Ol0003oTH2moi60_OnAP;go000000CoSX7000?o0000oh^2
a?n;P/@00_n;P/@00ol0003oQX?8ohJ3b002ohJ3b005o`000?n1Q<goPHC=oh64cOl000001?mkQM80
1Ol0003oLhKGo`000?l0003oSXc=00CoRhkA1On9TMH4ohNEfP03o`000?n5VMooQIWO00;oQIWO00Go
0000oh>Mi?l0003oPigTo`000004oh6Rj003o`000?moY^goOjK]00?oOjK]00Go0000ogj/lOmn[?7o
OZcao`000005ognam003o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool002Oooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`;o000000Codo_Qo`000?oFn^3o
00000ooIn=l01?l0003of_GOom[egol00003om_`g`05o`000?oKj]kofn[Nom_Zg_l000000ooIhmd6
o`0000;oa[W>00?o0000ol:bboo2///00_o2///01Ol0003o_J_8okf[b?nmZlSo000000?o^JG500?o
0000okFO`_neWl800_neWl83ok6I_`?o00001?naVl400ol0003o[9FnojbE_P02ojbE_P03o`000?nX
Sk_oZ8nk00;oZ8nk00Co0000ojF;^OnURkWo00000_nTS;/00ol0003oXXRhoj:8^002oj:8^004o`00
0?nPQk[oX8Njo`0000;oWXBg00?o0000oib3]onLPkL00_nLPkL01?l0003oVX6goiZ1]onJPKL3o`00
00KoV86i00?o0000oiF0^_nEP;X00onEP;X00ol0003oTX6moi:1_@03oi:1_@03o`000?nAP;goTH2m
00;oTH2m00?o0000ohj1`?n>PL000_n>PL001Ol0003oRh;4oh^2a?n;P/Co000000CoQX?800Go0000
oh64cOn1Q<goPHC=o`000004og^5dP;o00001?n>S<d3oh^>d@03o`000?n9TMKoRI7F00;oRI7F00?o
0000ohNEf_n7UMX00_n7UMX00ol0003oQIWOohFIg`02ohFIg`;o00000_n3WN@00ol0003oPJ;Xoh6R
j002oh6Rj003o`000?moY^goOjK]00?oOjK]00Go0000ogj/lOmn[?7oOZcao`000005ognam003o`00
0?oooooooooo01kooooo00?o0000ooooooooool06Oooool002Oooooo0_l0000/ooooo`03o`000?oo
oooooooo013ooooo00Co0000om?khOoCnn7o00000_oFn^001Ol0003ofOSOomWhgooIn=oo000000;o
f_GO00Co0000om_`gooKl=oo00000ooKj]h00ol0003ofN?MomWSg@03o`0000;ob/3@00?o0000olJi
c_o6^Lh00_o6^Lh00ol0003o`[;;ol:bb`02ol:bb`05o`000?nmZlSo_J_8okf[b?l000000oniYLD0
0ol0003o]Io2okFO`P02okFO`PCo/IVo0_n]U;d4o`0000Co[9Fn00?o0000ojR?^onXSk/00onXSk/0
1_l0003oYH^iojF;^Ol0003oY8bko`0000GoXXRh00?o0000oj27^_l000001?nNQ;L01?l0003oW8>g
oib3]onLPkL4o`0000;oVX6g00?o0000oiV0]_l000001?nHPKT2o`0000GoUH2j00Oo0000oi:1_OnB
PKgoTX6mo`000?nDP;[o000000CoTH2m00Go0000ohj1`?n>PL3oSX70o`000004oh^2a003o`000?n6
PlSoQX?800;oQX?800Ko0000oh64cOn1Q<goPHC=o`000?mkQM82o`000003oi29bOn>S<goSXc=00?o
SXc=00Go0000oh^>dOn;S]7oRhkAo`000004ohVAeP05o`000?n7UM[oQiGJohNEf_l000001?n5VMl0
0ol0003oPigTo`000002oh>Mi003o`000?n1X^SoPJ;X00;oPJ;X00?o0000ognVkOmoY^d00_moY^d0
0ol0003oOZcaogj/l@02ogj/l@03o`000?mo/OCoOk7d00?oOk7d00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00kooooo00Go0000om?khOoCnn7odo_Qo`000002omKjh004o`000?oIn=oofOSOo`0000;of_GO00Go
0000om_`gooKl=oofo3Oo`000003om_ZgP?o000000?oc/OCo`000?o:`=000_o:`=000ol0003oa[W>
olJicP02olJicP05o`000?o2//_o`[;;ol:bbol000001?nmZlP01Ol0003o^JG5okVUaOniYLGo0000
00Co]Io21?naVKl5ojfD_@;o00000on/UKh00ol0003oZ8nkojR?^`02ojR?^`03o`000?nURkWoYH^i
00;oYH^i00?o0000oj:8^?nRR;P01OnRR;P00ol0003oWXBgoij4]`03oij4]`03o`000?nLPkOo0000
00?o00001?nJPKL01?l0003oVH2foiV0]_l00003oiR1^@03o`000?nGOkSo000000GoUH2j00Ko0000
oi:1_OnBPKgo0000oiB0^_l00004oi60_@03o`000?n>PL3oSX7000;oSX7000?o0000oh^2a?n;P/@0
0_n;P/@00ol0003oQX?8ohJ3b002ohJ3b003o`000?n1Q<goPHC=00;o00001?n@RLT5ohj<c@04o`00
0?n;S]7oRhkAo`0000CoRI7F00?o0000ohNEf_n7UMX00_n7UMX00ol0003oQIWOohFIg`02ohFIg`03
o`000?n3WNCo000000;oPigT00Go0000oh6Rj?n1X^SoPJ;Xo`000005ognVk@03o`000?mn[?7oOZca
00;oOZca00?o0000ognam?mo/O@00omo/O@00ol0003oooooooooo`0Looooo`;o00006_ooool002Oo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`04o`000?oCnn7odo_Qo`00
00;oe_[P00Go0000omWhgooIn=oofOSOo`000002om[eg`06o`000?oKl=oofo3Oom_`gol0003ofn[N
0_l00004olk7d`05o`000?o:`=3ob/3@ol[0d?l000001?o6^Lh01Ol0003o`[;;ol:bboo2//_o0000
00?o_J_800?o0000okVUaOniYLD00_niYLD00ol0003o]Io2okFO`P02okFO`P04o`000?naVKoo/IVo
ok6I_`Go[IBm0_nYT;/01?l0003o[9FnojbE__l00004ojR?^`03o`000?nURkWoYH^i00;oYH^i00?o
0000oj:8^?nRR;P01OnRR;P00ol0003oWXBgoij4]`02oij4]`?o00000onLPkL00ol0003oVX6goiZ1
]`02oiZ1]`07o`000?nIP;KoVH2foiV0]_l0003oV86io`000003oiMo^003o`000?nEP;[oUH2j00?o
UH2j00?o0000oi:1_Ol000000_nDP;X00ol0003oTH2moi60_@02oi60_@03o`000?n>PL3oSX7000;o
SX7000Go0000oh^2a?n;P/CoRh;4o`000004ohJ3b0?o000000?oTHO5oi29bOn@RLT00on@RLT00ol0
003oSXc=ohj<c@02ohj<c@05o`000?n;S]7oRhkAoh^>dOl000001?n9TMH00ol0003oQiGJohNEfP02
ohNEfP03o`000?n5VMooQIWO00;oQIWO00Go0000oh>Mi?l0003oPigTo`000004oh6Rj003o`000?mo
Y^goOjK]00?oOjK]00?o0000ogj/lOmn[?400_mn[?400ol0003oOk7dognam003ognam003o`000?oo
oooooooo01gooooo00?o0000ooooooooool05oooool002Oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?oCnn7odo_Qom?khOl000000_oFn^001ol0003ofOSOomWh
gooIn=oo0000om[egol000000ooKl=l3o`000003om7=e_l0003oc/OC00?oc/OC00Go0000ol[0d?o:
`=3ob/3@o`000004olJicP05o`000?o2//_o`[;;ol:bbol000000onmZlP00ol0003o^JG5okVUa@02
okVUa@05o`000?neWl;o]Io2okFO`_l000001?naVKl00ol0003o[IBmojfD_@02ojfD_@?oZI2k0_l0
0005ojR?^`03o`000?nURkWoYH^i00;oYH^i00?oXXNgo`000?nRR;P01?nRR;P00ol0003oWhBfo`00
0003o`000003oij4]ol0003oW8>g00?oW8>g00?o0000oiZ1]onJPKL00_nJPKL00ol0003oVH2foiV0
]P02oiV0]P;o00001?nGOkP00ol0003oUH2joiF0^P03oiF0^P03o`000?nDP;[oU82j00;oU82j00Go
0000oi60_OnAP;goTH2mo`000004ohj1`003o`000?n;P/CoRh;400;oRh;400Go0000ohJ3b?l0003o
0000oi>6`P04oi67a@GoT8W900?o0000ohj<cOn>S<d00_n>S<d01Ol0003oRhkAoh^>dOn;S]7o0000
00CoRI7F00Go0000ohNEf_n7UM[oQiGJo`000005ohFIg`;o00000_n3WN@00ol0003oPJ;Xoh6Rj002
oh6Rj003o`000?moY^goOjK]00?oOjK]00?o0000ogj/lOmn[?400_mn[?400ol0003oOk7dognam003
ognam003o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool002Oooooo0_l0000`oooo
o`03o`000?oooooooooo00[ooooo00Co0000om?khOoCnn7o00000_oFn^001Ol0003ofOSOomWhgooI
n=oo000000;of_GO00Go0000om_`gooKl=oofo3Oo`000003om7=eP03o`000?o>am?oc/OC00;oc/OC
00Go0000ol[0d?o:`=3ob/3@o`000003olJicP03o`000?o2//_o`[;;00;o`[;;00Go0000okf[b?nm
ZlSo_J_8o`000004okVUa@05o`000?neWl;o]Io2okFO`_l000001?naVKl00ol0003o[IBmojfD_@02
ojfD_@CoZI2k0_l00003ojR?^`03o`000?nURkWoYH^i00;oYH^i00Co0000oj:7]onRQkOo00000onR
R;P4o`0000GoWXBg00?o0000oib3]ol000000ol00003oiZ1]`03o`000?nIP;KoVH2f00?oVH2f00?o
0000oiMo^?nGOkP00_nGOkP00ol0003oUH2joiF0^P03oiF0^P03o`000?nDP;[oU82j00;oU82j00?o
0000oi60_OnAP;d00_nAP;d00ol0003oSX70ohj1`002ohj1`003o`000?n;P/CoRh;400;oRh;400?o
0000oi>6`_nCQ/800_nCQ/83oi67a@03o`000?n@RLWoT8W900;oT8W900?o0000ohj<cOn>S<d00_n>
S<d01Ol0003oRhkAoh^>dOn;S]7o000000CoRI7F00?o0000ohNEf_n7UMX00_n7UMX00ol0003oQIWO
ohFIg`02ohFIg`03o`000?n3WNCo000000;oPigT00?o0000oh6Rj?n1X^P00_n1X^P00ol0003oOjK]
ognVk@03ognVk@03o`000?mn[?7oOZca00;oOZca00?o0000ognam?mo/O@00omo/O@00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01Kooooo000Vooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool01Ol0003odo_Qom?khOoCnn7o000000;oe_[P00Oo0000omWhgooIn=oo
fOSOo`000?oJmMoo000000;ofo3O0_l00004om7=eP03o`000?o>am?oc/OC00;oc/OC00Co0000ol[0
d?o:`=3o00001?o6^Lh00ol0003o`[;;ol:bb`02ol:bb`05o`000?nmZlSo_J_8okf[b?l000001?ni
YLD01Ol0003o]Io2okFO`_neWl;o000000Co/IVo00?o0000ojfD_On]U;d00_n]U;d01?l0003oZI2k
ojV@^onYT;/2ojJ<^@04o`000?nXSk_oZ8nko`0000CoYH^i00Ko0000oj:7]onRQkOoXXNgo`000?nR
R;P2o`0000?oWhBf00Co0000oij4]onNQ;OoWXBg0ol00002oib1]@03o`000?nKP;Go000000?o0000
1OnIP;H00ol0003oUgnhoiMo^003oiMo^007o`000?nEP;[oUH2joiF0^_l0003oUWnho`000004oiB0
^P05o`000?nAP;goTH2moi60_Ol000001?n>PL001Ol0003oRh;4oh^2a?n;P/Co000000GoThK200Go
0000oi67aOnAQlGoTHO5o`000004oi29b@03o`000?n>S<goSXc=00;oSXc=00Go0000oh^>dOn;S]7o
RhkAo`000004ohVAeP03o`000?n7UM[oQiGJ00;oQiGJ00?o0000ohFIgon5VMl00_n5VMl00ol0003o
PigTo`000002oh>Mi003o`000?n1X^SoPJ;X00;oPJ;X00?o0000ognVkOmoY^d00omoY^d00ol0003o
OZcaogj/l@02ogj/l@04o`000?mo/OCoOk7dognam0?o00007_ooool00ol0003oooooooooo`0Eoooo
o`009_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Co0000om?khOoC
nn7o00000_oFn^001Ol0003ofOSOomWhgooIn=oo000000;of_GO0ol000000ooCdmWo0000om7=eP03
om7=eP05o`000?o>am?oc/OColk7dol000000oo:`=000ol0003oa[W>olJicP02olJicP03o`000?o2
//_o`[;;00;o`[;;00Go0000okf[b?nmZlSo_J_8o`000004okVUa@05o`000?neWl;o]Io2okFO`_l0
00001?naVKl01Ol0003o[IBmojfD_On]U;go000000CoZI2k0onVS;T00ol0003oZ8nko`000004ojF;
^@03o`000?nRQkOoXXNg00?o00001OnOQ;H01_l0003oWXBgo`000?l0003oWH6do`0000?oW86e00?o
0000oi^0]OnKP;D00_nKP;D00ol0003oVH2foiV0]P03oiV0]P;o00001OnGOkP00ol0003oUH2jo`00
0002oiIo^003o`000?nDP;[oU82j00;oU82j00?o0000oi60_OnAP;d00_nAP;d00ol0003oSX70ohj1
`002ohj1`003o`000?n;P/Co000000;oU8Bo1?nCQ/801Ol0003oTHO5oi67aOnAQlGo000000CoT8W9
00?o0000ohj<cOn>S<d00_n>S<d01Ol0003oRhkAoh^>dOn;S]7o000000GoRI7F00Go0000ohNEf_n7
UM[oQiGJo`000005ohFIg`03o`000?n3WNCo000000;oPigT00Go0000oh6Rj?n1X^SoPJ;Xo`000006
ognVk@03o`000?mn[?7oOZca00Go00000_nW`>/00ol0003oooooooooo`0Looooo`;o00005_ooool0
02Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`04o`000?oCnn7odo_Q
o`0000?oe_[P00Co0000omWhgooIn=oofOSO0ol00004om?Cf@03o`000?oAcMKodLgF00;odLgF00Go
0000olk7doo>am?oc/OCo`000003ol[0d003o`000?o6^Lkoa[W>00;oa[W>00Go0000ol:bboo2//_o
`[;;o`000004okf[b005o`000?niYLGo^JG5okVUaOl000001?neWl800ol0003o/IVook6I_`02ok6I
_`05o`000?n]U;go[IBmojfD_Ol000001?nYT;/01?l0003oYXbiojJ<^OnVS;T2o`0000CoYH^i0ol0
0002oj:7]`03o`000?nOQ;KoWhBf00CoWhBf00Go0000oif1]?nMPKCoWH6do`000003oib1]@03o`00
0?nKP;GoVh2e00;oVh2e00?o0000oiYo]?l000000onIP;H00ol0003oVGnfo`000005oiMo^003o`00
0?nFOkSoUWnh00;oUWnh00?o0000oiB0^_nDP;X00_nDP;X00ol0003oTH2moi60_@02oi60_@04o`00
0?n>PL3oSX70ohj1`0;o00000onDQ;l00ol0003oThK2oi>6`P02oi>6`P05o`000?nAQlGoTHO5oi67
aOl000001?n@RLT00ol0003oSXc=ohj<c@02ohj<c@05o`000?n;S]7oRhkAoh^>dOl000001?n9TMH0
0ol0003oQiGJohNEfP02ohNEfP03o`000?n5VMooQIWO00;oQIWO00?o0000oh>Mi?l000000_n3WN@0
0ol0003oPJ;Xoh6Rj002oh6Rj003o`000?moY^goOjK]00?oOjK]0ol00002ojNki`03o`000?nW`>_o
Yl3[00?oYl3[00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`009_ooool3o`00
03Cooooo00?o0000ooooooooool01?ooool01?l0003odo_Qom?khOl00002omKjh004o`000?oIn=oo
fOSOomWhg`;o000000?oe=SKo`000?oCdmT00ooCdmT01Ol0003odLgFom7=e_oAcMKo000000Coc/OC
00Go0000ol[0d?o:`=3ob/3@o`000004olJicP05o`000?o2//_o`[;;ol:bbol000001?nmZlP01Ol0
003o^JG5okVUaOniYLGo000000Co]Io200Go0000ok6I_onaVKoo/IVoo`000004ojfD_@03o`000?nY
T;_oZI2k00;oZI2k00Co0000ojJ<^OnVS;WoYXbi0_nSR;L5o`0000CoXXNg00?oX8Beo`000?nOQ;H0
1?nOQ;H00ol0003oWH6doif1]002oif1]004o`000?nLPKGoW86eo`0000CoVh2e00Ko0000oiYo]?nJ
OkCo0000oiV0]_l00003oiUo]P03o`000?nGOkSoUgnh00;oUgnh00?o0000oiIo^?nFOkP00_nFOkP0
0ol0003oU82joiB0^P02oiB0^P03o`000?nAP;goTH2m00;oTH2m00Go0000ohj1`?l0003o0000oiJ3
_004oiB4_`03o`000?nCQ/;oThK200;oThK200Go0000oi67aOnAQlGoTHO5o`000004oi29b@03o`00
0?n>S<goSXc=00;oSXc=00Go0000oh^>dOn;S]7oRhkAo`000005ohVAeP03o`000?n7UM[oQiGJ00;o
QiGJ00?o0000ohFIgon5VMl00_n5VMl00ol0003oPigTo`000002oh>Mi003o`000?n1X^SoPJ;X00;o
PJ;X00?o0000ognVkOl000000_l000000onW]^?o0000ojNki`03ojNki`03o`000?nW`>_oYl3[00;o
Yl3[00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`009_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00;ooooo00Co0000om?khOoCnn7o00000ooFn^001Ol0003o
fOSOomWhgooIn=oo000000;oe=SK00?o0000om?CfOoCdmT00_oCdmT01Ol0003odLgFom7=e_oAcMKo
000000Coc/OC00Go0000ol[0d?o:`=3ob/3@o`000004olJicP05o`000?o2//_o`[;;ol:bbol00000
1?nmZlP01Ol0003o^JG5okVUaOniYLGo000000Co]Io200Go0000ok6I_onaVKoo/IVoo`000004ojfD
_@03o`000?nYT;_oZI2k00;oZI2k00Co0000ojJ<^OnVS;WoYXbi0ol000000onSR;Oo0000o`000004
oj:7]`04o`000?nPQ;GoX8Beo`0000?oWhBf00?o0000oij1]?l000000onMPK@01Ol0003oW86eoib1
]OnLPKGo000000?oVh2e00Co0000oiYo]?nJOkCoVWnd0_l00004oiUo]P06o`000?nGOkSoUgnho`00
0?nHOkKo00001?nFOkP00ol0003oU82joiB0^P02oiB0^P03o`000?nAP;goTH2m00;oTH2m00?o0000
oiJ3_?nFPk`00_nFPk`4oiB4_`03o`000?nCQ/;oThK200;oThK200Go0000oi67aOnAQlGoTHO5o`00
0004oi29b@03o`000?n>S<goSXc=00;oSXc=00Go0000oh^>dOn;S]7oRhkAo`000005ohVAeP05o`00
0?n7UM[oQiGJohNEf_l000001On5VMl00ol0003oPigTo`000002oh>Mi003o`000?n1X^SoPJ;X00?o
00001OnW]^<01Ol0003oYk_WojNkionW^nOo000000CoYl3[00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Booooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool00003om?kh@06o`000?oFn^3oe_[PomKjh?l0003ofOSO
0_l00003omCHf`03o`000?oCdmWodm?I00;odm?I00Go0000om7=e_oAcMKodLgFo`000004olk7d`05
o`000?o:`=3ob/3@ol[0d?l000001?o6^Lh01Ol0003o`[;;ol:bboo2//_o000000Co_J_800Go0000
okVUaOniYLGo^JG5o`000004okFO`P05o`000?naVKoo/IVook6I_ol000001?n]U;d00ol0003oZI2k
ojV@^`02ojV@^`Go00001?nSR;L00ol0003oXXNgoj:7]`02oj:7]`04o`000?nPQ;GoX8Beo`0000;o
WhBf00Co0000oij1]?nNPKCo00000onMPK@01Ol0003oW86eoib1]OnLPKGo000000?oVh2e00?o0000
oiYo]?nJOk@00_nJOk@00ol0003oVGnfoiUo]P03oiUo]P03o`000?nGOkSo000000;oV7nf00?o0000
oiIo^?nFOkP00_nFOkP00ol0003oU82joiB0^P02oiB0^P04o`000?nAP;goTH2mo`0000GoUX>l00Go
0000oiB4_onDQ;ooU8Boo`000004oi>6`P05o`000?nAQlGoTHO5oi67aOl000001?n@RLT00ol0003o
SXc=ohj<c@02ohj<c@05o`000?n;S]7oRhkAoh^>dOl000001On9TMH00ol0003oQiGJohNEfP02ohNE
fP03o`000?n5VMooQIWO00;oQIWO00Go0000oh>Mi?n3WNCo0000oh>Mi003o`0000;oYk7O00?o0000
ojNfhonW]^<00onW]^<00ol0003oYk_WojNki`02ojNki`03o`000?nW`>_oYl3[00;oYl3[00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Booooo`006oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ooooooooool0>?ooool3o`0000;odo_Q00Co0000omKjh?oFn^3oe_[P0ol0
00000ooEgMko0000omCHf`02omCHf`05o`000?oCdmWodm?Iom?CfOl000001?oAcMH00ol0003oc/OC
olk7d`02olk7d`05o`000?o:`=3ob/3@ol[0d?l000001?o6^Lh01Ol0003o`[;;ol:bboo2//_o0000
00?o_J_800?o0000okVUaOniYLD00_niYLD00ol0003o]Io2okFO`P02okFO`P05o`000?naVKoo/IVo
ok6I_ol000001?n]U;d00ol0003oZI2kojV@^`03o`0000?oYXbi00?o0000oj>8]onSR;L00_nSR;L0
0onQQKKo0000oj:7]`02oj:7]`07o`000?nPQ;GoX8Beoj24]Ol0003oWhBfo`000003oij1]005o`00
0?nMPKCoWH6doif1]?l000000_nLPKD01Ol0003oVh2eoi^0]OnKP;Go000000CoVWnd00?o0000oiUo
]_nIOkH01?nIOkH01Ol0003oV7nfoiQo]_nHOkKo000000CoUWnh00?o0000oiB0^_nDP;X00_nDP;X0
0ol0003oTH2mo`000002oiN2^PCoUX>l00?o0000oiB4_onDQ;l00_nDQ;l00ol0003oThK2oi>6`P02
oi>6`P05o`000?nAQlGoTHO5oi67aOl000001?n@RLT00ol0003oSXc=ohj<c@02ohj<c@05o`000?n;
S]7oRhkAoh^>dOl000001On9TMH01Ol0003oQiGJohNEf_n7UM[o000000GoQIWO00Ko0000oh>Mi?l0
003o0000ojJ/fol00004ojNag`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNkionW^nL00_nW^nL0
0ol0003oYl3[ojO0j`02ojO0j`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool4
o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`0003Wooooo00Go0000om?khOoCnn7odo_Qo`000003omKjh005o`000?oEgMkoeMgNomGMg_l00000
0ooDf=/01Ol0003odm?Iom?CfOoCdmWo000000CodLgF00?o0000olk7doo>am<00_o>am<01Ol0003o
b/3@ol[0d?o:`=3o000000Coa[W>00Go0000ol:bboo2//_o`[;;o`000003okf[b003o`000?niYLGo
^JG500;o^JG500Go0000okFO`_neWl;o]Io2o`000004ok6I_`03o`000?n]U;go[IBm00;o[IBm0ol0
00000onYT;_o0000ojJ<^@03ojJ<^@03o`000?nSR;OoXhRg00;oXhRg0_nQQKH01?l0003oXXNgoj:7
]ol00004oj24]@03o`000?nNPKCoWX6d00;oWX6d00?o0000oif1]?nMPK@01_l00002oi^0]@03o`00
0?nJOkCoVWnd00;oVWnd0_l00005oiUo]P03o`000?nHOkKoV7nf00;oV7nf00?o0000oiIo^?nFOkP0
0_nFOkP01?l0003oU82joiB0^_nDP;X2o`0000?oUh:j00?o0000oiJ3_?nFPk`00_nFPk`01Ol0003o
U8BooiB4_onDQ;oo000000CoThK200?o0000oi67aOnAQlD00_nAQlD01Ol0003oT8W9oi29bOn@RLWo
000000CoSXc=00?o0000oh^>dOn;S]400_n;S]400ol0003oRI7FohVAeP02ohVAeP03o`000?n7UM[o
QiGJ00;oQiGJ00Co0000ohFIgon5VMooQIWO0ol000001OnV[=_o0000ojJ/fonV[=_o000000?oYk7O
00?o0000ojNfhonW]^<00onW]^<01Ol0003oYk_WojNkionW^nOo000000GoYl3[00?o0000oooooooo
ool07?ooool3o`0000[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Wooooo00Co0000om?khOoCnn7o00000_oFn^02o`00
00CoeMgN00Co0000omCHfooDf=_o00001?oCdmT00ol0003odLgFom7=eP02om7=eP03o`000?o>am?o
c/OC00;oc/OC00Go0000ol[0d?o:`=3ob/3@o`000003olJicP03o`000?o2//_o`[;;00;o`[;;00Go
0000okf[b?nmZlSo_J_8o`000004okVUa@05o`000?neWl;o]Io2okFO`_l000001?naVKl00ol0003o
[IBmo`000002o`0000CoZI2k00?o0000ojJ<^OnVS;T00_nVS;T00ol0003oXhRgoj>8]`02oj>8]`03
o`000?nQQKKoXHFf00;o00001OnPQ;D00ol0003oWX6doij1]002oij1]005o`000?nMPKCo0000oiao
/ol000000_nLOk<00ol0003oVgnco`000002o`0000?oVWnd00Co0000oiYn]?nJO[Co00000onIOkH0
0ol0003oVGjdo`000003oiQo]P03o`000?nFOkSoUWnh00;oUWnh00Go0000oiB0^_l0003o0000oiR1
^005oiN2^P05o`000?nFPkcoUX>loiJ3_?l000001?nDQ;l01Ol0003oThK2oi>6`_nCQ/;o000000Co
THO500?o0000oi29bOn@RLT00_n@RLT00ol0003oSXc=ohj<c@02ohj<c@05o`000?n;S]7oRhkAoh^>
dOl000001On9TMH00ol0003oQiGJohNEfP05o`0000;oYZOG00Ko0000ojJ/fonV[=_o0000ojJ/fol0
0003ojNag`03o`000?nW]^?oYkKS00?oYkKS00?o0000ojNkionW^nL00_nW^nL00ol0003oYl3[ojO0
j`02ojO0j`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`006oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>?oo
ool01?l0003odo_Qom?khOoCnn43o`000003omGQh?l0003oeMgN00?oeMgN00Co0000omCHfooDf=_o
00001?oCdmT00ol0003odLgFom7=eP02om7=eP03o`000?o>am?oc/OC00;oc/OC00Co0000ol[0d?o:
`=3o00001?o6^Lh01Ol0003o`[;;ol:bboo2//_o000000Co_J_800?o0000okVUaOniYLD00_niYLD0
1Ol0003o]Io2okFO`_neWl;o000000?o/IVo0ol00002ojfD_@03o`000?nYT;_oZI2k00;oZI2k00Go
0000ojJ<^OnVS;WoYXbio`000004oj>8]`03o`000?nQQKKoXHFf00;oXHFf00?o0000oj24]OnPQ;D0
0_nPQ;D00ol0003oWX6co`000004oij1]004o`000?nLOk?oW7nco`0000;oW7nc00Go0000oi]o/onK
Ok?oVgnco`000003oiYo]004o`000?nJO[CoVWjdo`0000;oVGnf00Co0000oiUn]?nIO[Co00001?nH
OkH00ol0003oUWnhoiIo^002oiIo^003o`000?nHPKSoV86h00;oV86h1?nGP[X00ol0003oUX>loiJ3
_002oiJ3_005o`000?nDQ;ooU8BooiB4_ol000001?nCQ/800ol0003oTHO5oi67a@02oi67a@05o`00
0?n@RLWoT8W9oi29bOl000001?n>S<d00ol0003oRhkAoh^>d@02oh^>d@03o`000?n9TMKoRI7F00;o
RI7F0ol00002ojFRdPKoYZOG00?o0000ojJ/fonV[=/00_l00004ojNag`03o`000?nW]^?oYkKS00;o
YkKS00?o0000ojNkionW^nL00_nW^nL00ol0003oYl3[ojO0j`03ojO0j`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`006oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0>?ooool01?l0003odo_Qo`000?l00004omGQ
h005o`000?oEgMkoeMgNomGMg_l000000ooDf=/00ol0003odm?Iom?Cf@02om?Cf@03o`000?oAcMKo
dLgF00;odLgF00?o0000olk7doo>am<00_o>am<01?l0003ob/3@ol[0d?l00004olJicP05o`000?o2
//_o`[;;ol:bbol000000_nmZlPCo`000003ojfD_Ol0003oZI2k00?oZI2k00Go0000ojJ<^OnVS;Wo
YXbio`000004oj>8]`03o`000?nQQKKoXHFf00;oXHFf00?oWh:do`000?nPQ;D00_nPQ;D01?l0003o
WX6coij1/ol00003oij1]007o`000?nLOk?oW7ncoiao/ol0003oW7nco`000003oi]o/`;o00000_nJ
Ok@01ol0003oVWjdoiYn]?nJO[Co0000oiUo]_l000000_nIO[@00ol0003oV7nfoiQo]P03oiQo]P04
o`000?nFOkSoUWnho`0000GoV86h00Go0000oiN2^_nGP[[oUh:jo`000004oiJ3_005o`000?nDQ;oo
U8BooiB4_ol000001?nCQ/800ol0003oTHO5oi67a@02oi67a@03o`000?n@RLWoT8W900;oT8W900?o
0000ohj<cOn>S<d00_n>S<d01_l0003oRhkAoh^>dOn;S]7o0000ohVAeP?o000000?oY9g?ojFRd_nU
X]800onUX]85ojJWe`06o`000?nV[=_oYZcKo`000?nV[=_o00000onW/Ml00ol0003oYkKSojNfh`03
ojNfh`03o`000?nW^nOoYk_W00;oYk_W00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o0000>?ooool3o`000003om?Thol0003oeN7P00?oeN7P00Go0000
omGMg_oEgMkoeMgNo`000003omCHf`03o`000?oCdmWodm?I00;odm?I00?o0000om7=e_oAcMH00_oA
cMH01Ol0003oc/OColk7doo>am?o000000?ob/3@00?o0000olJic_o6^Lh00_o6^Lh00ol0003o`[;;
o`000004o`0000;o/Ig41On^VL42oj^D_`?o00001?nYTKd3ojJ=^`Go000000?oZI2ko`000?nVS;T0
0_nVS;T00ol0003oXhRgoj>8]`02oj>8]`03o`000?nQQKKoXHFf00;oXHFf0_nOP[@01?l0003oX8Be
oj24]Ol00002oij1/`06o`000?nNPKCoWX6do`000?nLOk?o00000_nLOk<00ol0003oW7nco`000003
oi]o/`04o`000?nKO[?o0000o`0000GoVWjd00?o0000oiUn]?nIO[@00_nIO[@00ol0003oV7nfoiQo
]P02oiQo]P03o`000?nFOkSo000000;oVH2g1?nHPKP00ol0003oUh:joiN2^P02oiN2^P03o`000?nF
PkcoUX>l00;oUX>l00Go0000oiB4_onDQ;ooU8Boo`000004oi>6`P03o`000?nAQlGoTHO500;oTHO5
00Go0000oi29bOn@RLWoT8W9o`000004ohj<c@03o`000?n;S]7oRhkA00?o00001?nTWLl00ol0003o
YJ;BojFRdP02ojFRdP03o`000?nVYmOoYZOG00;oYZOG00Co0000ojJ/fonV[=_oYZcK0_l00004ojNa
g`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNkionW^nL00_nW^nL00ol0003oYl3[ojO0j`02ojO0
j`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0=oooool01Ol0
003odnCSom?ThooCi>?o000000CoeN7P00Go0000omGMg_oEgMkoeMgNo`000003omCHf`03o`000?oC
dmWodm?I00;odm?I00Go0000om7=e_oAcMKodLgFo`000004olk7d`05o`000?o:`=3ob/3@ol[0d?l0
00000_o6^Lh4o`0000;o]:;61OnaWL@01?l0003o[YW1ojjI`On^VL43o`0000;oZiBo00?o0000ojVA
_OnYTKd00_nYTKd4ojJ=^`CoY8Zi0ol00002ojJ<^@03o`000?nSR;OoXhRg00;oXhRg00?o0000oj65
]_nQQKH00_nQQKH00ol0003oWh:doin2]002o`0000CoWX6c00Go0000oij1]?l0003oW7nco`000002
oiao/`04o`000?nLOk?oW7nco`0000;oVgnc00Co0000oi]n/onKO[?o00001OnJO[@00ol0003oVGjd
oiUn]002oiUn]003o`000?nHOkKoV7nf00?oV7nf00Go0000oiV0]onIP;OoVH2go`000004oiR1^005
o`000?nGP[[oUh:joiN2^_l000001?nFPk`01Ol0003oU8BooiB4_onDQ;oo000000CoThK200?o0000
oi67aOnAQlD00_nAQlD00ol0003oT8W9oi29b@02oi29b@04o`000?n>S<goSXc=ohj<c@?o00000_nS
VL/6ojBMc`CoYJ;B00?o0000ojJWeonVYmL00onVYmL01Ol0003oYZcKojJ/fonV[=_o000000CoYk7O
00?o0000ojNfhonW]^<00onW]^<00ol0003oYk_WojNki`02ojNki`03o`000?nW`>_oYl3[00;oYl3[
00?o0000ooooooooool07_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool002Cooooo00?o
0000ooooooooool0=oooool00ol0003odnCSom?Th`02om?Th`05o`000?oEhN3oeN7PomGQh?l00000
1?oEgMh01Ol0003oe=SKomCHfooDf=_o000000Codm?I00Go0000om7=e_oAcMKodLgFo`000004olk7
d`03o`000?o:`=3ob/3@00Co00000_ngYlT4okBRaP03o`000?naWLCo/Ig400;o/Ig41?l000000on^
VL7o0000oj^D_`02oj^D_`03o`000?nYTKgoZI6m00;oZI6m00Go0000ojJ=^onVSK_oYXfko`000004
ojB:^@;oXXNg0ol00004oj>8]`03o`000?nQQKKoXHFf00;oXHFf00Go0000oin2]?nOP[CoWh:do`00
0005oij1/`04o`000?nLOk?oW7nco`0000;oW7nc00Co0000oiao/onLOk?o00000_nKOk<00ol0003o
Vgjcoi]n/`02o`0000?oVWjd00?o0000oiYn/ol000001?nIO[@01Ol0003oV7nfoiQo]_nHOkKo0000
00CoVH2g00?o0000oiR1^?nHPKP00_nHPKP00ol0003oUh:joiN2^P02oiN2^P05o`000?nFPkcoUX>l
oiJ3_?l000001?nDQ;l00ol0003oThK2oi>6`P02oi>6`P03o`000?nAQlGoTHO500;oTHO500Ko0000
oi29bOn@RLWoT8W9o`000?n>S<d2o`000003oj:EaonSVL_oXiW;00?oXiW;1OnTWLl00ol0003oYJ;B
ojFRdP02ojFRdP03o`000?nVYmOoYZOG00;oYZOG00?o0000ojJ/fonV[=/00_nV[=/00ol0003oYk7O
ojNag`02ojNag`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNkionW^nL00_nW^nL00ol0003oYl3[
ojO0j`02ojO0j`03o`000?oooooooooo01gooooo00?o0000ooooool000001Oooool00omEEEGoIVIV
o`000007ooooo`009?ooool00ol0003oooooooooo`0gooooo`03o`000?oCi>?odnCS00;odnCS00Go
0000omGQh?oEhN3oeN7Po`000004omGMgP05o`000?oDf=_oe=SKomCHfol000001?oCdmT01Ol0003o
dLgFom7=e_oAcMKo000000Coc/OC0ol000000oni[<co]jO9okNWb@03okNWb@05o`000?ndX/Ko]:;6
okBRa_l000000onaWL@2o`0000Co[YW100Go0000oj^D_on[U;ooZiBoo`000004ojVA_@05o`000?nV
SK_oYXfkojJ=^ol000001?nTR[T01?l0003oXXNgoj:7]onRQkL2o`0000;oXhRg00?o0000oj65]_nQ
QKH00_nQQKH00ol0003oWh:doin2]002oin2]003oif1/ol0003oWX6c00?oWX6c00Oo0000oiao/onL
Ok?oW7nco`000?nLOk?o000000;oW7nc00Co0000oi]o/onKOk?o00000_nKO[<00ol0003oVgjco`00
0002oiYn]003o`000?nJO[?o000000CoVGjd00Co0000oiQo]_nHOkKo00000_nJOkD4oiV0]`05o`00
0?nHPKSoV86hoiR1^?l000001?nGP[X00ol0003oUX>loiJ3_002oiJ3_005o`000?nDQ;ooU8BooiB4
_ol000001?nCQ/800ol0003oTHO5oi67a@02oi67a@03o`000?n@RLWoT8W900?o00000onRULL00ol0
003oXiW;oj>Ib`02oj>Ib`GoY9g?00?o0000ojFRd_nUX]800_nUX]800ol0003oYZOGojJWe`02ojJW
e`03o`000?nV[=_oYZcK00;oYZcK00?o0000ojNagonW/Ml00_nW/Ml00ol0003oYkKSojNfh`02ojNf
h`03o`000?nW^nOoYk_W00?oYk_W00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00cooooo000Tooooo`;o0000>?ooool01Ol0003odnCSom?ThooCi>?o0000
00CoeN7P00?o0000omGMg_oEgMh00_oEgMh01Ol0003oe=SKomCHfooDf=_o000000?odm?I00?o0000
om7=e_oAcMH00_oAcMH00ol0003oc/OColk7d`03o`0000?o^Jc<00?o0000okNWbOngYlT00_ngYlT0
0ol0003o]:;6okBRaP02okBRaP?o000000?o/Ig4o`000?n^VL400on^VL400ol0003oZiBooj^D_`02
oj^D_`05o`000?nYTKgoZI6mojVA_Ol000000onVSK/00ol0003oY8ZiojB:^@02ojB:^@04o`000?nR
QkOoXXNgoj:7]`;oXHFf0ol00004oj65]P03o`000?nOP[CoWh:d00;oWh:d00?o0000oif1/ol00000
0_nNPK<00ol0003oW7nbo`000002oiao/`04o`000?nLOk?oW7ncoiao/`Go00000_nKO[<01_l0003o
Vgjcoi]n/ol0003oVWjdo`0000;oVWjc00Oo0000oiUn]?nIO[CoVGjdo`000?nHOkKo000000?oVWne
00Go0000oiV0]onIP;OoVH2go`000004oiR1^003o`000?nGP[[oUh:j00;oUh:j00Go0000oiJ3_?nF
PkcoUX>lo`000004oiB4_`05o`000?nCQ/;oThK2oi>6`_l000000onAQlD4o`0000;oXI;41OnRULL4
oj>Ib`03o`000?nTWLooY9g?00?oY9g?00Go0000ojFRd_nUX];oYJ;Bo`000005ojJWe`04o`000?nV
[=_oYZcKojJ/f`;o00000onW/Ml00ol0003oYkKSojNfh`03ojNfh`03o`000?nW^nOoYk_W00;oYk_W
00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`0Nooooo`?o00003Oooool002Cooooo00?o
0000ooooooooool0=oooool01Ol0003odnCSom?ThooCi>?o000000CoeN7P00?o0000omGMg_oEgMh0
0_oEgMh01Ol0003oe=SKomCHfooDf=_o000000?odm?I00Co0000om7=e_oAcMKodLgF1?l00002okba
d0Co^Jc<00?o0000okNWbOngYlT00_ngYlT00ol0003o]:;6o`000003o`0000Co/Ig400Go0000ojjI
`On^VL7o[YW1o`000004oj^D_`05o`000?nYTKgoZI6mojVA_Ol000000onVSK/00ol0003oY8ZiojB:
^@02ojB:^@05o`000?nRQkOoXXNgoj:7]ol000000onQQKH2o`0000?oXHFf00?o0000oin2]?nOP[@0
0_nOP[@01_l0003oWH6coif1/ol0003oWX6co`0000;oW7nb00Co0000oiao/ol0003oW7nc0_l00000
1onKO[;o0000oi]n/_nKO[;o0000oi]n/ol000001?nKO[<01Ol0003oVWjcoiYn/onJO[?o000000Co
VGjd00?o0000oiYo]OnJOkD00_nJOkD01Ol0003oVH2goiV0]onIP;Oo000000CoV86h00?o0000oiN2
^_nGP[X00_nGP[X00ol0003oUX>loiJ3_002oiJ3_005o`000?nDQ;ooU8BooiB4_ol000000onCQ/84
o`0000;oXHo11?nQT/@00ol0003oXYG7oj:Ea`02oj:Ea`03o`000?nSVL_oXiW;00;oXiW;00?o0000
ojBMconTWLl00_nTWLl00ol0003oYJ;BojFRdP02ojFRdP03o`000?nVYmOoYZOG00;oYZOG00?o0000
ojJ/fonV[=/00_nV[=/2o`0000?oYk7O00?o0000ojNfhonW]^<00_nW]^<00ol0003oYk_WojNki`02
ojNki`03o`000?nW`>_oYl3[00;oYl3[00?o0000ooooooooool06oooool3o`0000;ooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0=oooool01Ol0003odnCSom?ThooCi>?o
000000CoeN7P00?o0000omGMg_oEgMh00_oEgMh01?l0003oe=SKomCHfol00004om?Cf@05o`000?oA
cMKo0000o`000?nn]m<01Onl/M000ol0003o^Jc<okV/c002okV/c0?o]jO90ol00003okBRaP03o`00
0?naWLCo/Ig400;o/Ig400Go0000ojjI`On^VL7o[YW1o`000004oj^D_`05o`000?nYTKgoZI6mojVA
_Ol000000onVSK/00ol0003oY8ZiojB:^@02ojB:^@05o`000?nRQkOoXXNgoj:7]ol000000onQQKH2
oin3]@Co00000onOP[@00ol0003oWH6coif1/`02oif1/`05o`000?nLOk;oW7nboiao/_l000000_nL
Ok<01Ol0003oW7jbo`000?nKO[;o000000;oVgjb00?o0000oi]n/ol000001?nKO[<00ol0003oVWjc
oiYn/`02oiYn/`03o`000?nIO[CoVGjd00;o00001OnJOkD01Ol0003oVH2goiV0]onIP;Oo000000?o
V86h00?o0000oiN2^_nGP[X00_nGP[X00ol0003oUX>loiJ3_002oiJ3_006o`000?nDQ;ooU8BooiB4
_ol0003oThK20_l000000onPS;ooXHo1oj6?`@03oj6?`@03o`000?nQT/CoXI;400;oXI;41?nRULL0
0ol0003oXiW;oj>Ib`02oj>Ib`03o`000?nTWLooY9g?00;oY9g?00?o0000ojFRd_nUX]800_nUX]80
0ol0003oYZOGojJWe`02ojJWe`03o`000?nV[=_oYZcK00;oYZcK00?o0000ojNagol000000_nW/Ml0
0ol0003oYkKSojNfh`02ojNfh`03o`000?nW^nOoYk_W00?oYk_W00Co0000ojO0jonW`>_oYl3[0_l0
000Iooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oCi>?odnCS00;odnCS00?o0000omGQh?oEhN000_oEhN000ol0003oeMgNomGMgP02
omGMgP04o`000?oDf=_oe=SKo`0000Codm?I0_l00003okjgd`03o`000?nl/M3o_;7@00;o_;7@00?o
0000okV/c?ni[<`00_ni[<`3o`0000;o]jO900Go0000okBRa_ndX/Ko]:;6o`000004ok6Ma005o`00
0?n^VL7o[YW1ojjI`Ol000001?n[U;l01Ol0003oZI6mojVA_OnYTKgo000000?oYXfk00?o0000ojB:
^OnTR[T00_nTR[T01Ol0003oXXNgoj:7]onRQkOo000000?oXHFf00?o0000oin3]OnOPkD00_nOPkD2
o`0000;oWh:d00?o0000oif1/onMPK<00_nMPK<00onLOk;o0000oiao/P02oiao/P07o`000?nLOk?o
0000oian/_l0003oVgjbo`000002oi]n/P?o00000onKO[<00ol0003oVgjbo`000003oiYn/`03o`00
0?nIO[Co000000;oVWnd00?o0000oiYo]OnJOkD00_nJOkD01Ol0003oVH2goiV0]onIP;Oo000000Co
V86h00?o0000oiN2^_nGP[X00_nGP[X01Ol0003oUX>loiJ3_?nFPkco000000;oU8Bo0ol00003oj2<
_`03o`000?nQSl7oXHo100?oXHo11?nQT/@00ol0003oXYG7oj:Ea`02oj:Ea`05o`000?nSVL_oXiW;
oj>Ibol000001?nTWLl00ol0003oYJ;BojFRdP02ojFRdP03o`000?nVYmOoYZOG00?oYZOG00Oo0000
ojJ/fonV[=_oYZcKo`000?nW/Moo000000?oYk7O00?o0000ojNfhonW]^<00_nW]^<00ol0003oYk_W
ojNki`02ojNki`06o`000?nW`>_o0000o`000?o3e^So00005Oooool4o`0000Sooooo00?o0000oooo
ooooool02oooool002?ooooo0ol0000gooooo`03o`000?oCi>?odnCS00;odnCS00?o0000omGQh?oE
hN000_oEhN001Ol0003oeMgNomGMg_oEgMko000000?oe=SK00Co0000om?CfOoCdmWodm?I0_l00004
okjgd`03o`000?nl/M3o_;7@00?o_;7@00?o^Jc<o`000?l000000_l00004okNWb@05o`000?ndX/Ko
]:;6okBRa_l000001?naWL@01Ol0003o[YW1ojjI`On^VL7o000000CoZiBo00?o0000ojVA_OnYTKd0
0_nYTKd01?l0003oYXfkojJ=^ol00004ojB:^@05o`000?nRQkOoXXNgoj:7]ol000000onQQKH00ol0
003oWh>eoin3]@02oin3]@03o`000?nNPKCo000000;o00001?nMPK<00ol0003oW7nbo`000003oiao
/P04o`000?nLO[;o0000oian/P;o00000_nKO[800ol0003oVgjbo`000003oi]n/`03o`000?nKO[;o
000000CoVWjc00Go0000oiYo]?nJOkCoVWndo`000004oiYo]@05o`000?nIP;OoVH2goiV0]ol00000
1?nHPKP00ol0003oUh:joiN2^P02oiN2^P03o`000?nFPkcoUX>l00Co00000_nORK`5oj2<_`GoXHo1
00Go0000oj6Ba?nQT/CoXI;4o`000004oj:Ea`03o`000?nSVL_oXiW;00;oXiW;00?o0000ojBMconT
WLl00_nTWLl00ol0003oYJ;BojFRdP02ojFRdP03o`000?nVYmOoYZOG00;oYZOG00?o0000ojJ/fonV
[=/00_nV[=/00ol0003oYk7Oo`000002ojNag`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNkionW
^nL00_nW^nL2o`0000?o`mKX00?o0000ooooooooool04?ooool3o`0000gooooo00?o0000oooooooo
ool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003odnCSom?Th`02om?Th`03o`00
0?oEhN3oeN7P00;oeN7P00Go0000omGMg_oEgMkoeMgNo`000003omCHf`Co000000?o`;cFokjgdonn
]m<01?nn]m<00ol0003o_;7@okbad003o`0000?o^Jc<00?o0000okNWbOngYlT00_ngYlT01Ol0003o
]:;6okBRa_ndX/Ko000000Co/Ig400?o0000ojjI`On^VL400_n^VL401Ol0003oZiBooj^D_on[U;oo
000000CoZI6m00Go0000ojJ=^onVSK_oYXfko`000004ojB:^@04o`000?nRQkOoXXNgo`0000?oXHFf
00?o0000oin3]OnOPkD00_nOPkD01?l0003oWX6doij1]?nNPK@2o`0000?oWH6c00Co0000oiao/_nL
Ok;o00000_nLOk802ol0003oW7jbo`000?nLO[;o0000oi]n/_l0003oVgjbo`000?nKO[;o000000;o
Vgjc00Go0000oi]n/_nKO[;oVgjbo`000002oiYn/`;o00000onJOk@00ol0003oVWneoiYo]@03oiYo
]@05o`000?nIP;OoVH2goiV0]ol000000onHPKP00ol0003oUh:joiN2^P02oiN2^P?o00000_nNQkX4
oin9_003o`000?nPS;ooX8bo00;oX8bo00?o0000oj6?`OnQSl400_nQSl400ol0003oXI;4oj6Ba002
oj6Ba005o`000?nRULOoXYG7oj:Eaol000001?nSVL/00ol0003oY9g?ojBMc`02ojBMc`03o`000?nU
X];oYJ;B00;oYJ;B00?o0000ojJWeonVYmL00_nVYmL00ol0003oYZcKojJ/f`02ojJ/f`04o`000?nW
/MooYk7Oo`0000;oYk7O00Ko0000ojNfhonW]^?oYkKSo`000?nW^nL3o`000003olCAiOl0003o`mKX
00;o`mKX00?o0000ooooooooool03Oooool3o`00013ooooo00?o0000ooooooooool02_ooool002?o
oooo00?o0000ooooooooool0=oooool00ol0003odnCSom?Th`02om?Th`03o`000?oEhN3oeN7P00;o
eN7P00Go0000omGMg_oEgMkoeMgNo`000002omCHf`;o00001?o0_=H00ol0003o_[OCokjgd`03okjg
d`?o00000_nl/M001Ol0003o^Jc<okV/c?ni[<co000000Co]jO900?o0000okBRa_ndX/H00_ndX/H0
1Ol0003o/Ig4ok6Ma?naWLCo000000Co[YW100Go0000oj^D_on[U;ooZiBoo`000004ojVA_@05o`00
0?nVSK_oYXfkojJ=^ol000001?nTR[T01Ol0003oXXNgoj:7]onRQkOo000000;oXHFf00?o0000oin3
]OnOPkD00_nOPkD01_l0003oWX6doij1]?nNPKCo0000oif0/`;o000000?oWH6co`000?nLOk800_nL
Ok82o`000003oian/_l0003oW7jb00;o000000GoVgjbo`000?nKO[;o0000oi]n/P02o`000003oi]n
/ol0003oVgjb00;oVgjb00?o0000oiYn/ol000000_nKO[<01Ol0003oVWndoiYo]?nJOkCo000000Co
VWne00Go0000oiV0]onIP;OoVH2go`000004oiR1^0Co000000?oWXFioij7^_nNQkX00_nNQkX00ol0
003oWhVloin9_002oin9_0CoX8bo00?o0000oj6?`OnQSl400_nQSl400ol0003oXI;4oj6Ba002oj6B
a005o`000?nRULOoXYG7oj:Eaol000001?nSVL/00ol0003oY9g?ojBMc`02ojBMc`03o`000?nUX];o
YJ;B00;oYJ;B00?o0000ojJWeonVYmL00onVYmL01Ol0003oYZcKojJ/fonV[=_o000000?oYk7O00?o
0000ojNagol000000onW]^<2o`0000Coa=7U00Go0000ol?Fj?o3e^So`mKXo`00000;ooooo`Co0000
4oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`000?oC
i>?odnCS00;odnCS00Go0000omGQh?oEhN3oeN7Po`000004omGMgP?o000000?o`/7Io`000?o0_=H0
1?o0_=H2okjgd`Co00001?nl/M001Ol0003o^Jc<okV/c?ni[<co000000Co]jO900?o0000okBRa_nd
X/H00_ndX/H01Ol0003o/Ig4ok6Ma?naWLCo000000Co[YW100Go0000oj^D_on[U;ooZiBoo`000004
ojVA_@05o`000?nVSK_oYXfkojJ=^ol000001?nTR[T01Ol0003oXXNgoj:7]onRQkOo000000;oXHFf
00?o0000oin3]OnOPkD00_nOPkD01Ol0003oWX6doij1]?nNPKCo000000?oWH2c00?oWH6co`000?nL
Ok800onLOk801?l0003oW7jbo`000?nLO[82o`000008oi]n/_l0003oVgjbo`000?nKO[;o0000oi]n
/_l00004oi]n/P;o00000onKO[<01Ol0003oVWndoiYo]?nJOkCo000000CoVWne00Go0000oiV0]onI
P;OoVH2go`000002oiR1^0?o00001?nNQKT00ol0003oWXNjoij7^P02oij7^PCoWhVl00Go0000oj2<
_onPS;ooX8boo`000005oj6?`@05o`000?nQT/CoXI;4oj6Ba?l000001?nRULL00ol0003oXiW;oj>I
b`02oj>Ib`03o`000?nTWLooY9g?00;oY9g?00?o0000ojFRd_nUX]800_nUX]800ol0003oYZOGojJW
e`02ojJWe`03o`000?nV[=_oYZcK00;oYZcK00Oo0000ojNagonW/Moo0000ojNagol0003oYkKS00;o
000000?o`lcQo`000?o4dND00oo4dND01Ol0003o`mKXol?Fj?o3e^So000000Sooooo0ol0000Goooo
o`03o`000?oooooooooo00[ooooo000Sooooo`?o0000=oooool00ol0003odnCSom?Th`02om?Th`05
o`000?oEhN3oeN7PomGQh?l000000ooEgMh2o`0000?o`/7I00?o0000ol2le_o0_=H00_o0_=H3o`00
00?o_[OC00?o0000okbad?nl/M000_nl/M001Ol0003o^Jc<okV/c?ni[<co000000Co]jO900?o0000
okBRa_ndX/H00_ndX/H01Ol0003o/Ig4ok6Ma?naWLCo000000Co[YW100Go0000oj^D_on[U;ooZiBo
o`000004ojVA_@05o`000?nVSK_oYXfkojJ=^ol000001?nTR[T01Ol0003oXXNgoj:7]onRQkOo0000
00?oXHFf00Go0000oin3]OnOPkGoWh>eo`000003oij1]003o`000?nMP;?oWH2c00;oWH2c0_l00003
oiao/P03o`000?nLO[;oW7jb00;o000000CoW7jboi]n/_l0003oVgjb0_l00002oi]n/P07o`000?nK
O[;oVgjboi]n/_l0003oVgjbo`000003oi]n/`03o`000?nJOkCoVWnd00;oVWnd00?o0000oiYo]OnJ
OkD00_nJOkD00ol0003oVH2go`000003o`0000;oWH>g1OnNQKT00ol0003oWXNjoij7^P02oij7^P05
o`000?nORKcoWhVloin9_?l000001?nPS;l00ol0003oXHo1oj6?`@02oj6?`@03o`000?nQT/CoXI;4
00;oXI;400Go0000oj:EaonRULOoXYG7o`000004oj>Ib`03o`000?nTWLooY9g?00;oY9g?00?o0000
ojFRd_nUX]800_nUX]800ol0003oYZOGojJWe`02ojJWe`03o`000?nV[=_oYZcK00;oYZcK00Co0000
ojNagonW/MooYk7O0ol00003ol?<h@03o`000?o4dNGoa=7U00;oa=7U00Go0000ol?Fj?o3e^So`mKX
o`000005ooooo`?o00006_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooooooo
o`0gooooo`05o`000?oCi>?odnCSom?Thol000001?oEhN001_l0003oeMgNo`000?l0003o`lKMo`00
00Co`/7I1?l000000oo0_=Ko0000okjgd`03okjgd`03o`000?nl/M3o_;7@00;o_;7@00?o0000okV/
c?ni[<`00_ni[<`01Ol0003o]jO9okNWbOngYlWo000000Co]:;600Go0000ok6Ma?naWLCo/Ig4o`00
0004ojjI`@03o`000?n[U;ooZiBo00;oZiBo00Go0000ojVA_OnYTKgoZI6mo`000003ojJ=^`03o`00
0?nTR[WoY8Zi00;oY8Zi00Go0000oj:7]onRQkOoXXNgo`000003oj65]P03o`000?nOPkGoWh>e00;o
Wh>e00Co0000oij1]?nNPKCo00001?nMP;<00ol0003oW7nbo`000002oiao/P;o00000onLO[86o`00
0006oi]n/_l0003oVgjbo`000?nKO[;o00000onKO[801Ol0003oVgjcoi]n/onKO[?o000000?oVWnd
00Co0000oiYo]OnJOkGoVWne0ol00002oif2]PCoWH>g00?o0000oij5^OnNQKT00onNQKT01Ol0003o
WXNjoij7^_nNQk[o000000?oWhVl00?o0000oj2<_onPS;l00_nPS;l00ol0003oXHo1oj6?`@02oj6?
`@03o`000?nQT/CoXI;400;oXI;400Go0000oj:EaonRULOoXYG7o`000004oj>Ib`03o`000?nTWLoo
Y9g?00;oY9g?00?o0000ojFRd_nUX]800_nUX]800ol0003oYZOGojJWe`03ojJWe`06o`000?nV[=_o
YZcKojJ/fol0003oYk7O1Ol00003ol?<h@03o`000?o4dNGoa=7U00;oa=7U00Go0000ol?Fj?o3e^So
`mKXo`000002ooooo`?o00007Oooool00ol0003oooooooooo`0:ooooo`0000Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`03o`000?oooooooooo03Sooooo00Go0000om?ThooCi>?odnCSo`000004omGQh0;o00000oo3a]d0
0ol0003o`/7Iol;1f@03o`0000Co`;cF00?o0000okjgdonn]m<00_nn]m<00ol0003o_;7@okbad003
okbad005o`000?ni[<co^Jc<okV/c?l000000ongYlT00ol0003o]:;6okBRaP02okBRaP03o`000?na
WLCo/Ig400;o/Ig400Go0000ojjI`On^VL7o[YW1o`000004oj^D_`05o`000?nYTKgoZI6mojVA_Ol0
00000onVSK/00ol0003oY8ZiojB:^@02ojB:^@05o`000?nRQkOoXXNgoj:7]ol000000onQQKH00ol0
003oWh>eoin3]@02oin3]@05o`000?nNPKCoWX6doij1]?l000000onMP;<01Ol0003oW7nboiao/_nL
Ok;o000000;oW7jb00?o0000oian/_l000000ol000001OnKOK7o0000o`000?nKO[;o000000;oVgjb
00?o0000oi]n/_nKO[800_nKO[801Ol0003oVgjcoi]n/onKO[?o000000?oVWnd00Go0000oiYo]Ol0
003o0000oib1]004oif2]P03o`000?nMPkOoWH>g00;oWH>g1OnNQKT01Ol0003oWXNjoij7^_nNQk[o
000000CoWhVl00Go0000oj2<_onPS;ooX8boo`000004oj6?`@03o`000?nQT/CoXI;400;oXI;400?o
0000oj:EaonRULL00_nRULL00ol0003oXiW;oj>Ib`02oj>Ib`05o`000?nTWLooY9g?ojBMcol00000
1OnUX]800ol0003oYZOGojJWe`02ojJWe`04o`000?nV[=_oYZcKojJ/f`;o00000oo3a]d2o`0000?o
`lcQ00?o0000olCAiOo4dND00_o4dND01?l0003o`mKXol?Fj?o3e^P3o`00023ooooo00?o0000oooo
ooooool02_ooool00005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool0
1Ol0003odnCSom?ThooCi>?o000000?oeN7P0_l00004ol?6g@?o00000_o2`MT00ol0003o`;cFol2l
eP02ol2leP03o`000?nn]m?o_[OC00;o_[OC00?o0000okbad?nl/M000onl/M001Ol0003o^Jc<okV/
c?ni[<co000000?o]jO900?o0000okBRa_ndX/H00_ndX/H00ol0003o/Ig4ok6Ma002ok6Ma005o`00
0?n^VL7o[YW1ojjI`Ol000001?n[U;l01Ol0003oZI6mojVA_OnYTKgo000000?oYXfk00?o0000ojB:
^OnTR[T00_nTR[T01Ol0003oXXNgoj:7]onRQkOo000000?oXHFf00?o0000oin3]OnOPkD00_nOPkD0
1Ol0003oWX6doij1]?nNPKCo000000?oWH2c00Co0000oiao/_nLOk;oW7nb0_l00004oian/P?o0000
00GoVgfao`000?l0003oVgjbo`000002oi]n/P03o`000?nKO[;oVgjb00;oVgjb00Go0000oi]n/onK
O[?oVgjco`000002oiYo]0?o00000onLPK@00ol0003oWH:foif2]P02oif2]PCoWH>g00?o0000oij5
^OnNQKT00_nNQKT01Ol0003oWXNjoij7^_nNQk[o000000CoWhVl00Go0000oj2<_onPS;ooX8boo`00
0005oj6?`@05o`000?nQT/CoXI;4oj6Ba?l000001?nRULL00ol0003oXiW;oj>Ib`02oj>Ib`03o`00
0?nTWLooY9g?00;oY9g?00?o0000ojFRd_nUX]800_nUX]800ol0003oYZOGojJWe`02ojJWe`06o`00
0?nV[=_o0000o`000?o1`=Wo00001?o3a]d01Ol0003o`lcQol?<hOo3c>7o000000Coa=7U00Go0000
ol?Fj?o3e^So`mKXo`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooo
oooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000>?oo
ool00ol0003odnCSom?Th`02om?Th`Co000000Co`l_Po`000?o3a]go`lKM0_l000000oo3a]go0000
ol;1f@03ol;1f@03o`000?o0_=Ko`;cF00;o`;cF00?o0000okjgdonn]m<00_nn]m<00ol0003o_;7@
okbad002okbad005o`000?ni[<co^Jc<okV/c?l000001?ngYlT01Ol0003o]:;6okBRa_ndX/Ko0000
00Co/Ig400Go0000ojjI`On^VL7o[YW1o`000004oj^D_`03o`000?nYTKgo0000017o000000?oXHFf
o`000?nOPkD00onOPkD01Ol0003oWX6doij1]?nNPKCo000000?oWH2c00Ko0000oiao/_nLOk;oW7nb
o`000?nLO[82o`000003oian/_l0003o000000Ko00000_nKO[800ol0003oVgjbo`000004oi]n/P03
o`000?nKO[?o000000?o00000_nLP;<5oib1]0CoWH:f00Go0000oif3]onMPkOoWH>go`000004oij5
^@03o`000?nNQk[oWXNj00;oWXNj00Go0000oin9_?nORKcoWhVlo`000004oj2<_`03o`000?nQSl7o
XHo100;oXHo100?o0000oj6Ba?nQT/@00_nQT/@01Ol0003oXYG7oj:EaonRULOo000000CoXiW;00?o
0000ojBMconTWLl00_nTWLl00ol0003oYJ;BojFRdP02ojFRdP04o`000?nVYmOoYZOGojJWe`?o0000
0oo1`=T00ol0003o`lKMol?6g@02ol?6g@;o00000_o3c>400ol0003oa=7UolCAi@02olCAi@05o`00
0?o3e^So`mKXol?Fj?l000008oooool00ol0003oooooooooo`09ooooo`0000Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003o
ooooooooo`0gooooo`04o`000?oCi>?odnCSom?Th`;o00001?o3bn03o`0000?o`lKM00?o0000ol;1
fOo2`MT00_o2`MT00ol0003o`;cFol2leP02ol2leP03o`000?nn]m?o_[OC00;o_[OC00?o0000okba
d?nl/M000_nl/M001Ol0003o^Jc<okV/c?ni[<co000000Co]jO900?o0000okBRa_ndX/H00_ndX/H0
1_l0003o/Ig4ok6Ma?naWLCo0000ojjI`@Wo00000_nORK`4oij7^PGoWXFi00Go0000oif3]onMPkOo
WH>go`000002oif2]PWo000000?oWX6do`000?nMP;<00_nMP;<01Ol0003oW7nboiao/_nLOk;o0000
00CoW7jb2?l000001OnKO[;o0000oi]n/_nKO[;o000000?oVgjb0ol00002oiao/`CoW82c00?o0000
oib1]?nLPK@00_nLPK@01Ol0003oWH:foif2]_nMP[Ko000000?oWH>g00?o0000oij5^OnNQKT00_nN
QKT00ol0003oWXNjoij7^P02oij7^P03o`000?nORKcoWhVl00;oWhVl00Go0000oj2<_onPS;ooX8bo
o`000004oj6?`@03o`000?nQT/CoXI;400;oXI;400Go0000oj:EaonRULOoXYG7o`000005oj>Ib`05
o`000?nTWLooY9g?ojBMcol000001?nUX]84o`0000;o_k[F00Go0000ol70fOo1`=Wo`L3Io`000004
ol?6g@05o`000?o3c>7o0000ol?<hOl000001?o4dND01Ol0003o`mKXol?Fj?o3e^So000002?ooooo
00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0gooooo`Co
000000?o`loSo`000?o3bn000ol000000oo3bn3o0000ol?6g@03ol?6g@03o`000?o2`MWo`/7I00;o
`/7I00?o0000ol2le_o0_=H00_o0_=H00ol0003o_[OCokjgd`02okjgd`03o`000?nl/M3o_;7@00;o
_;7@00Go0000okV/c?ni[<co^Jc<o`000004okNWb@03o`000?ndX/Ko]:;600;o]:;600?o0000ok6M
a?l000000ol00002oj6?`@GoX8bo1?nORK`01Ol0003oWXNjoij7^_nNQk[o000000CoWXFi00Go0000
oif3]onMPkOoWH>go`000003oif2]P03o`000?nLPKCoW86d00;oW86d00?o0000oib0/onLP;<01?l0
00000onMP;?o0000oiao/P03oiao/P04o`000?nLO[;oW7jboian/POo000000?oVgfao`000?nKO[80
0_nKO[801Ol0003oVgjbo`000?l0003oW7jb00CoW7nc00?o0000oib0/onLP;<00_nLP;<01Ol0003o
W86doib1]?nLPKCo000000?oWH:f00?o0000oif3]onMPkL00_nMPkL01Ol0003oWXFioij5^OnNQKWo
000000CoWXNj00?o0000oin9_?nORK`00_nORK`01Ol0003oX8booj2<_onPS;oo000000CoXHo100?o
0000oj6Ba?nQT/@00_nQT/@00ol0003oXYG7oj:Ea`02oj:Ea`03o`000?nSVL_oXiW;00;oXiW;00?o
0000ojBMconTWLl00_nTWLl4o`000003okbdd_l0003o_k[F00?o_k[F00Go0000ol70fOo1`=Wo`L3I
o`000004ol?6g@05o`000?o3c>7o0000ol?<hOl000001?o4dND01Ol0003o`mKXol?Fj?o3e^So0000
02?ooooo00?o0000ooooooooool02Oooool00005oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01?l0
003o`loSol??hoo3cn<3o`0000Co`l_P00?o0000ol?6gOo3a]d00_o3a]d00ol0003o`/7Iol;1f@02
ol;1f@03o`000?o0_=Ko`;cF00;o`;cF00?o0000okjgdonn]m<00_nn]m<00ol0003o_;7@okbad002
okbad005o`000?ni[<co^Jc<okV/c?l000001?ngYlT00ol0003o]:;6okBRaP04o`0000;oXI;41?nQ
Sl400ol0003oX8booj2<_`02oj2<_`03o`000?nORKcoWhVl00;oWhVl1?nNQkX5oij5^@05o`000?nM
PkOoWH>goif3]ol000000_nMP[H00ol0003oW86doib1]002oib1]005o`000?nLP;?oW82coib0/ol0
00000_nLOk<9o`000003oian/_l0003oVgfa00Oo00000_nKO[83o`0000?oW7jb00?o0000oiao/onL
Ok<00_nLOk<01Ol0003oW82coib0/onLP;?o000000?oW86d00Go0000oif2]_nMP[KoWH:fo`000004
oif3]`03o`000?nNQKWoWXFi00;oWXFi00Go0000oij7^_nNQk[oWXNjo`000004oin9_005o`000?nP
S;ooX8booj2<_ol000001OnQSl400ol0003oXI;4oj6Ba002oj6Ba005o`000?nRULOoXYG7oj:Eaol0
00001?nSVL/01?l0003oY9g?ojBMconTWLl2o`0000Co_;CB00?o0000oknje_no^]H00_no^]H01Ol0
003o`L3Iol70fOo1`=Wo000000Co`lKM00?o0000ol?<hOo3c>400_l00004olCAi@05o`000?o3e^So
`mKXol?Fj?l000008oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000
>?ooool4o`0000;o`loS00?o0000ol?;h?o3bn000_o3bn000ol0003o`lKMol?6g@03ol?6g@03o`00
0?o2`MWo`/7I00;o`/7I00Go0000ol2le_o0_=Ko`;cFo`000004okjgd`03o`000?nl/M3o_;7@00;o
_;7@00?o0000okV/c?ni[<`00_ni[<`00ol0003o]jO9okNWb@04o`0000;oXYG71?nQT/@00ol0003o
XHo1oj6?`@02oj6?`@GoX8bo1?nORK`01Ol0003oWXNjoij7^_nNQk[o000000CoWXFi00Go0000oif3
]onMPkOoWH>go`000003oif2]P05o`000?nLPKCoW86doib1]?l000000onLP;<01Ol0003oW7ncoiao
/onLOk?o000000CoW7jb00?o0000oi]n/_nKO[803?l00002oi]n/P05o`000?nLO[;oW7jboian/_l0
00001?nLOk<01Ol0003oW82coib0/onLP;?o000000CoW86d00Go0000oif2]_nMP[KoWH:fo`000003
oif3]`03o`000?nNQKWoWXFi00;oWXFi00?o0000oij7^_nNQkX00_nNQkX01Ol0003oWhVloin9_?nO
RKco000000CoX8bo00?o0000oj6?`OnQSl400_nQSl400ol0003oXI;4oj6Ba002oj6Ba005o`000?nR
ULOoXYG7oj:Eaol000001OnSVL/3o`000003okV^c_l0003o_;CB00?o_;CB00?o0000oknje_no^]H0
0_no^]H01Ol0003o`L3Iol70fOo1`=Wo000000Co`lKM00Co0000ol?<hOo3c>7o`lcQ0_l00003olCA
i@05o`000?o3e^So`mKXol?Fj?l000008oooool00ol0003oooooooooo`09ooooo`0000Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o
0000ooooooooool0=_ooool4o`0000Co`loS00?o0000ol?;h?o3bn000oo3bn000ol0003o`lKMol?6
g@02ol?6g@03o`000?o2`MWo`/7I00;o`/7I00?o0000ol2le_o0_=H00_o0_=H01Ol0003o_[OCokjg
donn]m?o000000Go_;7@00Co0000okV/c?ni[<co^Jc<0ol000000onSVL_oXYG7oj:Ea`03oj:Ea`03
o`000?nQT/CoXI;400;oXI;41?nQSl400ol0003oX8booj2<_`02oj2<_`05o`000?nORKcoWhVloin9
_?l000000onNQkX00ol0003oWXFioij5^@02oij5^@05o`000?nMPkOoWH>goif3]ol000000onMP[H0
0ol0003oW86doib1]002oib1]005o`000?nLP;?oW82coib0/ol000000onLOk<01Ol0003oW7jboian
/_nLO[;o000000?oVgjb00Co0000oi]m/OnKOK7oVgfa1?l000000onKOK7o0000oi]n/P02oi]n/P03
o`000?nLO[;oW7jb00;oW7jb00Go0000oiao/onLOk?oW7nco`000003oib0/`03o`000?nLPKCoW86d
00;oW86d00Go0000oif2]_nMP[KoWH:fo`000003oif3]`03o`000?nNQKWoWXFi00;oWXFi00?o0000
oij7^_nNQkX00_nNQkX00ol0003oWhVloin9_002oin9_005o`000?nPS;ooX8booj2<_ol000001?nQ
Sl400ol0003oXI;4oj6Ba002oj6Ba003o`000?nRULOoXYG700;oXYG700?o0000oj>IbonSVL/00ol0
0003okV^cP03o`000?nl]=;o_;CB00;o_;CB00?o0000oknje_no^]H00_no^]H01Ol0003o`L3Iol70
fOo1`=Wo000000Co`lKM00?o0000ol?<hOo3c>400_o3c>401Ol0003oa=7UolCAiOo4dNGo000000?o
`mKX00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0cooooo`?o00000oooool00ol0003o`loSol??h`03ol??h`03o`000?o3bn3o`l_P00;o`l_P
00?o0000ol?6gOo3a]d00_o3a]d00ol0003o`/7Iol;1f@02ol;1f@03o`000?o0_=Ko`;cF00;o`;cF
00Go0000okjgdonn]m?o_[OCo`000005okbad003o`000?ni[<co000000;o00001?nSVL/5oj:Ea`Co
XI;400Go0000oj6?`OnQSl7oXHo1o`000004oj2<_`05o`000?nORKcoWhVloin9_?l000000onNQkX0
0ol0003oWXFioij5^@02oij5^@05o`000?nMPkOoWH>goif3]ol000000onMP[H00ol0003oW86doib1
]002oib1]005o`000?nLP;?oW82coib0/ol000000onLOk<00ol0003oW7jboian/P02oian/P04o`00
0?nKO[;oVgjboi]n/PGo000000?oVgfao`000?l000001?l000000onKO[;o0000oian/P02oian/P05
o`000?nLOk?oW7ncoiao/ol000000onLP;<00ol0003oW86doib1]002oib1]005o`000?nMP[KoWH:f
oif2]_l000001?nMPkL01Ol0003oWXFioij5^OnNQKWo000000CoWXNj00?o0000oin9_?nORK`00_nO
RK`01Ol0003oX8booj2<_onPS;oo000000CoXHo100?o0000oj6Ba?nQT/@00onQT/@00ol0003oXYG7
o`000004o`0000;o]jS;00Go0000okV^c_ni[/ko^Jk>o`000004okbddP03o`000?no^]Ko_k[F00;o
_k[F00Go0000ol70fOo1`=Wo`L3Io`000004ol?6g@03o`000?o3c>7o`lcQ00;o`lcQ00Go0000olCA
iOo4dNGoa=7Uo`000003ol?Fj003o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0
027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo00?o0000ol??hoo3cn<00oo3cn<00ol0
003o`l_Pol?;h002ol?;h003o`000?o3a]go`lKM00;o`lKM00?o0000ol;1fOo2`MT00_o2`MT00ol0
003o`;cFol2leP02ol2leP03o`000?nn]m?o_[OC00;o_[OC00Co0000okbad?nl/M3o_;7@0ol00002
ojBMc`GoXiW;1OnRULL01Ol0003oXI;4oj6Ba?nQT/Co000000?oXHo100?o0000oj2<_onPS;l00_nP
S;l01Ol0003oWhVloin9_?nORKco000000CoWXNj00Go0000oij5^OnNQKWoWXFio`000003oif3]`05
o`000?nMP[KoWH:foif2]_l000001?nLPK@01Ol0003oW82coib0/onLP;?o000000?oW7nc00?o0000
oian/_nLO[800_nLO[800ol0003oVgjbo`000002o`000003oi]m/Ol0003o000000;o000000?oVgfa
o`000?l000000onLO[84o`000003oian/_l0003oW7nc00;oW7nc00?o0000oib0/onLP;<00_nLP;<0
1Ol0003oW86doib1]?nLPKCo000000?oWH:f00?o0000oif3]onMPkL00_nMPkL01Ol0003oWXFioij5
^OnNQKWo000000CoWXNj00?o0000oin9_?nORK`00_nORK`01Ol0003oX8booj2<_onPS;oo000000Go
XHo100?o0000oj6Ba?nQT/@01?l00002ok>Sa`03o`000?ngZ<_o]jS;00;o]jS;00Go0000okV^c_ni
[/ko^Jk>o`000004okbddP03o`000?no^]Ko_k[F00;o_k[F00Go0000ol70fOo1`=Wo`L3Io`000004
ol?6g@03o`000?o3c>7o`lcQ00;o`lcQ0_l00002olCAi@03o`000?o3e^So`mKX00;o00009?ooool0
0ol0003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`03o`000?o3cn?o`loS
00;o`loS00?o0000ol?;h?o3bn000oo3bn000ol0003o`lKMol?6g@02ol?6g@03o`000?o2`MWo`/7I
00;o`/7I00Go0000ol2le_o0_=Ko`;cFo`000004okjgd`Co000000?oYJ;BojBMconTWLl00onTWLl4
oj>Ib`03o`000?nRULOoXYG700;oXYG700?o0000oj6Ba?nQT/@00_nQT/@01Ol0003oXHo1oj6?`OnQ
Sl7o000000?oX8bo00?o0000oin9_?nORK`00_nORK`01Ol0003oWXNjoij7^_nNQk[o000000CoWXFi
00Go0000oif3]onMPkOoWH>go`000003oif2]P05o`000?nLPKCoW86doib1]?l000000onLP;<00ol0
003oW7ncoiao/`02oiao/`03o`000?nLO[;o000000?o00000_nKO[82o`000003oi]m/Ol0003o0000
00;o000000?oVgfao`000?l000000onLO[83oiao/PGo000000?oW7nco`000?nLP;<00_nLP;<01Ol0
003oW86doib1]?nLPKCo000000?oWH:f00?o0000oif3]onMPkL00_nMPkL01Ol0003oWXFioij5^OnN
QKWo000000CoWXNj00?o0000oin9_?nORK`00_nORK`00ol0003oX8booj2<_`02oj2<_`03o`000?nQ
Sl7oXHo100Go00000_naW/@01Ol0003o/j?7ok>SaoncXlOo000000Co]jS;00Go0000okV^c_ni[/ko
^Jk>o`000004okbddP03o`000?no^]Ko_k[F00;o_k[F00?o0000ol70fOo1`=T00_o1`=T01Ol0003o
`lKMol?6gOo3a]go000000Co`lcQ00Co0000olCAiOl0003oa=7U0ol000000ooBm>Ko0000ooooo`0S
ooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo02[ooooo0ol0000=oooo
o`03o`000?o3cn?o`loS00?o`loS00?o0000ol?;h?o3bn000_o3bn000ol0003o`lKMol?6g@02ol?6
g@03o`000?o2`MWo`/7I00;o`/7I00Go0000ol2le_o0_=Ko`;cFo`000003okjgd`;o00001OnUX]84
ojBMc`03o`000?nSVL_oXiW;00;oXiW;00?o0000oj:EaonRULL00_nRULL01Ol0003oXI;4oj6Ba?nQ
T/Co000000?oXHo100?o0000oj2<_onPS;l00_nPS;l01Ol0003oWhVloin9_?nORKco000000?oWXNj
00?o0000oij5^OnNQKT00_nNQKT01Ol0003oWH>goif3]onMPkOo000000?oWH:f00Go0000oib1]?nL
PKCoW86do`000004oib0/`03o`000?nLOk?o000000?o00000_nKO[801_l0003oVgjboi]n/_nKO[;o
0000oi]m/@Ko00000_nLO[82o`000003oian/_l0003oW7nb00;oW7nb1?nMP;<9o`000003oib1]?l0
003oWH:f00;oWH:f00Go0000oif3]onMPkOoWH>go`000004oij5^@03o`000?nNQk[oWXNj00;oWXNj
00?o0000oin9_?nORK`00_nORK`00ol0003oX8boo`000004o`0000;o[YW200?o0000ok6Na?naW/@0
0_naW/@01Ol0003o/j?7ok>SaoncXlOo000000Co]jS;00?o0000okV^c_ni[/h00_ni[/h01Ol0003o
_;CBokbdd_nl]=;o000000Co_k[F00?o0000ol70fOo1`=T00_o1`=T01Ol0003o`lKMol?6gOo3a]go
000000Co`lcQ00?o0000olCAiOo4dND00_l00002om;diP03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02?ooool0027ooooo00?o0000ooooooooool09oooool3o`00013ooooo00?o0000ol??
hoo3cn<00oo3cn<00ol0003o`l_Pol?;h002ol?;h003o`000?o3a]go`lKM00;o`lKM00?o0000ol;1
fOo2`MT00_o2`MT00ol0003o`;cFol2leP02ol2leP?o000000?oYZOGojFRd_nUX]801?nUX]801Ol0
003oY9g?ojBMconTWLoo000000CoXiW;00?o0000oj:EaonRULL00_nRULL01Ol0003oXI;4oj6Ba?nQ
T/Co000000?oXHo100?o0000oj2<_onPS;l00_nPS;l01Ol0003oWhVloin9_?nORKco000000?oWXNj
00?o0000oij5^OnNQKT00_nNQKT01Ol0003oWH>goif3]onMPkOo000000?oWH:f00?o0000oib1]?nL
PK@00_nLPK@00ol0003oW82coib0/`03o`0000;oVgjc00Go0000oi]n/_nKO[;oVgjbo`000002oi]n
/P;o000000CoVgfao`000?l0003oVgfa0_l000000onKOK7o0000oian/P02oian/P;o00000onLOk80
0ol0003oWH2coif0/`02oif0/`CoWX6d1?nOPkD9o`000003oif3]ol0003oWXFi00;oWXFi00?o0000
oij7^_nNQkX02Ol00002oj^D_`03o`000?n^VL;o[YW200;o[YW200?o0000ok6Na?naW/@00_naW/@0
1Ol0003o/j?7ok>SaoncXlOo000000Co]jS;00?o0000okV^c_ni[/h00_ni[/h01Ol0003o_;CBokbd
d_nl]=;o000000Co_k[F00?o0000ol70fOo1`=T00_o1`=T01Ol0003o`lKMol?6gOo3a]go000000Co
`lcQ00?o0000olCAiOl000000_l00002om;diP03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool02?ooool0023ooooo00?o0000ooooooooool09Oooool3o`0001Cooooo00?o0000ol??hoo3cn<0
0_o3cn<00ol0003o`l_Pol?;h002ol?;h003o`000?o3a]go`lKM00;o`lKM00?o0000ol;1fOo2`MT0
0oo2`MT00ol0003o`;cFo`000002o`0000CoYZOG1OnUX]800ol0003oY9g?ojBMc`02ojBMc`05o`00
0?nSVL_oXiW;oj>Ibol000001?nRULL00ol0003oXI;4oj6Ba002oj6Ba005o`000?nQSl7oXHo1oj6?
`Ol000000onPS;l01Ol0003oWhVloin9_?nORKco000000?oWXNj00?o0000oij5^OnNQKT00_nNQKT0
1Ol0003oWH>goif3]onMPkOo000000?oWH:f00?o0000oib1]?nLPK@00_nLPK@3o`000003oiYo]?l0
003oVgjc00?oVgjc00Co0000oi]n/_nKO[;oVgjb0_l00002oi]n/P?o000000GoVgfao`000?l0003o
Vgfao`000004oian/P;o00000_nLOk800ol0003oWH2coif0/`02oif0/`05o`000?nNPKCoWX6doij1
]?l000001?nOPkD4oj25]PCoXXNg2?l00002ojJ=^`GoZ96m00Go0000oj^D_on[U;ooZiBoo`000004
ojjI`P03o`000?naW/Co/Ik400;o/Ik400Go0000ok>SaoncXlOo/j?7o`000004okNXb`03o`000?ni
[/ko^Jk>00;o^Jk>00Go0000okbdd_nl]=;o_;CBo`000004oknjeP03o`000?o1`=Wo`L3I00;o`L3I
00Go0000ol?6gOo3a]go`lKMo`000004ol?<h@;o000000GoeO7To`000?l0003od_CVo`00000Voooo
o`03o`000?oooooooooo00Sooooo000Pooooo`;o00008oooool3o`0001Oooooo00?o0000ol??hoo3
cn<00oo3cn<00ol0003o`l_Pol?;h002ol?;h005o`000?o3a]go`lKMol?6gOl000001?o2`MT3o`00
00;oYZcK1OnVYmL00ol0003oYJ;BojFRdP03ojFRdP05o`000?nTWLooY9g?ojBMcol000001?nSVL/0
0ol0003oXYG7oj:Ea`02oj:Ea`05o`000?nQT/CoXI;4oj6Ba?l000000onQSl401Ol0003oX8booj2<
_onPS;oo000000CoWhVl00Go0000oij7^_nNQk[oWXNjo`000003oij5^@05o`000?nMPkOoWH>goif3
]ol000001?nMP[H00ol0003oW86do`000002o`0000?oVWnd00?o0000oi]n/onKO[<00_nKO[<01Ol0
003oVgjboi]n/_nKO[;o000000?oVgjb0ol000001_nKOK7o0000o`000?l0003oW7jbo`0000?oW7jb
0_nLOk800ol0003oW7nbo`000004oif0/`05o`000?nNPKCoWX6doij1]?l000001?nOPkD01Ol0003o
X8Ffoj25]_nPQKKo000000CoXXNg1?nTR[T5ojJ=^`GoZ96m00Go0000oj^D_on[U;ooZiBoo`000004
ojjI`P03o`000?naW/Co/Ik400;o/Ik400Go0000ok>SaoncXlOo/j?7o`000004okNXb`03o`000?ni
[/ko^Jk>00;o^Jk>00?o0000okbdd_nl]=800_nl]=801Ol0003o_k[Foknje_no^]Ko000000Co`L3I
00Go0000ol?6gOo3a]go`lKMo`000003ol?<h@;o00000_oElN@01?l0003od_CVo`000?l0000Voooo
o`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo023ooooo0_l0000Jooooo`03
o`000?o3cn?o`loS00?o`loS00?o0000ol?;h?o3bn000_o3bn000ol0003o`lKMol?6g@02ol?6g@Co
000000?oYk7OojJ/fonV[=/00onV[=/5ojJWe`03o`000?nUX];oYJ;B00;oYJ;B00Go0000ojBMconT
WLooY9g?o`000004oj>Ib`03o`000?nRULOoXYG700;oXYG700Go0000oj6Ba?nQT/CoXI;4o`000003
oj6?`@03o`000?nPS;ooX8bo00;oX8bo00Go0000oin9_?nORKcoWhVlo`000003oij7^P03o`000?nN
QKWoWXFi00;oWXFi00Ko0000oif3]onMPkOoWH>go`000?nMP[H4o`0000;oVWne00?o0000oiYo]?nJ
Ok@00_nJOk@01Ol0003oVgjcoi]n/onKO[?o000000;oVgjb0_l00002oi]n/P03o`000?nKO[;o0000
00Go00000_nLO[801?l0003oW7jboian/_l00002oiao/P;o00001?nMP;<01Ol0003oWX6doij1]?nN
PKCo000000CoWh>e00Go0000oj25]_nPQKKoX8Ffo`000004oj:7]`05o`000?nTR[WoY8ZiojB:^Ol0
00001?nVSK/00ol0003oZ96mojRA_@02ojRA_@05o`000?n[U;ooZiBooj^D_ol000001?n^VL800ol0
003o/Ik4ok6Na002ok6Na005o`000?ncXlOo/j?7ok>Saol000001?ngZ</00ol0003o^Jk>okV^cP02
okV^cP03o`000?nl]=;o_;CB00;o_;CB00Go0000oknje_no^]Ko_k[Fo`000004ol70f@04o`000?o3
a]go`lKMol?6g@Co000000GoengSo`000?oElNCoeO7To`000002om;diP03o`000?oooooooooo02Go
oooo00?o0000ooooooooool01oooool0023ooooo00?o0000ooooooooool07Oooool3o`0001gooooo
00?o0000ol??hoo3cn<00_o3cn<00ol0003o`l_Pol?;h002ol?;h004o`000?o3a]go`lKMol?6g@;o
00001OnW/Ml4ojJ/f`03o`000?nVYmOoYZOG00;oYZOG00?o0000ojFRd_nUX]800onUX]801Ol0003o
Y9g?ojBMconTWLoo000000?oXiW;00?o0000oj:EaonRULL00_nRULL01Ol0003oXI;4oj6Ba?nQT/Co
000000?oXHo100?o0000oj2<_onPS;l00_nPS;l01Ol0003oWhVloin9_?nORKco000000?oWXNj00?o
0000oij5^OnNQKT00_nNQKT00ol0003oWH>go`000003o`0000;oVH2g00Go0000oiYo]OnJOkGoVWne
o`000004oiYo]003o`000?nKO[?oVgjc00;oVgjc0_l00002oi]n/P04o`000?nKO[;o0000oi]n/P;o
000000?oVgjbo`000?l000000_l00003oian/P03o`000?nLOk;oW7nb00;oW7nb0_l00003oif0/`05
o`000?nNPKCoWX6doij1]?l000001?nOPkD01Ol0003oX8Ffoj25]_nPQKKo000000CoXXNg00Go0000
ojB:^OnTR[WoY8Zio`000004ojJ=^`03o`000?nXTKgoZ96m00;oZ96m00Go0000oj^D_on[U;ooZiBo
o`000004ojjI`P03o`000?naW/Co/Ik400;o/Ik400Go0000ok>SaoncXlOo/j?7o`000004okNXb`03
o`000?ni[/ko^Jk>00;o^Jk>00?o0000okbdd_nl]=800_nl]=801Ol0003o_k[Foknje_no^]Ko0000
00Co`L3I00?o0000ol?6gOo3a]d00_l00003omO]h`04o`000?oElNCoeO7To`0000;od_CV0_l0000W
ooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo0ol0000Poooo
o`03o`000?o3cn?o`loS00?o`loS00?o0000ol?;h?o3bn000_o3bn03o`000003ojNfhonW/MooYk7O
00CoYk7O00?o0000ojJ/fonV[=/00_nV[=/00ol0003oYZOGojJWe`02ojJWe`03o`000?nUX];oYJ;B
00;oYJ;B00Go0000ojBMconTWLooY9g?o`000004oj>Ib`05o`000?nRULOoXYG7oj:Eaol000001?nQ
T/@01Ol0003oXHo1oj6?`OnQSl7o000000?oX8bo00Go0000oin9_?nORKcoWhVlo`000003oij7^P04
o`000?nNQKWoWXFioij5^@?o00000_nHPKP00ol0003oVH2goiV0]`02oiV0]`05o`000?nJOkGoVWne
oiYo]Ol000000onJOk@00ol0003oVgjcoi]n/`02oi]n/`08o`000?nKO[;oVgjboi]n/_l0003oVgjb
o`000?nKO[82o`000005oi]n/_l0003o0000oian/_l000000onLO[800ol0003oW7nboiao/P02oiao
/P;oWH6c0_l000000onMP;?o0000oij1]003oij1]005o`000?nOPkGoWh>eoin3]Ol000000onPQKH0
0ol0003oXXNgoj:7]`02oj:7]`05o`000?nTR[WoY8ZiojB:^Ol000001?nVSK/00ol0003oZ96mojRA
_@02ojRA_@03o`000?n[U;ooZiBo00;oZiBo00Go0000ojjI`_n^VL;o[YW2o`000004ok6Na005o`00
0?ncXlOo/j?7ok>Saol000001?ngZ</00ol0003o^Jk>okV^cP02okV^cP03o`000?nl]=;o_;CB00;o
_;CB00Go0000oknje_no^]Ko_k[Fo`000004ol70f@05o`000?o3a]go0000omSWh?l000000ooGkN<0
1?l0003oeO7TomGai?l00002om;diP03o`000?oooooo000002Kooooo00?o0000ooooooooool01ooo
ool0023ooooo0ol0000Gooooo`?o00008oooool00ol0003o`loSol??h`03ol??h`04o`000?o3bn3o
`l_Pol?;h0;o00001?nW]^<6ojNag`05o`000?nV[=_oYZcKojJ/fol000001?nVYmL00ol0003oYJ;B
ojFRdP03ojFRdP05o`000?nTWLooY9g?ojBMcol000000onSVL/00ol0003oXYG7oj:Ea`02oj:Ea`05
o`000?nQT/CoXI;4oj6Ba?l000000onQSl401Ol0003oX8booj2<_onPS;oo000000?oWhVl00?o0000
oij7^_nNQkX00_nNQkX3o`000003oiN1^_l0003oV86h00?oV86h00Go0000oiV0]onIP;OoVH2go`00
0003oiYo]@05o`000?nJOkCoVWndoiYo]?l000000onKO[<2o`0000CoVgjb00Ko0000oi]n/_l0003o
Vgjbo`000?nKO[82o`0000;oW7jb00Go0000oian/_nLO[;oW7nbo`000003oiao/P04o`000?nMPK?o
WH6coif1/`;o00001?nNPK@01Ol0003oWh>eoin3]OnOPkGo000000?oX8Ff00?o0000oj:7]onRQkL0
0_nRQkL00ol0003oY8ZiojB:^@02ojB:^@05o`000?nVSK_oYXfkojJ=^ol000001?nXTKd00ol0003o
ZiBooj^D_`02oj^D_`05o`000?n^VL;o[YW2ojjI`_l000001?naW/@01Ol0003o/j?7ok>SaoncXlOo
000000Go]jS;00Go0000okV^c_ni[/ko^Jk>o`000004okbddP05o`000?no^]Ko_k[Foknje_l00000
1?o1`=T2o`000003omSWh?l0003oengS00?oengS00?o0000omGai?l000000_oBm>H01Ol0003ooooo
oooooooooooo000002Gooooo00?o0000ooooooooool01oooool001oooooo0_l0000Fooooo`?o0000
9oooool00ol0003o`loSol??h`02ol??h`06o`000?o3bn3o0000o`000?nW^nOo00001OnW]^<5ojNa
g`03o`000?nV[=_oYZcK00;oYZcK00?o0000ojJWeonVYmL00_nVYmL00ol0003oYJ;BojFRdP02ojFR
dP05o`000?nTWLooY9g?ojBMcol000000onSVL/00ol0003oXYG7oj:Ea`02oj:Ea`05o`000?nQT/Co
XI;4oj6Ba?l000000onQSl401Ol0003oX8booj2<_onPS;oo000000CoWhVl00?o0000oij7^_l00000
0_l00004oiN1^P05o`000?nHPKSoV86hoiR1^?l000000onIP;L01Ol0003oVWneoiYo]OnJOkGo0000
00?oVWnd00Co0000oi]n/onKO[?o00000_nJO[<03_l0003oVgjboi]n/_nKO[;o0000oi]n/_l0003o
Vgjbo`000?nKO[;o0000oi]n/_nLO[;o00000onLO[82oiao/P04o`000?nLOk;oW7nbo`0000CoWH6c
0_l00003oij1]005o`000?nOPkGoWh>eoin3]Ol000000onPQKH00ol0003oXXNgoj:7]`02oj:7]`03
o`000?nTR[WoY8Zi00;oY8Zi00Go0000ojJ=^onVSK_oYXfko`000004ojRA_@03o`000?n[U;ooZiBo
00;oZiBo00Go0000ojjI`_n^VL;o[YW2o`000004ok6Na003o`000?ncXlOo/j?700;o/j?700?o0000
okNXbongZ</00_ngZ</01Ol0003o^Jk>okV^c_ni[/ko000000Co_;CB00Go0000oknje_no^]Ko_k[F
o`000003ol70f@;o00000_oHin001Ol0003oengSomO]hooGkN?o000000;oeO7T00Co0000om;di_oB
m>Ko00001?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01;ooooo0ol0000Zooooo`03o`000?o3cn?o`loS00;o`loS0_l00004
ojNki`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNagonW/Ml00onW/Ml01Ol0003oYZcKojJ/fonV
[=_o000000CoYZOG00?o0000ojFRd_nUX]800_nUX]801Ol0003oY9g?ojBMconTWLoo000000CoXiW;
00Go0000oj:EaonRULOoXYG7o`000004oj6Ba004o`000?nQSl7oXHo1o`0000CoX8bo00?o0000oin9
_?l000000ol00002oiJ2_003o`000?nGPK[oUh6j00;oUh6j00Go0000oiR1^?nHPKSoV86ho`000004
oiV0]`05o`000?nJOkGoVWneoiYo]Ol000000onJOk@2o`0000?oVWjc00Go0000oi]n/_nKO[;o0000
oi]n/`02o`000006oi]n/_l0003oVgjbo`000?nKO[;o00000_nLO[82o`0000?oW7nb00?o0000oiao
/_l000001?nMPK<2oin2]0;o000000?oWX6do`000?nOPkD00_nOPkD00ol0003oX8Ffoj25]P02oj25
]P05o`000?nRQkOoXXNgoj:7]ol000001?nTR[T01Ol0003oYXfkojJ=^onVSK_o000000CoZ96m00?o
0000oj^D_on[U;l00_n[U;l01Ol0003o[YW2ojjI`_n^VL;o000000Go/Ik400Go0000ok>SaoncXlOo
/j?7o`000004okNXb`05o`000?ni[/ko^Jk>okV^c_l000001?nl]=801?l0003o_k[Foknje_no^]H4
o`000005omOPg_l0003of>OPomSWh?l000000ooGkN<00ol0003oeO7To`000002om;diP03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool03oooool3o`0002gooooo00?o0000ol??hol000000_l000000onW`>_o0000ojNk
i`04ojNki`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNagonW/Ml00_nW/Ml00ol0003oYZcKojJ/
f`02ojJ/f`03o`000?nVYmOoYZOG00;oYZOG00?o0000ojFRd_nUX]800_nUX]801Ol0003oY9g?ojBM
conTWLoo000000?oXiW;00?o0000oj:EaonRULL00_nRULL01Ol0003oXI;4oj6Ba?nQT/Co000000?o
XHo100?o0000oj2<_ol000000ol00002oiB4_`03o`000?nFP[coUX:l00;oUX:l00Go0000oiN1^_nG
PK[oUh6jo`000004oiR1^005o`000?nIP;OoVH2goiV0]ol000000onJOkD01Ol0003oVWndoiYo]?nJ
OkCo000000CoVWjc00?o0000oi]n/_l000000onKO[<00ol0003oVgjbo`000003oi]n/P05o`000?nL
O[;oW7jboian/_l000001OnLOk800ol0003oWH6coif1/`02oif1/`04o`000?nOP[CoWh:doin2]0;o
00000onOPkD00ol0003oX8Ffoj25]P02oj25]P03o`000?nRQkOoXXNg00;oXXNg00Go0000ojB:^OnT
R[WoY8Zio`000003ojJ=^`03o`000?nXTKgoZ96m00;oZ96m00?o0000oj^D_on[U;l00_n[U;l00ol0
003o[YW2ojjI`P02ojjI`P03o`000?naW/Co/Ik400;o/Ik400Go0000ok>SaoncXlOo/j?7o`000004
okNXb`03o`000?ni[/ko^Jk>00;o^Jk>00Go0000okbdd_nl]=;o_;CBo`000002oknjeP;o00000ooG
h=h01?l0003of>OPomSWh?l00003omO]h`04o`000?oElNCoeO7To`0000;od_CV00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo0004ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo0ol0000aooooo`03o`000?nW`>_oYl3[00?oYl3[00?o0000ojNkionW^nL00_nW^nL00ol0003o
YkKSojNfh`03ojNfh`03o`000?nW/MooYk7O00;oYk7O00Go0000ojJ/fonV[=_oYZcKo`000004ojJW
e`03o`000?nUX];oYJ;B00;oYJ;B00Go0000ojBMconTWLooY9g?o`000003oj>Ib`03o`000?nRULOo
XYG700;oXYG700Go0000oj6Ba?nQT/CoXI;4o`000002oj6?`@?o00000_nBQL85oiB4_`05o`000?nF
P[coUX:loiJ2_?l000001?nGPKX01Ol0003oV86hoiR1^?nHPKSo000000?oVH2g00Go0000oiYo]OnJ
OkGoVWneo`000002oiYo]0;o00001OnJO[<2o`0000?oVgjc0ol00003oi]n/P05o`000?nLO[;o0000
oian/_l000001OnLOk800ol0003oWH6coif1/`02oif1/`03o`000?nOP[CoWh:d00;oWh:d0_l00002
oin3]@03o`000?nPQKKoX8Ff00;oX8Ff00?o0000oj:7]onRQkL00_nRQkL01Ol0003oY8ZiojB:^OnT
R[Wo000000CoYXfk00?o0000ojRA_OnXTKd00_nXTKd01Ol0003oZiBooj^D_on[U;oo000000Co[YW2
00?o0000ok6Na?naW/@00_naW/@01Ol0003o/j?7ok>SaoncXlOo000000Co]jS;00?o0000okV^c_ni
[/h00_ni[/h01?l0003o_;CBokbdd_nl]=83o`000003omCHfol0003oen3N00;oen3N00Co0000omSW
h?oHin3o00000ooGkN<01?l0003oeO7TomGai?l00002om;diP03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool2o`0000[ooooo0ol0000dooooo`03o`000?nW
`>_oYl3[00CoYl3[00?o0000ojNkionW^nL00_nW^nL00ol0003oYkKSojNfh`02ojNfh`03o`000?nW
/MooYk7O00;oYk7O00?o0000ojJ/fonV[=/00_nV[=/01Ol0003oYZOGojJWeonVYmOo000000GoYJ;B
00Co0000ojBMconTWLoo00001?nSVL/01Ol0003oXYG7oj:EaonRULOo000000CoXI;40_l000000on@
QlKoTXG2oi:5`P03oi:5`PCoU8Bo00Go0000oiJ2_?nFP[coUX:lo`000004oiN1^P03o`000?nHPKSo
V86h00;oV86h00Go0000oiV0]onIP;OoVH2go`000003oiYo]@;o00000_nIO[@00ol0003oVWjcoiYn
/`02oiYn/`03o`000?nKO[?oVgjc00;oVgjc00?o0000oi]n/ol000000_l00002oi]n/P05oian/_l0
003o0000oiao/ol000001?nLOk800ol0003oWH6coif1/`02oif1/`03o`000?nOP[CoWh:d00;oWh:d
0_nQQKH3o`0000CoX8Ff00?o0000oj:7]onRQkL00_nRQkL01Ol0003oY8ZiojB:^OnTR[Wo000000Co
YXfk00?o0000ojRA_OnXTKd00_nXTKd01Ol0003oZiBooj^D_on[U;oo000000Co[YW200?o0000ok6N
a?naW/@00_naW/@01Ol0003o/j?7ok>SaoncXlOo000000Co]jS;00?o0000okV^c_ni[/h00_ni[/h0
0ol0003o_;CBokbddP02o`0000?oe=SK00Go0000omOPg_oGh=koen3No`000002omSWh004o`000?oG
kN?oengSo`0000;oeO7T00Co0000om;di_oBm>Ko00002Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3o`0003Sooooo00?o0000ojO0
jonW`>/01?nW`>/00ol0003oYk_WojNki`02ojNki`03o`000?nW]^?oYkKS00;oYkKS00?o0000ojNa
gonW/Ml00_nW/Ml01Ol0003oYZcKojJ/fonV[=_o000000CoYZOG00?o0000ojFRd_nUX]800_nUX]80
1Ol0003oY9g?ojBMconTWLoo000000?oXiW;00?o0000oj:EaonRULL00_nRULL00ol0003oXI;4o`00
0002o`0000?oT8O61?nBQL801Ol0003oU8BooiB4_onDQ;oo000000CoUX:l00Go0000oiN1^_nGPK[o
Uh6jo`000004oiR1^005o`000?nIP;OoVH2goiV0]ol000000onJOkD01Ol0003oVGjdoiUn]?nIO[Co
000000CoVWjc00?o0000oi]n/onKO[<00_nKO[<00ol0003oVgjco`000002oi]o/`?o000000GoW7nc
o`000?nLOk?oW7nco`000002oiao/P03o`000?nNPK?o000000;oWH6c00?o0000oin2]?nOP[@00onO
P[@4oj65]P;o00000onPQKH00ol0003oXXNgoj:7]`02oj:7]`05o`000?nTR[WoY8ZiojB:^Ol00000
1?nVSK/00ol0003oZ96mojRA_@02ojRA_@05o`000?n[U;ooZiBooj^D_ol000001?n^VL800ol0003o
/Ik4ok6Na002ok6Na005o`000?ncXlOo/j?7ok>Saol000001?ngZ</00ol0003o^Jk>okV^cP02okV^
cP?o000000GodLoHo`000?oDf=_oe=SKo`000003omOPgP04o`000?oHin3of>OPo`0000?oengS00Co
0000omGai?oElNCo00000_oBm>H00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01_ooool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0003cooooo00?o0000ojO0jonW`>/0
0onW`>/00ol0003oYk_WojNki`02ojNki`03o`000?nW]^?oYkKS00?oYkKS00Go0000ojNagonW/Moo
Yk7Oo`000004ojJ/f`05o`000?nVYmOoYZOGojJWeol000001OnUX]801?l0003oY9g?ojBMcol00003
oj>Ib`03o`000?nRULOoXYG700Co00000_n>RLT4oi27aP03o`000?nBQL;oTXG200;oTXG21?nDQ;l0
1Ol0003oUX:loiJ2_?nFP[co000000CoUh6j00Go0000oiR1^?nHPKSoV86ho`000003oiV0]`03o`00
0?nJOkGoVWne00;o00001?nIO[@01_l0003oVWjcoiYn/ol0003oVWjdo`0000;oVgjc00Co0000oi]n
/onKO[?o00000_nKOk<00ol0003oW7nco`000002oiao/`03o`000?nLOk?o000000;oW7nb00Ko0000
oij1/onNPK?o0000oif1/ol00005oin2]004o`000?nQQKKoXHFfoj65]P;oXhRg0_l000000onPQKKo
0000oj:7]`03oj:7]`05o`000?nTR[WoY8ZiojB:^Ol000001?nVSK/00ol0003oZ96mojRA_@02ojRA
_@05o`000?n[U;ooZiBooj^D_ol000001?n^VL800ol0003o/Ik4ok6Na002ok6Na005o`000?ncXlOo
/j?7ok>Saol000001?ngZ</01?l0003o^Jk>okV^c_ni[/h2o`0000?odLoH00Co0000omCHfooDf=_o
00000ooGh=h01?l0003of>OPomSWh?l00003omO]h`04o`000?oElNCo0000om;diP;o00002oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o0000@?oo
ool00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW^nOoYk_W00;oYk_W00?o0000ojNfhonW]^<00_nW
]^<00ol0003oYk7OojNag`02ojNag`05o`000?nV[=_oYZcKojJ/fol000001?nVYmL00ol0003oYJ;B
ojFRdP02ojFRdP04o`000?nTWLooY9g?o`0000;oXiW;1?l00002oh^;cPGoSXW91?n@QlH01Ol0003o
TXG2oi:5`_nBQL;o000000?oU8Bo00?o0000oiJ2_?nFP[`00_nFP[`01Ol0003oUh6joiN1^_nGPK[o
000000CoV86h00Co0000oiV0]onIP;OoVH2g0_l00002oiQo]P03o`000?nIO[CoVGjd00;oVGjd00?o
0000oiYn/ol000000_nJO[@00ol0003oVgjco`000002oi]n/`06o`000?nKOk?oVgnco`000?nLOk?o
00000_nLOk<01_l0003oW7ncoiao/ol0003oW7nbo`0000?oWX6c00?oWH6co`000?nOP[@01?nOP[@0
1?l0003oXHFfoj65]_nQQKH5oj>8]`;o00000onRQkL00ol0003oY8ZiojB:^@02ojB:^@05o`000?nV
SK_oYXfkojJ=^ol000001?nXTKd01Ol0003oZiBooj^D_on[U;oo000000Co[YW200?o0000ok6Na?na
W/@00_naW/@01Ol0003o/j?7ok>SaoncXlOo000000Co]jS;1?l000001Oo=amCo0000om7?f?oAcmSo
000000?oe=SK00Go0000omOPg_oGh=koen3No`000002omSWh004o`000?oGkN?oengSo`0000;oeO7T
0ol0000=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool4o`0004Cooooo00?o0000ojO0jonW`>/0
0onW`>/00ol0003oYk_WojNki`02ojNki`03o`000?nW]^?oYkKS00;oYkKS00Go0000ojNagonW/Moo
Yk7Oo`000004ojJ/f`05o`000?nVYmOoYZOGojJWeol000001?nUX]800ol0003oY9g?ojBMc`03o`00
00;oR8kB1On;Rlh4ohj9b@05o`000?n@QlKoT8O6oi27a_l000001?nBQL801Ol0003oU8BooiB4_onD
Q;oo000000?oUX:l00Go0000oiN1^_nGPK[oUh6jo`000004oiR1^003o`000?nIP;OoVH2g00;o0000
0onHOkH00ol0003oVGjdoiUn]002oiUn]003o`000?nJO[?o000000?oVWjd0_l00002oi]n/`04o`00
0?nKOk?oVgnco`0000;oW7nc00?o0000oiao/onLOk<00onLOk<00ol0003oWX6coij1/`03oij1/`;o
00000onOP[@00ol0003oXHFfoj65]P02oj65]P03o`000?nSR;OoXhRg00;oXhRg0_nVRkT2o`000003
oj:7]ol0003oY8Zi00?oY8Zi00Go0000ojJ=^onVSK_oYXfko`000004ojRA_@03o`000?n[U;ooZiBo
00;oZiBo00Go0000ojjI`_n^VL;o[YW2o`000004ok6Na005o`000?ncXlOo/j?7ok>Saol000000ong
Z</2o`0000CocLOD00Co0000om7?f?oAcmSo00000_oDf=/01Ol0003oen3NomOPg_oGh=ko000000;o
f>OP00Go0000omO]hooGkN?oengSo`000002omGai0;o00003oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Kooooo000Nooooo`;o0000Aoooool00ol0003oYl3[ojO0j`03ojO0j`03
o`000?nW^nOoYk_W00;oYk_W00Go0000ojNfhonW]^?oYkKSo`000004ojNag`05o`000?nV[=_oYZcK
ojJ/fol000001?nVYmL01?l0003oYJ;BojFRd_nUX]83o`000003ohBAf?n8S];oR8kB00?oR8kB1?n;
Rlh00ol0003oSXW9ohj9b@02ohj9b@05o`000?n@QlKoT8O6oi27a_l000000onBQL801Ol0003oU8Bo
oiB4_onDQ;oo000000?oUX:l00?o0000oiN1^_nGPKX00_nGPKX02Ol0003oV86hoiR1^?nHPKSo0000
oiV0]ol0003oUWnho`000004oiQo]P03o`000?nIO[CoVGjd00;oVGjd00?o0000oiYn]?nJO[@00onJ
O[@01?l0003oVgjcoi]n/ol00002oi]o/`04o`000?nLOk?oW7nco`0000GoW7nc00?o0000oij1/onN
PK<00onNPK<2oin3]@04o`000?nOP[CoWh:do`0000CoXHFf00?o0000oj>8]onSR;L00_nSR;L5ojJ;
^@Co000000?oY8Zio`000?nVSK/00_nVSK/00ol0003oZ96mojRA_@02ojRA_@03o`000?n[U;ooZiBo
00;oZiBo00Go0000ojjI`_n^VL;o[YW2o`000004ok6Na004o`000?ncXlOo/j?7ok>Sa`Co000000?o
b;kAo`000?o=am@00_o=am@01Ol0003odLoHom7?f?oAcmSo000000;oe=SK00Go0000omOPg_oGh=ko
en3No`000002omSWh005o`000?oGkN?oengSo`000?oElN@00ol0000@ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0AOooool00ol0003o
Yl3[ojO0j`02ojO0j`03o`000?nW^nOoYk_W00;oYk_W00?o0000ojNfhonW]^<00_nW]^<01Ol0003o
Yk7OojNagonW/Moo000000CoYZcK00Ko0000ojJWeonVYmOoYZOGo`000?nUX]82o`000003oh6DgOn4
TMSoQ97H00;oQ97H1?n8S]800ol0003oRh_>oh^;cP02oh^;cP05o`000?n>RLWoSXW9ohj9bOl00000
0on@QlH00ol0003oTXG2oi:5`P02oi:5`P05o`000?nDQ;ooU8BooiB4_ol000000onFP[`01Ol0003o
Uh6joiN1^_nGPK[o000000?oV86h0_l00003oiIo^003o`000?nHOkKoV7nf00;oV7nf00Go0000oiUn
]?nIO[CoVGjdo`000005oiYn]0;o000000?oVgjco`000?nKOk<00_nKOk<00ol0003oW7nco`000002
oiao/`05o`000?nLOk?o0000oif1]?l000000onNPK<01ol0003oWh>eoin3]OnOPkGo0000oin2]?l0
00001?nQQKH00ol0003oXhRgoj>8]`02oj>8]`GoYX^i1?nYSk/4o`000003ojJ=^ol0003oZ96m00?o
Z96m00?o0000oj^D_on[U;l00_n[U;l01Ol0003o[YW2ojjI`_n^VL;o000000Co/Ik400?o0000ok>S
aol000000_l00004olRnd@05o`000?o=amCocLODolg7e?l000000ooAcmP01?l0003oe=SKomCHfol0
0003omOPgP04o`000?oHin3of>OPo`0000;oengS0_l000000onan;oo0000ooooo`0Aooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0AOoo
ool00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW^nOoYk_W00;oYk_W00?o0000ojNfhonW]^<00_nW
]^<01Ol0003oYk7OojNagonW/Moo000000?oYZcK00?o0000ojJWeonVYmL00ol00004oh6Dg@CoQ97H
1?n8S]800ol0003oRh_>oh^;cP02oh^;cPCoSXW900Go0000oi27a_n@QlKoT8O6o`000003oi:5`P05
o`000?nDQ;ooU8BooiB4_ol000000onFP[`01Ol0003oUh6joiN1^_nGPK[o000000;oV86h00?o0000
oi=o^_l000000onFOkP00ol0003oV7nfoiQo]P02oiQo]P06o`000?nIO[CoVGjdo`000?nHOkKo0000
0onJO[@00ol0003oVWndoiYo]002o`0000?oVgnc0_nLOk<00ol0003oW7ncoiao/`02o`0000?oWH6d
00Co0000oij1/onNPK?o00001?nOPkD2o`0000?oXHFf00?o0000oj>8]onSR;L00onSR;L00ol0003o
YX^iojJ;^@02ojJ;^@GoZHnk00?o0000ojfD_On]U;d01Ol000000onXTKgo0000oj^D_`03oj^D_`03
o`000?n^VL;o000000So00000_o3]/d01Ol0003ob;kAolRndOo8_]7o000000CocLOD00Co0000om7?
f?oAcmSo00000ooDf=/01?l0003oen3NomOPg_l00002omSWh007o`000?oGkN?oengSomO]hol0003o
/ORoo`00000Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool002;ooooo
00?o0000ooooooooool0A?ooool00ol0003oYl3[ojO0j`03ojO0j`03o`000?nW^nOoYk_W00;oYk_W
00Go0000ojNfhonW]^?oYkKSo`000003ojNag`03o`000?nV[=_oYZcK00Co00000_mmV><6oh6Dg@?o
Q97H00?o0000ohR>d_n8S]800_n8S]801Ol0003oRh_>oh^;c_n;Rlko000000?oSXW900Go0000oi27
a_n@QlKoT8O6o`000003oi:5`P05o`000?nDQ;ooU8BooiB4_ol000001?nFP[`01?l0003oUh6joiN1
^_nGPKX2o`0000?oTgnj00Go0000oiIo^?nFOkSoUWnho`000004oiQo]P03o`000?nIO[Co000000;o
V7nf00Co0000oiYn]?nJO[Co00000onJOk@3o`000003oi]o/onLOk?oW7nc00;oW7nc00?o0000oif1
]?l000000onMPK@01?l0003oWX6coij1/ol00005oin3]@05o`000?nQQKKoXHFfoj65]_l000001OnS
R;L00ol0003oYX^iojJ;^@02ojJ;^@GoZHnk00Go0000ojfD_On]U;go[IBmo`000003ok2J`0So0000
0_niY/H00ol0003o_Zk9okj^b@02okj^b@05o`000?o3]/go`kK=ol>fcOl000000oo8_]400ol0003o
cLODolg7e002olg7e004o`000?oAcmSodLoHo`0000;oe=SK00Go0000omOPg_oGh=koen3No`000002
omSWh006o`000?oGkN?o0000o`000?nan;oo00005_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00Gooooo000Sooooo`;o0000AOooool00ol0003oYl3[ojO0j`02ojO0j`03o`000?nW
^nOoYk_W00;oYk_W00?o0000ojNfhonW]^<00_nW]^<00ol0003oYk7OojNag`03o`0000;oNIcX00?o
0000ogfHhommV><00_mmV><5oh6Dg@05o`000?n4TMSoQ97HohBAf?l000000on8S]800ol0003oRh_>
oh^;cP02oh^;cP05o`000?n>RLWoSXW9ohj9bOl000000on@QlH01Ol0003oTXG2oi:5`_nBQL;o0000
00?oU8Bo00Go0000oiJ2_?nFP[coUX:lo`000002oiN1^P;o00001?nCOkX01Ol0003oUWnhoiIo^?nF
OkSo000000CoV7nf00?o0000oiUn]?l000000_nHOkH01?l0003oVWjdoiYn]?l00003oiYo]003o`00
0?nKP;GoVh2e00Go00000onMPK@01?l0003oWH6doif1]?nMPK@2o`0000KoWh>e00GoXXJgo`000?nQ
QKKoXHFfo`000005oj>8]`05o`000?nVRkWoYX^iojJ;^Ol000001OnYSk/01Ol0003o[IBmojfD_On]
U;go000000Co/9[000?o0000okFO`oneWl<00_neWl<01Ol0003o^JK6okVVa_niY/Ko000000Co_Zk9
00Go0000ol>fcOo3]/go`kK=o`000003olRnd@05o`000?o=amCocLODolg7e?l000000ooAcmP01?l0
003oe=SKomCHfol00003omOPgP03o`000?oHin3of>OP00;o000000?o_?_5o`000?l000005oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000Uooooo`03o`000?oooooooooo
04?ooooo00?o0000ojO0jonW`>/00_nW`>/00ol0003oYk_WojNki`02ojNki`03o`000?nW]^?oYkKS
00Co00000_meXNd01Ol0003oNIcXogVLj?miW>So000000CoOISS1On1U=d01?l0003oQ97HohBAf?l0
0004ohR>dP05o`000?n;RlkoRh_>oh^;c_l000000on>RLT01Ol0003oT8O6oi27a_n@QlKo000000?o
TXG200Go0000oiB4_onDQ;ooU8Boo`000003oiJ2_005o`000?nGPK[o0000oi20_Ol000001OnCOkX0
1Ol0003oUWnhoiIo^?nFOkSo000000CoV7nf00?o0000oiQo]_nHOkH00_nHOkH2o`0000CoVWnd00Go
0000oi^0]OnKP;GoVh2eo`000002oib1]@05o`000?nMPKCoWH6doif1]?l000001?nMPK@00ol0003o
Wh>eoin3]@03oin3]@06o`000?nRQ[OoXXJgo`000?nQQKKo00001?nSR;L00ol0003oYX^iojJ;^@02
ojJ;^@03o`000?nYSk_oZHnk00?oZHnk00Go0000ojfD_On]U;go[IBmo`000004ok2J`003o`000?ne
Wl?o]Io300;o]Io300Go0000okVVa_niY/Ko^JK6o`000004okj^b@04o`000?o3]/go`kK=o`0000Co
b;kA00Go0000olg7e?o=amCocLODo`000002om7?f005o`000?oDf=_oe=SKomCHfol000000_oGh=h0
0ol0003of>OPomSWh002o`000003okckaOl0003o000001Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`05ooooo`009_ooool00ol0003oooooooooo`13ooooo`03o`000?nW`>_oYl3[
00;oYl3[00?o0000ojNkionW^nL01?l00003og:VlP05o`000?meXNgoMJ7]ogFQkOl000000omiW>P0
0ol0003oOISSogfHh`02ogfHh`CoPICM00Go0000ohBAf?n4TMSoQ97Ho`000003ohR>dP03o`000?n;
RlkoRh_>00;oRh_>00Go0000ohj9bOn>RLWoSXW9o`000003oi27aP05o`000?nBQL;oTXG2oi:5`_l0
00000onDQ;l01Ol0003oUX:loiJ2_?nFP[co000000?oT82m00?o0000oi=o^_nCOkX00_nCOkX01Ol0
003oUWnhoiIo^?nFOkSo000000CoV7nf00?o0000oiQo]_nHOkH00onHOkH2o`0000?oVWnd00Go0000
oi^0]OnKP;GoVh2eo`000002oib1]@05o`000?nMPKCoWH6doif1]?l000001?nMPK@00ol0003oWh>e
oin3]@03oin3]@04o`000?nRQ[OoXXJgoj:6]`;o00001?nSR;L00ol0003oYX^iojJ;^@02ojJ;^@03
o`000?nYSk_oZHnk00;oZHnk00?o0000ojfD_On]U;d00_n]U;d00ol0003o/9[0ok2J`002ok2J`003
o`000?neWl?o]Io300;o]Io300Co0000okVVa_niY/Ko00001?nn[/T01Ol0003o`kK=ol>fcOo3]/go
000000Cob;kA00Go0000olg7e?o=amCocLODo`000002om7?f005o`000?oDf=_oe=SKomCHfol00000
0_oGh=h01Ol0003of>OPo`000?l0003o_?_500;o00006oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Co0000ojO0jonW`>_o
Yl3[0ol00004og2[m@CoLZKb00Go0000ogFQkOmeXNgoMJ7]o`000003ogVLj003o`000?mmV>?oOISS
00;oOISS1?n1U=d01Ol0003oQ97HohBAf?n4TMSo000000?oR8kB00Go0000oh^;c_n;RlkoRh_>o`00
0003ohj9b@05o`000?n@QlKoT8O6oi27a_l000000onBQL801Ol0003oU8BooiB4_onDQ;oo000000;o
UX:l0_l00004oi20_@03o`000?nCOk[oTgnj00;oTgnj00Go0000oiIo^?nFOkSoUWnho`000002oiQo
]P03o`000?nGOkSo000000CoV7nf00?o0000oiV0]_l000000_nJOk@01Ol0003oVh2eoi^0]OnKP;Go
000000?oW86e00Go0000oif1]?nMPKCoWH6do`000002oif1]003o`000?nOQ;Ko000000CoWh>e00?o
0000oj:6]onRQ[L00_nRQ[L2o`0000?oXhRg00?o0000ojJ;^OnVRkT00_nVRkT00ol0003oZHnkojV?
^`02ojV?^`05o`000?n]U;go[IBmojfD_Ol000001On`V/001Ol0003o]Io3okFO`oneWl?o000000?o
^JK600?o0000okj^bOnn[/T00_nn[/T01Ol0003o`kK=ol>fcOo3]/go000000?ob;kA00Go0000olg7
e?o=amCocLODo`000003om7?f004o`000?oDf=_oe=SKo`0000?oen3N0_l000001?o6o/go0000o`00
0?l0000Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Sooooo0_l0
0014ooooo`03o`000?nW`>_o000000?oKk3h1Om`ZoD4og:VlP05o`000?meXNgoMJ7]ogFQkOl00000
0omiW>P01Ol0003oOISSogfHhommV>?o000000CoPICM00Co0000ohBAf?n4TMSo00000on8S]800ol0
003oRh_>oh^;cP02oh^;cP05o`000?n>RLWoSXW9ohj9bOl000000on@QlH01Ol0003oTXG2oi:5`_nB
QL;o000000;oU8Bo00?o0000oiJ2_?l000000_n=P<401Ol0003oT82moi20_On@P;go000000CoTgnj
00Oo0000oiIo^?nFOkSoUWnho`000?nHOkKo000000?oUgnh00Go0000oiQo]_nHOkKoV7nfo`000002
oiV0]P03o`000?nJOkCo000000?oVh2e00Go0000oib1]OnLPKGoW86eo`000003oif1]003o`000?nM
PKCo000000?oWhBf00Co0000oin3]OnOPkGo00001OnRQ[L2ojF;^@04o`000?nSR;OoXhRgo`0000Co
YX^i00?o0000ojV?^onYSk/00_nYSk/01Ol0003o[IBmojfD_On]U;go000000Co/9[000?o0000okFO
`oneWl<00_neWl<01Ol0003o^JK6okVVa_niY/Ko000000Co_Zk900Go0000ol>fcOo3]/go`kK=o`00
0003olRnd@05o`000?o=amCocLODolg7e?l000000ooAcmP01?l0003oe=SKomCHfol00002omOPgP;o
000000Coa_k=o`000?l0003o00007_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Cooooo000Zooooo`03o`000?oooooooooo04;ooooo00?o0000ofn`n?m_/?P00om_/?P5og2[m@Co
LZKb00Go0000ogFQkOmeXNgoMJ7]o`000003ogVLj005o`000?mmV>?oOISSogfHhol000000on1U=d0
1Ol0003oQ97HohBAf?n4TMSo000000?oR8kB00Go0000oh^;c_n;RlkoRh_>o`000003ohj9b@05o`00
0?n@QlKoT8O6oi27a_l000000onBQL800ol0003oU8BooiB4_`02o`0000?oSH3100?o0000oi20_On@
P;d00_n@P;d00ol0003oTgnjoi=o^P02oi=o^P05o`000?nFOkSoUWnhoiIo^?l000001OnGOkP01?l0
003oV7nfoiQo]_l00003oiV0]P;o00001?nKP;D01?l0003oW86eoib1]Ol00003oif1]003o`000?nM
PKCo000000?oWhBf00Co0000oin3]OnOPkGo00001?nRQ[L01ol0003oYH^iojF;^OnURkWo0000oj>8
]ol000001?nVRkT00ol0003oZHnkojV?^`02ojV?^`05o`000?n]U;go[IBmojfD_Ol000001?n`V/00
0ol0003o]Io3okFO``02okFO``05o`000?niY/Ko^JK6okVVa_l000001?nn[/T01Ol0003o`kK=ol>f
cOo3]/go000000?ob;kA00Go0000olg7e?o=amCocLODo`000002om7?f006o`000?oDf=_oe=SKomCH
fol0003oen3N0_l000001?o6o/go0000o`000?l0000Pooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@oooool5ofn`n003o`000?m`ZoGo
L:_e00;oL:_e00Go0000og:Vl_mbY_;oLZKbo`000003ogFQk@05o`000?miW>SoNIcXogVLj?l00000
0ommV><01Ol0003oPICMoh6DgOn1U=go000000;oQ97H00Go0000ohR>d_n8S];oR8kBo`000004oh^;
cP05o`000?n>RLWoSXW9ohj9bOl000000on@QlH00ol0003oTXG2oi:5`P03o`000003ohR1aOl0003o
SH3100?oSH3100Go0000oi20_On@P;goT82mo`000004oi=o^P05o`000?nFOkSoUWnhoiIo^?l00000
1OnGOkP00ol0003oV7nfo`000005oiV0]P;o00000onKP;D01?l0003oW86eoib1]Ol00003oif1]0;o
00001OnOQ;H00ol0003oWh>eo`000004oj:6]`03o`000?nURkWoYH^i00;oYH^i0_l00004ojJ;^@03
o`000?nYSk_oZHnk00;oZHnk00Go0000ojfD_On]U;go[IBmo`000004ok2J`003o`000?neWl?o]Io3
00;o]Io300Go0000okVVa_niY/Ko^JK6o`000004okj^b@05o`000?o3]/go`kK=ol>fcOl000000oo8
_]401Ol0003ocLODolg7e?o=amCo000000;odLoH00?o0000omCHfooDf=/00ol000000oo@omKo0000
o`000002o`0002;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`00;?oo
ool00ol0003oooooooooo`13ooooo`03o`000?m_/?SoKk3h00?oKk3h1?m`ZoD01Ol0003oLZKbog:V
l_mbY_;o000000?oMJ7]00Go0000ogVLj?miW>SoNIcXo`000003ogfHh`04o`000?n1U=goPICMo`00
00?oQ97H00Go0000ohR>d_n8S];oR8kBo`000004oh^;cP04o`000?n>RLWoSXW9o`0000?oT8O600Go
0000oi:5`_l0003oPh79o`000003ohR1a@03o`000?n=P<7oSH3100;oSH3100Go0000oi20_On@P;go
T82mo`000004oi=o^P05o`000?nFOkSo0000oiB0^_l000001OnGOkP2o`0000GoVH2f00?o0000oiZ1
]ol000000ol00003oib1]@05oif1]?l0003o0000oij4]ol000001_nOQ;H00ol0003oXXJgoj:6]`03
oj:6]`03o`000?nURkWoYH^i00?oYH^i0_l00002ojJ;^@03o`000?nYSk_oZHnk00?oZHnk00Go0000
ojfD_On]U;go[IBmo`000004ok2J`003o`000?neWl?o]Io300;o]Io300Go0000okVVa_niY/Ko^JK6
o`000004okj^b@04o`000?o3]/go`kK=o`0000Cob;kA00Co0000olg7e?o=amCo00000ooAcmP01?l0
003oe=SKo`000?l00002om3oeP;o000000?o_?_5o`000?ooool08_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Cooooo000]ooooo`;o0000AOooool00ol0003oKk3hofn`n002ofn`
n005o`000?m`ZoGoL:_eog2[mOl000000ombY_801Ol0003oMJ7]ogFQkOmeXNgo000000;oNIcX00?o
0000ogfHhommV><00_mmV><01?l0003oPICMoh6DgOl00003ohBAf005o`000?n8S];oR8kBohR>d_l0
00000on;Rlh01Ol0003oSXW9ohj9bOn>RLWo000000;oT8O60_l00003oh>1b@05o`000?n8PLGoR875
ohR1aOl000000on=P<400ol0003oT82moi20_@02oi20_@07o`000?nCOk[oTgnjoi=o^_l0003oUWnh
o`000002oiB0^P03o`000?nGOkSoUgnh00?oUgnh0_l00004oiV0]P03o`000?nJPKOoVX6g00;oVX6g
1Ol00004oij4]`03o`000?nOQ;KoWhBf00?oWhBf00?o0000oj:6]onRQ[L00_nRQ[L00ol0003oYH^i
ojF;^@04ojF;^@;oZ8nk00?o0000ojJ;^Ol000001OnYSk/01Ol0003o[IBmojfD_On]U;go000000Co
/9[000Go0000okFO`oneWl?o]Io3o`000003okVVaP03o`000?nn[/Wo_Zk900;o_Zk900Go0000ol>f
cOo3]/go`kK=o`000003olRnd@05o`000?o=amCocLODolg7e?l000000ooAcmP2o`000005omOlg?l0
003od?oFo`000?o6o/d00ol0000Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
1?ooool002oooooo00?o0000ooooooooool0@oooool00ol0003oKk3hofn`n002ofn`n004o`000?m`
ZoGoL:_eog2[m@;o00000_mbY_801Ol0003oMJ7]ogFQkOmeXNgo000000;oNIcX00?o0000ogfHhomm
V><00_mmV><01?l0003oPICMoh6DgOl00002ohBAf005o`000?n8S];oR8kBohR>d_l000001?n;Rlh0
2?l0003oSXW9ohj9bOl0003oT8O6o`000?mkP/ko00001?n3PLT01?l0003oR875ohR1aOl00004ohf0
`@05o`000?n@P;goT82moi20_Ol000001?nCOkX00ol0003oU82joiB0^P02oiB0^P03o`000?nGOkSo
Ugnh00;oUgnh00?o0000oiN1^Ol000000onIP;H00ol0003oVX6goiZ1]`02oiZ1]`05o`000?nLPkOo
W8>goib3]ol000001?nNQ;L00ol0003oWhBfoin4]P02oin4]P03o`000?nQQkSo000000?oXXJg00?o
0000ojF;^OnURkT00onURkT01?l0003oZ8nkojR?^onXSk/2o`0000CoZHnk00?o0000ojfD_On]U;d0
0_n]U;d00ol0003o/9[0ok2J`002ok2J`005o`000?neWl?o]Io3okFO`ol000000oniY/H00ol0003o
_Zk9okj^b@02okj^b@05o`000?o3]/go`kK=ol>fcOl000000oo8_]401Ol0003ocLODolg7e?o=amCo
000000;odLoH0_l000001OoGo=co0000om3oe_l0003oa_k=00;o00009oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l00004
ofn`n005o`000?m`ZoGoL:_eog2[mOl000000_mbY_801Ol0003oMJ7]ogFQkOmeXNgo000000;oNIcX
00Go0000ogfHhommV>?oOISSo`000002oh6Dg@05o`000?n4TMSoQ97HohBAf?l000000on8S]801Ol0
003oRh_>oh^;c_n;Rlko000000;oSXW90_l00003og^2cP05o`000?n3PLWoPh79oh>1bOl000000on8
PLD01Ol0003oSH31ohf0`On=P<7o000000CoT82m00Go0000oi=o^_nCOk[oTgnjo`000005oiB0^P05
o`000?nGOkSoUgnhoiMo^?l000000_nGPKT01?l0003oVH2foiV0]_l00004oiZ1]`03o`000?nLPkOo
W8>g00;oW8>g00?o0000oij4]onNQ;L00_nNQ;L01?l0003oWhBfoin4]_l00003oj67^004o`000?nR
Q[OoXXJgo`0000GoYH^i00?o0000ojR?^onXSk/00_nXSk/2o`0000?oZHnk00?o0000ojfD_On]U;d0
0_n]U;d00ol0003o/9[0ok2J`002ok2J`005o`000?neWl?o]Io3okFO`ol000000oniY/H00ol0003o
_Zk9okj^b@02okj^b@05o`000?o3]/go`kK=ol>fcOl000000oo8_]401_l0003ocLODolg7e?o=amCo
0000om7?f0;o000000CoeocLo`000?o@omKod?oF0ol0000Yooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool01?ooool0037ooooo0_l00015ooooo`03o`000?m_/?SoKk3h00;oKk3h00Go
0000og2[mOm`ZoGoL:_eo`000002og:VlP05o`000?meXNgoMJ7]ogFQkOl000000_miW>P01Ol0003o
OISSogfHhommV>?o000000;oPICM00Co0000ohBAf?n4TMSo00000on8S]800ol0003oRh_>oh^;cP04
o`000003og:2e?l0003oNh;>00?oNh;>00Go0000oh>1bOn3PLWoPh79o`000003ohR1a@05o`000?n=
P<7oSH31ohf0`Ol000000on@P;d01_l0003oTgnjoi=o^_l0003oTH6no`0000CoU82j00Go0000oiMo
^?nGOkSoUgnho`000003oiN1^@03o`000?nIP;Ko000000CoVX6g00?o0000oib3]onLPkL00_nLPkL0
0ol0003oWXBgoij4]`02oij4]`04o`000?nOQ;KoWhBfo`0000CoXHNh0_l00006ojF;^@03o`000?nX
Sk_oZ8nk00;oZ8nk00?o0000ojbE__l000000ol00003ojfD_@03o`000?n`V/3o/9[000?o/9[000Go
0000okFO`oneWl?o]Io3o`000003okVVaP03o`000?nn[/Wo_Zk900;o_Zk900Go0000ol>fcOo3]/go
`kK=o`000003olRnd@03o`000?o=amCocLOD00?o000000Gof_GOo`000?oGo=co0000om3oeP03o`00
02[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00<oooool00ol0003o
ooooooooo`13ooooo`;o00000om_/?P01Ol0003oL:_eog2[mOm`ZoGo000000;oLZKb00Go0000ogFQ
kOmeXNgoMJ7]o`000002ogVLj007o`000?mmV>?oOISSogfHhol0003oPICMo`000003ohBAf003o`00
0?n8S];oR8kB00?o00000_mWP]X01Ol0003oLX;Dog:2e?mbP]Co000000?oNh;>00Go0000oh>1bOn3
PLWoPh79o`000003ohR1a@05o`000?n=P<7oSH31ohf0`Ol000001?n@P;d00ol0003oTgnjo`000002
oi61_P03o`000?nDP;[oU82j00;oU82j00?o0000oiMo^?l000001OnGPKT2o`0000CoVX6g00?o0000
oib3]onLPkL00_nLPkL00ol0003oWXBgoij4]`02oij4]`03o`000?nOQ;Ko000000KoXHNh00?o0000
ojF;^OnURkT00onURkT00ol0003oZ8nkojR?^`02ojR?^`03o`000?n/UKko[9Fn00?o[9Fn0_l00002
ojfD_@03o`000?n`V/3o/9[000?o/9[000Go0000okFO`oneWl?o]Io3o`000003okVVaP03o`000?nn
[/Wo_Zk900;o_Zk900Go0000ol>fcOo3]/go`kK=o`000003olRnd@04o`000?o=amCo0000o`0000;o
f_GO00Co0000omOlg?l0003od?oF0ol0000/ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool003Cooooo00?o0000ooooooooool0A?ooool01?l0003oKk3hofn`n?m_/?P2o`00
00;oL:_e00Co0000og:Vl_mbY_;o00000omeXNd01?l0003oNIcXogVLj?l00003ogfHh`03o`000?n1
U=go000000;oQ97H0ol000000omHPMoo0000ofN2fP03ofN2fP05o`000?mbP]CoLX;Dog:2e?l00000
0omkP/h01Ol0003oPh79oh>1bOn3PLWo000000?oR87500Go0000ohf0`On=P<7oSH31o`000004oi20
_@05o`000?nAPKkoTH6noi61__l000001OnDP;X2o`0000KoUh6i0_l00004oiZ1]`03o`000?nLPkOo
W8>g00;oW8>g00Co0000oij4]onNQ;OoWXBg0_l00007oj67^003o`000?nURkWoYH^i00?oYH^i00?o
0000ojR?^onXSk/00_nXSk/00ol0003o[9FnojbE_P03ojbE_P03o`000?n`Vl;o000000;o00001?n`
V/000ol0003o]Io3okFO``02okFO``05o`000?niY/Ko^JK6okVVa_l000001?nn[/T01?l0003o`kK=
ol>fcOl00003olRnd@?o000000CofN[Po`000?oJmMoo00000_oGo=`2o`000003olKncOl0003ooooo
02gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003o
ooooooooo`14ooooo`03o`000?m_/?SoKk3h00;oKk3h00Co0000og2[mOm`ZoGo00000_mbY_801Ol0
003oMJ7]ogFQkOmeXNgo000000;oNIcX00?o0000ogfHhommV><01Ol00002odJ0i004o`000?mHPMoo
F87Oo`0000CoIh;J00Go0000og:2e?mbP]CoLX;Do`000003og^2cP05o`000?n3PLWoPh79oh>1bOl0
00000_n8PLD00ol0003oSH31ohf0`@02ohf0`@03o`000?n@P;goT82m00;o00001?nAPKh00ol0003o
U82joiB0^P03oiB0^P;o00001OnGPKT01?l0003oVH>jo`000?l00002oiZ1]`03o`000?nLPkOoW8>g
00;oW8>g00Ko0000oij4]onNQ;Oo0000oin7^_l00006oj67^003o`000?nTS;_o000000?oYH^i00?o
0000ojR?^onXSk/00onXSk/00ol0003o[9FnojbE_P02ojbE_P03o`000?n`Vl;o/9_200;o/9_20_l0
0003ok2J`005o`000?neWl?o]Io3okFO`ol000001?niY/H01Ol0003o_Zk9okj^bOnn[/Wo000000?o
`kK=00?o0000olRndOl000000_l00002omWZh007o`000?oJmMoof_GOo`000?oGo=co0000om3oeP02
o`00033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00=_ooool2o`00
04Gooooo0_l00003ofn`n004o`000?m`ZoGoL:_eo`0000;oLZKb00?o0000ogFQkOmeXNd01_l00003
oaahi0;o<WgV0om6P>@01?l0003oF87OoeR1gol00004ofN2fP04o`000?mbP]CoLX;Do`0000?oNh;>
00Go0000oh>1bOn3PLWoPh79o`000003ohR1a@07o`000?n=P<7oSH31ohf0`Ol0003oT82mo`000002
ohf1`P03o`000?nAPKkoTH6n00;oTH6n00?o0000oiB0^_nDP;X00_nDP;X00ol0003oUH:mo`000004
oiN1^@04o`000?nIPk[oVH>joiV3^P?o00001?nLPkL00ol0003oWXBgo`000003oin7^P03o`000?nQ
QkSoXHNh00?oXHNh00Co0000ojB<^onTS;_o00000_nURkT00ol0003oZ8nkojR?^`02ojR?^`03o`00
0?n/UKko[9Fn00?o[9Fn00?o0000ok2K`_n`Vl800_n`Vl800ol0003o]Z?6o`000003o`0000?o]Io3
00Go0000okVVa_niY/Ko^JK6o`000004okj^b@03o`000?o3]/go000000?o00000_oEgMd02Ol0003o
fN[PomWZh?l0003of_GOo`000?oGo=co0000om3oeP02o`00037ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`03o`000?m_/?So
Kk3h00Wo00000ol0K]L3o`Icg`Co77ST0_lbONH3odJ0i004o`000?mHPMooF87Oo`0000?oIh;J00Go
0000og:2e?mbP]CoLX;Do`000003og^2cP05o`000?n3PLWoPh79oh>1bOl000000on8PLD01Ol0003o
SH31ohf0`On=P<7o000000CoSH7200?o0000oi61__nAPKh00_nAPKh01?l0003oU82joiB0^_l00003
oiF2_@05o`000?nGPKWoUh6ioiN1^Ol000001OnIPkX7o`0000GoWhNj00Go0000oj67^?nQQkSoXHNh
o`000004ojB<^`03o`000?nURkWo000000CoZ8nk00?o0000ojbE__n/UKh00on/UKh01Ol0003o/9_2
ok2K`_n`Vl;o000000Go]Z?61ol000001?niY/Ko0000okj^bOnn[/T4o`0000;ocm3I00Co0000omGM
gOoEgMgo00000_oIj^000ol0003of_GOo`000002omOlg0?o0000<oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo0_l00003o`1_
b0?o06_90ol0Jll4o`1^e`?o1W?O1?lLN>@2oc9miP?oAX3T00Co0000oeR1gomHPMoo00000omWP]X0
1Ol0003oLX;Dog:2e?mbP]Co000000?oNh;>00Go0000oh>1bOn3PLWoPh79o`000002ohR1a@05o`00
0?n=P<7oSH31ohf0`Ol000001On=PL801Ol0003oTH6noi61__nAPKko000000;oU82j00?o0000oiF2
_OnEP[d00_nEP[d01?l0003oUh6ioiN1^Ol00005oiV3^P03o`000?nLQ[[oW8Jj00?oW8Jj00?o0000
oin7^_nOQkX00onOQkX01?l0003oXHNhoj67^?l00006ojB<^`03o`000?nXSk_oZ8nk00?oZ8nk00?o
0000ojbE__n/UKh00_n/UKh00ol0003o/9_2ok2K`P02ok2K`P03o`000?nfXlKo]Z?600?o]Z?600Go
0000okb]bonl[L_o_:g;o`000002ol:gc`Co00000_o9`m@01?l0003ocm3Iolo@fOl00002omGMg@04
o`000?oIj^3ofN[Po`0000;of_GO00Go0000omOlg?l0003od?oFo`00000eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00oooool003[ooooo00?o0000ooooooooool0AOooool5o`1_
b0?o06_90ol0Jll3o`1^e`04o`000?l6Lmoo1W?Oo`0000?o77ST00?o0000oc9mi_l000000_m6P>@0
1?l0003oF87OoeR1gol00003ofN2fP05o`000?mbP]CoLX;Dog:2e?l000000omkP/h01?l0003oPh79
oh>1bOl00003ohR1a@05o`000?n=P<7o0000ohN2aol000001On=PL801ol0003oTH6noi61__nAPKko
0000oiB0^_l000001OnEP[d00ol0003oUh6io`000005oiV3^P03o`000?nLQ[[oW8Jj00CoW8Jj00?o
0000oin7^_nOQkX00onOQkX00ol0003oXHNho`000006ojB<^`;o00000onXSk/00ol0003o[9FnojbE
_P03ojbE_P03o`000?n`Vl;o/9_200;o/9_200?o0000okJSa_nfXlH00_nfXlH01Ol0003o_:g;okb]
bonl[L_o000000Co`[O?00Go0000olW3e?o9`mCobL?Do`000003olo@f@04o`000?oEgMgoeMgMo`00
00;ofN[P00Oo0000om[egol0003oeocLo`000?o@omKo000003Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`00>oooool2o`0004Sooooo1?l0KlP3o`1[b@;o06_?1?l0K]L3
o`Icg`?o77ST00?o0000oc9mi_l000000_m6P>@01?l0003oF87OoeR1gol00003ofN2fP04o`000?mb
P]CoLX;Do`0000?oNh;>00Go0000oh>1bOn3PLWoPh79o`000003ohR1a@05o`000?n7P/OoQh;7ohN2
aol000001?n=PL800ol0003oTH6noi61_P02oi61_P;o00001_nEP[d2o`0000GoVH>j00?o0000oib6
^_nLQ[X01?nLQ[X00ol0003oWhNjoin7^P03oin7^P;o00001_nTS;/01?l0003oYi:oojNB_ol00002
ojR?^`03o`000?n/UKko[9Fn00;o[9Fn00?o0000ok2K`_n`Vl800_n`Vl800ol0003o]Z?6okJSaP03
okJSaP05o`000?nl[L_o_:g;okb]bol000000oo2]ll00ol0003obL?DolW3e002olW3e004o`000?o?
d=Wocm3Io`0000;oeMgM00Ko0000omWZh?oIj^3o0000om[egol00002omOlg0;o0000>?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000mooooo`03o`000?oooooooooo04Oo
oooo00Co0000o`1_b?l0KlSo06o80_l0JlT00ol0003o06_?o`1[c`03o`1^e`04o`000?l6Lmoo1W?O
o`0000;o77ST00?o0000oc9mi_l000000_m6P>@01?l0003oF87OoeR1gol00002ofN2fP05o`000?mb
P]CoLX;Dog:2e?l000000omkP/h01?l0003oPh79oh>1bOl00003ohR1a@03o`000?n7P/OoQh;700;o
Qh;700?o0000ohf1`_n=PL800_n=PL801ol0003oTH6noi61__nAPKko0000oi:4`Ol000001_nEP[d2
o`0000GoVH>j00?o0000oib6^_nLQ[X00onLQ[X01?l0003oWhNjoin7^_nOQkX2o`000003oj6<_Ol0
003oY8bk00CoY8bk00?o0000ojNB_onWT[l00_nWT[l00ol0003oZ8nko`000004ojbE_P03o`000?n`
Vl;o/9_200;o/9_200?o0000okJSa_nfXlH00_nfXlH00ol0003o_:g;okb]b`02okb]b`05o`000?o2
]loo`[O?ol:gcol000000oo9`m@01Ol0003ocm3Iolo@fOo?d=Wo000000;oeMgM00Oo0000omWZh?oI
j^3o0000om[egol0003oeocL00;o0000>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00;ooooo000nooooo`03o`000?oooooooooo04Wooooo0ol0KlP2o`1[b@03o`000?l0Jloo06_?
00?o06kG0_l6Lml01_l0003o77SToaahi?l0003o<WgVo`0000;oAX3T00?o0000oeR1gol000000omW
P]X01Ol0003oLX;Dog:2e?mbP]Co000000?oNh;>00So0000oh>1bOn3PLWo0000ohR1aOl0003oOX?=
o`0000CoQh;700?o0000ohf1`_n=PL800_n=PL801?l0003oTH6noi61__l00002oi:4`@03o`000?nE
P[goUH:m00?oUH:m00?o0000oiR6__l000000_l00002oiV3^P03o`000?nLQ[[oW8Jj00CoW8Jj0ol0
0004oj6<_@03o`000?nTS;_oY8bk00;oY8bk00?o0000ojNB_onWT[l00onWT[l00ol0003o[9FnojbE
_P03ojbE_P03o`000?n`Vl;o/9_200;o/9_200?o0000okJSa_nfXlH00_nfXlH01Ol0003o_:g;okb]
bonl[L_o000000?o`[O?00?o0000olW3e?o9`m@00_o9`m@01?l0003ocm3Iolo@fOl00002omGMg@06
o`000?oIj^3ofN[Po`000?oJmMoo00000_oGo=`00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool003oooooo00?o0000ooooooooool0B_ooool01_l0
003o06o8o`1_b?l0KlSo06_9o`0000;o06_?0_l0K]L01?l0003o1W?Oo`Icgol00002oaahi007o`00
0?lbONKo0000odJ0i?l0003oF87Oo`000003ofN2fP04o`000?mbP]CoLX;Do`0000?oNh;>00Go0000
oh>1bOn3PLWoPh79o`000003ogj3c@03o`000?n7P/OoQh;700;oQh;700?o0000ohf1`_n=PL800_n=
PL82o`0000CoTXC10_l00003oiF2_@03o`000?nHQ[koV8Jn00;oV8Jn0ol00003oib6^PCo00001_nQ
S;d01Ol0003oY8bkojB<^onTS;_o000000KoYi:o0_l00003ojbE_P03o`000?n`Vl;o/9_200;o/9_2
00?o0000okJSa_nfXlH00onfXlH01Ol0003o_:g;okb]bonl[L_o000000?o`[O?00Go0000olW3e?o9
`mCobL?Do`000003olo@f@03o`000?oEgMgo000000?ofN[P0_l00002omOlg003o`000?oooooooooo
03cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@?ooool2o`0004co
oooo0_l00002o`1_b003o`1[bOl0003o06_?00;o06kG0_l000002ol6Lmoo0000oaahi?lLN>Co0000
oc9mi_l0003oAX3To`000?mHPMoo000000?oIh;J00Co0000og:2e?mbP]Co00000omkP/h01?l0003o
Ph79o`000?l00004ogj3c@05o`000?n7P/OoQh;7ohN2aol000001On=PL82o`0000GoTXC100Co0000
oiF2_OnEP[go00001_nHQ[h4o`0000?oWHVn00?o0000oj6<_OnQS;d01OnQS;d01?l0003oY8bkojB<
^ol00005ojNB_`04o`000?n[VL?oZiW3o`0000;o[9Fn00?o0000ok2K`_n`Vl800_n`Vl800ol0003o
]Z?6okJSaP02okJSaP05o`000?nl[L_o_:g;okb]bol000000oo2]ll00ol0003obL?DolW3e002olW3
e004o`000?o?d=Wocm3Io`0000;oeMgM00Go0000omWZh?oIj^3o0000om[eg`03o`0003oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@_ooool00ol0003oooooooooo`1<
ooooo`06o`000?l0KlSo06o8o`1[bOl0003o06_?0_l0K]L00ol0003o1W?Oo`000002oaahi007o`00
0?lbONKo0000odJ0i?l0003oF87Oo`000002ofN2fP05o`000?mbP]CoLX;Dog:2e?l000000_mkP/h2
o`0000;oLh?D00?o0000ogj3cOmnPld00_mnPld01Ol0003oQh;7ohN2aon7P/Oo000000CoSH7200?o
0000ohf6aol000001OnBQ<400ol0003oUH:mo`000006oiR6_P03o`000?nMRKkoWHVn00CoWHVn00?o
0000oj6<_OnQS;d01OnQS;d00ol0003oY8bko`000005ojNB_`03o`000?n[VL?oZiW300;oZiW300?o
0000ojbE__l000001?n`Vl800ol0003o]Z?6okJSaP02okJSaP05o`000?nl[L_o_:g;okb]bol00000
0oo2]ll01Ol0003obL?DolW3e?o9`mCo000000?ocm3I00?o0000omGMgOl000000ooIj^03o`0004;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003ooooo
ooooo`1=ooooo`;o000000Go06o8o`000?l0003o06_?o`1^e`04o`000008oaahi?l0003o<WgVo`00
0?m6P>Co0000oeR1gol00002ofN2fP04o`000?mbP]CoLX;Dog:2e0;o00000_mRP]`01?l0003oLh?D
og>3e?l00004ogj3c@05o`000?n7P/OoQh;7ohN2aol000000on=PL801?l0003oSHK7ohf6aol00005
oi:4`@;o00001_nHQ[h00ol0003oWHVnoif9_P05oif9_P03o`000?nQS;goXHbm00CoXHbm0_l00006
ojNB_`03o`000?n[VL?oZiW300?oZiW30_l00003ok2K`P03o`000?nfXlKo]Z?600;o]Z?600?o0000
okb]bonl[L/00_nl[L/01?l0003o`[O?ol:gcol00004olW3e004o`000?o?d=Wocm3Io`0000;oeMgM
00?o0000omWZh?oIj^000ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
0Oooool004Cooooo00?o0000ooooooooool0Coooool5o`00000<o`1^eol0003o1W?Oo`000?lLN>Co
0000oc9mi_l0003oAX3To`000?mHPMoo00000_mWP]X00ol0003oLX;Do`000002odYohP04o`000?mR
P]coHX;Lo`0000;oLh?D00?o0000ogj3cOmnPld00_mnPld01ol0003oQh;7ohN2aon7P/Oo0000ohf1
`_l000001?n=Q/L00ol0003oTXC1oi:4`@03oi:4`@;o00001OnHQ[h00ol0003oWHVnoif9_P05oif9
_P03o`000?nQS;goXHbm00;oXHbm0_l000000onTT/;o0000ojNB_`04ojNB_`03o`000?n[VL?oZiW3
00CoZiW300?o0000ok2RbOl000000_n`Vl800ol0003o]Z?6okJSaP02okJSaP05o`000?nl[L_o_:g;
okb]bol000000oo2]ll01Ol0003obL?DolW3e?o9`mCo000000?ocm3I00?o0000omGMgOl000000_oI
j^03o`0004Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2
o`0005;ooooo013oR`00o`000?l0003o06kGo`000?l6Lmoo0000oaahi?l0003o<WgVo`000?m6P>Co
0000oeR1gol0003oIh;J0ol00003odYohP04o`000?mRP]coHX;Lo`0000;oLh?D00?o0000ogj3cOmn
Pld00_mnPld01?l0003oQh;7ohN2aon7P/L2o`0000GoSHK70_l00003oi:4`@03o`000?nFRLCo0000
00;o00000onHQ[h00ol0003oWHVnoif9_P04oif9_P05o`000?nQS;goXHbmoj6<_Ol000001?nTT/80
1Ol0003oYi:oojNB_onWT[oo000000KoZiW300Oo0000ok2RbOn`X/Wo/:;9o`000?n`Vl;o000000?o
]Z?600?o0000okb]bonl[L/00_nl[L/01Ol0003o`[O?ol:gcoo2]loo000000?obL?D00Ko0000olo@
fOo?d=Wo0000omGMgOl00003omWZh003o`000?oooooooooo04Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`1Booooo`;oT`403?l00002
obQgh`05o`000?m:On;oBWoRodYoh_l000000_mRP]`01?l0003oLh?Dog>3e?l00004ogj3c@04o`00
0?n7P/OoQh;7ohN2a`;o00001_n=Q/L01?l0003oTXC1oi:4`Ol00004oiJ9a0Co00001onMRKh3o`00
00KoY9;200Co0000ojNB_onWT[oo00001On[VL<00ol0003o/:;9ok2Rb@03ok2Rb@;o00000onfXlH0
1Ol0003o_:g;okb]bonl[L_o000000?o`[O?00Go0000olW3e?o9`mCobL?Do`000003olo@f@03o`00
0?oEgMgo000000?o0000B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo
0018ooooo`03o`000?oooooooooo05Cooooo00?oT`40ohT00?n900000_mj0002oeh000;o04jm0_l0
ImT01?l0003o:7OSobQghol00003odYohP04o`000?mRP]coHX;Lo`0000;oLh?D00?o0000ogj3cOmn
Pld00_mnPld01_l0003oQh;7ohN2aol0003oQXW?o`0000KoSHK700?o0000oi:4`Ol000001onFRL@9
o`0000SoY9;200?o0000ojNB_ol000001On[VL<00ol0003o/:;9ok2Rb@04ok2Rb@06o`000?nf[M3o
0000o`000?nfXlKo00000onl[L/01Ol0003o`[O?ol:gcoo2]loo000000?obL?D00?o0000olo@fOo?
d=T01Ol000000om`d8ooooooooooo`1:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00Oooool004Wooooo00?o0000ooooooooool0E_ooool2ohT00003ogX00?mN003oGP0000;o04jm
0_l0ImT01?l0003o:7OSobQghol00003odYohP04o`000?mRP]coHX;Lo`0000;oLh?D00?o0000ogj3
cOmnPld00_mnPld2o`0000?oQXW?0_l00005ohf6a`;o00001onFRL@00ol0003oWHo4oif?a005oif?
a003o`000?nTT/;oY9;200KoY9;20_l00005oj^I``03o`000?n`X/Wo/:;900Co/:;900?o0000okJ]
d?nf[M000_nf[M03o`0000;o_:g;00Co0000ol:gcoo2]loo00000oo9`m@01?l0003ocm3Iolo@fOo?
d=T2o`000003ok3jd_l0003oL=2?04kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`01ooooo`00B_ooool2o`0005Oooooo00Co0000ohT00?n9003oNP000_mN0002o`1>_@04o`1WfOl0
003o0000obQgh`;o00000_m:On801?l0003oHX;Lof:2g?l00002og>3e003o`000?mnPlgoOX?=00;o
OX?=0_l00004ohJ9c`03o`000?n=Q/OoSHK700?oSHK70ol00005oiJ9a003o`000?nMSlCoWHo400Ko
WHo400?o0000ojBB`_nTT/800onTT/82o`000003ojJIb?l0003oZiW300CoZiW300?o0000ok2RbOn`
X/T00on`X/T00ol0003o]Zg@okJ]d003okJ]d003o`000?nl^]Oo_;[G00Co000000?o`[O?o`000?o9
`m@00_o9`m@7o`000003og3@Sooooooooooo04gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`01ooooo`00C?ooool00ol0003oooooooooo`1Dooooo`04o`000?ooooooooooohT000;o
NP0000?oGP00o`000?l0C[d00_l0ImT01?l0003o:7OSobQghol00002odYohP04o`000?mRP]coHX;L
o`0000;oLh?D00Oo0000ogj3cOmnPlgoOX?=o`000?mlS=So000000CoQXW?00?o0000ohf6aon=Q/L0
0_n=Q/L00ol0003oThk;oi>>b`03o`0000?oUXW400?o0000oif?a?nMSl@01OnMSl@01?l0003oY9;2
ojBB`_nTT/82o`0000CoYYW800Go0000oj^I`on[VL?oZiW3o`000005ok2Rb@03o`000?nf[M3o]Zg@
00?o]Zg@00?o0000okbjeonl^]L00_nl^]L00ol0003o`l_Pol?;h007o`000004olCli_l0003o0000
o`0005;ooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool004gooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`02ooooo`08ohT00?mj003oGP00o`000?l0C[go0000o`1W
fOl00002obQgh`04o`000?m:On;oBWoRo`0000;oHX;L00Ko0000og>3e?mcPmCo0000ogj3cOl00003
ogb<f003o`000?n6RLooQXW?00;oQXW?0_l00002ohf6a`03o`000?nCS/_oThk;00?oThk;1?l00007
oif?a004o`000?nTT/;o0000o`0000OoYYW800?o0000oj^I`ol000001On`X/T00ol0003o]Zg@okJ]
d003okJ]d003o`000?nl^]Oo_;[G00;o_;[G00Go0000ol?;h?o3bn3o`l_Po`000002olWMj004o`00
0?o;l>co0000olCliP?o0000E?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00
C_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Gooooo00GoNP00oeh00?l0003o
04jmo`1Wf@02o`000005obQghol0003oBWoRodYoh_l000000_mRP]`00ol0003oLh?Dog>3e002o`00
00CoO8cH0_l00004ohJ9c`;o00002OnCS//:o`0000WoYYW80_l00005ok2Rb@03o`000?nf[M3o]Zg@
00?o]Zg@00?o0000okbjeonl^]L00_nl^]L01Ol0003o`l_Pol?;h?o3bn3o000000;obMgX00Co0000
ol_`k?l0003oa?cV0_l0001Fooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001?
ooooo`;o0000D_ooool00ol0003oooooooooo`07ooooo`07oeh00?l0003o04jmo`000?l0ImWo0000
obQgh`02o`000009odYoh_l0003oHX;Lof:2g?l0003oLh?Do`000?mZS^?o000000GoO8cH00?o0000
ohJ9con6RLl00_n6RLl2o`0000SoThk;00?o0000oifFc?nMU/`01_nMU/`00ol0003oYYW8ojJIb005
ojJIb0;o00000_nZY=401Ol0003o/:;9ok2RbOn`X/Wo000000Go]Zg@00?o0000okbjeonl^]L00_nl
^]L01Ol0003o`l_Pol?;h?o3bn3o000000;obMgX00Co0000ol_`k?l0003oa?cV0_l0001Hooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool02Oooool01OmN003o0000o`1>_Ol0ImWo000000;o:7OS00?o0000odYoh_l0
00000_mRP]`2o`0000;oJXkS0_l00004ogb<f0;o00000_n6RLl00ol0003oSiCEo`000002o`0000Go
Thk;00?o0000oifFc?nMU/`01onMU/`00ol0003oYYW8ojJIb002ojJIb0;o00001OnZY=400ol0003o
/:;9o`000005okJ]d003o`000?nl^]Oo_;[G00;o_;[G00Go0000ol?;h?o3bn3o`l_Po`000002olWM
j004o`000?o;l>co0000olCliP;o0000F_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?oGP00o`00
0?l0C[d00ol000002?lXMn?o0000odYoh_l0003oHX;Lo`000?m=SNco00000omZS^<2o`0000CoO8cH
00?o0000ohJ9col000001?n?U=D3o`0000?oThk;00?o0000oifFc?nMU/`01_nMU/`01Ol0003oYYW8
ojJIb?nVVLSo000000OoZZCA0_l00005okJ]d003o`000?nl^]Oo_;[G00;o_;[G00Go0000ol?;h?o3
bn3o`l_Po`000002olWMj004o`000?o;l>co0000olCliP;o0000G?ooool00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000ooooooooool03?ooool3o`00
0005o`1WfOl0003o:7OSo`000?m:On800_l00002odf=k0;o00000omZS^<00ol0003oO8cHogb<f002
ogb<f0;o00001on?U=D4o`0000SoWIK<00Co0000ojJIb?l0003o00001_nZY=42o`0000;o[[7K00Go
0000okJ]d?nf[M3o]Zg@o`000004okbje`05o`000?o3bn3o`l_Pol?;h?l000000_o9gNP01?l0003o
bo3/o`000?o4o>H2o`0005gooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005Go
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0>ooooo`05o`000?l0C[go0000o`00
0?lXMn<00_l000000olKP^So0000o`000002odf=k004o`000?mZS^?oJXkSofZ>h`;o00000omlS=P3
o`0000SoSiCE2ol00007ojZTd@03o`000?n^/M_o[[7K00?o[[7K00?o0000okJ]d?l000001?nl^]L0
1Ol0003o`l_Pol?;h?o3bn3o000000;obMgX00Co0000ol_`k?l0003oa?cV0_l0001Oooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo00oooooo1Ol000001?l0HlGo0000o`000?lKP^P2o`000003odf=k?l0003o000000?oJXkS
0_l000001?mlS=So0000ohJLh_n6W>83o`0000GoSiCE00?o0000oifOe_nMWmH01onMWmH00ol0003o
ZZCAojZTd@03ojZTd@;o00001_n^/M/3o`0000?o_;[G00Go0000ol?;h?o3bn3o`l_Po`000002olWM
j005o`000?o;l>co0000olCli_l00000H_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
05Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Aooooo`;oP`0000CoH@00o`00
0?l0003o06?50_l000001?lKP^So0000o`000?m=SN`2o`0000?oJXkS0_l00005ohJLhP?o00000_n?
U=D00ol0003oWIoFoifOeP08oifOeP03o`000?nZY=7oZZCA00;o00001_n^/M/2o`0000?o/L?X00?o
0000okbjeol000000oo3bn001Ol0003obMgXolWMj?l0003obo3/00?o0000I?ooool00ol0003ooooo
ooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo01Cooooo00Go
P`00of400?l0003o0000o`1Sa@02o`000005oa^2j?l0003oCHg/odf=k?l000000omZS^<3o`0000Ko
QYcR1?l00009oifOeP03o`000?nZY=7o000000Ko[[7K0_l00005ok73j0Co000000Co`l_Po`000?o9
gNSobMgX1?l0001Vooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F_ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00CoP`00o`000?l0003o06?51?l000001Om=
SNco0000o`000?mZS^?o000000;oMJG`0ol00006ohJLhPco00001_n^/M/00ol0003o/L?Xok73j003
ok73j0;o00000onafOD7o`0006Wooooo00Go0000ooooooooooooooooo`000001ooooo`00Foooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01[ooooo1ol000000om=SNco0000o`000005
ogFUl0?o00000on6W>800ol0003oVjcSoi^/h`08oi^/h`03o`000?n^/M_o[[7K00;o[[7K0_l00004
ok73j0;o00000onafOD2o`000004ojK/nOl0003o0000o`0006gooooo00Co0000oooooooooooo0000
0Oooool005cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Looooo`03of400?l0
003o000000Oo00001_meYO03o`000003ohJLh_l0003oVjcS00WoVjcS00Co0000ojjafol0003o0000
1Ona`nP01?l0003o/MWeok7ImOnafOD2o`000004ojK/nOl0003o0000o`00073ooooo00?o0000oooo
ool000000Oooool005gooooo0_l00014ooooo`03o`000?oooooooooo01kooooo00?oH@00o`000?l0
00002?l00006ogFUl0oo00001?na`nP2o`0000;o/MWe1_l0001booooo`03o`000?oooooooooo007o
0000001Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08Oooool<o`0000?oMJG`
00?o0000oiBmlonD_O<02onD_O<01?l0003o/L?Xo`000?l00002ok7Im@Ko0000MOooool1o`00007o
oooo0Ol00000063ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?lg003o=`0000[o000000?oMJG`o`000?nD_O<01OnD_O<9o`000003ok7ImOl0003o000000Co0000
N?ooool2o`000000HOooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02Oooooo0olg
000>o`0000;oP<go3?l0001iooooo`?o0000001Rooooo`;o0000?oooool00ol0003oooooooooo`0/
ooooo`;o=`004ol0001jooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0aooooo`03ocL00?l0003o000000Co0000Ooooool4o`0000Oooooo001Uooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0/oooool4o`0000_ooooo001Vooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0/?ooool3o`0000oooooo001Wooooo`;o0000>_oo
ool00ol0003oooooooooo`2/ooooo`Co00004_ooool006Wooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`2Xooooo`Co00005_ooool006[ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2Tooooo`Co00006_ooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`2Qooooo`Co00007_ooool006cooooo0_l0000dooooo`03o`000?oooooooooo09gooooo
1?l0000Rooooo`00K_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Wooooo1?l0
000Vooooo`00Koooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Gooooo1?l0000Z
ooooo`00L?ooool2o`00033ooooo00?o0000ooooooooool0TOooool4o`0002kooooo001booooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0S_ooool3o`0003;ooooo001cooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0R_ooool4o`0003Gooooo001dooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0Q_ooool4o`0003Wooooo001eooooo`;o0000:oooool0
0ol0003oooooooooo`22ooooo`Co0000?Oooool007Oooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1nooooo`Co0000@Oooool007Sooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1jooooo`Co0000AOooool007Wooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`1fooooo`Co0000BOooool007[ooooo0_l0000Vooooo`03o`000?oooooooooo07;ooooo1?l0
001=ooooo`00O?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06oooooo0ol0001A
ooooo`00OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06_ooooo1?l0001Doooo
o`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Oooooo1?l0001Hooooo`00
Ooooool2o`00027ooooo00?o0000ooooooooool0Hoooool4o`0005cooooo0021ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0Goooool4o`00063ooooo0022ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0Foooool4o`0006Cooooo0023ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Eoooool4o`0006Sooooo0024ooooo`;o00007?ooool00ol0003o
ooooooooo`1Cooooo`Co0000K?ooool008Kooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1?ooooo`Co0000L?ooool008Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1<ooooo`?o0000M?ooool008Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`18
ooooo`Co0000Moooool008Wooooo0_l0000Gooooo`03o`000?oooooooooo04Cooooo1?l0001koooo
o`00Roooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo043ooooo1?l0001oooooo`00
S?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03cooooo1?l00023ooooo`00SOoo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Sooooo1?l00027ooooo`00S_ooool2
o`0001;ooooo00?o0000ooooooooool0=?ooool4o`0008_ooooo002@ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0<Oooool4o`0008oooooo002Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;_ooool3o`0009?ooooo002Booooo`;o00003Oooool00ol0003ooooo
ooooo`0Zooooo`Co0000U_ooool009Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Vooooo`Co0000V_ooool009Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`Co0000W_ooool009Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Noooo
o`Co0000X_ooool009Oooooo0_l00008ooooo`03o`000?oooooooooo01[ooooo1?l0002Vooooo`00
VOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002Zooooo`00V_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002^ooooo`00Voooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002booooo`00W?ooool2o`00
00?ooooo00?o0000ooooooooool02oooool3o`000;Kooooo002Nooooo`04o`000?ooooooooooo`00
00Wooooo1?l0002iooooo`00Woooool00ol0003oooooo`000005ooooo`Co0000_Oooool00:3ooooo
0_l000000ooooooo0000o`000002o`000<7ooooo002Qooooo`;o0000aOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886655, -0.0135833, \
0.0036241, 0.0036241}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51721 .66581 m .51694 .65827 L .43899 .65168 L p .629 .18 .166 r
F P
0 g
s
.51694 .65827 m .51721 .66581 L .59291 .66195 L p .547 .121 .183 r
F P
0 g
s
.59291 .66195 m .59527 .65394 L .51694 .65827 L p .547 .121 .183 r
F P
0 g
s
.59527 .65394 m .59291 .66195 L .66528 .6467 L p .413 0 .113 r
F P
0 g
s
.66528 .6467 m .67023 .63881 L .59527 .65394 L p .413 0 .113 r
F P
0 g
s
.44193 .6582 m .43899 .65168 L .36521 .63435 L p .667 .166 .045 r
F P
0 g
s
.43899 .65168 m .44193 .6582 L .51721 .66581 L p .629 .18 .166 r
F P
0 g
s
.51749 .67377 m .51721 .66581 L .44193 .6582 L p .638 .194 .178 r
F P
0 g
s
.51721 .66581 m .51749 .67377 L .59052 .67038 L p .554 .132 .196 r
F P
0 g
s
.59052 .67038 m .59291 .66195 L .51721 .66581 L p .554 .132 .196 r
F P
0 g
s
.59291 .66195 m .59052 .67038 L .66027 .655 L p .416 0 .125 r
F P
0 g
s
.66027 .655 m .66528 .6467 L .59291 .66195 L p .416 0 .125 r
F P
0 g
s
.36521 .63435 m .37082 .63936 L .44193 .6582 L p .667 .166 .045 r
F P
0 g
s
.4449 .66508 m .44193 .6582 L .37082 .63936 L p .68 .183 .057 r
F P
0 g
s
.44193 .6582 m .4449 .66508 L .51749 .67377 L p .638 .194 .178 r
F P
0 g
s
.67023 .63881 m .66528 .6467 L .73052 .62055 L p .152 0 0 r
F P
0 g
s
.73052 .62055 m .73799 .61332 L .67023 .63881 L p .152 0 0 r
F P
0 g
s
.36521 .63435 m .30113 .60751 L p .37072 .63931 L .576 0 0 r
F P
0 g
s
.37082 .63936 m .37058 .63914 L p .37072 .63931 L .576 0 0 r
F P
0 g
s
.37058 .63914 m .36521 .63435 L p .37072 .63931 L .576 0 0 r
F P
0 g
s
.37082 .63936 m .30113 .60751 L .30289 .60837 L .576 0 0 r
F
.30113 .60751 m .29943 .6068 L p .30289 .60837 L F P
0 g
s
.29943 .6068 m .30766 .60993 L .37082 .63936 L p .576 0 0 r
F P
0 g
s
.37649 .64466 m .37082 .63936 L .30766 .60993 L p .589 .015 0 r
F P
0 g
s
.37423 .64349 m .37649 .64466 L p .37164 .64221 L .589 .015 0 r
F P
0 g
s
.38224 .65003 m .37649 .64466 L .37423 .64349 L p .583 .01 0 r
F P
0 g
s
.30766 .60993 m .31597 .61327 L .36631 .63938 L p .589 .015 0 r
F P
0 g
s
.36746 .64005 m .30766 .60993 L .36631 .63938 L .589 .015 0 r
F
.37304 .64289 m .30766 .60993 L .37219 .64243 L F
.36631 .63938 m .37219 .64243 L p .36746 .64005 L F P
0 g
s
.37219 .64243 m .37423 .64349 L p .37304 .64289 L .589 .015 0 r
F P
0 g
s
.37164 .64221 m .30766 .60993 L .37423 .64349 L .589 .015 0 r
F
.37423 .64349 m .31597 .61327 L p .37754 .64742 L .583 .01 0 r
F P
0 g
s
.38224 .65003 m .37423 .64349 L .37754 .64742 L .583 .01 0 r
F
.31597 .61327 m .32438 .61663 L .37441 .64551 L p F P
0 g
s
.37441 .64551 m .38224 .65003 L p .37727 .64727 L .583 .01 0 r
F P
0 g
s
.37727 .64727 m .31597 .61327 L .37441 .64551 L .583 .01 0 r
F
.38809 .65522 m .38224 .65003 L .37441 .64551 L p .553 0 0 r
F P
0 g
s
.37441 .64551 m .3245 .6167 L p .38809 .65522 L .553 0 0 r
F P
0 g
s
.38809 .65522 m .3245 .6167 L .32445 .61667 L .553 0 0 r
F
.3245 .6167 m .32438 .61663 L p .32445 .61667 L F P
0 g
s
.32438 .61663 m .33289 .61985 L .3772 .64825 L p .553 0 0 r
F P
0 g
s
.3772 .64825 m .38809 .65522 L p .38068 .65073 L .553 0 0 r
F P
0 g
s
.38068 .65073 m .32438 .61663 L .3772 .64825 L .553 0 0 r
F
.39404 .65999 m .38809 .65522 L .33589 .62178 L p .491 0 0 r
F P
0 g
s
.38809 .65522 m .39404 .65999 L .45415 .68519 L p .678 .153 0 r
F P
0 g
s
.45736 .69073 m .45415 .68519 L .39404 .65999 L p .654 .107 0 r
F P
0 g
s
.39404 .65999 m .40009 .6641 L .45736 .69073 L p .654 .107 0 r
F P
0 g
s
.40009 .6641 m .39404 .65999 L .34702 .62666 L p 0 .157 .599 r
F P
0 g
s
.34702 .62666 m .34151 .62275 L p .34513 .6253 L 0 .157 .599 r
F P
0 g
s
.40009 .6641 m .34702 .62666 L .34513 .6253 L 0 .157 .599 r
F
.33589 .62178 m .33456 .62092 L p .33536 .62145 L .491 0 0 r
F P
0 g
s
.39404 .65999 m .33589 .62178 L .33536 .62145 L .491 0 0 r
F
.33456 .62092 m .33289 .61985 L p .33421 .62072 L F P
0 g
s
.39404 .65999 m .33456 .62092 L .33421 .62072 L .491 0 0 r
F
.51777 .68185 m .51749 .67377 L .4449 .66508 L p .643 .197 .178 r
F P
0 g
s
.51749 .67377 m .51777 .68185 L .58809 .67896 L p .555 .133 .196 r
F P
0 g
s
.58809 .67896 m .59052 .67038 L .51749 .67377 L p .555 .133 .196 r
F P
0 g
s
.59052 .67038 m .58809 .67896 L .65517 .66343 L p .411 0 .122 r
F P
0 g
s
.65517 .66343 m .66027 .655 L .59052 .67038 L p .411 0 .122 r
F P
0 g
s
.37082 .63936 m .37649 .64466 L .4449 .66508 L p .68 .183 .057 r
F P
0 g
s
.44793 .67207 m .4449 .66508 L .37649 .64466 L p .687 .187 .049 r
F P
0 g
s
.4449 .66508 m .44793 .67207 L .51777 .68185 L p .643 .197 .178 r
F P
0 g
s
.66528 .6467 m .66027 .655 L .72296 .62814 L p .144 0 0 r
F P
0 g
s
.72296 .62814 m .73052 .62055 L .66528 .6467 L p .144 0 0 r
F P
0 g
s
.51806 .68975 m .51777 .68185 L .44793 .67207 L p .644 .192 .163 r
F P
0 g
s
.51777 .68185 m .51806 .68975 L .58561 .68734 L p .551 .124 .183 r
F P
0 g
s
.58561 .68734 m .58809 .67896 L .51777 .68185 L p .551 .124 .183 r
F P
0 g
s
.37649 .64466 m .38224 .65003 L .44793 .67207 L p .687 .187 .049 r
F P
0 g
s
.45101 .67887 m .44793 .67207 L .38224 .65003 L p .687 .178 .022 r
F P
0 g
s
.44793 .67207 m .45101 .67887 L .51806 .68975 L p .644 .192 .163 r
F P
0 g
s
.66027 .655 m .65517 .66343 L .71529 .63582 L p .117 0 0 r
F P
0 g
s
.71529 .63582 m .72296 .62814 L .66027 .655 L p .117 0 0 r
F P
0 g
s
.72296 .62814 m .71529 .63582 L .71983 .63228 L p .476 .861 .656 r
F P
0 g
s
.73799 .61332 m .73084 .62024 L p .73412 .61806 L 0 0 0 r
F P
0 g
s
.78479 .58441 m .74098 .61147 L .73412 .61806 L 0 0 0 r
F
.74098 .61147 m .73799 .61332 L .73412 .61806 L F
.71529 .63582 m .7075 .64332 L .7102 .64104 L p .558 .913 .717 r
F P
0 g
s
.73061 .62049 m .78479 .58441 L p .73084 .62024 L 0 0 0 r
F P
0 g
s
.7398 .61437 m .73382 .61835 L p .73982 .61432 L .412 .819 .615 r
F P
0 g
s
.77484 .59078 m .73382 .61835 L .73436 .61797 L .412 .819 .615 r
F
.77484 .59078 m .78479 .58441 L .7398 .61437 L p F P
0 g
s
.77484 .59078 m .7398 .61437 L .73982 .61432 L .412 .819 .615 r
F
.77484 .59078 m .73061 .62049 L .73067 .62045 L F
.73382 .61835 m .73061 .62049 L p .73436 .61797 L F P
0 g
s
.72296 .62814 m .77484 .59078 L p .73067 .62045 L .412 .819 .615 r
F P
0 g
s
.73084 .62024 m .73052 .62055 L .73061 .62049 L p 0 0 0 r
F P
0 g
s
.73061 .62049 m .73052 .62055 L p .73067 .62045 L .412 .819 .615 r
F P
0 g
s
.73052 .62055 m .72296 .62814 L p .73067 .62045 L .412 .819 .615 r
F P
0 g
s
.76479 .59722 m .77484 .59078 L .73036 .62281 L p .476 .861 .656 r
F P
0 g
s
.73036 .62281 m .72529 .62646 L p .73077 .6224 L .476 .861 .656 r
F P
0 g
s
.76479 .59722 m .73036 .62281 L .73077 .6224 L .476 .861 .656 r
F
.73093 .62225 m .72529 .62646 L .72642 .62558 L F
.76479 .59722 m .73077 .6224 L .73093 .62225 L F
.73077 .6224 m .72529 .62646 L .73093 .62225 L F
.74037 .61301 m .73897 .6143 L .74038 .61297 L .648 .962 .786 r
F
.71983 .63228 m .76471 .59728 L p .72499 .62663 L .476 .861 .656 r
F P
0 g
s
.76466 .59732 m .72499 .62663 L .76471 .59728 L .476 .861 .656 r
F
.72529 .62646 m .72296 .62814 L p .72642 .62558 L F P
0 g
s
.72499 .62663 m .72296 .62814 L .71983 .63228 L .476 .861 .656 r
F
.76471 .59728 m .76479 .59722 L p .76466 .59732 L F P
0 g
s
.75461 .6035 m .76479 .59722 L .71529 .63582 L p .558 .913 .717 r
F P
0 g
s
.7102 .64104 m .75269 .60512 L p .72108 .63107 L .558 .913 .717 r
F P
0 g
s
.72108 .63107 m .71769 .63385 L .71288 .63847 L .558 .913 .717 r
F
.72108 .63107 m .71288 .63847 L .7102 .64104 L F
.75241 .60534 m .71769 .63385 L .75269 .60512 L F
.75289 .60491 m .71769 .63385 L .75318 .60471 L F
.71769 .63385 m .71529 .63582 L .7102 .64104 L F
.73897 .6143 m .7075 .64332 L .73932 .61396 L .648 .962 .786 r
F
.73897 .6143 m .73932 .61396 L .74038 .61297 L F
.65517 .66343 m .64998 .67167 L .7075 .64332 L p .069 0 0 r
F P
0 g
s
.7075 .64332 m .71529 .63582 L .65517 .66343 L p .069 0 0 r
F P
0 g
s
.69957 .65037 m .7075 .64332 L .64998 .67167 L p 0 0 0 r
F P
0 g
s
.7075 .64332 m .69957 .65037 L .73942 .61386 L p .648 .962 .786 r
F P
0 g
s
.73942 .61386 m .74038 .61297 L p .73932 .61396 L .648 .962 .786 r
F P
0 g
s
.73932 .61396 m .7075 .64332 L .73942 .61386 L .648 .962 .786 r
F
.75269 .60512 m .75318 .60471 L p .75241 .60534 L .558 .913 .717 r
F P
0 g
s
.78479 .58441 m .79464 .57831 L .79415 .57861 L p 0 0 0 r
F P
0 g
s
.79415 .57861 m .73799 .61332 L p .78479 .58441 L 0 0 0 r
F P
0 g
s
.78479 .58441 m .77484 .59078 L .77519 .59035 L p .77 .97 .923 r
F P
0 g
s
.77519 .59035 m .81227 .54456 L p .78479 .58441 L .77 .97 .923 r
F P
0 g
s
.74038 .61297 m .74429 .60939 L p .74037 .61301 L .648 .962 .786 r
F P
0 g
s
.75318 .60471 m .75461 .6035 L p .75289 .60491 L .558 .913 .717 r
F P
0 g
s
.58809 .67896 m .58561 .68734 L .64998 .67167 L p .396 0 .102 r
F P
0 g
s
.64998 .67167 m .65517 .66343 L .58809 .67896 L p .396 0 .102 r
F P
0 g
s
.30766 .60993 m .29943 .6068 L .24558 .56996 L p 0 .407 .824 r
F P
0 g
s
.51836 .69713 m .51806 .68975 L .45101 .67887 L p .639 .174 .133 r
F P
0 g
s
.51806 .68975 m .51836 .69713 L .58308 .6952 L p .541 .102 .156 r
F P
0 g
s
.58308 .6952 m .58561 .68734 L .51806 .68975 L p .541 .102 .156 r
F P
0 g
s
.38224 .65003 m .38809 .65522 L .45101 .67887 L p .687 .178 .022 r
F P
0 g
s
.45415 .68519 m .45101 .67887 L .38809 .65522 L p .678 .153 0 r
F P
0 g
s
.45101 .67887 m .45415 .68519 L .51836 .69713 L p .639 .174 .133 r
F P
0 g
s
.58561 .68734 m .58308 .6952 L .64468 .67941 L p .369 0 .063 r
F P
0 g
s
.64468 .67941 m .64998 .67167 L .58561 .68734 L p .369 0 .063 r
F P
0 g
s
.24558 .56996 m .25628 .57102 L .30766 .60993 L p 0 .407 .824 r
F P
0 g
s
.31597 .61327 m .30766 .60993 L .25628 .57102 L p 0 .399 .832 r
F P
0 g
s
.51866 .70366 m .51836 .69713 L .45415 .68519 L p .627 .142 .081 r
F P
0 g
s
.51836 .69713 m .51866 .70366 L .58048 .7022 L p .522 .065 .108 r
F P
0 g
s
.58048 .7022 m .58308 .6952 L .51836 .69713 L p .522 .065 .108 r
F P
0 g
s
.25628 .57102 m .26705 .57218 L .31597 .61327 L p 0 .399 .832 r
F P
0 g
s
.32438 .61663 m .31597 .61327 L .26705 .57218 L p 0 .406 .848 r
F P
0 g
s
.45415 .68519 m .45736 .69073 L .51866 .70366 L p .627 .142 .081 r
F P
0 g
s
.64998 .67167 m .64468 .67941 L .69957 .65037 L p 0 0 0 r
F P
0 g
s
.58308 .6952 m .58048 .7022 L .63926 .68632 L p .324 0 0 r
F P
0 g
s
.63926 .68632 m .64468 .67941 L .58308 .6952 L p .324 0 0 r
F P
0 g
s
.26705 .57218 m .2779 .57334 L .32438 .61663 L p 0 .406 .848 r
F P
0 g
s
.33289 .61985 m .32438 .61663 L .2779 .57334 L p .044 .424 .867 r
F P
0 g
s
.79464 .57831 m .78479 .58441 L .82429 .53976 L p .743 .973 .926 r
F P
0 g
s
.82429 .53976 m .83625 .53514 L .79464 .57831 L p .743 .973 .926 r
F P
0 g
s
.33289 .61985 m .34151 .62275 L .39404 .65999 L p .491 0 0 r
F P
0 g
s
.51897 .70902 m .51866 .70366 L .45736 .69073 L p .602 .087 0 r
F P
0 g
s
.51866 .70366 m .51897 .70902 L .57782 .708 L p .488 .003 .03 r
F P
0 g
s
.57782 .708 m .58048 .7022 L .51866 .70366 L p .488 .003 .03 r
F P
0 g
s
.46064 .69518 m .45736 .69073 L .40009 .6641 L p .6 .028 0 r
F P
0 g
s
.45736 .69073 m .46064 .69518 L .51897 .70902 L p .602 .087 0 r
F P
0 g
s
.64468 .67941 m .63926 .68632 L .6915 .65668 L p 0 0 0 r
F P
0 g
s
.6915 .65668 m .69957 .65037 L .64468 .67941 L p 0 0 0 r
F P
0 g
s
.58048 .7022 m .57782 .708 L .63372 .69208 L p .25 0 0 r
F P
0 g
s
.63372 .69208 m .63926 .68632 L .58048 .7022 L p .25 0 0 r
F P
0 g
s
.2779 .57334 m .28884 .57441 L .33289 .61985 L p .044 .424 .867 r
F P
0 g
s
.34151 .62275 m .33289 .61985 L .28884 .57441 L p .123 .446 .881 r
F P
0 g
s
.25628 .57102 m .24558 .56996 L .20758 .52532 L p .414 .642 .951 r
F P
0 g
s
.81227 .54456 m .82429 .53976 L .78479 .58441 L p .77 .97 .923 r
F P
0 g
s
.74429 .60939 m .75461 .6035 L .7075 .64332 L p .648 .962 .786 r
F P
0 g
s
.34151 .62275 m .35025 .62513 L .40009 .6641 L p 0 .157 .599 r
F P
0 g
s
.40009 .6641 m .40627 .66729 L .46064 .69518 L p .6 .028 0 r
F P
0 g
s
.40627 .66729 m .40009 .6641 L .35025 .62513 L p 0 .259 .726 r
F P
0 g
s
.20758 .52532 m .22041 .52429 L .25628 .57102 L p .414 .642 .951 r
F P
0 g
s
.26705 .57218 m .25628 .57102 L .22041 .52429 L p .427 .627 .937 r
F P
0 g
s
.51929 .71289 m .51897 .70902 L .46064 .69518 L p .548 0 0 r
F P
0 g
s
.51897 .70902 m .51929 .71289 L .5751 .71229 L p .424 0 0 r
F P
0 g
s
.5751 .71229 m .57782 .708 L .51897 .70902 L p .424 0 0 r
F P
0 g
s
.464 .69828 m .46064 .69518 L .40627 .66729 L p .488 0 0 r
F P
0 g
s
.46064 .69518 m .464 .69828 L .51929 .71289 L p .548 0 0 r
F P
0 g
s
.28884 .57441 m .29986 .57528 L .34151 .62275 L p .123 .446 .881 r
F P
0 g
s
.35025 .62513 m .34151 .62275 L .29986 .57528 L p .207 .469 .886 r
F P
0 g
s
.63926 .68632 m .63372 .69208 L .68326 .66196 L p 0 0 0 r
F P
0 g
s
.68326 .66196 m .6915 .65668 L .65782 .67579 L p 0 0 0 r
F P
0 g
s
.68326 .66196 m .65782 .67579 L .65789 .676 L 0 0 0 r
F
.67485 .66596 m .68326 .66196 L .65486 .67923 L p .481 .883 .731 r
F P
0 g
s
.65486 .67923 m .63372 .69208 L p .65309 .67978 L .481 .883 .731 r
F P
0 g
s
.67485 .66596 m .65486 .67923 L .65309 .67978 L .481 .883 .731 r
F
.65782 .67579 m .63926 .68632 L p .65789 .676 L 0 0 0 r
F P
0 g
s
.57782 .708 m .5751 .71229 L .62806 .6964 L p .122 0 0 r
F P
0 g
s
.62806 .6964 m .63372 .69208 L .57782 .708 L p .122 0 0 r
F P
0 g
s
.62806 .6964 m .5751 .71229 L p .60924 .70266 L 0 0 0 r
F P
0 g
s
.62226 .69899 m .62606 .69729 L p .60924 .70266 L 0 0 0 r
F P
0 g
s
.62606 .69729 m .62806 .6964 L p .60924 .70266 L 0 0 0 r
F P
0 g
s
.51929 .71289 m .51961 .71498 L .57231 .71476 L p .298 0 0 r
F P
0 g
s
.57231 .71476 m .5751 .71229 L .51929 .71289 L p .298 0 0 r
F P
0 g
s
.5751 .71229 m .57231 .71476 L .62226 .69899 L p 0 0 0 r
F P
0 g
s
.56945 .71514 m .57231 .71476 L .51961 .71498 L p .053 0 0 r
F P
0 g
s
.56945 .71514 m .61633 .69959 L p .58463 .71051 L .379 .843 .838 r
F P
0 g
s
.57231 .71476 m .5706 .71499 L p .58463 .71051 L .379 .843 .838 r
F P
0 g
s
.5706 .71499 m .56945 .71514 L p .58463 .71051 L .379 .843 .838 r
F P
0 g
s
.62806 .6964 m .62226 .69899 L .64735 .68158 L p .655 .971 .879 r
F P
0 g
s
.64735 .68158 m .66628 .66844 L p .64905 .68105 L .655 .971 .879 r
F P
0 g
s
.63372 .69208 m .62806 .6964 L .65818 .67681 L p .481 .883 .731 r
F P
0 g
s
.65811 .6766 m .63372 .69208 L .65818 .67681 L .481 .883 .731 r
F
.64905 .68105 m .62806 .6964 L .64735 .68158 L .655 .971 .879 r
F
.65818 .67681 m .67485 .66596 L p .65811 .6766 L .481 .883 .731 r
F P
0 g
s
.77484 .59078 m .76479 .59722 L .80016 .54939 L p .794 .96 .919 r
F P
0 g
s
.80016 .54939 m .81227 .54456 L .77484 .59078 L p .794 .96 .919 r
F P
0 g
s
.22041 .52429 m .23327 .52327 L .26705 .57218 L p .427 .627 .937 r
F P
0 g
s
.2779 .57334 m .26705 .57218 L .23327 .52327 L p .445 .614 .921 r
F P
0 g
s
.69957 .65037 m .6915 .65668 L .73382 .61468 L p .731 .991 .848 r
F P
0 g
s
.73382 .61468 m .74429 .60939 L .69957 .65037 L p .731 .991 .848 r
F P
0 g
s
.35025 .62513 m .35912 .62684 L .40627 .66729 L p 0 .259 .726 r
F P
0 g
s
.41256 .66934 m .40627 .66729 L .35912 .62684 L p 0 .36 .826 r
F P
0 g
s
.40627 .66729 m .41256 .66934 L .464 .69828 L p .488 0 0 r
F P
0 g
s
.29986 .57528 m .31099 .57586 L .35025 .62513 L p .207 .469 .886 r
F P
0 g
s
.35912 .62684 m .35025 .62513 L .31099 .57586 L p .288 .489 .88 r
F P
0 g
s
.23327 .52327 m .24617 .52225 L .2779 .57334 L p .445 .614 .921 r
F P
0 g
s
.28884 .57441 m .2779 .57334 L .24617 .52225 L p .467 .602 .903 r
F P
0 g
s
.76479 .59722 m .75461 .6035 L .78796 .55409 L p .812 .941 .911 r
F P
0 g
s
.78796 .55409 m .80016 .54939 L .76479 .59722 L p .812 .941 .911 r
F P
0 g
s
.51961 .71498 m .51929 .71289 L .464 .69828 L p .431 0 0 r
F P
0 g
s
.464 .69828 m .46743 .69975 L .51961 .71498 L p .431 0 0 r
F P
0 g
s
.46743 .69975 m .464 .69828 L .41256 .66934 L p 0 .271 .675 r
F P
0 g
s
.24617 .52225 m .2591 .5212 L .28884 .57441 L p .467 .602 .903 r
F P
0 g
s
.29986 .57528 m .28884 .57441 L .2591 .5212 L p .49 .592 .883 r
F P
0 g
s
.35912 .62684 m .36812 .6277 L .41256 .66934 L p 0 .36 .826 r
F P
0 g
s
.41897 .67003 m .41256 .66934 L .36812 .6277 L p .137 .44 .876 r
F P
0 g
s
.41256 .66934 m .41897 .67003 L .46743 .69975 L p 0 .271 .675 r
F P
0 g
s
.6915 .65668 m .68326 .66196 L .72319 .61914 L p .792 .989 .887 r
F P
0 g
s
.72319 .61914 m .73382 .61468 L .6915 .65668 L p .792 .989 .887 r
F P
0 g
s
.31099 .57586 m .32221 .57604 L .35912 .62684 L p .288 .489 .88 r
F P
0 g
s
.36812 .6277 m .35912 .62684 L .32221 .57604 L p .361 .505 .867 r
F P
0 g
s
.75461 .6035 m .74429 .60939 L .77565 .55852 L p .822 .915 .901 r
F P
0 g
s
.77565 .55852 m .78796 .55409 L .75461 .6035 L p .822 .915 .901 r
F P
0 g
s
.2591 .5212 m .27207 .52012 L .29986 .57528 L p .49 .592 .883 r
F P
0 g
s
.31099 .57586 m .29986 .57528 L .27207 .52012 L p .512 .583 .863 r
F P
0 g
s
.47094 .69937 m .46743 .69975 L .41897 .67003 L p 0 .437 .86 r
F P
0 g
s
.51961 .71498 m .51995 .71503 L .56945 .71514 L p .053 0 0 r
F P
0 g
s
.46743 .69975 m .47094 .69937 L .51995 .71503 L p 0 .398 .686 r
F P
0 g
s
.51995 .71503 m .51961 .71498 L .46743 .69975 L p 0 .398 .686 r
F P
0 g
s
.66628 .66844 m .67485 .66596 L .62806 .6964 L p .655 .971 .879 r
F P
0 g
s
.32221 .57604 m .33354 .57573 L .36812 .6277 L p .361 .505 .867 r
F P
0 g
s
.37725 .62757 m .36812 .6277 L .33354 .57573 L p .423 .516 .848 r
F P
0 g
s
.36812 .6277 m .37725 .62757 L .41897 .67003 L p .137 .44 .876 r
F P
0 g
s
.42551 .66918 m .41897 .67003 L .37725 .62757 L p .286 .49 .882 r
F P
0 g
s
.41897 .67003 m .42551 .66918 L .47094 .69937 L p 0 .437 .86 r
F P
0 g
s
.83625 .53514 m .82429 .53976 L .84549 .48878 L p .733 .845 .933 r
F P
0 g
s
.84549 .48878 m .85906 .48583 L .83625 .53514 L p .733 .845 .933 r
F P
0 g
s
.68326 .66196 m .67485 .66596 L .7124 .62258 L p .824 .958 .9 r
F P
0 g
s
.7124 .62258 m .72319 .61914 L .68326 .66196 L p .824 .958 .9 r
F P
0 g
s
.27207 .52012 m .28508 .51898 L .31099 .57586 L p .512 .583 .863 r
F P
0 g
s
.32221 .57604 m .31099 .57586 L .28508 .51898 L p .534 .575 .843 r
F P
0 g
s
.61633 .69959 m .62226 .69899 L .57231 .71476 L p .379 .843 .838 r
F P
0 g
s
.74429 .60939 m .73382 .61468 L .76322 .56253 L p .825 .883 .886 r
F P
0 g
s
.76322 .56253 m .77565 .55852 L .74429 .60939 L p .825 .883 .886 r
F P
0 g
s
.82429 .53976 m .81227 .54456 L .83191 .49179 L p .743 .829 .918 r
F P
0 g
s
.83191 .49179 m .84549 .48878 L .82429 .53976 L p .743 .829 .918 r
F P
0 g
s
.28508 .51898 m .29813 .51778 L .32221 .57604 L p .534 .575 .843 r
F P
0 g
s
.33354 .57573 m .32221 .57604 L .29813 .51778 L p .553 .569 .824 r
F P
0 g
s
.33354 .57573 m .34497 .57486 L .37725 .62757 L p .423 .516 .848 r
F P
0 g
s
.38652 .62631 m .37725 .62757 L .34497 .57486 L p .474 .523 .828 r
F P
0 g
s
.37725 .62757 m .38652 .62631 L .42551 .66918 L p .286 .49 .882 r
F P
0 g
s
.47453 .69694 m .47094 .69937 L .42551 .66918 L p .239 .534 .921 r
F P
0 g
s
.47094 .69937 m .47453 .69694 L .52029 .71282 L p .141 .599 .927 r
F P
0 g
s
.52029 .71282 m .51995 .71503 L .47094 .69937 L p .141 .599 .927 r
F P
0 g
s
.51995 .71503 m .52029 .71282 L .56653 .71322 L p .283 .756 .938 r
F P
0 g
s
.56653 .71322 m .56945 .71514 L .51995 .71503 L p .283 .756 .938 r
F P
0 g
s
.43216 .66663 m .42551 .66918 L .38652 .62631 L p .395 .518 .863 r
F P
0 g
s
.42551 .66918 m .43216 .66663 L .47453 .69694 L p .239 .534 .921 r
F P
0 g
s
.62226 .69899 m .61633 .69959 L .65755 .66917 L p .754 .962 .935 r
F P
0 g
s
.65755 .66917 m .66628 .66844 L .62226 .69899 L p .754 .962 .935 r
F P
0 g
s
.22041 .52429 m .20758 .52532 L .18911 .47507 L p .629 .735 .924 r
F P
0 g
s
.73382 .61468 m .72319 .61914 L .75067 .56596 L p .82 .847 .868 r
F P
0 g
s
.75067 .56596 m .76322 .56253 L .73382 .61468 L p .82 .847 .868 r
F P
0 g
s
.67485 .66596 m .66628 .66844 L .70144 .62479 L p .831 .908 .891 r
F P
0 g
s
.70144 .62479 m .7124 .62258 L .67485 .66596 L p .831 .908 .891 r
F P
0 g
s
.81227 .54456 m .80016 .54939 L .81829 .49481 L p .75 .811 .901 r
F P
0 g
s
.81829 .49481 m .83191 .49179 L .81227 .54456 L p .75 .811 .901 r
F P
0 g
s
.29813 .51778 m .31121 .51649 L .33354 .57573 L p .553 .569 .824 r
F P
0 g
s
.34497 .57486 m .33354 .57573 L .31121 .51649 L p .571 .563 .806 r
F P
0 g
s
.18911 .47507 m .20346 .47212 L .22041 .52429 L p .629 .735 .924 r
F P
0 g
s
.23327 .52327 m .22041 .52429 L .20346 .47212 L p .636 .719 .908 r
F P
0 g
s
.56945 .71514 m .56653 .71322 L .61028 .698 L p .6 .916 .977 r
F P
0 g
s
.61028 .698 m .61633 .69959 L .56945 .71514 L p .6 .916 .977 r
F P
0 g
s
.34497 .57486 m .3565 .57336 L .38652 .62631 L p .474 .523 .828 r
F P
0 g
s
.39591 .62381 m .38652 .62631 L .3565 .57336 L p .515 .528 .807 r
F P
0 g
s
.38652 .62631 m .39591 .62381 L .43216 .66663 L p .395 .518 .863 r
F P
0 g
s
.20346 .47212 m .21779 .46912 L .23327 .52327 L p .636 .719 .908 r
F P
0 g
s
.24617 .52225 m .23327 .52327 L .21779 .46912 L p .642 .702 .89 r
F P
0 g
s
.47818 .69231 m .47453 .69694 L .43216 .66663 L p .401 .569 .904 r
F P
0 g
s
.47453 .69694 m .47818 .69231 L .52063 .70819 L p .391 .664 .968 r
F P
0 g
s
.52063 .70819 m .52029 .71282 L .47453 .69694 L p .391 .664 .968 r
F P
0 g
s
.21779 .46912 m .23209 .46612 L .24617 .52225 L p .642 .702 .89 r
F P
0 g
s
.2591 .5212 m .24617 .52225 L .23209 .46612 L p .648 .686 .872 r
F P
0 g
s
.31121 .51649 m .32434 .5151 L .34497 .57486 L p .571 .563 .806 r
F P
0 g
s
.3565 .57336 m .34497 .57486 L .32434 .5151 L p .587 .559 .789 r
F P
0 g
s
.43893 .66226 m .43216 .66663 L .39591 .62381 L p .473 .531 .837 r
F P
0 g
s
.43216 .66663 m .43893 .66226 L .47818 .69231 L p .401 .569 .904 r
F P
0 g
s
.80016 .54939 m .78796 .55409 L .80464 .49777 L p .753 .79 .883 r
F P
0 g
s
.80464 .49777 m .81829 .49481 L .80016 .54939 L p .753 .79 .883 r
F P
0 g
s
.52029 .71282 m .52063 .70819 L .56354 .70882 L p .514 .794 .996 r
F P
0 g
s
.56354 .70882 m .56653 .71322 L .52029 .71282 L p .514 .794 .996 r
F P
0 g
s
.72319 .61914 m .7124 .62258 L .73801 .5687 L p .812 .81 .849 r
F P
0 g
s
.73801 .5687 m .75067 .56596 L .72319 .61914 L p .812 .81 .849 r
F P
0 g
s
.23209 .46612 m .24635 .46321 L .2591 .5212 L p .648 .686 .872 r
F P
0 g
s
.27207 .52012 m .2591 .5212 L .24635 .46321 L p .652 .669 .854 r
F P
0 g
s
.61633 .69959 m .61028 .698 L .64865 .66797 L p .784 .897 .923 r
F P
0 g
s
.64865 .66797 m .65755 .66917 L .61633 .69959 L p .784 .897 .923 r
F P
0 g
s
.66628 .66844 m .65755 .66917 L .69032 .62561 L p .822 .851 .87 r
F P
0 g
s
.69032 .62561 m .70144 .62479 L .66628 .66844 L p .822 .851 .87 r
F P
0 g
s
.3565 .57336 m .36813 .57115 L .39591 .62381 L p .515 .528 .807 r
F P
0 g
s
.40542 .61999 m .39591 .62381 L .36813 .57115 L p .549 .531 .788 r
F P
0 g
s
.39591 .62381 m .40542 .61999 L .43893 .66226 L p .473 .531 .837 r
F P
0 g
s
.24635 .46321 m .26057 .46043 L .27207 .52012 L p .652 .669 .854 r
F P
0 g
s
.28508 .51898 m .27207 .52012 L .26057 .46043 L p .656 .654 .836 r
F P
0 g
s
.32434 .5151 m .3375 .5136 L .3565 .57336 L p .587 .559 .789 r
F P
0 g
s
.36813 .57115 m .3565 .57336 L .3375 .5136 L p .602 .555 .774 r
F P
0 g
s
.56653 .71322 m .56354 .70882 L .6041 .69405 L p .691 .86 .963 r
F P
0 g
s
.6041 .69405 m .61028 .698 L .56653 .71322 L p .691 .86 .963 r
F P
0 g
s
.78796 .55409 m .77565 .55852 L .79095 .50059 L p .753 .767 .864 r
F P
0 g
s
.79095 .50059 m .80464 .49777 L .78796 .55409 L p .753 .767 .864 r
F P
0 g
s
.26057 .46043 m .27474 .45787 L .28508 .51898 L p .656 .654 .836 r
F P
0 g
s
.29813 .51778 m .28508 .51898 L .27474 .45787 L p .66 .639 .818 r
F P
0 g
s
.4458 .65598 m .43893 .66226 L .40542 .61999 L p .528 .538 .809 r
F P
0 g
s
.43893 .66226 m .4458 .65598 L .4819 .68537 L p .498 .575 .864 r
F P
0 g
s
.4819 .68537 m .47818 .69231 L .43893 .66226 L p .498 .575 .864 r
F P
0 g
s
.47818 .69231 m .4819 .68537 L .52099 .70102 L p .52 .654 .919 r
F P
0 g
s
.52099 .70102 m .52063 .70819 L .47818 .69231 L p .52 .654 .919 r
F P
0 g
s
.27474 .45787 m .28887 .45557 L .29813 .51778 L p .66 .639 .818 r
F P
0 g
s
.31121 .51649 m .29813 .51778 L .28887 .45557 L p .663 .626 .802 r
F P
0 g
s
.3375 .5136 m .3507 .51198 L .36813 .57115 L p .602 .555 .774 r
F P
0 g
s
.37985 .56821 m .36813 .57115 L .3507 .51198 L p .614 .551 .761 r
F P
0 g
s
.36813 .57115 m .37985 .56821 L .40542 .61999 L p .549 .531 .788 r
F P
0 g
s
.7124 .62258 m .70144 .62479 L .72522 .5706 L p .799 .774 .83 r
F P
0 g
s
.72522 .5706 m .73801 .5687 L .7124 .62258 L p .799 .774 .83 r
F P
0 g
s
.41504 .61479 m .40542 .61999 L .37985 .56821 L p .576 .534 .771 r
F P
0 g
s
.40542 .61999 m .41504 .61479 L .4458 .65598 L p .528 .538 .809 r
F P
0 g
s
.52063 .70819 m .52099 .70102 L .5605 .70182 L p .611 .744 .94 r
F P
0 g
s
.5605 .70182 m .56354 .70882 L .52063 .70819 L p .611 .744 .94 r
F P
0 g
s
.28887 .45557 m .30294 .4536 L .31121 .51649 L p .663 .626 .802 r
F P
0 g
s
.32434 .5151 m .31121 .51649 L .30294 .4536 L p .665 .613 .787 r
F P
0 g
s
.61028 .698 m .6041 .69405 L .63961 .66471 L p .78 .822 .886 r
F P
0 g
s
.63961 .66471 m .64865 .66797 L .61028 .698 L p .78 .822 .886 r
F P
0 g
s
.77565 .55852 m .76322 .56253 L .77721 .50322 L p .751 .744 .846 r
F P
0 g
s
.77721 .50322 m .79095 .50059 L .77565 .55852 L p .751 .744 .846 r
F P
0 g
s
.65755 .66917 m .64865 .66797 L .67904 .62492 L p .805 .797 .844 r
F P
0 g
s
.67904 .62492 m .69032 .62561 L .65755 .66917 L p .805 .797 .844 r
F P
0 g
s
.30294 .4536 m .31697 .45201 L .32434 .5151 L p .665 .613 .787 r
F P
0 g
s
.3375 .5136 m .32434 .5151 L .31697 .45201 L p .666 .602 .774 r
F P
0 g
s
.3507 .51198 m .36393 .51024 L .37985 .56821 L p .614 .551 .761 r
F P
0 g
s
.39166 .56449 m .37985 .56821 L .36393 .51024 L p .625 .549 .749 r
F P
0 g
s
.37985 .56821 m .39166 .56449 L .41504 .61479 L p .576 .534 .771 r
F P
0 g
s
.56354 .70882 m .5605 .70182 L .59782 .68764 L p .713 .782 .906 r
F P
0 g
s
.59782 .68764 m .6041 .69405 L .56354 .70882 L p .713 .782 .906 r
F P
0 g
s
.45276 .64776 m .4458 .65598 L .41504 .61479 L p .567 .541 .785 r
F P
0 g
s
.4458 .65598 m .45276 .64776 L .48568 .67608 L p .556 .571 .824 r
F P
0 g
s
.48568 .67608 m .4819 .68537 L .4458 .65598 L p .556 .571 .824 r
F P
0 g
s
.31697 .45201 m .33096 .45083 L .3375 .5136 L p .666 .602 .774 r
F P
0 g
s
.3507 .51198 m .3375 .5136 L .33096 .45083 L p .668 .592 .761 r
F P
0 g
s
.42477 .60819 m .41504 .61479 L .39166 .56449 L p .597 .535 .755 r
F P
0 g
s
.41504 .61479 m .42477 .60819 L .45276 .64776 L p .567 .541 .785 r
F P
0 g
s
.4819 .68537 m .48568 .67608 L .52135 .69124 L p .584 .629 .862 r
F P
0 g
s
.52135 .69124 m .52099 .70102 L .4819 .68537 L p .584 .629 .862 r
F P
0 g
s
.33096 .45083 m .3449 .4501 L .3507 .51198 L p .668 .592 .761 r
F P
0 g
s
.36393 .51024 m .3507 .51198 L .3449 .4501 L p .669 .583 .75 r
F P
0 g
s
.70144 .62479 m .69032 .62561 L .71231 .57157 L p .786 .74 .81 r
F P
0 g
s
.71231 .57157 m .72522 .5706 L .70144 .62479 L p .786 .74 .81 r
F P
0 g
s
.36393 .51024 m .3772 .50837 L .39166 .56449 L p .625 .549 .749 r
F P
0 g
s
.40355 .56 m .39166 .56449 L .3772 .50837 L p .634 .546 .738 r
F P
0 g
s
.39166 .56449 m .40355 .56 L .42477 .60819 L p .597 .535 .755 r
F P
0 g
s
.76322 .56253 m .75067 .56596 L .76342 .50557 L p .747 .722 .828 r
F P
0 g
s
.76342 .50557 m .77721 .50322 L .76322 .56253 L p .747 .722 .828 r
F P
0 g
s
.52099 .70102 m .52135 .69124 L .5574 .69217 L p .648 .689 .875 r
F P
0 g
s
.5574 .69217 m .5605 .70182 L .52099 .70102 L p .648 .689 .875 r
F P
0 g
s
.3449 .4501 m .35881 .44985 L .36393 .51024 L p .669 .583 .75 r
F P
0 g
s
.3772 .50837 m .36393 .51024 L .35881 .44985 L p .67 .575 .74 r
F P
0 g
s
.64865 .66797 m .63961 .66471 L .66762 .62259 L p .786 .748 .818 r
F P
0 g
s
.66762 .62259 m .67904 .62492 L .64865 .66797 L p .786 .748 .818 r
F P
0 g
s
.6041 .69405 m .59782 .68764 L .63042 .6593 L p .764 .757 .846 r
F P
0 g
s
.63042 .6593 m .63961 .66471 L .6041 .69405 L p .764 .757 .846 r
F P
0 g
s
.43459 .60019 m .42477 .60819 L .40355 .56 L p .615 .536 .742 r
F P
0 g
s
.42477 .60819 m .43459 .60019 L .45981 .6376 L p .596 .541 .764 r
F P
0 g
s
.45981 .6376 m .45276 .64776 L .42477 .60819 L p .596 .541 .764 r
F P
0 g
s
.45276 .64776 m .45981 .6376 L .48951 .66445 L p .594 .565 .792 r
F P
0 g
s
.48951 .66445 m .48568 .67608 L .45276 .64776 L p .594 .565 .792 r
F P
0 g
s
.35881 .44985 m .37269 .4501 L .3772 .50837 L p .67 .575 .74 r
F P
0 g
s
.39051 .50637 m .3772 .50837 L .37269 .4501 L p .671 .568 .731 r
F P
0 g
s
.3772 .50837 m .39051 .50637 L .40355 .56 L p .634 .546 .738 r
F P
0 g
s
.41551 .55472 m .40355 .56 L .39051 .50637 L p .642 .544 .728 r
F P
0 g
s
.40355 .56 m .41551 .55472 L .43459 .60019 L p .615 .536 .742 r
F P
0 g
s
.5605 .70182 m .5574 .69217 L .59143 .67872 L p .713 .717 .852 r
F P
0 g
s
.59143 .67872 m .59782 .68764 L .5605 .70182 L p .713 .717 .852 r
F P
0 g
s
.48568 .67608 m .48951 .66445 L .52171 .67889 L p .618 .606 .816 r
F P
0 g
s
.52171 .67889 m .52135 .69124 L .48568 .67608 L p .618 .606 .816 r
F P
0 g
s
.37269 .4501 m .38654 .45084 L .39051 .50637 L p .671 .568 .731 r
F P
0 g
s
.40385 .50423 m .39051 .50637 L .38654 .45084 L p .671 .562 .723 r
F P
0 g
s
.39051 .50637 m .40385 .50423 L .41551 .55472 L p .642 .544 .728 r
F P
0 g
s
.75067 .56596 m .73801 .5687 L .74958 .5076 L p .742 .7 .811 r
F P
0 g
s
.74958 .5076 m .76342 .50557 L .75067 .56596 L p .742 .7 .811 r
F P
0 g
s
.69032 .62561 m .67904 .62492 L .69928 .57152 L p .771 .708 .793 r
F P
0 g
s
.69928 .57152 m .71231 .57157 L .69032 .62561 L p .771 .708 .793 r
F P
0 g
s
.42754 .54869 m .41551 .55472 L .40385 .50423 L p .649 .543 .72 r
F P
0 g
s
.41551 .55472 m .42754 .54869 L .44448 .59083 L p .629 .537 .731 r
F P
0 g
s
.44448 .59083 m .43459 .60019 L .41551 .55472 L p .629 .537 .731 r
F P
0 g
s
.43459 .60019 m .44448 .59083 L .46693 .62557 L p .617 .541 .747 r
F P
0 g
s
.46693 .62557 m .45981 .6376 L .43459 .60019 L p .617 .541 .747 r
F P
0 g
s
.38654 .45084 m .40038 .45208 L .40385 .50423 L p .671 .562 .723 r
F P
0 g
s
.41722 .50197 m .40385 .50423 L .40038 .45208 L p .672 .557 .716 r
F P
0 g
s
.40385 .50423 m .41722 .50197 L .42754 .54869 L p .649 .543 .72 r
F P
0 g
s
.52135 .69124 m .52171 .67889 L .55427 .67988 L p .663 .647 .824 r
F P
0 g
s
.55427 .67988 m .5574 .69217 L .52135 .69124 L p .663 .647 .824 r
F P
0 g
s
.36495 .39105 m .37849 .39354 L .37269 .4501 L p .71 .61 .743 r
F P
0 g
s
.37269 .4501 m .35881 .44985 L .36495 .39105 L p .71 .61 .743 r
F P
0 g
s
.38654 .45084 m .37269 .4501 L .37849 .39354 L p .704 .597 .734 r
F P
0 g
s
.37849 .39354 m .39195 .39711 L .38654 .45084 L p .704 .597 .734 r
F P
0 g
s
.40038 .45208 m .38654 .45084 L .39195 .39711 L p .698 .586 .726 r
F P
0 g
s
.35131 .38961 m .36495 .39105 L .35881 .44985 L p .716 .624 .754 r
F P
0 g
s
.35881 .44985 m .3449 .4501 L .35131 .38961 L p .716 .624 .754 r
F P
0 g
s
.45981 .6376 m .46693 .62557 L .49339 .65054 L p .619 .559 .766 r
F P
0 g
s
.49339 .65054 m .48951 .66445 L .45981 .6376 L p .619 .559 .766 r
F P
0 g
s
.39195 .39711 m .40535 .40174 L .40038 .45208 L p .698 .586 .726 r
F P
0 g
s
.4142 .4538 m .40038 .45208 L .40535 .40174 L p .693 .575 .718 r
F P
0 g
s
.40038 .45208 m .4142 .4538 L .41722 .50197 L p .672 .557 .716 r
F P
0 g
s
.43061 .49959 m .41722 .50197 L .4142 .4538 L p .672 .552 .71 r
F P
0 g
s
.41722 .50197 m .43061 .49959 L .43962 .54193 L p .655 .542 .713 r
F P
0 g
s
.43962 .54193 m .42754 .54869 L .41722 .50197 L p .655 .542 .713 r
F P
0 g
s
.33757 .38919 m .35131 .38961 L .3449 .4501 L p .722 .639 .765 r
F P
0 g
s
.3449 .4501 m .33096 .45083 L .33757 .38919 L p .722 .639 .765 r
F P
0 g
s
.40535 .40174 m .41869 .4074 L .4142 .4538 L p .693 .575 .718 r
F P
0 g
s
.42802 .45598 m .4142 .4538 L .41869 .4074 L p .689 .567 .712 r
F P
0 g
s
.4142 .4538 m .42802 .45598 L .43061 .49959 L p .672 .552 .71 r
F P
0 g
s
.42754 .54869 m .43962 .54193 L .45445 .58018 L p .641 .537 .721 r
F P
0 g
s
.45445 .58018 m .44448 .59083 L .42754 .54869 L p .641 .537 .721 r
F P
0 g
s
.32371 .38974 m .33757 .38919 L .33096 .45083 L p .729 .656 .777 r
F P
0 g
s
.33096 .45083 m .31697 .45201 L .32371 .38974 L p .729 .656 .777 r
F P
0 g
s
.63961 .66471 m .63042 .6593 L .65607 .61856 L p .767 .706 .795 r
F P
0 g
s
.65607 .61856 m .66762 .62259 L .63961 .66471 L p .767 .706 .795 r
F P
0 g
s
.41869 .4074 m .43199 .41405 L .42802 .45598 L p .689 .567 .712 r
F P
0 g
s
.44184 .4586 m .42802 .45598 L .43199 .41405 L p .685 .559 .706 r
F P
0 g
s
.42802 .45598 m .44184 .4586 L .44404 .49709 L p .673 .548 .705 r
F P
0 g
s
.44404 .49709 m .43061 .49959 L .42802 .45598 L p .673 .548 .705 r
F P
0 g
s
.59782 .68764 m .59143 .67872 L .62112 .65169 L p .747 .704 .811 r
F P
0 g
s
.62112 .65169 m .63042 .6593 L .59782 .68764 L p .747 .704 .811 r
F P
0 g
s
.43041 .36587 m .44229 .37658 L .43199 .41405 L p .702 .582 .718 r
F P
0 g
s
.43199 .41405 m .41869 .4074 L .43041 .36587 L p .702 .582 .718 r
F P
0 g
s
.44528 .42161 m .43199 .41405 L .44229 .37658 L p .695 .57 .711 r
F P
0 g
s
.43199 .41405 m .44528 .42161 L .44184 .4586 L p .685 .559 .706 r
F P
0 g
s
.41847 .35659 m .43041 .36587 L .41869 .4074 L p .711 .596 .726 r
F P
0 g
s
.41869 .4074 m .40535 .40174 L .41847 .35659 L p .711 .596 .726 r
F P
0 g
s
.43061 .49959 m .44404 .49709 L .45175 .53451 L p .66 .54 .707 r
F P
0 g
s
.45175 .53451 m .43962 .54193 L .43061 .49959 L p .66 .54 .707 r
F P
0 g
s
.30972 .3912 m .32371 .38974 L .31697 .45201 L p .735 .674 .791 r
F P
0 g
s
.31697 .45201 m .30294 .4536 L .30972 .3912 L p .735 .674 .791 r
F P
0 g
s
.73801 .5687 m .72522 .5706 L .7357 .50925 L p .736 .679 .795 r
F P
0 g
s
.7357 .50925 m .74958 .5076 L .73801 .5687 L p .736 .679 .795 r
F P
0 g
s
.44448 .59083 m .45445 .58018 L .47411 .61175 L p .633 .541 .732 r
F P
0 g
s
.47411 .61175 m .46693 .62557 L .44448 .59083 L p .633 .541 .732 r
F P
0 g
s
.44229 .37658 m .45413 .38862 L .44528 .42161 L p .695 .57 .711 r
F P
0 g
s
.45855 .43002 m .44528 .42161 L .45413 .38862 L p .688 .56 .705 r
F P
0 g
s
.44528 .42161 m .45855 .43002 L .45566 .4616 L p .682 .552 .702 r
F P
0 g
s
.45566 .4616 m .44184 .4586 L .44528 .42161 L p .682 .552 .702 r
F P
0 g
s
.48951 .66445 m .49339 .65054 L .52208 .66401 L p .638 .587 .781 r
F P
0 g
s
.52208 .66401 m .52171 .67889 L .48951 .66445 L p .638 .587 .781 r
F P
0 g
s
.40644 .3488 m .41847 .35659 L .40535 .40174 L p .72 .612 .736 r
F P
0 g
s
.40535 .40174 m .39195 .39711 L .40644 .3488 L p .72 .612 .736 r
F P
0 g
s
.45821 .34611 m .4678 .36183 L .45413 .38862 L p .699 .58 .718 r
F P
0 g
s
.45413 .38862 m .44229 .37658 L .45821 .34611 L p .699 .58 .718 r
F P
0 g
s
.46594 .40187 m .45413 .38862 L .4678 .36183 L p .691 .567 .71 r
F P
0 g
s
.45413 .38862 m .46594 .40187 L .45855 .43002 L p .688 .56 .705 r
F P
0 g
s
.44184 .4586 m .45566 .4616 L .45749 .49449 L p .673 .545 .701 r
F P
0 g
s
.45749 .49449 m .44404 .49709 L .44184 .4586 L p .673 .545 .701 r
F P
0 g
s
.44858 .33203 m .45821 .34611 L .44229 .37658 L p .709 .596 .728 r
F P
0 g
s
.44229 .37658 m .43041 .36587 L .44858 .33203 L p .709 .596 .728 r
F P
0 g
s
.4678 .36183 m .47735 .37905 L .46594 .40187 L p .691 .567 .71 r
F P
0 g
s
.47774 .41619 m .46594 .40187 L .47735 .37905 L p .685 .556 .703 r
F P
0 g
s
.46594 .40187 m .47774 .41619 L .47182 .43915 L p .683 .552 .7 r
F P
0 g
s
.47182 .43915 m .45855 .43002 L .46594 .40187 L p .683 .552 .7 r
F P
0 g
s
.45855 .43002 m .47182 .43915 L .46951 .46493 L p .679 .547 .698 r
F P
0 g
s
.46951 .46493 m .45566 .4616 L .45855 .43002 L p .679 .547 .698 r
F P
0 g
s
.43962 .54193 m .45175 .53451 L .46446 .56834 L p .65 .537 .713 r
F P
0 g
s
.46446 .56834 m .45445 .58018 L .43962 .54193 L p .65 .537 .713 r
F P
0 g
s
.5574 .69217 m .55427 .67988 L .58496 .66729 L p .707 .668 .81 r
F P
0 g
s
.58496 .66729 m .59143 .67872 L .5574 .69217 L p .707 .668 .81 r
F P
0 g
s
.2956 .39347 m .30972 .3912 L .30294 .4536 L p .741 .693 .805 r
F P
0 g
s
.30294 .4536 m .28887 .45557 L .2956 .39347 L p .741 .693 .805 r
F P
0 g
s
.39432 .34254 m .40644 .3488 L .39195 .39711 L p .731 .63 .747 r
F P
0 g
s
.39195 .39711 m .37849 .39354 L .39432 .34254 L p .731 .63 .747 r
F P
0 g
s
.47872 .3247 m .48538 .34305 L .4678 .36183 L p .697 .585 .726 r
F P
0 g
s
.4678 .36183 m .45821 .34611 L .47872 .3247 L p .697 .585 .726 r
F P
0 g
s
.47735 .37905 m .4678 .36183 L .48538 .34305 L p .69 .57 .715 r
F P
0 g
s
.43888 .31971 m .44858 .33203 L .43041 .36587 L p .72 .615 .74 r
F P
0 g
s
.43041 .36587 m .41847 .35659 L .43888 .31971 L p .72 .615 .74 r
F P
0 g
s
.44404 .49709 m .45749 .49449 L .46392 .52649 L p .664 .539 .702 r
F P
0 g
s
.46392 .52649 m .45175 .53451 L .44404 .49709 L p .664 .539 .702 r
F P
0 g
s
.48538 .34305 m .49201 .36309 L .47735 .37905 L p .69 .57 .715 r
F P
0 g
s
.48688 .39759 m .47735 .37905 L .49201 .36309 L p .684 .558 .706 r
F P
0 g
s
.47735 .37905 m .48688 .39759 L .47774 .41619 L p .685 .556 .703 r
F P
0 g
s
.45566 .4616 m .46951 .46493 L .47097 .4918 L p .673 .542 .697 r
F P
0 g
s
.47097 .4918 m .45749 .49449 L .45566 .4616 L p .673 .542 .697 r
F P
0 g
s
.67904 .62492 m .66762 .62259 L .68615 .57037 L p .757 .68 .776 r
F P
0 g
s
.68615 .57037 m .69928 .57152 L .67904 .62492 L p .757 .68 .776 r
F P
0 g
s
.46693 .62557 m .47411 .61175 L .4973 .63447 L p .636 .554 .745 r
F P
0 g
s
.4973 .63447 m .49339 .65054 L .46693 .62557 L p .636 .554 .745 r
F P
0 g
s
.48955 .43141 m .47774 .41619 L .48688 .39759 L p .68 .548 .697 r
F P
0 g
s
.47774 .41619 m .48955 .43141 L .48511 .4489 L p .679 .546 .696 r
F P
0 g
s
.48511 .4489 m .47182 .43915 L .47774 .41619 L p .679 .546 .696 r
F P
0 g
s
.47202 .30818 m .47872 .3247 L .45821 .34611 L p .706 .604 .74 r
F P
0 g
s
.45821 .34611 m .44858 .33203 L .47202 .30818 L p .706 .604 .74 r
F P
0 g
s
.49201 .36309 m .49862 .3846 L .48688 .39759 L p .684 .558 .706 r
F P
0 g
s
.49642 .41725 m .48688 .39759 L .49862 .3846 L p .679 .549 .699 r
F P
0 g
s
.48688 .39759 m .49642 .41725 L .48955 .43141 L p .68 .548 .697 r
F P
0 g
s
.47182 .43915 m .48511 .4489 L .48337 .46855 L p .677 .543 .695 r
F P
0 g
s
.48337 .46855 m .46951 .46493 L .47182 .43915 L p .677 .543 .695 r
F P
0 g
s
.28135 .39645 m .2956 .39347 L .28887 .45557 L p .746 .713 .821 r
F P
0 g
s
.28887 .45557 m .27474 .45787 L .28135 .39645 L p .746 .713 .821 r
F P
0 g
s
.5057 .33357 m .50894 .35507 L .49201 .36309 L p .684 .569 .719 r
F P
0 g
s
.49201 .36309 m .48538 .34305 L .5057 .33357 L p .684 .569 .719 r
F P
0 g
s
.49862 .3846 m .49201 .36309 L .50894 .35507 L p .68 .557 .709 r
F P
0 g
s
.45445 .58018 m .46446 .56834 L .48134 .59628 L p .645 .54 .721 r
F P
0 g
s
.48134 .59628 m .47411 .61175 L .45445 .58018 L p .645 .54 .721 r
F P
0 g
s
.45749 .49449 m .47097 .4918 L .47612 .51794 L p .667 .539 .698 r
F P
0 g
s
.47612 .51794 m .46392 .52649 L .45749 .49449 L p .667 .539 .698 r
F P
0 g
s
.50244 .31382 m .5057 .33357 L .48538 .34305 L p .688 .584 .733 r
F P
0 g
s
.48538 .34305 m .47872 .3247 L .50244 .31382 L p .688 .584 .733 r
F P
0 g
s
.52171 .67889 m .52208 .66401 L .55109 .66502 L p .669 .616 .786 r
F P
0 g
s
.55109 .66502 m .55427 .67988 L .52171 .67889 L p .669 .616 .786 r
F P
0 g
s
.45175 .53451 m .46392 .52649 L .47452 .55543 L p .657 .537 .706 r
F P
0 g
s
.47452 .55543 m .46446 .56834 L .45175 .53451 L p .657 .537 .706 r
F P
0 g
s
.38208 .33782 m .39432 .34254 L .37849 .39354 L p .742 .651 .759 r
F P
0 g
s
.37849 .39354 m .36495 .39105 L .38208 .33782 L p .742 .651 .759 r
F P
0 g
s
.50894 .35507 m .51217 .37811 L .49862 .3846 L p .68 .557 .709 r
F P
0 g
s
.50523 .40737 m .49862 .3846 L .51217 .37811 L p .677 .548 .701 r
F P
0 g
s
.49862 .3846 m .50523 .40737 L .49642 .41725 L p .679 .549 .699 r
F P
0 g
s
.4291 .30921 m .43888 .31971 L .41847 .35659 L p .733 .638 .754 r
F P
0 g
s
.41847 .35659 m .40644 .3488 L .4291 .30921 L p .733 .638 .754 r
F P
0 g
s
.46951 .46493 m .48337 .46855 L .48447 .48904 L p .673 .54 .694 r
F P
0 g
s
.48447 .48904 m .47097 .4918 L .46951 .46493 L p .673 .54 .694 r
F P
0 g
s
.50138 .44733 m .48955 .43141 L .49642 .41725 L p .677 .542 .694 r
F P
0 g
s
.48955 .43141 m .50138 .44733 L .49841 .45914 L p .676 .541 .693 r
F P
0 g
s
.49841 .45914 m .48511 .4489 L .48955 .43141 L p .676 .541 .693 r
F P
0 g
s
.50596 .43778 m .49642 .41725 L .50523 .40737 L p .676 .542 .694 r
F P
0 g
s
.49642 .41725 m .50596 .43778 L .50138 .44733 L p .677 .542 .694 r
F P
0 g
s
.46526 .29362 m .47202 .30818 L .44858 .33203 L p .717 .628 .757 r
F P
0 g
s
.44858 .33203 m .43888 .31971 L .46526 .29362 L p .717 .628 .757 r
F P
0 g
s
.48511 .4489 m .49841 .45914 L .49726 .4724 L p .675 .54 .692 r
F P
0 g
s
.49726 .4724 m .48337 .46855 L .48511 .4489 L p .675 .54 .692 r
F P
0 g
s
.26696 .40003 m .28135 .39645 L .27474 .45787 L p .749 .733 .837 r
F P
0 g
s
.27474 .45787 m .26057 .46043 L .26696 .40003 L p .749 .733 .837 r
F P
0 g
s
.51217 .37811 m .5154 .40246 L .50523 .40737 L p .677 .548 .701 r
F P
0 g
s
.51185 .43114 m .50523 .40737 L .5154 .40246 L p .675 .542 .695 r
F P
0 g
s
.50523 .40737 m .51185 .43114 L .50596 .43778 L p .676 .542 .694 r
F P
0 g
s
.52739 .33406 m .52701 .35556 L .50894 .35507 L p .674 .563 .721 r
F P
0 g
s
.50894 .35507 m .5057 .33357 L .52739 .33406 L p .674 .563 .721 r
F P
0 g
s
.51217 .37811 m .50894 .35507 L .52701 .35556 L p .674 .553 .71 r
F P
0 g
s
.49915 .29599 m .50244 .31382 L .47872 .3247 L p .694 .604 .751 r
F P
0 g
s
.47872 .3247 m .47202 .30818 L .49915 .29599 L p .694 .604 .751 r
F P
0 g
s
.52701 .35556 m .52663 .37857 L .51217 .37811 L p .674 .553 .71 r
F P
0 g
s
.5154 .40246 m .51217 .37811 L .52663 .37857 L p .674 .546 .701 r
F P
0 g
s
.47097 .4918 m .48447 .48904 L .48834 .50897 L p .67 .538 .695 r
F P
0 g
s
.48834 .50897 m .47612 .51794 L .47097 .4918 L p .67 .538 .695 r
F P
0 g
s
.72522 .5706 m .71231 .57157 L .72178 .51048 L p .73 .659 .78 r
F P
0 g
s
.72178 .51048 m .7357 .50925 L .72522 .5706 L p .73 .659 .78 r
F P
0 g
s
.49339 .65054 m .4973 .63447 L .52246 .64676 L p .65 .573 .755 r
F P
0 g
s
.52246 .64676 m .52208 .66401 L .49339 .65054 L p .65 .573 .755 r
F P
0 g
s
.46392 .52649 m .47612 .51794 L .48461 .54159 L p .663 .537 .701 r
F P
0 g
s
.48461 .54159 m .47452 .55543 L .46392 .52649 L p .663 .537 .701 r
F P
0 g
s
.85906 .48583 m .84549 .48878 L .84547 .43439 L p .632 .732 .92 r
F P
0 g
s
.84547 .43439 m .85986 .43317 L .85906 .48583 L p .632 .732 .92 r
F P
0 g
s
.48337 .46855 m .49726 .4724 L .498 .48621 L p .673 .538 .692 r
F P
0 g
s
.498 .48621 m .48447 .48904 L .48337 .46855 L p .673 .538 .692 r
F P
0 g
s
.52777 .31427 m .52739 .33406 L .5057 .33357 L p .674 .576 .737 r
F P
0 g
s
.5057 .33357 m .50244 .31382 L .52777 .31427 L p .674 .576 .737 r
F P
0 g
s
.46446 .56834 m .47452 .55543 L .4886 .57934 L p .655 .539 .711 r
F P
0 g
s
.4886 .57934 m .48134 .59628 L .46446 .56834 L p .655 .539 .711 r
F P
0 g
s
.63042 .6593 m .62112 .65169 L .6444 .61281 L p .749 .671 .774 r
F P
0 g
s
.6444 .61281 m .65607 .61856 L .63042 .6593 L p .749 .671 .774 r
F P
0 g
s
.52663 .37857 m .52625 .40284 L .5154 .40246 L p .674 .546 .701 r
F P
0 g
s
.51864 .42784 m .5154 .40246 L .52625 .40284 L p .674 .541 .695 r
F P
0 g
s
.5154 .40246 m .51864 .42784 L .51185 .43114 L p .675 .542 .695 r
F P
0 g
s
.47411 .61175 m .48134 .59628 L .50124 .6164 L p .648 .549 .729 r
F P
0 g
s
.50124 .6164 m .4973 .63447 L .47411 .61175 L p .648 .549 .729 r
F P
0 g
s
.59143 .67872 m .58496 .66729 L .6117 .64189 L p .731 .663 .783 r
F P
0 g
s
.6117 .64189 m .62112 .65169 L .59143 .67872 L p .731 .663 .783 r
F P
0 g
s
.3697 .33462 m .38208 .33782 L .36495 .39105 L p .755 .674 .772 r
F P
0 g
s
.36495 .39105 m .35131 .38961 L .3697 .33462 L p .755 .674 .772 r
F P
0 g
s
.51323 .46376 m .50138 .44733 L .50596 .43778 L p .674 .538 .691 r
F P
0 g
s
.50138 .44733 m .51323 .46376 L .51175 .46971 L p .674 .538 .691 r
F P
0 g
s
.51175 .46971 m .49841 .45914 L .50138 .44733 L p .674 .538 .691 r
F P
0 g
s
.51553 .45895 m .50596 .43778 L .51185 .43114 L p .674 .538 .691 r
F P
0 g
s
.50596 .43778 m .51553 .45895 L .51323 .46376 L p .674 .538 .691 r
F P
0 g
s
.4192 .3006 m .4291 .30921 L .40644 .3488 L p .747 .665 .77 r
F P
0 g
s
.40644 .3488 m .39432 .34254 L .4192 .3006 L p .747 .665 .77 r
F P
0 g
s
.49841 .45914 m .51175 .46971 L .51117 .47639 L p .674 .537 .691 r
F P
0 g
s
.51117 .47639 m .49726 .4724 L .49841 .45914 L p .674 .537 .691 r
F P
0 g
s
.51847 .4556 m .51185 .43114 L .51864 .42784 L p .674 .538 .691 r
F P
0 g
s
.51185 .43114 m .51847 .4556 L .51553 .45895 L p .674 .538 .691 r
F P
0 g
s
.25244 .40408 m .26696 .40003 L .26057 .46043 L p .752 .753 .853 r
F P
0 g
s
.26057 .46043 m .24635 .46321 L .25244 .40408 L p .752 .753 .853 r
F P
0 g
s
.48447 .48904 m .498 .48621 L .50059 .49966 L p .672 .537 .692 r
F P
0 g
s
.50059 .49966 m .48834 .50897 L .48447 .48904 L p .672 .537 .692 r
F P
0 g
s
.54499 .36456 m .54101 .38596 L .52663 .37857 L p .668 .548 .709 r
F P
0 g
s
.52663 .37857 m .52701 .35556 L .54499 .36456 L p .668 .548 .709 r
F P
0 g
s
.52625 .40284 m .52663 .37857 L .54101 .38596 L p .67 .543 .701 r
F P
0 g
s
.47612 .51794 m .48834 .50897 L .49472 .52699 L p .668 .537 .696 r
F P
0 g
s
.49472 .52699 m .48461 .54159 L .47612 .51794 L p .668 .537 .696 r
F P
0 g
s
.54899 .34453 m .54499 .36456 L .52701 .35556 L p .664 .554 .72 r
F P
0 g
s
.52701 .35556 m .52739 .33406 L .54899 .34453 L p .664 .554 .72 r
F P
0 g
s
.54101 .38596 m .53704 .40851 L .52625 .40284 L p .67 .543 .701 r
F P
0 g
s
.52587 .42812 m .52625 .40284 L .53704 .40851 L p .672 .54 .695 r
F P
0 g
s
.52625 .40284 m .52587 .42812 L .51864 .42784 L p .674 .541 .695 r
F P
0 g
s
.55427 .67988 m .55109 .66502 L .57842 .65344 L p .7 .632 .777 r
F P
0 g
s
.57842 .65344 m .58496 .66729 L .55427 .67988 L p .7 .632 .777 r
F P
0 g
s
.49726 .4724 m .51117 .47639 L .51155 .48335 L p .673 .537 .691 r
F P
0 g
s
.51155 .48335 m .498 .48621 L .49726 .4724 L p .673 .537 .691 r
F P
0 g
s
.52187 .45395 m .51864 .42784 L .52587 .42812 L p .673 .538 .691 r
F P
0 g
s
.51864 .42784 m .52187 .45395 L .51847 .4556 L p .674 .538 .691 r
F P
0 g
s
.45843 .28112 m .46526 .29362 L .43888 .31971 L p .73 .658 .778 r
F P
0 g
s
.43888 .31971 m .4291 .30921 L .45843 .28112 L p .73 .658 .778 r
F P
0 g
s
.49584 .28019 m .49915 .29599 L .47202 .30818 L p .7 .629 .774 r
F P
0 g
s
.47202 .30818 m .46526 .29362 L .49584 .28019 L p .7 .629 .774 r
F P
0 g
s
.84549 .48878 m .83191 .49179 L .83112 .43558 L p .639 .716 .903 r
F P
0 g
s
.83112 .43558 m .84547 .43439 L .84549 .48878 L p .639 .716 .903 r
F P
0 g
s
.52815 .29634 m .52777 .31427 L .50244 .31382 L p .673 .592 .756 r
F P
0 g
s
.50244 .31382 m .49915 .29599 L .52815 .29634 L p .673 .592 .756 r
F P
0 g
s
.47452 .55543 m .48461 .54159 L .49588 .56112 L p .662 .539 .704 r
F P
0 g
s
.49588 .56112 m .4886 .57934 L .47452 .55543 L p .662 .539 .704 r
F P
0 g
s
.66762 .62259 m .65607 .61856 L .67293 .56809 L p .744 .655 .761 r
F P
0 g
s
.67293 .56809 m .68615 .57037 L .66762 .62259 L p .744 .655 .761 r
F P
0 g
s
.498 .48621 m .51155 .48335 L .51284 .49012 L p .673 .537 .691 r
F P
0 g
s
.51284 .49012 m .50059 .49966 L .498 .48621 L p .673 .537 .691 r
F P
0 g
s
.48834 .50897 m .50059 .49966 L .50485 .51181 L p .671 .537 .693 r
F P
0 g
s
.50485 .51181 m .49472 .52699 L .48834 .50897 L p .671 .537 .693 r
F P
0 g
s
.53704 .40851 m .53306 .43196 L .52587 .42812 L p .672 .54 .695 r
F P
0 g
s
.52549 .4541 m .52587 .42812 L .53306 .43196 L p .673 .537 .691 r
F P
0 g
s
.52587 .42812 m .52549 .4541 L .52187 .45395 L p .673 .538 .691 r
F P
0 g
s
.52208 .66401 m .52246 .64676 L .54788 .64774 L p .672 .593 .758 r
F P
0 g
s
.54788 .64774 m .55109 .66502 L .52208 .66401 L p .672 .593 .758 r
F P
0 g
s
.553 .32605 m .54899 .34453 L .52739 .33406 L p .659 .563 .735 r
F P
0 g
s
.52739 .33406 m .52777 .31427 L .553 .32605 L p .659 .563 .735 r
F P
0 g
s
.48134 .59628 m .4886 .57934 L .5052 .59657 L p .657 .545 .717 r
F P
0 g
s
.5052 .59657 m .50124 .6164 L .48134 .59628 L p .657 .545 .717 r
F P
0 g
s
.23779 .40847 m .25244 .40408 L .24635 .46321 L p .752 .772 .87 r
F P
0 g
s
.24635 .46321 m .23209 .46612 L .23779 .40847 L p .752 .772 .87 r
F P
0 g
s
.52511 .48046 m .51553 .45895 L .51847 .4556 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .51323 .46376 L .51553 .45895 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .51175 .46971 L .51323 .46376 L closepath p .673 .536 .69 r
F P
0 g
s
.4973 .63447 m .50124 .6164 L .52283 .62731 L p .658 .562 .735 r
F P
0 g
s
.52283 .62731 m .52246 .64676 L .4973 .63447 L p .658 .562 .735 r
F P
0 g
s
.52511 .48046 m .51847 .4556 L .52187 .45395 L closepath p .673 .536 .69 r
F P
0 g
s
.55434 .39981 m .54703 .41909 L .53704 .40851 L p .668 .54 .7 r
F P
0 g
s
.53704 .40851 m .54101 .38596 L .55434 .39981 L p .668 .54 .7 r
F P
0 g
s
.53306 .43196 m .53704 .40851 L .54703 .41909 L p .671 .538 .695 r
F P
0 g
s
.56167 .38149 m .55434 .39981 L .54101 .38596 L p .663 .543 .707 r
F P
0 g
s
.54101 .38596 m .54499 .36456 L .56167 .38149 L p .663 .543 .707 r
F P
0 g
s
.52511 .48046 m .51117 .47639 L .51175 .46971 L closepath p .673 .536 .69 r
F P
0 g
s
.48461 .54159 m .49472 .52699 L .50319 .54188 L p .667 .538 .698 r
F P
0 g
s
.50319 .54188 m .49588 .56112 L .48461 .54159 L p .667 .538 .698 r
F P
0 g
s
.52511 .48046 m .52187 .45395 L .52549 .4541 L closepath p .673 .536 .69 r
F P
0 g
s
.35717 .33291 m .3697 .33462 L .35131 .38961 L p .767 .698 .786 r
F P
0 g
s
.35131 .38961 m .33757 .38919 L .35717 .33291 L p .767 .698 .786 r
F P
0 g
s
.52511 .48046 m .51155 .48335 L .51117 .47639 L closepath p .673 .536 .69 r
F P
0 g
s
.50059 .49966 m .51284 .49012 L .51498 .49624 L p .673 .537 .691 r
F P
0 g
s
.51498 .49624 m .50485 .51181 L .50059 .49966 L p .673 .537 .691 r
F P
0 g
s
.54703 .41909 m .53972 .43912 L .53306 .43196 L p .671 .538 .695 r
F P
0 g
s
.52909 .45604 m .53306 .43196 L .53972 .43912 L p .673 .537 .691 r
F P
0 g
s
.53306 .43196 m .52909 .45604 L .52549 .4541 L p .673 .537 .691 r
F P
0 g
s
.71231 .57157 m .69928 .57152 L .70781 .51124 L p .723 .642 .767 r
F P
0 g
s
.70781 .51124 m .72178 .51048 L .71231 .57157 L p .723 .642 .767 r
F P
0 g
s
.56902 .36431 m .56167 .38149 L .54499 .36456 L p .657 .546 .716 r
F P
0 g
s
.54499 .36456 m .54899 .34453 L .56902 .36431 L p .657 .546 .716 r
F P
0 g
s
.83191 .49179 m .81829 .49481 L .81681 .43677 L p .645 .7 .886 r
F P
0 g
s
.81681 .43677 m .83112 .43558 L .83191 .49179 L p .645 .7 .886 r
F P
0 g
s
.52511 .48046 m .52549 .4541 L .52909 .45604 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .51284 .49012 L .51155 .48335 L closepath p .673 .536 .69 r
F P
0 g
s
.49472 .52699 m .50485 .51181 L .51049 .52184 L p .67 .537 .694 r
F P
0 g
s
.51049 .52184 m .50319 .54188 L .49472 .52699 L p .67 .537 .694 r
F P
0 g
s
.40917 .29389 m .4192 .3006 L .39432 .34254 L p .763 .696 .788 r
F P
0 g
s
.39432 .34254 m .38208 .33782 L .40917 .29389 L p .763 .696 .788 r
F P
0 g
s
.53972 .43912 m .53242 .45966 L .52909 .45604 L p .673 .537 .691 r
F P
0 g
s
.52511 .48046 m .52909 .45604 L .53242 .45966 L closepath p .673 .536 .69 r
F P
0 g
s
.4886 .57934 m .49588 .56112 L .50918 .5752 L p .663 .542 .707 r
F P
0 g
s
.50918 .5752 m .5052 .59657 L .4886 .57934 L p .663 .542 .707 r
F P
0 g
s
.52511 .48046 m .51498 .49624 L .51284 .49012 L closepath p .673 .536 .69 r
F P
0 g
s
.50485 .51181 m .51498 .49624 L .51781 .50128 L p .672 .537 .691 r
F P
0 g
s
.51781 .50128 m .51049 .52184 L .50485 .51181 L p .672 .537 .691 r
F P
0 g
s
.55555 .43388 m .5454 .4491 L .53972 .43912 L p .67 .537 .694 r
F P
0 g
s
.53972 .43912 m .54703 .41909 L .55555 .43388 L p .67 .537 .694 r
F P
0 g
s
.53242 .45966 m .53972 .43912 L .5454 .4491 L p .672 .537 .691 r
F P
0 g
s
.56571 .4192 m .55555 .43388 L .54703 .41909 L p .667 .538 .698 r
F P
0 g
s
.54703 .41909 m .55434 .39981 L .56571 .4192 L p .667 .538 .698 r
F P
0 g
s
.55705 .30929 m .553 .32605 L .52777 .31427 L p .652 .573 .754 r
F P
0 g
s
.52777 .31427 m .52815 .29634 L .55705 .30929 L p .652 .573 .754 r
F P
0 g
s
.22302 .41303 m .23779 .40847 L .23209 .46612 L p .75 .791 .886 r
F P
0 g
s
.23209 .46612 m .21779 .46912 L .22302 .41303 L p .75 .791 .886 r
F P
0 g
s
.52854 .28041 m .52815 .29634 L .49915 .29599 L p .672 .614 .782 r
F P
0 g
s
.49915 .29599 m .49584 .28019 L .52854 .28041 L p .672 .614 .782 r
F P
0 g
s
.5454 .4491 m .53525 .46469 L .53242 .45966 L p .672 .537 .691 r
F P
0 g
s
.52511 .48046 m .53242 .45966 L .53525 .46469 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .51781 .50128 L .51498 .49624 L closepath p .673 .536 .69 r
F P
0 g
s
.62112 .65169 m .6117 .64189 L .63263 .60534 L p .734 .641 .756 r
F P
0 g
s
.63263 .60534 m .6444 .61281 L .62112 .65169 L p .734 .641 .756 r
F P
0 g
s
.5759 .40522 m .56571 .4192 L .55434 .39981 L p .662 .539 .704 r
F P
0 g
s
.55434 .39981 m .56167 .38149 L .5759 .40522 L p .662 .539 .704 r
F P
0 g
s
.58496 .66729 m .57842 .65344 L .6022 .62998 L p .718 .631 .759 r
F P
0 g
s
.6022 .62998 m .6117 .64189 L .58496 .66729 L p .718 .631 .759 r
F P
0 g
s
.57641 .34843 m .56902 .36431 L .54899 .34453 L p .649 .55 .729 r
F P
0 g
s
.54899 .34453 m .553 .32605 L .57641 .34843 L p .649 .55 .729 r
F P
0 g
s
.52511 .48046 m .53525 .46469 L .5374 .4708 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .52113 .50491 L .51781 .50128 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .52473 .50688 L .52113 .50491 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .52836 .50704 L .52473 .50688 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .53177 .50539 L .52836 .50704 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .53473 .50204 L .53177 .50539 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .53703 .49721 L .53473 .50204 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .53851 .49125 L .53703 .49721 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .53909 .48455 L .53851 .49125 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .5387 .47757 L .53909 .48455 L closepath p .673 .536 .69 r
F P
0 g
s
.52511 .48046 m .5374 .4708 L .5387 .47757 L closepath p .673 .536 .69 r
F P
0 g
s
.50124 .6164 m .5052 .59657 L .52321 .60591 L p .664 .554 .72 r
F P
0 g
s
.52321 .60591 m .52283 .62731 L .50124 .6164 L p .664 .554 .72 r
F P
0 g
s
.49248 .26654 m .49584 .28019 L .46526 .29362 L p .708 .662 .802 r
F P
0 g
s
.46526 .29362 m .45843 .28112 L .49248 .26654 L p .708 .662 .802 r
F P
0 g
s
.49588 .56112 m .50319 .54188 L .51316 .5526 L p .668 .54 .7 r
F P
0 g
s
.51316 .5526 m .50918 .5752 L .49588 .56112 L p .668 .54 .7 r
F P
0 g
s
.45151 .27072 m .45843 .28112 L .4291 .30921 L p .745 .694 .803 r
F P
0 g
s
.4291 .30921 m .4192 .3006 L .45151 .27072 L p .745 .694 .803 r
F P
0 g
s
.54969 .46123 m .5374 .4708 L .53525 .46469 L p .673 .537 .691 r
F P
0 g
s
.53525 .46469 m .5454 .4491 L .54969 .46123 L p .673 .537 .691 r
F P
0 g
s
.51049 .52184 m .51781 .50128 L .52113 .50491 L p .673 .537 .691 r
F P
0 g
s
.55109 .66502 m .54788 .64774 L .57182 .63728 L p .693 .605 .753 r
F P
0 g
s
.57182 .63728 m .57842 .65344 L .55109 .66502 L p .693 .605 .753 r
F P
0 g
s
.81829 .49481 m .80464 .49777 L .80254 .43798 L p .65 .684 .868 r
F P
0 g
s
.80254 .43798 m .81681 .43677 L .81829 .49481 L p .65 .684 .868 r
F P
0 g
s
.52246 .64676 m .52283 .62731 L .54465 .62821 L p .673 .576 .737 r
F P
0 g
s
.54465 .62821 m .54788 .64774 L .52246 .64676 L p .673 .576 .737 r
F P
0 g
s
.50319 .54188 m .51049 .52184 L .51715 .52906 L p .671 .538 .695 r
F P
0 g
s
.51715 .52906 m .51316 .5526 L .50319 .54188 L p .671 .538 .695 r
F P
0 g
s
.52113 .50491 m .51715 .52906 L .51049 .52184 L p .673 .537 .691 r
F P
0 g
s
.562 .45187 m .54969 .46123 L .5454 .4491 L p .671 .537 .693 r
F P
0 g
s
.5454 .4491 m .55555 .43388 L .562 .45187 L p .671 .537 .693 r
F P
0 g
s
.55232 .4747 m .5387 .47757 L .5374 .4708 L p .673 .537 .691 r
F P
0 g
s
.5374 .4708 m .54969 .46123 L .55232 .4747 L p .673 .537 .691 r
F P
0 g
s
.58611 .39208 m .5759 .40522 L .56167 .38149 L p .655 .54 .711 r
F P
0 g
s
.56167 .38149 m .56902 .36431 L .58611 .39208 L p .655 .54 .711 r
F P
0 g
s
.51715 .52906 m .52113 .50491 L .52473 .50688 L p .673 .537 .691 r
F P
0 g
s
.65607 .61856 m .6444 .61281 L .65963 .56467 L p .732 .632 .748 r
F P
0 g
s
.65963 .56467 m .67293 .56809 L .65607 .61856 L p .732 .632 .748 r
F P
0 g
s
.57433 .44281 m .562 .45187 L .55555 .43388 L p .668 .537 .696 r
F P
0 g
s
.55555 .43388 m .56571 .4192 L .57433 .44281 L p .668 .537 .696 r
F P
0 g
s
.55309 .48857 m .53909 .48455 L .5387 .47757 L p .673 .537 .691 r
F P
0 g
s
.5387 .47757 m .55232 .4747 L .55309 .48857 L p .673 .537 .691 r
F P
0 g
s
.52473 .50688 m .52435 .53298 L .51715 .52906 L p .673 .537 .691 r
F P
0 g
s
.52435 .53298 m .52473 .50688 L .52836 .50704 L p .673 .538 .691 r
F P
0 g
s
.20815 .41764 m .22302 .41303 L .21779 .46912 L p .746 .807 .901 r
F P
0 g
s
.21779 .46912 m .20346 .47212 L .20815 .41764 L p .746 .807 .901 r
F P
0 g
s
.5052 .59657 m .50918 .5752 L .52359 .58284 L p .668 .548 .709 r
F P
0 g
s
.52359 .58284 m .52321 .60591 L .5052 .59657 L p .668 .548 .709 r
F P
0 g
s
.34446 .3326 m .35717 .33291 L .33757 .38919 L p .779 .725 .802 r
F P
0 g
s
.33757 .38919 m .32371 .38974 L .34446 .3326 L p .779 .725 .802 r
F P
0 g
s
.51316 .5526 m .51715 .52906 L .52435 .53298 L p .672 .54 .695 r
F P
0 g
s
.56595 .47185 m .55232 .4747 L .54969 .46123 L p .672 .537 .692 r
F P
0 g
s
.54969 .46123 m .562 .45187 L .56595 .47185 L p .672 .537 .692 r
F P
0 g
s
.55195 .5019 m .53851 .49125 L .53909 .48455 L p .674 .537 .691 r
F P
0 g
s
.53909 .48455 m .55309 .48857 L .55195 .5019 L p .674 .537 .691 r
F P
0 g
s
.69928 .57152 m .68615 .57037 L .6938 .51151 L p .716 .625 .755 r
F P
0 g
s
.6938 .51151 m .70781 .51124 L .69928 .57152 L p .716 .625 .755 r
F P
0 g
s
.52836 .50704 m .53162 .53331 L .52435 .53298 L p .673 .538 .691 r
F P
0 g
s
.53162 .53331 m .52836 .50704 L .53177 .50539 L p .674 .538 .691 r
F P
0 g
s
.58669 .43415 m .57433 .44281 L .56571 .4192 L p .663 .537 .701 r
F P
0 g
s
.56571 .4192 m .5759 .40522 L .58669 .43415 L p .663 .537 .701 r
F P
0 g
s
.54897 .51377 m .53703 .49721 L .53851 .49125 L p .674 .538 .691 r
F P
0 g
s
.53851 .49125 m .55195 .5019 L .54897 .51377 L p .674 .538 .691 r
F P
0 g
s
.50918 .5752 m .51316 .5526 L .52397 .55842 L p .67 .543 .701 r
F P
0 g
s
.52397 .55842 m .52359 .58284 L .50918 .5752 L p .67 .543 .701 r
F P
0 g
s
.52435 .53298 m .52397 .55842 L .51316 .5526 L p .672 .54 .695 r
F P
0 g
s
.53177 .50539 m .53845 .53003 L .53162 .53331 L p .674 .538 .691 r
F P
0 g
s
.53845 .53003 m .53177 .50539 L .53473 .50204 L p .674 .538 .691 r
F P
0 g
s
.58385 .33399 m .57641 .34843 L .553 .32605 L p .638 .554 .744 r
F P
0 g
s
.553 .32605 m .55705 .30929 L .58385 .33399 L p .638 .554 .744 r
F P
0 g
s
.54437 .52337 m .53473 .50204 L .53703 .49721 L p .674 .538 .691 r
F P
0 g
s
.53703 .49721 m .54897 .51377 L .54437 .52337 L p .674 .538 .691 r
F P
0 g
s
.53473 .50204 m .54437 .52337 L .53845 .53003 L p .674 .538 .691 r
F P
0 g
s
.80464 .49777 m .79095 .50059 L .78831 .43922 L p .654 .668 .851 r
F P
0 g
s
.78831 .43922 m .80254 .43798 L .80464 .49777 L p .654 .668 .851 r
F P
0 g
s
.59637 .37991 m .58611 .39208 L .56902 .36431 L p .646 .541 .72 r
F P
0 g
s
.56902 .36431 m .57641 .34843 L .59637 .37991 L p .646 .541 .72 r
F P
0 g
s
.52283 .62731 m .52321 .60591 L .5414 .60671 L p .674 .563 .722 r
F P
0 g
s
.5414 .60671 m .54465 .62821 L .52283 .62731 L p .674 .563 .722 r
F P
0 g
s
.56113 .29434 m .55705 .30929 L .52815 .29634 L p .642 .587 .778 r
F P
0 g
s
.52815 .29634 m .52854 .28041 L .56113 .29434 L p .642 .587 .778 r
F P
0 g
s
.52397 .55842 m .52435 .53298 L .53162 .53331 L p .674 .541 .695 r
F P
0 g
s
.57961 .46905 m .56595 .47185 L .562 .45187 L p .67 .538 .695 r
F P
0 g
s
.562 .45187 m .57433 .44281 L .57961 .46905 L p .67 .538 .695 r
F P
0 g
s
.56712 .49245 m .55309 .48857 L .55232 .4747 L p .673 .538 .692 r
F P
0 g
s
.55232 .4747 m .56595 .47185 L .56712 .49245 L p .673 .538 .692 r
F P
0 g
s
.399 .28905 m .40917 .29389 L .38208 .33782 L p .779 .731 .808 r
F P
0 g
s
.38208 .33782 m .3697 .33462 L .399 .28905 L p .779 .731 .808 r
F P
0 g
s
.59908 .42597 m .58669 .43415 L .5759 .40522 L p .658 .538 .706 r
F P
0 g
s
.5759 .40522 m .58611 .39208 L .59908 .42597 L p .658 .538 .706 r
F P
0 g
s
.54788 .64774 m .54465 .62821 L .56518 .61901 L p .688 .584 .734 r
F P
0 g
s
.56518 .61901 m .57182 .63728 L .54788 .64774 L p .688 .584 .734 r
F P
0 g
s
.19318 .42214 m .20815 .41764 L .20346 .47212 L p .738 .822 .916 r
F P
0 g
s
.20346 .47212 m .18911 .47507 L .19318 .42214 L p .738 .822 .916 r
F P
0 g
s
.57842 .65344 m .57182 .63728 L .59263 .61606 L p .706 .605 .741 r
F P
0 g
s
.59263 .61606 m .6022 .62998 L .57842 .65344 L p .706 .605 .741 r
F P
0 g
s
.6117 .64189 m .6022 .62998 L .62077 .59621 L p .72 .617 .741 r
F P
0 g
s
.62077 .59621 m .63263 .60534 L .6117 .64189 L p .72 .617 .741 r
F P
0 g
s
.53162 .53331 m .53488 .55892 L .52397 .55842 L p .674 .541 .695 r
F P
0 g
s
.53488 .55892 m .53162 .53331 L .53845 .53003 L p .675 .542 .695 r
F P
0 g
s
.56541 .51225 m .55195 .5019 L .55309 .48857 L p .675 .54 .692 r
F P
0 g
s
.55309 .48857 m .56712 .49245 L .56541 .51225 L p .675 .54 .692 r
F P
0 g
s
.52894 .26657 m .52854 .28041 L .49584 .28019 L p .668 .642 .815 r
F P
0 g
s
.49584 .28019 m .49248 .26654 L .52894 .26657 L p .668 .642 .815 r
F P
0 g
s
.52359 .58284 m .52397 .55842 L .53488 .55892 L p .674 .546 .701 r
F P
0 g
s
.52321 .60591 m .52359 .58284 L .53814 .5835 L p .674 .553 .71 r
F P
0 g
s
.53814 .5835 m .5414 .60671 L .52321 .60591 L p .674 .553 .71 r
F P
0 g
s
.59329 .46632 m .57961 .46905 L .57433 .44281 L p .668 .539 .698 r
F P
0 g
s
.57433 .44281 m .58669 .43415 L .59329 .46632 L p .668 .539 .698 r
F P
0 g
s
.53488 .55892 m .53814 .5835 L .52359 .58284 L p .674 .546 .701 r
F P
0 g
s
.58117 .49612 m .56712 .49245 L .56595 .47185 L p .673 .54 .694 r
F P
0 g
s
.56595 .47185 m .57961 .46905 L .58117 .49612 L p .673 .54 .694 r
F P
0 g
s
.79095 .50059 m .77721 .50322 L .77412 .44051 L p .658 .653 .833 r
F P
0 g
s
.77412 .44051 m .78831 .43922 L .79095 .50059 L p .658 .653 .833 r
F P
0 g
s
.53845 .53003 m .54513 .55405 L .53488 .55892 L p .675 .542 .695 r
F P
0 g
s
.54513 .55405 m .53845 .53003 L .54437 .52337 L p .676 .542 .694 r
F P
0 g
s
.56094 .52989 m .54897 .51377 L .55195 .5019 L p .676 .541 .693 r
F P
0 g
s
.55195 .5019 m .56541 .51225 L .56094 .52989 L p .676 .541 .693 r
F P
0 g
s
.6444 .61281 m .63263 .60534 L .64626 .5601 L p .721 .613 .737 r
F P
0 g
s
.64626 .5601 m .65963 .56467 L .6444 .61281 L p .721 .613 .737 r
F P
0 g
s
.54437 .52337 m .55402 .54415 L .54513 .55405 L p .676 .542 .694 r
F P
0 g
s
.55402 .54415 m .54437 .52337 L .54897 .51377 L p .677 .542 .694 r
F P
0 g
s
.54897 .51377 m .56094 .52989 L .55402 .54415 L p .677 .542 .694 r
F P
0 g
s
.68615 .57037 m .67293 .56809 L .67976 .51128 L p .71 .611 .744 r
F P
0 g
s
.67976 .51128 m .6938 .51151 L .68615 .57037 L p .71 .611 .744 r
F P
0 g
s
.48908 .25507 m .49248 .26654 L .45843 .28112 L p .715 .703 .838 r
F P
0 g
s
.45843 .28112 m .45151 .27072 L .48908 .25507 L p .715 .703 .838 r
F P
0 g
s
.60669 .3688 m .59637 .37991 L .57641 .34843 L p .635 .542 .732 r
F P
0 g
s
.57641 .34843 m .58385 .33399 L .60669 .3688 L p .635 .542 .732 r
F P
0 g
s
.53814 .5835 m .53488 .55892 L .54513 .55405 L p .677 .548 .701 r
F P
0 g
s
.44448 .26243 m .45151 .27072 L .4192 .3006 L p .76 .737 .832 r
F P
0 g
s
.4192 .3006 m .40917 .29389 L .44448 .26243 L p .76 .737 .832 r
F P
0 g
s
.6115 .41835 m .59908 .42597 L .58611 .39208 L p .651 .538 .713 r
F P
0 g
s
.58611 .39208 m .59637 .37991 L .6115 .41835 L p .651 .538 .713 r
F P
0 g
s
.54465 .62821 m .5414 .60671 L .55851 .59886 L p .683 .568 .72 r
F P
0 g
s
.55851 .59886 m .56518 .61901 L .54465 .62821 L p .683 .568 .72 r
F P
0 g
s
.57889 .52215 m .56541 .51225 L .56712 .49245 L p .677 .543 .695 r
F P
0 g
s
.56712 .49245 m .58117 .49612 L .57889 .52215 L p .677 .543 .695 r
F P
0 g
s
.607 .46367 m .59329 .46632 L .58669 .43415 L p .664 .54 .702 r
F P
0 g
s
.58669 .43415 m .59908 .42597 L .607 .46367 L p .664 .54 .702 r
F P
0 g
s
.59135 .32109 m .58385 .33399 L .55705 .30929 L p .623 .56 .763 r
F P
0 g
s
.55705 .30929 m .56113 .29434 L .59135 .32109 L p .623 .56 .763 r
F P
0 g
s
.33158 .33361 m .34446 .3326 L .32371 .38974 L p .791 .752 .818 r
F P
0 g
s
.32371 .38974 m .30972 .3912 L .33158 .33361 L p .791 .752 .818 r
F P
0 g
s
.59524 .49952 m .58117 .49612 L .57961 .46905 L p .673 .542 .697 r
F P
0 g
s
.57961 .46905 m .59329 .46632 L .59524 .49952 L p .673 .542 .697 r
F P
0 g
s
.5414 .60671 m .53814 .5835 L .55182 .57711 L p .68 .557 .709 r
F P
0 g
s
.54513 .55405 m .55182 .57711 L .53814 .5835 L p .677 .548 .701 r
F P
0 g
s
.57182 .63728 m .56518 .61901 L .58301 .60029 L p .697 .585 .726 r
F P
0 g
s
.58301 .60029 m .59263 .61606 L .57182 .63728 L p .697 .585 .726 r
F P
0 g
s
.55182 .57711 m .55851 .59886 L .5414 .60671 L p .68 .557 .709 r
F P
0 g
s
.55182 .57711 m .54513 .55405 L .55402 .54415 L p .679 .549 .699 r
F P
0 g
s
.77721 .50322 m .76342 .50557 L .75998 .44186 L p .661 .638 .817 r
F P
0 g
s
.75998 .44186 m .77412 .44051 L .77721 .50322 L p .661 .638 .817 r
F P
0 g
s
.57293 .54534 m .56094 .52989 L .56541 .51225 L p .679 .546 .696 r
F P
0 g
s
.56541 .51225 m .57889 .52215 L .57293 .54534 L p .679 .546 .696 r
F P
0 g
s
.6022 .62998 m .59263 .61606 L .60886 .5855 L p .709 .596 .728 r
F P
0 g
s
.60886 .5855 m .62077 .59621 L .6022 .62998 L p .709 .596 .728 r
F P
0 g
s
.55402 .54415 m .56369 .56409 L .55182 .57711 L p .679 .549 .699 r
F P
0 g
s
.56369 .56409 m .55402 .54415 L .56094 .52989 L p .68 .548 .697 r
F P
0 g
s
.56094 .52989 m .57293 .54534 L .56369 .56409 L p .68 .548 .697 r
F P
0 g
s
.59238 .53144 m .57889 .52215 L .58117 .49612 L p .679 .547 .698 r
F P
0 g
s
.58117 .49612 m .59524 .49952 L .59238 .53144 L p .679 .547 .698 r
F P
0 g
s
.63263 .60534 m .62077 .59621 L .63283 .55442 L p .711 .596 .727 r
F P
0 g
s
.63283 .55442 m .64626 .5601 L .63263 .60534 L p .711 .596 .727 r
F P
0 g
s
.55851 .59886 m .55182 .57711 L .56369 .56409 L p .684 .558 .706 r
F P
0 g
s
.67293 .56809 m .65963 .56467 L .6657 .51052 L p .704 .597 .734 r
F P
0 g
s
.6657 .51052 m .67976 .51128 L .67293 .56809 L p .704 .597 .734 r
F P
0 g
s
.62074 .46112 m .607 .46367 L .59908 .42597 L p .66 .541 .707 r
F P
0 g
s
.59908 .42597 m .6115 .41835 L .62074 .46112 L p .66 .541 .707 r
F P
0 g
s
.56526 .28132 m .56113 .29434 L .52854 .28041 L p .626 .604 .808 r
F P
0 g
s
.52854 .28041 m .52894 .26657 L .56526 .28132 L p .626 .604 .808 r
F P
0 g
s
.56518 .61901 m .55851 .59886 L .57336 .58289 L p .69 .57 .715 r
F P
0 g
s
.57336 .58289 m .58301 .60029 L .56518 .61901 L p .69 .57 .715 r
F P
0 g
s
.60933 .50258 m .59524 .49952 L .59329 .46632 L p .673 .545 .701 r
F P
0 g
s
.59329 .46632 m .607 .46367 L .60933 .50258 L p .673 .545 .701 r
F P
0 g
s
.62398 .41134 m .6115 .41835 L .59637 .37991 L p .642 .538 .721 r
F P
0 g
s
.59637 .37991 m .60669 .3688 L .62398 .41134 L p .642 .538 .721 r
F P
0 g
s
.56369 .56409 m .57336 .58289 L .55851 .59886 L p .684 .558 .706 r
F P
0 g
s
.76342 .50557 m .74958 .5076 L .74587 .44329 L p .663 .625 .801 r
F P
0 g
s
.74587 .44329 m .75998 .44186 L .76342 .50557 L p .663 .625 .801 r
F P
0 g
s
.58492 .55989 m .57293 .54534 L .57889 .52215 L p .683 .552 .7 r
F P
0 g
s
.57889 .52215 m .59238 .53144 L .58492 .55989 L p .683 .552 .7 r
F P
0 g
s
.57336 .58289 m .56369 .56409 L .57293 .54534 L p .685 .556 .703 r
F P
0 g
s
.59263 .61606 m .58301 .60029 L .5969 .57334 L p .699 .58 .718 r
F P
0 g
s
.5969 .57334 m .60886 .5855 L .59263 .61606 L p .699 .58 .718 r
F P
0 g
s
.57293 .54534 m .58492 .55989 L .57336 .58289 L p .685 .556 .703 r
F P
0 g
s
.61707 .35884 m .60669 .3688 L .58385 .33399 L p .62 .543 .745 r
F P
0 g
s
.58385 .33399 m .59135 .32109 L .61707 .35884 L p .62 .543 .745 r
F P
0 g
s
.38866 .28603 m .399 .28905 L .3697 .33462 L p .796 .769 .829 r
F P
0 g
s
.3697 .33462 m .35717 .33291 L .38866 .28603 L p .796 .769 .829 r
F P
0 g
s
.60588 .54 m .59238 .53144 L .59524 .49952 L p .682 .552 .702 r
F P
0 g
s
.59524 .49952 m .60933 .50258 L .60588 .54 L p .682 .552 .702 r
F P
0 g
s
.58301 .60029 m .57336 .58289 L .58492 .55989 L p .691 .567 .71 r
F P
0 g
s
.62342 .50525 m .60933 .50258 L .607 .46367 L p .673 .548 .705 r
F P
0 g
s
.607 .46367 m .62074 .46112 L .62342 .50525 L p .673 .548 .705 r
F P
0 g
s
.62077 .59621 m .60886 .5855 L .61937 .54769 L p .702 .582 .718 r
F P
0 g
s
.61937 .54769 m .63283 .55442 L .62077 .59621 L p .702 .582 .718 r
F P
0 g
s
.58492 .55989 m .5969 .57334 L .58301 .60029 L p .691 .567 .71 r
F P
0 g
s
.65963 .56467 m .64626 .5601 L .65162 .50925 L p .698 .586 .726 r
F P
0 g
s
.65162 .50925 m .6657 .51052 L .65963 .56467 L p .698 .586 .726 r
F P
0 g
s
.74958 .5076 m .7357 .50925 L .73182 .44481 L p .665 .613 .786 r
F P
0 g
s
.73182 .44481 m .74587 .44329 L .74958 .5076 L p .665 .613 .786 r
F P
0 g
s
.52934 .25487 m .52894 .26657 L .49248 .26654 L p .659 .678 .857 r
F P
0 g
s
.49248 .26654 m .48908 .25507 L .52934 .25487 L p .659 .678 .857 r
F P
0 g
s
.6345 .45866 m .62074 .46112 L .6115 .41835 L p .656 .542 .713 r
F P
0 g
s
.6115 .41835 m .62398 .41134 L .6345 .45866 L p .656 .542 .713 r
F P
0 g
s
.5969 .57334 m .58492 .55989 L .59238 .53144 L p .688 .56 .705 r
F P
0 g
s
.59238 .53144 m .60588 .54 L .5969 .57334 L p .688 .56 .705 r
F P
0 g
s
.60886 .5855 m .5969 .57334 L .60588 .54 L p .694 .57 .711 r
F P
0 g
s
.60588 .54 m .61937 .54769 L .60886 .5855 L p .694 .57 .711 r
F P
0 g
s
.61937 .54769 m .60588 .54 L .60933 .50258 L p .685 .559 .706 r
F P
0 g
s
.60933 .50258 m .62342 .50525 L .61937 .54769 L p .685 .559 .706 r
F P
0 g
s
.64626 .5601 m .63283 .55442 L .63752 .50749 L p .693 .575 .718 r
F P
0 g
s
.63752 .50749 m .65162 .50925 L .64626 .5601 L p .693 .575 .718 r
F P
0 g
s
.59892 .30981 m .59135 .32109 L .56113 .29434 L p .602 .567 .787 r
F P
0 g
s
.56113 .29434 m .56526 .28132 L .59892 .30981 L p .602 .567 .787 r
F P
0 g
s
.63651 .40499 m .62398 .41134 L .60669 .3688 L p .631 .538 .73 r
F P
0 g
s
.60669 .3688 m .61707 .35884 L .63651 .40499 L p .631 .538 .73 r
F P
0 g
s
.3185 .33581 m .33158 .33361 L .30972 .3912 L p .802 .781 .834 r
F P
0 g
s
.30972 .3912 m .2956 .39347 L .3185 .33581 L p .802 .781 .834 r
F P
0 g
s
.7357 .50925 m .72178 .51048 L .7178 .44643 L p .667 .602 .773 r
F P
0 g
s
.7178 .44643 m .73182 .44481 L .7357 .50925 L p .667 .602 .773 r
F P
0 g
s
.63752 .50749 m .62342 .50525 L .62074 .46112 L p .672 .552 .71 r
F P
0 g
s
.62074 .46112 m .6345 .45866 L .63752 .50749 L p .672 .552 .71 r
F P
0 g
s
.63283 .55442 m .61937 .54769 L .62342 .50525 L p .689 .566 .712 r
F P
0 g
s
.62342 .50525 m .63752 .50749 L .63283 .55442 L p .689 .566 .712 r
F P
0 g
s
.48563 .2458 m .48908 .25507 L .45151 .27072 L p .719 .754 .88 r
F P
0 g
s
.45151 .27072 m .44448 .26243 L .48563 .2458 L p .719 .754 .88 r
F P
0 g
s
.43733 .25624 m .44448 .26243 L .40917 .29389 L p .775 .787 .863 r
F P
0 g
s
.40917 .29389 m .399 .28905 L .43733 .25624 L p .775 .787 .863 r
F P
0 g
s
.72178 .51048 m .70781 .51124 L .70382 .44817 L p .668 .592 .761 r
F P
0 g
s
.70382 .44817 m .7178 .44643 L .72178 .51048 L p .668 .592 .761 r
F P
0 g
s
.6483 .45632 m .6345 .45866 L .62398 .41134 L p .65 .543 .72 r
F P
0 g
s
.62398 .41134 m .63651 .40499 L .6483 .45632 L p .65 .543 .72 r
F P
0 g
s
.65162 .50925 m .63752 .50749 L .6345 .45866 L p .672 .557 .716 r
F P
0 g
s
.70781 .51124 m .6938 .51151 L .68989 .45002 L p .669 .583 .75 r
F P
0 g
s
.68989 .45002 m .70382 .44817 L .70781 .51124 L p .669 .583 .75 r
F P
0 g
s
.6345 .45866 m .6483 .45632 L .65162 .50925 L p .672 .557 .716 r
F P
0 g
s
.6657 .51052 m .65162 .50925 L .6483 .45632 L p .672 .562 .723 r
F P
0 g
s
.62754 .35009 m .61707 .35884 L .59135 .32109 L p .602 .544 .762 r
F P
0 g
s
.59135 .32109 m .59892 .30981 L .62754 .35009 L p .602 .544 .762 r
F P
0 g
s
.6938 .51151 m .67976 .51128 L .67599 .452 L p .67 .575 .74 r
F P
0 g
s
.67599 .452 m .68989 .45002 L .6938 .51151 L p .67 .575 .74 r
F P
0 g
s
.67976 .51128 m .6657 .51052 L .66213 .4541 L p .671 .568 .731 r
F P
0 g
s
.6483 .45632 m .66213 .4541 L .6657 .51052 L p .672 .562 .723 r
F P
0 g
s
.66213 .4541 m .67599 .452 L .67976 .51128 L p .671 .568 .731 r
F P
0 g
s
.56945 .27025 m .56526 .28132 L .52894 .26657 L p .602 .625 .847 r
F P
0 g
s
.52894 .26657 m .52934 .25487 L .56945 .27025 L p .602 .625 .847 r
F P
0 g
s
.66213 .4541 m .6483 .45632 L .63651 .40499 L p .644 .545 .728 r
F P
0 g
s
.64911 .39934 m .63651 .40499 L .61707 .35884 L p .618 .538 .741 r
F P
0 g
s
.61707 .35884 m .62754 .35009 L .64911 .39934 L p .618 .538 .741 r
F P
0 g
s
.63651 .40499 m .64911 .39934 L .66213 .4541 L p .644 .545 .728 r
F P
0 g
s
.37814 .28476 m .38866 .28603 L .35717 .33291 L p .811 .811 .85 r
F P
0 g
s
.35717 .33291 m .34446 .3326 L .37814 .28476 L p .811 .811 .85 r
F P
0 g
s
.30522 .33905 m .3185 .33581 L .2956 .39347 L p .81 .809 .85 r
F P
0 g
s
.2956 .39347 m .28135 .39645 L .30522 .33905 L p .81 .809 .85 r
F P
0 g
s
.67599 .452 m .66213 .4541 L .64911 .39934 L p .636 .547 .737 r
F P
0 g
s
.60658 .30018 m .59892 .30981 L .56526 .28132 L p .574 .574 .815 r
F P
0 g
s
.56526 .28132 m .56945 .27025 L .60658 .30018 L p .574 .574 .815 r
F P
0 g
s
.52974 .24533 m .52934 .25487 L .48908 .25507 L p .64 .722 .908 r
F P
0 g
s
.48908 .25507 m .48563 .2458 L .52974 .24533 L p .64 .722 .908 r
F P
0 g
s
.64911 .39934 m .66179 .39441 L .67599 .452 L p .636 .547 .737 r
F P
0 g
s
.66179 .39441 m .64911 .39934 L .62754 .35009 L p .603 .537 .754 r
F P
0 g
s
.68989 .45002 m .67599 .452 L .66179 .39441 L p .628 .55 .747 r
F P
0 g
s
.63811 .34257 m .62754 .35009 L .59892 .30981 L p .578 .544 .78 r
F P
0 g
s
.59892 .30981 m .60658 .30018 L .63811 .34257 L p .578 .544 .78 r
F P
0 g
s
.62754 .35009 m .63811 .34257 L .66179 .39441 L p .603 .537 .754 r
F P
0 g
s
.4821 .23872 m .48563 .2458 L .44448 .26243 L p .715 .814 .927 r
F P
0 g
s
.44448 .26243 m .43733 .25624 L .4821 .23872 L p .715 .814 .927 r
F P
0 g
s
.43005 .25209 m .43733 .25624 L .399 .28905 L p .786 .843 .895 r
F P
0 g
s
.399 .28905 m .38866 .28603 L .43005 .25209 L p .786 .843 .895 r
F P
0 g
s
.70382 .44817 m .68989 .45002 L .67455 .3902 L p .618 .553 .759 r
F P
0 g
s
.66179 .39441 m .67455 .3902 L .68989 .45002 L p .628 .55 .747 r
F P
0 g
s
.5737 .26116 m .56945 .27025 L .52934 .25487 L p .563 .649 .893 r
F P
0 g
s
.52934 .25487 m .52974 .24533 L .5737 .26116 L p .563 .649 .893 r
F P
0 g
s
.29174 .34319 m .30522 .33905 L .28135 .39645 L p .815 .836 .865 r
F P
0 g
s
.28135 .39645 m .26696 .40003 L .29174 .34319 L p .815 .836 .865 r
F P
0 g
s
.67455 .3902 m .66179 .39441 L .63811 .34257 L p .585 .537 .768 r
F P
0 g
s
.36742 .28511 m .37814 .28476 L .34446 .3326 L p .823 .853 .87 r
F P
0 g
s
.34446 .3326 m .33158 .33361 L .36742 .28511 L p .823 .853 .87 r
F P
0 g
s
.7178 .44643 m .70382 .44817 L .68741 .38671 L p .608 .556 .771 r
F P
0 g
s
.67455 .3902 m .68741 .38671 L .70382 .44817 L p .618 .553 .759 r
F P
0 g
s
.61435 .29223 m .60658 .30018 L .56945 .27025 L p .534 .581 .848 r
F P
0 g
s
.56945 .27025 m .5737 .26116 L .61435 .29223 L p .534 .581 .848 r
F P
0 g
s
.63811 .34257 m .64879 .3363 L .67455 .3902 L p .585 .537 .768 r
F P
0 g
s
.64879 .3363 m .63811 .34257 L .60658 .30018 L p .548 .544 .802 r
F P
0 g
s
.73182 .44481 m .7178 .44643 L .70038 .38391 L p .596 .561 .785 r
F P
0 g
s
.68741 .38671 m .70038 .38391 L .7178 .44643 L p .608 .556 .771 r
F P
0 g
s
.60658 .30018 m .61435 .29223 L .64879 .3363 L p .548 .544 .802 r
F P
0 g
s
.53015 .23793 m .52974 .24533 L .48563 .2458 L p .599 .771 .962 r
F P
0 g
s
.48563 .2458 m .4821 .23872 L .53015 .23793 L p .599 .771 .962 r
F P
0 g
s
.68741 .38671 m .67455 .3902 L .64879 .3363 L p .563 .537 .783 r
F P
0 g
s
.74587 .44329 m .73182 .44481 L .71346 .38177 L p .583 .566 .8 r
F P
0 g
s
.70038 .38391 m .71346 .38177 L .73182 .44481 L p .596 .561 .785 r
F P
0 g
s
.42261 .24989 m .43005 .25209 L .38866 .28603 L p .787 .9 .922 r
F P
0 g
s
.38866 .28603 m .37814 .28476 L .42261 .24989 L p .787 .9 .922 r
F P
0 g
s
.27806 .34802 m .29174 .34319 L .26696 .40003 L p .818 .862 .88 r
F P
0 g
s
.26696 .40003 m .25244 .40408 L .27806 .34802 L p .818 .862 .88 r
F P
0 g
s
.47851 .23377 m .4821 .23872 L .43733 .25624 L p .692 .877 .968 r
F P
0 g
s
.43733 .25624 m .43005 .25209 L .47851 .23377 L p .692 .877 .968 r
F P
0 g
s
.75998 .44186 m .74587 .44329 L .72665 .38024 L p .57 .572 .816 r
F P
0 g
s
.71346 .38177 m .72665 .38024 L .74587 .44329 L p .583 .566 .8 r
F P
0 g
s
.57803 .25404 m .5737 .26116 L .52974 .24533 L p .498 .671 .941 r
F P
0 g
s
.52974 .24533 m .53015 .23793 L .57803 .25404 L p .498 .671 .941 r
F P
0 g
s
.64879 .3363 m .65959 .33127 L .68741 .38671 L p .563 .537 .783 r
F P
0 g
s
.65959 .33127 m .64879 .3363 L .61435 .29223 L p .51 .542 .825 r
F P
0 g
s
.35649 .28694 m .36742 .28511 L .33158 .33361 L p .829 .893 .887 r
F P
0 g
s
.33158 .33361 m .3185 .33581 L .35649 .28694 L p .829 .893 .887 r
F P
0 g
s
.70038 .38391 m .68741 .38671 L .65959 .33127 L p .538 .536 .8 r
F P
0 g
s
.77412 .44051 m .75998 .44186 L .73997 .37926 L p .556 .579 .832 r
F P
0 g
s
.72665 .38024 m .73997 .37926 L .75998 .44186 L p .57 .572 .816 r
F P
0 g
s
.62224 .28593 m .61435 .29223 L .5737 .26116 L p .476 .584 .884 r
F P
0 g
s
.5737 .26116 m .57803 .25404 L .62224 .28593 L p .476 .584 .884 r
F P
0 g
s
.61435 .29223 m .62224 .28593 L .65959 .33127 L p .51 .542 .825 r
F P
0 g
s
.78831 .43922 m .77412 .44051 L .75341 .37876 L p .541 .587 .849 r
F P
0 g
s
.73997 .37926 m .75341 .37876 L .77412 .44051 L p .556 .579 .832 r
F P
0 g
s
.26419 .35336 m .27806 .34802 L .25244 .40408 L p .816 .884 .894 r
F P
0 g
s
.25244 .40408 m .23779 .40847 L .26419 .35336 L p .816 .884 .894 r
F P
0 g
s
.53058 .2326 m .53015 .23793 L .4821 .23872 L p .515 .808 .999 r
F P
0 g
s
.4821 .23872 m .47851 .23377 L .53058 .2326 L p .515 .808 .999 r
F P
0 g
s
.71346 .38177 m .70038 .38391 L .67053 .32744 L p .51 .535 .818 r
F P
0 g
s
.65959 .33127 m .67053 .32744 L .70038 .38391 L p .538 .536 .8 r
F P
0 g
s
.80254 .43798 m .78831 .43922 L .76698 .37865 L p .527 .596 .867 r
F P
0 g
s
.75341 .37876 m .76698 .37865 L .78831 .43922 L p .541 .587 .849 r
F P
0 g
s
.67053 .32744 m .65959 .33127 L .62224 .28593 L p .461 .538 .85 r
F P
0 g
s
.41502 .24952 m .42261 .24989 L .37814 .28476 L p .77 .948 .935 r
F P
0 g
s
.37814 .28476 m .36742 .28511 L .41502 .24952 L p .77 .948 .935 r
F P
0 g
s
.47483 .23085 m .47851 .23377 L .43005 .25209 L p .629 .919 .978 r
F P
0 g
s
.43005 .25209 m .42261 .24989 L .47483 .23085 L p .629 .919 .978 r
F P
0 g
s
.81681 .43677 m .80254 .43798 L .78067 .37885 L p .513 .607 .884 r
F P
0 g
s
.76698 .37865 m .78067 .37885 L .80254 .43798 L p .527 .596 .867 r
F P
0 g
s
.34534 .29007 m .35649 .28694 L .3185 .33581 L p .828 .929 .899 r
F P
0 g
s
.3185 .33581 m .30522 .33905 L .34534 .29007 L p .828 .929 .899 r
F P
0 g
s
.58244 .24881 m .57803 .25404 L .53015 .23793 L p .389 .679 .975 r
F P
0 g
s
.53015 .23793 m .53058 .2326 L .58244 .24881 L p .389 .679 .975 r
F P
0 g
s
.25014 .35899 m .26419 .35336 L .23779 .40847 L p .81 .902 .906 r
F P
0 g
s
.23779 .40847 m .22302 .41303 L .25014 .35899 L p .81 .902 .906 r
F P
0 g
s
.62224 .28593 m .63026 .28124 L .67053 .32744 L p .461 .538 .85 r
F P
0 g
s
.63026 .28124 m .62224 .28593 L .57803 .25404 L p .392 .58 .916 r
F P
0 g
s
.72665 .38024 m .71346 .38177 L .68163 .32475 L p .477 .533 .836 r
F P
0 g
s
.67053 .32744 m .68163 .32475 L .71346 .38177 L p .51 .535 .818 r
F P
0 g
s
.83112 .43558 m .81681 .43677 L .79449 .37926 L p .501 .619 .901 r
F P
0 g
s
.78067 .37885 m .79449 .37926 L .81681 .43677 L p .513 .607 .884 r
F P
0 g
s
.57803 .25404 m .58244 .24881 L .63026 .28124 L p .392 .58 .916 r
F P
0 g
s
.84547 .43439 m .83112 .43558 L .80842 .37978 L p .49 .633 .916 r
F P
0 g
s
.79449 .37926 m .80842 .37978 L .83112 .43558 L p .501 .619 .901 r
F P
0 g
s
.68163 .32475 m .67053 .32744 L .63026 .28124 L p .4 .53 .872 r
F P
0 g
s
.53101 .22926 m .53058 .2326 L .47851 .23377 L p .363 .794 .968 r
F P
0 g
s
.47851 .23377 m .47483 .23085 L .53101 .22926 L p .363 .794 .968 r
F P
0 g
s
.85986 .43317 m .84547 .43439 L .82246 .38031 L p .484 .649 .931 r
F P
0 g
s
.80842 .37978 m .82246 .38031 L .84547 .43439 L p .49 .633 .916 r
F P
0 g
s
.73997 .37926 m .72665 .38024 L .69288 .32313 L p .441 .531 .854 r
F P
0 g
s
.68163 .32475 m .69288 .32313 L .72665 .38024 L p .477 .533 .836 r
F P
0 g
s
.23591 .3647 m .25014 .35899 L .22302 .41303 L p .8 .916 .917 r
F P
0 g
s
.22302 .41303 m .20815 .41764 L .23591 .3647 L p .8 .916 .917 r
F P
0 g
s
.40725 .25081 m .41502 .24952 L .36742 .28511 L p .729 .976 .923 r
F P
0 g
s
.36742 .28511 m .35649 .28694 L .40725 .25081 L p .729 .976 .923 r
F P
0 g
s
.33398 .29432 m .34534 .29007 L .30522 .33905 L p .819 .958 .904 r
F P
0 g
s
.30522 .33905 m .29174 .34319 L .33398 .29432 L p .819 .958 .904 r
F P
0 g
s
.82246 .38031 m .8366 .38074 L .85986 .43317 L p .484 .649 .931 r
F P
0 g
s
.47107 .22982 m .47483 .23085 L .42261 .24989 L p .512 .908 .925 r
F P
0 g
s
.42261 .24989 m .41502 .24952 L .47107 .22982 L p .512 .908 .925 r
F P
0 g
s
.63026 .28124 m .63842 .27809 L .68163 .32475 L p .4 .53 .872 r
F P
0 g
s
.63842 .27809 m .63026 .28124 L .58244 .24881 L p .275 .56 .931 r
F P
0 g
s
.58694 .24541 m .58244 .24881 L .53058 .2326 L p .221 .644 .955 r
F P
0 g
s
.53058 .2326 m .53101 .22926 L .58694 .24541 L p .221 .644 .955 r
F P
0 g
s
.58244 .24881 m .58694 .24541 L .63842 .27809 L p .275 .56 .931 r
F P
0 g
s
.69288 .32313 m .68163 .32475 L .63842 .27809 L p .325 .516 .889 r
F P
0 g
s
.75341 .37876 m .73997 .37926 L .7043 .32246 L p .402 .529 .87 r
F P
0 g
s
.69288 .32313 m .7043 .32246 L .73997 .37926 L p .441 .531 .854 r
F P
0 g
s
.22154 .37026 m .23591 .3647 L .20815 .41764 L p .786 .925 .928 r
F P
0 g
s
.20815 .41764 m .19318 .42214 L .22154 .37026 L p .786 .925 .928 r
F P
0 g
s
.32239 .29945 m .33398 .29432 L .29174 .34319 L p .8 .977 .903 r
F P
0 g
s
.29174 .34319 m .27806 .34802 L .32239 .29945 L p .8 .977 .903 r
F P
0 g
s
.53145 .22778 m .53101 .22926 L .47483 .23085 L p .159 .695 .833 r
F P
0 g
s
.47483 .23085 m .47107 .22982 L .53145 .22778 L p .159 .695 .833 r
F P
0 g
s
.76698 .37865 m .75341 .37876 L .71589 .32263 L p .362 .527 .885 r
F P
0 g
s
.7043 .32246 m .71589 .32263 L .75341 .37876 L p .402 .529 .87 r
F P
0 g
s
.3993 .25357 m .40725 .25081 L .35649 .28694 L p .662 .972 .883 r
F P
0 g
s
.35649 .28694 m .34534 .29007 L .3993 .25357 L p .662 .972 .883 r
F P
0 g
s
.63842 .27809 m .64674 .27637 L .69288 .32313 L p .325 .516 .889 r
F P
0 g
s
.64674 .27637 m .63842 .27809 L .58694 .24541 L p .125 .514 .912 r
F P
0 g
s
.7043 .32246 m .69288 .32313 L .64674 .27637 L p .237 .495 .897 r
F P
0 g
s
.40725 .25081 m .3993 .25357 L .4065 .25123 L p 0 0 0 r
F P
0 g
s
.46825 .23081 m .41502 .24952 L p .4485 .23734 L .355 .828 .803 r
F P
0 g
s
.41502 .24952 m .40725 .25081 L .46722 .23054 L p .355 .828 .803 r
F P
0 g
s
.4065 .25123 m .46327 .23279 L p .4267 .24455 L 0 0 0 r
F P
0 g
s
.40725 .25081 m .4065 .25123 L .4267 .24455 L 0 0 0 r
F
.46722 .23054 m .47107 .22982 L .46825 .23081 L p .355 .828 .803 r
F P
0 g
s
.4485 .23734 m .46722 .23054 L .46825 .23081 L .355 .828 .803 r
F
.59154 .24371 m .58694 .24541 L .53101 .22926 L p .012 .548 .846 r
F P
0 g
s
.53101 .22926 m .53145 .22778 L .59154 .24371 L p .012 .548 .846 r
F P
0 g
s
.58694 .24541 m .59154 .24371 L .64674 .27637 L p .125 .514 .912 r
F P
0 g
s
.78067 .37885 m .76698 .37865 L .72766 .32351 L p .323 .526 .898 r
F P
0 g
s
.71589 .32263 m .72766 .32351 L .76698 .37865 L p .362 .527 .885 r
F P
0 g
s
.31059 .30522 m .32239 .29945 L .27806 .34802 L p .775 .986 .898 r
F P
0 g
s
.27806 .34802 m .26419 .35336 L .31059 .30522 L p .775 .986 .898 r
F P
0 g
s
.71589 .32263 m .7043 .32246 L .65522 .27595 L p .142 .466 .891 r
F P
0 g
s
.64674 .27637 m .65522 .27595 L .7043 .32246 L p .237 .495 .897 r
F P
0 g
s
.39116 .25758 m .3993 .25357 L .34534 .29007 L p .579 .941 .822 r
F P
0 g
s
.34534 .29007 m .33398 .29432 L .39116 .25758 L p .579 .941 .822 r
F P
0 g
s
.65522 .27595 m .64674 .27637 L .59154 .24371 L p 0 .441 .845 r
F P
0 g
s
.5319 .228 m .53145 .22778 L .47107 .22982 L p .034 0 0 r
F P
0 g
s
.47107 .22982 m .46722 .23054 L .5319 .228 L p .034 0 0 r
F P
0 g
s
.79449 .37926 m .78067 .37885 L .7396 .32494 L p .288 .528 .909 r
F P
0 g
s
.72766 .32351 m .7396 .32494 L .78067 .37885 L p .323 .526 .898 r
F P
0 g
s
.46327 .23279 m .46722 .23054 L .40725 .25081 L p 0 0 0 r
F P
0 g
s
.59154 .24371 m .59625 .24356 L .65522 .27595 L p 0 .441 .845 r
F P
0 g
s
.59625 .24356 m .59154 .24371 L .53145 .22778 L p .178 0 0 r
F P
0 g
s
.53145 .22778 m .5319 .228 L .59625 .24356 L p .178 0 0 r
F P
0 g
s
.29858 .31138 m .31059 .30522 L .26419 .35336 L p .747 .989 .892 r
F P
0 g
s
.26419 .35336 m .25014 .35899 L .29858 .31138 L p .747 .989 .892 r
F P
0 g
s
.80842 .37978 m .79449 .37926 L .75172 .32675 L p .259 .532 .917 r
F P
0 g
s
.7396 .32494 m .75172 .32675 L .79449 .37926 L p .288 .528 .909 r
F P
0 g
s
.72766 .32351 m .71589 .32263 L .66386 .27667 L p .049 .434 .872 r
F P
0 g
s
.65522 .27595 m .66386 .27667 L .71589 .32263 L p .142 .466 .891 r
F P
0 g
s
.66386 .27667 m .65522 .27595 L .59625 .24356 L p 0 .354 .743 r
F P
0 g
s
.33398 .29432 m .32239 .29945 L .38284 .2626 L p .495 .894 .755 r
F P
0 g
s
.38284 .2626 m .39116 .25758 L .34552 .2869 L p .495 .894 .755 r
F P
0 g
s
.34552 .2869 m .34224 .28901 L p .34561 .28682 L .495 .894 .755 r
F P
0 g
s
.34561 .28682 m .38284 .2626 L .34552 .2869 L .495 .894 .755 r
F
.34468 .28737 m .38284 .2626 L .34224 .28901 L F
.37434 .26835 m .38284 .2626 L .32693 .29669 L p .423 .847 .696 r
F P
0 g
s
.32693 .29669 m .32239 .29945 L p .32905 .29546 L .423 .847 .696 r
F P
0 g
s
.32905 .29546 m .37434 .26835 L .32693 .29669 L .423 .847 .696 r
F
.32239 .29945 m .31059 .30522 L .36467 .27395 L p F P
0 g
s
.32239 .29945 m .36467 .27395 L .36199 .27575 L .423 .847 .696 r
F
.36467 .27395 m .37434 .26835 L p .36199 .27575 L F P
0 g
s
.36407 .27429 m .31077 .30512 L p .36071 .27731 L .369 .809 .655 r
F P
0 g
s
.31077 .30512 m .31059 .30522 L p .3109 .30505 L .369 .809 .655 r
F P
0 g
s
.3109 .30505 m .36566 .27454 L .31077 .30512 L .369 .809 .655 r
F
.31059 .30522 m .29858 .31138 L .34884 .28378 L p F P
0 g
s
.31059 .30522 m .34884 .28378 L .34849 .28411 L .369 .809 .655 r
F
.36071 .27731 m .36566 .27454 L .36407 .27429 L F
.34884 .28378 m .36566 .27454 L p .34849 .28411 L F P
0 g
s
.35682 .28087 m .36566 .27454 L .29858 .31138 L p .334 .785 .635 r
F P
0 g
s
.29858 .31138 m .28638 .31765 L .3566 .28098 L p .334 .785 .635 r
F P
0 g
s
.29858 .31138 m .3566 .28098 L .35646 .28105 L .334 .785 .635 r
F
.34224 .28901 m .33398 .29432 L p .34468 .28737 L .495 .894 .755 r
F P
0 g
s
.28638 .31765 m .29858 .31138 L .29805 .3119 L p .719 .986 .887 r
F P
0 g
s
.29805 .3119 m .25014 .35899 L p .28638 .31765 L .719 .986 .887 r
F P
0 g
s
.28638 .31765 m .27399 .32374 L .27469 .3234 L p .319 .778 .638 r
F P
0 g
s
.34782 .287 m .35644 .28112 L p .28638 .31765 L .319 .778 .638 r
F P
0 g
s
.3566 .28098 m .28638 .31765 L p .35644 .28112 L .319 .778 .638 r
F P
0 g
s
.27469 .3234 m .34782 .287 L p .28638 .31765 L .319 .778 .638 r
F P
0 g
s
.3566 .28098 m .35682 .28087 L p .35646 .28105 L .334 .785 .635 r
F P
0 g
s
.35644 .28112 m .35682 .28087 L .3566 .28098 L p .319 .778 .638 r
F P
0 g
s
.36566 .27454 m .37434 .26835 L .36407 .27429 L p .369 .809 .655 r
F P
0 g
s
.82246 .38031 m .80842 .37978 L .764 .32877 L p .241 .541 .925 r
F P
0 g
s
.75172 .32675 m .764 .32877 L .80842 .37978 L p .259 .532 .917 r
F P
0 g
s
.53236 .22972 m .5319 .228 L .46722 .23054 L p .173 0 0 r
F P
0 g
s
.46722 .23054 m .46327 .23279 L .53236 .22972 L p .173 0 0 r
F P
0 g
s
.25014 .35899 m .23591 .3647 L .28638 .31765 L p .719 .986 .887 r
F P
0 g
s
.45922 .23635 m .46327 .23279 L .3993 .25357 L p 0 0 0 r
F P
0 g
s
.3993 .25357 m .39116 .25758 L .45922 .23635 L p 0 0 0 r
F P
0 g
s
.7396 .32494 m .72766 .32351 L .67268 .27835 L p 0 .402 .843 r
F P
0 g
s
.66386 .27667 m .67268 .27835 L .72766 .32351 L p .049 .434 .872 r
F P
0 g
s
.59625 .24356 m .60106 .24477 L .66386 .27667 L p 0 .354 .743 r
F P
0 g
s
.60106 .24477 m .59625 .24356 L .5319 .228 L p .313 0 0 r
F P
0 g
s
.5319 .228 m .53236 .22972 L .60106 .24477 L p .313 0 0 r
F P
0 g
s
.8366 .38074 m .82246 .38031 L .77643 .33083 L p .234 .556 .933 r
F P
0 g
s
.764 .32877 m .77643 .33083 L .82246 .38031 L p .241 .541 .925 r
F P
0 g
s
.67268 .27835 m .66386 .27667 L .60106 .24477 L p .306 0 0 r
F P
0 g
s
.27399 .32374 m .28638 .31765 L .23591 .3647 L p .694 .981 .887 r
F P
0 g
s
.23591 .3647 m .22154 .37026 L .27399 .32374 L p .694 .981 .887 r
F P
0 g
s
.77643 .33083 m .78901 .33274 L .8366 .38074 L p .234 .556 .933 r
F P
0 g
s
.75172 .32675 m .7396 .32494 L .68167 .2808 L p 0 .377 .812 r
F P
0 g
s
.67268 .27835 m .68167 .2808 L .7396 .32494 L p 0 .402 .843 r
F P
0 g
s
.53284 .23272 m .53236 .22972 L .46327 .23279 L p .261 0 0 r
F P
0 g
s
.46327 .23279 m .45922 .23635 L .53284 .23272 L p .261 0 0 r
F P
0 g
s
.45508 .24096 m .45922 .23635 L .39116 .25758 L p .006 0 0 r
F P
0 g
s
.39116 .25758 m .38284 .2626 L .45508 .24096 L p .006 0 0 r
F P
0 g
s
.60106 .24477 m .60599 .24714 L .67268 .27835 L p .306 0 0 r
F P
0 g
s
.60599 .24714 m .60106 .24477 L .53236 .22972 L p .396 0 0 r
F P
0 g
s
.53236 .22972 m .53284 .23272 L .60599 .24714 L p .396 0 0 r
F P
0 g
s
.68167 .2808 m .67268 .27835 L .60599 .24714 L p .382 0 0 r
F P
0 g
s
.764 .32877 m .75172 .32675 L .69083 .28379 L p 0 .363 .786 r
F P
0 g
s
.68167 .2808 m .69083 .28379 L .75172 .32675 L p 0 .377 .812 r
F P
0 g
s
.53333 .23674 m .53284 .23272 L .45922 .23635 L p .313 0 0 r
F P
0 g
s
.45922 .23635 m .45508 .24096 L .53333 .23674 L p .313 0 0 r
F P
0 g
s
.45083 .24634 m .45508 .24096 L .38284 .2626 L p .061 0 0 r
F P
0 g
s
.38284 .2626 m .37434 .26835 L .45083 .24634 L p .061 0 0 r
F P
0 g
s
.60599 .24714 m .61103 .25044 L .68167 .2808 L p .382 0 0 r
F P
0 g
s
.61103 .25044 m .60599 .24714 L .53284 .23272 L p .442 0 0 r
F P
0 g
s
.77643 .33083 m .764 .32877 L .70016 .28708 L p 0 .363 .773 r
F P
0 g
s
.69083 .28379 m .70016 .28708 L .764 .32877 L p 0 .363 .786 r
F P
0 g
s
.69083 .28379 m .68167 .2808 L .61103 .25044 L p .425 0 0 r
F P
0 g
s
.53284 .23272 m .53333 .23674 L .61103 .25044 L p .442 0 0 r
F P
0 g
s
.78901 .33274 m .77643 .33083 L .70964 .29044 L p 0 .38 .775 r
F P
0 g
s
.70964 .29044 m .77643 .33083 L p .70111 .28763 L 0 .363 .773 r
F P
0 g
s
.70964 .29044 m .71927 .29362 L .78901 .33274 L p 0 .38 .775 r
F P
0 g
s
.70964 .29044 m .62681 .2632 L p .71815 .29325 L .419 0 0 r
F P
0 g
s
.71927 .29362 m .70964 .29044 L p .71815 .29325 L .419 0 0 r
F P
0 g
s
.70016 .28708 m .70964 .29044 L p .70111 .28763 L 0 .363 .773 r
F P
0 g
s
.53382 .2415 m .53333 .23674 L .45508 .24096 L p .342 0 0 r
F P
0 g
s
.45508 .24096 m .45083 .24634 L .53382 .2415 L p .342 0 0 r
F P
0 g
s
.44649 .25218 m .45083 .24634 L .37434 .26835 L p .091 0 0 r
F P
0 g
s
.37434 .26835 m .36566 .27454 L .44649 .25218 L p .091 0 0 r
F P
0 g
s
.61103 .25044 m .61618 .2544 L .69056 .28368 L p .425 0 0 r
F P
0 g
s
.61103 .25044 m .69056 .28368 L .69067 .28372 L .425 0 0 r
F
.69056 .28368 m .69083 .28379 L p .69067 .28372 L F P
0 g
s
.70016 .28708 m .69083 .28379 L .61618 .2544 L p .443 0 0 r
F P
0 g
s
.61618 .2544 m .62144 .25875 L .70016 .28708 L p .443 0 0 r
F P
0 g
s
.70964 .29044 m .70016 .28708 L .63065 .26206 L p .44 0 0 r
F P
0 g
s
.63065 .26206 m .62144 .25875 L p .62689 .26071 L .44 0 0 r
F P
0 g
s
.62689 .26071 m .70964 .29044 L .63065 .26206 L .44 0 0 r
F
.61618 .2544 m .61103 .25044 L .53333 .23674 L p .466 0 0 r
F P
0 g
s
.53333 .23674 m .53382 .2415 L .61618 .2544 L p .466 0 0 r
F P
0 g
s
.53433 .2467 m .53382 .2415 L .45083 .24634 L p .353 0 0 r
F P
0 g
s
.45083 .24634 m .44649 .25218 L .53433 .2467 L p .353 0 0 r
F P
0 g
s
.44206 .25815 m .44649 .25218 L .36566 .27454 L p .102 0 0 r
F P
0 g
s
.36566 .27454 m .35682 .28087 L .44206 .25815 L p .102 0 0 r
F P
0 g
s
.62144 .25875 m .61618 .2544 L .53382 .2415 L p .472 0 0 r
F P
0 g
s
.53382 .2415 m .53433 .2467 L .62144 .25875 L p .472 0 0 r
F P
0 g
s
.62144 .25875 m .62681 .2632 L .70964 .29044 L p .44 0 0 r
F P
0 g
s
.43754 .26392 m .44206 .25815 L .35682 .28087 L p .095 0 0 r
F P
0 g
s
.35682 .28087 m .34782 .287 L .43754 .26392 L p .095 0 0 r
F P
0 g
s
.62681 .2632 m .62144 .25875 L .53433 .2467 L p .466 0 0 r
F P
0 g
s
.53485 .25202 m .53433 .2467 L .44649 .25218 L p .351 0 0 r
F P
0 g
s
.44649 .25218 m .44206 .25815 L .53485 .25202 L p .351 0 0 r
F P
0 g
s
.53433 .2467 m .53485 .25202 L .62681 .2632 L p .466 0 0 r
F P
0 g
s
.62681 .2632 m .63227 .26744 L .71927 .29362 L p .419 0 0 r
F P
0 g
s
.63227 .26744 m .62681 .2632 L .53485 .25202 L p .446 0 0 r
F P
0 g
s
.53539 .25714 m .53485 .25202 L .44206 .25815 L p .336 0 0 r
F P
0 g
s
.44206 .25815 m .43754 .26392 L .53539 .25714 L p .336 0 0 r
F P
0 g
s
.53485 .25202 m .53539 .25714 L .63227 .26744 L p .446 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0001nooooo`go0000<ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`00000/ooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0003ooooooooo
o`1_oooooago0000<?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000/ooooo`00:Oooool00omEEEGoIVIVo`00000Aooooo`?o0000M?oo
oolUo`0002_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05oa0@4?oo
ooooooooooooool@4100;?ooool003_ooooo0_l0001doooooa3o00001_m@000Fo`0002Oooooo00?o
0000ooooooooool0:Oooool2o`0000Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00>?oo
ool3o`000003ooooool0003ooooo073ooooo1Ol00002o`400003o`000?m@003oD00000;oD0003Ol0
0006oeL00004o`000?mg003oM`00ogL0013o00008oooool00ol0003oooooooooo`0Xooooo`04o`00
0?ooooooooooo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00=_ooool2o`0007?o
oooo1Ol00002o`4000So00001_mG000Ao`0000GoM`003_l0000Pooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<oooool003?ooooo0ol0001booooo`Go00000_l1000Ao`0000OoFP00
4Ol00003ogL000_o00007_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo
000aooooo`;o0000L_ooool5o`000003o`400?l0003o000000?o00000_lG00000ol0003oFP00oeX0
0003oeX000oo00001omI00000ol0003oM`00ogL00002ogL000co000000?oM`00o`000?l000001Ol0
000Mooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool002kooooo0ol00000
0ooooooo0000ooooo`1_ooooo`Co000000?o0@00o`000?l000000ol00002oaL000Wo00003_mI000=
o`0000OoM`003ol0000Kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool0
02gooooo0_l00004ooooo`03o`000?oooooooooo06[ooooo1?l000000ol1003o0000o`000003o`00
00;o5`000ol000000olJ003o0000oeT00005oeT000oo00002?mF00000ol0003oLP00og800002og80
00Oo00001omg000;o`0001Sooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`oooo
o`00;Oooool00ol0003oooooo`00001^ooooo`Wo00000_lG0003o`000003oaX00?l0003o000000So
00003omF000>o`0000KoLP002?l00006ogL000Ko00005_ooool00ol0003oooooooooo`0]ooooo`?o
0000<Oooool002gooooo00Co0000oooooooooooo0000K?ooool7o`000003oaL00?l0003o000000;o
000000Co6P00o`000?l0003o00000_lH00000ol0003oEP00oeH00004oeH0013o00001_nX[M/00ol0
003oVYoHoiZOf002oiZOf0ko00000omb0007o`0000;oM`001Ol0000Dooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0;oooool002gooooo00Go0000ooooooooooooooooo`00001Yoooo
o`Ko000000Go5`00o`000?l0003o0000oaX00004o`0000;o60003?l00008okNceP03o`000?nX[M_o
Z:gK00WoZ:gK00?o0000oiZOf?nJWmP01OnJWmP2o`0000CoT:KT00?o0000ohRDfOmiUN800_miUN8C
o`0001;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`00;?ooool3o`00
00?ooooo00?o0000ooooooooool0I?ooool9o`000004oaX00?l0003o0000o`0000;o60001?l00002
olK9g004o`000?o2_=Co`[cDo`0000;o^<7Q0_l00009okNceP;o000000?oZ:gKo`000?l000002Ol0
0009oiZOf0Co00000on8U=T00ol0003oNIGRogVEhP02ogVEhP05o`000?mTU>[oI9CZofBDj_l00000
0om6Snh;o`0000oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`00;?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo1_l000000olJ003o0000o`00
0002o`0000;o60001?l00004olK9g003o`000?o2_=Co`[cD00;o`[cD00?o0000okNce_ng/mH02?ng
/mH2o`000003okFYcOl0003oZjC@00[oZjC@00?o0000oj2Jc_l000000_l00008oiZOf003o`000?n8
U=WoR9CI00?oR9CI00Co0000ogVEh_miUN;oNIGR0_l00002ofBDjP;o00000om6Snh01Ol0003o7h?Y
oan3jOl0003o073H00Ko00003Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02go
oooo000/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool6o`000004oaX0
0?l0003o0000o`0000;o60001?l00002olWGi@03o`000?o6bMcoa/WL00;oa/WL00?o0000ol:le?o2
_=@00_o2_=@2o`0000Oo]k?F0ol00003okFYc@03o`000?n[Y=3oZjC@00WoZjC@00?o0000oj2Jc_nP
V/h00_nPV/h2o`0000KoVYoH00?o0000oi:Bd?n8U=T01?n8U=T00ol0003oNIGRogVEhP02ogVEhP05
o`000?mTU>[oI9CZofBDj_l000000om6Snh2o`000004oan3jOl0003o0000o`1`f0Ko00002oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo000/ooooo`?o00001_ooool00ol0
003oooooooooo`1Looooo`So000000?o6000o`000?l000000_l000000oo9i^cobMOUolWGi@02olWG
i@03o`000?o6bMcoa/WL00;oa/WL00?o0000ol:le?o2_=@00_o2_=@01?l0003o_[7=okjacOl00004
okNceP;o00001oneZLd00ol0003oZjC@oj^Td008oj^Td003o`000?nPV/koX9[>00CoX9[>0_l00004
oiZOf004o`000?nBT]3oTY;@o`0000CoR9CI0_l00003ogVEhP;o00000_mTU>X2o`0000?oAXo^00?o
0000oan3jOl000002_l00008ooooo`03o`000?oooooooooo03;ooooo0_l0000]ooooo`00;?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Wooooo1_l000000olH003o0000o`000002
o`0000CobNK/1?o9enD01?l0003oa/WLolK9g?o6bM`2o`0000Co`[cD00?o0000okjacOnn/Ld00_nn
/Ld01?l0003o]k?FokNce_l00008okFYc@So00001?n[Y=000ol0003oX9[>oj2JcP06oj2JcPCo0000
1?nBT]000ol0003oR9CIohRDf@03ohRDf@03o`000?miUN;oNIGR00;oNIGR00Go0000ofBDj_mTU>[o
I9CZo`000002odJ?kP;o00000_mCQ><01?l0003o?7kUocaniOllO^D3obAgi0Go00001Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo000Aooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0E_ooool5o`000004oaP00?l0003o0000o`0000?oaO;_1?o9
i^`4olWGi@Goa/WL1Oo2_=@00ol0003o_[7=okjac@03okjac@;o00002?neZLd2o`000003ok>Qa_l0
003o[9g800Go[9g81Ol0000;oj2JcP03o`000?nBT]3oTY;@00?oTY;@00?o0000ohRDfOn8U=T00on8
U=T2o`0000?oNIGR00?o0000ofBDj_mTU>X00ol000000omVQmoo0000oe>4h`02oe>4h`04o`000?ll
O^Go?7kUocani@?o97OT0_l<Kml4o`0000Cooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Zooooo`004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Doooooa;o0000
0_o9enD5olK9g0Go`[cD00?o0000okjacOnn/Ld00onn/Ld00ol0003o^ZS7o`000006okFYc@;o0000
0oncXLH00ol0003o[9g8ojbMb008ojbMb003o`000?nTU/Oo000000;o00001onPV/h00ol0003oVY79
oi:Bd004oi:Bd0;o00001On8U=T01?l0003oNIGRogVEh_miUN82o`000003ogJ9fOl0003oIXOO00;o
IXOO00Go0000oe>4homCQ>?oDhCSo`000003ocani@?o97OT0_l<Kml2o`1Ve`Co000000?oooooo`00
0?ooool0=?ooool00ol0003oooooooooo`0Zooooo`002Oooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`03o`000?oooooooooo
057ooooo2?l00002omCTh`04o`000?oBf]kod][No`0000?ocloI00?o0000ol_4e?o;a=@00_l00004
olK9g0Go`[cD00?o0000okjacOnn/Ld00onn/Ld01Ol0003o^ZS7okZXaonjZ<Oo000000?o]JW=0_l0
0005ok>QaP03o`000?n/WLSo[9g800So[9g800?o0000ojBFaonTU/L00_nTU/L2o`0000CoX9[>00Go
0000oiZAbOnJTLWoVY79o`000005oi:Bd003o`000?n8U=WoR9CI00?oR9CI00Co0000ogVEh_l0003o
00000omfRMT01Ol0003oIXOOofJ7gomVQmoo000000?oDhCS00Go0000ocaniOllO^Go?7kUo`000002
obAgi004o`000?l<Kmoo0000o`1Ve`;o063?1?l0000eooooo`03o`000?oooooooooo02Wooooo000A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0C_ooool6o`0000;odngV00Co0000omCThooDi>?o0000
0_oBf]h01Ol0003ocloIolo?fOo?cmWo000000?oblCD00?o0000olNkc_l000000_o6bM`5ol:le003
o`000?nn/Lgo_[7=00?o_[7=00?o0000okZXaonjZ<L00_njZ<L01?l0003o]JW=okFYcOl00008ok>Q
aP03o`000?n/WLSo[9g800Oo[9g800?o0000ojBFaonTU/L01?nTU/L3o`000003oj2Jc_l0003oVY79
00?oVY7900?o0000oi:Bd?nBT]000onBT]000ol0003oR9CIohRDf@03ohRDf@04o`000?n2R]?oPX[C
o`0000?oMXWI00Go0000ofJ7gomVQmooIXOOo`000003oe>4h`05o`000?llO^Go?7kUocaniOl00000
0_lTMn@01_l0003o36oOo`000?l0I]Oo0000o`1Pc`Ko0000<oooool00ol0003oooooooooo`0Xoooo
o`004Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0C?ooool4o`000005om7eiol0003o
dngVom?]i_l000000_oDi><01?l0003od][Nom;Jg_l00003olo?f@05o`000?o;a=CoblCDol_4e?l0
00000oo7^lh2o`0000Co`[cD00?o0000okjacOnn/Ld00onn/Ld00ol0003o^ZS7okZXa`03okZXa`;o
00002_ncXLH00ol0003o[9g8ojbMb007ojbMb003o`000?nTU/OoY9K700OoY9K700?o0000oiZAbOnJ
TLT01?nJTLT2o`0000CoTY;@00Co0000ohRDfOn8U=WoR9CI0_l00003oh::d`05o`000?mfRMWoMXWI
ogJ9fOl000000omVQml01Ol0003oDhCSoe>4homCQ>?o000000?o?7kU00Go0000obAgi?lTMnCo0000
o`a_g`02o`000006o`1Veol0H<oo0000o`1LbOl0003o05c50ol0000aooooo`;o0000:Oooool0017o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`19ooooo`?o000000Coc?[Wo`000?oAmNOo00000_oCkNH0
1?l0003oe>CSomCThol00003om;JgP05o`000?o?cmWocloIolo?fOl000000_o;a=@00ol0003oak_>
olNkcP02olNkcP04o`000?o3//Wo0000o`0000;o`[cD1Onn/Ld00ol0003o^ZS7okZXa`03okZXa`03
o`000?ngX<7o000000Wo/j763?l00009ojBFa`03o`000?nOSl?oVY7900KoVY7900?o0000oi:Bd?nB
T]000_nBT]000ol0003oR9CIo`000002ohb;c@05o`000?n2R]?oPX[Coh::dol000000omfRMT01Ol0
003oIXOOofJ7gomVQmoo000000?oDhCS00Go0000ocaniOllO^Go?7kUo`000002obAgi0;o000000Oo
36oOo`000?l0I]Oo0000o`1Pcol0003o05c900;o05c500?o0676o`000?l00000;oooool2o`0002Wo
oooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o
00004?ooool00ol0003oooooooooo`16ooooo`?o00000_o<n^L00ol0003odOGWo`000002om?]iP05
o`000?oDi>?oe>CSomCThol000000_oBf]h01Ol0003ocloIolo?fOo?cmWo000000?oblCD00Go0000
olNkc_o7^lkoak_>o`000004ol>bb@03o`000?nn/Lgo_[7=00?o_[7=00?o0000okZXaonjZ<L00onj
Z<L01Ol0003o]j31okNP`OngX<7o000000Ko/j760_l000000onaV/3o0000ojbG`@08ojbG`@04o`00
0?nVT/7o0000o`0000KoY9K700Co0000oin?`onOSl?o00001_nJTLT00ol0003oTY;@oi:Bd002oi:B
d003o`000?n<RlgoS8_=00;oS8_=00Go0000oh::don2R]?oPX[Co`000003ogJ9f@05o`000?mVQmoo
IXOOofJ7gol000000omCQ><01Ol0003o?7kUocaniOllO^Go000000?o97OT00?o0000o`a_gol00000
0_l000002?l0H<oo0000o`000?l0G<Wo05c5o`000?l0HLKo0000<?ooool00ol0003oooooooooo`0V
ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooo
oooo013ooooo0_l00015ooooo`;o000000Koa_cUo`000?o<n^Oo0000om7eiol00003om?]iP04o`00
0?oDi>?oe>CSo`0000;od][N00Go0000olo?fOo?cmWocloIo`000003ol_4e003o`000?o7^lkoak_>
00;oak_>00?o0000ol>bbOo3//T00_o3//T2o`0000?o_[7=00?o0000okZXaonjZ<L00onjZ<L00ol0
003o]j31okNP`@02okNP`@04o`000?ncXLKo/j76ok>QaP?o00000onaV/000ol0003o[9O1ojbG`@07
ojbG`@04o`000?nVT/7oYY;1ojJB`@?o00000_nTU/L00ol0003oWho3oin?``02oin?``03o`000?nJ
TLWoVY7900CoVY7900Go0000oi:Bd?nBT]3oTY;@o`000005ohb;c@05o`000?n2R]?oPX[Coh::dol0
00000omfRMT01Ol0003oIXOOofJ7gomVQmoo000000?oDhCS00Go0000ocaniOllO^Go?7kUo`000003
obAgi0?o00000_l0I]L01_l0003o063?o`000?l0G<Wo0000o`1La@?o0000;_ooool00ol0003ooooo
ooooo`0Vooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo043ooooo0_l0
0002olKli@05o`000?o<n^Oo0000om7eiol000000ooCkNH01?l0003oe>CSomCThol00003om;JgP05
o`000?o?cmWocloIolo?fOl000000_o;a=@00ol0003oak_>olNkcP02olNkcP03o`000?o3//Wo`k;9
00;o`k;900Ko0000oknZaOnoZ/Go0000okjacOl00005okZXa`03o`000?ngX<7o]j3100?o]j3100Co
0000ok>Qa_ncXLKo00001_naV/000ol0003o[9O1ojbG`@07ojbG`@03o`000?nVT/7oYY;100CoYY;1
0ol00005oin?``03o`000?nJTLWoVY7900CoVY7900Go0000oi:Bd?l0003oTh_7o`000004ohb;c@03
o`000?n2R]?oPX[C00;oPX[C00Go0000ogJ9fOmfRMWoMXWIo`000003ofJ7g`05o`000?mCQ>?oDhCS
oe>4hol000000ollO^D7o`0000;o06KG1?l000001?l0G<Wo0000o`1LaOl0HLH2o`0002gooooo00?o
0000ooooooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l00000
1_nooNCo0000olKliOl0003oc?[Wo`0000;odOGW00Co0000om?]i_oCkNKo00000_oDi><01Ol0003o
d][Nom;Jg_oBf]ko000000?ocloI00Go0000ol_4e?o;a=CoblCDo`000003olNkcP03o`000?o3//Wo
`k;900?o`k;900Go0000oknZaOnoZ/Go_j[5o`000005okZXa`03o`000?ngX<7o]j3100Go]j3100?o
0000ok6J`?naV/001onaV/000ol0003o[9O1ojbG`@05ojbG`@03o`000?nVT/7oYY;100OoYY;100?o
0000oin?`onOSl<01?nOSl<00ol0003oVY79oiZAb@04oiZAb@05o`000?nCRlOoTh_7oi>;aol00000
1?n<Rld00ol0003oPX[Coh::d`02oh::d`04o`000?mfRMWoMXWIo`0000CoIXOO00Co0000oe>4homC
Q>?oDhCS1Ol00003obAgi0Co00000_l0I]L00ol0003o063?o`000002o`1Lb@;o000000?o0676o`00
0?l00000;?ooool00ol0003oooooooooo`0Tooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo03[ooooo0_l00002okomi005o`000?o6o>Go0000olcjiol000000_oAmNL01?l0
003odngVom?]i_l00003omCTh`04o`000?oBf]kod][No`0000?ocloI00Go0000ol_4e?o;a=CoblCD
o`000004olNkcP03o`000?o3//Wo`k;900;o`k;900?o0000oknZaOnoZ/D00_noZ/D2o`0000?o^ZS7
00?o0000okNP`OngX<401OngX<42o`0000Wo/I[000?o0000ojbG`On/Ul401On/Ul400ol0003oYY;1
ojJB`@07ojJB`@03o`000?nSSKkoWho300GoWho300?o0000oiZAbOnJTLT00onJTLT00ol0003oTh_7
oi>;a`02oi>;a`03o`000?n<RlgoS8_=00;oS8_=00Go0000oh::don2R]?oPX[Co`000003ogJ9f@03
o`000?mVQmooIXOO00;oIXOO1Ol00003ocani@04o`000?lTMnCo97OTobAgi0;o000000Ko36oOo`00
0?l0I]Oo06KGo`000?l0H<l2o`000005o`1LbOl0003o05c5o`000?l0HLH00_l0000Zooooo`;o0000
9Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0gooooo`;o00000ono
oN@01Ol0003oa_cUo`000?o<n^Oo000000;odOGW00Go0000om?]i_oCkNKodngVo`000002omCTh`04
o`000?oBf]kod][No`0000?ocloI00Go0000ol_4e?o;a=CoblCDo`000004olNkcP03o`000?o3//Wo
`k;900;o`k;900?o0000oknZaOnoZ/D00_noZ/D01_l0003o^j?1ok^S`Ol0003o^ZS7o`0000Oo]j31
00Co0000okBJ_OndV[go00001onaV/0:o`0000WoYY;100Co0000oj>=__nSSKko00001OnOSl<01ol0
003oVY79oiZAbOnJTLWo0000oiZ;`ol000001?nCRlL00ol0003oS8_=ohb;c@02ohb;c@05o`000?n2
R]?oPX[Coh::dol000000omfRMT00ol0003oIXOOo`000003o`0000?oDhCS00Go0000ocaniOllO^Go
?7kUo`000003obAgi0;o000000Co36oOo`000?l0I]Oo06KG0_l000002Ol0H<oo0000o`1LbOl0G<Wo
0000o`1LaOl0003o0676o`00000Yooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0dooooo`?o00000onooN@01Ol0003oa_cUo`000?o<n^Oo0000
00;odOGW00Go0000om?]i_oCkNKodngVo`000002omCTh`05o`000?oBf]kod][Nom;Jg_l000000oo?
cmT01Ol0003oblCDol_4e?o;a=Co000000Coak_>00?o0000ol>bbOo3//T00_o3//T00ol0003o_j[5
oknZa@02oknZa@05o`000?nkXl7o^j?1ok^S`Ol000001ongX<401Ol0003o]9ZmokBJ_OndV[go0000
00Co/I[00ol000000on`UK_o0000ojbC_006ojbC_004o`000?nXT;co0000o`0000KoYY;100Go0000
oj>=__nSSKkoXhfno`000005oin?``03o`000?nJTLWo000000?oVX_300Go0000oi>;aonCRlOoTh_7
o`000004ohb;c@03o`000?n2R]?oPX[C00;oPX[C00?o0000ogJ9fOl000000_l00004ofJ7g`05o`00
0?mCQ>?oDhCSoe>4hol000000ollO^D01Ol0003o97OTobAgi?lTMnCo000000;o36oO00Oo0000o`1V
eol0I]Oo06KGo`000?l0H<oo000000;o05c91_l0000Xooooo`03o`000?oooooooooo00Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`00:_oo
ool2o`0001Wooooo00?o0000ooooooooool0<Oooool2o`000003okSlhol0003o_ogT00;o_ogT00?o
0000olKliOl000000_o<n^L00ol0003odOGWo`000003om?]iP04o`000?oDi>?oe>CSo`0000?od][N
00Go0000olo?fOo?cmWocloIo`000003ol_4e003o`000?o7^lkoak_>00;oak_>00?o0000ol>bbOo3
//T00_o3//T00ol0003o_j[5oknZa@02oknZa@03o`000?nkXl7o^j?100;o^j?100?o0000okNP`Ong
X<401?ngX<400ol0003o]9ZmokBJ_@02okBJ_@03o`000?naV/3o/I[000;o00001?n`UK/00ol0003o
[9>lojbC_005ojbC_004o`000?nXT;coZ92lojR@_0?o00000_nVT/400ol0003oXhfnoj>=_P03oj>=
_P03o`000?nOSl?oWho300?oWho300?o0000oiZ;`onJRl<00_nJRl<00ol0003oTh_7oi>;a`02oi>;
a`03o`000?n<RlgoS8_=00;oS8_=00?o0000oh::don2R]<00ol00003ogJ9f@03o`000?mVQmooIXOO
00;oIXOO00Go0000oe>4homCQ>?oDhCSo`000002ocani@Wo00000ol0I]L01?l0003o063?o`000?l0
0002o`1Lb@Ko00009oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`05ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02kooooo0ol00002okSlh`?o_ogT00?o0000olKliOl000000_o<n^L00ol0003odOGWo`00
0003om?]iP05o`000?oDi>?oe>CSomCThol000000_oBf]h01Ol0003ocloIolo?fOo?cmWo000000?o
blCD00?o0000olNkc_o7^lh00oo7^lh00ol0003o`k;9ol>bb@02ol>bb@03o`000?noZ/Go_j[500;o
_j[500Oo0000ok^S`OnkXl7o^j?1o`000?nhWKgo000000Co]j3100?o0000okBJ_OndV[d01?ndV[d0
0ol0003o/9Fkok2E^`05ok2E^`03o`000?n/Tkco[9>l00Go[9>l00?o0000ojR@_?nXT;`01?nXT;`3
o`0000KoXhfn00?o0000oin?`onOSl<00_nOSl<00ol0003oVX_3oiZ;``03oiZ;``03o`000?nCRlOo
Th_700;oTh_700Co0000ohb;cOn<RlgoS8_=0ol00003oh::d`05o`000?mfRMWoMXWIogJ9fOl00000
0_mVQml8o`000003og27f_mVQmkoIXON00;oIXON00?oG8KRo`000?mLQ^802Ol00003o`1Lb@04o`00
0?l0G<Go0000o`1QaP;o00009_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`06ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02cooooo00?o0000ok7khol000000_nho><3okomi003o`000?o6o>Go000000;o
c?[W00Co0000om7eiooAmNOo00000ooCkNH01?l0003oe>CSomCThol00003om;JgP05o`000?o?cmWo
cloIolo?fOl000000oo;a=@00ol0003oak_>olNkcP02olNkcP03o`000?o3//Wo`k;900;o`k;900?o
0000oknZaOnoZ/D00_noZ/D00ol0003o^j?1ok^S`@02ok^S`@04o`000?nhWKgo^9fmo`0000;o]j31
00?o0000okBJ_OndV[d01OndV[d00ol0003o/9Fkok2E^`06ok2E^`03o`000?n/Tkco[9>l00Co[9>l
00?o0000ojR@_?nXT;`01_nXT;`00ol0003oXhfnoj>=_P05oj>=_P06o`000?nOSl?oWho3o`000?nN
Rkko00001OnJRl<00ol0003oTh_7oi>;a`02oi>;a`?o000000?oS8_=o`000?n2R]<01?n2R]<00ol0
003oMXWIogJ9f@03o`0000;oPXSA1?mjR=H4og27fPCoIXON00?oG8KRo`000?mLQ^801?mBQ^D00ol0
003oBHOXodV7j009o`000003o`1Qa_l0003ooooo02Cooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3
o`0001cooooo00?o0000ooooooooool0:_ooool00ol0003o/O_Sok7kh`02okSlh`?o_ogT00?o0000
olKliOl000000_o<n^L01?l0003odOGWom7eiol00003om?]iP04o`000?oDi>?oe>CSo`0000?od][N
00Go0000olo?fOo?cmWocloIo`000003ol_4e003o`000?o7^lkoak_>00;oak_>00?o0000ol>bbOo3
//T00oo3//T01Ol0003o_j[5oknZaOnoZ/Go000000Co^j?100Oo0000okRM_OnhWKgo^9fmo`000?ng
X<7o000000Oo]9Zm00?o0000ok:E^Ol000001on`UK/00ol0003o[9>lojbC_004ojbC_003o`000?nX
T;coZ92l00KoZ92l0_l00007oj>=_P03o`000?nOSl?o000000;oWX^n00?o0000oiZ;`onJRl<00onJ
Rl<5o`0000CoS8_=00?o0000oh::don2R]<00_n2R]<3o`000003ohV9c?n2R=7oPXSA00?oPXSA1?mj
R=H4og27fPCoIXON00?o0000oeb6h_mLQ^801?mBQ^D01?l0003oBHOXodV7j?l00003od:8jP03o`00
0?lmR^co?H[/00Go00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo02Sooooo00?o0000ok7khonann<00_nho><3okomi003o`000?o6o>Go000000;oc?[W
00Co0000om7eiooAmNOo00000ooCkNHCo`0000;oak_>00?o0000ol>bbOo3//T00_o3//T00ol0003o
_j[5oknZa@02oknZa@03o`000?nkXl7o^j?100;o^j?100?o0000okRM_OnhWKd00_nhWKd00ol0003o
]9ZmokBJ_@05okBJ_@04o`000?nbUKWo/YFio`0000Ko/9Fk2Ol00007ojR@_004o`000?nVS;[oYXbj
o`0000OoXhfn00?o0000oij;__nNRkh00_nNRkh00ol0003oVX_3oiZ;``03o`0000CoTh_700?o0000
ohb;cOn<Rld00_n<Rld01Ol0003oPX[Co`000?l0003oT8W800CoRHW<1?n2R=400ol0003oNXSFogZ8
eP02ogZ8eP?oL8OJ00Co0000ofJ7g_mVQmkoIXON0_l00002oeb6hPCoDXKU00Co0000odV7j?m9QnSo
00000om2R>X01?l0003o?H[/ocf:k?l00002oc^>kP;o00008_ooool3o`0000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool09_ooool00ol0003o/O_Sok7kh`02okSlh`?o_ogT00?o0000olKl
iOl000000_o<n^L01Ol0003odOGWom7eiooAmNOodngV00Co00000_o=amD01Ol0003ob/3Aol[0dOo:
`=7o000000?oakW=00Go0000olBbbOo4//Woa;;9o`000003ol6/a@?o00000oo3//T00ol0003o_j[5
oknZa@02oknZa@03o`000?nkXl7o^j?100;o^j?100?o0000okRM_OnhWKd00onhWKd2o`0000Go]9Zm
00Go0000ok:E^OnbUKWo/YFio`000003ok2E^`?o000000?o[i6ho`000?n/T;P01On/T;P01?l0003o
ZHfho`000?l00004ojR@_005o`000?nVS;[oYXbjojJ<^_l000001_nSSKh00ol0003oWX^noij;_P02
oij;_P?o00000onJRl<00ol0003oTh_7oi>;a`02oi>;a`04o`000?n<RlgoS8_=ohb;c@;o00001?n@
RLP3ohV9c003o`000?n2R=7oPXSA00;oPXSA00Go0000ogZ8e_mjR=KoNXSFo`000003og27fP04o`00
0?mVQmkoIXONofJ7gP;o00000_mLQ^84oe:6i@04o`000?m9QnSoBHOXo`0000?o@XSZ00Co0000ocf:
k?lmR^co00000olkS^h00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o/O_Sok7kh`02okSlh`?o_ogT
00?o0000olKliOo6o>D00oo<n^L5o`0000;ocloI00Co0000olg7eOo=amGo00000oo:`=401Ol0003o
akW=olNicOo7^Lgo000000?oa;;900?o0000ol6/aOo1[<D00oo1[<D01_l0003o_JK2o`000?l0003o
`k;9o`0000Co_j[500?o0000ok^S`OnkXl400_nkXl400ol0003o^9fmokRM_@02okRM_@04o`000?ne
V;[o]IRjo`0000?o]9Zm00?o0000ok:E^OnbUKT00onbUKT00ol0003o/9Fko`000004ojnA^003o`00
0?n/T;So[92h00Co[92h00Go0000ojV=^?nYSKSoZHfho`000003ojR@_003o`000?nVS;[oYXbj00;o
YXbj00?o0000oj>=__nSSKh00_nSSKh00ol0003oXXZko`000003o`000003oij;__l0003oVX_300Co
VX_300?o0000oi>;aonCRlL00_nCRlL01?l0003oS8_=o`000?nERL@5oi29b005o`000?n9RLcoRHW<
ohV9c?l000000on2R=400ol0003oNXSFogZ8eP02ogZ8eP04o`000?m`Qm[oL8OJo`0000CoIXON0_l0
00000omLQ^;o0000oe:6i@02oe:6i@05o`000?m9QnSoBHOXodV7j?l000000om2R>X01?l0003o?H[/
ocf:k?l00003oc^>kP03o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool000Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool00oooool3o`00027ooooo00?o0000ooooooooool08_ooool00ol0
003o/O_Sok7kh`02okSlh`?o_ogT00Co0000olKliOo6o>Goc?[W0ol00002om3Fg@05o`000?o?cmWo
cloIolo?fOl000000oo=amD01Ol0003ob/3Aol[0dOo:`=7o000000?oakW=00Go0000olBbbOo4//Wo
a;;9o`000004ol6/a@03o`000?nmY/;o_JK200;o_JK20_l00003oknZa@03o`000?nkXl7o^j?100?o
^j?100?o0000okRM_OnhWKd00_nhWKd01ol0003o]IRjokFH^_neV;[o0000okBJ_Ol000001_nbUKT0
0ol0003o[i6hojnA^004ojnA^003o`000?n/T;So[92h00Co[92h00?o0000ojV=^?nYSKP00_nYSKP3
o`0000KoYXbj00Go0000oj>=__nSSKko0000oj::^`02o`0000GoWX^n00?o0000oiZ;`onJRl<00_nJ
Rl<00ol0003oTh_7oi>;a`02oi>;a`;o00000onERL@5oi29b004o`000?n9RLcoRHW<o`0000CoPXSA
00Go0000ogZ8e_mjR=KoNXSFo`000003og27fP04o`000?mVQmkoIXONofJ7gP;o00000_mLQ^801Ol0
003oDXKUoe:6iOmBQ^Go000000?oBHOX00Go0000od:8j_m2R>[o@XSZo`000002ocf:k005o`000?lk
S^ko>hk^oc^>k_l000008oooool00ol0003oooooooooo`0Mooooo`001?l00002ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Oooooo`;o00000_nann<2okSlh`Co_ogT
0_o6o>D2o`000005om7LhOl0003od=KMom3FgOl000001?o?cmT01Ol0003ocLOEolg7eOo=amGo0000
00?ob/3A00Go0000olNicOo7^LgoakW=o`000003olBbb@03o`000?o1[<Go`Jc500;o`Jc500?o0000
okfV`_nmY/800_nmY/801_l0003o^j6oo`000?l0003o_j[5o`0000Co^j?100?o0000okRM_OnhWKd0
0_nhWKd00ol0003o]IRjokFH^P03okFH^P03o`000?nbUKWo/YFi00Go/YFi00?o0000ojnA^?n_TKP0
1On_TKP00ol0003o[92hojb@^003ojb@^003o`000?nYSKSoZHfh00CoZHfh00?o0000ojJ<^_nVS;X0
1OnVS;X4o`0000;oXXZk00?o0000oij;__nNRkh00onNRkh00ol0003oVX_3oiZ;``02oiZ;``05o`00
0?nCRlOo0000o`000?nJRL401?nERL@00ol0003oT8W8oi29b002oi29b005o`000?n9RLcoRHW<ohV9
c?l000000on2R=400ol0003oNXSFogZ8eP02ogZ8eP05o`000?m`Qm[oL8OJog27f_l000000omVQmh2
o`0000;oG8KR00Go0000oe:6iOmBQ^GoDXKUo`000003odV7j005o`000?m2R>[o@XSZod:8j_l00000
0_lmR^`01Ol0003o>hk^oc^>k_lkS^ko000002;ooooo00?o0000ooooooooool07Oooool000Kooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00Co0000ok7khona
nn?o/O_S0_nho><4okomi0;o00000ooAg>401Ol0003od=KMom3FgOo@e]go000000CocloI00Co0000
olg7eOo=amGo00000oo:`=401Ol0003oakW=olNicOo7^Lgo000000?oa;;900?o0000ol6/aOo1[<D0
0oo1[<D01Ol0003o_JK2okfV`_nmY/;o000000Co^j6o0_l00004ok^S`@03o`000?nhWKgo^9fm00;o
^9fm00?o0000okFH^_neV;X00oneV;X00ol0003o/YFiok:E^@04ok:E^@03o`000?n`TKOo000000Ko
[i6h00?o0000ojb@^?n/T;P00on/T;P00ol0003oZHfhojV=^004ojV=^003o`000?nXRkOo000000?o
YXbj1?l00005oj::^`03o`000?nNRkkoWX^n00;oWX^n00?o0000oiZ;`onJRl<00onJRl<00ol0003o
VXW1oiZ9`@02oiZ9`@CoUHW400?o0000oi29b?n@RLP00_n@RLP01?l0003oRHW<ohV9c?l00004oh:8
d@03o`000?mjR=KoNXSF00;oNXSF00Co0000og27f_m`Qm[o00001?mVQmh2o`000003oeb6h_l0003o
DXKU00;oDXKU00Go0000odV7j?m9QnSoBHOXo`000004od:8jP04o`000?lmR^co?H[/o`0000?o>hk^
00?o0000ooooooooool08?ooool2o`0001gooooo0006ooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003o
ooooooooo`0Tooooo`;o00007?ooool01?l0003o/O_Sok7khonann<2okSlh`Co_ogT00?o0000om3R
i?l000000ooAg>401Ol0003od=KMom3FgOo@e]go000000?ocloI00Go0000olg7eOo=amGocLOEo`00
0003ol[0d@05o`000?o7^LgoakW=olNicOl000000oo4//T00ol0003o`Jc5ol6/a@02ol6/a@03o`00
0?nmY/;o_JK200;o_JK200?o0000ok^Q_onkXKl00_nkXKl00ol0003o^9blo`000002ok^S`@03o`00
0?nhWKgo^9fm00;o^9fm00?o0000okFH^_neV;X00oneV;X00ol0003o/YBgo`000004ok:E^@04o`00
0?n`TKOo/96go`0000Ko[i6h00?o0000ojb@^?n/T;P00on/T;P00ol0003oZHfhojV=^004ojV=^003
o`000?nXRkOoZ8^g00?o00000onVS;X00ol0003oXXZkoj::^`03oj::^`03o`000?nNRkkoWX^n00?o
WX^n00Go0000oiZ;`onJRl?oVX_3o`000005oiZ9`@05o`000?nERLCoUHW4oiF9a?l000001?n@RLP0
1Ol0003oRHW<ohV9c?n9RLco000000?oPXSA00?o0000ogZ8e_mjR=H00_mjR=H01Ol0003oL8OJog27
f_m`Qm[o000000CoIXON0_l000000omLQ^;o0000oe:6i@02oe:6i@05o`000?m9QnSoBHOXodV7j?l0
00001?m2R>X01?l0003o?H[/ocf:k?l00003oc^>kP03o`000?oooooooooo01kooooo00?o0000oooo
ool000007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool2o`0002Oooooo00?o0000ooooooooool06?ooool01?l0
003o/O_Sok7khonann<2okSlh`04okomi?l0003o0000o`0000;od>;T00?o0000om7LhOoAg>400_oA
g>401?l0003od=KMom3FgOl00004olo?f@05o`000?o=amGocLOEolg7eOl000000_o:`=400ol0003o
akW=olNic@02olNic@05o`000?o4//Woa;;9olBbbOl000001?o1[<D00ol0003o_JK2okfV`P02okfV
`P03o`000?nkXKoo^j6o00;o^j6o00Ko0000okRL_?nhW;co0000ok^S`Ol00003okRM_@03o`000?ne
V;[o]IRj00?o]IRj00Go0000ok:D]onbU;Oo/YBgo`000002ok:E^@03o`000?n`TKOo/96g00;o/96g
00?o0000ojnA^?n_TKP00_n_TKP9o`0000GoZHfh0ol000000onXRkOo0000ojJ<^P02ojJ<^P03o`00
0?nUR[So000000GoXXZk00?o0000oij;__nNRkh00onNRkh00ol0003oVX_3o`000002oij9_@CoVXW1
00?o0000oiF9a?nERL@00_nERL@00ol0003oT8W8oi29b002oi29b004o`000?n9RLcoRHW<o`0000Co
PXSA00?o0000ogZ8e_mjR=H00_mjR=H01Ol0003oL8OJog27f_m`Qm[o000000?oIXON0_l00002oeb6
hP05o`000?mBQ^GoDXKUoe:6iOl000000om9QnP00ol0003o@XSZod:8jP02od:8jP04o`000?lmR^co
?H[/o`0000?o>hk^00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`04o`00
0?nann?o/O_Sok7kh`Co00000_o?i^L01?l0003od>;Tom3Ri?l00003om7Lh@05o`000?o@e]god=KM
om3FgOl000000oo?cmT01Ol0003ocLOEolg7eOo=amGo000000?ob/3A00Go0000olNicOo7^LgoakW=
o`000003olBbb@03o`000?o1[<Go`Jc500?o`Jc500Go0000okfV`_nmY/;o_JK2o`000004ok^Q_`03
o`000?nhW;co^9bl00;o^9bl00?o0000okRM_OnhWKd00_nhWKd00ol0003o]IRjokFH^P03okFH^P07
o`000?nbU;Oo/YBgok:D]ol0003o/YFio`000005ok2A]`03o`000?n_TKSo[i6h00;o000000?o[Xje
o`000?n/SKD01?n/SKD00ol0003oZhbeo`000004o`0000GoZ8^g00Co0000ojJ<^_nVS;[o00000_nU
R[P00ol0003oXXZkoj::^`02oj::^`03o`000?nNRkkoWX^n00CoWX^n00Go0000oij9_OnNRKgoWXVm
o`000004oiZ9`@05o`000?nERLCoUHW4oiF9a?l000001?n@RLP01Ol0003oRHW<ohV9c?n9RLco0000
00CoPXSA00Go0000ogZ8e_mjR=KoNXSFo`000003og27fP03o`000?mVQmkoIXON00;oIXON0_l00002
oeb6hP05o`000?mBQ^GoDXKUoe:6iOl000000om9QnP01Ol0003o@XSZod:8j_m2R>[o000000?o?H[/
00Go0000oc^>k_lkS^ko>hk^o`00000Qooooo`03o`000?oooooooooo01[ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool01ol0003o/O_Sok7khonann?o
0000olcZj_l000000oo?i^L01?l0003od>;Tom3Ri?l00004om7Lh@04o`000?o@e]god=KMo`0000Co
cloI00Go0000olg7eOo=amGocLOEo`000003ol[0d@05o`000?o7^LgoakW=olNicOl000000oo4//T0
0ol0003o`Jc5ol6/a@02ol6/a@03o`000?nmY/;o_JK200;o_JK200?o0000ok^Q_onkXKl00_nkXKl0
0ol0003o^9blokRL_002okRL_0;o00000_nhWKd00ol0003o]IRjokFH^P03okFH^P03o`000?nbU;Oo
/YBg00?o/YBg00?o0000ok2A]on`TKL01?n`TKL00ol0003o[i6ho`000003ojj>]@03o`000?n/SKGo
[8fe00?o[8fe1ol00006ojR;]`03o`000?nVS;[o000000;oYHZh00?o0000oj::^onRR[/00onRR[/0
0ol0003oWX^noij;_P02oij;_P03o`000?nNRKgoWXVm00;oWXVm00?o0000oiZ9`OnJRL400_nJRL40
0ol0003oUHW4oiF9a002oiF9a003o`000?n@RLSoT8W800;oT8W800Go0000ohV9c?n9RLcoRHW<o`00
0003oh:8d@03o`000?mjR=KoNXSF00;oNXSF00Go0000og27f_m`Qm[oL8OJo`000004ofJ7gP;o0000
00?oG8KRo`000?mBQ^D00_mBQ^D00ol0003oBHOXodV7j002odV7j005o`000?m2R>[o@XSZod:8j_l0
00000olmR^`01Ol0003o>hk^oc^>k_lkS^ko0000023ooooo00?o0000ooooooooool06_ooool002Oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`04o`000?nann?o0000o`00
00;oc>[Z00?o0000oloVioo?i^L00_o?i^L01?l0003od>;Tom3Ri?l00003om7Lh@05o`000?o@e]go
d=KMom3FgOl000000oo?cmT01Ol0003ocLOEolg7eOo=amGo000000?ob/3A00?o0000olNicOo7^Ld0
0_o7^Ld01Ol0003oa;;9olBbbOo4//Wo000000Co`Jc500?o0000okfV`_nmY/800_nmY/800ol0003o
^j6ook^Q_`02ok^Q_`05o`000?nhW;co^9blokRL_?l000000_nfV;T00ol0003o^9fmo`000005okFH
^P03o`000?nbU;Oo/YBg00?o/YBg00?o0000ok2A]on`TKL01On`TKL00ol0003o[Xjeojj>]@02ojj>
]@04o`000?n/SKGo[8feojb=]@?o00001On[S;D00ol0003oZ8^gojR;]`05ojR;]`03o`000?nUR[So
YHZh00;oYHZh00?o0000oj::^onRR[/00onRR[/01?l0003oWX^noij;__l00002oj69^PCoWXVm00?o
0000oiZ9`OnJRL400_nJRL401Ol0003oUHW4oiF9a?nERLCo000000CoT8W800Go0000ohV9c?n9RLco
RHW<o`000004oh:8d@03o`000?mjR=KoNXSF00;oNXSF00Go0000og27f_m`Qm[oL8OJo`000003ofJ7
gP;o00000_mLQ^801Ol0003oDXKUoe:6iOmBQ^Go000000?oBHOX00?o0000od:8j_m2R>X00_m2R>X0
1Ol0003o?H[/ocf:k?lmR^co000000?o>hk^00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Iooooo`009oooool2o`0002cooooo00?o0000ooooooooool04?ooool3o`000005olW/kOl0003o
c>[ZolcZj_l000000oo?i^L01Ol0003od>;Tom3Ri?o@h^Co000000?odMcQ00Co0000om3FgOo@e]go
00001?o?cmT01Ol0003ocLOEolg7eOo=amGo000000?ob/3A00Go0000olNicOo7^LgoakW=o`000003
olBbb@03o`000?o1[<Go`Jc500?o`Jc500Go0000okfV`_nmY/;o_JK2o`000004ok^Q_`03o`000?nh
W;co^9bl00;o^9bl00Co0000okJH^OnfV;Wo]YRi0_l00004okFH^P03o`000?nbU;Oo/YBg00?o/YBg
00?o0000ok2A]Ol000001On`TKL2o`0000Co[Xje1?l00002ojb=]@03o`000?n[S;GoZhbe00?oZhbe
0_l00006ojR;]`03o`000?nUR[SoYHZh00?oYHZh00?o0000oj::^onRR[/00_nRR[/00ol0003oWX^n
o`000003oj69^P05o`000?nNRKgoWXVmoij9_Ol000001?nJRL400ol0003oUHW4oiF9a002oiF9a003
o`000?n@RLSoT8W800;oT8W800Go0000ohV9c?n9RLcoRHW<o`000003oh:8d@03o`000?mjR=KoNXSF
00;oNXSF00Go0000og27f_m`Qm[oL8OJo`000004ofJ7gP;o00000_mLQ^801Ol0003oDXKUoe:6iOmB
Q^Go000000?oBHOX00?o0000od:8j_m2R>X00_m2R>X01Ol0003o?H[/ocf:k?lmR^co000000?o>hk^
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00kooooo00Go0000olW/kOo9k>gobNc]o`000002olcZjP03o`00
0?o?i^OocnKW00;ocnKW00Co0000om3Ri?o@h^Co00000ooAg>401Ol0003od=KMom3FgOo@e]go0000
00CocloI00Go0000olg7eOo=amGocLOEo`000003ol[0d@05o`000?o7^LgoakW=olNicOl000000oo4
//T00ol0003o`Jc5ol6/a@02ol6/a@03o`000?nmY/;o_JK200;o_JK200?o0000ok^Q_onkXKl00_nk
XKl00ol0003o^9blokRL_002okRL_007o`000?nfV;Wo]YRiokJH^Ol0003o/iBgo`000002okFH^P03
o`000?nbU;Oo/YBg00Co/YBg00?o0000ok2A]Ol000001?n`TKL00ol0003o[hjdo`000002ojj>]@Co
00001?n/SKD00ol0003oZhbeoj^<]@03oj^<]@03o`000?nYRkCo000000CoZ8^g00?o0000ojN:]_l0
00001OnUR[P00ol0003oXXZkoj::^`02oj::^`03o`000?nQRK[oXHVj00;oXHVj00?o0000oij9_OnN
RKd00_nNRKd00ol0003oVXW1oiZ9`@02oiZ9`@05o`000?nERLCoUHW4oiF9a?l000001?n@RLP01Ol0
003oRHW<ohV9c?n9RLco000000CoPXSA00?o0000ogZ8e_mjR=H00_mjR=H01Ol0003oL8OJog27f_m`
Qm[o000000CoIXON0_l000000omLQ^;o0000oe:6i@02oe:6i@03o`000?m9QnSoBHOX00;oBHOX00?o
0000od:8j_m2R>X00_m2R>X01Ol0003o?H[/ocf:k?lmR^co000000?o>hk^00?o0000ooooooooool0
7?ooool2o`0001[ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Ooo
ool01Ol0003obNc]olW/kOo9k>go000000;oc>[Z00Go0000oloVioo?i^OocnKWo`000003om3Ri005
o`000?oAg>7odMcQom7LhOl000000oo@e]d01Ol0003ocloIolo?fOo?cmWo000000?ocLOE00Go0000
ol[0dOo:`=7ob/3Ao`000004olNic@05o`000?o4//Woa;;9olBbbOl000001?o1[<D00ol0003o_JK2
okfV`P02okfV`P03o`000?nkXKoo^j6o00;o^j6o00Go0000okRL_?nhW;co^9blo`000004okJH^@06
o`000?ncU;Oo/iBgo`000?neV;[o00001OnbU;L01Ol0003o/96eok2A]On`TKGo000000;o/96g00?o
0000ojn>]?n_S[@00ol00003ojj>]@03o`000?n/SKGo[8fe00;o[8fe00?o0000oj^<]On[S;D00on[
S;D01?l0003oZH^dojV;]?l00003ojR;]`04o`000?nWR[KoYhZfo`0000CoYHZh00Go0000oj::^onR
R[_oXXZko`000006oj69^P05o`000?nNRKgoWXVmoij9_Ol000001?nJRL400ol0003oUHW4oiF9a002
oiF9a003o`000?n@RLSoT8W800;oT8W800Go0000ohV9c?n9RLcoRHW<o`000003oh:8d@03o`000?mj
R=KoNXSF00;oNXSF00Go0000og27f_m`Qm[oL8OJo`000004ofJ7gP05o`000?mLQ^;o0000oeb6h_l0
00000omBQ^D00ol0003oBHOXodV7j002odV7j003o`000?m2R>[o@XSZ00;o@XSZ00Go0000ocf:k?lm
R^co?H[/o`000003oc^>kP03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool002Oo
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`05o`000?o9k>gobNc]olW/
kOl000000_o<j^X00ol0003ocnKWoloVi`02oloVi`04o`000?o@h^Cod>;To`0000CodMcQ00Co0000
om3FgOo@e]go00001?o?cmT01Ol0003ocLOEolg7eOo=amGo000000?ob/3A00Go0000olNicOo7^Lgo
akW=o`000003olBbb@03o`000?o1[<Go`Jc500?o`Jc500Go0000okfV`_nmY/;o_JK2o`000004ok^Q
_`03o`000?nhW;co^9bl00;o^9bl00Go0000okJH^OnfV;Wo]YRio`000004ok>D]`03o`000?nbU;Oo
/YBg00?o/YBg00?o0000ok2A]On`TKD00_n`TKD00ol0003o/96go`000003o`000003ojn>]?l0003o
[Xje00?o[Xje00?o0000ojb=]On/SKD00_n/SKD00ol0003oZhbeoj^<]@02oj^<]@03o`000?nYRkCo
ZH^d00;oZH^d00Co0000ojR;]onXRkOo00000_nWR[H00ol0003oYHZhojF:^003ojF:^003o`000?nR
R[_o000000;oY8Vh1OnQRKX00ol0003oWXVmoij9_@02oij9_@05o`000?nJRL7oVXW1oiZ9`Ol00000
1?nERL@00ol0003oT8W8oi29b002oi29b005o`000?n9RLcoRHW<ohV9c?l000001?n2R=400ol0003o
NXSFogZ8eP02ogZ8eP05o`000?m`Qm[oL8OJog27f_l000001?mVQmh2o`0000;oG8KR00Go0000oe:6
iOmBQ^GoDXKUo`000004odV7j003o`000?m2R>[o@XSZ00;o@XSZ00Go0000ocf:k?lmR^co?H[/o`00
0003oc^>kP03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool002Oooooo0_l0000`
ooooo`03o`000?oooooooooo00[ooooo00Co0000olW/kOo9k>go00000oo<j^X01Ol0003ocnKWoloV
ioo?i^Oo000000?od>;T00Go0000om7LhOoAg>7odMcQo`000003om3Fg@05o`000?o?cmWocloIolo?
fOl000001?o=amD01?l0003ob/3Aol[0dOl00004olNic@05o`000?o4//Woa;;9olBbbOl000001?o1
[<D00ol0003o_JK2okfV`P02okfV`P03o`000?nkXKoo^j6o00;o^j6o00?o0000okRL_?nhW;`00_nh
W;`01Ol0003o]YRiokJH^OnfV;Wo000000Co/iBg00?o/I6fo`000?nbU;L00onbU;L00ol0003o/96e
ok2A]@02ok2A]@?o00001?n_S[@01?l0003o[Xjeojj>]On^S[D8o`0000?oZhbe00?o0000ojV;]?nY
Rk@00onYRk@2o`0000CoYhZf00?o0000ojF:^?nUR[P00onUR[P01Ol0003oY8VhojB9^?nTRKSo0000
00GoXHVj00Go0000oij9_OnNRKgoWXVmo`000004oiZ9`@03o`000?nERLCoUHW400;oUHW400?o0000
oi29b?n@RLP00_n@RLP01Ol0003oRHW<ohV9c?n9RLco000000?oPXSA00Co0000ogZ8e_mjR=KoNXSF
9_l0000Nooooo`03o`000?oooooooooo01Kooooo000Vooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool01Ol0003obNc]olW/kOo9k>go000000;oc>[Z00?o0000oloVioo?i^L0
0_o?i^L01?l0003od>;Tom3Ri?l00004om7Lh@04o`000?o@e]god=KMo`0000CocloI00Go0000olg7
eOo=amGocLOEo`000003ol[0d@03o`000?o7^LgoakW=00;oakW=00Go0000olBbbOo4//Woa;;9o`00
0004ol6/a@03o`000?nmY/;o_JK200;o_JK200?o0000ok^Q_onkXKl00_nkXKl01Ol0003o^9blokRL
_?nhW;co000000Co]YRi00?o0000ok>D]oncU;L00_ncU;L2ok6A]P04o`000?nbU;Oo/YBgo`0000?o
/96e0_l000000on`TKGo0000ojn>]005ojn>]0?o000000?o[Hbco`000?n/Rk<00on/Rk<00ol0003o
Zh^co`000003o`0000KoZH^d00?o0000ojN:]_nWR[H00onWR[H00ol0003oYHZhojF:^002ojF:^0Go
Y8Vh00?o0000oj69^_nQRKX00_nQRKX01Ol0003oWXVmoij9_OnNRKgo000000CoVXW100?o0000oiF9
a?nERL@00_nERL@00ol0003oT8W8oi29b002oi29b005o`000?n9RLcoRHW<ohV9c?l000000_n2R=45
o`0000;oUI3<1?nAT]05ohjDe0;oRYKI00?o0000ohZFfOn6V=d00on6V=d5oh>KhPGoP9kV1?mmX^X4
og^VkP;o00007_ooool00ol0003oooooooooo`0Eooooo`009_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00Oooooo00Co0000olW/kOo9k>go00000oo<j^X01Ol0003ocnKWoloVioo?
i^Oo000000?od>;T00Go0000om7LhOoAg>7odMcQo`000003om3Fg@05o`000?o?cmWocloIolo?fOl0
00001?o=amD01Ol0003ob/3Aol[0dOo:`=7o000000?oakW=00Go0000olBbbOo4//Woa;;9o`000005
ol6/a@05o`000?nmY/;o_JK2okfV`_l000001?nkXKl00ol0003o^9blokRL_002okRL_003o`000?nf
V;Wo]YRi00;o]YRi00Go0000ok>D]oncU;Oo/iBgo`000003ok6A]P03o`000?nbU;Oo000000?o0000
0_n`TKD00ol0003o[hjco`000005ojn>]005o`000?n]S;?o[Hbcojf</ol000001?n/Rk<00ol0003o
Zh^coj^;/`02oj^;/`03o`000?nYRkCoZH^d00CoZH^d00?o0000ojN:]_nWR[H00onWR[H01_l0003o
YHZhojF:^?nUR[So0000ojJ9]PCoY8Vh00?o0000oj69^_nQRKX00_nQRKX00ol0003oWXVmoij9_@02
oij9_@03o`000?nJRL7oVXW100;oVXW100?o0000oiF9a?nERL@00_nERL@01?l0003oT8W8oi29b?n@
RLP7o`0000;oV8o81OnET<`00ol0003oTI;@oi6Bd002oi6Bd0CoSYCD00Go0000ohZFfOn:U]Wo0000
ohZFf@04ohJHg@GoPi_R1On0W^H4ogfRjPCoNjK^00?o0000ooooooooool07?ooool2o`0001Kooooo
000Vooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool01Ol0003obNc]olW/
kOo9k>go000000;oc>[Z00?o0000oloVioo?i^L00_o?i^L01?l0003od>;Tom3Ri?l00004om7Lh@04
o`000?o@e]god=KMo`0000CocloI00?o0000olg7eOo=amD00_o=amD@o`000003ol6/aOl0003o_JK2
00?o_JK200?o0000ok^Q_onkXKl00_nkXKl00ol0003o^9blokRL_002okRL_005o`000?nfV;Wo]YRi
okJH^Ol000001?ncU;L01?l0003o/I6fok6A]_naTKH3o`0000Go/96e00?o0000ojn>/ol000001?n_
S[@2o`0000?o[Hbc00?o0000ojb;/on/Rk<00_n/Rk<00ol0003oZh^coj^;/`02oj^;/`03o`000?nY
RkCoZH^d00?oZH^d00?o0000ojV9]?l000001OnWR[H00ol0003oYHZho`000002ojJ9]P05o`000?nT
RKSoY8VhojB9^?l000001OnQRKX01Ol0003oWXVmoij9_OnNRKgo000000CoVXW100?o0000oiF9a?nE
RL@00_nERL@01Ol0003oT8W8o`000?l0003oWXg200CoVhk51?nHSlP00ol0003oUI3<oiF@c003oiF@
c0CoTI;@1On>U=@2ohZFf@03o`000?n:U]Wo000000?oQYSM00?o0000oh>Kh_n3Vn800_n3Vn800ol0
003oP9kVoh2NiP02oh2NiP05o`000?mmX^[oOJ;ZogfRj_l000001?mkY^h00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?ooool00ol0003oooooooooo`04oooo
o`04o`000?o9k>gobNc]o`0000?oc>[Z00Go0000oloVioo?i^OocnKWo`000003om3Ri005o`000?oA
g>7odMcQom7LhOl000000oo@e]d00ol0003ocloIolo?f@02olo?f@03o`000?o=amGo000000?o0000
0_nl[<X00ol0003o^ZO6okZWaP02okZWaP05o`000?nhXl?o^:?3okRS`ol000000ongWl44o`0000;o
_JK200?o0000ok^Q_onkXKl00_nkXKl01Ol0003o^9blokRL_?nhW;co000000Co]YRi00?o0000ok>D
]oncU;L00_ncU;L4o`000003ok6A]_n`SkCo000000Co/96e00Go0000ojn>/on_S[?o[hjco`000002
ojn>]003o`000?n]S;;o000000?o[Hbc00?o0000ojb;/on/Rk<00_n/Rk<00ol0003oZh^coj^;/`02
oj^;/`;o00001?nYRk@00ol0003oZHVdo`000006ojN:]P05o`000?nVRKKoYXVfojJ9]_l000001?nT
RKP00ol0003oXHVjoj69^P02oj69^P03o`000?nNRKgoWXVm00;oWXVm00Go0000oiZ9`OnJRL7oVXW1
o`000003oiF9a0?o00000onNSL801Ol0003oVhk5oi^>aOnKS/Go000000CoV8o81OnET<`01Ol0003o
TI;@oi6Bd?nAT]3o000000CoSYCD00?o0000ohZFfOn:U]T00_l00003ohJHg@03o`000?n3Vn;oPi_R
00;oPi_R00?o0000oh2Ni_n0W^H00_n0W^H00ol0003oOJ;ZogfRjP02ogfRjPCoNjK^00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00;ooooo00Go0000olW/kOo9k>gobNc]o`000002olcZjP03o`000?o?i^OocnKW
00;ocnKW00Go0000om3Ri?o@h^Cod>;To`000003om7Lh@06o`000?o@e]god=KMom3FgOl0003ocloI
1Ol00002okfacP05o`000?nl[<[o_:c:okb/b_l000001?njYlH01Ol0003o^:?3okRS`onhXl?o0000
00Co]io100?o0000okFL__neW;h01Ol000000onkXKoo0000okRL_003okRL_003o`000?nfV;Wo]YRi
00;o]YRi00?o0000ok>D]oncU;L00ol00004ok6A]P;o/8nd00Co0000ok2A]On`TKGo00001?n_S[<0
0ol0003o[hjdo`000003ojf</P05o`000?n]S;?o[Hbcojf</ol000000on/Rk<01Ol0003oZh^coj^;
/on[Rk?o000000;oZhZc00Co0000ojV;]?nYRkCo00000onYRK@00ol0003oYhZfojN:]P03ojN:]PGo
YXVf00Go0000ojB9^?nTRKSoY8Vho`000005oj69^P05o`000?nNRKgoWXVmoij9_Ol000000onJRL44
o`0000;oX8bo1OnNSL84oi^>a@CoV8o800?o0000oiF@c?nET<`00_nET<`00ol0003oTI;@oi6Bd002
oi6Bd0CoSYCD00Co0000ohZFfOn:U]WoRYKI0_l00003ohJHg@03o`000?n3Vn;oPi_R00;oPi_R00?o
0000oh2Ni_n0W^H00_n0W^H01Ol0003oOJ;ZogfRj_mmX^[o000000?oNjK^00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Booooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0=_ooool01?l0003oooooooooool00003olW/k@05o`000?o<j^[oc>[ZolcZ
j_l000000oo?i^L01Ol0003od>;Tom3Ri?o@h^Co000000CodMcQ1_l00002okjfdP03o`000?nm/Lko
_K7>00;o_K7>00Go0000okb/b_nl[<[o_:c:o`000004okZWaP05o`000?nhXl?o^:?3okRS`ol00000
1?ngWl401?l0003o]IbnokFL__neW;h4okBH^`Co00000_nhW;`00ol0003o]YRiokJH^@02okJH^@?o
000000?o/iBgo`000?naTKH00onaTKH01ol0003o/8ndok2?]?n`SkCo0000ok2A]Ol000001On_S[<0
0ol0003o[Hbbojf</P02ojf</P05o`000?n]S;?o[Hbcojf</ol000000on/Rk<01Ol0003oZh^coj^;
/on[Rk?o000000?oZhZc00?o0000ojV;]?l000000onYRK@00ol0003oYhZfojN:]P02ojN:]P03o`00
0?nXRKCoYXVf00?oYXVf00?o0000ojB9^?nTRKP00_nTRKP00ol0003oXHVjoj69^P02oj69^P06o`00
0?nNRKgoWXVmoij9_Ol0003oVXW10_l000000onRS;coX8booj2<_`03oj2<_`03o`000?nNSL;oWXg2
00;oWXg200Go0000oi^>aOnKS/GoVhk5o`000003oiR?b003o`000?nET<coUI3<00?oUI3<00Go0000
oi6Bd?nAT]3oTI;@o`000004ohjDe005o`000?n:U]WoRYKIohZFfOl000000on6V=d00ol0003oPi_R
oh>KhP02oh>KhP03o`000?n0W^KoP9kV00;oP9kV00Go0000ogfRj_mmX^[oOJ;Zo`000004og^VkP03
o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool001_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo0ol00003olW/k@04o`000?o<j^[oc>[Zo`00
00CocnKW00Ko0000om3Ri?o@h^Cod>;To`000?oAg>44o`0000;o_k_F00?o0000okjfd_nn]]800_nn
]]800ol0003o_K7>okfacP02okfacP05o`000?nl[<[o_:c:okb/b_l000001?njYlH01Ol0003o^:?3
okRS`onhXl?o000000Co]io100Co0000okFL__neW;ko]Ibn1OndV;/3ok:F^@?o000000?o]YRio`00
0?l000000_l00003ok>D]`03o`000?naTKKo/I6f00;o/I6f00?o0000ok2?]?n`Sk@00_n`Sk@00ol0
003o[hjcojn>/`04ojn>/`03o`000?n]S;;o[Hbb00;o[Hbb00Go0000ojf</on]S;?o[Hbco`000003
ojb;/`05o`000?n[Rk?oZh^coj^;/ol000001?n[R[<00ol0003oZHVdojV9]003ojV9]004o`000?nW
R[KoYhZfo`0000;oZ8Vd00?o0000ojJ9]_nVRKH00_nVRKH01Ol0003oY8VhojB9^?nTRKSo000000Co
XHVj00?o0000oij9_OnNRKd00ol00003oj:<_003o`000?nPS;ooX8bo00?oX8bo1?nNSL801Ol0003o
Vhk5oi^>aOnKS/Go000000CoV8o800?o0000oiF@c?nET<`00_nET<`01Ol0003oTI;@oi6Bd?nAT]3o
000000CoSYCD00Go0000ohZFfOn:U]WoRYKIo`000004ohJHg@05o`000?n3Vn;oPi_Roh>Kh_l00000
1?n0W^H00ol0003oOJ;ZogfRjP02ogfRjP05o`000?mkY^koNjK^og^Vk_l000008?ooool00ol0003o
ooooooooo`07ooooo`Co000000?o410@ooooooooool00oooool001_ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`?o0000>Oooool01Ol0003obNc]olW/kOo9k>go000000?oc>[Z00Go0000oloV
ioo?i^OocnKWo`000002om3Ri0Co00000_o0`=X01Ol0003o_k_Foknke_no^mKo000000Co_[KB00?o
0000okfac_nm/Lh00_nm/Lh01Ol0003o_:c:okb/b_nl[<[o000000Co^ZO600Go0000okRS`onhXl?o
^:?3o`000004okNO`@04o`000?neW;ko]IbnokFL_PGo]9Rk1?nbU[T6o`0000Co/iBg00?o0000ok6A
]_naTKH00_naTKH00ol0003o/8ndok2?]002ok2?]003o`000?n_S[?o[hjc00?o[hjc00?o0000ojj<
/_l000001?n]S;800ol0003o[Hbco`000006o`0000;oZh^c00?o0000oj^:/on[R[<00_n[R[<00ol0
003oZHVdojV9]003ojV9]003o`000?nWR[Ko000000?oZ8Vd00?o0000ojJ9]_nVRKH00_nVRKH00ol0
003oY8VhojB9^002ojB9^004o`000?nQRK[oXHVjoj69^P?o00000_nTRkX5oj:<_0GoX8bo00Go0000
oij=`_nNSL;oWXg2o`000004oi^>a@05o`000?nHSlSoV8o8oiR?b?l000001?nET<`00ol0003oTI;@
oi6Bd002oi6Bd005o`000?n>U=CoSYCDohjDe?l000001?n:U]T01Ol0003oQYSMohJHgOn6V=go0000
00CoPi_R00?o0000oh2Ni_n0W^H00_n0W^H01Ol0003oOJ;ZogfRj_mmX^[o000000CoNjK^00?o0000
ooooooooool07?ooool3o`0000[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo03Wooooo00Co0000olW/kOo9k>go00000oo<
j^X00ol0003ocnKWoloVi`02oloVi`?o000000?o`<GNo`000?o0`=X00oo0`=X01Ol0003o_k_Foknk
e_no^mKo000000Co_[KB00?o0000okfac_nm/Lh00_nm/Lh01?l0003o_:c:okb/b_l00004okZWaP05
o`000?nhXl?o^:?3okRS`ol000001OngWl401Ol0003o]IbnokFL__neW;ko000000Co]9Rk00Co/YJi
o`000?l0003o00001OnaTkL2o`0000?o/iBg00Go0000ok6A]_naTKKo/I6fo`000005ok2?]0;o0000
1?n_S[<00ol0003o[Xbbo`000004ojf</P;o000000?o[8Zao`000?n/R[400_n/R[401?l0003o[8Za
o`000?l00004oj^:/`03o`000?nZRK;o000000GoZHVd00?o0000ojR9]?nXRK@00onXRK@01Ol0003o
YXVfojJ9]_nVRKKo000000CoY8Vh00Go0000oj69^_nQRK[o0000ojJ;^004ojB;^P03o`000?nRS;co
XXbl00;oXXbl00?o0000oj2<_onPS;l00_nPS;l00ol0003oWXg2oij=`P02oij=`P05o`000?nKS/Go
Vhk5oi^>aOl000000onHSlP00ol0003oUI3<oiF@c002oiF@c003o`000?nAT]3oTI;@00;oTI;@00?o
0000ohjDe?n>U=@00_n>U=@01?l0003oRYKIohZFfOn:U]T2o`0000?oQYSM00Go0000oh>Kh_n3Vn;o
Pi_Ro`000004oh2NiP03o`000?mmX^[oOJ;Z00;oOJ;Z00Go0000og^Vk_mkY^koNjK^o`00000Poooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo03Sooooo00Go0000olW/kOo9k>gobNc]o`000003
olcZjP03o`000?o?i^Oo000000;o00001?o0aMh00ol0003o`<3Jol30fP02ol30fP05o`000?no^mKo
_k_Foknke_l000001?nn]]801Ol0003o_K7>okfac_nm/Lko000000?o_:c:00?o0000okZWa_njYlH0
0_njYlH01Ol0003o^:?3okRS`onhXl?o000000Co]io100Go0000okFL__neW;ko]Ibno`000003okBH
^`?o00000onbU[T5ok6C]`;o/96f0ol00004ok6A]P03o`000?n`SkCo/8nd00;o/8nd00Co0000ojj=
/on^SK?o00000_n_S[<01Ol0003o[Xbbojj</_n^S;;o000000?o[Hbb00Co0000ojb:/On/R[7o0000
0on/R[400ol0003o[8Zaojb:/@02o`0000?oZhZc00Co0000ojZ9/_nZRK;o00001?nYRK@00ol0003o
Z8VdojR9]003ojR9]003o`000?nVRKKoYXVf00;oYXVf00Oo0000ojB9^?nTRKSoY8Vho`000?nQRK[o
000000;oYX^h00?o0000ojB;^_nTRkX00_nTRkX4oj:<_003o`000?nPS;ooX8bo00;oX8bo00?o0000
oij=`_nNSL800_nNSL801Ol0003oVhk5oi^>aOnKS/Go000000?oV8o800?o0000oiF@c?nET<`00onE
T<`01Ol0003oTI;@oi6Bd?nAT]3o000000CoSYCD00Oo0000ohZFfOn:U]WoRYKIo`000?n6V=go0000
00;oQYSM00?o0000oh>Kh_n3Vn800_n3Vn800ol0003oP9kVoh2NiP02oh2NiP05o`000?mmX^[oOJ;Z
ogfRj_l000001?mkY^h00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo03Sooooo00Co0000olW/kOo9k>go00000_o<j^X4o`0000;o_l[R00?o0000ol35g_o0aMh00_o0
aMh00ol0003o`<3Jol30fP02ol30fP05o`000?no^mKo_k_Foknke_l000000onn]]800ol0003o_K7>
okfacP02okfacP05o`000?nl[<[o_:c:okb/b_l000001?njYlH01Ol0003o^:?3okRS`onhXl?o0000
00Co]io100Co0000okFL__neW;ko]Ibn1?l000000ondV;_o0000ok:F^@03ok:F^@03o`000?naTkOo
/I>g00;o/I>g1?n`TKH2o`0000?o/I6f00?o0000ok2?]?n`Sk@00_n`Sk@01ol0003o[Xfcojj=/on^
SK?o0000ojn>/ol000000on^S;800ol0003o[Hbbojf</P02o`0000;o[8Za00Go0000ojb:/On/R[7o
[8Zao`000002ojb:/@03o`000?n[RK7o000000;oZhZc00Co0000ojZ9/_nZRK;o00000onYRK@00ol0
003oZHVco`000004ojR9]003o`000?nVRKKoYXVf00;oYXVf00Co0000ojB9^?nTRKSoY8Vh0_l00004
ojJ;^0CoY8^j00Go0000oj:<_?nRS;coXXblo`000005oj2<_`05o`000?nNSL;oWXg2oij=`_l00000
1?nKS/D01Ol0003oV8o8oiR?b?nHSlSo000000CoUI3<00?o0000oi6Bd?nAT]000_nAT]001Ol0003o
SYCDohjDe?n>U=Co000000CoRYKI0_l00002ohJHg@03o`000?n3Vn;oPi_R00;oPi_R00?o0000oh2N
i_n0W^H00_n0W^H00ol0003oOJ;ZogfRjP02ogfRjP05o`000?mkY^koNjK^og^Vk_l000008?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2o`0003Sooooo00Co0000olW/kOo9k>gobNc]0ol000000onnc^Ko0000oko:
hP03oko:hP03o`000?o0aMko`<GN00;o`<GN00?o0000ol30f_o0`=X00_o0`=X01?l0003o_k_Foknk
e_l00004okjfdP03o`000?nm/Lko_K7>00;o_K7>00Go0000okb/b_nl[<[o_:c:o`000004okZWaP05
o`000?nhXl?o^:?3okRS`ol000001?ngWl400ol0003o]Ibno`000002o`0000Co]9Rk00?o0000ok:F
^OnbU[T00_nbU[T00ol0003o/I>gok6C]`02ok6C]`Co/96f0_n_Sk@01?l0003o/I6fok6A]_l00004
ok2?]003o`000?n^SK?o[Xfc00;o[Xfc00?o0000ojj</_n^S;800_n^S;800ol0003o[Hbbo`000002
ojf:/@03o`000?n/R[7o000000?o[8Za00Co0000ojb:/On/R[7o00000_n[RK42o`0000CoZXVb00?o
0000ojV9]?l000000_nYRK<00ol0003oZ8VdojR9]003ojR9]006o`000?nVRKKoYXVfojJ9]_l0003o
Y8Vh0_l000000onWR[KoYX^hojJ;^003ojJ;^005o`000?nTRk[oY8^jojB;^_l000001?nRS;`00ol0
003oX8booj2<_`02oj2<_`05o`000?nNSL;oWXg2oij=`_l000001?nKS/D01Ol0003oV8o8oiR?b?nH
SlSo000000CoUI3<00?o0000oi6Bd?nAT]000_nAT]001Ol0003oSYCDohjDe?n>U=Co000000CoRYKI
00?o0000ohJHgOl000000_n6V=d01Ol0003oPi_Roh>Kh_n3Vn;o000000CoP9kV00?o0000ogfRj_mm
X^X00_mmX^X01Ol0003oNjK^og^Vk_mkY^ko0000027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool0=oooool4o`0000Co_/kV00?o0000oko:h_nob^800_nob^800ol0003o`<GNol35gP02ol35
gP05o`000?o0`=[o`<3Jol30f_l000000ono^mH00ol0003o_[KBokjfdP02okjfdP03o`000?nm/Lko
_K7>00;o_K7>00Go0000okb/b_nl[<[o_:c:o`000004okZWaP05o`000?nhXl?o^:?3okRS`ol00000
0ongWl43o`0000;o]Ibn00?o0000okBH^ondV;/00_ndV;/00ol0003o/YJiok:F^@02ok:F^@03o`00
0?naTkOo/I>g00;o/I>g00Co0000ok2A]_n`TKKo/96f0on_Sk@2o`0000Go/8nd00?o0000ojj=/on^
SK<00_n^SK<00ol0003o[Xbbojj</P03ojj</P05o`000?n]R[7o[HZaojf:/Ol000000_n/R[401?l0
003o[8Zaojb:/Ol00002ojb:/@05o`000?n[RK7oZhVaoj^9/Ol000001OnZRK800ol0003oZHVcojV9
/`02ojV9/`03o`000?nXRKCoZ8Vd00;oZ8Vd00Co0000ojJ9]_nVRKKoYXVf0_l00003ojN:]P03o`00
0?nVRkSoYX^h00;oYX^h00?o0000ojB;^_nTRkX00_nTRkX01Ol0003oXXbloj:<_?nRS;co000000Co
X8bo00?o0000oij=`_nNSL800_nNSL801Ol0003oVhk5oi^>aOnKS/Go000000?oV8o800?o0000oiF@
c?nET<`00onET<`01Ol0003oTI;@oi6Bd?nAT]3o000000CoSYCD00Go0000ohZFfOn:U]WoRYKIo`00
0002ohJHg@03o`000?n6V=go000000CoPi_R00?o0000oh2Ni_n0W^H00_n0W^H00ol0003oOJ;ZogfR
jP02ogfRjP05o`000?mkY^koNjK^og^Vk_l000008?ooool2o`0000Oooooo00?o0000ooooooooool0
1Oooool002Cooooo00?o0000ooooooooool0=oooool2o`0000;o_=;Z00?o0000okk>i_nnc^H00_nn
c^H00ol0003o_l[Roko:hP02oko:hP05o`000?o0aMko`<GNol35g_l000001?o0`=X01Ol0003o_k_F
oknke_no^mKo000000Co_[KB00?o0000okfac_nm/Lh00_nm/Lh01Ol0003o_:c:okb/b_nl[<[o0000
00Co^ZO600Co0000okRS`onhXl?o^:?31?l000000ongWl7o0000okFL_P02okFL_P03o`000?ndV;_o
]9Rk00;o]9Rk00?o0000ok:F^OnbU[T00_nbU[T01Ol0003o/I>gok6C]onaTkOo000000Co/96f00Co
0000ojn?]?n_SkCo[hnd0_l00004ok2?]003o`000?n^SK?o[Xfc00;o[Xfc0_l00004ojj</P05o`00
0?n]R[7o[HZaojf:/Ol000000_n/R[401_l0003o[8Zaojb:/Ol0003o[8Zao`0000CoZhVa00?o0000
ojZ9/_nZRK800onZRK800ol0003oZHVcojV9/`02ojV9/`03o`000?nXRKCoZ8Vd00;oZ8Vd00Go0000
ojJ9]_l0003o0000ojR:]005ojN:]PCoYX^h00?o0000ojB;^_nTRkX00_nTRkX01Ol0003oXXbloj:<
_?nRS;co000000GoX8bo00Go0000oij=`_nNSL;oWXg2o`000003oi^>a@03o`000?nHSlSoV8o800;o
V8o800?o0000oiF@c?nET<`00_nET<`00ol0003oTI;@oi6Bd002oi6Bd005o`000?n>U=CoSYCDohjD
e?l000001?n:U]T01_l0003oQYSMohJHgOl0003oQYSMo`0000?oPi_R00?o0000oh2Ni_n0W^H00_n0
W^H00ol0003oOJ;ZogfRjP02ogfRjP05o`000?mkY^koNjK^og^Vk_l000007oooool00ol0003ooooo
o`000005ooooo`03oeEEEOmVIVKo000000Oooooo000Tooooo`03o`000?oooooooooo03Oooooo00Go
0000okcBj_nld^[o_=;Zo`000004okk>iP03o`000?nob^;o_l[R00;o_l[R00Go0000ol35g_o0aMko
`<GNo`000004ol30fP05o`000?no^mKo_k_Foknke_l000001?nn]]800ol0003o_K7>okfacP02okfa
cP05o`000?nl[<[o_:c:okb/b_l000001?njYlH00ol0003o^:?3okRS``02o`0000Co]io100Go0000
okFL__neW;ko]Ibno`000004okBH^`03o`000?nbU[Wo/YJi00;o/YJi00Go0000ok6C]onaTkOo/I>g
o`000004ok2A]P06o`000?n_SkCo[hndojn?]?l0003o[Xfc0_l000000on`SkCo0000ojj=/`03ojj=
/`04o`000?n]Rk;o[H^bo`0000;o[Xbb00?o0000ojf:/Ol000000_n]R[401?l0003o[8Zaojb:/Ol0
0002ojb:/@03o`000?n/R[7o000000?oZhVa00?o0000oj^9/Ol000000onZRK800ol0003oZhVbo`00
0003ojV9/`03o`000?nXRKCoZ8Vd00;oZ8Vd0_l00003ojR:]003o`000?nWR[KoYhZf00;oYhZf00?o
0000ojJ;^?nVRkP00_nVRkP01Ol0003oY8^jojB;^_nTRk[o000000CoXXbl00?o0000oj2<_onPS;l0
0_nPS;l01Ol0003oWXg2oij=`_nNSL;o000000CoVhk500Go0000oiR?b?nHSlSoV8o8o`000004oiF@
c003o`000?nAT]3oTI;@00;oTI;@00Go0000ohjDe?n>U=CoSYCDo`000004ohZFf@06o`000?n6V=go
QYSMo`000?n6V=go00000on3Vn800ol0003oP9kVoh2NiP02oh2NiP03o`000?mmX^[oOJ;Z00;oOJ;Z
00?o0000og^Vk_mkY^h00_mkY^h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo
000Tooooo`;o0000>?ooool01Ol0003o_=;ZokcBj_nld^[o000000Co_/kV00Go0000oko:h_nob^;o
_l[Ro`000004ol35gP03o`000?o0`=[o`<3J00;o`<3J00Go0000oknke_no^mKo_k_Fo`000004okjf
dP03o`000?nm/Lko_K7>00;o_K7>00Go0000okb/b_nl[<[o_:c:o`000004okZWaP?o000000?o^:?3
o`000?ngWl400ongWl401Ol0003o]IbnokFL__neW;ko000000Co]9Rk00Go0000ok:F^OnbU[Wo/YJi
o`000004ok6C]`03o`000?n`TKKo/96f00;o/96f00Go0000ojn?]?n_SkCo[hndo`000003ojj=/`;o
00001?n^SK<02Ol0003o[H^bojf;/_n]Rk;o0000ojj</_l0003o[HZao`000003ojf:/@03ojb:/Ol0
003o000000Go00000on[RK401_l0003oZhVaoj^9/Ol0003oZXVbo`0000;oZhVb00?o0000ojV9/onY
RK<00_nYRK<01Ol0003oZ8VdojR9]?l0003oZHZc00GoZ8Zd1?nWR[H00ol0003oYX^hojJ;^002ojJ;
^005o`000?nTRk[oY8^jojB;^_l000001?nRS;`00ol0003oX8booj2<_`02oj2<_`05o`000?nNSL;o
WXg2oij=`_l000001?nKS/D01Ol0003oV8o8oiR?b?nHSlSo000000CoUI3<00?o0000oi6Bd?nAT]00
0_nAT]000ol0003oSYCDohjDe002ohjDe005o`000?n:U]WoRYKIohZFfOl000000on6V=d00ol0003o
QYSMo`000003oh>KhP03o`000?n0W^KoP9kV00;oP9kV00?o0000ogfRj_mmX^X00_mmX^X01Ol0003o
NjK^og^Vk_mkY^ko0000023ooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`0gooooo`05
o`000?nld^[o_=;ZokcBj_l000001?nnc^H01Ol0003o_l[Roko:h_nob^;o000000Co`<GN00?o0000
ol30f_o0`=X00_o0`=X01Ol0003o_k_Foknke_no^mKo000000Co_[KB00?o0000okfac_nm/Lh00_nm
/Lh01_l0003o_:c:okb/b_nl[<[o0000okZWaPCo00000onhXl<00ol0003o]io1okNO`@02okNO`@05
o`000?neW;ko]IbnokFL__l000001?ndV;/01Ol0003o/YJiok:F^OnbU[Wo000000Co/I>g00?o0000
ok2A]_n`TKH00_n`TKH01Ol0003o[hndojn?]?n_SkCo000000Co[Xfc0_l00003ojj=/`03o`000?n]
Rk;o[H^b00;o[H^b00Go0000ojf:/On]R[7o[HZao`000002ojf:/@03o`000?n/RK3o000000;o[8V`
00?o0000ojb9/?l000000_n[RK401ol0003oZhVaoj^9/On[RK7o0000ojZ9/_l000000_n[RK800ol0
003oZHVcojV9/`02ojV9/`03o`000?nXRKCo000000;oZHZc00?o0000ojR:]?nXR[@00_nXR[@01Ol0
003oYhZfojN:]_nWR[Ko000000CoYX^h00?o0000ojB;^_nTRkX00_nTRkX01Ol0003oXXbloj:<_?nR
S;co000000CoX8bo00Go0000oij=`_nNSL;oWXg2o`000004oi^>a@05o`000?nHSlSoV8o8oiR?b?l0
00001OnET<`00ol0003oTI;@oi6Bd002oi6Bd005o`000?n>U=CoSYCDohjDe?l000001?n:U]T01?l0
003oQYSMohJHgOn6V=d2o`0000?oPi_R00?o0000oh2Ni_n0W^H00_n0W^H00ol0003oOJ;ZogfRjP02
ogfRjP05o`000?mkY^koNjK^og^Vk_l000007Oooool3o`0000;ooooo00?o0000ooooooooool02ooo
ool002Cooooo00?o0000ooooooooool0=oooool01Ol0003o_=;ZokcBj_nld^[o000000Co_/kV00Go
0000oko:h_nob^;o_l[Ro`000004ol35gP03o`000?o0`=[o`<3J00;o`<3J00Go0000oknke_no^mKo
_k_Fo`000004okjfdP03o`000?nm/Lko_K7>00;o_K7>00?o0000okb/b_nl[<X00ol00003okZWaP05
o`000?nhXl?o^:?3okRS`ol000001?ngWl401Ol0003o]IbnokFL__neW;ko000000Co]9Rk00Go0000
ok:F^OnbU[Wo/YJio`000004ok6C]`03o`000?n`TKKo/96f00;o/96f00Go0000ojn?]?n_SkCo[hnd
o`000004ojj=/`03o`000?n]S;;o000000;o[Xfc00?o0000ojf;/_n]Rk800_n]Rk801_l0003o[HZa
ojf:/On]R[7o0000ojf:/@;o000000Oo[8V`o`000?n/RK3o[8V`o`000?n/RK3o000000;oZhVa00?o
0000oj^9/On[RK400_n[RK400ol0003oZhVboj^9/P02oj^9/P04o`000?nYRK?oZHVcojV9/`;o0000
0onYR[<00ol0003oZ8ZdojR:]002ojR:]005o`000?nWR[KoYhZfojN:]_l000001?nVRkP00ol0003o
Y8^jojB;^P02ojB;^P05o`000?nRS;coXXbloj:<_?l000001OnPS;l01Ol0003oWXg2oij=`_nNSL;o
000000CoVhk500Go0000oiR?b?nHSlSoV8o8o`000004oiF@c003o`000?nAT]3oTI;@00;oTI;@00Go
0000ohjDe?n>U=CoSYCDo`000004ohZFf@03o`000?n6V=goQYSM00;oQYSM00Go0000oh>Kh_n3Vn;o
Pi_Ro`000004oh2NiP04o`000?mmX^[oOJ;ZogfRjPOo00006Oooool3o`0000Gooooo00?o0000oooo
ooooool02oooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003o_=;ZokcBjP02okcBjP03
o`000?nnc^Ko_/kV00;o_/kV00Go0000oko:h_nob^;o_l[Ro`000004ol35gP03o`000?o0`=[o`<3J
00;o`<3J00Go0000oknke_no^mKo_k_Fo`000004okjfdP03o`000?nm/Lko_K7>00;o_K7>0ol00000
0onl[<[o0000okZWaP03okZWaP04o`000?nhXl?o^:?3o`0000Co]io100Go0000okFL__neW;ko]Ibn
o`000005okBH^`05o`000?nbU[Wo/YJiok:F^Ol000001?naTkL01Ol0003o/96fok2A]_n`TKKo0000
00Co[hnd00?o0000ojj=/on^SK<00_n^SK<00ol0003o[Hbbojf</P02o`0000Co[H^b00?o0000ojf:
/Ol000000on]R[401Ol0003o[8V`o`000?n/RK3o000000;o[8V`00Ko0000ojb9/?l0003o0000oj^9
/Ol00004oj^9/@03o`000?n[RK;oZhVb00;oZhVb00Go0000ojV9/onYRK?o0000oj^9/P05ojV:/`05
o`000?nXR[CoZ8ZdojR:]?l000001?nWR[H01Ol0003oYX^hojJ;^?nVRkSo000000CoY8^j00?o0000
oj:<_?nRS;`00_nRS;`00ol0003oX8booj2<_`02oj2<_`05o`000?nNSL;oWXg2oij=`_l000001?nK
S/D01Ol0003oV8o8oiR?b?nHSlSo000000CoUI3<00?o0000oi6Bd?nAT]000_nAT]000ol0003oSYCD
ohjDe002ohjDe005o`000?n:U]WoRYKIohZFfOl000000on6V=d>o`0000;oXkOW00Go0000oj6kjonQ
^n_oXK_[o`00000Eooooo`Co00002?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`0003Oo
oooo00?o0000okcBj_nld^X00_nld^X00ol0003o_/kVokk>iP02okk>iP05o`000?nob^;o_l[Roko:
h_l000001?o0aMh00ol0003o`<3Jol30fP02ol30fP05o`000?no^mKo_k_Foknke_l000001?nn]]80
0ol0003o_K7>o`000002o`0000?o_:c:00?o0000okZWa_njYlH00_njYlH01Ol0003o^:?3okRS`onh
Xl?o000000Co]io100Go0000okFL__neW;ko]Ibno`000004okBH^`03o`000?nbU[Wo/YJi00;o/YJi
00?o0000ok6C]onaTkL00_naTkL01Ol0003o/96fok2A]_n`TKKo000000Co[hnd00?o0000ojj=/on^
SK<00_n^SK<01?l0003o[Hbbojf</_n]S;82o`0000?o[H^b00Co0000ojf:/On]R[7o00000_n]R[40
0ol0003o[8V`ojb9/002o`0000;o[8V`00Go0000ojb9/?l0003o[8V`o`000004oj^9/@03o`000?n[
RK7o000000?oZhVb00?o0000ojV9/ol000000_n[RK800ol0003oZHZcojV:/`02ojV:/`05o`000?nX
R[CoZ8ZdojR:]?l000001?nWR[H00ol0003oYX^hojJ;^002ojJ;^005o`000?nTRk[oY8^jojB;^_l0
00001?nRS;`00ol0003oX8booj2<_`02oj2<_`05o`000?nNSL;oWXg2oij=`_l000001?nKS/D01Ol0
003oV8o8oiR?b?nHSlSo000000GoUI3<00?o0000oi6Bd?nAT]000_nAT]000ol0003oSYCDo`000009
o`0000;oYj_I00Go0000ojJ_g_nV[mkoYZoNo`000004ojFchP03o`000?nS]nOoXkOW00;oXkOW00Go
0000oj6kjonQ^n_oXK_[o`00000Booooo`?o00003Oooool00ol0003oooooooooo`0:ooooo`008ooo
ool00ol0003oooooooooo`0gooooo`03o`000?nld^[o_=;Z00;o_=;Z00Go0000okk>i_nnc^Ko_/kV
o`000004oko:hP03o`000?o0aMko`<GN00;o`<GN00?o0000ol30f_o0`=X00_o0`=X01Ol0003o_k_F
oknke_no^mKo000000?o_[KB0ol00002okfacP05o`000?nl[<[o_:c:okb/b_l000001?njYlH01Ol0
003o^:?3okRS`onhXl?o000000Co]io100Go0000okFL__neW;ko]Ibno`000004okBH^`03o`000?nb
U[Wo/YJi00;o/YJi00?o0000ok6C]onaTkL00_naTkL01Ol0003o/96fok2A]_n`TKKo000000?o[hnd
00?o0000ojj=/on^SK<00on^SK<01ol0003o[Hbbojf</_n]S;;o0000ojf;/Ol000000_n]Rk801?l0
003o[HZaojf:/On]R[42o`00000<ojb9/?l0003o[8V`o`000?n/RK3o0000ojb9/?l0003o[8V`o`00
0?n/RK3o00000on[RK401?l0003oZhVaoj^9/Ol00003oj^9/P;o00000on[RK800ol0003oZHZcojV:
/`02ojV:/`03o`000?nXR[CoZ8Zd00;oZ8Zd00Go0000ojN:]_nWR[KoYhZfo`000004ojJ;^003o`00
0?nTRk[oY8^j00;oY8^j00Go0000oj:<_?nRS;coXXblo`000004oj2<_`05o`000?nNSL;oWXg2oij=
`_l000001OnKS/D01Ol0003oV8o8oiR?b?nHSlSo000000;oUI3<2Ol00002ojVSd@03o`000?nXYmGo
Z:OE00;oZ:OE00?o0000ojN[fOnWZmT00_nWZmT2o`0000;oYZoN00?o0000ojFch_nU/n800_nU/n80
0ol0003oXkOWoj>gi`02oj>gi`05o`000?nQ^n_oXK_[oj6kjol000003oooool3o`00013ooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003o_=;ZokcBjP02
okcBjP05o`000?nnc^Ko_/kVokk>i_l000001?nob^800ol0003o`<GNol35gP02ol35gP03o`000?o0
`=[o`<3J00;o`<3J00Go0000oknke_no^mKo0000okjfdP04o`0000Co_K7>00Go0000okb/b_nl[<[o
_:c:o`000004okZWaP05o`000?nhXl?o^:?3okRS`ol000001?ngWl401Ol0003o]IbnokFL__neW;ko
000000Co]9Rk00?o0000ok:F^OnbU[T00_nbU[T01Ol0003o/I>gok6C]onaTkOo000000Co/96f00Go
0000ojn?]?n_SkCo[hndo`000005ojj=/`05o`000?n]S;;o[Hbbojf</_l000000_n]Rk42o`0000Go
[HZa00So0000ojb9/?l0003o[8V`o`000?n/RK3o0000ojb9/0;o000000Ko[8V`o`000?n/RK3o0000
oj^9/Ol00003oj^9/@05o`000?n[RK;oZhVbo`000?n[RK401On[RK801Ol0003oZHZcojV:/onYR[?o
000000CoZ8Zd00Go0000ojN:]_nWR[KoYhZfo`000004ojJ;^003o`000?nTRk[oY8^j00;oY8^j00Go
0000oj:<_?nRS;coXXblo`000005oj2<_`05o`000?nNSL;oWXg2oij=`_l000000_nKS/D9o`0000;o
ZYc900?o0000ojVOcOnYWld00_nYWld01Ol0003oZJ?AojVSdOnYXm7o000000CoZ:OE00?o0000ojN[
fOnWZmT00_nWZmT01Ol0003oYZoNo`000?nV[mko000000CoYK?R00?o0000oj>gionS]nL00_nS]nL0
1Ol0003oXK_[oj6kjonQ^n_o000000_ooooo1?l0000Cooooo`03o`000?oooooooooo00[ooooo000S
ooooo`03o`000?oooooooooo03Oooooo00Go0000okcBj_nld^[o_=;Zo`000004okk>iP03o`000?no
b^;o_l[R00;o_l[R00?o0000ol35g_o0aMh00_o0aMh01Ol0003o`<3Jol30f_o0`=[o000000;o_k_F
0ol00003okjfdP03o`000?nm/Lko_K7>00;o_K7>00Go0000okb/b_nl[<[o_:c:o`000004okZWaP03
o`000?nhXl?o000000ko000000?o]9Rko`000?nbU[T00onbU[T01Ol0003o/I>gok6C]onaTkOo0000
00Co/96f00Go0000ojn?]?n_SkCo[hndo`000004ojj=/`03o`000?n]S;;o[Hbb00;o[Hbb00Co0000
ojf;/On]Rk7o[H^a0_l00004ojf:/@03o`000?n/RK3o[8V`00;o000000?o[8V`o`000?n/RK000_l0
00001On/RK3o0000ojb9/?n/RK3o000000GoZhVa0_l00002oj^9/@03o`000?n[RK;oZhVb00;oZhVb
00Go0000ojV:/onYR[?oZHZco`000004ojR:]005o`000?nWR[KoYhZfojN:]_l000001?nVRkP00ol0
003oY8^jojB;^P02ojB;^P03o`000?nRS;coXXbl00;oXXbl00?o0000oj2<_onPS;l02Ol00002oj^G
`P05o`000?nZV/GoZY[5ojZJaOl000001?nZW<T00ol0003oZIo=ojVOc@02ojVOc@05o`000?nYXm7o
ZJ?AojVSdOl000001?nXYmD00ol0003oYj_IojN[f@02ojN[f@05o`000?nV[mko0000ojJ_g_l00000
1?nU/n800ol0003oXkOWoj>gi`02oj>gi`05o`000?nQ^n_oXK_[oj6kjol000002?ooool3o`0001Oo
oooo00?o0000ooooooooool02_ooool002?ooooo0ol0000gooooo`05o`000?nld^[o_=;ZokcBj_l0
00001?nnc^H00ol0003o_l[Roko:hP02oko:hP05o`000?o0aMko`<GNol35g_l000001?o0`=X3o`00
0003oknke_l0003o_[KB00?o_[KB00?o0000okfac_nm/Lh03Ol00002oj^G`PGoZiFo1?n[Tkd4oj^A
^`Wo000000?o/I>go`000?n`TKH00on`TKH01Ol0003o[hndojn?]?n_SkCo000000Co[Xfc00?o0000
ojf</_n]S;800_n]S;801_l0003o[H^aojf;/On]Rk7o0000ojb:/@;o00000_n]R[42o`000006ojb9
/?l0003o[8V`ojb9/?l0003o[8V`0_l000001On/RK3o0000ojb9/?n/RK3o000000CoZhVa0_l00003
oj^9/@03o`000?n[RK;oZhVb00;oZhVb00Go0000ojV:/onYR[?oZHZco`000004ojR:]003o`000?nW
R[KoYhZf00;oYhZf00?o0000ojJ;^?nVRkP00_nVRkP00ol0003oY8^jojB;^P02ojB;^P03o`000?nR
S;co000000Co00000_n[Tkd01Ol0003oZiFooj^E_on[UKoo000000CoZiO200Go0000ojZJaOnZV/Go
ZY[5o`000004ojZLb@03o`000?nYWlgoZIo=00;oZIo=00Go0000ojVSdOnYXm7oZJ?Ao`000004ojRW
e@03o`000?nWZmWoYj_I00;oYj_I00?o0000ojJ_g_nV[mh00_l00004ojFchP03o`000?nS]nOoXkOW
00;oXkOW00Go0000oj6kjonQ^n_oXK_[o`000005ooooo`?o00006_ooool00ol0003oooooooooo`0:
ooooo`008oooool00ol0003oooooooooo`0gooooo`05o`000?nld^[o_=;ZokcBj_l000001?nnc^H0
1Ol0003o_l[Roko:h_nob^;o000000Co`<GN00?o0000ol30f_l000000ol00003oknkeP03o`000?nn
]];o_[KB00Go00000_nYX<d4ojZLb@GoZY[61?n[Ul800ol0003oZiFooj^E_`02oj^E_`CoZi>m1On[
TK/5oj^?^@?o[8jg2Ol000000on_SkCo0000ojj=/`03ojj=/`05o`000?n]S;;o[Hbbojf</_l00000
1?n]Rk401?l0003o[8Zaojb:/On/R[42o`0000;o[8V`0_l000000on/RK3o0000o`000004o`0000;o
[8V`00?o0000ojb9/?l000000_n[RK400ol0003o[8Vaoj^9/@03oj^9/@03o`000?n[RK;oZhVb00;o
ZhVb00Go0000ojV:/onYR[?oZHZco`000004ojR:]003o`000?nWR[KoYhZf00;oYhZf00?o0000ojJ;
^?nVRkP02Ol00002oj^A^`03o`000?n[TkgoZi>m00;oZi>m00Go0000oj^E_on[UKooZiFoo`000004
oj^G`P05o`000?nZV/GoZY[5ojZJaOl000001?nZW<T00ol0003oZIo=ojVOc@02ojVOc@05o`000?nY
Xm7oZJ?AojVSdOl000001?nXYmD00ol0003oYj_IojN[f@02ojN[f@05o`000?nV[mkoYZoNojJ_g_l0
00001?nU/n800ol0003oXkOWoj>gi`02oj>gi`05o`000?nQ^n_oXK_[oj6kjol000000_ooool3o`00
01gooooo00?o0000ooooooooool02_ooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0h
ooooo`05o`000?nld^[o_=;ZokcBj_l000001?nnc^H01Ol0003o_l[Roko:h_nob^;o000000?o`<GN
0ol00003ol30fP03o`000?no^mKo000000Co00000_nXXm45ojVPc@05o`000?nZW<WoZYc9ojZLbOl0
00001?nZV/H4oj^G`P03o`000?n[UKooZiFo00;oZiFo00Go0000oj^C_On[TkgoZi>mo`000004oj^A
^`03o`000?n[SkWoZhni00;oZhni1?n/S[L5ojb=]@03o`000?n/S;Co[8bd00Go000000?o[Xfco`00
0?n]S;800_n]S;800ol0003o[H^aojf;/@02ojf;/@03o`000?n/R[7o[8Za00;o[8Za00Go0000ojb9
/?n/RK3o0000ojb9/003o`000006ojb9/?l0003o0000o`000?n/RK3o00000_n/RK000ol0003oZhVa
o`000002ojb9/@03o`000?n[RK7oZhVa00;oZhVa00Go0000oj^9/_n[RK;oZhVbo`000004ojV:/`03
o`000?nXR[CoZ8Zd00;oZ8Zd00?o0000ojN:]_l000001?l00002ojb>]`Go[8ni1?n[TK/00ol0003o
Zi>moj^C_@02oj^C_@05o`000?n[UKooZiFooj^E_ol000001?n[Ul801Ol0003oZY[5ojZJaOnZV/Go
000000CoZYc900?o0000ojVOcOnYWld00_nYWld01Ol0003oZJ?AojVSdOnYXm7o000000CoZ:OE00?o
0000ojN[fOnWZmT00_nWZmT01Ol0003oYZoNojJ_g_nV[mko000000CoYK?R00?o0000oj>gionS]nL0
0_nS]nL01?l0003oXK_[oj6kjonQ^n/3o`00023ooooo00?o0000ooooooooool02_ooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool01Ol0003o_=;ZokcBj_nld^[o
000000Co_/kV00Co0000oko:h_nob^;o_l[R1?l000001?o0aMko0000ol30f_o0`=X4o`0000;oYjOF
1OnXXm400ol0003oZJ3=ojVPc@02ojVPc@05o`000?nZW<WoZYc9ojZLbOl000001?nZV/H01Ol0003o
ZiO2oj^G`_n[Ul;o000000CoZiFo00Go0000oj^C_On[TkgoZi>mo`000004oj^A^`03o`000?n[SkWo
Zhni00;oZhni00Go0000ojb>]on/S[Oo[8jgo`000004ojb=]@05o`000?n/S;Co[8bdojb<]?l00000
0on/Rk<4o`000003ojf</_l0003o[H^a00?o[H^a00?o0000ojb:/On/R[400_n/R[42o`0000;o[8V`
0_l000000on/RK3o0000ojb9/003o`000004ojb9/?l0003o[8V`ojb9/0;o00000on/RK400ol0003o
ZhVaoj^9/@02oj^9/@03o`000?n[RK;oZhVb00;oZhVb00Go0000ojV:/onYR[?oZHZco`000002ojR:
]0Co00000_n/SKD5ojb>]`03o`000?n/SkWo[8ni00;o[8ni1?n[TK/00ol0003oZi>moj^C_@02oj^C
_@05o`000?n[UKooZiFooj^E_ol000001?n[Ul801Ol0003oZY[5ojZJaOnZV/Go000000CoZYc900?o
0000ojVOcOnYWld00_nYWld01Ol0003oZJ?AojVSdOnYXm7o000000CoZ:OE00?o0000ojN[fOnWZmT0
0_nWZmT01?l0003oYZoNojJ_g_nV[mh2o`0000?oYK?R00?o0000oj>gionS]nL00_nS]nL01Ol0003o
XK_[oj6kjonQ^n_o000002?ooooo00?o0000ooooooooool02Oooool00005oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0_l0000hoooo
o`03o`000?nld^[o_=;Z00;o_=;Z00?o0000okk>i_nnc^H00_nnc^H00ol0003o_l[Roko:hP02o`00
00;o`<GN1Ol00002ojJ[fPCoYjOF00?o0000ojRSdOnXXm400_nXXm400ol0003oZJ3=ojVPc@02ojVP
c@03o`000?nZW<WoZYc900;oZYc91?nZV/H01Ol0003oZiO2oj^G`_n[Ul;o000000CoZiFo00Go0000
oj^C_On[TkgoZi>mo`000004oj^A^`03o`000?n[SkWoZhni00;oZhni00Go0000ojb>]on/S[Oo[8jg
o`000004ojb=]@05o`000?n/S;Co[8bdojb<]?l000001?n/Rk<00ol0003o[8Zbojb:/P05o`000003
ojf;/Ol0003o[8Za00?o[8Za00?o0000ojb9/?l000000_n/RK08o`0000;o[8V`00?o0000ojb9/?l0
00001?n/RK401Ol0003oZhVaoj^9/On[RK7o000000CoZhVb00?o0000ojV:/ol000001?l00002ojb<
]0Co[8fe00?o0000ojb>]on/S[L00_n/S[L00ol0003o[8niojb?^@02ojb?^@05o`000?n[TK_oZi6k
oj^A^ol000001?n[Tkd01Ol0003oZiFooj^E_on[UKoo000000CoZiO200?o0000ojZJaOnZV/D00_nZ
V/D01Ol0003oZYc9ojZLbOnZW<Wo000000CoZIo=00Go0000ojVSdOnYXm7oZJ?Ao`000004ojRWe@03
o`000?nWZmWoYj_I00;oYj_I00Oo0000ojJ_g_nV[mkoYZoNo`000?nU/n;o000000;oYK?R00?o0000
oj>gionS]nL00_nS]nL01Ol0003oXK_[oj6kjonQ^n_o000002?ooooo00?o0000ooooooooool02Ooo
ool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003o_=;ZokcBjP02okcBjP03o`000?nn
c^Ko_/kV00;o_/kV1ol00002ojF_g`GoYZ_J00?o0000ojNWe_nWYmH00_nWYmH5ojRSd@CoZJ3=00?o
0000ojZLbOnZW<T00_nZW<T01Ol0003oZY[6ojZJa_nZV/Ko000000CoZiO200?o0000oj^E_on[UKl0
0_n[UKl01Ol0003oZi>moj^C_On[Tkgo000000?oZi6k00?o0000oj^?^On[SkT00_n[SkT01Ol0003o
[8jgojb>]on/S[Oo000000Co[8fe00Go0000ojb<]?n/S;Co[8bdo`000004ojb;/`05o`000?n/R[;o
[8Zbojb:/_l000000on/R[43o`0000;o[8Za00Ko0000ojb9/?n/RK3o[8V`o`000?n/RK06o`000004
ojb9/?l0003o[8V`o`0000;o[8V`00?o0000ojb9/On/RK400_n/RK401Ol0003oZhVaoj^9/On[RK7o
000000;oZhVb1?l00002ojb;/`Go[8bd00Go0000ojb=]On/SKGo[8feo`000004ojb>]`03o`000?n/
SkWo[8ni00;o[8ni00Go0000oj^A^on[TK_oZi6ko`000004oj^C_@03o`000?n[UKooZiFo00;oZiFo
00Go0000oj^G`_n[Ul;oZiO2o`000004ojZJa@05o`000?nZW<WoZYc9ojZLbOl000001?nYWld01Ol0
003oZJ?AojVSdOnYXm7o000000CoZ:OE00?o0000ojN[fOnWZmT00_nWZmT00ol0003oYZoNojJ_gP02
ojJ_gP05o`000?nU/n;o0000ojFch_l000001?nS]nL01Ol0003oXK_[oj6kjonQ^n_o000002?ooooo
00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003_ooool00omgMgOoIVIV
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0gooooo`03
o`000?nld^[o_=;Z00;o_=;Z00?o0000okk>i_l000001?l00002ojBch`GoYJoO00?o0000ojJ[f_nV
ZmX00_nVZmX00ol0003oYjOFojNWeP02ojNWePGoZ:?A00?o0000ojVPcOnYX<d00_nYX<d01Ol0003o
ZYc9ojZLbOnZW<Wo000000CoZY[600Go0000oj^G`_n[Ul;oZiO2o`000004oj^E_`05o`000?n[Tkgo
Zi>moj^C_Ol000000on[TK/00ol0003oZhnioj^?^@02oj^?^@05o`000?n/S[Oo[8jgojb>]ol00000
1?n/SKD01Ol0003o[8bdojb<]?n/S;Co000000Co[8^c00Go0000ojb:/_n/R[;o[8Zbo`000004ojb:
/@03o`000?n/RK7o000000;o00001?n/RK0:o`0000?o[8V`00?o0000ojb9/On/RK402Ol00002ojb:
/PCo[8^c00?o0000ojb<]?n/S;@00_n/S;@01Ol0003o[8feojb=]On/SKGo000000Co[8jg00?o0000
ojb?^On/SkT00_n/SkT01Ol0003oZi6koj^A^on[TK_o000000CoZi>m00?o0000oj^E_on[UKl00_n[
UKl01Ol0003oZiO2oj^G`_n[Ul;o000000CoZY[500Go0000ojZLbOnZW<WoZYc9o`000004ojVOc@05
o`000?nYXm7oZJ?AojVSdOl000001?nXYmD00ol0003oYj_IojN[f@02ojN[f@03o`000?nV[mkoYZoN
00;oYZoN00Go0000ojFch_l0003oYK?Ro`000004oj>gi`05o`000?nQ^n_oXK_[oj6kjol000008ooo
ool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`So00000_nR
^>P4ojBch`03o`000?nU[mooYJoO00?oYJoO1OnVZmX4ojNWeP03o`000?nXXm7oZ:?A00;oZ:?A00?o
0000ojVPcOnYX<d00_nYX<d01Ol0003oZYc9ojZLbOnZW<Wo000000CoZY[600Go0000oj^G`_n[Ul;o
ZiO2o`000004oj^E_`05o`000?n[TkgoZi>moj^C_Ol000000on[TK/00ol0003oZhnioj^?^@02oj^?
^@05o`000?n/S[Oo[8jgojb>]ol000001?n/SKD01Ol0003o[8bdojb<]?n/S;Co000000Co[8^c00Go
0000ojb:/_n/R[;o[8Zbo`000004ojb:/@04o`000?n/RK7o[8Vaojb9/@Co000000?o[8V`o`000?n/
RK001_l000000on/RK3o0000ojb9/005o`0000;o[8Va1?n/R[45ojb:/P05o`000?n/Rk?o[8^cojb;
/ol000001?n/S;@01Ol0003o[8feojb=]On/SKGo000000Co[8jg00?o0000ojb?^On/SkT00_n/SkT0
1Ol0003oZi6koj^A^on[TK_o000000CoZi>m00?o0000oj^E_on[UKl00_n[UKl01Ol0003oZiO2oj^G
`_n[Ul;o000000CoZY[500Go0000ojZLbOnZW<WoZYc9o`000004ojVOc@03o`000?nYXm7oZJ?A00;o
ZJ?A00?o0000ojRWeOnXYmD00_nXYmD01Ol0003oYj_IojN[fOnWZmWo000000CoYZoN00?o0000ojFc
h_nU/n800_l00004oj>gi`05o`000?nQ^n_oXK_[oj6kjol000008oooool00ol0003oooooooooo`09
ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`06ooooo`;o0000>?ooool01OnQ_>co0000o`000?l0003oXKc/00GoX[SX
00?o0000ojBchonT/n<00_nT/n<5ojF_g`03o`000?nVZm[oYZ_J00;oYZ_J00Go0000ojNWe_nWYmKo
YjOFo`000004ojRSd@03o`000?nYX<goZJ3=00;oZJ3=00Go0000ojZLbOnZW<WoZYc9o`000004ojZJ
aP05o`000?n[Ul;oZiO2oj^G`_l000001?n[UKl01Ol0003oZi>moj^C_On[Tkgo000000?oZi6k00?o
0000oj^?^On[SkT00_n[SkT01Ol0003o[8jgojb>]on/S[Oo000000Co[8fe00Go0000ojb<]?n/S;Co
[8bdo`000004ojb;/`05o`000?n/R[;o[8Zbojb:/_l000001?n/R[401Ol0003o[8Vaojb9/On/RK7o
000000?o[8V`3?l00002ojb9/0Go[8Va00Go0000ojb:/On/R[7o[8Zao`000004ojb:/P05o`000?n/
Rk?o[8^cojb;/ol000001?n/S;@01Ol0003o[8feojb=]On/SKGo000000Co[8jg00?o0000ojb?^On/
SkT00_n/SkT01Ol0003oZi6koj^A^on[TK_o000000CoZi>m00?o0000oj^E_on[UKl00_n[UKl01Ol0
003oZiO2oj^G`_n[Ul;o000000CoZY[500?o0000ojZLbOnZW<T00_nZW<T00ol0003oZIo=ojVOc@02
ojVOc@05o`000?nYXm7oZJ?AojVSdOl000001?nXYmD01Ol0003oYj_IojN[fOnWZmWo000000CoYZoN
00Go0000ojFch_nU/n;oYK?Ro`000004oj>gi`05o`000?nQ^n_oXK_[oj6kjol000008oooool00ol0
003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool0=_ooool3o`0000CoXKc/00?o0000
oj:hj?nR^>P00onR^>P4ojBch`03o`000?nU[mooYJoO00;oYJoO00?o0000ojJ[f_nVZmX00_nVZmX0
1Ol0003oYjOFojNWe_nWYmKo000000CoZ:?A00?o0000ojVPcOnYX<d00_nYX<d01Ol0003oZYc9ojZL
bOnZW<Wo000000CoZY[600Go0000oj^G`_n[Ul;oZiO2o`000004oj^E_`05o`000?n[TkgoZi>moj^C
_Ol000000on[TK/00ol0003oZhnioj^?^@03oj^?^@05o`000?n/S[Oo[8jgojb>]ol000001?n/SKD0
1Ol0003o[8bdojb<]?n/S;Co000000?o[8^c00?o0000ojb:/_n/R[800_n/R[801Ol0003o[8Zaojb:
/On/R[7o000000?o[8Va00?o0000ojb9/?n/RK000_n/RK000ol0003o[8V`ojb9/004o`0000;o[8V`
00Go0000ojb9/?n/RK3o[8V`o`000004ojb9/@05o`000?n/R[7o[8Zaojb:/Ol000001?n/R[801Ol0
003o[8^cojb;/on/Rk?o000000Co[8bd00Go0000ojb=]On/SKGo[8feo`000004ojb>]`03o`000?n/
SkWo[8ni00;o[8ni00Go0000oj^A^on[TK_oZi6ko`000004oj^C_@03o`000?n[UKooZiFo00;oZiFo
00?o0000oj^G`_n[Ul800_n[Ul801Ol0003oZY[5ojZJaOnZV/Go000000CoZYc900?o0000ojVOcOnY
Wld00_nYWld01Ol0003oZJ?AojVSdOnYXm7o000000CoZ:OE00Go0000ojN[fOnWZmWoYj_Io`000004
ojJ_gP04o`000?nU/n;oYK?RojFchP;o00000onS]nL01Ol0003oXK_[oj6kjonQ^n_o000002?ooooo
00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0<oooool3o`0000?ooooo1OnQ
_>`00ol0003oX[SXoj:hj002oj:hj005o`000?nT/n?oY;?SojBchol000001?nU[ml00ol0003oYZ_J
ojJ[fP02ojJ[fP03o`000?nWYmKoYjOF00;oYjOF00Go0000ojRSdOnXXm7oZ:?Ao`000004ojVPc@05
o`000?nZW<WoZYc9ojZLbOl000001?nZV/H01Ol0003oZiO2oj^G`_n[Ul;o000000CoZiFo00Go0000
oj^C_On[TkgoZi>mo`000004oj^A^`03o`000?n[SkWoZhni00;oZhni00Go0000ojb>]on/S[Oo[8jg
o`000004ojb=]@05o`000?n/S;Co[8bdojb<]?l000000on/Rk<00ol0003o[8Zbojb:/P02ojb:/P05
o`000?n/R[7o[8Zaojb:/Ol000001?n/RK400ol0003o[8V`o`000005o`000003ojb9/?l0003o0000
00?o00001?n/RK001Ol0003o[8Vaojb9/On/RK7o000000?o[8Za00?o0000ojb:/_n/R[800_n/R[80
1Ol0003o[8^cojb;/on/Rk?o000000Co[8bd00Go0000ojb=]On/SKGo[8feo`000004ojb>]`03o`00
0?n/SkWo[8ni00;o[8ni00?o0000oj^A^on[TK/00_n[TK/00ol0003oZi>moj^C_@02oj^C_@05o`00
0?n[UKooZiFooj^E_ol000001?n[Ul801Ol0003oZY[5ojZJaOnZV/Go000000CoZYc900?o0000ojVO
cOnYWld00_nYWld01Ol0003oZJ?AojVSdOnYXm7o000000CoZ:OE00Go0000ojN[fOnWZmWoYj_Io`00
0004ojJ_gP04o`000?nU/n;oYK?RojFchP;o00000onS]nL01Ol0003oXK_[oj6kjonQ^n_o000002Co
oooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo
00?o0000oj6lk?nQ_>`00_nQ_>`00ol0003oX[SXoj:hj002oj:hj003o`000?nT/n?oY;?S00;oY;?S
00Go0000ojF_gonU[mooYJoOo`000004ojJ[fP03o`000?nWYmKoYjOF00;oYjOF00Go0000ojRSdOnX
Xm7oZ:?Ao`000004ojVPc@03o`000?nZW<WoZYc900;oZYc900Go0000ojZJa_nZV/KoZY[6o`000003
oj^G`P03o`000?n[UKooZiFo00;oZiFo00Go0000oj^C_On[TkgoZi>mo`000004oj^A^`03o`000?n[
SkWoZhni00;oZhni00Go0000ojb>]on/S[Oo[8jgo`000004ojb=]@05o`000?n/S;Co[8bdojb<]?l0
00000on/Rk<00ol0003o[8Zbojb:/P02ojb:/P05o`000?n/R[7o[8Zaojb:/Ol000000_n/RK44o`00
00;o[8V`00Co0000ojb9/?l0003o[8V`1?l000000on/RK3o0000o`000002o`000003ojb9/?l0003o
[8Va00;o[8Va00?o0000ojb:/On/R[400_n/R[400ol0003o[8Zbojb:/P02ojb:/P05o`000?n/Rk?o
[8^cojb;/ol000001?n/S;@01Ol0003o[8feojb=]On/SKGo000000Co[8jg00?o0000ojb?^On/SkT0
0_n/SkT01Ol0003oZi6koj^A^on[TK_o000000CoZi>m00Go0000oj^E_on[UKooZiFoo`000004oj^G
`P05o`000?nZV/GoZY[5ojZJaOl000001?nZW<T00ol0003oZIo=ojVOc@02ojVOc@05o`000?nYXm7o
ZJ?AojVSdOl000001?nXYmD01Ol0003oYj_IojN[fOnWZmWo000000CoYZoN00Oo0000ojFch_nU/n;o
YK?Ro`000?nS]nOo000000;oXkOW00?o0000oj6kjol000000_l0000Tooooo`03o`000?oooooooooo
00Sooooo000Qooooo`;o0000;_ooool3o`0000[ooooo00Go0000oj6lk?nQ_>coXKc/o`000005oj:h
j005o`000?nT/n?oY;?SojBchol000001?nU[ml01Ol0003oYZ_JojJ[f_nVZm[o000000CoYjOF00?o
0000ojRSdOnXXm400_nXXm401Ol0003oZJ3=ojVPcOnYX<go000000CoZYc900Go0000ojZJa_nZV/Ko
ZY[6o`000003oj^G`P03o`000?n[UKooZiFo00;oZiFo00Go0000oj^C_On[TkgoZi>mo`000004oj^A
^`03o`000?n[SkWoZhni00;oZhni00Go0000ojb>]on/S[Oo[8jgo`000004ojb=]@05o`000?n/S;Co
[8bdojb<]?l000000on/Rk<00ol0003o[8Zbojb:/P02ojb:/P03o`000?n/R[7o000000Co00000_n/
RK401?l0003o[8V`ojb9/?n/RK02o`000003ojb9/?l0003o000000;o000000?o[8V`o`000?n/RK00
0on/RK04o`000003ojb9/Ol0003o[8Za00?o[8Za00?o0000ojb:/_n/R[800_n/R[801Ol0003o[8^c
ojb;/on/Rk?o000000Co[8bd00Go0000ojb=]On/SKGo[8feo`000004ojb>]`03o`000?n/SkWo[8ni
00;o[8ni00Go0000oj^A^on[TK_oZi6ko`000004oj^C_@05o`000?n[UKooZiFooj^E_ol000001?n[
Ul801Ol0003oZY[5ojZJaOnZV/Go000000CoZYc900?o0000ojVOcOnYWld00_nYWld01Ol0003oZJ?A
ojVSdOnYXm7o000000CoZ:OE00Go0000ojN[fOnWZmWoYj_Io`000004ojJ_gP05o`000?nU/n;oYK?R
ojFch_l000000_nS]nL4o`0000;o^mS^00?o0000ooooooooool08_ooool00ol0003oooooooooo`08
ooooo`008Oooool00ol0003oooooooooo`0Zooooo`?o00003Oooool00ol0003oXKc/oj6lk002oj6l
k003o`000?nR^>SoX[SX00;oX[SX00Go0000ojBchonT/n?oY;?So`000004ojF_g`03o`000?nVZm[o
YZ_J00;oYZ_J00Go0000ojNWe_nWYmKoYjOFo`000004ojRSd@05o`000?nYX<goZJ3=ojVPcOl00000
1?nZW<T01Ol0003oZY[6ojZJa_nZV/Ko000000?oZiO200?o0000oj^E_on[UKl00_n[UKl01Ol0003o
Zi>moj^C_On[Tkgo000000CoZi6k00?o0000oj^?^On[SkT00_n[SkT01Ol0003o[8jgojb>]on/S[Oo
000000Co[8fe00Go0000ojb<]?n/S;Co[8bdo`000003ojb;/`03o`000?n/R[;o[8Zb00Co00000_n[
RK400ol0003o[8Vaojb9/@02ojb9/@05o`000?n/RK3o[8V`o`000?n/RK001ol000000on/RK3o0000
o`000003ojb9/0?o[8Za1Ol000000on/R[7o0000ojb:/P03ojb:/P05o`000?n/Rk?o[8^cojb;/ol0
00001?n/S;@01Ol0003o[8feojb=]On/SKGo000000Co[8jg00?o0000ojb?^On/SkT00_n/SkT01Ol0
003oZi6koj^A^on[TK_o000000CoZi>m00Go0000oj^E_on[UKooZiFoo`000004oj^G`P05o`000?nZ
V/GoZY[5ojZJaOl000001?nZW<T00ol0003oZIo=ojVOc@02ojVOc@05o`000?nYXm7oZJ?AojVSdOl0
00001?nXYmD01Ol0003oYj_IojN[fOnWZmWo000000CoYZoN00?o0000ojFch_l000001?l000000onn
e>_o0000o`000002ok_HkP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0027o
oooo00?o0000ooooooooool09oooool3o`00013ooooo00?o0000oj6lk?nQ_>`00_nQ_>`00ol0003o
X[SXoj:hj002oj:hj005o`000?nT/n?oY;?SojBchol000001?nU[ml00ol0003oYZ_JojJ[fP02ojJ[
fP05o`000?nWYmKoYjOFojNWe_l000001?nXXm401Ol0003oZJ3=ojVPcOnYX<go000000CoZYc900Go
0000ojZJa_nZV/KoZY[6o`000003oj^G`P03o`000?n[UKooZiFo00;oZiFo00?o0000oj^C_On[Tkd0
0_n[Tkd01Ol0003oZi6koj^A^on[TK_o000000CoZhni00Go0000ojb>]on/S[Oo[8jgo`000004ojb=
]@06o`000?n/S;Co[8bdojb<]?l0003o[8^c1Ol00002ojZ9/P05o`000?n[RK7oZhVaoj^9/Ol00000
1?n/RK400ol0003o[8V`o`000002ojb9/005o`000?n/RK3o0000o`000?n/RK000_l00003ojb9/004
o`000?n/RK3o[8V`o`0000?o[8Za1?n]Rk43o`0000?o[8Zb00Go0000ojb;/on/Rk?o[8^co`000004
ojb<]005o`000?n/SKGo[8feojb=]Ol000001?n/S[L00ol0003o[8niojb?^@02ojb?^@05o`000?n[
TK_oZi6koj^A^ol000001?n[Tkd01Ol0003oZiFooj^E_on[UKoo000000CoZiO200Go0000ojZJaOnZ
V/GoZY[5o`000004ojZLb@03o`000?nYWlgoZIo=00;oZIo=00Go0000ojVSdOnYXm7oZJ?Ao`000004
ojRWe@05o`000?nWZmWoYj_IojN[fOl000000_nV[mh4o`0000;o_loV00Go0000okkDjonne>_o_]C[
o`000003ok_HkP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0023ooooo00?o
0000ooooooooool09Oooool3o`0001Cooooo00Go0000oj6lk?nQ_>coXKc/o`000005oj:hj005o`00
0?nT/n?oY;?SojBchol000000onU[ml00ol0003oYZ_JojJ[fP02ojJ[fP03o`000?nWYmKoYjOF00;o
YjOF00Go0000ojRSdOnXXm7oZ:?Ao`000003ojVPc@03o`000?nZW<WoZYc900;oZYc900Go0000ojZJ
a_nZV/KoZY[6o`000003oj^G`P03o`000?n[UKooZiFo00?oZiFo00Go0000oj^C_On[TkgoZi>mo`00
0003oj^A^`03o`000?n[SkWoZhni00;oZhni00Go0000ojb>]on/S[Oo[8jgo`000004ojb=]@03o`00
0?n/S;Co000000?o00000_nYRK<00ol0003oZXVbojZ9/P02ojZ9/P05o`000?n[RK7oZhVaoj^9/Ol0
00001?n/RK42o`0000?o[8V`00Go0000ojb9/?l0003o0000ojb9/003o`0000?o[8V`0_l00004ojb:
/@03o`000?n]Rk7o[H^a00;o[H^a0_n]S;84o`0000?o[8^c00?o0000ojb<]?n/S;@00_n/S;@01Ol0
003o[8feojb=]On/SKGo000000Co[8jg00?o0000ojb?^On/SkT00_n/SkT01Ol0003oZi6koj^A^on[
TK_o000000CoZi>m00?o0000oj^E_on[UKl00_n[UKl01Ol0003oZiO2oj^G`_n[Ul;o000000CoZY[5
00Go0000ojZLbOnZW<WoZYc9o`000004ojVOc@05o`000?nYXm7oZJ?AojVSdOl000001?nXYmD00ol0
003oYj_Io`000004o`0000;o`<[R00Co0000oko?i_nocnKo00001?nne>/2o`000003ok_Hk_l0003o
oooo02Gooooo00?o0000ooooooooool02?ooool0023ooooo0_l0000Sooooo`?o00005oooool00ol0
003oXKc/oj6lk002oj6lk003o`000?nR^>SoX[SX00;oX[SX00Go0000ojBchonT/n?oY;?So`000003
ojF_g`03o`000?nVZm[oYZ_J00;oYZ_J00?o0000ojNWe_nWYmH00_nWYmH01Ol0003oZ:?AojRSdOnX
Xm7o000000?oZJ3=00?o0000ojZLbOnZW<T00_nZW<T00ol0003oZY[6ojZJaP02ojZJaP05o`000?n[
Ul;oZiO2oj^G`_l000001?n[UKl01Ol0003oZi>moj^C_On[Tkgo000000?oZi6k00?o0000oj^?^On[
SkT00_n[SkT00ol0003o[8jgo`000008o`0000;oZ8Zd00Go0000ojV9/onYRK?oZHVco`000004ojZ9
/P03o`000?n[RK7oZhVa00;oZhVa00?o0000ojb9/On/RK400_l00003ojb9/003o`000?n/RK3o0000
00;o000000Co[8V`o`000?l0003o00001?n/RK02o`0000?o[8Za00?o0000ojf;/On]Rk400_n]Rk40
0ol0003o[Hbbojf</P02ojf</P?o000000?o[8^co`000?n/S;@00on/S;@01Ol0003o[8feojb=]On/
SKGo000000Co[8jg00?o0000ojb?^On/SkT00_n/SkT01Ol0003oZi6koj^A^on[TK_o000000CoZi>m
00?o0000oj^E_on[UKl00_n[UKl01Ol0003oZiO2oj^G`_n[Ul;o000000CoZY[500Go0000ojZLbOnZ
W<WoZYc9o`000004ojVOc@05o`000?nYXm7oZJ?AojVSdOl000000_nXYmD4o`0000;o`<CM00Go0000
ol3:h_o0b^;o`<[Ro`000003oko?iP03o`000?nne>_o_]C[00;o_]C[00Co0000ok_Hk_l0003o0000
9_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Pooooo`;o00006_oo
ool00ol0003oXKc/oj6lk002oj6lk003o`000?nR^>SoX[SX00;oX[SX00Go0000ojBchonT/n?oY;?S
o`000004ojF_g`05o`000?nVZm[oYZ_JojJ[f_l000001?nWYmH01Ol0003oZ:?AojRSdOnXXm7o0000
00CoZJ3=00Go0000ojZLbOnZW<WoZYc9o`000004ojZJaP05o`000?n[Ul;oZiO2oj^G`_l000001?n[
UKl01Ol0003oZi>moj^C_On[Tkgo000000?oZi6k00?o0000oj^?^On[SkT01?l00002ojJ;^003o`00
0?nWR[KoYhZf00;oYhZf00Go0000ojR:]?nXR[CoZ8Zdo`000004ojV9/`05o`000?nZRK;oZXVbojZ9
/_l000001?n[RK401Ol0003o[8Vao`000?n[RK7o000000?o[8V`00?o0000ojb9/?l000000_l00000
0on/RK3o0000o`000002o`0000?o[8V`0_n]R[401?l0003o[8Zaojb:/Ol00004ojf;/@03o`000?n]
S;;o[Hbb00;o[Hbb0on^SK<9o`000003ojb=]Ol0003o[8jg00?o[8jg00?o0000ojb?^On/SkT00_n/
SkT01Ol0003oZi6koj^A^on[TK_o000000CoZi>m00?o0000oj^E_on[UKl00_n[UKl01Ol0003oZiO2
oj^G`_n[Ul;o000000CoZY[500Go0000ojZLbOnZW<WoZYc9o`000004ojVOc@03o`000?nYXm7o0000
00Co00000_o0_]P01Ol0003o`<CMol34gOo0a=go000000?o`<[R00Go0000oko?i_nocnKo_loVo`00
0003okkDj`05o`000?nkf>ko^mS^ok_Hk_l000009oooool00ol0003oooooooooo`07ooooo`008?oo
ool00ol0003oooooooooo`0Mooooo`?o00007Oooool01Ol0003oXKc/oj6lk?nQ_>co000000CoX[SX
00Go0000ojBchonT/n?oY;?So`000004ojF_g`05o`000?nVZm[oYZ_JojJ[f_l000001?nWYmH01Ol0
003oZ:?AojRSdOnXXm7o000000CoZJ3=00?o0000ojZLbOnZW<T00_nZW<T01Ol0003oZY[6ojZJa_nZ
V/Ko000000?oZiO200?o0000oj^E_on[UKl00_n[UKl00ol0003oZi>mo`000008o`0000;oY8^j1?nV
RkP00ol0003oYhZfojN:]P02ojN:]P05o`000?nXR[CoZ8ZdojR:]?l000001?nYRK<00ol0003oZXVb
ojZ9/P02ojZ9/P04o`000?n[RK7oZhVaoj^9/@;o00000on[RK400ol0003o[8V`o`000002ojb9/0Ko
000000?o[8V`o`000?l000000_n/RK001_l0003o[HZaojf:/Ol0003o[8Zao`0000Co[H^a00?o0000
ojf</_n]S;800_n]S;84ojj=/`Go[hnd0on`T;H5o`000003ojb>]ol0003o[8ni00?o[8ni00Go0000
oj^A^on[TK_oZi6ko`000004oj^C_@03o`000?n[UKooZiFo00;oZiFo00Go0000oj^G`_n[Ul;oZiO2
o`000004ojZJa@03o`000?nZW<Wo000000So00000_no^=<00ol0003o`;kHol2nf002ol2nf004o`00
0?o0a=go`<CMo`0000Co`<[R00Co0000oko?i_nocnKo00001?nne>/00ol0003o^mS^ok_HkP02o`00
02Oooooo00?o0000ooooooooool01oooool0023ooooo00?o0000ooooooooool06_ooool3o`00023o
oooo00Go0000oj6lk?nQ_>coXKc/o`000005oj:hj005o`000?nT/n?oY;?SojBchol000000onU[ml0
1Ol0003oYZ_JojJ[f_nVZm[o000000CoYjOF00?o0000ojRSdOnXXm400_nXXm401Ol0003oZJ3=ojVP
cOnYX<go000000CoZYc900Go0000ojZJa_nZV/KoZY[6o`000003oj^G`P03o`000?n[UKooZiFo00Co
00000_nOS;l4oj:;_0GoY8^j00Go0000ojJ;^?nVRkSoYX^ho`000004ojN:]P03o`000?nXR[CoZ8Zd
00;oZ8Zd00Go0000ojV9/onYRK?oZHVco`000004ojZ9/P03o`000?n[RK7oZhVa00;o00001?n[RK40
1_l0003o[8V`o`000?n/RK3o0000ojb9/0;o000000Ko[8V`o`000?l0003o[8V`o`000?n/RK02o`00
00Co[HZa0_l00003ojf;/@03o`000?n]S;;o[Hbb00?o[Hbb00Co0000ojj=/on^SK?o[Xfc1On_Sk@4
ok2@]P04o`000?naTkOo/I>gok6C]aoo00000_nl[L/00ol0003o_K??okfcc`02okfcc`05o`000?no
^=?o_kSCoknhdol000000oo0_]P01Ol0003o`<CMol34gOo0a=go000000?o`<[R00Go0000oko?i_no
cnKo_loVo`000003okkDj`07o`000?nkf>ko^mS^ok_Hk_l0003oooooo`00000Vooooo`03o`000?oo
oooooooo00Oooooo000Pooooo`?o00005oooool3o`0002?ooooo00?o0000oj6lk?nQ_>`00_nQ_>`0
0ol0003oX[SXoj:hj002oj:hj005o`000?nT/n?oY;?SojBchol000000onU[ml00ol0003oYZ_JojJ[
fP02ojJ[fP03o`000?nWYmKoYjOF00;oYjOF00Go0000ojRSdOnXXm7oZ:?Ao`000003ojVPc@03o`00
0?nZW<WoZYc900;oZYc900?o0000ojZJa_l000002?l00002oif=`PCoWhbo00Go0000oj:;_?nRRkco
XX^lo`000005ojB;^PCoYX^h00?o0000ojN:]_nWR[H00_nWR[H01Ol0003oZ8ZdojR:]?nXR[Co0000
00?oZHVc00?o0000ojZ9/_nZRK800_nZRK801Ol0003oZhVao`000?n[RK;o000000GoZhVa00Go0000
ojb9/?n/RK3o0000ojb9/002o`000003ojb9/?l0003o[8V`00;o[8V`00?o0000ojb9/?l000001On]
R[42o`0000;o[H^a00?o0000ojf</_n]S;800on]S;801Ol0003o[Xfcojj=/on^SK?o000000Co[hnd
1?n`T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo/YJi00;o/YJi00Go0000okBH^ondV;_o
]9Rko`000004okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co^JC4o`000004okZX
a`05o`000?nl[L_o_:g;okb]bol000001?nm/ll01?l0003o_kSCoknhdol00004ol2nf005o`000?o0
a=go`<CMol34gOl000000oo0b^801Ol0003o_loVoko?i_nocnKo000000?o_]C[00Co0000ok_Hk_nk
f>ko00000oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Oooooo000Oooooo`;o
00005_ooool3o`0002Oooooo00Go0000oj6lk?nQ_>coXKc/o`000004oj:hj005o`000?nT/n?oY;?S
ojBchol000000onU[ml00ol0003oYZ_JojJ[fP02ojJ[fP03o`000?nWYmKoYjOF00;oYjOF00Ko0000
ojRSdOnXXm7oZ:?Ao`000?nYX<d9o`0000;oUXo91?nJS/H5oif=`P03o`000?nOS;ooWhbo00;oWhbo
1?nRRk`5ojB;^P05o`000?nVRkSoYX^hojJ;^?l000001?nWR[H01Ol0003oZ8ZdojR:]?nXR[Co0000
00?oZHVc00?o0000ojZ9/_nZRK800_nZRK82o`0000?oZhVb00?o0000oj^9/On[RK400_n[RK401Ol0
003o[8V`ojb9/?l0003o[8V`00;o000000?o[8V`o`000?n/RK000_n/RK000ol0003o[8V`o`000005
ojf:/@;o[H^b00?o0000ojf;/Ol000001On]S;801Ol0003o[Xfcojj=/on^SK?o000000?o[hnd00?o
0000ok2@]_n`T;H00_n`T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo/YJi00;o/YJi00Go
0000okBH^ondV;_o]9Rko`000004okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co
^JC4o`000004okZXa`04o`000?nl[L_o_:g;o`0000Co_K??00Go0000oknhdono^=?o_kSCo`000004
ol2nf004o`000?o0a=go`<CMo`0000Co`<[R00Co0000oko?i_nocnKo00000onne>/01Ol0003o^mS^
ok_Hk_nkf>ko000000Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`00
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`?o0000:_ooool01Ol0003oXKc/oj6lk?nQ_>co
000000GoX[SX00Go0000ojBchonT/n?oY;?So`000003ojF_g`03o`000?nVZm[o000000co00000_n=
TM85oi:@cPCoUXo900Go0000oiZ>a_nJS/KoVXk6o`000005oif=`PCoWhbo00Go0000oj:;_?nRRkco
XX^lo`000004ojB;^P05o`000?nVRkSoYX^hojJ;^?l000001?nWR[H01Ol0003oZ8ZdojR:]?nXR[Co
000000CoZHVc00?o0000ojZ9/_nZRK800_l00004oj^9/P06o`000?n[RK7oZhVaoj^9/Ol0003oZhVa
0_l000002On/RK3o0000ojb9/?l0003o[8V`o`000?n/RK3o0000ojb9/002o`000003ojf:/Ol0003o
[HZa00;o[HZa00Co0000ojf;/_n]Rk;o[H^b0_l00004ojf</P03o`000?n^SK?o[Xfc00;o[Xfc00Go
0000ojn?]?n_SkCo[hndo`000004ok2@]P03o`000?naTkOo/I>g00;o/I>g00?o0000ok:F^OnbU[T0
0_nbU[T01Ol0003o]9RkokBH^ondV;_o000000Co]Ibn00?o0000okNO`OngWl400_ngWl401Ol0003o
^JC4okVTa?niY<Co000000?o^ZS700Go0000okb]bonl[L_o_:g;o`000004okfcc`05o`000?no^=?o
_kSCoknhdol000001?o0_]P01?l0003o`<CMol34gOl00003ol3:hP05o`000?nocnKo_loVoko?i_l0
00000onne>/01?l0003o^mS^ok_Hk_l00005ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0ol0000]ooooo`03o`000?nQ_>coXKc/
00;oXKc/00?o0000oj:hj?nR^>P03?l00002ogfGhPGoPiGL1?n8TmL5ohfAdPCoTY3>00?o0000oiJ?
bOnFSlT00_nFSlT4oiZ>aPGoWHg200Go0000oin<_onOS;ooWhboo`000003oj:;_003o`000?nTRk[o
Y8^j00;oY8^j00Go0000ojJ;^?nVRkSoYX^ho`000004ojN:]P05o`000?nXR[CoZ8ZdojR:]?l00000
1?nYRK<3o`000003ojV9/ol0003oZhVb00CoZhVb00?o0000oj^9/Ol000000on[RK401Ol0003o[8V`
o`000?n/RK3o000000?o[8V`00Co0000ojb9/?n/RK3o00000_n]R[401?l0003o[HZaojf:/Ol00004
ojf;/P;o00000on]S;800ol0003o[Xfcojj=/`02ojj=/`05o`000?n_SkCo[hndojn?]?l000001?n`
T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo/YJi00;o/YJi00Go0000okBH^ondV;_o]9Rk
o`000003okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co^JC4o`000004okZXa`05
o`000?nl[L_o_:g;okb]bol000001?nm/ll01Ol0003o_kSCoknhdono^=?o000000?o`;kH00Go0000
ol34gOo0a=go`<CMo`000003ol3:hP05o`000?nocnKo_loVoko?i_l000000onne>/01?l0003o^mS^
ok_Hk_l00006ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool000Cooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03?ooool3o`00037ooooo1ol00002offPk`CoLIg[1?mgV^L5ogfGhPGoPiGL1?n8TmL4ohfAdPGo
TY3>1?nFSlT01Ol0003oVXk6oiZ>a_nJS/Ko000000CoWHg200Go0000oin<_onOS;ooWhboo`000004
oj:;_003o`000?nTRk[oY8^j00;oY8^j00Co0000ojJ;^?nVRkSo00001?nWR[H01Ol0003oZ8ZdojR:
]?nXR[Co000000?oZHVc0_l00004ojV9/`03o`000?n[RK;oZhVb00;oZhVb00?o0000oj^9/Ol00000
0on[RK43o`000003ojb9/?l0003o[8V`00;o[8V`00Co0000ojb9/?n/RK3o00000on]R[400ol0003o
[HZao`000004ojf;/P;o[Xfc0_l000000on]S;;o0000ojj=/`02ojj=/`03o`000?n_SkCo[hnd00;o
[hnd00?o0000ok2@]_n`T;H00_n`T;H01Ol0003o/I>gok6C]onaTkOo000000Co/YJi00?o0000okBH
^ondV;/00_ndV;/01Ol0003o]IbnokFL__neW;ko000000Co]io100Go0000okVTa?niY<Co^JC4o`00
0004okZXa`05o`000?nl[L_o_:g;okb]bol000001?nm/ll01Ol0003o_kSCoknhdono^=?o000000?o
`;kH00Go0000ol34gOo0a=go`<CMo`000003ol3:hP04o`000?nocnKo_loVo`0000?o_]C[00Go0000
ok_Hk_nkf>ko^mS^o`000007ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool000Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0
000:ooooo`?o0000=?ooool01Ol0003oJJCcofVTlomYY??o000000GoKJ3_1?maWN/4ogNJi`CoOIOR
00?o0000oh>Eg?n3UM`00_n3UM`01Ol0003oR9?GohRCeon8TmOo000000?oSI7B00?o0000oi:@c_nB
T<h00_nBT<h01Ol0003oUXo9oiJ?bOnFSlWo000000?oVXk600?o0000oif=`_nMSL800_nMSL800ol0
003oWhbooin<_`02oin<_`05o`000?nRRkcoXX^loj:;_?l000001?nTRkX01Ol0003oYX^hojJ;^?nV
RkSo000000?oYhZf00?o0000ojR:]?nXR[@00_nXR[@01Ol0003oZHVco`000?nXRKCo000000CoZHVc
00?o0000oj^9/_n[RK800on[RK801Ol0003oZhVaoj^9/On[RK7o000000;oZhVa00?o0000ojb9/?l0
00001On/RK000ol0003o[HZao`000003ojf:/@03o`000?n]Rk;o[H^b00?o[H^b1?n^SK<2o`0000?o
[Xfc00?o0000ojn?]?n_Sk@00_n_Sk@00ol0003o/92fok2@]P02ok2@]P05o`000?naTkOo/I>gok6C
]ol000001?nbU[T01Ol0003o]9RkokBH^ondV;_o000000Co]Ibn00?o0000okNO`OngWl400_ngWl40
1Ol0003o^JC4okVTa?niY<Co000000Co^ZS700Go0000okb]bonl[L_o_:g;o`000004okfcc`04o`00
0?no^=?o_kSCo`0000Co`;kH00Co0000ol34gOo0a=go00000oo0b^801Ol0003o_loVoko?i_nocnKo
000000?o_]C[00Co0000ok_Hk_nkf>ko00002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3o`0003Sooooo00Go0000ofVTlomYY??o
JJCco`000005offPk`?oLIg[00Go0000ogNJiomgV^OoMi[Wo`000004ogfGhPCoPiGL00Go0000ohRC
eon8TmOoR9?Go`000004ohfAdP05o`000?nBT<koTY3>oi:@c_l000001?nFSlT01Ol0003oVXk6oiZ>
a_nJS/Ko000000CoWHg200Go0000oin<_onOS;ooWhboo`000003oj:;_003o`000?nTRk[oY8^j00;o
Y8^j00Go0000ojJ;^?nVRkSoYX^ho`000003ojN:]P03o`000?nXR[CoZ8Zd00;oZ8Zd0_l00003ojR9
]003o`000?nYRK?oZHVc00;oZHVc00Co0000oj^9/_n[RK;oZhVb0_l00003oj^9/@03o`000?n[RK7o
ZhVa00?o00000on/RK02o`0000;o[HZa00Go0000ojf:/On]R[7o[HZao`000004ojf;/P03o`000?n^
SK?o[Xfc00?o[Xfc0_l00002ojj=/`03o`000?n_SkCo[hnd00;o[hnd00?o0000ok2@]_n`T;H00_n`
T;H01Ol0003o/I>gok6C]onaTkOo000000Co/YJi00Go0000okBH^ondV;_o]9Rko`000004okFL_P03
o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co^JC4o`000004okZXa`04o`000?nl[L_o_:g;
o`0000Co_K??00Go0000oknhdono^=?o_kSCo`000003ol2nf005o`000?o0a=go`<CMol34gOl00000
0oo0b^801Ol0003o_loVoko?i_nocnKo000000;o_]C[00Go0000ok_Hk_nkf>ko^mS^o`000009oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`00
03cooooo00Go0000ofVTlomYY??oJJCco`000004offPk`05o`000?maWN_oLIg[og6Mjol000000omg
V^L00ol0003oOIORogfGhP02ogfGhPCoPiGL00Go0000ohRCeon8TmOoR9?Go`000003ohfAdP03o`00
0?nBT<koTY3>00;oTY3>00Go0000oiJ?bOnFSlWoUXo9o`000003oiZ>aP03o`000?nMSL;oWHg200;o
WHg200Go0000oin<_onOS;ooWhboo`000004oj:;_005o`000?nTRk[oY8^jojB;^_l000000onVRkP0
0ol0003oYhZfojN:]P02ojN:]P03o`000?nXR[CoZ8Zd00;o00001?nXRK@00ol0003oZHVcojV9/`02
ojV9/`04o`000?n[RK;oZhVbo`0000;oZXVb00?o0000oj^9/Ol000000on[RK400ol0003o[8Zao`00
0003o`000003ojb:/Ol0003o[HZa00Co[HZa00?o0000ojj</_l000000on]Rk800ol0003o[Xfcojj=
/`03ojj=/`;o/8nd00?o0000ojj=/ol000001?n_Sk@01Ol0003o/92fok2@]_n`T;Ko000000Co/I>g
00?o0000ok:F^OnbU[T00_nbU[T01Ol0003o]9RkokBH^ondV;_o000000Co]Ibn00?o0000okNO`Ong
Wl400_ngWl401Ol0003o^JC4okVTa?niY<Co000000?o^ZS700Go0000okb]bonl[L_o_:g;o`000004
okfcc`05o`000?no^=?o_kSCoknhdol000000oo0_]P01Ol0003o`<CMol34gOo0a=go000000?o`<[R
00Co0000oko?i_nocnKo00000onne>/01?l0003o^mS^o`000?l0000;ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0ol00010ooooo`05o`000?mYY??o
JJCcofVTlol000001?m]X>l01Ol0003oLIg[og6MjomaWN_o000000?oMi[W00Go0000ogfGh_mmUn;o
OIORo`000003oh>Eg005o`000?n8TmOoR9?GohRCeol000001?n=TM801Ol0003oTY3>oi:@c_nBT<ko
000000?oUXo900Go0000oiZ>a_nJS/KoVXk6o`000004oif=`P03o`000?nOS;ooWhbo00;oWhbo00Go
0000oj:;_?nRRkcoXX^lo`000003ojB;^P05o`000?nVRkSoYX^hojJ;^?l000001?nWR[H3o`000003
ojJ9]_l0003oZ8Vd00?oZ8Vd00?o0000ojV9/onYRK<00_nYRK<00ol0003oZhVbo`000003ojZ9/P03
o`000?n[RK7o000000?oZhVa00?o0000ojb:/Ol000000_n/R[400ol0003o[8Zao`000003ojf:/@03
o`000?n]R[7o000000;o[Xbb00Co0000ojf;/_n]Rk;o00001?n^SK<01?l0003o/8ndok2?]?n`Sk@2
o`0000?o[hnd00?o0000ok2@]_n`T;H00_n`T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo
/YJi00;o/YJi00Go0000okBH^ondV;_o]9Rko`000004okFL_P03o`000?ngWl7o]io100;o]io100Go
0000okVTa?niY<Co^JC4o`000003okZXa`05o`000?nl[L_o_:g;okb]bol000001?nm/ll01Ol0003o
_kSCoknhdono^=?o000000?o`;kH00Go0000ol34gOo0a=go`<CMo`000002ol3:hP05o`000?nocnKo
_loVoko?i_l000000onne>/3o`0000gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`06ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`Co0000A?oo
ool01Ol0003oJJCcofVTlomYY??o000000CoKJ3_00Co0000og6MjomaWN_o00000omgV^L00ol0003o
OIORogfGhP02ogfGhPCoPiGL00Go0000ohRCeon8TmOoR9?Go`000003ohfAdP05o`000?nBT<koTY3>
oi:@c_l000001?nFSlT01Ol0003oVXk6oiZ>a_nJS/Ko000000CoWHg200Go0000oin<_onOS;ooWhbo
o`000003oj:;_003o`000?nTRk[oY8^j00;oY8^j00Co0000ojJ;^?nVRkSo00000onWR[H2o`0000Co
YXVf00?o0000ojR9]?nXRK@00_nXRK@00ol0003oZHVcojV9/`02ojV9/`03o`000?nZRK;oZXVb00?o
ZXVb00?o0000oj^9/On[RK400_n[RK400ol0003o[8Zao`000002ojb:/@04o`000?n/R[7o[8Zao`00
00;o[HZa00?o0000ojf:/Ol000000_n^S;801?l0003o[H^bojf;/_l00004ojj=/`03o`000?n`SkCo
/8nd00;o/8nd0_l00002ojn?]003o`000?n`T;Ko/92f00;o/92f00?o0000ok6C]onaTkL00_naTkL0
0ol0003o/YJiok:F^@02ok:F^@05o`000?ndV;_o]9RkokBH^ol000001?neW;h00ol0003o]io1okNO
`@02okNO`@05o`000?niY<Co^JC4okVTa?l000000onjZ<L01Ol0003o_:g;okb]bonl[L_o000000Co
_K??00Go0000oknhdono^=?o_kSCo`000003ol2nf004o`000?o0a=go`<CMo`0000?o`<[R00Co0000
oko?i_nocnKo_loV1?l000000onnnNgo0000ooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool001kooooo0_l00017ooooo`04o`000?mYY??oJJCco`0000CoKJ3_00Go
0000og6MjomaWN_oLIg[o`000003ogNJi`05o`000?mmUn;oOIORogfGh_l000000on3UM`01Ol0003o
R9?GohRCeon8TmOo000000?oSI7B00?o0000oi:@c_nBT<h00_nBT<h01Ol0003oUXo9oiJ?bOnFSlWo
000000?oVXk600?o0000oif=`_nMSL800_nMSL801Ol0003oWhbooin<_onOS;oo000000?oXX^l00?o
0000ojB;^_nTRkX00_nTRkX02Ol0003oYX^hojJ;^?nVRkSo0000ojN:]_l0003oY8Vho`000004ojJ9
]P03o`000?nXRKCoZ8Vd00;oZ8Vd00?o0000ojV9/onYRK<00_nYRK<00ol0003oZXVbojZ9/P03ojZ9
/P;o00000_n[RK401?l0003o[8Zaojb:/Ol00002ojb:/@04o`000?n/R[7o[8Zao`0000?o[HZa00?o
0000ojj</_n^S;800_n^S;82o`0000Go[Xfc00?o0000ok2?]?n`Sk@00_n`Sk@2ok6A]P?o00001?n`
T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo/YJi00;o/YJi00Go0000okBH^ondV;_o]9Rk
o`000003okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co^JC4o`000004okZXa`05
o`000?nl[L_o_:g;okb]bol000001?nm/ll01?l0003o_kSCoknhdol00003ol2nf005o`000?o0a=go
`<CMol34gOl000000oo0b^800ol0003o_loVo`000002o`0000;oaOS/0_l0000@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0AOooool0
1?l0003oJJCcofVTlol00004offPk`04o`000?maWN_oLIg[o`0000?oMi[W00?o0000ogfGh_mmUn80
0_mmUn801Ol0003oPiGLoh>Eg?n3UMco000000?oR9?G00Go0000ohfAd_n=TM;oSI7Bo`000003oi:@
cP05o`000?nFSlWoUXo9oiJ?bOl000000onJS/H00ol0003oWHg2oif=`P02oif=`P05o`000?nOS;oo
Whbooin<_ol000001?nRRk`01Ol0003oY8^jojB;^_nTRk[o000000?oYX^h0_l00003ojB9^003o`00
0?nVRKKoYXVf00;oYXVf00?o0000ojR9]?nXRK@00_nXRK@01_l0003oZHVcojV9/ol0003oZHVdo`00
00CoZXVb00Go0000oj^:/ol0003oZhVao`000002ojb:/@04o`000?n/R[7o[8Zao`0000;o[8Za00?o
0000ojf:/On]R[400_l00005ojj</P03o`000?n^SK?o[Xfc00;o[Xfc00?o0000ok2?]?n`Sk@00on`
Sk@4ok6A]P;o00000on`T;H00ol0003o/I>gok6C]`02ok6C]`03o`000?nbU[Wo/YJi00;o/YJi00Go
0000okBH^ondV;_o]9Rko`000003okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co
^JC4o`000004okZXa`04o`000?nl[L_o_:g;o`0000Co_K??00Go0000oknhdono^=?o_kSCo`000003
ol2nf005o`000?o0a=go`<CMol34gOl000000_o0b^83o`000004ol_ejol0003oaOS/olGhk0;o0000
4_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oo
oooooooo04Gooooo00Co0000ofVTlomYY??o00001?m]X>l01?l0003oLIg[og6Mjol00003ogNJi`05
o`000?mmUn;oOIORogfGh_l000000on3UM`01Ol0003oR9?GohRCeon8TmOo000000?oSI7B00Go0000
oi:@c_nBT<koTY3>o`000003oiJ?b@03o`000?nJS/KoVXk600;oVXk600Go0000oif=`_nMSL;oWHg2
o`000004oin<_`05o`000?nRRkcoXX^loj:;_?l000000onTRkX00ol0003oYX^hojJ;^002o`0000Co
Y8Vh00?o0000ojJ9]_nVRKH00_nVRKH00ol0003oZ8VdojR9]002ojR9]003o`000?nYRK?o000000;o
ZHVd00Go0000ojZ9/_nZRK;oZXVbo`000003oj^:/`;o00000_n/R[400ol0003o[8Zaojb:/@04ojb:
/@05ojf:/Ol0003o[Hbbojf</_l000001?n^S;800on_S[?o0000ojj=/`02ojj=/`03o`000?n`SkCo
/8nd00;o/8nd00?o0000ok6A]_naTKH00_naTKH01_l0003o/iBgo`000?l0003o/92fo`0000?o/I>g
00?o0000ok:F^OnbU[T00onbU[T01Ol0003o]9RkokBH^ondV;_o000000?o]Ibn00?o0000okNO`Ong
Wl400_ngWl401Ol0003o^JC4okVTa?niY<Co000000?o^ZS700Go0000okb]bonl[L_o_:g;o`000004
okfcc`05o`000?no^=?o_kSCoknhdol000000oo0_]P01Ol0003o`<CMol34gOl0003o`<[R00?o0000
0_o;mN/00ol0003oaOS/olGhk002o`0001Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`05ooooo`008_ooool00ol0003oooooooooo`14ooooo`05o`000?mYY??oJJCcofVTlol00000
1?m]X>l01?l0003oLIg[og6Mjol00003ogNJi`05o`000?mmUn;oOIORogfGh_l000000_n3UM`01Ol0
003oR9?GohRCeon8TmOo000000CoSI7B00Go0000oi:@c_nBT<koTY3>o`000003oiJ?b@05o`000?nJ
S/KoVXk6oiZ>a_l000001?nMSL801Ol0003oWhbooin<_onOS;oo000000?oXX^l00?o0000ojB;^_nT
RkX00_nTRkX2o`000003oj69^ol0003oY8Vh00?oY8Vh00?o0000ojJ9]_nVRKH00onVRKH01ol0003o
Z8VdojR9]?nXRKCo0000ojV9/ol000000onYRK@01?l0003oZXVbojZ9/_l00004oj^:/`;o000000?o
[8Zao`000?n/R[401?n/R[42o`0000?o[Hbb00Go0000ojj</_n^S;;o[Xbbo`000002ojn>/`04o`00
0?n^SK?o[Xfco`0000Co/8nd00?o0000ok6A]_naTKH00_naTKH01?l0003o/iBgok>D]oncU;L2o`00
00?o/I>g00?o0000ok:F^OnbU[T00_nbU[T00ol0003o]9RkokBH^`02okBH^`05o`000?neW;ko]Ibn
okFL__l000001?ngWl401Ol0003o^JC4okVTa?niY<Co000000?o^ZS700Go0000okb]bonl[L_o_:g;
o`000004okfcc`05o`000?no^=?o_kSCoknhdol000000oo0_]P00ol0003o`<CMo`000002o`0000;o
co3Y00?o0000ol_ejol000000_o5n>`2o`0001Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`05ooooo`008oooool2o`0004Gooooo00Go0000ofVTlomYY??oJJCco`000003offPk`04
o`000?maWN_oLIg[o`0000?oMi[W00Go0000ogfGh_mmUn;oOIORo`000003oh>Eg005o`000?n8TmOo
R9?GohRCeol000000on=TM801Ol0003oTY3>oi:@c_nBT<ko000000?oUXo900Go0000oiZ>a_nJS/Ko
VXk6o`000004oif=`P05o`000?nOS;ooWhbooin<_ol000001?nRRk`00ol0003oY8^jo`000002o`00
00?oXHVk00?o0000ojB9^?nTRKP00_nTRKP00ol0003oYXVfojJ9]P02ojJ9]P03o`000?nXRKCoZ8Vd
00;oZ8Vd00?o0000ojV9]?nYRK@00onYRK@00ol0003oZXVbo`000004oj^:/`04o`000?n[Rk?o0000
o`0000Co[8Za00?o0000ojf</ol000001?n]S;801?l0003o[Xbbojj</_l00003ojn>/`;o00001On`
Sk@01Ol0003o/I6fok6A]_naTKKo000000Go/iBg0ol000000onaTkOo0000ok:F^@03ok:F^@05o`00
0?ndV;_o]9RkokBH^ol000001?neW;h00ol0003o]io1okNO`@02okNO`@05o`000?niY<Co^JC4okVT
a?l000000onjZ<L01Ol0003o_:g;okb]bonl[L_o000000Co_K??00Go0000oknhdono^=?o_kSCo`00
0002ol2nf0?o000000Ood^[Vo`000?o?l>Woco3Yo`000?o;mN_o000000;oaOS/0_l0000Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool002Gooooo00?o0000ooooooooool0
@oooool01?l0003oJJCcofVTlol00004offPk`04o`000?maWN_oLIg[o`0000?oMi[W00Go0000ogfG
h_mmUn;oOIORo`000002oh>Eg005o`000?n8TmOoR9?GohRCeol000000on=TM801Ol0003oTY3>oi:@
c_nBT<ko000000?oUXo900?o0000oiZ>a_nJS/H00_nJS/H01Ol0003oWHg2oif=`_nMSL;o000000?o
Whbo00Co0000oj:;_?nRRkcoXX^l0ol00002oif9_@05o`000?nQRK_oXHVkoj69^ol000001?nTRKP0
0ol0003oYXVfojJ9]P02ojJ9]P03o`000?nXRKCoZ8Vd00;oZ8Vd00?o0000ojV9]?nYRK@00onYRK@2
o`0000GoZhZc00?o0000oj^;/on[Rk<01Ol00002ojf</`03o`000?n]S;;o[Hbb00;o[Hbb00?o0000
ojj</_l000001On_S[<00ol0003o/8ndok2?]002ok2?]003o`000?naTKKo/I6f00;o/I6f00?o0000
ok>D]oncU;L00oncU;L00ol0003o]YRjokJH^P03o`0000?o/YJi00Go0000okBH^ondV;_o]9Rko`00
0004okFL_P03o`000?ngWl7o]io100;o]io100Go0000okVTa?niY<Co^JC4o`000003okZXa`05o`00
0?nl[L_o_:g;okb]bol000001?nm/ll01Ol0003o_kSCoknhdol0003o`;kH00?o00000_oBj^H01_l0
003oco3Yolo`jOl0003oboG[o`0000;oaOS/0_l0000Iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01Oooool002Kooooo00?o0000ooooooooool0@oooool01?l0003oJJCcofVTlol0
0004offPk`03o`000?maWN_o000000?oMi[W00?o0000ogfGh_mmUn800_mmUn801?l0003oPiGLoh>E
g?l00003ohRCe`05o`000?n=TM;oSI7BohfAd_l000000onBT<h01Ol0003oUXo9oiJ?bOnFSlWo0000
00?oVXk600Go0000oif=`_nMSL;oWHg2o`000004oin<_`?o000000?oV8S1oif9_OnMRKd00onMRKd0
1Ol0003oXHVkoj69^onQRK_o000000CoY8Vh00?o0000ojJ9]_nVRKH00_nVRKH01_l0003oZ8VdojR9
]?l0003oYhVfo`0000GoZHVd00?o0000oj^:/on[R[<00_n[R[<01Ol0003oZh^coj^;/on[Rk?o0000
00?o[8^c00Go0000ojf</on]S;?o[Hbco`000003ojf</P03o`000?n^S;;o000000Go[hjc00?o0000
ok2?]?n`Sk@00_n`Sk@00ol0003o/I6fok6A]P02ok6A]P03o`000?ncU;Oo/iBg00?o/iBg00Ko0000
okJH^_nfV;[o]YRjo`000?nhW;`4o`0000?o]9Rk00?o0000okFL__neW;h00_neW;h00ol0003o]io1
okNO`@02okNO`@05o`000?niY<Co^JC4okVTa?l000000onjZ<L01?l0003o_:g;okb]bol00004okfc
c`03o`000?no^=?o000000?o00000_oCh^800ol0003od^[Vo`000002olo`j@05o`000?o;mN_oboG[
o`000?o5n>`00_l0000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0
02Oooooo00?o0000ooooooooool0@oooool01?l0003oJJCcofVTlol00003offPk`04o`000?maWN_o
LIg[o`0000?oMi[W00Go0000ogfGh_mmUn;oOIORo`000002oh>Eg005o`000?n8TmOoR9?GohRCeol0
00000on=TM801Ol0003oTY3>oi:@c_nBT<ko000000?oUXo900Go0000oiZ>a_nJS/KoVXk6o`000004
oif=`P03o`000?nOS;oo000000;o00001?nHR<44oif9_@05o`000?nQRK_oXHVkoj69^ol000001?nT
RKP00ol0003oYXVfojJ9]P02ojJ9]P03o`000?nXRKCo000000?oYhVf00?o0000ojV9]?nYRK@00_nY
RK@2o`0000?oZhZc00Go0000oj^;/on[Rk?oZh^co`000003ojb;/`05o`000?n]S;?o[Hbcojf</ol0
00001?n]S;800ol0003o[hjcojn>/`03ojn>/`03o`000?n`TKGo000000?o/8nd00?o0000ok6A]_na
TKH00_naTKH00ol0003o/iBgok>D]`02ok>D]`03o`000?nfV;[o]YRj00;o]YRj00?o0000okRL_?nh
W;`00_nhW;`3o`000003okBH^ol0003o]Ibn00;o]Ibn00?o0000okNO`OngWl400_ngWl401Ol0003o
^JC4okVTa?niY<Co000000?o^ZS700Go0000okb]bonl[L_o_:g;o`000002okfcc`Co00000_oAf=h0
1?l0003odn;Rom?Rh_l00002om;ZiP07o`000?o?l>Woco3Yo`000?o;mN_o0000olGhk002o`0001co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`00:?ooool2o`0004Cooooo
00Co0000ofVTlomYY??o00000om]X>l01?l0003oLIg[og6Mjol00003ogNJi`05o`000?mmUn;oOIOR
ogfGh_l000000_n3UM`01Ol0003oR9?GohRCeon8TmOo000000?oSI7B00Co0000oi:@c_nBT<ko0000
0onFSlT00ol0003oVXk6oiZ>aP02oiZ>aP03o`000?nMSL;o000000?o00000_nCR<D5oiR8`@05o`00
0?nMRKgoWHVmoif9_Ol000000onQRK/00ol0003oY8VhojB9^002ojB9^003o`000?nVRKKoYXVf00?o
YXVf00?o0000ojN9]_nWRKH00_nWRKH01Ol0003oZHVdojV9]?nYRKCo000000;oZHZd00Co0000oj^:
/on[R[?o00000on[Rk<01Ol0003o[8^cojb;/on/Rk?o000000?o[Hbc00Co0000ojf</_n]S;;o[Hbb
0_l00005ojn>/`04o`000?n`TKGo/96eo`0000;o/8nd00Go0000ok6A]_naTKKo/I6fo`000005ok>D
]`05o`000?nfV;[o]YRjokJH^_l000001OnhW;`00ol0003o^j6ook^Q_`04o`000003okFL__l0003o
]io100?o]io100Go0000okVTa?niY<Co^JC4o`000003okZXa`03o`000?nl[L_o000000Co00000_o?
cmT01?l0003odMSNom7Hg_l00003om?RhP03o`000?oBj^Ko000000;oco3Y00Co0000ol_ejol0003o
aOS/0_l0000Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002[ooooo
00?o0000ooooooooool0@_ooool:o`0000?oMi[W00Go0000ogfGh_mmUn;oOIORo`000002oh>Eg005
o`000?n8TmOoR9?GohRCeol000000on=TM801Ol0003oTY3>oi:@c_nBT<ko000000?oUXo900?o0000
oiZ>a_l000000ol00002ohb7b@GoThS51OnHR<401Ol0003oWHVmoif9_OnMRKgo000000?oXHVk00?o
0000ojB9^?nTRKP00_nTRKP01?l0003oYXVfojJ9]_nVRKH2o`0000GoYhVf00Co0000ojV9]?nYRKCo
00000onYR[@2o`0000CoZh^c00Go0000ojb;/on/Rk?o[8^co`000003ojf</`04o`000?n]S;;o[Hbb
o`0000;o[hjd00Go0000ojn>/on_S[?o[hjco`000004ok2A]@;o00001?naTKH00ol0003o/iBgok>D
]`03ok>D]`05o`000?nfV;[o]YRjokJH^_l000001OnhW;`01Ol0003o^j6ook^Q_onkXKoo000000;o
_ZO24?l00002olc6e005o`000?o?cmWocloIolo?fOl000000ooAf=h01_l0003odn;Rom?Rh_l0003o
d^[Vo`0000;oco3Y00Co0000ol_ejol0003oaOS/0_l0000Pooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@oooool3o`1XdPCo06KD00?o
06OIo`000?l000002Ol00003ohRCe`05o`000?n=TM;oSI7BohfAd_l000000_nBT<h7o`0000;oPhO>
1On<QlT4oi>8a@03o`000?nHR<7oV8S100;oV8S100Go0000oif9_OnMRKgoWHVmo`000003oj69^`03
o`000?nTRKSoY8Vh00;oY8Vh00Co0000ojJ9]_nVRKKo00000_nUR[P00ol0003oYhVfojN9]P02ojN9
]P04o`000?nYRKCoZHVdo`0000CoZHZd0_l00003oj^;/`03o`000?n/Rk?o[8^c00;o[8^c00Ko0000
ojf</on]S;?o[Hbcojf</_l00003ojn>]005o`000?n_S[?o[hjcojn>/ol000001On`TKD00ol0003o
/I6fok6A]P02ok6A]P03o`000?ncU;Oo/iBg00;o/iBg00?o0000okJH^_nfV;X00_nfV;X00ol0003o
^9blokRL_002okRL_003o`000?nkXKoo^j6o00;o^j6o00Go0000okjW`_nnYl;o_ZO2o`000004ol6^
aP05o`000?o5]L_oaKG;olFebol000000oo9_Ll01?l0003oc<KDolc6e?l00004olo?f@04o`000?oA
f=kodMSNo`0000;odn;R00Wo0000om;Zi_oBj^Ko0000olo`jOl0003oboG[o`000?o5n>`00_l0000R
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002cooooo00?o0000oooo
ooooool0@oooool3o`1XdPCo06KD0_l0ImT2o`]/g@04o`000?lOL^7o7g;Qoambh@?o=7SR2_l00000
0om/Q=WoNHGCogV5d`02ogV5d`GoPhO>1?n<QlT00ol0003oThS5oi>8a@02oi>8a@05o`000?nHR<7o
V8S1oiR8`Ol000001?nMRKd01Ol0003oXHVkoj69^onQRK_o000000?oY8Vh00?o0000ojJ9]_l00000
0onUR[P00ol0003oYhVfojN9]P03ojN9]P;o00001OnYR[@01_l0003oZhbeo`000?l0003oZh^co`00
00Co[8^c00?o0000ojf</on]S;<00_l00005ojn>]003o`000?n_S[?o000000Ko/96e0_l00003ok6A
]P03o`000?ncU;Oo/iBg00;o/iBg00?o0000okJH^_nfV;X00_nfV;X00ol0003o^9blokRL_002okRL
_005o`000?nkXKoo^j6ook^Q_ol000000onnYl800ol0003o`Jk6ol6^aP02ol6^aP05o`000?o5]L_o
aKG;olFebol000000oo9_Ll01Ol0003oc<KDolc6e?o<a]Co000000?ocloI00Co0000om7Hg_oAf=ko
00000ooCh^800ol0003od^[Vo`000002olo`j@03o`000?o;mN_o000000;o00008oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000]ooooo`;o0000AOooool2o`1XdP04o`00
0?l0I]Co06KDo`1Ve0;o06OI0_l;K=d01?l0003o7g;QoambhOlOL^42ocAhhP04o`000?m9ON7oBGgQ
odUmh@CoG87M1?m/Q=T4ogV5d`CoPhO>00?o0000ohb7bOn<QlT00_n<QlT01Ol0003oThS5oi>8aOnC
R<Go000000CoV8S100Go0000oif9_OnMRKgoWHVmo`000003oj69^`03o`000?nTRKSoY8Vh00;oY8Vh
00?o0000ojF:^?nUR[P00onUR[P00ol0003oYhVfojN9]P03ojN9]P03o`000?nYR[CoZHZd00?oZHZd
00Co0000oj^<]On[S;GoZhbe0_l00004ojb;/`05ojf</ol0003o0000ojj>]Ol000001On_S[@00ol0
003o[hjco`000005ok2A]@04o`000?nbU;Oo/YBgo`0000;o/I6f00?o0000ok>D]oncU;L00_ncU;L0
1Ol0003o]YRjokJH^_nfV;[o000000Go^9bl00Go0000ok^Q_onkXKoo^j6oo`000003okjW`P03o`00
0?o1[/Ko`Jk600;o`Jk600Go0000olFeboo5]L_oaKG;o`000003olVmc`04o`000?o<a]Coc<KDo`00
00CocloI00Co0000om7Hg_oAf=ko00000_oCh^800ol0003od^[Vo`000002olo`j@04o`000?o;mN_o
0000o`0002Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`00;oooool0
0ol0003oooooooooo`13ooooo`?o06SB0ol0I]@2o`1Wf@;o2fcM00Co0000oambhOlOL^7o7g;Q0_ld
N>801?l0003oBGgQodUmhOm9ON44oeb1g@CoK8CI0omiQM<00ol0003oPhO>oh>7cP02oh>7cP05o`00
0?n<QlWoS8O9ohb7bOl000000onCR<D00ol0003oV8S1oiR8`@02oiR8`@05o`000?nMRKgoWHVmoif9
_Ol000001?nQRK/01Ol0003oY8VhojB9^?nTRKSo000000KoYHZh00?o0000ojN9]_nWRKH00_nWRKH2
o`0000CoZHZd00?o0000oj^<]On[S;D00_n[S;D6o`0000Co[Xje00?o0000ojn>]?n_S[@00on_S[@0
0ol0003o/96eok2A]@04ok2A]@04o`000?nbU;Oo/YBgok:D]`;o00001?ncU;L00ol0003o]YRjokJH
^P02okJH^P03o`000?nhW;co^9bl00;o^9bl00?o0000ok^Q_onkXKl00_nkXKl01Ol0003o_ZO2okjW
`_nnYl;o000000Co`Jk600Go0000olFeboo5]L_oaKG;o`000002olVmc`05o`000?o<a]Coc<KDolc6
e?l000000oo?cmT01?l0003odMSNom7Hg_l00003om?RhP06o`000?oBj^Ko0000olo`jOl0003oboG[
0_l0000Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0033ooooo00?o
0000ooooooooool0@oooool00ol0003o06SBo`1XdP03o`1Ve005o`000?l0ImWo2fcMo`]/gOl00000
0olOL^42ocAhhP04o`000?m9ON7oBGgQodUmh@CoG87M0om/Q=T01Ol0003oNHGCogV5domiQM?o0000
00?oPhO>00?o0000ohb7bOn<QlT00_n<QlT01Ol0003oThS5oi>8aOnCR<Go000000CoV8S100Go0000
oif9_OnMRKgoWHVmo`000003oj69^`06o`000?nTRKSoY8Vho`000?nRR[_o00001OnUR[P01Ol0003o
YhVfojN9]_nWRKKo000000;oZ8^g00Co0000ojV:]?nYR[Co00001On[S;D00ol0003o[8feojb=]@02
ojb=]@03o`000?n^S[Go[Xje00;o[Xje00?o0000ojn>]?n_S[@00on_S[@00ol0003o/96eok2A]@03
ok2A]@03o`000?nbU;Oo/YBg00?o/YBg0_l00003ok>D]`03o`000?nfV;[o]YRj00;o]YRj00?o0000
okRL_?nhW;`00_nhW;`01Ol0003o^j6ook^Q_onkXKoo000000?o_ZO200?o0000ol6^a_o1[/H00_o1
[/H01Ol0003oaKG;olFeboo5]L_o000000?obKg?00Go0000olc6e?o<a]Coc<KDo`000003olo?f@04
o`000?oAf=kodMSNo`0000;odn;R00Oo0000om;Zi_l0003oco3Yo`000?o;mN_o000002_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`0004Gooooo0_l0J=80
1Ol0003o06KDo`1Ve?l0003o06OI00;o2fcM00Co0000oambhOlOL^7o7g;Q0_ldN>801?l0003oBGgQ
odUmhOm9ON43oeb1g@05o`000?m/Q=WoK8CIofb4fOl000000omiQM<01Ol0003oPhO>oh>7c_n3Qlko
000000?oS8O900Go0000oi>8aOnCR<GoThS5o`000004oiR8`@05o`000?nMRKgoWHVmoif9_Ol00000
0onQRK/00ol0003oY8Vho`000003oj::^`03o`000?nUR[SoYHZh00?oYHZh00?o0000ojN9]_l00000
1?nXRkL00ol0003oZHZdo`000005oj^<]@03o`000?n/SKGo[8fe00;o[8fe00?o0000ojj>]On^S[D0
0on^S[D01ol0003o[hjdojn>]?n_S[Co0000ok2A]ol000001?n`TKD00ol0003o/YBgok:D]`03ok:D
]`03o`000?neV;[o000000;o/iBg00Go0000okJH^_nfV;[o]YRjo`000005okRL_005o`000?nkXKoo
^j6ook^Q_ol000000onnYl800ol0003o`Jk6ol6^aP02ol6^aP05o`000?o5]L_oaKG;olFebol00000
0oo9_Ll01?l0003oc<KDolc6e?l00003olo?f@04o`000?oAf=kodMSNo`0000;odn;R00Go0000om;Z
i_oBj^Ko0000olo`j@02o`0002cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03
ooooo`00<oooool00ol0003oooooooooo`13ooooo`03o`000?l0J=;o06SB00;o06KD00Go0000o`1W
fOl0003o2fcMo`000002oambh@04o`000?ldN>;o=7SRo`0000;oBGgQ00Go0000oeb1gOmLPMgoG87M
o`000002ofb4f@05o`000?miQM?oNHGCogV5dol000000on3Qlh00ol0003oS8O9ohb7b@02ohb7b@05
o`000?nCR<GoThS5oi>8aOl000001?nHR<401Ol0003oWHVmoif9_OnMRKgo000000?oXHVk00?o0000
oj::^onRR[/00_nRR[/00ol0003oYHZhojF:^003ojF:^003o`000?nWRKKo000000GoZ8^g0_l00005
oj^<]@03o`000?n/SKGo[8fe00;o[8fe00?o0000ojj>]On^S[D00on^S[D01?l0003o[hjdojn>]?l0
0003ok2A]`05o`000?n`TKGo/96eok2A]Ol000001?nbU;L01?l0003o]IRjokFH^_neV;X2o`0000Co
]YRj00?o0000okRL_?nhW;`00_nhW;`00ol0003o^j6ook^Q_`02ok^Q_`05o`000?nnYl;o_ZO2okjW
`_l000000oo1[/H01Ol0003oaKG;olFeboo5]L_o000000?obKg?00Go0000olc6e?o<a]Coc<KDo`00
0003olo?f@03o`000?oAf=ko000000?odn;R00Go0000om;Zi_l0003oco3Yo`00000_ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000ooooooooool0A?oo
ool00ol0003o06SBo`000002o`1Ve0;o000000Oo2fcMo`000?lOL^7o7g;Qo`000?ldN>;o000000?o
BGgQ00Go0000oeb1gOmLPMgoG87Mo`000002ofb4f@05o`000?miQM?oNHGCogV5dol000000on3Qlh0
1Ol0003oS8O9ohb7bOn<QlWo000000?oThS500?o0000oiR8`OnHR<400_nHR<401Ol0003oWHVmoif9
_OnMRKgo000000;oXHVk0_l00005oj::^`03o`000?nUR[SoYHZh00?oYHZh00?o0000ojR;]onXRkL0
1OnXRkL2o`0000CoZhbe00?o0000ojb=]On/SKD00_n/SKD00ol0003o[Xjeojj>]@03ojj>]@03o`00
0?n_S[Co000000Co/96g00Co0000ok2A]On`TKGo00001OnbU;L00ol0003o]IRjokFH^P02okFH^P;o
00000onfV;X00ol0003o^9blokRL_002okRL_005o`000?nkXKoo^j6ook^Q_ol000000onnYl800ol0
003o`Jk6ol6^aP02ol6^aP05o`000?o5]L_oaKG;olFebol000000oo9_Ll01?l0003oc<KDolc6e?l0
0003olo?f@04o`000?oAf=kodMSNo`0000;odn;R00Go0000om;Zi_l0003oco3Yo`00000aooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0
A?ooool00ol0003o06SBo`000002o`1Ve004o`000?l0ImWo2fcMo`0000;o7g;Q00?o0000ocAhh_l0
00000om9ON401?l0003oG87Moeb1gOl00003ofb4f@04o`000?miQM?oNHGCo`0000CoPhO>00Co0000
ohb7bOn<QlWo00001?nCR<D01Ol0003oV8S1oiR8`OnHR<7o000000?oWHVm00?o0000oj69^ol00000
0_nMR[l00ol0003oXXZkoj::^`03oj::^`03o`000?nUR[SoYHZh00;oYHZh0_l00006ojR;]`04o`00
0?nYSKSo0000o`0000;oZhbe00?o0000ojb=]On/SKD00on/SKD00ol0003o[Xjeojj>]@02ojj>]@;o
00001_n`TKL00ol0003o/96eo`000004ok:D]`03o`000?neV;[o]IRj00?o]IRj00?o0000okRM_Ol0
00000_nfV;X00ol0003o^9blokRL_002okRL_005o`000?nkXKoo^j6ook^Q_ol000000onnYl800ol0
003o`Jk6ol6^aP02ol6^aP05o`000?o5]L_oaKG;olFebol000000_o9_Ll01Ol0003oc<KDolc6e?o<
a]Co000000?ocloI00?o0000om7Hg_l000000ooCh^801?l0003od^[Vo`000?l0000cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool003Kooooo0_l00015ooooo`Co000000Go
06KDo`000?l0ImWo2fcMo`000002oambh@03o`000?ldN>;o000000?oBGgQ00Co0000oeb1gOmLPMgo
00000_m/Q=T01Ol0003oNHGCogV5domiQM?o000000?oPhO>00Go0000ohb7bOn<QlWoS8O9o`000003
oi>8a@03o`000?nHR<7oV8S100;oV8S100?o0000oif9_OnMRKd00_l00004oif:_`03o`000?nRR[_o
XXZk00?oXXZk00Co0000ojF:^?nUR[So00000_nUS;X00ol0003oZ8^gojR;]`03ojR;]`04o`000?nY
SKSoZHfhojV=^0?o00001On/SKD00ol0003o[Xjeojj>]@02o`000003ojjA^?l0003o/96g00Ko/96g
00?o0000ok:D]onbU;L00onbU;L00ol0003o]IRjokFH^P02okFH^P04o`000?nhWKgo^9fmokRM_@;o
00001?nhW;`00ol0003o^j6ook^Q_`02ok^Q_`05o`000?nnYl;o_ZO2okjW`_l000000oo1[/H01Ol0
003oaKG;olFeboo5]L_o000000?obKg?00Co0000olc6e?o<a]Co00000oo?cmT01?l0003odMSNom7H
g_l00002om?RhP03o`000?oBj^Ko000003Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`08o`000?l0J=;o0000o`1Ve?l0003o
06OIo`]/gOl00002oambh@03o`000?ldN>;o000000;oBGgQ00Go0000oeb1gOmLPMgoG87Mo`000002
ofb4f@05o`000?miQM?oNHGCogV5dol000000on3Qlh01?l0003oS8O9ohb7bOl00003oi>8a@03o`00
0?nHR<7oV8S100;oV8S100Go0000oif9_Ol0003oV8[3o`000004oif:_`03o`000?nRR[_oXXZk00?o
XXZk00Co0000ojF:^?nUR[So00000onUS;X00ol0003oZ8^gojR;]`02ojR;]`03o`000?nYSKSoZHfh
00?oZHfh1?l00002ojb=]@?o00000on^TKP00ol0003o/96gok2A]`04ok2A]`;o00001?nbU;L00ol0
003o]IRjokFH^P03okFH^P03o`000?nhWKgo^9fm00;o^9fm0_l00003okRL_003o`000?nkXKoo^j6o
00;o^j6o00Co0000okjW`_nnYl;o00001?o1[/H01Ol0003oaKG;olFeboo5]L_o000000;obKg?00Go
0000olc6e?o<a]Coc<KDo`000003olo?f@03o`000?oAf=ko000000;odn;R0ol0000gooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool003Wooooo00?o0000ooooooooool0A?oo
ool3o`000003o`1Ve?l0003o06OI00;o00000_lOL^400ol0003o=7SRo`000002odUmh@04o`000?mL
PMgoG87Mo`0000;oK8CI00Go0000ogV5domiQM?oNHGCo`000003oh>7cP05o`000?n<QlWoS8O9ohb7
bOl000000onCR<D01?l0003oV8S1oiR8`OnHR<42o`0000?oV8[300?o0000oif:_onMR[l00_nMR[l0
0ol0003oXXZkoj::^`03oj::^`03o`000?nUR[So000000CoYHbj00Co0000ojR;]onXRkOo00001_nY
SKP01?l0003o[92hojb@^?n/T;P3o`0000Ko[Y6h00?o0000ok2A]on`TKL00_n`TKL01?l0003o/YFi
ok:E^Ol00003ok:D]`03o`000?neV;[o]IRj00;o]IRj00?o0000okRM_OnhWKd00onhWKd00ol0003o
^jC1o`000002okRL_005o`000?nkXKoo^j6ook^Q_ol000000onnYl800ol0003o`Jk6ol6^aP02ol6^
aP05o`000?o5]L_oaKG;olFebol000000_o9_Ll01?l0003oc<KDolc6e?l00003olo?f@03o`000?oA
f=ko000000?odn;R0_l0000iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool003[ooooo00?o0000ooooooooool0AOooool01OnC003o0000o`000?l0003o06OI00;o000000Go
7g;Qo`000?ldN>;o=7SRo`000002odUmh@04o`000?mLPMgoG87Mo`0000;oK8CI00Go0000ogV5domi
QM?oNHGCo`000003oh>7cP04o`000?n<QlWoS8O9o`0000?oThS500Ko0000oiR8`Ol0003o0000oi6:
b?l00004oiR:``03o`000?nMR[ooWHZo00;oWHZo00?o0000oj::^onRR[/00onRR[/00ol0003oYHbj
ojF<^P04ojF<^P03o`000?nXRkOo000000KoZHfh00?o0000ojb@^?n/T;P00on/T;P00ol0003o[Y6h
ojjA^004ojjA^005o`000?n`TKOo/96gok2A]ol000001?nbUKT00ol0003o/YBgo`000005okFH^P03
o`000?nhWKgo^9fm00;o^9fm00Co0000ok^T`OnkY<7o^jC10_l00004ok^Q_`05o`000?nnYl;o_ZO2
okjW`_l000000oo1[/H01Ol0003oaKG;olFeboo5]L_o000000;obKg?00Go0000olc6e?o<a]Coc<KD
o`000003olo?f@03o`000?oAf=ko000000?o0000??ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;ooooo000kooooo`;o0000B?ooool00onF0`3o0000o`000002o`000004oambhOl0
003o=7SRo`0000?oBGgQ00?o0000oeb1gOl000000om/Q=T01?l0003oNHGCogV5dol00003oh>7cP05
o`000?n<QlWoS8O9ohb7bOl000000_nCR<D2o`0000CoTH[800Go0000oiR:`onHR/?oV8[3o`000004
oif:_`03o`000?nRR[_oXXZk00?oXXZk00?o0000ojF<^_nUS;X01OnUS;X2o`0000KoZHfh00?o0000
ojb@^?n/T;P00on/T;P00ol0003o[Y6hojjA^004ojjA^004o`000?n`TKOo/96go`0000Go/YFi00?o
0000ok:D]ol000001?neV;X00ol0003o^9fmokRM_@03okRM_@03o`000?nkY<7o^jC100;o^jC10_l0
0003ok^Q_`04o`000?nnYl;o_ZO2o`0000Co`Jk600Go0000olFeboo5]L_oaKG;o`000002olVmc`05
o`000?o<a]Coc<KDolc6e?l000000_o?cmT6o`0003gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`00?Oooool00ol0003oooooooooo`17ooooo`08oiH30?nE0P3o0000o`00
0?lOL^7o0000ocAhh_l00002odUmh@04o`000?mLPMgoG87Mo`0000;oK8CI00Go0000ogV5domiQM?o
NHGCo`000003oh>7cP08o`000?n<QlWoS8O9o`000?nCR<Go0000ohN9col00005oi6:b005o`000?nH
R/?oV8[3oiR:`ol000001?nMR[l01ol0003oXXZkoj::^onRR[_o0000oj:=__l000001onUS;X2o`00
00GoZHfh00?o0000ojb@^?n/T;P00on/T;P00ol0003o[Y6hojjA^005ojjA^003ok2A]ol0003o/YFi
00Ko/YFi00?o0000okFH^_neV;X00_neV;X00ol0003o^9fmokRM_@03okRM_@03o`000?nkY<7o^jC1
00?o^jC100?o0000okn[a_l000000_l00003okjW`P05o`000?o1[/Ko`Jk6ol6^a_l000000oo5]L/0
1Ol0003obKg?olVmcoo9_Loo000000;oc<KD00Co0000olo?fOo?cmWocloI0_l000000onkoMWo0000
o`00000oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003kooooo00?o
0000ooooooooool0B?ooool00onF0`3oU@80o`000002o`000005ocAhh_l0003oBGgQodUmhOl00000
0_mLPMd01?l0003oK8CIofb4fOl00003ogV5d`04o`000?n3QlkoPhO>o`0000;oS8O90_l00003ohN9
c`03o`000?nAR/SoTH[800;oTH[800?o0000oiR:`onHR/<00_nHR/<01Ol0003oWHZooif:_onMR[oo
000000;oXXZk00Go0000oj:=__nRSKkoXXfno`000006ojF<^P03o`000?nXSkco000000;o00000_nY
SKP00ol0003o[92hojb@^004ojb@^003o`000?n^TKSo[Y6h00?o[Y6h0_l00007ok:E^@;o00001?ne
V;X00ol0003o^9fmokRM_@02okRM_@03o`000?nkY<7o^jC100?o^jC100?o0000okn[a_noZlH00_no
ZlH3o`000003okjW`_l0003o`Jk600;o`Jk600Go0000olFeboo5]L_oaKG;o`000002olVmc`04o`00
0?o<a]Coc<KDolc6e0Go000000?o^ogIo`000?l00000@Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo04Wooooo00?oUP<0o`000?mm0000
0ol00002odUmh@03o`000?mLPMgo000000;oK8CI00Go0000ogV5domiQM?oNHGCo`000002oh>7cP?o
000000?oNHOFo`000?n7RLl00on7RLl00ol0003oTH[8oi6:b002oi6:b005o`000?nHR/?oV8[3oiR:
`ol000001?nMR[l00ol0003oXXZko`000004oj:=_P03o`000?nUS;[oYHbj00;oYHbj00?o0000ojR?
_?nXSk`00onXSk`3o`0000Ko[92h00?o0000ojjA^?n^TKP00ol000000on`UK_o0000ok:E^@05ok:E
^@04o`000?ndV[go]9Zmo`0000;o]IRj00?o0000okRM_OnhWKd00onhWKd00ol0003o^jC1ok^T`@02
ok^T`@03o`000?noZlKo_j_600?o_j_600?o0000olBdboo4]</00ol00002ol6^aP05o`000?o5]L_o
aKG;olFebol000000_o9_Ll5o`000005om;ei_l0003o0000ok_mfOl00000A?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo0010ooooo`;o0000Boooool01?nE0P3oO@00ogd0
0?l0:9T6o`0000;oK8CI00?o0000ogV5domiQM<00ol000000omUQ=co0000ogV7eP02ogV7eP03o`00
0?n7RLooQhW?00;oQhW?00?o0000oi6:b?nAR/P00_nAR/P01Ol0003oV8[3oiR:`onHR/?o000000Co
WHZo0_l00005oj:=_P05o`000?nUS;[oYHbjojF<^_l000001onXSk`5o`0000;o[92h0ol00005ok2E
^`03o`000?nbUKWo/YFi00;o/YFi00?o0000okBJ_OndV[d00_ndV[d00ol0003o]IRjo`000004okRM
_@03o`000?nkY<7o^jC100?o^jC100?o0000okn[a_noZlH00_noZlH01Ol0003oa;C;olBdboo4]<_o
000000;obKoA2_l00002omCXi006o`000?oBmNKo0000o`000?nkoMWo0000AOooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo0012ooooo`03o`000?oooooooooo04[ooooo00Co
0000ogd00?l0:9Wo02RI0ol0@[T00ol0G=?o0000o`000003o`000003odUmhOl0003oIHCL00;oIHCL
00Go0000ogV7e_miQmKoNHOFo`000003ohN9c`03o`000?nAR/SoTH[800?oTH[800Go0000oiR:`onH
R/?oV8[3o`000003oif:_`03o`000?nNSlCo000000GoXXfn00Co0000ojF<^_nUS;[o00001onXSk`0
0ol0003o[9>lojbC_002ojbC_0?o00001on`UK/01Ol0003o/YFiok:E^OnbUKWo000000Ko]9Zm00?o
0000okRM_OnhWKd00onhWKd00ol0003o^jC1ok^T`@02ok^T`@03o`000?noZlKo_j_600;o_j_600Go
0000olBdboo4]<_oa;C;o`000004olVod@05o`000?o>c=Soc/cHolk<f?l000000_oBfMh01Ol0003o
e>STomCXi?l0003od_GV00Co0000Aoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo0013ooooo`03o`000?oooooooooo04_ooooo00?oO@00o`0XVOl0:9T00ol0@[T2o`1Ld`;o
8g3P00Co0000odUmhOm9ON7o00000omUQ=`01Ol0003oNHOFogV7e_miQmKo000000?oQhW?00?o0000
oi6:b?nAR/P00_nAR/P01Ol0003oV8[3oiR:`onHR/?o000000;oWHZo00Go0000oij?a?nNSlCoWXo4
o`000005oj:=_P;o00002?nXSk`00ol0003o[9>lojbC_004ojbC_003o`000?n`UK_o/9Fk00Go/9Fk
00Co0000ok:E^OnbUKWo00001_ndV[d2o`0000Co^9fm00?o0000ok^T`OnkY<400_nkY<400ol0003o
_j_6okn[aP03okn[aP04o`000?o4]<_oa;C;o`0000CobKoA00Go0000olk<f?o>c=Soc/cHo`000002
om;IgP05o`000?oDj>Coe>STo`000?oBmNH01?l00019ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0C?ooool00omm003o02RIo`12^@02
o`12^@;o05cC0_lSL>001?l0003oBGgQodUmhOl00003ofF4g005o`000?miQmKoNHOFogV7e_l00000
0on7RLl00ol0003oTH[8oi6:b002oi6:b007o`000?nHR/?oV8[3oiR:`ol0003oWHZoo`000004oij?
a003o`000?nRSKkoXXfn00?oXXfn0_l00007ojR?_003o`000?n/Tkco[9>l00Co[9>l00?o0000ok2E
^on`UK/01_n`UK/2o`0000Ko]9Zm00Co0000okNQ`_ngXL;o00000_nhWKd00ol0003o^jC1ok^T`@03
ok^T`@03o`000?noZlKo_j_600;o_j_600Go0000olBdboo4]<_oa;C;o`000003olVod@05o`000?o>
c=Soc/cHolk<f?l000000_oBfMh01Ol0003oe>STomCXi?l0003od_GV00?o000000?oS^Vgoooooooo
ool0BOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000
COooool00omm003o02RIo`000002o`12^@05o`000?l0G=?o8g3Pob=`h?l000000_m9ON401Ol0003o
IHCLofF4g?mUQ=co000000;oNHOF00Go0000ohN9con7RLooQhW?o`000005oi6:b004o`000?nHR/?o
V8[3oiR:``;o00001OnNSl@00ol0003oXXfnoj:=_P02oj:=_P04o`000?nVT/7o0000o`0000GoZ8nl
00?o0000ojbC_?n/Tk`01?n/Tk`00ol0003o/9Fkok2E^`05ok2E^`;o00001_ndV[d00ol0003o]j72
okNQ`P02okNQ`P03o`000?nhWKgo000000Co^jC100?o0000okn[a_noZlH00_noZlH01Ol0003oa;C;
olBdboo4]<_o000000?obKoA00Go0000olk<f?o>c=Soc/cHo`000002om;IgP05o`000?oDj>Coe>ST
o`000?oBmNH00ol0001=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool0
04Oooooo00?o0000ooooooooool0C?ooool2o`0XV@;o04:i00Go0000o`1LdolSL>3o8g3Po`000002
odUmh@05o`000?mUQ=coIHCLofF4g?l000000_miQmH01Ol0003oQhW?ohN9con7RLoo000000CoTH[8
00Oo0000oiR:`onHR/?oV8[3o`000?nHT<[o000000GoWXo400Go0000oj:=__nRSKkoXXfno`000003
ojJB`@?o00000_nXSk`00ol0003o[9>lojbC_005ojbC_004o`000?n`UK_o/9Fkok2E^`?o000000?o
/I[0o`000?ndV[d01?ndV[d00ol0003o]j72okNQ`P04okNQ`P03o`000?nkY<7o^jC100;o^jC100?o
0000okn[a_noZlH00_noZlH01Ol0003oa;C;olBdboo4]<_o000000CobKoA00Co0000olk<f?o>c=So
00000_oBfMh01Ol0003oe>STomCXi?l0003od_GV00?o0000Coooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo04cooooo00KoO@00o`0XVOl0
@[Wo04:io`000?l0G=<2ob=`h004o`000?m9ON7oBGgQo`0000?oIHCL00Co0000ogV7e_miQmKo0000
0on7RLl00ol0003oTH[8oi6:b002oi6:b003o`000?nHR/?o000000?oV93:00?o0000oij?a?nNSl@0
0onNSl@00ol0003oXXfno`000007ojJB`@?o00001on/Tk`4o`0000Go/I[000Go0000okBJ_OndV[go
]9Zmo`000006okNQ`P03o`000?nkZLSo000000?o^jC100?o0000okn[a_noZlH00_noZlH01Ol0003o
a;C;olBdboo4]<_o000000?obKoA00Go0000olk<f?o>c=Soc/cHo`000002om;IgP04o`000?oDj>Co
0000om;eiP?o0000DOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0019
ooooo`03o`000?oooooooooo04gooooo00So02RIo`000?l0@[Wo0000o`1Ldol0003o8g3Po`0000;o
BGgQ00Co0000ofF4g?mUQ=co00000omiQmH01Ol0003oQhW?ohN9con7RLoo000000CoTH[80_l00004
oiR@bP03o`000?nNSlCoWXo400?oWXo40_l00009ojJB`@Wo00002?naV/001?l0003o]9ZmokBJ_Ol0
0006okNQ`P07o`000?nkZLSo^jW8ok^Yb?l0003o^jC1o`000004okn[aP05o`000?o4]<_oa;C;olBd
bol000000oo9_m401Ol0003oc/cHolk<f?o>c=So000000;od]WN00?o0000omCXi?oDj>@01?l0001C
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004[ooooo0_l0001>oooo
o`08o`0XVOl0003o04:io`12^Ol0003o05cCob=`h?l00002odUmh@04o`000?mUQ=coIHCLo`0000;o
NHOF00Go0000ohN9con7RLooQhW?o`000003oi6:b004o`000?n>T];oSY;Bo`0000CoV93:00?o0000
oij?a?nNSl@00onNSl@2o`0000SoYY;100?o0000ojbG`_n/Ul801On/Ul800ol0003o/I[0ok6J`006
ok6J`003o`000?ndV[go000000Ko]j7200?o0000ok^Yb?nkZLP00_nkZLP2o`0000Co_j_600?o0000
olBdboo4]</00_o4]</01Ol0003obKoAolVodOo9_m7o000000;oc/cH00Co0000om;Ig_oBfMko0000
0_oDj>@4o`0005Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?oo
ool00ol0003oooooooooo`1=ooooo`;o000000Go04:io`000?l0G=?o8g3Po`000002odUmh@04o`00
0?mUQ=coIHCLo`0000;oNHOF00Oo0000ohN9con7RLooQhW?o`000?nAR/So000000CoSY;B00?o0000
oiR@b_nHT<X00_nHT<X00ol0003oWXo4oij?a002oij?a004o`000?nSU/Oo0000o`0000KoYY;100?o
0000ojbG`_n/Ul801On/Ul800ol0003o/I[0ok6J`006ok6J`0;o00001_ngXL800ol0003o^jW8ok^Y
b002ok^Yb004o`000?no]<oo_kC?o`0000?o_j_600Go0000olBdboo4]<_oa;C;o`000003olVod@04
o`000?o>c=Soc/cHo`0000;od]WN00?o0000omCXi?oDj>@00ol0001Gooooo`03o`000?oooooooooo
00Sooooo0Ol00001ooooo`7ooooo001=ooooo`03o`000?oooooooooo04gooooo00Oo02RIo`000?l0
@[Wo0000o`1LdolSL>3o000000;oBGgQ00Co0000ofF4g?mUQ=co00000_miQmH01?l0003oQhW?ohN9
con7RLl2o`0000GoSY;B00?o0000oiR@b_nHT<X00_nHT<X01Ol0003oWXo4oij?a?nNSlCo000000?o
XiK70_l00004ojJB`@03o`000?n/Ul;o[9O200Go[9O200?o0000ok6J`?naV/001?naV/02o`000003
ok>Qa_l0003o]j7200Co]j7200?o0000ok^Yb?nkZLP00_nkZLP00ol0003o_kC?okndc`02okndc`03
o`000?noZlKo000000?oa;C;00Go0000olVodOo9_m7obKoAo`000003olk<f005o`000?oBfMkod]WN
o`000?oDj>@00ol0001Iooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001>oooo
o`03o`000?oooooooooo04kooooo00Co0000o`12^Ol0003o05cC0_l00002odUmh@04o`000?mUQ=co
IHCLo`0000;oNHOF00?o0000ohN9col000000_moTmd00ol0003oSY;BohjBdP03ohjBdP03o`000?nH
T<[oV93:00;oV93:00?o0000oij?a?l000001_nSU/L2o`0000;oYY;100?o0000ojbG`_n/Ul801_n/
Ul800ol0003o/I[0ok6J`003o`0000Co/j7600Go0000okNQ`_ngXL;o]j72o`000004ok^Yb003o`00
0?no]<oo_kC?00?o_kC?0ol00003olBdb`04o`000?o9_m7obKoAo`0000?oc/cH00Go0000om;Ig_oB
fMko0000omCXi002o`0005_ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004oo
oooo0_l0001?ooooo`04o`000?l0@[Wo0000o`1Ld`;o00000_m9ON401Ol0003oIHCLofF4g?l0003o
NHOF00?o00000omoTmd00ol0003oSY;BohjBdP03ohjBdP03o`000?nHT<[oV93:00;oV93:0_l00008
oj>Fa`?o00002?n/Ul83o`0000Oo/j7600Co0000okNQ`_ngXL;o00001?nkZLP00ol0003o_kC?oknd
c`03okndc`07o`000?o3`MSo`l7Hol?1f?l0003oa;C;o`000003olVod@04o`000?o>c=Soc/cHo`00
00;od]WN00Co0000omCXi?l0003o0000GOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1
ooooo`00DOooool00ol0003oooooooooo`1=ooooo`?o000000?o05cCo`000?l000000_m9ON401?l0
003oIHCLo`000?l00003ofJAi`05o`000?moTmgoOi?MognCgOl000001On>T]800ol0003oV93:oiR@
bP02oiR@bP;o00002OnSU/L:o`0000Wo/j7600?o0000okNQ`_l000001?nkZLP00ol0003o_kC?oknd
c`03okndc`03o`000?o3`MSo`l7H00;o`l7H1?l000001Oo9_m7o0000olk<f?o>c=So000000;od]WN
0ol0001Pooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001Booooo`03o`000?oo
oooooooo04kooooo00?oV@L0o`000?l000000_l000000om9ON7o0000o`000003ocf8j`?oIY7W00Go
0000ognCgOmoTmgoOi?Mo`000005ohjBdP06o`000?nHT<[oV93:oiR@b_l0003oWY_@0ol00006oj>F
a`03o`000?n[WLWoZig900KoZig900?o0000ok>Qa_ncXLH01oncXLH2o`0000Co^jW800?o0000oknd
cono]<l00ono]<l00ol0003o`l7Hol?1f002ol?1f004o`000?o7d^;oam;RolOBhP[o0000H_ooool0
0ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000oooo
oonI1`000_ml00001?l0003o06oLo`1_g?l0Km`3ocf8j`03o`000?mVTNOoIY7W00;o00000_moTmd2
o`0000CoSY;B00Co0000oiR@b_nHT<[o00001?nNVm02o`0000CoXiK700?o0000oj^MbOn[WLT01_n[
WLT00ol0003o/j76ok>QaP04ok>QaP?o000000?o]:_?o`000?nkZLP00_nkZLP00ol0003o_kC?oknd
c`02okndc`;o00001?o3`MP01Ol0003oam;RolOBh_o7d^;o000000;ob>G/00?o0000ol7fkoo1m^l0
0ol0001Tooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oo
oooooooo04_ooooo00Oo0000oooooooooooooooooiT70?ml003o000000?o06oL00Co0000ocf8jolm
R>_o?HS[0omVTNL01Ol0003oOi?MognCgOmoTmgo000000CoSY;B0_l00007oijKd0Co00002_n[WLT0
1?l0003o/j76ok>Qa_ncXLH2o`0000Go]:_?00?o0000ok^Yb?l000001?no]<l00ol0003o`l7Hol?1
f002ol?1f0;o00000oo7d^801Ol0003ob>G/o`000?l0003o`OK_00Co0000I_ooool00ol0003ooooo
ooooo`04ooooo`7o00000Oooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`03ooooo`03oiT70?ml003o000000?o06oL0olmR>/01?l0003oIY7WofJAiol00003ognCg@03o`00
0?n>T];oSY;B00;oSY;B0_l00009oijKd0Oo00001?n[WLT4o`0000Oo]:_?0_l00004okndc`03o`00
0?o3`MSo`l7H00;o`l7H00?o0000olOBh_o7d^800_o7d^800ol0003ob>G/o`000002ol7fk`?o0000
JOooool00ol0003oooooooooo`03ooooo`7o00000Oooool005Oooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`05ooooo`;oO00000Co0000o`1_g?l0Kmco00000_lmR>/2o`000003ofJA
iol0003oOi?M00;oOi?M00Ko0000ohjBd_n>T];oSY;Bo`000?nEXM`3o`0000KoWY_@00?o0000ojVU
d_nYYM801?nYYM85o`0000So]:_?0_l000000onf]m[o0000okndc`02okndc`03o`000?o3`MSo`l7H
00;o`l7H00?o0000olOBh_o7d^800_o7d^801?l0003ob>G/o`000?o1m^l4o`0006_ooooo00?o0000
ooooooooool00_ooool1o`00007ooooo001Hooooo`;o0000BOooool00ol0003oooooooooo`07oooo
o`03og`00?l0003o000000;o06oL00Go0000ocf8jolmR>_o0000ofJAi`02o`0000;oOi?M00?o0000
ohjBd_l000001OnEXM`3o`0000?oWY_@00?o0000ojVUd_nYYM802?nYYM800ol0003o]:_?okB[c`03
okB[c`?o00001?nf]mX00ol0003o_kC?o`000003ol?1f0;o00000oo7d^84o`000004ol7fkol0003o
0000og_R^fgooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool02Oooool01?ml003o0000o`000?l0Km`2o`000005ocf8jol0
003o0000ofJAiol000000_moTmd2o`0000SoUJ7L1?l0000:ojVUdP04o`000?ndZloo]:_?okB[c`;o
00001onf]mX2o`0000?o`l7H00?o0000olOBh_o7d^800_o7d^801?l0003ob>G/o`000?o1m^l3o`00
073ooooo00Go0000ooooooooooooooooo`000001ooooo`00Foooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo00_ooooo0_l00002o`1_g009o`000?lmR>_o?HS[o`000?mVTNOo0000ognC
gOl0003oQJO[00?o00002?nEXM`7o`0000GoZJGB0ol00006okJgfP?o00000_nfb>L00ol0003o`l7H
o`000004olOBhP?o000000Co`OK_o`000?l0003o0000L_ooool01?l0003oooooooooool00001oooo
o`00G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00gooooo0_l000001_l0Kmco
0000o`000?lmR>_o0000ofJAi`;o00001?n5Yn/3o`0000GoUJ7L00?o0000ojF`gonU/=l01?nU/=l6
o`0000Ko][OJ0_l00005okK8i`?o00000oo7d^82o`000004ol7fkol0003o0000o`0007Gooooo00?o
0000ooooool000000Oooool005gooooo0_l00014ooooo`03o`000?oooooooooo00kooooo00KoO000
o`000?l0003o06oLo`000?lmR>/2o`000004ofBYmol0003o0000o`0000CoQJO[0_l00003oiFQg003
o`000?nU/=ooYK3O00WoYK3O00?o0000okJgf_nf]mX00_nf]mX2o`0000Co]/SW0ol00003ok3LmP05
o`000?o7d^;o0000o`000?o1m^l00_l0001gooooo`03o`000?oooooooooo007o0000001Oooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool04?ooool9o`000004ofBYmol0003o0000o`00
00?oQJO[1?l0000<ojF`g`Co00000onfb>L3o`0000Ko/=cf1Ol0001jooooo`7o00000Oooool1o`00
0000H?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01?ooooo0_m^0006o`0000;o
I:Wg0ol00003ohFWj`ko00001?nfb>L2o`0000Ko/=cf1Ol0001nooooo`;o0000001Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool05oooool00om^003o0000o`000004o`0000;oI:Wg
1?l0000<oibnl003o`000?nfb>Oo000000;o00001On`g?H5o`00083ooooo0ol0000006;ooooo0_l0
000oooooo`03o`000?oooooooooo01_ooooo00?oKP00o`000?l000000_l00003ofBYm`oo00001On`
g?H5o`0007oooooo1?l00003ooooo`00I?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo01kooooo00?oKP00o`000?l000000ol0000=oh?;oP03o`000?n`g?Ko/=cf00Go0000O_ooool4
o`0000Oooooo001Uooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_oooolDo`00
07gooooo1?l0000;ooooo`00I_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0;3o
oooo0ol0000?ooooo`00Ioooool2o`0003[ooooo00?o0000ooooooooool0[?ooool4o`0001;ooooo
001Yooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Z?ooool4o`0001Kooooo001Z
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Y?ooool4o`0001[ooooo001[oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0XOooool4o`0001kooooo001/ooooo`;o
0000=?ooool00ol0003oooooooooo`2Mooooo`Co00008_ooool006kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`2Iooooo`Co00009_ooool006oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`2Eooooo`Co0000:_ooool0073ooooo0_l0000`ooooo`03o`000?oooooo
oooo097ooooo1?l0000^ooooo`00L_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
08kooooo0ol0000booooo`00Loooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08[o
oooo1?l0000eooooo`00M?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo
1?l0000iooooo`00MOooool2o`0002_ooooo00?o0000ooooooooool0P_ooool4o`0003gooooo001g
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0O_ooool4o`00047ooooo001hoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0N_ooool4o`0004Gooooo001iooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0M_ooool4o`0004Wooooo001jooooo`;o0000
9_ooool00ol0003oooooooooo`1booooo`Co0000COooool007cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1_ooooo`?o0000DOooool007gooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`1[ooooo`Co0000E?ooool007kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`1Wooooo`Co0000F?ooool007oooooo0_l0000Qooooo`03o`000?oooooooooo06?o
oooo1?l0001Looooo`00POooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05oooooo
1?l0001Pooooo`00P_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05_ooooo1?l0
001Tooooo`00Poooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oooooo1?l0001X
ooooo`00Q?ooool2o`0001cooooo00?o0000ooooooooool0Doooool4o`0006cooooo0026ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool4o`00073ooooo0027ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool3o`0007Cooooo0028ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007Oooooo0029ooooo`;o00005oooool0
0ol0003oooooooooo`14ooooo`Co0000Noooool008_ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`10ooooo`Co0000Ooooool008cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0looooo`Co0000Poooool008gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0hooooo`Co0000Qoooool008kooooo0_l0000Booooo`03o`000?oooooooooo03Cooooo1?l0
002;ooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037ooooo1?l0002?
ooooo`00TOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo0ol0002Coooo
o`00T_ooool2o`0000gooooo00?o0000ooooooooool0:_ooool4o`0009Kooooo002Dooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool09_ooool4o`0009[ooooo002Eooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0009kooooo002Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07_ooool4o`000:;ooooo002Gooooo`;o00002?ooool00ol0
003oooooooooo`0Jooooo`Co0000Y_ooool009Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0>ooooo`Co0000/_ooool009cooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo0ol0002f
ooooo`00W_ooool01?l0003oooooooooool00009ooooo`Co0000^Oooool009oooooo00?o0000oooo
ool000001Oooool4o`000;gooooo002Pooooo`;o000000?oooooo`000?l000000_l00031ooooo`00
XOooool2o`000<Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51721 .66611 m .51694 .65827 L .43899 .65168 L p .634 .19 .179 r
F P
0 g
s
.51694 .65827 m .51721 .66611 L .5929 .66105 L p .529 .086 .141 r
F P
0 g
s
.5929 .66105 m .59527 .65394 L .51694 .65827 L p .529 .086 .141 r
F P
0 g
s
.59527 .65394 m .5929 .66105 L .6652 .64467 L p .338 0 0 r
F P
0 g
s
.6652 .64467 m .67023 .63881 L .59527 .65394 L p .338 0 0 r
F P
0 g
s
.44189 .65967 m .43899 .65168 L .36521 .63435 L p .7 .229 .13 r
F P
0 g
s
.43899 .65168 m .44189 .65967 L .51721 .66611 L p .634 .19 .179 r
F P
0 g
s
.51749 .67438 m .51721 .66611 L .44189 .65967 L p .639 .2 .192 r
F P
0 g
s
.51721 .66611 m .51749 .67438 L .59049 .66856 L p .531 .093 .154 r
F P
0 g
s
.59049 .66856 m .5929 .66105 L .51721 .66611 L p .531 .093 .154 r
F P
0 g
s
.5929 .66105 m .59049 .66856 L .6601 .65085 L p .332 0 0 r
F P
0 g
s
.6601 .65085 m .6652 .64467 L .5929 .66105 L p .332 0 0 r
F P
0 g
s
.67023 .63881 m .6652 .64467 L .73033 .61749 L p 0 0 0 r
F P
0 g
s
.7226 .62191 m .73033 .61749 L .6652 .64467 L p 0 0 0 r
F P
0 g
s
.73033 .61749 m .7226 .62191 L .72307 .62156 L p .676 .961 .94 r
F P
0 g
s
.73742 .61353 m .67023 .63881 L p .73033 .61749 L 0 0 0 r
F P
0 g
s
.72307 .62156 m .77426 .58288 L p .73033 .61749 L .676 .961 .94 r
F P
0 g
s
.73033 .61749 m .73799 .61332 L .73742 .61353 L p 0 0 0 r
F P
0 g
s
.36521 .63435 m .3707 .64192 L .44189 .65967 L p .7 .229 .13 r
F P
0 g
s
.44483 .66809 m .44189 .65967 L .3707 .64192 L p .708 .242 .142 r
F P
0 g
s
.44189 .65967 m .44483 .66809 L .51749 .67438 L p .639 .2 .192 r
F P
0 g
s
.3707 .64192 m .36521 .63435 L .29943 .6068 L p .712 .187 0 r
F P
0 g
s
.51777 .68278 m .51749 .67438 L .44483 .66809 L p .639 .2 .191 r
F P
0 g
s
.51749 .67438 m .51777 .68278 L .58804 .67618 L p .526 .088 .152 r
F P
0 g
s
.58804 .67618 m .59049 .66856 L .51749 .67438 L p .526 .088 .152 r
F P
0 g
s
.59049 .66856 m .58804 .67618 L .65493 .65712 L p .312 0 0 r
F P
0 g
s
.65493 .65712 m .6601 .65085 L .59049 .66856 L p .312 0 0 r
F P
0 g
s
.6652 .64467 m .6601 .65085 L .7226 .62191 L p 0 0 0 r
F P
0 g
s
.3707 .64192 m .37626 .64988 L .44483 .66809 L p .708 .242 .142 r
F P
0 g
s
.44782 .67664 m .44483 .66809 L .37626 .64988 L p .711 .243 .139 r
F P
0 g
s
.44483 .66809 m .44782 .67664 L .51777 .68278 L p .639 .2 .191 r
F P
0 g
s
.29943 .6068 m .30744 .61342 L .3707 .64192 L p .712 .187 0 r
F P
0 g
s
.37626 .64988 m .3707 .64192 L .30744 .61342 L p .723 .201 0 r
F P
0 g
s
.51806 .69099 m .51777 .68278 L .44782 .67664 L p .634 .19 .178 r
F P
0 g
s
.51777 .68278 m .51806 .69099 L .58555 .68361 L p .513 .07 .135 r
F P
0 g
s
.58555 .68361 m .58804 .67618 L .51777 .68278 L p .513 .07 .135 r
F P
0 g
s
.6601 .65085 m .65493 .65712 L .71477 .62637 L p 0 0 0 r
F P
0 g
s
.71477 .62637 m .7226 .62191 L .6601 .65085 L p 0 0 0 r
F P
0 g
s
.58804 .67618 m .58555 .68361 L .64967 .6632 L p .274 0 0 r
F P
0 g
s
.64967 .6632 m .65493 .65712 L .58804 .67618 L p .274 0 0 r
F P
0 g
s
.73799 .61332 m .73033 .61749 L .78449 .58052 L p .634 .952 .939 r
F P
0 g
s
.78449 .58052 m .79464 .57831 L .73799 .61332 L p .634 .952 .939 r
F P
0 g
s
.37626 .64988 m .38191 .65795 L .44782 .67664 L p .711 .243 .139 r
F P
0 g
s
.45087 .68501 m .44782 .67664 L .38191 .65795 L p .709 .235 .12 r
F P
0 g
s
.44782 .67664 m .45087 .68501 L .51806 .69099 L p .634 .19 .178 r
F P
0 g
s
.30744 .61342 m .31554 .62037 L .37626 .64988 L p .723 .201 0 r
F P
0 g
s
.38191 .65795 m .37626 .64988 L .31554 .62037 L p .725 .201 0 r
F P
0 g
s
.29943 .6068 m .24716 .57104 L p .30735 .61336 L .515 0 0 r
F P
0 g
s
.30744 .61342 m .3071 .61314 L p .30735 .61336 L .515 0 0 r
F P
0 g
s
.3071 .61314 m .29943 .6068 L p .30735 .61336 L .515 0 0 r
F P
0 g
s
.30744 .61342 m .24716 .57104 L .24896 .57234 L .515 0 0 r
F
.24716 .57104 m .24558 .56996 L p .24896 .57234 L F P
0 g
s
.24558 .56996 m .25595 .57522 L .30744 .61342 L p .515 0 0 r
F P
0 g
s
.31554 .62037 m .30744 .61342 L .25595 .57522 L p .513 0 0 r
F P
0 g
s
.31354 .61876 m .31554 .62037 L p .31099 .61693 L .513 0 0 r
F P
0 g
s
.32374 .6274 m .31554 .62037 L .31354 .61876 L p .483 0 0 r
F P
0 g
s
.25595 .57522 m .2664 .58071 L .31354 .61876 L p .513 0 0 r
F P
0 g
s
.31099 .61693 m .25595 .57522 L .31354 .61876 L .513 0 0 r
F
.31354 .61876 m .2664 .58071 L p .31931 .62379 L .483 0 0 r
F P
0 g
s
.32374 .6274 m .31354 .61876 L .31931 .62379 L .483 0 0 r
F
.77426 .58288 m .78449 .58052 L .73033 .61749 L p .676 .961 .94 r
F P
0 g
s
.65493 .65712 m .64967 .6632 L .70683 .63068 L p 0 0 0 r
F P
0 g
s
.70683 .63068 m .71477 .62637 L .66703 .6509 L p 0 0 0 r
F P
0 g
s
.66703 .6509 m .65965 .65469 L p .6679 .6505 L 0 0 0 r
F P
0 g
s
.70683 .63068 m .66703 .6509 L .6679 .6505 L 0 0 0 r
F
.70683 .63068 m .65965 .65469 L .66206 .65348 L F
.66525 .65434 m .65628 .65945 L p .66567 .65396 L .421 .846 .696 r
F P
0 g
s
.69877 .63461 m .65628 .65945 L .65903 .65775 L .421 .846 .696 r
F
.69877 .63461 m .70683 .63068 L .66525 .65434 L p F P
0 g
s
.69877 .63461 m .66525 .65434 L .66567 .65396 L .421 .846 .696 r
F
.65628 .65945 m .64967 .6632 L p .65903 .65775 L F P
0 g
s
.64967 .6632 m .64431 .66884 L .69501 .63698 L p .421 .846 .696 r
F P
0 g
s
.69287 .63805 m .64967 .6632 L .69501 .63698 L .421 .846 .696 r
F
.69501 .63698 m .69877 .63461 L p .69287 .63805 L F P
0 g
s
.69059 .63797 m .69877 .63461 L .64431 .66884 L p .557 .929 .797 r
F P
0 g
s
.64431 .66884 m .63885 .67376 L .6821 .64384 L p .557 .929 .797 r
F P
0 g
s
.68106 .64433 m .64431 .66884 L .6821 .64384 L .557 .929 .797 r
F
.583 .69054 m .58039 .69666 L .63885 .67376 L p .117 0 0 r
F P
0 g
s
.63885 .67376 m .64431 .66884 L .583 .69054 L p .117 0 0 r
F P
0 g
s
.63327 .67768 m .63885 .67376 L .58039 .69666 L p 0 0 0 r
F P
0 g
s
.63885 .67376 m .63327 .67768 L .67094 .64913 L p .68 .978 .875 r
F P
0 g
s
.67094 .64913 m .68227 .64054 L p .67042 .64961 L .68 .978 .875 r
F P
0 g
s
.67042 .64961 m .63885 .67376 L .67094 .64913 L .68 .978 .875 r
F
.6821 .64384 m .69059 .63797 L p .68106 .64433 L .557 .929 .797 r
F P
0 g
s
.65965 .65469 m .65493 .65712 L p .66206 .65348 L 0 0 0 r
F P
0 g
s
.51835 .69868 m .51806 .69099 L .45087 .68501 L p .624 .168 .149 r
F P
0 g
s
.51806 .69099 m .51835 .69868 L .583 .69054 L p .49 .036 .1 r
F P
0 g
s
.583 .69054 m .58555 .68361 L .51806 .69099 L p .49 .036 .1 r
F P
0 g
s
.58555 .68361 m .583 .69054 L .64431 .66884 L p .213 0 0 r
F P
0 g
s
.64431 .66884 m .64967 .6632 L .58555 .68361 L p .213 0 0 r
F P
0 g
s
.38191 .65795 m .38766 .66585 L .45087 .68501 L p .709 .235 .12 r
F P
0 g
s
.45399 .69286 m .45087 .68501 L .38766 .66585 L p .702 .213 .083 r
F P
0 g
s
.45087 .68501 m .45399 .69286 L .51835 .69868 L p .624 .168 .149 r
F P
0 g
s
.31554 .62037 m .32374 .6274 L .38191 .65795 L p .725 .201 0 r
F P
0 g
s
.38766 .66585 m .38191 .65795 L .32374 .6274 L p .716 .184 0 r
F P
0 g
s
.7226 .62191 m .71477 .62637 L .76394 .58525 L p .718 .963 .941 r
F P
0 g
s
.76394 .58525 m .77426 .58288 L .7226 .62191 L p .718 .963 .941 r
F P
0 g
s
.51866 .70551 m .51835 .69868 L .45399 .69286 L p .605 .13 .1 r
F P
0 g
s
.51835 .69868 m .51866 .70551 L .58039 .69666 L p .452 0 .04 r
F P
0 g
s
.58039 .69666 m .583 .69054 L .51835 .69868 L p .452 0 .04 r
F P
0 g
s
.32374 .6274 m .33207 .63426 L .38766 .66585 L p .716 .184 0 r
F P
0 g
s
.39353 .67325 m .38766 .66585 L .33207 .63426 L p .691 .146 0 r
F P
0 g
s
.38766 .66585 m .39353 .67325 L .45399 .69286 L p .702 .213 .083 r
F P
0 g
s
.71477 .62637 m .70683 .63068 L .75352 .58751 L p .756 .956 .938 r
F P
0 g
s
.75352 .58751 m .76394 .58525 L .71477 .62637 L p .756 .956 .938 r
F P
0 g
s
.45718 .69985 m .45399 .69286 L .39353 .67325 L p .684 .174 .021 r
F P
0 g
s
.45399 .69286 m .45718 .69985 L .51866 .70551 L p .605 .13 .1 r
F P
0 g
s
.79464 .57831 m .78449 .58052 L .82389 .53529 L p .698 .834 .948 r
F P
0 g
s
.82389 .53529 m .83625 .53514 L .79464 .57831 L p .698 .834 .948 r
F P
0 g
s
.51897 .71115 m .51866 .70551 L .45718 .69985 L p .57 .066 .019 r
F P
0 g
s
.51866 .70551 m .51897 .71115 L .57773 .70164 L p .388 0 0 r
F P
0 g
s
.57773 .70164 m .58039 .69666 L .51866 .70551 L p .388 0 0 r
F P
0 g
s
.2664 .58071 m .27695 .58625 L .32374 .6274 L p .483 0 0 r
F P
0 g
s
.33207 .63426 m .32374 .6274 L .27695 .58625 L p 0 .092 .574 r
F P
0 g
s
.58039 .69666 m .57773 .70164 L .63327 .67768 L p 0 0 0 r
F P
0 g
s
.70683 .63068 m .69877 .63461 L .743 .58951 L p .785 .938 .929 r
F P
0 g
s
.743 .58951 m .75352 .58751 L .70683 .63068 L p .785 .938 .929 r
F P
0 g
s
.33207 .63426 m .34054 .64068 L .39353 .67325 L p .691 .146 0 r
F P
0 g
s
.39952 .67985 m .39353 .67325 L .34054 .64068 L p .639 .081 0 r
F P
0 g
s
.39353 .67325 m .39952 .67985 L .45718 .69985 L p .684 .174 .021 r
F P
0 g
s
.78449 .58052 m .77426 .58288 L .81148 .53549 L p .716 .824 .932 r
F P
0 g
s
.81148 .53549 m .82389 .53529 L .78449 .58052 L p .716 .824 .932 r
F P
0 g
s
.46045 .70565 m .45718 .69985 L .39952 .67985 L p .647 .108 0 r
F P
0 g
s
.45718 .69985 m .46045 .70565 L .51897 .71115 L p .57 .066 .019 r
F P
0 g
s
.25595 .57522 m .24558 .56996 L .20758 .52532 L p .038 .41 .86 r
F P
0 g
s
.68227 .64054 m .69059 .63797 L .63885 .67376 L p .68 .978 .875 r
F P
0 g
s
.77426 .58288 m .76394 .58525 L .79903 .53569 L p .73 .81 .914 r
F P
0 g
s
.79903 .53569 m .81148 .53549 L .77426 .58288 L p .73 .81 .914 r
F P
0 g
s
.69877 .63461 m .69059 .63797 L .73237 .59113 L p .805 .911 .913 r
F P
0 g
s
.73237 .59113 m .743 .58951 L .69877 .63461 L p .805 .911 .913 r
F P
0 g
s
.27695 .58625 m .28762 .59164 L .33207 .63426 L p 0 .092 .574 r
F P
0 g
s
.34054 .64068 m .33207 .63426 L .28762 .59164 L p 0 .157 .655 r
F P
0 g
s
.51928 .71526 m .51897 .71115 L .46045 .70565 L p .503 0 0 r
F P
0 g
s
.51897 .71115 m .51928 .71526 L .575 .7052 L p .276 0 0 r
F P
0 g
s
.575 .7052 m .57773 .70164 L .51897 .71115 L p .276 0 0 r
F P
0 g
s
.20758 .52532 m .21998 .52893 L .25595 .57522 L p .038 .41 .86 r
F P
0 g
s
.2664 .58071 m .25595 .57522 L .21998 .52893 L p .065 .407 .86 r
F P
0 g
s
.57773 .70164 m .575 .7052 L .62758 .68036 L p 0 0 0 r
F P
0 g
s
.62758 .68036 m .63327 .67768 L .59877 .69256 L p 0 0 0 r
F P
0 g
s
.62758 .68036 m .59877 .69256 L .59976 .69224 L 0 0 0 r
F
.62177 .68156 m .62758 .68036 L .59839 .69415 L p .497 .905 .827 r
F P
0 g
s
.59839 .69415 m .575 .7052 L p .59765 .69375 L .497 .905 .827 r
F P
0 g
s
.62177 .68156 m .59839 .69415 L .59765 .69375 L .497 .905 .827 r
F
.575 .7052 m .5722 .70705 L .60326 .69108 L p F P
0 g
s
.60232 .69139 m .575 .7052 L .60326 .69108 L .497 .905 .827 r
F
.59877 .69256 m .57773 .70164 L p .59976 .69224 L 0 0 0 r
F P
0 g
s
.5722 .70705 m .575 .7052 L .51928 .71526 L p .072 0 0 r
F P
0 g
s
.5722 .70705 m .56935 .70695 L .59531 .6925 L p .682 .964 .936 r
F P
0 g
s
.59531 .6925 m .61584 .68107 L p .59601 .69287 L .682 .964 .936 r
F P
0 g
s
.59601 .69287 m .5722 .70705 L .59531 .6925 L .682 .964 .936 r
F
.60326 .69108 m .62177 .68156 L p .60232 .69139 L .497 .905 .827 r
F P
0 g
s
.40564 .68534 m .39952 .67985 L .34915 .64641 L p .54 0 0 r
F P
0 g
s
.39952 .67985 m .40564 .68534 L .46045 .70565 L p .647 .108 0 r
F P
0 g
s
.46379 .70994 m .46045 .70565 L .40564 .68534 L p .57 0 0 r
F P
0 g
s
.40564 .68534 m .4119 .68943 L .46379 .70994 L p .57 0 0 r
F P
0 g
s
.4119 .68943 m .40564 .68534 L .37831 .66578 L p 0 .172 .618 r
F P
0 g
s
.37074 .66074 m .39952 .67985 L p .36654 .65795 L .639 .081 0 r
F P
0 g
s
.37831 .66578 m .35793 .65119 L p .38167 .66801 L 0 .172 .618 r
F P
0 g
s
.4119 .68943 m .37831 .66578 L .38167 .66801 L 0 .172 .618 r
F
.34054 .64068 m .34915 .64641 L .37074 .66074 L p .639 .081 0 r
F P
0 g
s
.36654 .65795 m .34054 .64068 L .37074 .66074 L .639 .081 0 r
F
.76394 .58525 m .75352 .58751 L .78651 .53584 L p .741 .793 .895 r
F P
0 g
s
.78651 .53584 m .79903 .53569 L .76394 .58525 L p .741 .793 .895 r
F P
0 g
s
.46045 .70565 m .46379 .70994 L .51928 .71526 L p .503 0 0 r
F P
0 g
s
.63327 .67768 m .62758 .68036 L .67381 .64214 L p .766 .98 .913 r
F P
0 g
s
.67381 .64214 m .68227 .64054 L .63327 .67768 L p .766 .98 .913 r
F P
0 g
s
.69059 .63797 m .68227 .64054 L .72162 .59223 L p .814 .878 .892 r
F P
0 g
s
.72162 .59223 m .73237 .59113 L .69059 .63797 L p .814 .878 .892 r
F P
0 g
s
.21998 .52893 m .23244 .53267 L .2664 .58071 L p .065 .407 .86 r
F P
0 g
s
.27695 .58625 m .2664 .58071 L .23244 .53267 L p .111 .416 .863 r
F P
0 g
s
.28762 .59164 m .29842 .59668 L .34054 .64068 L p 0 .157 .655 r
F P
0 g
s
.34915 .64641 m .34054 .64068 L .29842 .59668 L p 0 .239 .74 r
F P
0 g
s
.75352 .58751 m .743 .58951 L .77394 .53588 L p .749 .775 .875 r
F P
0 g
s
.77394 .53588 m .78651 .53584 L .75352 .58751 L p .749 .775 .875 r
F P
0 g
s
.51961 .71756 m .51928 .71526 L .46379 .70994 L p .367 0 0 r
F P
0 g
s
.51928 .71526 m .51961 .71756 L .5722 .70705 L p .072 0 0 r
F P
0 g
s
.34915 .64641 m .35793 .65119 L .40564 .68534 L p .54 0 0 r
F P
0 g
s
.23244 .53267 m .24497 .53643 L .27695 .58625 L p .111 .416 .863 r
F P
0 g
s
.28762 .59164 m .27695 .58625 L .24497 .53643 L p .17 .432 .866 r
F P
0 g
s
.68227 .64054 m .67381 .64214 L .71075 .5927 L p .816 .842 .869 r
F P
0 g
s
.71075 .5927 m .72162 .59223 L .68227 .64054 L p .816 .842 .869 r
F P
0 g
s
.62758 .68036 m .62177 .68156 L .66522 .64259 L p .81 .944 .913 r
F P
0 g
s
.66522 .64259 m .67381 .64214 L .62758 .68036 L p .81 .944 .913 r
F P
0 g
s
.46722 .71243 m .46379 .70994 L .4119 .68943 L p .408 0 0 r
F P
0 g
s
.46379 .70994 m .46722 .71243 L .51961 .71756 L p .367 0 0 r
F P
0 g
s
.743 .58951 m .73237 .59113 L .76131 .53577 L p .754 .756 .854 r
F P
0 g
s
.76131 .53577 m .77394 .53588 L .743 .58951 L p .754 .756 .854 r
F P
0 g
s
.29842 .59668 m .30937 .60119 L .34915 .64641 L p 0 .239 .74 r
F P
0 g
s
.35793 .65119 m .34915 .64641 L .30937 .60119 L p 0 .327 .811 r
F P
0 g
s
.56935 .70695 m .5722 .70705 L .51961 .71756 L p .244 .759 .792 r
F P
0 g
s
.61584 .68107 m .62177 .68156 L .5722 .70705 L p .682 .964 .936 r
F P
0 g
s
.24497 .53643 m .25758 .54008 L .28762 .59164 L p .17 .432 .866 r
F P
0 g
s
.29842 .59668 m .28762 .59164 L .25758 .54008 L p .238 .452 .866 r
F P
0 g
s
.51994 .71778 m .51961 .71756 L .46722 .71243 L p .098 0 0 r
F P
0 g
s
.51961 .71756 m .51994 .71778 L .56935 .70695 L p .244 .759 .792 r
F P
0 g
s
.73237 .59113 m .72162 .59223 L .74861 .53546 L p .756 .737 .835 r
F P
0 g
s
.74861 .53546 m .76131 .53577 L .73237 .59113 L p .756 .737 .835 r
F P
0 g
s
.67381 .64214 m .66522 .64259 L .69976 .59242 L p .813 .806 .845 r
F P
0 g
s
.69976 .59242 m .71075 .5927 L .67381 .64214 L p .813 .806 .845 r
F P
0 g
s
.35793 .65119 m .36687 .65477 L .4119 .68943 L p 0 .172 .618 r
F P
0 g
s
.4183 .69186 m .4119 .68943 L .36687 .65477 L p 0 .34 .798 r
F P
0 g
s
.4119 .68943 m .4183 .69186 L .46722 .71243 L p .408 0 0 r
F P
0 g
s
.83625 .53514 m .82389 .53529 L .84503 .48401 L p .617 .705 .908 r
F P
0 g
s
.84503 .48401 m .85906 .48583 L .83625 .53514 L p .617 .705 .908 r
F P
0 g
s
.62177 .68156 m .61584 .68107 L .65649 .64172 L p .824 .891 .891 r
F P
0 g
s
.65649 .64172 m .66522 .64259 L .62177 .68156 L p .824 .891 .891 r
F P
0 g
s
.46722 .71243 m .47073 .71285 L .51994 .71778 L p .098 0 0 r
F P
0 g
s
.47073 .71285 m .46722 .71243 L .4183 .69186 L p 0 .43 .787 r
F P
0 g
s
.30937 .60119 m .32046 .60496 L .35793 .65119 L p 0 .327 .811 r
F P
0 g
s
.36687 .65477 m .35793 .65119 L .32046 .60496 L p .128 .405 .854 r
F P
0 g
s
.82389 .53529 m .81148 .53549 L .831 .48216 L p .629 .694 .892 r
F P
0 g
s
.831 .48216 m .84503 .48401 L .82389 .53529 L p .629 .694 .892 r
F P
0 g
s
.72162 .59223 m .71075 .5927 L .73585 .5349 L p .757 .718 .816 r
F P
0 g
s
.73585 .5349 m .74861 .53546 L .72162 .59223 L p .757 .718 .816 r
F P
0 g
s
.25758 .54008 m .27028 .54351 L .29842 .59668 L p .238 .452 .866 r
F P
0 g
s
.30937 .60119 m .29842 .59668 L .27028 .54351 L p .307 .473 .861 r
F P
0 g
s
.81148 .53549 m .79903 .53569 L .81699 .48031 L p .639 .683 .875 r
F P
0 g
s
.81699 .48031 m .831 .48216 L .81148 .53549 L p .639 .683 .875 r
F P
0 g
s
.66522 .64259 m .65649 .64172 L .68865 .59129 L p .806 .773 .822 r
F P
0 g
s
.68865 .59129 m .69976 .59242 L .66522 .64259 L p .806 .773 .822 r
F P
0 g
s
.56643 .70468 m .56935 .70695 L .51994 .71778 L p .538 .897 .972 r
F P
0 g
s
.56935 .70695 m .56643 .70468 L .6098 .67872 L p .766 .926 .94 r
F P
0 g
s
.6098 .67872 m .61584 .68107 L .56935 .70695 L p .766 .926 .94 r
F P
0 g
s
.52028 .71569 m .51994 .71778 L .47073 .71285 L p .269 .732 .949 r
F P
0 g
s
.51994 .71778 m .52028 .71569 L .56643 .70468 L p .538 .897 .972 r
F P
0 g
s
.21998 .52893 m .20758 .52532 L .18911 .47507 L p .425 .602 .92 r
F P
0 g
s
.36687 .65477 m .37598 .65692 L .4183 .69186 L p 0 .34 .798 r
F P
0 g
s
.42484 .69237 m .4183 .69186 L .37598 .65692 L p .142 .474 .895 r
F P
0 g
s
.4183 .69186 m .42484 .69237 L .47073 .71285 L p 0 .43 .787 r
F P
0 g
s
.61584 .68107 m .6098 .67872 L .64763 .63942 L p .821 .837 .86 r
F P
0 g
s
.64763 .63942 m .65649 .64172 L .61584 .68107 L p .821 .837 .86 r
F P
0 g
s
.79903 .53569 m .78651 .53584 L .80299 .4785 L p .65 .672 .858 r
F P
0 g
s
.80299 .4785 m .81699 .48031 L .79903 .53569 L p .65 .672 .858 r
F P
0 g
s
.71075 .5927 m .69976 .59242 L .72303 .53405 L p .756 .701 .799 r
F P
0 g
s
.72303 .53405 m .73585 .5349 L .71075 .5927 L p .756 .701 .799 r
F P
0 g
s
.32046 .60496 m .3317 .60782 L .36687 .65477 L p .128 .405 .854 r
F P
0 g
s
.37598 .65692 m .36687 .65477 L .3317 .60782 L p .271 .465 .867 r
F P
0 g
s
.47432 .71098 m .47073 .71285 L .42484 .69237 L p .221 .607 .951 r
F P
0 g
s
.47073 .71285 m .47432 .71098 L .52028 .71569 L p .269 .732 .949 r
F P
0 g
s
.27028 .54351 m .28307 .5466 L .30937 .60119 L p .307 .473 .861 r
F P
0 g
s
.32046 .60496 m .30937 .60119 L .28307 .5466 L p .373 .493 .852 r
F P
0 g
s
.78651 .53584 m .77394 .53588 L .78901 .47676 L p .66 .662 .841 r
F P
0 g
s
.78901 .47676 m .80299 .4785 L .78651 .53584 L p .66 .662 .841 r
F P
0 g
s
.18911 .47507 m .20299 .47689 L .21998 .52893 L p .425 .602 .92 r
F P
0 g
s
.23244 .53267 m .21998 .52893 L .20299 .47689 L p .443 .592 .905 r
F P
0 g
s
.65649 .64172 m .64763 .63942 L .67743 .58925 L p .798 .742 .801 r
F P
0 g
s
.67743 .58925 m .68865 .59129 L .65649 .64172 L p .798 .742 .801 r
F P
0 g
s
.77394 .53588 m .76131 .53577 L .77504 .47512 L p .668 .652 .825 r
F P
0 g
s
.77504 .47512 m .78901 .47676 L .77394 .53588 L p .668 .652 .825 r
F P
0 g
s
.69976 .59242 m .68865 .59129 L .71014 .53288 L p .755 .684 .783 r
F P
0 g
s
.71014 .53288 m .72303 .53405 L .69976 .59242 L p .755 .684 .783 r
F P
0 g
s
.56345 .7001 m .56643 .70468 L .52028 .71569 L p .682 .874 .971 r
F P
0 g
s
.56643 .70468 m .56345 .7001 L .60365 .67436 L p .79 .858 .901 r
F P
0 g
s
.60365 .67436 m .6098 .67872 L .56643 .70468 L p .79 .858 .901 r
F P
0 g
s
.6098 .67872 m .60365 .67436 L .63863 .63558 L p .811 .787 .83 r
F P
0 g
s
.63863 .63558 m .64763 .63942 L .6098 .67872 L p .811 .787 .83 r
F P
0 g
s
.20299 .47689 m .21688 .47876 L .23244 .53267 L p .443 .592 .905 r
F P
0 g
s
.24497 .53643 m .23244 .53267 L .21688 .47876 L p .465 .585 .889 r
F P
0 g
s
.52063 .71111 m .52028 .71569 L .47432 .71098 L p .523 .789 .993 r
F P
0 g
s
.52028 .71569 m .52063 .71111 L .56345 .7001 L p .682 .874 .971 r
F P
0 g
s
.37598 .65692 m .38525 .65746 L .42484 .69237 L p .142 .474 .895 r
F P
0 g
s
.43151 .69077 m .42484 .69237 L .38525 .65746 L p .343 .549 .909 r
F P
0 g
s
.42484 .69237 m .43151 .69077 L .47432 .71098 L p .221 .607 .951 r
F P
0 g
s
.76131 .53577 m .74861 .53546 L .76109 .47362 L p .677 .643 .809 r
F P
0 g
s
.76109 .47362 m .77504 .47512 L .76131 .53577 L p .677 .643 .809 r
F P
0 g
s
.28307 .5466 m .29596 .54924 L .32046 .60496 L p .373 .493 .852 r
F P
0 g
s
.3317 .60782 m .32046 .60496 L .29596 .54924 L p .434 .511 .838 r
F P
0 g
s
.3317 .60782 m .34309 .60961 L .37598 .65692 L p .271 .465 .867 r
F P
0 g
s
.38525 .65746 m .37598 .65692 L .34309 .60961 L p .385 .507 .859 r
F P
0 g
s
.64763 .63942 m .63863 .63558 L .6661 .58622 L p .789 .715 .782 r
F P
0 g
s
.6661 .58622 m .67743 .58925 L .64763 .63942 L p .789 .715 .782 r
F P
0 g
s
.68865 .59129 m .67743 .58925 L .69719 .53136 L p .753 .669 .769 r
F P
0 g
s
.69719 .53136 m .71014 .53288 L .68865 .59129 L p .753 .669 .769 r
F P
0 g
s
.47799 .70665 m .47432 .71098 L .43151 .69077 L p .448 .665 .955 r
F P
0 g
s
.47432 .71098 m .47799 .70665 L .52063 .71111 L p .523 .789 .993 r
F P
0 g
s
.74861 .53546 m .73585 .5349 L .74716 .47228 L p .684 .635 .795 r
F P
0 g
s
.74716 .47228 m .76109 .47362 L .74861 .53546 L p .684 .635 .795 r
F P
0 g
s
.21688 .47876 m .23078 .48062 L .24497 .53643 L p .465 .585 .889 r
F P
0 g
s
.25758 .54008 m .24497 .53643 L .23078 .48062 L p .49 .58 .873 r
F P
0 g
s
.56041 .69308 m .56345 .7001 L .52063 .71111 L p .731 .808 .912 r
F P
0 g
s
.56345 .7001 m .56041 .69308 L .5974 .66792 L p .789 .794 .856 r
F P
0 g
s
.5974 .66792 m .60365 .67436 L .56345 .7001 L p .789 .794 .856 r
F P
0 g
s
.73585 .5349 m .72303 .53405 L .73325 .47113 L p .691 .628 .781 r
F P
0 g
s
.73325 .47113 m .74716 .47228 L .73585 .5349 L p .691 .628 .781 r
F P
0 g
s
.60365 .67436 m .5974 .66792 L .62953 .63013 L p .799 .745 .803 r
F P
0 g
s
.62953 .63013 m .63863 .63558 L .60365 .67436 L p .799 .745 .803 r
F P
0 g
s
.29596 .54924 m .30895 .55132 L .3317 .60782 L p .434 .511 .838 r
F P
0 g
s
.34309 .60961 m .3317 .60782 L .30895 .55132 L p .486 .525 .823 r
F P
0 g
s
.67743 .58925 m .6661 .58622 L .68418 .52947 L p .75 .656 .756 r
F P
0 g
s
.68418 .52947 m .69719 .53136 L .67743 .58925 L p .75 .656 .756 r
F P
0 g
s
.23078 .48062 m .24469 .48245 L .25758 .54008 L p .49 .58 .873 r
F P
0 g
s
.27028 .54351 m .25758 .54008 L .24469 .48245 L p .515 .577 .856 r
F P
0 g
s
.52098 .70394 m .52063 .71111 L .47799 .70665 L p .636 .756 .935 r
F P
0 g
s
.52063 .71111 m .52098 .70394 L .56041 .69308 L p .731 .808 .912 r
F P
0 g
s
.63863 .63558 m .62953 .63013 L .65466 .58217 L p .78 .691 .765 r
F P
0 g
s
.65466 .58217 m .6661 .58622 L .63863 .63558 L p .78 .691 .765 r
F P
0 g
s
.38525 .65746 m .39468 .65621 L .43151 .69077 L p .343 .549 .909 r
F P
0 g
s
.43831 .6869 m .43151 .69077 L .39468 .65621 L p .475 .582 .882 r
F P
0 g
s
.43151 .69077 m .43831 .6869 L .47799 .70665 L p .448 .665 .955 r
F P
0 g
s
.34309 .60961 m .35464 .61017 L .38525 .65746 L p .385 .507 .859 r
F P
0 g
s
.39468 .65621 m .38525 .65746 L .35464 .61017 L p .473 .534 .84 r
F P
0 g
s
.72303 .53405 m .71014 .53288 L .71936 .47019 L p .697 .621 .768 r
F P
0 g
s
.71936 .47019 m .73325 .47113 L .72303 .53405 L p .697 .621 .768 r
F P
0 g
s
.48172 .69974 m .47799 .70665 L .43831 .6869 L p .567 .665 .903 r
F P
0 g
s
.47799 .70665 m .48172 .69974 L .52098 .70394 L p .636 .756 .935 r
F P
0 g
s
.6661 .58622 m .65466 .58217 L .67112 .52719 L p .748 .643 .745 r
F P
0 g
s
.67112 .52719 m .68418 .52947 L .6661 .58622 L p .748 .643 .745 r
F P
0 g
s
.71014 .53288 m .69719 .53136 L .70548 .46948 L p .702 .615 .757 r
F P
0 g
s
.70548 .46948 m .71936 .47019 L .71014 .53288 L p .702 .615 .757 r
F P
0 g
s
.24469 .48245 m .25862 .48421 L .27028 .54351 L p .515 .577 .856 r
F P
0 g
s
.28307 .5466 m .27028 .54351 L .25862 .48421 L p .54 .575 .839 r
F P
0 g
s
.59106 .65935 m .5974 .66792 L .56041 .69308 L p .781 .742 .817 r
F P
0 g
s
.5974 .66792 m .59106 .65935 L .62031 .62304 L p .787 .71 .779 r
F P
0 g
s
.62031 .62304 m .62953 .63013 L .5974 .66792 L p .787 .71 .779 r
F P
0 g
s
.30895 .55132 m .32204 .55274 L .34309 .60961 L p .486 .525 .823 r
F P
0 g
s
.35464 .61017 m .34309 .60961 L .32204 .55274 L p .531 .537 .807 r
F P
0 g
s
.55732 .68359 m .56041 .69308 L .52098 .70394 L p .744 .748 .855 r
F P
0 g
s
.56041 .69308 m .55732 .68359 L .59106 .65935 L p .781 .742 .817 r
F P
0 g
s
.62953 .63013 m .62031 .62304 L .64314 .57708 L p .771 .67 .751 r
F P
0 g
s
.64314 .57708 m .65466 .58217 L .62953 .63013 L p .771 .67 .751 r
F P
0 g
s
.69719 .53136 m .68418 .52947 L .69162 .46902 L p .706 .61 .746 r
F P
0 g
s
.69162 .46902 m .70548 .46948 L .69719 .53136 L p .706 .61 .746 r
F P
0 g
s
.52134 .69412 m .52098 .70394 L .48172 .69974 L p .683 .713 .871 r
F P
0 g
s
.52098 .70394 m .52134 .69412 L .55732 .68359 L p .744 .748 .855 r
F P
0 g
s
.35464 .61017 m .36633 .6094 L .39468 .65621 L p .473 .534 .84 r
F P
0 g
s
.40425 .65304 m .39468 .65621 L .36633 .6094 L p .538 .552 .817 r
F P
0 g
s
.39468 .65621 m .40425 .65304 L .43831 .6869 L p .475 .582 .882 r
F P
0 g
s
.65466 .58217 m .64314 .57708 L .65801 .52452 L p .745 .632 .734 r
F P
0 g
s
.65801 .52452 m .67112 .52719 L .65466 .58217 L p .745 .632 .734 r
F P
0 g
s
.44523 .68066 m .43831 .6869 L .40425 .65304 L p .558 .594 .846 r
F P
0 g
s
.43831 .6869 m .44523 .68066 L .48172 .69974 L p .567 .665 .903 r
F P
0 g
s
.25862 .48421 m .27257 .48586 L .28307 .5466 L p .54 .575 .839 r
F P
0 g
s
.29596 .54924 m .28307 .5466 L .27257 .48586 L p .564 .575 .822 r
F P
0 g
s
.68418 .52947 m .67112 .52719 L .67776 .4688 L p .711 .605 .737 r
F P
0 g
s
.67776 .4688 m .69162 .46902 L .68418 .52947 L p .711 .605 .737 r
F P
0 g
s
.48552 .69019 m .48172 .69974 L .44523 .68066 L p .63 .65 .851 r
F P
0 g
s
.48172 .69974 m .48552 .69019 L .52134 .69412 L p .683 .713 .871 r
F P
0 g
s
.611 .61433 m .62031 .62304 L .59106 .65935 L p .775 .681 .759 r
F P
0 g
s
.62031 .62304 m .611 .61433 L .63153 .57096 L p .763 .652 .738 r
F P
0 g
s
.63153 .57096 m .64314 .57708 L .62031 .62304 L p .763 .652 .738 r
F P
0 g
s
.58464 .64865 m .59106 .65935 L .55732 .68359 L p .771 .702 .786 r
F P
0 g
s
.59106 .65935 m .58464 .64865 L .611 .61433 L p .775 .681 .759 r
F P
0 g
s
.67112 .52719 m .65801 .52452 L .66391 .46884 L p .714 .601 .729 r
F P
0 g
s
.66391 .46884 m .67776 .4688 L .67112 .52719 L p .714 .601 .729 r
F P
0 g
s
.32204 .55274 m .33522 .55342 L .35464 .61017 L p .531 .537 .807 r
F P
0 g
s
.36633 .6094 m .35464 .61017 L .33522 .55342 L p .569 .547 .79 r
F P
0 g
s
.64314 .57708 m .63153 .57096 L .64485 .52146 L p .743 .622 .726 r
F P
0 g
s
.64485 .52146 m .65801 .52452 L .64314 .57708 L p .743 .622 .726 r
F P
0 g
s
.5542 .67162 m .55732 .68359 L .52134 .69412 L p .746 .703 .811 r
F P
0 g
s
.55732 .68359 m .5542 .67162 L .58464 .64865 L p .771 .702 .786 r
F P
0 g
s
.27257 .48586 m .28654 .48739 L .29596 .54924 L p .564 .575 .822 r
F P
0 g
s
.30895 .55132 m .29596 .54924 L .28654 .48739 L p .587 .574 .806 r
F P
0 g
s
.65801 .52452 m .64485 .52146 L .65007 .46913 L p .717 .597 .721 r
F P
0 g
s
.65007 .46913 m .66391 .46884 L .65801 .52452 L p .717 .597 .721 r
F P
0 g
s
.36633 .6094 m .37815 .6072 L .40425 .65304 L p .538 .552 .817 r
F P
0 g
s
.41397 .64788 m .40425 .65304 L .37815 .6072 L p .586 .563 .795 r
F P
0 g
s
.40425 .65304 m .41397 .64788 L .44523 .68066 L p .558 .594 .846 r
F P
0 g
s
.52171 .68165 m .52134 .69412 L .48552 .69019 L p .705 .677 .821 r
F P
0 g
s
.52134 .69412 m .52171 .68165 L .5542 .67162 L p .746 .703 .811 r
F P
0 g
s
.61985 .56383 m .63153 .57096 L .611 .61433 L p .756 .636 .727 r
F P
0 g
s
.63153 .57096 m .61985 .56383 L .63165 .51802 L p .74 .614 .718 r
F P
0 g
s
.63165 .51802 m .64485 .52146 L .63153 .57096 L p .74 .614 .718 r
F P
0 g
s
.45225 .672 m .44523 .68066 L .41397 .64788 L p .611 .597 .812 r
F P
0 g
s
.44523 .68066 m .45225 .672 L .48552 .69019 L p .63 .65 .851 r
F P
0 g
s
.60161 .60403 m .611 .61433 L .58464 .64865 L p .765 .657 .743 r
F P
0 g
s
.611 .61433 m .60161 .60403 L .61985 .56383 L p .756 .636 .727 r
F P
0 g
s
.71936 .47019 m .70548 .46948 L .70157 .40769 L p .646 .576 .762 r
F P
0 g
s
.70548 .46948 m .69162 .46902 L .68778 .40887 L p .659 .577 .751 r
F P
0 g
s
.68778 .40887 m .70157 .40769 L .70548 .46948 L p .659 .577 .751 r
F P
0 g
s
.64485 .52146 m .63165 .51802 L .63622 .46967 L p .72 .594 .715 r
F P
0 g
s
.63622 .46967 m .65007 .46913 L .64485 .52146 L p .72 .594 .715 r
F P
0 g
s
.73325 .47113 m .71936 .47019 L .71546 .40733 L p .632 .576 .773 r
F P
0 g
s
.70157 .40769 m .71546 .40733 L .71936 .47019 L p .646 .576 .762 r
F P
0 g
s
.69162 .46902 m .67776 .4688 L .67406 .41089 L p .671 .578 .741 r
F P
0 g
s
.67406 .41089 m .68778 .40887 L .69162 .46902 L p .671 .578 .741 r
F P
0 g
s
.74716 .47228 m .73325 .47113 L .72943 .40775 L p .617 .576 .785 r
F P
0 g
s
.71546 .40733 m .72943 .40775 L .73325 .47113 L p .632 .576 .773 r
F P
0 g
s
.67776 .4688 m .66391 .46884 L .66041 .41376 L p .682 .578 .732 r
F P
0 g
s
.66041 .41376 m .67406 .41089 L .67776 .4688 L p .682 .578 .732 r
F P
0 g
s
.76109 .47362 m .74716 .47228 L .74351 .40888 L p .6 .576 .798 r
F P
0 g
s
.72943 .40775 m .74351 .40888 L .74716 .47228 L p .617 .576 .785 r
F P
0 g
s
.66391 .46884 m .65007 .46913 L .64681 .41748 L p .692 .579 .724 r
F P
0 g
s
.64681 .41748 m .66041 .41376 L .66391 .46884 L p .692 .579 .724 r
F P
0 g
s
.57815 .63589 m .58464 .64865 L .5542 .67162 L p .762 .67 .761 r
F P
0 g
s
.58464 .64865 m .57815 .63589 L .60161 .60403 L p .765 .657 .743 r
F P
0 g
s
.77504 .47512 m .76109 .47362 L .75769 .41066 L p .583 .577 .812 r
F P
0 g
s
.74351 .40888 m .75769 .41066 L .76109 .47362 L p .6 .576 .798 r
F P
0 g
s
.65007 .46913 m .63622 .46967 L .63326 .42203 L p .7 .58 .717 r
F P
0 g
s
.63326 .42203 m .64681 .41748 L .65007 .46913 L p .7 .58 .717 r
F P
0 g
s
.78901 .47676 m .77504 .47512 L .77199 .41301 L p .566 .579 .826 r
F P
0 g
s
.75769 .41066 m .77199 .41301 L .77504 .47512 L p .583 .577 .812 r
F P
0 g
s
.33522 .55342 m .3485 .5533 L .36633 .6094 L p .569 .547 .79 r
F P
0 g
s
.37815 .6072 m .36633 .6094 L .3485 .5533 L p .601 .555 .775 r
F P
0 g
s
.28654 .48739 m .30052 .48874 L .30895 .55132 L p .587 .574 .806 r
F P
0 g
s
.32204 .55274 m .30895 .55132 L .30052 .48874 L p .607 .575 .791 r
F P
0 g
s
.61842 .51421 m .63165 .51802 L .61985 .56383 L p .738 .607 .711 r
F P
0 g
s
.63165 .51802 m .61842 .51421 L .62238 .47044 L p .723 .592 .709 r
F P
0 g
s
.62238 .47044 m .63622 .46967 L .63165 .51802 L p .723 .592 .709 r
F P
0 g
s
.63622 .46967 m .62238 .47044 L .61974 .42736 L p .707 .581 .711 r
F P
0 g
s
.61974 .42736 m .63326 .42203 L .63622 .46967 L p .707 .581 .711 r
F P
0 g
s
.80299 .4785 m .78901 .47676 L .78639 .41583 L p .549 .582 .84 r
F P
0 g
s
.77199 .41301 m .78639 .41583 L .78901 .47676 L p .566 .579 .826 r
F P
0 g
s
.48937 .67803 m .48552 .69019 L .45225 .672 L p .666 .635 .809 r
F P
0 g
s
.48552 .69019 m .48937 .67803 L .52171 .68165 L p .705 .677 .821 r
F P
0 g
s
.60812 .55574 m .61985 .56383 L .60161 .60403 L p .75 .623 .718 r
F P
0 g
s
.61985 .56383 m .60812 .55574 L .61842 .51421 L p .738 .607 .711 r
F P
0 g
s
.60624 .43343 m .61974 .42736 L .62238 .47044 L p .713 .581 .706 r
F P
0 g
s
.63326 .42203 m .61974 .42736 L .61068 .38789 L p .694 .576 .718 r
F P
0 g
s
.61974 .42736 m .60624 .43343 L .59844 .39864 L p .704 .578 .71 r
F P
0 g
s
.59844 .39864 m .61068 .38789 L .61974 .42736 L p .704 .578 .71 r
F P
0 g
s
.81699 .48031 m .80299 .4785 L .80089 .41901 L p .532 .586 .855 r
F P
0 g
s
.78639 .41583 m .80089 .41901 L .80299 .4785 L p .549 .582 .84 r
F P
0 g
s
.64681 .41748 m .63326 .42203 L .62295 .37831 L p .683 .573 .726 r
F P
0 g
s
.61068 .38789 m .62295 .37831 L .63326 .42203 L p .694 .576 .718 r
F P
0 g
s
.55103 .65725 m .5542 .67162 L .52171 .68165 L p .744 .669 .778 r
F P
0 g
s
.5542 .67162 m .55103 .65725 L .57815 .63589 L p .762 .67 .761 r
F P
0 g
s
.58623 .41047 m .59844 .39864 L .60624 .43343 L p .712 .579 .704 r
F P
0 g
s
.61068 .38789 m .59844 .39864 L .58568 .36941 L p .7 .58 .718 r
F P
0 g
s
.59844 .39864 m .58623 .41047 L .57558 .38555 L p .71 .581 .709 r
F P
0 g
s
.57558 .38555 m .58568 .36941 L .59844 .39864 L p .71 .581 .709 r
F P
0 g
s
.60853 .47142 m .62238 .47044 L .61842 .51421 L p .725 .589 .704 r
F P
0 g
s
.62238 .47044 m .60853 .47142 L .60624 .43343 L p .713 .581 .706 r
F P
0 g
s
.59274 .44016 m .60624 .43343 L .60853 .47142 L p .718 .582 .701 r
F P
0 g
s
.60624 .43343 m .59274 .44016 L .58623 .41047 L p .712 .579 .704 r
F P
0 g
s
.62295 .37831 m .61068 .38789 L .5958 .35467 L p .688 .579 .728 r
F P
0 g
s
.58568 .36941 m .5958 .35467 L .61068 .38789 L p .7 .58 .718 r
F P
0 g
s
.5655 .40291 m .57558 .38555 L .58623 .41047 L p .717 .582 .702 r
F P
0 g
s
.58568 .36941 m .57558 .38555 L .5615 .36706 L p .712 .587 .714 r
F P
0 g
s
.57558 .38555 m .5655 .40291 L .55423 .38785 L p .719 .585 .705 r
F P
0 g
s
.55423 .38785 m .5615 .36706 L .57558 .38555 L p .719 .585 .705 r
F P
0 g
s
.5958 .35467 m .58568 .36941 L .56879 .3477 L p .702 .589 .726 r
F P
0 g
s
.5615 .36706 m .56879 .3477 L .58568 .36941 L p .712 .587 .714 r
F P
0 g
s
.58623 .41047 m .57403 .42324 L .5655 .40291 L p .717 .582 .702 r
F P
0 g
s
.57403 .42324 m .58623 .41047 L .59274 .44016 L p .719 .58 .699 r
F P
0 g
s
.66041 .41376 m .64681 .41748 L .63528 .37 L p .668 .57 .735 r
F P
0 g
s
.62295 .37831 m .63528 .37 L .64681 .41748 L p .683 .573 .726 r
F P
0 g
s
.831 .48216 m .81699 .48031 L .8155 .42246 L p .516 .592 .869 r
F P
0 g
s
.80089 .41901 m .8155 .42246 L .81699 .48031 L p .532 .586 .855 r
F P
0 g
s
.60515 .51008 m .61842 .51421 L .60812 .55574 L p .736 .6 .706 r
F P
0 g
s
.61842 .51421 m .60515 .51008 L .60853 .47142 L p .725 .589 .704 r
F P
0 g
s
.56879 .3477 m .5615 .36706 L .54494 .35625 L p .718 .596 .719 r
F P
0 g
s
.5615 .36706 m .55423 .38785 L .54098 .37907 L p .723 .591 .708 r
F P
0 g
s
.54098 .37907 m .54494 .35625 L .5615 .36706 L p .723 .591 .708 r
F P
0 g
s
.59216 .59223 m .60161 .60403 L .57815 .63589 L p .757 .638 .729 r
F P
0 g
s
.60161 .60403 m .59216 .59223 L .60812 .55574 L p .75 .623 .718 r
F P
0 g
s
.60853 .47142 m .59466 .47261 L .59274 .44016 L p .718 .582 .701 r
F P
0 g
s
.57925 .44747 m .59274 .44016 L .59466 .47261 L p .723 .582 .697 r
F P
0 g
s
.59274 .44016 m .57925 .44747 L .57403 .42324 L p .719 .58 .699 r
F P
0 g
s
.59466 .47261 m .60853 .47142 L .60515 .51008 L p .726 .587 .7 r
F P
0 g
s
.55543 .42132 m .5655 .40291 L .57403 .42324 L p .723 .582 .697 r
F P
0 g
s
.5655 .40291 m .55543 .42132 L .54697 .40985 L p .724 .584 .699 r
F P
0 g
s
.54697 .40985 m .55423 .38785 L .5655 .40291 L p .724 .584 .699 r
F P
0 g
s
.5958 .35467 m .60598 .34146 L .62295 .37831 L p .688 .579 .728 r
F P
0 g
s
.60598 .34146 m .5958 .35467 L .57611 .32995 L p .69 .591 .74 r
F P
0 g
s
.56879 .3477 m .57611 .32995 L .5958 .35467 L p .702 .589 .726 r
F P
0 g
s
.63528 .37 m .62295 .37831 L .60598 .34146 L p .672 .577 .74 r
F P
0 g
s
.57611 .32995 m .56879 .3477 L .54891 .33497 L p .711 .602 .733 r
F P
0 g
s
.54494 .35625 m .54891 .33497 L .56879 .3477 L p .718 .596 .719 r
F P
0 g
s
.55423 .38785 m .54697 .40985 L .53702 .40318 L p .726 .587 .7 r
F P
0 g
s
.53702 .40318 m .54098 .37907 L .55423 .38785 L p .726 .587 .7 r
F P
0 g
s
.57403 .42324 m .56183 .4368 L .55543 .42132 L p .723 .582 .697 r
F P
0 g
s
.56183 .4368 m .57403 .42324 L .57925 .44747 L p .724 .581 .695 r
F P
0 g
s
.84503 .48401 m .831 .48216 L .83021 .42604 L p .503 .601 .884 r
F P
0 g
s
.8155 .42246 m .83021 .42604 L .831 .48216 L p .516 .592 .869 r
F P
0 g
s
.67406 .41089 m .66041 .41376 L .64769 .36301 L p .652 .567 .746 r
F P
0 g
s
.63528 .37 m .64769 .36301 L .66041 .41376 L p .668 .57 .735 r
F P
0 g
s
.54891 .33497 m .54494 .35625 L .52701 .35388 L p .727 .605 .72 r
F P
0 g
s
.54494 .35625 m .54098 .37907 L .52663 .37717 L p .728 .596 .709 r
F P
0 g
s
.52663 .37717 m .52701 .35388 L .54494 .35625 L p .728 .596 .709 r
F P
0 g
s
.85906 .48583 m .84503 .48401 L .845 .42965 L p .492 .611 .898 r
F P
0 g
s
.83021 .42604 m .845 .42965 L .84503 .48401 L p .503 .601 .884 r
F P
0 g
s
.54098 .37907 m .53702 .40318 L .52625 .40176 L p .729 .59 .7 r
F P
0 g
s
.52625 .40176 m .52663 .37717 L .54098 .37907 L p .729 .59 .7 r
F P
0 g
s
.59466 .47261 m .58079 .47396 L .57925 .44747 L p .723 .582 .697 r
F P
0 g
s
.56574 .45526 m .57925 .44747 L .58079 .47396 L p .726 .582 .694 r
F P
0 g
s
.57925 .44747 m .56574 .45526 L .56183 .4368 L p .724 .581 .695 r
F P
0 g
s
.60515 .51008 m .59186 .50564 L .59466 .47261 L p .726 .587 .7 r
F P
0 g
s
.58079 .47396 m .59466 .47261 L .59186 .50564 L p .728 .586 .696 r
F P
0 g
s
.59633 .54678 m .60812 .55574 L .59216 .59223 L p .745 .612 .711 r
F P
0 g
s
.60812 .55574 m .59633 .54678 L .60515 .51008 L p .736 .6 .706 r
F P
0 g
s
.37815 .6072 m .3901 .6035 L .41397 .64788 L p .586 .563 .795 r
F P
0 g
s
.42381 .64068 m .41397 .64788 L .3901 .6035 L p .622 .569 .774 r
F P
0 g
s
.41397 .64788 m .42381 .64068 L .45225 .672 L p .611 .597 .812 r
F P
0 g
s
.59186 .50564 m .60515 .51008 L .59633 .54678 L p .734 .595 .701 r
F P
0 g
s
.52208 .66662 m .52171 .68165 L .48937 .67803 L p .716 .651 .784 r
F P
0 g
s
.52171 .68165 m .52208 .66662 L .55103 .65725 L p .744 .669 .778 r
F P
0 g
s
.54534 .44054 m .55543 .42132 L .56183 .4368 L p .727 .582 .693 r
F P
0 g
s
.55543 .42132 m .54534 .44054 L .53969 .43281 L p .727 .583 .694 r
F P
0 g
s
.53969 .43281 m .54697 .40985 L .55543 .42132 L p .727 .583 .694 r
F P
0 g
s
.54697 .40985 m .53969 .43281 L .53305 .42832 L p .728 .585 .694 r
F P
0 g
s
.53305 .42832 m .53702 .40318 L .54697 .40985 L p .728 .585 .694 r
F P
0 g
s
.5716 .62117 m .57815 .63589 L .55103 .65725 L p .754 .646 .742 r
F P
0 g
s
.57815 .63589 m .5716 .62117 L .59216 .59223 L p .757 .638 .729 r
F P
0 g
s
.54891 .33497 m .55291 .31543 L .57611 .32995 L p .711 .602 .733 r
F P
0 g
s
.55291 .31543 m .54891 .33497 L .52739 .33213 L p .725 .615 .735 r
F P
0 g
s
.52701 .35388 m .52739 .33213 L .54891 .33497 L p .727 .605 .72 r
F P
0 g
s
.57611 .32995 m .58347 .31399 L .60598 .34146 L p .69 .591 .74 r
F P
0 g
s
.58347 .31399 m .57611 .32995 L .55291 .31543 L p .702 .61 .75 r
F P
0 g
s
.56183 .4368 m .54961 .45099 L .54534 .44054 L p .727 .582 .693 r
F P
0 g
s
.54961 .45099 m .56183 .4368 L .56574 .45526 L p .727 .582 .692 r
F P
0 g
s
.845 .42965 m .85986 .43317 L .85906 .48583 L p .492 .611 .898 r
F P
0 g
s
.30052 .48874 m .31452 .48991 L .32204 .55274 L p .607 .575 .791 r
F P
0 g
s
.33522 .55342 m .32204 .55274 L .31452 .48991 L p .626 .575 .777 r
F P
0 g
s
.53702 .40318 m .53305 .42832 L .52587 .42738 L p .73 .586 .694 r
F P
0 g
s
.52587 .42738 m .52625 .40176 L .53702 .40318 L p .73 .586 .694 r
F P
0 g
s
.64769 .36301 m .63528 .37 L .61622 .32989 L p .653 .574 .754 r
F P
0 g
s
.60598 .34146 m .61622 .32989 L .63528 .37 L p .672 .577 .74 r
F P
0 g
s
.61622 .32989 m .60598 .34146 L .58347 .31399 L p .673 .593 .757 r
F P
0 g
s
.68778 .40887 m .67406 .41089 L .66019 .35737 L p .633 .562 .758 r
F P
0 g
s
.64769 .36301 m .66019 .35737 L .67406 .41089 L p .652 .567 .746 r
F P
0 g
s
.45936 .66093 m .45225 .672 L .42381 .64068 L p .647 .596 .783 r
F P
0 g
s
.45225 .672 m .45936 .66093 L .48937 .67803 L p .666 .635 .809 r
F P
0 g
s
.52701 .35388 m .52663 .37717 L .51216 .38229 L p .734 .6 .708 r
F P
0 g
s
.52663 .37717 m .52625 .40176 L .51539 .40569 L p .732 .592 .7 r
F P
0 g
s
.51539 .40569 m .51216 .38229 L .52663 .37717 L p .732 .592 .7 r
F P
0 g
s
.59186 .50564 m .57854 .50093 L .58079 .47396 L p .728 .586 .696 r
F P
0 g
s
.5669 .47546 m .58079 .47396 L .57854 .50093 L p .729 .584 .693 r
F P
0 g
s
.58079 .47396 m .5669 .47546 L .56574 .45526 L p .726 .582 .694 r
F P
0 g
s
.52739 .33213 m .52701 .35388 L .50891 .36011 L p .736 .611 .719 r
F P
0 g
s
.51216 .38229 m .50891 .36011 L .52701 .35388 L p .734 .6 .708 r
F P
0 g
s
.55222 .46344 m .56574 .45526 L .5669 .47546 L p .728 .582 .691 r
F P
0 g
s
.56574 .45526 m .55222 .46344 L .54961 .45099 L p .727 .582 .692 r
F P
0 g
s
.59633 .54678 m .58451 .53701 L .59186 .50564 L p .734 .595 .701 r
F P
0 g
s
.57854 .50093 m .59186 .50564 L .58451 .53701 L p .733 .591 .697 r
F P
0 g
s
.52625 .40176 m .52587 .42738 L .51863 .43005 L p .731 .587 .694 r
F P
0 g
s
.51863 .43005 m .51539 .40569 L .52625 .40176 L p .731 .587 .694 r
F P
0 g
s
.58265 .57904 m .59216 .59223 L .5716 .62117 L p .749 .622 .718 r
F P
0 g
s
.59216 .59223 m .58265 .57904 L .59633 .54678 L p .745 .612 .711 r
F P
0 g
s
.3485 .5533 m .36186 .55232 L .37815 .6072 L p .601 .555 .775 r
F P
0 g
s
.3901 .6035 m .37815 .6072 L .36186 .55232 L p .627 .561 .761 r
F P
0 g
s
.58451 .53701 m .59633 .54678 L .58265 .57904 L p .741 .603 .704 r
F P
0 g
s
.53524 .46034 m .54534 .44054 L .54961 .45099 L p .729 .582 .69 r
F P
0 g
s
.54534 .44054 m .53524 .46034 L .53241 .45645 L p .729 .582 .69 r
F P
0 g
s
.53241 .45645 m .53969 .43281 L .54534 .44054 L p .729 .582 .69 r
F P
0 g
s
.53969 .43281 m .53241 .45645 L .52909 .45419 L p .73 .583 .691 r
F P
0 g
s
.52909 .45419 m .53305 .42832 L .53969 .43281 L p .73 .583 .691 r
F P
0 g
s
.54961 .45099 m .53738 .46561 L .53524 .46034 L p .729 .582 .69 r
F P
0 g
s
.53738 .46561 m .54961 .45099 L .55222 .46344 L p .729 .582 .69 r
F P
0 g
s
.52739 .33213 m .52777 .31211 L .55291 .31543 L p .725 .615 .735 r
F P
0 g
s
.52777 .31211 m .52739 .33213 L .50566 .33937 L p .738 .624 .733 r
F P
0 g
s
.50891 .36011 m .50566 .33937 L .52739 .33213 L p .736 .611 .719 r
F P
0 g
s
.53305 .42832 m .52909 .45419 L .52549 .45372 L p .73 .583 .691 r
F P
0 g
s
.52549 .45372 m .52587 .42738 L .53305 .42832 L p .73 .583 .691 r
F P
0 g
s
.57854 .50093 m .56521 .49602 L .5669 .47546 L p .729 .584 .693 r
F P
0 g
s
.55299 .47706 m .5669 .47546 L .56521 .49602 L p .729 .583 .691 r
F P
0 g
s
.5669 .47546 m .55299 .47706 L .55222 .46344 L p .728 .582 .691 r
F P
0 g
s
.55291 .31543 m .55693 .29779 L .58347 .31399 L p .702 .61 .75 r
F P
0 g
s
.55693 .29779 m .55291 .31543 L .52777 .31211 L p .721 .629 .755 r
F P
0 g
s
.54783 .6406 m .55103 .65725 L .52208 .66662 L p .741 .644 .752 r
F P
0 g
s
.55103 .65725 m .54783 .6406 L .5716 .62117 L p .754 .646 .742 r
F P
0 g
s
.50891 .36011 m .51216 .38229 L .49854 .39411 L p .738 .601 .705 r
F P
0 g
s
.51216 .38229 m .51539 .40569 L .50519 .41472 L p .734 .593 .699 r
F P
0 g
s
.50519 .41472 m .49854 .39411 L .51216 .38229 L p .734 .593 .699 r
F P
0 g
s
.58451 .53701 m .57266 .52656 L .57854 .50093 L p .733 .591 .697 r
F P
0 g
s
.56521 .49602 m .57854 .50093 L .57266 .52656 L p .732 .587 .694 r
F P
0 g
s
.53868 .47188 m .55222 .46344 L .55299 .47706 L p .73 .582 .69 r
F P
0 g
s
.55222 .46344 m .53868 .47188 L .53738 .46561 L p .729 .582 .69 r
F P
0 g
s
.51539 .40569 m .51863 .43005 L .51183 .43615 L p .732 .587 .694 r
F P
0 g
s
.51183 .43615 m .50519 .41472 L .51539 .40569 L p .732 .587 .694 r
F P
0 g
s
.52587 .42738 m .52549 .45372 L .52187 .45507 L p .73 .583 .691 r
F P
0 g
s
.52187 .45507 m .51863 .43005 L .52587 .42738 L p .73 .583 .691 r
F P
0 g
s
.49327 .66332 m .48937 .67803 L .45936 .66093 L p .688 .621 .776 r
F P
0 g
s
.48937 .67803 m .49327 .66332 L .52208 .66662 L p .716 .651 .784 r
F P
0 g
s
.70157 .40769 m .68778 .40887 L .6728 .35311 L p .61 .557 .77 r
F P
0 g
s
.66019 .35737 m .6728 .35311 L .68778 .40887 L p .633 .562 .758 r
F P
0 g
s
.58347 .31399 m .59089 .29992 L .61622 .32989 L p .673 .593 .757 r
F P
0 g
s
.59089 .29992 m .58347 .31399 L .55693 .29779 L p .689 .619 .773 r
F P
0 g
s
.50566 .33937 m .50891 .36011 L .49189 .37455 L p .742 .612 .715 r
F P
0 g
s
.49854 .39411 m .49189 .37455 L .50891 .36011 L p .738 .601 .705 r
F P
0 g
s
.58265 .57904 m .5731 .5646 L .58451 .53701 L p .741 .603 .704 r
F P
0 g
s
.57266 .52656 m .58451 .53701 L .5731 .5646 L p .737 .596 .699 r
F P
0 g
s
.66019 .35737 m .64769 .36301 L .62655 .32004 L p .629 .571 .77 r
F P
0 g
s
.61622 .32989 m .62655 .32004 L .64769 .36301 L p .653 .574 .754 r
F P
0 g
s
.56521 .49602 m .55186 .49093 L .55299 .47706 L p .729 .583 .691 r
F P
0 g
s
.53906 .47874 m .55299 .47706 L .55186 .49093 L p .73 .582 .69 r
F P
0 g
s
.55299 .47706 m .53906 .47874 L .53868 .47188 L p .73 .582 .69 r
F P
0 g
s
.57266 .52656 m .56079 .51555 L .56521 .49602 L p .732 .587 .694 r
F P
0 g
s
.55186 .49093 m .56521 .49602 L .56079 .51555 L p .731 .584 .691 r
F P
0 g
s
.62655 .32004 m .61622 .32989 L .59089 .29992 L p .652 .595 .778 r
F P
0 g
s
.51863 .43005 m .52187 .45507 L .51847 .45815 L p .731 .584 .69 r
F P
0 g
s
.51847 .45815 m .51183 .43615 L .51863 .43005 L p .731 .584 .69 r
F P
0 g
s
.56501 .60465 m .5716 .62117 L .54783 .6406 L p .747 .627 .727 r
F P
0 g
s
.5716 .62117 m .56501 .60465 L .58265 .57904 L p .749 .622 .718 r
F P
0 g
s
.5731 .5646 m .58265 .57904 L .56501 .60465 L p .743 .61 .709 r
F P
0 g
s
.52511 .48046 m .53241 .45645 L .53524 .46034 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .52909 .45419 L .53241 .45645 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53524 .46034 L .53738 .46561 L closepath p .73 .582 .689 r
F P
0 g
s
.31452 .48991 m .32855 .49086 L .33522 .55342 L p .626 .575 .777 r
F P
0 g
s
.3485 .5533 m .33522 .55342 L .32855 .49086 L p .642 .576 .765 r
F P
0 g
s
.52511 .48046 m .52549 .45372 L .52909 .45419 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53738 .46561 L .53868 .47188 L closepath p .73 .582 .689 r
F P
0 g
s
.49854 .39411 m .50519 .41472 L .49632 .42824 L p .735 .592 .697 r
F P
0 g
s
.50519 .41472 m .51183 .43615 L .50592 .44528 L p .732 .587 .693 r
F P
0 g
s
.50592 .44528 m .49632 .42824 L .50519 .41472 L p .732 .587 .693 r
F P
0 g
s
.50566 .33937 m .50239 .32026 L .52777 .31211 L p .738 .624 .733 r
F P
0 g
s
.50239 .32026 m .50566 .33937 L .48521 .35625 L p .747 .626 .726 r
F P
0 g
s
.49189 .37455 m .48521 .35625 L .50566 .33937 L p .742 .612 .715 r
F P
0 g
s
.49189 .37455 m .49854 .39411 L .48671 .41183 L p .739 .6 .702 r
F P
0 g
s
.49632 .42824 m .48671 .41183 L .49854 .39411 L p .735 .592 .697 r
F P
0 g
s
.5731 .5646 m .56352 .5491 L .57266 .52656 L p .737 .596 .699 r
F P
0 g
s
.56079 .51555 m .57266 .52656 L .56352 .5491 L p .734 .59 .695 r
F P
0 g
s
.52777 .31211 m .52815 .29401 L .55693 .29779 L p .721 .629 .755 r
F P
0 g
s
.52815 .29401 m .52777 .31211 L .50239 .32026 L p .74 .642 .751 r
F P
0 g
s
.52511 .48046 m .52187 .45507 L .52549 .45372 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53868 .47188 L .53906 .47874 L closepath p .73 .582 .689 r
F P
0 g
s
.56079 .51555 m .5489 .5041 L .55186 .49093 L p .731 .584 .691 r
F P
0 g
s
.53849 .48573 m .55186 .49093 L .5489 .5041 L p .73 .583 .69 r
F P
0 g
s
.55186 .49093 m .53849 .48573 L .53906 .47874 L p .73 .582 .69 r
F P
0 g
s
.51183 .43615 m .51847 .45815 L .51551 .46276 L p .731 .583 .69 r
F P
0 g
s
.51551 .46276 m .50592 .44528 L .51183 .43615 L p .731 .583 .69 r
F P
0 g
s
.52246 .64915 m .52208 .66662 L .49327 .66332 L p .722 .631 .756 r
F P
0 g
s
.52208 .66662 m .52246 .64915 L .54783 .6406 L p .741 .644 .752 r
F P
0 g
s
.52511 .48046 m .51847 .45815 L .52187 .45507 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53906 .47874 L .53849 .48573 L closepath p .73 .582 .689 r
F P
0 g
s
.48521 .35625 m .49189 .37455 L .47709 .39624 L p .743 .609 .709 r
F P
0 g
s
.48671 .41183 m .47709 .39624 L .49189 .37455 L p .739 .6 .702 r
F P
0 g
s
.3901 .6035 m .40215 .5983 L .42381 .64068 L p .622 .569 .774 r
F P
0 g
s
.43375 .63146 m .42381 .64068 L .40215 .5983 L p .65 .574 .756 r
F P
0 g
s
.42381 .64068 m .43375 .63146 L .45936 .66093 L p .647 .596 .783 r
F P
0 g
s
.56352 .5491 m .55392 .53272 L .56079 .51555 L p .734 .59 .695 r
F P
0 g
s
.5489 .5041 m .56079 .51555 L .55392 .53272 L p .732 .586 .692 r
F P
0 g
s
.55693 .29779 m .56099 .28218 L .59089 .29992 L p .689 .619 .773 r
F P
0 g
s
.56099 .28218 m .55693 .29779 L .52815 .29401 L p .715 .647 .78 r
F P
0 g
s
.56501 .60465 m .55839 .58652 L .5731 .5646 L p .743 .61 .709 r
F P
0 g
s
.56352 .5491 m .5731 .5646 L .55839 .58652 L p .739 .6 .702 r
F P
0 g
s
.52511 .48046 m .51551 .46276 L .51847 .45815 L closepath p .73 .582 .689 r
F P
0 g
s
.5489 .5041 m .53701 .49236 L .53849 .48573 L p .73 .583 .69 r
F P
0 g
s
.52511 .48046 m .53849 .48573 L .53701 .49236 L closepath p .73 .582 .689 r
F P
0 g
s
.71546 .40733 m .70157 .40769 L .68554 .3502 L p .585 .552 .783 r
F P
0 g
s
.6728 .35311 m .68554 .3502 L .70157 .40769 L p .61 .557 .77 r
F P
0 g
s
.55392 .53272 m .54432 .51567 L .5489 .5041 L p .732 .586 .692 r
F P
0 g
s
.53701 .49236 m .5489 .5041 L .54432 .51567 L p .731 .583 .69 r
F P
0 g
s
.49632 .42824 m .50592 .44528 L .50131 .45682 L p .732 .586 .692 r
F P
0 g
s
.50592 .44528 m .51551 .46276 L .51321 .46857 L p .731 .583 .69 r
F P
0 g
s
.51321 .46857 m .50131 .45682 L .50592 .44528 L p .731 .583 .69 r
F P
0 g
s
.48671 .41183 m .49632 .42824 L .4894 .44534 L p .734 .59 .695 r
F P
0 g
s
.50131 .45682 m .4894 .44534 L .49632 .42824 L p .732 .586 .692 r
F P
0 g
s
.36186 .55232 m .3753 .55044 L .3901 .6035 L p .627 .561 .761 r
F P
0 g
s
.40215 .5983 m .3901 .6035 L .3753 .55044 L p .649 .566 .748 r
F P
0 g
s
.54461 .62185 m .54783 .6406 L .52246 .64915 L p .738 .625 .733 r
F P
0 g
s
.54783 .6406 m .54461 .62185 L .56501 .60465 L p .747 .627 .727 r
F P
0 g
s
.46655 .64753 m .45936 .66093 L .43375 .63146 L p .672 .594 .76 r
F P
0 g
s
.45936 .66093 m .46655 .64753 L .49327 .66332 L p .688 .621 .776 r
F P
0 g
s
.52511 .48046 m .51321 .46857 L .51551 .46276 L closepath p .73 .582 .689 r
F P
0 g
s
.54432 .51567 m .53472 .49818 L .53701 .49236 L p .731 .583 .69 r
F P
0 g
s
.52511 .48046 m .53701 .49236 L .53472 .49818 L closepath p .73 .582 .689 r
F P
0 g
s
.55839 .58652 m .56501 .60465 L .54461 .62185 L p .742 .613 .715 r
F P
0 g
s
.47709 .39624 m .48671 .41183 L .47748 .43427 L p .737 .596 .699 r
F P
0 g
s
.4894 .44534 m .47748 .43427 L .48671 .41183 L p .734 .59 .695 r
F P
0 g
s
.52511 .48046 m .51172 .4752 L .51321 .46857 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .51115 .48219 L .51172 .4752 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .51152 .48906 L .51115 .48219 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .51282 .49536 L .51152 .48906 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .51496 .50063 L .51282 .49536 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .5178 .50454 L .51496 .50063 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .52113 .5068 L .5178 .50454 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .52473 .50726 L .52113 .5068 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .52836 .50589 L .52473 .50726 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53177 .5028 L .52836 .50589 L closepath p .73 .582 .689 r
F P
0 g
s
.52511 .48046 m .53472 .49818 L .53177 .5028 L closepath p .73 .582 .689 r
F P
0 g
s
.55839 .58652 m .55174 .567 L .56352 .5491 L p .739 .6 .702 r
F P
0 g
s
.55392 .53272 m .56352 .5491 L .55174 .567 L p .735 .592 .697 r
F P
0 g
s
.48521 .35625 m .4785 .33937 L .50239 .32026 L p .747 .626 .726 r
F P
0 g
s
.4785 .33937 m .48521 .35625 L .46743 .38164 L p .749 .622 .718 r
F P
0 g
s
.47709 .39624 m .46743 .38164 L .48521 .35625 L p .743 .609 .709 r
F P
0 g
s
.50131 .45682 m .51321 .46857 L .51172 .4752 L p .73 .583 .69 r
F P
0 g
s
.53843 .52486 m .53177 .5028 L .53472 .49818 L p .731 .583 .69 r
F P
0 g
s
.53472 .49818 m .54432 .51567 L .53843 .52486 L p .731 .583 .69 r
F P
0 g
s
.59089 .29992 m .59839 .28784 L .62655 .32004 L p .652 .595 .778 r
F P
0 g
s
.59839 .28784 m .59089 .29992 L .56099 .28218 L p .67 .63 .801 r
F P
0 g
s
.50239 .32026 m .49909 .30295 L .52815 .29401 L p .74 .642 .751 r
F P
0 g
s
.49909 .30295 m .50239 .32026 L .4785 .33937 L p .753 .644 .741 r
F P
0 g
s
.6728 .35311 m .66019 .35737 L .637 .31194 L p .599 .565 .787 r
F P
0 g
s
.62655 .32004 m .637 .31194 L .66019 .35737 L p .629 .571 .77 r
F P
0 g
s
.55174 .567 m .54509 .54635 L .55392 .53272 L p .735 .592 .697 r
F P
0 g
s
.54432 .51567 m .55392 .53272 L .54509 .54635 L p .733 .587 .693 r
F P
0 g
s
.54509 .54635 m .53843 .52486 L .54432 .51567 L p .733 .587 .693 r
F P
0 g
s
.4894 .44534 m .50131 .45682 L .49832 .46998 L p .731 .584 .691 r
F P
0 g
s
.51172 .4752 m .49832 .46998 L .50131 .45682 L p .73 .583 .69 r
F P
0 g
s
.32855 .49086 m .34258 .49158 L .3485 .5533 L p .642 .576 .765 r
F P
0 g
s
.36186 .55232 m .3485 .5533 L .34258 .49158 L p .657 .577 .753 r
F P
0 g
s
.49832 .46998 m .51172 .4752 L .51115 .48219 L p .73 .582 .69 r
F P
0 g
s
.53162 .53102 m .52836 .50589 L .53177 .5028 L p .731 .584 .69 r
F P
0 g
s
.53177 .5028 m .53843 .52486 L .53162 .53102 L p .731 .584 .69 r
F P
0 g
s
.46743 .38164 m .47709 .39624 L .46553 .42374 L p .74 .603 .704 r
F P
0 g
s
.47748 .43427 m .46553 .42374 L .47709 .39624 L p .737 .596 .699 r
F P
0 g
s
.4972 .6462 m .49327 .66332 L .46655 .64753 L p .702 .611 .752 r
F P
0 g
s
.49327 .66332 m .4972 .6462 L .52246 .64915 L p .722 .631 .756 r
F P
0 g
s
.47748 .43427 m .4894 .44534 L .48491 .46487 L p .732 .587 .694 r
F P
0 g
s
.49832 .46998 m .48491 .46487 L .4894 .44534 L p .731 .584 .691 r
F P
0 g
s
.637 .31194 m .62655 .32004 L .59839 .28784 L p .622 .596 .803 r
F P
0 g
s
.54461 .62185 m .54137 .60124 L .55839 .58652 L p .742 .613 .715 r
F P
0 g
s
.55174 .567 m .55839 .58652 L .54137 .60124 L p .738 .602 .705 r
F P
0 g
s
.51115 .48219 m .49716 .48388 L .49832 .46998 L p .73 .582 .69 r
F P
0 g
s
.49716 .48388 m .51115 .48219 L .51152 .48906 L p .73 .582 .69 r
F P
0 g
s
.52435 .53375 m .52473 .50726 L .52836 .50589 L p .731 .583 .691 r
F P
0 g
s
.52836 .50589 m .53162 .53102 L .52435 .53375 L p .731 .583 .691 r
F P
0 g
s
.52815 .29401 m .52854 .27795 L .56099 .28218 L p .715 .647 .78 r
F P
0 g
s
.52854 .27795 m .52815 .29401 L .49909 .30295 L p .742 .665 .774 r
F P
0 g
s
.53487 .55551 m .53162 .53102 L .53843 .52486 L p .732 .587 .694 r
F P
0 g
s
.53843 .52486 m .54509 .54635 L .53487 .55551 L p .732 .587 .694 r
F P
0 g
s
.48491 .46487 m .49832 .46998 L .49716 .48388 L p .73 .583 .691 r
F P
0 g
s
.51152 .48906 m .4979 .49755 L .49716 .48388 L p .73 .582 .69 r
F P
0 g
s
.4979 .49755 m .51152 .48906 L .51282 .49536 L p .729 .582 .69 r
F P
0 g
s
.51714 .53283 m .52113 .5068 L .52473 .50726 L p .73 .583 .691 r
F P
0 g
s
.52473 .50726 m .52435 .53375 L .51714 .53283 L p .73 .583 .691 r
F P
0 g
s
.52283 .62944 m .52246 .64915 L .4972 .6462 L p .725 .616 .736 r
F P
0 g
s
.52246 .64915 m .52283 .62944 L .54461 .62185 L p .738 .625 .733 r
F P
0 g
s
.46553 .42374 m .47748 .43427 L .47147 .45991 L p .733 .591 .697 r
F P
0 g
s
.48491 .46487 m .47147 .45991 L .47748 .43427 L p .732 .587 .694 r
F P
0 g
s
.54137 .60124 m .53812 .57903 L .55174 .567 L p .738 .602 .705 r
F P
0 g
s
.54509 .54635 m .55174 .567 L .53812 .57903 L p .734 .593 .699 r
F P
0 g
s
.54137 .60124 m .54461 .62185 L .52283 .62944 L p .736 .611 .719 r
F P
0 g
s
.53812 .57903 m .53487 .55551 L .54509 .54635 L p .734 .593 .699 r
F P
0 g
s
.51282 .49536 m .50051 .51007 L .4979 .49755 L p .729 .582 .69 r
F P
0 g
s
.50051 .51007 m .51282 .49536 L .51496 .50063 L p .729 .582 .69 r
F P
0 g
s
.51047 .52834 m .5178 .50454 L .52113 .5068 L p .73 .583 .691 r
F P
0 g
s
.52113 .5068 m .51714 .53283 L .51047 .52834 L p .73 .583 .691 r
F P
0 g
s
.72943 .40775 m .71546 .40733 L .69842 .3486 L p .557 .545 .797 r
F P
0 g
s
.68554 .3502 m .69842 .3486 L .71546 .40733 L p .585 .552 .783 r
F P
0 g
s
.51496 .50063 m .50479 .52057 L .50051 .51007 L p .729 .582 .69 r
F P
0 g
s
.50479 .52057 m .51496 .50063 L .5178 .50454 L p .729 .582 .69 r
F P
0 g
s
.5178 .50454 m .51047 .52834 L .50479 .52057 L p .729 .582 .69 r
F P
0 g
s
.46743 .38164 m .45774 .36815 L .4785 .33937 L p .749 .622 .718 r
F P
0 g
s
.45774 .36815 m .46743 .38164 L .45356 .41384 L p .745 .612 .711 r
F P
0 g
s
.46553 .42374 m .45356 .41384 L .46743 .38164 L p .74 .603 .704 r
F P
0 g
s
.4785 .33937 m .47175 .32405 L .49909 .30295 L p .753 .644 .741 r
F P
0 g
s
.47175 .32405 m .4785 .33937 L .45774 .36815 L p .756 .636 .729 r
F P
0 g
s
.52397 .55956 m .52435 .53375 L .53162 .53102 L p .731 .587 .694 r
F P
0 g
s
.53162 .53102 m .53487 .55551 L .52397 .55956 L p .731 .587 .694 r
F P
0 g
s
.40215 .5983 m .4143 .59158 L .43375 .63146 L p .65 .574 .756 r
F P
0 g
s
.44378 .62028 m .43375 .63146 L .4143 .59158 L p .671 .577 .741 r
F P
0 g
s
.43375 .63146 m .44378 .62028 L .46655 .64753 L p .672 .594 .76 r
F P
0 g
s
.47147 .45991 m .48491 .46487 L .48315 .48549 L p .729 .584 .693 r
F P
0 g
s
.49716 .48388 m .48315 .48549 L .48491 .46487 L p .73 .583 .691 r
F P
0 g
s
.48315 .48549 m .49716 .48388 L .4979 .49755 L p .728 .582 .691 r
F P
0 g
s
.3753 .55044 m .38881 .54766 L .40215 .5983 L p .649 .566 .748 r
F P
0 g
s
.4143 .59158 m .40215 .5983 L .38881 .54766 L p .667 .57 .736 r
F P
0 g
s
.45356 .41384 m .46553 .42374 L .45802 .45516 L p .734 .595 .701 r
F P
0 g
s
.47147 .45991 m .45802 .45516 L .46553 .42374 L p .733 .591 .697 r
F P
0 g
s
.52283 .62944 m .52321 .60774 L .54137 .60124 L p .736 .611 .719 r
F P
0 g
s
.53812 .57903 m .54137 .60124 L .52321 .60774 L p .734 .6 .708 r
F P
0 g
s
.47381 .63191 m .46655 .64753 L .44378 .62028 L p .689 .591 .741 r
F P
0 g
s
.46655 .64753 m .47381 .63191 L .4972 .6462 L p .702 .611 .752 r
F P
0 g
s
.34258 .49158 m .35663 .49205 L .36186 .55232 L p .657 .577 .753 r
F P
0 g
s
.3753 .55044 m .36186 .55232 L .35663 .49205 L p .67 .577 .743 r
F P
0 g
s
.56099 .28218 m .5651 .2687 L .59839 .28784 L p .67 .63 .801 r
F P
0 g
s
.5651 .2687 m .56099 .28218 L .52854 .27795 L p .706 .67 .812 r
F P
0 g
s
.51314 .5582 m .51714 .53283 L .52435 .53375 L p .73 .586 .694 r
F P
0 g
s
.52435 .53375 m .52397 .55956 L .51314 .5582 L p .73 .586 .694 r
F P
0 g
s
.52359 .58434 m .52397 .55956 L .53487 .55551 L p .732 .592 .7 r
F P
0 g
s
.53487 .55551 m .53812 .57903 L .52359 .58434 L p .732 .592 .7 r
F P
0 g
s
.4979 .49755 m .48426 .5058 L .48315 .48549 L p .728 .582 .691 r
F P
0 g
s
.48426 .5058 m .4979 .49755 L .50051 .51007 L p .727 .582 .692 r
F P
0 g
s
.45802 .45516 m .47147 .45991 L .46913 .487 L p .728 .586 .696 r
F P
0 g
s
.48315 .48549 m .46913 .487 L .47147 .45991 L p .729 .584 .693 r
F P
0 g
s
.52321 .60774 m .52359 .58434 L .53812 .57903 L p .734 .6 .708 r
F P
0 g
s
.49909 .30295 m .49577 .28756 L .52854 .27795 L p .742 .665 .774 r
F P
0 g
s
.49577 .28756 m .49909 .30295 L .47175 .32405 L p .76 .667 .759 r
F P
0 g
s
.50117 .62686 m .4972 .6462 L .47381 .63191 L p .711 .602 .733 r
F P
0 g
s
.4972 .6462 m .50117 .62686 L .52283 .62944 L p .725 .616 .736 r
F P
0 g
s
.46913 .487 m .48315 .48549 L .48426 .5058 L p .726 .582 .694 r
F P
0 g
s
.50312 .55153 m .51047 .52834 L .51714 .53283 L p .728 .585 .694 r
F P
0 g
s
.51714 .53283 m .51314 .5582 L .50312 .55153 L p .728 .585 .694 r
F P
0 g
s
.52321 .60774 m .52283 .62944 L .50117 .62686 L p .727 .605 .72 r
F P
0 g
s
.50051 .51007 m .48817 .5244 L .48426 .5058 L p .727 .582 .692 r
F P
0 g
s
.48817 .5244 m .50051 .51007 L .50479 .52057 L p .727 .582 .693 r
F P
0 g
s
.4946 .54 m .50479 .52057 L .51047 .52834 L p .727 .583 .694 r
F P
0 g
s
.51047 .52834 m .50312 .55153 L .4946 .54 L p .727 .583 .694 r
F P
0 g
s
.50479 .52057 m .4946 .54 L .48817 .5244 L p .727 .582 .693 r
F P
0 g
s
.45356 .41384 m .44155 .40467 L .45774 .36815 L p .745 .612 .711 r
F P
0 g
s
.44155 .40467 m .45356 .41384 L .44455 .45066 L p .736 .6 .706 r
F P
0 g
s
.45802 .45516 m .44455 .45066 L .45356 .41384 L p .734 .595 .701 r
F P
0 g
s
.68554 .3502 m .6728 .35311 L .64756 .30562 L p .562 .558 .806 r
F P
0 g
s
.637 .31194 m .64756 .30562 L .6728 .35311 L p .599 .565 .787 r
F P
0 g
s
.45774 .36815 m .44799 .3559 L .47175 .32405 L p .756 .636 .729 r
F P
0 g
s
.44799 .3559 m .45774 .36815 L .44155 .40467 L p .75 .623 .718 r
F P
0 g
s
.50914 .58256 m .51314 .5582 L .52397 .55956 L p .729 .59 .7 r
F P
0 g
s
.52397 .55956 m .52359 .58434 L .50914 .58256 L p .729 .59 .7 r
F P
0 g
s
.44455 .45066 m .45802 .45516 L .45509 .48838 L p .726 .587 .7 r
F P
0 g
s
.46913 .487 m .45509 .48838 L .45802 .45516 L p .728 .586 .696 r
F P
0 g
s
.48426 .5058 m .47061 .51369 L .46913 .487 L p .726 .582 .694 r
F P
0 g
s
.47061 .51369 m .48426 .5058 L .48817 .5244 L p .724 .581 .695 r
F P
0 g
s
.50117 .62686 m .50515 .60555 L .52321 .60774 L p .727 .605 .72 r
F P
0 g
s
.52359 .58434 m .52321 .60774 L .50515 .60555 L p .728 .596 .709 r
F P
0 g
s
.45509 .48838 m .46913 .487 L .47061 .51369 L p .723 .582 .697 r
F P
0 g
s
.50515 .60555 m .50914 .58256 L .52359 .58434 L p .728 .596 .709 r
F P
0 g
s
.59839 .28784 m .60599 .27779 L .637 .31194 L p .622 .596 .803 r
F P
0 g
s
.60599 .27779 m .59839 .28784 L .5651 .2687 L p .642 .643 .836 r
F P
0 g
s
.35663 .49205 m .37069 .49226 L .3753 .55044 L p .67 .577 .743 r
F P
0 g
s
.38881 .54766 m .3753 .55044 L .37069 .49226 L p .681 .578 .733 r
F P
0 g
s
.4143 .59158 m .42652 .58341 L .44378 .62028 L p .671 .577 .741 r
F P
0 g
s
.45388 .60724 m .44378 .62028 L .42652 .58341 L p .687 .579 .728 r
F P
0 g
s
.44378 .62028 m .45388 .60724 L .47381 .63191 L p .689 .591 .741 r
F P
0 g
s
.38881 .54766 m .40237 .54398 L .4143 .59158 L p .667 .57 .736 r
F P
0 g
s
.42652 .58341 m .4143 .59158 L .40237 .54398 L p .682 .573 .726 r
F P
0 g
s
.49577 .57379 m .50312 .55153 L .51314 .5582 L p .726 .587 .7 r
F P
0 g
s
.51314 .5582 m .50914 .58256 L .49577 .57379 L p .726 .587 .7 r
F P
0 g
s
.74351 .40888 m .72943 .40775 L .71145 .34825 L p .526 .538 .811 r
F P
0 g
s
.69842 .3486 m .71145 .34825 L .72943 .40775 L p .557 .545 .797 r
F P
0 g
s
.20299 .47689 m .18911 .47507 L .19318 .42214 L p .609 .71 .916 r
F P
0 g
s
.48817 .5244 m .47582 .53813 L .47061 .51369 L p .724 .581 .695 r
F P
0 g
s
.47582 .53813 m .48817 .5244 L .4946 .54 L p .723 .582 .697 r
F P
0 g
s
.4811 .61426 m .47381 .63191 L .45388 .60724 L p .702 .589 .726 r
F P
0 g
s
.47381 .63191 m .4811 .61426 L .50117 .62686 L p .711 .602 .733 r
F P
0 g
s
.50515 .60555 m .50117 .62686 L .4811 .61426 L p .718 .596 .719 r
F P
0 g
s
.47175 .32405 m .46493 .31042 L .49577 .28756 L p .76 .667 .759 r
F P
0 g
s
.46493 .31042 m .47175 .32405 L .44799 .3559 L p .764 .655 .742 r
F P
0 g
s
.4844 .55863 m .4946 .54 L .50312 .55153 L p .724 .584 .699 r
F P
0 g
s
.50312 .55153 m .49577 .57379 L .4844 .55863 L p .724 .584 .699 r
F P
0 g
s
.4946 .54 m .4844 .55863 L .47582 .53813 L p .723 .582 .697 r
F P
0 g
s
.52854 .27795 m .52893 .26402 L .5651 .2687 L p .706 .67 .812 r
F P
0 g
s
.52893 .26402 m .52854 .27795 L .49577 .28756 L p .744 .694 .804 r
F P
0 g
s
.44455 .45066 m .43105 .44644 L .44155 .40467 L p .736 .6 .706 r
F P
0 g
s
.43105 .44644 m .44455 .45066 L .44104 .48958 L p .725 .589 .704 r
F P
0 g
s
.45509 .48838 m .44104 .48958 L .44455 .45066 L p .726 .587 .7 r
F P
0 g
s
.64756 .30562 m .637 .31194 L .60599 .27779 L p .582 .595 .831 r
F P
0 g
s
.44155 .40467 m .42949 .39632 L .44799 .3559 L p .75 .623 .718 r
F P
0 g
s
.42949 .39632 m .44155 .40467 L .43105 .44644 L p .738 .606 .711 r
F P
0 g
s
.44104 .48958 m .45509 .48838 L .45694 .5211 L p .718 .582 .701 r
F P
0 g
s
.47061 .51369 m .45694 .5211 L .45509 .48838 L p .723 .582 .697 r
F P
0 g
s
.45694 .5211 m .47061 .51369 L .47582 .53813 L p .719 .58 .699 r
F P
0 g
s
.48843 .5948 m .49577 .57379 L .50914 .58256 L p .723 .591 .708 r
F P
0 g
s
.50914 .58256 m .50515 .60555 L .48843 .5948 L p .723 .591 .708 r
F P
0 g
s
.19318 .42214 m .20769 .42222 L .20299 .47689 L p .609 .71 .916 r
F P
0 g
s
.21688 .47876 m .20299 .47689 L .20769 .42222 L p .622 .699 .9 r
F P
0 g
s
.4811 .61426 m .48843 .5948 L .50515 .60555 L p .718 .596 .719 r
F P
0 g
s
.37069 .49226 m .38476 .49222 L .38881 .54766 L p .681 .578 .733 r
F P
0 g
s
.40237 .54398 m .38881 .54766 L .38476 .49222 L p .691 .579 .725 r
F P
0 g
s
.20769 .42222 m .22215 .42225 L .21688 .47876 L p .622 .699 .9 r
F P
0 g
s
.23078 .48062 m .21688 .47876 L .22215 .42225 L p .634 .687 .882 r
F P
0 g
s
.47582 .53813 m .46346 .55106 L .45694 .5211 L p .719 .58 .699 r
F P
0 g
s
.46346 .55106 m .47582 .53813 L .4844 .55863 L p .717 .582 .702 r
F P
0 g
s
.47421 .57621 m .4844 .55863 L .49577 .57379 L p .719 .586 .705 r
F P
0 g
s
.49577 .57379 m .48843 .5948 L .47421 .57621 L p .719 .586 .705 r
F P
0 g
s
.45388 .60724 m .46402 .59248 L .4811 .61426 L p .702 .589 .726 r
F P
0 g
s
.48843 .5948 m .4811 .61426 L .46402 .59248 L p .712 .587 .715 r
F P
0 g
s
.40237 .54398 m .41598 .53943 L .42652 .58341 L p .682 .573 .726 r
F P
0 g
s
.4388 .57386 m .42652 .58341 L .41598 .53943 L p .694 .576 .718 r
F P
0 g
s
.42652 .58341 m .4388 .57386 L .45388 .60724 L p .687 .579 .728 r
F P
0 g
s
.46402 .59248 m .45388 .60724 L .4388 .57386 L p .7 .58 .718 r
F P
0 g
s
.4844 .55863 m .47421 .57621 L .46346 .55106 L p .717 .582 .702 r
F P
0 g
s
.44104 .48958 m .42697 .49058 L .43105 .44644 L p .725 .589 .704 r
F P
0 g
s
.42697 .49058 m .44104 .48958 L .44328 .52792 L p .713 .581 .706 r
F P
0 g
s
.45694 .5211 m .44328 .52792 L .44104 .48958 L p .718 .582 .701 r
F P
0 g
s
.44328 .52792 m .45694 .5211 L .46346 .55106 L p .712 .579 .704 r
F P
0 g
s
.44799 .3559 m .43818 .34497 L .46493 .31042 L p .764 .655 .742 r
F P
0 g
s
.43818 .34497 m .44799 .3559 L .42949 .39632 L p .756 .635 .727 r
F P
0 g
s
.46402 .59248 m .47421 .57621 L .48843 .5948 L p .712 .587 .715 r
F P
0 g
s
.43105 .44644 m .41751 .44254 L .42949 .39632 L p .738 .606 .711 r
F P
0 g
s
.41751 .44254 m .43105 .44644 L .42697 .49058 L p .723 .592 .709 r
F P
0 g
s
.22215 .42225 m .23654 .42228 L .23078 .48062 L p .634 .687 .882 r
F P
0 g
s
.24469 .48245 m .23078 .48062 L .23654 .42228 L p .646 .676 .864 r
F P
0 g
s
.38476 .49222 m .39883 .49192 L .40237 .54398 L p .691 .579 .725 r
F P
0 g
s
.41598 .53943 m .40237 .54398 L .39883 .49192 L p .7 .58 .717 r
F P
0 g
s
.46346 .55106 m .45112 .56303 L .44328 .52792 L p .712 .579 .704 r
F P
0 g
s
.45112 .56303 m .46346 .55106 L .47421 .57621 L p .71 .581 .709 r
F P
0 g
s
.4388 .57386 m .45112 .56303 L .46402 .59248 L p .7 .58 .718 r
F P
0 g
s
.47421 .57621 m .46402 .59248 L .45112 .56303 L p .71 .581 .709 r
F P
0 g
s
.41598 .53943 m .42962 .53406 L .4388 .57386 L p .694 .576 .718 r
F P
0 g
s
.45112 .56303 m .4388 .57386 L .42962 .53406 L p .704 .578 .71 r
F P
0 g
s
.44328 .52792 m .42962 .53406 L .42697 .49058 L p .713 .581 .706 r
F P
0 g
s
.42962 .53406 m .44328 .52792 L .45112 .56303 L p .704 .578 .71 r
F P
0 g
s
.42697 .49058 m .4129 .49137 L .41751 .44254 L p .723 .592 .709 r
F P
0 g
s
.4129 .49137 m .42697 .49058 L .42962 .53406 L p .707 .581 .711 r
F P
0 g
s
.49577 .28756 m .4924 .27418 L .52893 .26402 L p .744 .694 .804 r
F P
0 g
s
.4924 .27418 m .49577 .28756 L .46493 .31042 L p .768 .694 .782 r
F P
0 g
s
.39883 .49192 m .4129 .49137 L .41598 .53943 L p .7 .58 .717 r
F P
0 g
s
.42962 .53406 m .41598 .53943 L .4129 .49137 L p .707 .581 .711 r
F P
0 g
s
.23654 .42228 m .25087 .42237 L .24469 .48245 L p .646 .676 .864 r
F P
0 g
s
.25862 .48421 m .24469 .48245 L .25087 .42237 L p .657 .665 .846 r
F P
0 g
s
.42949 .39632 m .41737 .38884 L .43818 .34497 L p .756 .635 .727 r
F P
0 g
s
.41737 .38884 m .42949 .39632 L .41751 .44254 L p .74 .614 .718 r
F P
0 g
s
.5651 .2687 m .56926 .25739 L .60599 .27779 L p .642 .643 .836 r
F P
0 g
s
.56926 .25739 m .5651 .2687 L .52893 .26402 L p .689 .698 .853 r
F P
0 g
s
.25087 .42237 m .26513 .42256 L .25862 .48421 L p .657 .665 .846 r
F P
0 g
s
.27257 .48586 m .25862 .48421 L .26513 .42256 L p .666 .655 .829 r
F P
0 g
s
.40394 .43898 m .41751 .44254 L .4129 .49137 L p .72 .594 .715 r
F P
0 g
s
.4129 .49137 m .39883 .49192 L .40394 .43898 L p .72 .594 .715 r
F P
0 g
s
.41751 .44254 m .40394 .43898 L .41737 .38884 L p .74 .614 .718 r
F P
0 g
s
.75769 .41066 m .74351 .40888 L .72466 .34907 L p .492 .531 .824 r
F P
0 g
s
.71145 .34825 m .72466 .34907 L .74351 .40888 L p .526 .538 .811 r
F P
0 g
s
.69842 .3486 m .68554 .3502 L .65828 .30105 L p .518 .547 .825 r
F P
0 g
s
.64756 .30562 m .65828 .30105 L .68554 .3502 L p .562 .558 .806 r
F P
0 g
s
.26513 .42256 m .27931 .42291 L .27257 .48586 L p .666 .655 .829 r
F P
0 g
s
.28654 .48739 m .27257 .48586 L .27931 .42291 L p .675 .645 .813 r
F P
0 g
s
.39033 .43578 m .40394 .43898 L .39883 .49192 L p .717 .598 .721 r
F P
0 g
s
.39883 .49192 m .38476 .49222 L .39033 .43578 L p .717 .598 .721 r
F P
0 g
s
.27931 .42291 m .29343 .42345 L .28654 .48739 L p .675 .645 .813 r
F P
0 g
s
.30052 .48874 m .28654 .48739 L .29343 .42345 L p .683 .637 .797 r
F P
0 g
s
.46493 .31042 m .45805 .29855 L .4924 .27418 L p .768 .694 .782 r
F P
0 g
s
.45805 .29855 m .46493 .31042 L .43818 .34497 L p .773 .676 .757 r
F P
0 g
s
.37667 .43296 m .39033 .43578 L .38476 .49222 L p .714 .601 .729 r
F P
0 g
s
.38476 .49222 m .37069 .49226 L .37667 .43296 L p .714 .601 .729 r
F P
0 g
s
.29343 .42345 m .30747 .42424 L .30052 .48874 L p .683 .637 .797 r
F P
0 g
s
.31452 .48991 m .30052 .48874 L .30747 .42424 L p .69 .629 .783 r
F P
0 g
s
.36295 .4305 m .37667 .43296 L .37069 .49226 L p .711 .605 .737 r
F P
0 g
s
.37069 .49226 m .35663 .49205 L .36295 .4305 L p .711 .605 .737 r
F P
0 g
s
.30747 .42424 m .32144 .42531 L .31452 .48991 L p .69 .629 .783 r
F P
0 g
s
.32855 .49086 m .31452 .48991 L .32144 .42531 L p .696 .622 .77 r
F P
0 g
s
.34918 .42842 m .36295 .4305 L .35663 .49205 L p .706 .61 .747 r
F P
0 g
s
.35663 .49205 m .34258 .49158 L .34918 .42842 L p .706 .61 .747 r
F P
0 g
s
.32144 .42531 m .33534 .4267 L .32855 .49086 L p .696 .622 .77 r
F P
0 g
s
.34258 .49158 m .32855 .49086 L .33534 .4267 L p .702 .616 .758 r
F P
0 g
s
.40517 .38227 m .41737 .38884 L .40394 .43898 L p .742 .622 .725 r
F P
0 g
s
.40394 .43898 m .39033 .43578 L .40517 .38227 L p .742 .622 .725 r
F P
0 g
s
.33534 .4267 m .34918 .42842 L .34258 .49158 L p .702 .616 .758 r
F P
0 g
s
.43818 .34497 m .42828 .33543 L .45805 .29855 L p .773 .676 .757 r
F P
0 g
s
.42828 .33543 m .43818 .34497 L .41737 .38884 L p .762 .65 .738 r
F P
0 g
s
.60599 .27779 m .6137 .26979 L .64756 .30562 L p .582 .595 .831 r
F P
0 g
s
.6137 .26979 m .60599 .27779 L .56926 .25739 L p .598 .656 .878 r
F P
0 g
s
.41737 .38884 m .40517 .38227 L .42828 .33543 L p .762 .65 .738 r
F P
0 g
s
.52893 .26402 m .52933 .25227 L .56926 .25739 L p .689 .698 .853 r
F P
0 g
s
.52933 .25227 m .52893 .26402 L .4924 .27418 L p .742 .731 .841 r
F P
0 g
s
.65828 .30105 m .64756 .30562 L .6137 .26979 L p .527 .589 .86 r
F P
0 g
s
.39289 .37665 m .40517 .38227 L .39033 .43578 L p .745 .632 .734 r
F P
0 g
s
.39033 .43578 m .37667 .43296 L .39289 .37665 L p .745 .632 .734 r
F P
0 g
s
.77199 .41301 m .75769 .41066 L .73804 .35094 L p .457 .523 .837 r
F P
0 g
s
.72466 .34907 m .73804 .35094 L .75769 .41066 L p .492 .531 .824 r
F P
0 g
s
.4924 .27418 m .48899 .26286 L .52933 .25227 L p .742 .731 .841 r
F P
0 g
s
.48899 .26286 m .4924 .27418 L .45805 .29855 L p .776 .729 .809 r
F P
0 g
s
.41828 .32733 m .42828 .33543 L .40517 .38227 L p .769 .667 .75 r
F P
0 g
s
.40517 .38227 m .39289 .37665 L .41828 .32733 L p .769 .667 .75 r
F P
0 g
s
.71145 .34825 m .69842 .3486 L .66916 .29818 L p .464 .533 .843 r
F P
0 g
s
.65828 .30105 m .66916 .29818 L .69842 .3486 L p .518 .547 .825 r
F P
0 g
s
.38051 .37199 m .39289 .37665 L .37667 .43296 L p .747 .642 .744 r
F P
0 g
s
.37667 .43296 m .36295 .4305 L .38051 .37199 L p .747 .642 .744 r
F P
0 g
s
.45805 .29855 m .45108 .28848 L .48899 .26286 L p .776 .729 .809 r
F P
0 g
s
.45108 .28848 m .45805 .29855 L .42828 .33543 L p .782 .702 .775 r
F P
0 g
s
.42828 .33543 m .41828 .32733 L .45108 .28848 L p .782 .702 .775 r
F P
0 g
s
.56926 .25739 m .57349 .24828 L .6137 .26979 L p .598 .656 .878 r
F P
0 g
s
.57349 .24828 m .56926 .25739 L .52933 .25227 L p .659 .731 .903 r
F P
0 g
s
.36802 .36826 m .38051 .37199 L .36295 .4305 L p .75 .654 .755 r
F P
0 g
s
.36295 .4305 m .34918 .42842 L .36802 .36826 L p .75 .654 .755 r
F P
0 g
s
.78639 .41583 m .77199 .41301 L .7516 .35374 L p .421 .516 .85 r
F P
0 g
s
.73804 .35094 m .7516 .35374 L .77199 .41301 L p .457 .523 .837 r
F P
0 g
s
.6137 .26979 m .62154 .26382 L .65828 .30105 L p .527 .589 .86 r
F P
0 g
s
.62154 .26382 m .6137 .26979 L .57349 .24828 L p .53 .664 .922 r
F P
0 g
s
.40816 .32066 m .41828 .32733 L .39289 .37665 L p .777 .686 .763 r
F P
0 g
s
.39289 .37665 m .38051 .37199 L .40816 .32066 L p .777 .686 .763 r
F P
0 g
s
.66916 .29818 m .65828 .30105 L .62154 .26382 L p .452 .577 .888 r
F P
0 g
s
.52933 .25227 m .52974 .24272 L .57349 .24828 L p .659 .731 .903 r
F P
0 g
s
.52974 .24272 m .52933 .25227 L .48899 .26286 L p .735 .776 .886 r
F P
0 g
s
.3554 .36545 m .36802 .36826 L .34918 .42842 L p .752 .667 .767 r
F P
0 g
s
.34918 .42842 m .33534 .4267 L .3554 .36545 L p .752 .667 .767 r
F P
0 g
s
.44401 .28023 m .45108 .28848 L .41828 .32733 L p .793 .732 .796 r
F P
0 g
s
.41828 .32733 m .40816 .32066 L .44401 .28023 L p .793 .732 .796 r
F P
0 g
s
.48899 .26286 m .48552 .25361 L .52974 .24272 L p .735 .776 .886 r
F P
0 g
s
.48552 .25361 m .48899 .26286 L .45108 .28848 L p .783 .77 .841 r
F P
0 g
s
.72466 .34907 m .71145 .34825 L .68022 .29694 L p .402 .515 .858 r
F P
0 g
s
.66916 .29818 m .68022 .29694 L .71145 .34825 L p .464 .533 .843 r
F P
0 g
s
.45108 .28848 m .44401 .28023 L .48552 .25361 L p .783 .77 .841 r
F P
0 g
s
.80089 .41901 m .78639 .41583 L .76534 .35731 L p .387 .51 .861 r
F P
0 g
s
.7516 .35374 m .76534 .35731 L .78639 .41583 L p .421 .516 .85 r
F P
0 g
s
.34266 .36351 m .3554 .36545 L .33534 .4267 L p .754 .681 .781 r
F P
0 g
s
.33534 .4267 m .32144 .42531 L .34266 .36351 L p .754 .681 .781 r
F P
0 g
s
.39791 .31542 m .40816 .32066 L .38051 .37199 L p .784 .707 .778 r
F P
0 g
s
.38051 .37199 m .36802 .36826 L .39791 .31542 L p .784 .707 .778 r
F P
0 g
s
.57349 .24828 m .57781 .24133 L .62154 .26382 L p .53 .664 .922 r
F P
0 g
s
.57781 .24133 m .57349 .24828 L .52974 .24272 L p .602 .765 .957 r
F P
0 g
s
.32978 .36237 m .34266 .36351 L .32144 .42531 L p .755 .696 .796 r
F P
0 g
s
.32144 .42531 m .30747 .42424 L .32978 .36237 L p .755 .696 .796 r
F P
0 g
s
.68022 .29694 m .66916 .29818 L .62952 .25983 L p .352 .552 .908 r
F P
0 g
s
.62154 .26382 m .62952 .25983 L .66916 .29818 L p .452 .577 .888 r
F P
0 g
s
.62952 .25983 m .62154 .26382 L .57781 .24133 L p .423 .658 .958 r
F P
0 g
s
.43683 .27378 m .44401 .28023 L .40816 .32066 L p .803 .767 .82 r
F P
0 g
s
.40816 .32066 m .39791 .31542 L .43683 .27378 L p .803 .767 .82 r
F P
0 g
s
.52974 .24272 m .53015 .23535 L .57781 .24133 L p .602 .765 .957 r
F P
0 g
s
.53015 .23535 m .52974 .24272 L .48552 .25361 L p .712 .828 .937 r
F P
0 g
s
.8155 .42246 m .80089 .41901 L .77926 .3615 L p .355 .507 .871 r
F P
0 g
s
.76534 .35731 m .77926 .3615 L .80089 .41901 L p .387 .51 .861 r
F P
0 g
s
.38752 .31157 m .39791 .31542 L .36802 .36826 L p .792 .731 .795 r
F P
0 g
s
.36802 .36826 m .3554 .36545 L .38752 .31157 L p .792 .731 .795 r
F P
0 g
s
.73804 .35094 m .72466 .34907 L .69147 .29722 L p .331 .493 .869 r
F P
0 g
s
.68022 .29694 m .69147 .29722 L .72466 .34907 L p .402 .515 .858 r
F P
0 g
s
.48199 .24642 m .48552 .25361 L .44401 .28023 L p .786 .819 .878 r
F P
0 g
s
.44401 .28023 m .43683 .27378 L .48199 .24642 L p .786 .819 .878 r
F P
0 g
s
.31676 .36196 m .32978 .36237 L .30747 .42424 L p .755 .712 .812 r
F P
0 g
s
.30747 .42424 m .29343 .42345 L .31676 .36196 L p .755 .712 .812 r
F P
0 g
s
.48552 .25361 m .48199 .24642 L .53015 .23535 L p .712 .828 .937 r
F P
0 g
s
.83021 .42604 m .8155 .42246 L .79336 .36612 L p .328 .507 .882 r
F P
0 g
s
.77926 .3615 m .79336 .36612 L .8155 .42246 L p .355 .507 .871 r
F P
0 g
s
.30358 .36218 m .31676 .36196 L .29343 .42345 L p .755 .729 .829 r
F P
0 g
s
.29343 .42345 m .27931 .42291 L .30358 .36218 L p .755 .729 .829 r
F P
0 g
s
.57781 .24133 m .58221 .2365 L .62952 .25983 L p .423 .658 .958 r
F P
0 g
s
.58221 .2365 m .57781 .24133 L .53015 .23535 L p .497 .782 .996 r
F P
0 g
s
.37697 .30904 m .38752 .31157 L .3554 .36545 L p .799 .756 .813 r
F P
0 g
s
.3554 .36545 m .34266 .36351 L .37697 .30904 L p .799 .756 .813 r
F P
0 g
s
.42951 .26909 m .43683 .27378 L .39791 .31542 L p .811 .805 .845 r
F P
0 g
s
.39791 .31542 m .38752 .31157 L .42951 .26909 L p .811 .805 .845 r
F P
0 g
s
.69147 .29722 m .68022 .29694 L .63767 .25772 L p .228 .51 .909 r
F P
0 g
s
.62952 .25983 m .63767 .25772 L .68022 .29694 L p .352 .552 .908 r
F P
0 g
s
.7516 .35374 m .73804 .35094 L .70293 .29888 L p .256 .467 .873 r
F P
0 g
s
.69147 .29722 m .70293 .29888 L .73804 .35094 L p .331 .493 .869 r
F P
0 g
s
.29026 .36293 m .30358 .36218 L .27931 .42291 L p .752 .746 .847 r
F P
0 g
s
.27931 .42291 m .26513 .42256 L .29026 .36293 L p .752 .746 .847 r
F P
0 g
s
.63767 .25772 m .62952 .25983 L .58221 .2365 L p .264 .619 .958 r
F P
0 g
s
.53015 .23535 m .53057 .23011 L .58221 .2365 L p .497 .782 .996 r
F P
0 g
s
.53057 .23011 m .53015 .23535 L .48199 .24642 L p .659 .876 .98 r
F P
0 g
s
.845 .42965 m .83021 .42604 L .80763 .371 L p .307 .511 .892 r
F P
0 g
s
.79336 .36612 m .80763 .371 L .83021 .42604 L p .328 .507 .882 r
F P
0 g
s
.47839 .24123 m .48199 .24642 L .43683 .27378 L p .78 .872 .916 r
F P
0 g
s
.43683 .27378 m .42951 .26909 L .47839 .24123 L p .78 .872 .916 r
F P
0 g
s
.48199 .24642 m .47839 .24123 L .53057 .23011 L p .659 .876 .98 r
F P
0 g
s
.36625 .30773 m .37697 .30904 L .34266 .36351 L p .804 .783 .833 r
F P
0 g
s
.34266 .36351 m .32978 .36237 L .36625 .30773 L p .804 .783 .833 r
F P
0 g
s
.27679 .36409 m .29026 .36293 L .26513 .42256 L p .748 .763 .865 r
F P
0 g
s
.26513 .42256 m .25087 .42237 L .27679 .36409 L p .748 .763 .865 r
F P
0 g
s
.42206 .26607 m .42951 .26909 L .38752 .31157 L p .817 .846 .871 r
F P
0 g
s
.38752 .31157 m .37697 .30904 L .42206 .26607 L p .817 .846 .871 r
F P
0 g
s
.85986 .43317 m .845 .42965 L .82205 .37594 L p .295 .521 .902 r
F P
0 g
s
.80763 .371 m .82205 .37594 L .845 .42965 L p .307 .511 .892 r
F P
0 g
s
.26318 .36553 m .27679 .36409 L .25087 .42237 L p .741 .779 .884 r
F P
0 g
s
.25087 .42237 m .23654 .42228 L .26318 .36553 L p .741 .779 .884 r
F P
0 g
s
.76534 .35731 m .7516 .35374 L .7146 .30176 L p .18 .439 .87 r
F P
0 g
s
.70293 .29888 m .7146 .30176 L .7516 .35374 L p .256 .467 .873 r
F P
0 g
s
.58221 .2365 m .5867 .23369 L .63767 .25772 L p .264 .619 .958 r
F P
0 g
s
.5867 .23369 m .58221 .2365 L .53057 .23011 L p .32 .746 .973 r
F P
0 g
s
.70293 .29888 m .69147 .29722 L .64598 .25737 L p .085 .451 .883 r
F P
0 g
s
.63767 .25772 m .64598 .25737 L .69147 .29722 L p .228 .51 .909 r
F P
0 g
s
.35535 .30754 m .36625 .30773 L .32978 .36237 L p .808 .811 .853 r
F P
0 g
s
.32978 .36237 m .31676 .36196 L .35535 .30754 L p .808 .811 .853 r
F P
0 g
s
.24942 .36713 m .26318 .36553 L .23654 .42228 L p .732 .794 .902 r
F P
0 g
s
.23654 .42228 m .22215 .42225 L .24942 .36713 L p .732 .794 .902 r
F P
0 g
s
.47471 .23795 m .47839 .24123 L .42951 .26909 L p .755 .922 .945 r
F P
0 g
s
.42951 .26909 m .42206 .26607 L .47471 .23795 L p .755 .922 .945 r
F P
0 g
s
.64598 .25737 m .63767 .25772 L .5867 .23369 L p .061 .532 .894 r
F P
0 g
s
.82205 .37594 m .8366 .38074 L .85986 .43317 L p .295 .521 .902 r
F P
0 g
s
.53057 .23011 m .531 .22689 L .5867 .23369 L p .32 .746 .973 r
F P
0 g
s
.531 .22689 m .53057 .23011 L .47839 .24123 L p .55 .891 .983 r
F P
0 g
s
.47839 .24123 m .47471 .23795 L .531 .22689 L p .55 .891 .983 r
F P
0 g
s
.41447 .26461 m .42206 .26607 L .37697 .30904 L p .815 .888 .896 r
F P
0 g
s
.37697 .30904 m .36625 .30773 L .41447 .26461 L p .815 .888 .896 r
F P
0 g
s
.23554 .36876 m .24942 .36713 L .22215 .42225 L p .721 .807 .918 r
F P
0 g
s
.22215 .42225 m .20769 .42222 L .23554 .36876 L p .721 .807 .918 r
F P
0 g
s
.77926 .3615 m .76534 .35731 L .72649 .30566 L p .109 .413 .862 r
F P
0 g
s
.7146 .30176 m .72649 .30566 L .76534 .35731 L p .18 .439 .87 r
F P
0 g
s
.34427 .30833 m .35535 .30754 L .31676 .36196 L p .808 .838 .873 r
F P
0 g
s
.31676 .36196 m .30358 .36218 L .34427 .30833 L p .808 .838 .873 r
F P
0 g
s
.22154 .37026 m .23554 .36876 L .20769 .42222 L p .707 .817 .934 r
F P
0 g
s
.20769 .42222 m .19318 .42214 L .22154 .37026 L p .707 .817 .934 r
F P
0 g
s
.7146 .30176 m .70293 .29888 L .65448 .25863 L p 0 .379 .829 r
F P
0 g
s
.64598 .25737 m .65448 .25863 L .70293 .29888 L p .085 .451 .883 r
F P
0 g
s
.5867 .23369 m .5913 .23277 L .64598 .25737 L p .061 .532 .894 r
F P
0 g
s
.5913 .23277 m .5867 .23369 L .531 .22689 L p .089 .631 .849 r
F P
0 g
s
.47095 .23645 m .47471 .23795 L .42206 .26607 L p .699 .954 .952 r
F P
0 g
s
.42206 .26607 m .41447 .26461 L .47095 .23645 L p .699 .954 .952 r
F P
0 g
s
.65448 .25863 m .64598 .25737 L .5913 .23277 L p 0 .409 .766 r
F P
0 g
s
.40671 .26456 m .41447 .26461 L .36625 .30773 L p .804 .927 .916 r
F P
0 g
s
.36625 .30773 m .35535 .30754 L .40671 .26456 L p .804 .927 .916 r
F P
0 g
s
.333 .30994 m .34427 .30833 L .30358 .36218 L p .804 .864 .893 r
F P
0 g
s
.30358 .36218 m .29026 .36293 L .333 .30994 L p .804 .864 .893 r
F P
0 g
s
.531 .22689 m .53144 .22557 L .5913 .23277 L p .089 .631 .849 r
F P
0 g
s
.53144 .22557 m .531 .22689 L .47471 .23795 L p .375 .835 .906 r
F P
0 g
s
.79336 .36612 m .77926 .3615 L .73859 .31039 L p .049 .392 .851 r
F P
0 g
s
.72649 .30566 m .73859 .31039 L .77926 .3615 L p .109 .413 .862 r
F P
0 g
s
.47471 .23795 m .47095 .23645 L .53144 .22557 L p .375 .835 .906 r
F P
0 g
s
.72649 .30566 m .7146 .30176 L .66316 .26131 L p 0 .307 .759 r
F P
0 g
s
.65448 .25863 m .66316 .26131 L .7146 .30176 L p 0 .379 .829 r
F P
0 g
s
.32155 .31219 m .333 .30994 L .29026 .36293 L p .796 .888 .911 r
F P
0 g
s
.29026 .36293 m .27679 .36409 L .32155 .31219 L p .796 .888 .911 r
F P
0 g
s
.5913 .23277 m .59601 .23358 L .65448 .25863 L p 0 .409 .766 r
F P
0 g
s
.59601 .23358 m .5913 .23277 L .53144 .22557 L p .125 0 0 r
F P
0 g
s
.4671 .23659 m .47095 .23645 L .41447 .26461 L p .604 .948 .919 r
F P
0 g
s
.41447 .26461 m .40671 .26456 L .4671 .23659 L p .604 .948 .919 r
F P
0 g
s
.39879 .26577 m .40671 .26456 L .35535 .30754 L p .78 .956 .927 r
F P
0 g
s
.35535 .30754 m .34427 .30833 L .39879 .26577 L p .78 .956 .927 r
F P
0 g
s
.80763 .371 m .79336 .36612 L .75091 .31571 L p .004 .378 .842 r
F P
0 g
s
.73859 .31039 m .75091 .31571 L .79336 .36612 L p .049 .392 .851 r
F P
0 g
s
.66316 .26131 m .65448 .25863 L .59601 .23358 L p .304 0 0 r
F P
0 g
s
.53144 .22557 m .5319 .22598 L .59601 .23358 L p .125 0 0 r
F P
0 g
s
.51499 .22853 m .47095 .23645 L p .50627 .23038 L .172 .708 .754 r
F P
0 g
s
.50627 .23038 m .5319 .22598 L .51499 .22853 L .172 .708 .754 r
F
.47095 .23645 m .4671 .23659 L .5319 .22598 L p F P
0 g
s
.46316 .23816 m .4671 .23659 L .42159 .25767 L p .478 .897 .845 r
F P
0 g
s
.42159 .25767 m .40671 .26456 L p .42476 .25612 L .478 .897 .845 r
F P
0 g
s
.42476 .25612 m .46316 .23816 L .42159 .25767 L .478 .897 .845 r
F
.40671 .26456 m .39879 .26577 L .46316 .23816 L p F P
0 g
s
.45912 .24096 m .46316 .23816 L .41077 .26063 L p .347 .817 .748 r
F P
0 g
s
.41077 .26063 m .39879 .26577 L p .41471 .25923 L .347 .817 .748 r
F P
0 g
s
.41471 .25923 m .45912 .24096 L .41077 .26063 L .347 .817 .748 r
F
.39879 .26577 m .3907 .26804 L .44159 .2479 L p F P
0 g
s
.39879 .26577 m .44159 .2479 L .43808 .24961 L .347 .817 .748 r
F
.3907 .26804 m .39879 .26577 L .34427 .30833 L p .742 .973 .927 r
F P
0 g
s
.34427 .30833 m .333 .30994 L .3907 .26804 L p .742 .973 .927 r
F P
0 g
s
.38244 .27115 m .3907 .26804 L .333 .30994 L p .692 .974 .916 r
F P
0 g
s
.3907 .26804 m .38244 .27115 L .44083 .24989 L p 0 0 0 r
F P
0 g
s
.44083 .24989 m .45499 .24473 L p .43647 .25145 L 0 0 0 r
F P
0 g
s
.3907 .26804 m .44083 .24989 L .43647 .25145 L 0 0 0 r
F
.44159 .2479 m .45912 .24096 L p .43808 .24961 L .347 .817 .748 r
F P
0 g
s
.4671 .23659 m .46316 .23816 L .48465 .23498 L p .004 0 0 r
F P
0 g
s
.48465 .23498 m .53236 .22793 L p .49371 .23306 L .004 0 0 r
F P
0 g
s
.4671 .23659 m .48465 .23498 L .49371 .23306 L .004 0 0 r
F
.5319 .22598 m .53144 .22557 L .51499 .22853 L p .172 .708 .754 r
F P
0 g
s
.30991 .3149 m .32155 .31219 L .27679 .36409 L p .783 .906 .927 r
F P
0 g
s
.27679 .36409 m .26318 .36553 L .30991 .3149 L p .783 .906 .927 r
F P
0 g
s
.73859 .31039 m .72649 .30566 L .67205 .2652 L p 0 .246 .69 r
F P
0 g
s
.66316 .26131 m .67205 .2652 L .72649 .30566 L p 0 .307 .759 r
F P
0 g
s
.82205 .37594 m .80763 .371 L .76343 .32138 L p 0 .376 .837 r
F P
0 g
s
.75091 .31571 m .76343 .32138 L .80763 .371 L p .004 .378 .842 r
F P
0 g
s
.59601 .23358 m .60084 .23591 L .66316 .26131 L p .304 0 0 r
F P
0 g
s
.60084 .23591 m .59601 .23358 L .5319 .22598 L p .277 0 0 r
F P
0 g
s
.2981 .31787 m .30991 .3149 L .26318 .36553 L p .765 .92 .94 r
F P
0 g
s
.26318 .36553 m .24942 .36713 L .2981 .31787 L p .765 .92 .94 r
F P
0 g
s
.67205 .2652 m .66316 .26131 L .60084 .23591 L p .412 0 0 r
F P
0 g
s
.53236 .22793 m .5319 .22598 L .4671 .23659 L p .004 0 0 r
F P
0 g
s
.8366 .38074 m .82205 .37594 L .77613 .32714 L p 0 .386 .839 r
F P
0 g
s
.76343 .32138 m .77613 .32714 L .82205 .37594 L p 0 .376 .837 r
F P
0 g
s
.5319 .22598 m .53236 .22793 L .60084 .23591 L p .277 0 0 r
F P
0 g
s
.75091 .31571 m .73859 .31039 L .68112 .27006 L p 0 .202 .632 r
F P
0 g
s
.67205 .2652 m .68112 .27006 L .73859 .31039 L p 0 .246 .69 r
F P
0 g
s
.333 .30994 m .32155 .31219 L .38244 .27115 L p .692 .974 .916 r
F P
0 g
s
.28612 .32089 m .2981 .31787 L .24942 .36713 L p .743 .928 .951 r
F P
0 g
s
.24942 .36713 m .23554 .36876 L .28612 .32089 L p .743 .928 .951 r
F P
0 g
s
.77613 .32714 m .78901 .33274 L .8366 .38074 L p 0 .386 .839 r
F P
0 g
s
.60084 .23591 m .60579 .23955 L .67205 .2652 L p .412 0 0 r
F P
0 g
s
.60579 .23955 m .60084 .23591 L .53236 .22793 L p .372 0 0 r
F P
0 g
s
.27399 .32374 m .28612 .32089 L .23554 .36876 L p .719 .93 .96 r
F P
0 g
s
.23554 .36876 m .22154 .37026 L .27399 .32374 L p .719 .93 .96 r
F P
0 g
s
.68112 .27006 m .67205 .2652 L .60579 .23955 L p .477 0 0 r
F P
0 g
s
.37402 .27486 m .38244 .27115 L .32155 .31219 L p .637 .963 .898 r
F P
0 g
s
.32155 .31219 m .30991 .3149 L .37402 .27486 L p .637 .963 .898 r
F P
0 g
s
.53284 .23118 m .53236 .22793 L .46316 .23816 L p .129 0 0 r
F P
0 g
s
.46316 .23816 m .45912 .24096 L .53284 .23118 L p .129 0 0 r
F P
0 g
s
.76343 .32138 m .75091 .31571 L .69039 .27562 L p .38 0 0 r
F P
0 g
s
.68112 .27006 m .69039 .27562 L .75091 .31571 L p 0 .202 .632 r
F P
0 g
s
.53236 .22793 m .53284 .23118 L .60579 .23955 L p .372 0 0 r
F P
0 g
s
.45499 .24473 m .45912 .24096 L .3907 .26804 L p 0 0 0 r
F P
0 g
s
.60579 .23955 m .61085 .24423 L .68112 .27006 L p .477 0 0 r
F P
0 g
s
.61085 .24423 m .60579 .23955 L .53284 .23118 L p .428 0 0 r
F P
0 g
s
.36543 .27891 m .37402 .27486 L .30991 .3149 L p .584 .945 .879 r
F P
0 g
s
.30991 .3149 m .2981 .31787 L .36543 .27891 L p .584 .945 .879 r
F P
0 g
s
.69039 .27562 m .68112 .27006 L .61085 .24423 L p .512 0 0 r
F P
0 g
s
.69039 .27562 m .69984 .2816 L .70422 .28433 L p .38 0 0 r
F P
0 g
s
.70422 .28433 m .76343 .32138 L p .69955 .28135 L .38 0 0 r
F P
0 g
s
.69039 .27562 m .70422 .28433 L .69955 .28135 L .38 0 0 r
F
.77613 .32714 m .76343 .32138 L .70422 .28433 L p .391 0 0 r
F P
0 g
s
.70422 .28433 m .69984 .2816 L p .7091 .28712 L .391 0 0 r
F P
0 g
s
.7091 .28712 m .77613 .32714 L .70422 .28433 L .391 0 0 r
F
.69984 .2816 m .70947 .2877 L .77613 .32714 L p F P
0 g
s
.78901 .33274 m .77613 .32714 L .70947 .2877 L p .379 0 0 r
F P
0 g
s
.71927 .29362 m .7854 .33072 L p .70967 .28781 L .379 0 0 r
F P
0 g
s
.7854 .33072 m .78901 .33274 L p .78156 .32852 L .379 0 0 r
F P
0 g
s
.70967 .28781 m .7854 .33072 L .78156 .32852 L .379 0 0 r
F
.70947 .2877 m .70988 .28795 L p .70967 .28781 L F P
0 g
s
.70988 .28795 m .71927 .29362 L p .70967 .28781 L .379 0 0 r
F P
0 g
s
.53332 .23548 m .53284 .23118 L .45912 .24096 L p .211 0 0 r
F P
0 g
s
.45912 .24096 m .45499 .24473 L .53332 .23548 L p .211 0 0 r
F P
0 g
s
.53284 .23118 m .53332 .23548 L .61085 .24423 L p .428 0 0 r
F P
0 g
s
.45076 .24921 m .45499 .24473 L .38244 .27115 L p 0 0 0 r
F P
0 g
s
.38244 .27115 m .37402 .27486 L .45076 .24921 L p 0 0 0 r
F P
0 g
s
.34782 .287 m .3567 .28305 L .28612 .32089 L p .504 .91 .861 r
F P
0 g
s
.3567 .28305 m .34782 .287 L .34866 .28679 L p 0 0 0 r
F P
0 g
s
.36472 .27933 m .2981 .31787 L p .3567 .28305 L .538 .926 .865 r
F P
0 g
s
.2981 .31787 m .28612 .32089 L .3567 .28305 L p .538 .926 .865 r
F P
0 g
s
.34866 .28679 m .43754 .26392 L p .3567 .28305 L 0 0 0 r
F P
0 g
s
.3567 .28305 m .36543 .27891 L .36472 .27933 L p .538 .926 .865 r
F P
0 g
s
.69984 .2816 m .69039 .27562 L .61604 .24967 L p .527 0 0 r
F P
0 g
s
.61085 .24423 m .61604 .24967 L .69039 .27562 L p .512 0 0 r
F P
0 g
s
.61604 .24967 m .61085 .24423 L .53332 .23548 L p .459 0 0 r
F P
0 g
s
.53382 .24054 m .53332 .23548 L .45499 .24473 L p .262 0 0 r
F P
0 g
s
.45499 .24473 m .45076 .24921 L .53382 .24054 L p .262 0 0 r
F P
0 g
s
.53332 .23548 m .53382 .24054 L .61604 .24967 L p .459 0 0 r
F P
0 g
s
.44644 .25411 m .45076 .24921 L .37402 .27486 L p 0 0 0 r
F P
0 g
s
.37402 .27486 m .36543 .27891 L .44644 .25411 L p 0 0 0 r
F P
0 g
s
.28612 .32089 m .27399 .32374 L .34782 .287 L p .504 .91 .861 r
F P
0 g
s
.70947 .2877 m .69984 .2816 L .62134 .25557 L p .525 0 0 r
F P
0 g
s
.61604 .24967 m .62134 .25557 L .69984 .2816 L p .527 0 0 r
F P
0 g
s
.62134 .25557 m .61604 .24967 L .53382 .24054 L p .473 0 0 r
F P
0 g
s
.53433 .24605 m .53382 .24054 L .45076 .24921 L p .289 0 0 r
F P
0 g
s
.45076 .24921 m .44644 .25411 L .53433 .24605 L p .289 0 0 r
F P
0 g
s
.44203 .25912 m .44644 .25411 L .36543 .27891 L p 0 0 0 r
F P
0 g
s
.36543 .27891 m .3567 .28305 L .44203 .25912 L p 0 0 0 r
F P
0 g
s
.53382 .24054 m .53433 .24605 L .62134 .25557 L p .473 0 0 r
F P
0 g
s
.71927 .29362 m .70947 .2877 L .62675 .2616 L p .508 0 0 r
F P
0 g
s
.62134 .25557 m .62675 .2616 L .70947 .2877 L p .525 0 0 r
F P
0 g
s
.62675 .2616 m .62134 .25557 L .53433 .24605 L p .473 0 0 r
F P
0 g
s
.43754 .26392 m .44203 .25912 L .3567 .28305 L p 0 0 0 r
F P
0 g
s
.53485 .2517 m .53433 .24605 L .44644 .25411 L p .299 0 0 r
F P
0 g
s
.44644 .25411 m .44203 .25912 L .53485 .2517 L p .299 0 0 r
F P
0 g
s
.53433 .24605 m .53485 .2517 L .62675 .2616 L p .473 0 0 r
F P
0 g
s
.62675 .2616 m .63227 .26744 L .71927 .29362 L p .508 0 0 r
F P
0 g
s
.63227 .26744 m .62675 .2616 L .53485 .2517 L p .459 0 0 r
F P
0 g
s
.53539 .25714 m .53485 .2517 L .44203 .25912 L p .291 0 0 r
F P
0 g
s
.44203 .25912 m .43754 .26392 L .53539 .25714 L p .291 0 0 r
F P
0 g
s
.53485 .2517 m .53539 .25714 L .63227 .26744 L p .459 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol00024ooooo`[o0000<?oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`00000/ooooo`00:oooool00ol0003oooooooooo`0Booooo`;o00000oooool00ol0003ooooooooo
o`1joooooaco00009_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000/ooooo`00:Oooool00omEEEGoIVIVo`00000Aooooo`?o0000Nooo
ool?o`0000?o=P0000?o0000ofd00?m]00000_m]000Bo`00023ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
001iooooo`ko00001Olf0009o`0000SoK@003Ol0000Mooooo`03o`000?oooooooooo02Wooooo0_l0
0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool003Sooooo0ol000000ooooooo0000oooo
o`1fooooo`[o00000_lf000Ko`0000OoK@001ol0000Kooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
N_oooolGo`0000CoB@0000?o0000ogT00?mi00000omi000Ao`0000;oK@001Ol0000Iooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0<oooool003?ooooo0ol0001joooooa3o00002Om9
000;o`0000SoN@003Ol000000omj003o0000o`000002o`0001Kooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0booooo`00<Oooool2o`0007[ooooo2_l00008odT000[o00001Om<0000
0ol0003oN@00ogT00003ogT000Wo00002?mi000;o`0001Cooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0aooooo`00;_ooool3o`000003ooooool0003ooooo07Oooooo2?l00003odT0
00Wo00002_m<000;o`0000WoN@002Ol00003ogT000Wo00004_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo037ooooo000]ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`ko
00002?m<000;o`0000GoBP0000?o0000ogD00?me00000ome000:o`0000SoN@001_l000000on6003o
0000o`000006o`0000oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00
;Oooool00ol0003oooooo`00001eooooo`co00000om<000:o`0000SoBP003_l0000:ogD000[o0000
0omi0004o`000003ohH00?l0003o000000Ko00003?ooool00ol0003oooooooooo`0]ooooo`?o0000
<Oooool002gooooo00Co0000oooooooooooo0000LOoooolBo`0000;oBP004?l00006okfke`03o`00
0?n`/][o/;;J00Go/;;J2ol00009ogD000[o000000?oQP00o`000?l000001Ol0000:ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;oooool002gooooo0_l00002ooooo`03o`000?oo
oooooooo06_ooooo5ol00003olWAh003o`000?o8aMOob<GG00;ob<GG0ol0000:okfke`;o00000_n`
/]X00ol0003o/;;Jok2bfP07ok2bfP06o`000?nTY=KoY:CFojBTe_l0003oVJOP2ol00003ogD00003
o`000?n2003o000000Go000000?oQP00o`000?l000000ol00009ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0;_ooool002cooooo0_l00004ooooo`03o`000?oooooooooo06Sooooo
3ol000000oo1k?7o0000olOOjP02olOOjP03o`000?o9dN3obM7P00?obM7P0_l00004olS5e`03o`00
0?o6^/oo000000So_K_G0ol000000onn/Lgo0000okB[c`02okB[c`Ko00000_n`/]X00ol0003oY:CF
ojBTeP03ojBTeP;o00001_nIYn02o`000003ohNYk?l0003o000000Ko000000?oPP00o`000?l00000
2_l00006ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool002cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Vooooo`go00000_oAf=h3o`0000;oamoZ1Oo9
dN02o`0000Cob<GG0_l00002olJjc`03o`000?nm^mOo_K_G00?o_K_G0ol00004okjac@03o`000?nd
Zloo]:_?00Oo]:_?0ol00007ojBTeP;o00001_nIYn001Ol0003oQYKLohJFg?n6U]co000000CoLi?S
0ol000000on2003o0000o`000009o`0000Cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0]ooooo`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06?ooooo2ol0
00000oo@hnGo0000om7HgP02om7HgP05o`000?o?c]SoclkHolo>f?l000001Oo9dN000ol0003ob<GG
olS5e`02olS5e`;o00001Oo6^/l00ol0003o_K_Go`000002o`0000Oo_[7=00?o0000okB[condZll0
2OndZll00ol0003oZj7=o`000007ojBTeP03o`000?nIYn3oVJOP00;oVJOP0_l00004ohJFg003o`00
0?mcTn?oLi?S00;oLi?S00?o0000oeZ=j?l000000_l000000on2003o0000o`000007o`0000?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Kooooo00?o
0000ooooooooool0H?ooool9o`000005olg]j_o@hnGod>?Uom3SiOl000000ooAf=h00ol0003oclkH
olo>f002olo>f003o`000?o9dN3obM7P00;obM7P00?o0000olS5eoo8aML00_o8aML00ol0003oa[[?
olJjc`04olJjc`?o00002_nn/Ld00ol0003o]:_?okB[c`08okB[c`03o`000?n[XLgoZj7=00;oZj7=
0_l00005ojBTeP;o000000GoVJOPo`000?nDV=CoU9SDo`000004ohJFg003o`000?mcTn?oLi?S00;o
Li?S00?o0000oeZ=j?mJSNP01?l000000on2003o0000o`000006o`000003ooooool0003ooooo03?o
oooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05cooooo
2_l00002olg]jP?od>?U00Go0000om7Hg_oAf=kodMSNo`000004olo>f003o`000?o=a=7o000000;o
bM7P1?o8aML2o`0000Koa[[?00?o0000olBab?l000002Onn/Ld3o`000003okB[col0003o000000;o
00001OndZll00ol0003oZj7=oj^Qc@04oj^Qc@03o`000?nTY=KoY:CF00CoY:CF00?o0000oiBHe?nD
V=@00_nDV=@00ol0003oQYKLohJFg002ohJFg003o`000?mcTn?oLi?S00;oLi?S00Co0000oeZ=j?mJ
SNSo00000_ljP^P3o`000003oh800?l0003o000000Go0000=Oooool00ol0003oooooooooo`0[oooo
o`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo2Ol00000
0oo7m>go0000olg]jP02olg]jP?od>?U00Go0000om7Hg_oAf=kodMSNo`000004olo>f005o`000?o=
a=7ocLCAolg4dOl000001?o8aML00ol0003oa[[?olJjc`05olJjc`04o`000?o4/LSoa;78o`0000Go
_[7=1?l00002okfZaP03o`000?ngYLOo]jG700?o]jG71Ol00008oj^Qc@;o00001?nTY=H00ol0003o
U9SDoiBHe003oiBHe003o`000?n6U]coQYKL00;oQYKL00?o0000og>ChomcTn<00_mcTn<01?l0003o
FXgXoeZ=j?l00003ocZ2j0Co000000?oPP00o`000?l000000ol0000eooooo`03o`000?oooooooooo
02[ooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Gooooo1ol00002okgi
k@03o`000?o7m>go000000?ocNgZ0oo@hnD01Ol0003odMSNom7Hg_oAf=ko000000CoclkH00?o0000
olg4dOo=a=400_o=a=42o`0000;ob<GG1oo6^/l2o`0000Coa;7800?o0000okjacOl000000_l00006
okfZaP03o`000?ngYLOo]jG700Oo]jG700Co0000ok2NaOl0003o00001on[XLd2o`000004ojBTe_l0
003oWiS=o`0000GoU9SD00?o0000ohJFg?n6U]`00_n6U]`00ol0003oLi?Sog>Ch`02og>Ch`04o`00
0?mJSNSoFXgXo`0000?o>X;X00?o0000oaEch_lELn800ol000001?n2003o0000o`000?l0000doooo
o`03o`000?oooooooooo02[ooooo0009ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000ooooooooool0Doooool4o`00
0004oj?fiOl0003o/OWZokgik@;o000000?oaoC]o`000?o=kNX00_o=kNX3om3Si@05o`000?oAf=ko
dMSNom7Hg_l000001?o?c]P00ol0003ocLCAolg4d@02olg4d@04o`000?o;^l_obk_;o`0000Ooa[[?
00?o0000olBab?o4/LP00oo4/LP3o`0000Wo_J[600?o0000okNUaongYLL01ongYLL01Ol0003o/9k5
ok2NaOn`W/Go000000SoZj7=00Go0000oinHcOnOV<goWiS=o`000005oiBHe003o`000?n6U]coQYKL
00;oQYKL00?o0000og>ChomcTn<00_mcTn<01?l0003oFXgXoeZ=j?l00003ocZ2j005o`000?lELn;o
5G?Ro`000?l0HM@00ol000000on2003o0000o`00000cooooo`03o`000?oooooooooo02Wooooo000A
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0D?ooool3o`000004oiGahOl0003oXoKUo`0000;o_OW]
00Co0000olOdkOo7m>go00000oo=kNX3om3Si@05o`000?oAf=kodMSNom7Hg_l000001?o?c]P00ol0
003ocLCAolg4d@02olg4d@05o`000?o;^l_obk_;ol^kbol000001_o6^/l00ol0003oa;78olBab003
olBab003o`000?o2Z/;o000000[o_J[600?o0000okNUaongYLL01_ngYLL00ol0003o/9k5ok2Na@03
ok2Na@;o00001_n[XLd00ol0003oWiS=oinHc@02oinHc@03o`000?nDV=CoU9SD00?oU9SD00?o0000
ohJFg?n6U]`00_n6U]`00ol0003oLi?Sog>Ch`02og>Ch`04o`000?mJSNSoFXgXo`0000?o>X;X00Co
0000oaEch_lELn;o00000_l0HM@6o`0003;ooooo00?o0000ooooooooool0:?ooool0017ooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo04gooooo0ol000001OnElN7o0000oj?fiOl0003o/OWZ
00;o_OW]00?o0000olOdkOo7m>d01?o=kNX3om3Si@05o`000?oAf=kodMSNom7Hg_l000001?o?c]P0
0ol0003ocLCAolg4d@02olg4d@07o`000?o;^l_obk_;ol^kbol0003ob;?6o`000004olJjc`Goa;78
0_l00002ol:Z`P03o`000?nmZ/Ko_J[600Ko_J[62?l00003okNUa`03o`000?n`W/Go/9k500Go/9k5
0_l00003oj^Qc@03o`000?nVV<Oo000000CoWiS=00?o0000oiBHe?nDV=@00onDV=@00ol0003oQYKL
ohJFg002ohJFg003o`000?mcTn?oLi?S00;oLi?S00Co0000oeZ=j?mJSNSo00000oljP^P01Ol0003o
5G?RoaEch_l0003o067D00;o000000?o04k2o`000?l000000_l0000aooooo`;o0000:Oooool0017o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000?oooo
o`03o`000?oooooooooo04[ooooo0_l000000on9kMgo0000oiGah@02oj?fi@05ok7ij_nmnNgo_OW]
okgikOl000000_o7m>d4olg]jP?od>?U00Go0000om7Hg_oAf=kodMSNo`000004olo>f003o`000?o=
a=7ocLCA00;ocLCA00Go0000ol^kboo;^l_obk_;o`000003olRcaP03o`000?o6^/ooa[[?00Goa;78
00?o0000ol:Z`_o2Z/800oo2Z/800ol0003o_J[6okfZaP02okfZaP?o00000_nmY<000ol0003o^:71
okRQ`@03okRQ`@Co00002On`W/D00ol0003oZj7=o`000003ojJHa`03o`000?nOV<goWiS=00;oWiS=
00?o0000oiBHe?nDV=@00onDV=@00ol0003oQYKLohJFg002ohJFg003o`000?mcTn?oLi?S00ko0000
00?o067Do`000?l0C/800ol000000omQ003o0000ooooo`0^ooooo`;o0000:Oooool0017ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`17ooooo`;o000000OoPNSLo`000?nElN7o0000oj?fiOl0003o/OWZ
00?o_OW]0oo7m>d4olg]jPCod>?U0ooAf=h00ol0003oclkHolo>f002olo>f003o`000?o=a=7ocLCA
00;ocLCA00Go0000ol^kboo;^l_obk_;o`000005olRcaP03o`000?o4/LSoa;7800?oa;7800?o0000
ol:Z`_o2Z/801?o2Z/800ol0003o_J[6o`000002o`0000Go_JC000?o0000okRQ`OnhXL401_nhXL40
0ol0003o/iboo`000008ok2Na@03o`000?nVV<OoYYS700?oYYS700?o0000oinHcOnOV<d00_nOV<d0
0ol0003oU9SDoiBHe003oiBHe004o`000?n6U]coQYKLohJFg0?o00000_n4S=<3ogJ8e`CoIX?K0omD
O]h5o`0000;o04k200?o0000o`0n/?l000000_l0000_ooooo`03o`000?oooooooooo02Kooooo000A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?oo
ool2o`0004Gooooo0_l000001?n1j=coRNgMoiGahOnElN42oj?fi@;o/OWZ0onmnNd3olOdk@CocNgZ
1?o@hnD4om7HgPCoclkH00?o0000olg4dOo=a=400_o=a=401Ol0003obk_;ol^kboo;^l_o000000Ko
b;?600?o0000olBab?o4/LP00_o4/LP00ol0003o`Z[2ol:Z`P04ol:Z`P?o00002?nmY<000ol0003o
^:71okRQ`@06okRQ`@03o`000?ncW;oo/ibo00;o00001_n`W/D00ol0003oYYS7ojJHa`04ojJHa`03
o`000?nOV<goWiS=00;oWiS=00?o0000oiBHe?nDV=@00onDV=@01?l0003oQYKLo`000?n?S/h5ohB<
d`?oMXSG1?mVPm/2oeAngP;o00000_m1Mml5o`000004o`0n/?l0003oI000o`0002kooooo00?o0000
ooooooooool09_ooool002[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`10oooo
o`;o000000GoPNSLohW]gOl0003oUO7Qo`000002oj?fi@03ok7ij_nmnNgo_OW]00;o_OW]1Ol00002
olg]jPCod>?U1?oAf=h4olo>f003o`000?o=a=7ocLCA00;ocLCA00Go0000ol^kboo;^l_obk_;o`00
0006olRcaP03o`000?o5[L7o000000;oa;781oo2Z/800ol0003o`:Bmo`000008okfT`003o`000?nh
XL7o^:7100Oo^:7100?o0000ok>L_oncW;l00_ncW;l00ol0003o/9k5ok2Na@02ok2Na@03o`000?n/
Ul7o000000KoYYS700?o0000oinHcOnOV<d00_nOV<d00ol0003oU9SDoiBHe002oiBHe0;o00000on?
S/h4ohB<d`04o`000?mfR=OoMXSGogJ8e`;oIX?K0ol000000omDO]ko0000od5gg`02od5gg`?o;W3N
1ol0000]ooooo`03o`000?oooooooooo02Gooooo000Zooooo`;o00005Oooool00ol0003ooooooooo
o`0mooooo`;o000000?oPNSLohW]gOn9kMd00_nElN42oj?fi@Oo00000_o>e]l00ol0003oc/oJolk?
fP07o`0000;odMSN1?o?c]P00ol0003ocLCAolg4d@02olg4d@05o`000?o;^l_obk_;ol^kbol00000
1_o8/lH01Ol0003oaJg1olF]`Oo5[L7o000000Oo`Z[200Co0000ol2T_Oo0Y;go00002?nmY<000ol0
003o^:71okRQ`@06okRQ`@03o`000?ncW;oo/ibo00Co/ibo0_l00002ok2Na@04o`000?n/Ul7o[9O1
o`0000GoYYS700?o0000oinHcOnOV<d00onOV<d01Ol0003oU9SDo`000?l0003oVI3900CoShk>00?o
0000ohB<don4S=<00_n4S=<00ol0003oMXSGo`000002o`0000;oIX?K00Co0000oeAng_mDO]ko0000
0om1Mml3obi`gP?o6fWL1Ol0000/ooooo`03o`000?oooooooooo02Cooooo000Zooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0>_ooool2o`000003oh7Xg?n9kMgoRNgM00;oUO7Q1?l0
00000oo;hnWo0000olgMi002olgMi004o`000?o>e]ooc]KOo`0000?oc/oJ00Go0000olg8eOo=b=Go
cLSEo`000002olc1d0?o00000oo?c]P4olg4d@03o`000?o;^l_obk_;00;obk_;00?o0000olRca_o8
/lH00oo8/lH00ol0003oaJg1olF]`@02olF]`@03o`000?o2Z/;o`Z[200?o`Z[20_l00003ol2T_@03
o`000?nmY<3o_JC000Go_JC01ol00003okRQ`@03o`000?ncW;oo/ibo00Ko/ibo00?o0000ok2NaOl0
00000on/Ul400ol0003oYYS7ojJHa`03ojJHa`03o`000?nOV<goWiS=00?oWiS=00?o0000oiV@bOnI
T<T00_nIT<T4ohn>cP03o`000?n4S=?oQ8cC00?o00000_mfR=L01Ol0003oIX?KofJ3fomVPm_o0000
00;oE7kN00Co0000od5ggom1Mmoo@GOO0ol^L=h3oa]Yg0;o36CI0_l000000omQ003o0000ooooo`0Y
ooooo`;o00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0goooo
o`;o00000_n1j=`00on9kMgo0000o`000002o`0000;ob>O]00?o0000ol_SjOl000000oo=gN@01?l0
003oc]KOolkFgol00003olk?fP05o`000?o=b=GocLSEolg8eOl000000oo<`M000ol0003ob[_;olZk
b`03o`0000?ocLCA00?o0000ol^kboo;^l/00_o;^l/00ol0003ob;?6olRcaP03olRcaP03o`000?o5
[L7oaJg100;oaJg100?o0000ol>W_Ol000000oo2Z/800ol0003o`:Bmol2T_@04ol2T_@04o`000?nm
Y<3o_JC0okfT`0?o000000?o_9nko`000?niWK`01?niWK`4o`0000Wo/ibo00?o0000ojbG`On/Ul40
0on/Ul400ol0003oYYS7ojJHa`03ojJHa`05o`000?nOV<goWiS=oinHcOl000001OnIT<T01?l0003o
Shk>ohn>c_n?S/h3o`0000;oQ8cC00Go0000ogJ8eomfR=OoMXSGo`000003ofJ3f`04o`000?mDO]ko
E7kNo`0000;o@GOO00Co0000obi`g_l^L=ko;W3N0olKJM`3o`aTf@;o000000?oH@00o`000?ooool0
9oooool2o`0000Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Oooooo000Zooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0=?ooool2o`0000;oPNSL0ol00002ol?[l006o`000?o8ingob>O]o`000?o;hnWo00000oo=gN@0
1?l0003oc]KOolkFgol00003olk?fP05o`000?o=b=GocLSEolg8eOl000000oo<`M000ol0003ob[_;
olZkb`02olZkb`03o`000?o8]<Oo000000;ocLCA1?o;^l/00ol0003ob;?6olRcaP03olRcaP03o`00
0?o5[L7oaJg100;oaJg100Co0000ol>W_Oo3Ykgo00000_o2Z/800ol0003o`:Bmol2T_@05ol2T_@04
o`000?nmY<3o0000o`0000Co_9nk00?o0000okVM_?niWK`01_niWK`00ol0003o]YZko`000007ok>L
_`03o`000?n/Ul7o[9O100?o[9O100?o0000ojJHaonVV<L01?nVV<L00ol0003oWiS=o`000002oj6B
a@GoVI390ol000000on?S/ko0000ohB<d`02ohB<d`05o`000?mfR=OoMXSGogJ8eol000000omVPm/0
0ol0003oE7kNoeAngP02o`0000;o@GOO00Co0000obi`g_l^L=ko00000olKJM`2o`aTf@06o`000?l1
H=Oo0000o`000?mQ003o00009oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01_ooool002[ooooo0_l0000Iooooo`03
o`000?oooooooooo037ooooo1Ol000000onnkO?o0000ol?[l002ol?[l006o`000?o8ingob>O]o`00
0?o;hnWo00000oo=gN@01Ol0003oc]KOolkFgoo>e]oo000000?oc/oJ00Go0000olg8eOo=b=GocLSE
o`000003olc1d005o`000?o:^l_ob[_;olZkbol000000oo8]<L2o`0000?obk_;00?o0000olRca_o8
/lH01?o8/lH01Ol0003oaJg1olF]`Oo5[L7o000000?o`jNm00?o0000ol:Z`_o2Z/801oo0Y;d2o`00
00Oo_9nk00?o0000okVM_?niWK`01OniWK`01?l0003o]YZkokJJ^onfV[/2o`0000Co/ibo00?o0000
ok2G_Ol000001On/Ul400ol0003oYYS7ojJHa`03ojJHa`;o00000onQT/D00ol0003oVI39o`000003
o`0000CoShk>00Go0000ohB<don4S=?oQ8cCo`000003ogJ8e`05o`000?mVPm_oIX?KofJ3fol00000
0_mDO]h01Ol0003o@GOOod5ggom1Mmoo000000;o;W3N00Co0000oa]Yg?lKJMco6fWL0_l<I=T00ol0
003o0F3Go`5Pe`03o`0002Oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool01Oooool002Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0^ooooo`Co00000onnkO<01Ol0003o`n_`ol?[l?o3jo3o000000;ob>O]00?o0000
ol_SjOl000001?o=gN@01?l0003oc]KOolkFgol00003olk?fP05o`000?o=b=GocLSEolg8eOl00000
0oo<`M000ol0003ob[_;olZkb`02olZkb`09o`000?o8]<Oob;C7olRdaol0003oaZo3o`000?o;^l_o
000000Kob;?600?o0000olF]`Oo5[L400_o5[L400ol0003o`jNmol>W_@02ol>W_@03o`000?o0Y;go
`:Bm00Go`:Bm00?o0000oknP^Ol000001onlWk/00ol0003o^IflokVM_005okVM_003o`000?nfV[_o
]YZk00?o]YZk00Co0000ok>L_oncW;oo00000on`Ukd00ol0003o[9O1ojbG`@03ojbG`@06o`000?nV
V<OoYYS7ojJHaol0003oYi;10onQT/D3o`0000CoVI3900Go0000ohn>c_n?S/koShk>o`000004ohB<
d`05o`000?mfR=OoMXSGogJ8eol000000omVPm/01?l0003oE7kNoeAng_l00003od5gg`04o`000?l^
L=ko;W3No`0000;o6fWL00Oo0000o`aTfOl<I=Wo0000o`5Peol0003o063F00?o00009_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06
ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02cooooo00Co0000okS^
mOnhk_Go00000onnkO<01Ol0003o`n_`ol?[l?o3jo3o000000;ob>O]00Co0000ol_SjOo;hnWo0000
0oo=gN@01?l0003oc]KOolkFgol00003olk?fP03o`000?o=b=GocLSE00;ocLSE00Co0000olc1d?o<
`M3o00001?o:^l/01Ol0003ob;C7olRdaoo8]<Oo000000?oaZo30_l00005olRcaP03o`000?o5[L7o
aJg100;oaJg100?o0000ol>W_Oo3Ykd00oo3Ykd00ol0003o`:Bmol2T_@04ol2T_@04o`000?noX;Wo
_j2io`0000Oo_9nk00?o0000okVM_?niWK`01OniWK`00ol0003o]YZkokJJ^`04okJJ^`03o`000?nc
W;oo000000Co/9Nm00?o0000ojbG`On/Ul400on/Ul400ol0003oYYS7o`000002ojNB`@?o00000_nQ
T/D00ol0003oVI39oiV@b@02oiV@b@03o`000?n?S/koShk>00;oShk>00Go0000ohB<don4S=?oQ8cC
o`000003ogJ8e`05o`000?mVPm_oIX?KofJ3fol000000omDO]h01?l0003o@GOOod5ggol00003obi`
gP04o`000?lKJMco6fWLo`0000;o36CI00?o0000o`5Peol000000_l0H=H00ol0003oH@00o`00000T
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01oooool002Wooooo0ol0000Looooo`03o`000?oooooooooo02[ooooo00Co
0000okS^mOnhk_Go00000onnkO<01Ol0003o`n_`ol?[l?o3jo3o000000;ob>O]00Co0000ol_SjOo;
hnWo00000oo=gN@01Ol0003oc]KOolkFgoo>e]oo000000;oc/oJ00?o0000olg8eOo=b=D00_o=b=D0
1Ol0003oc<7@olc1d?o<`M3o000000?ob[_;00?o0000olRdaoo8]<L00_o8]<L01ol0003oaZo3olJ_
`oo6[l?o0000olBZ_ol000000oo8/lH00ol0003oaJg1olF]`@02olF]`@03o`000?o3Ykgo`jNm00?o
`jNm00?o0000ol6R^_l000000oo0Y;d2o`0000?o_j2i00?o0000okbO^onlWk/01OnlWk/00ol0003o
^IflokVM_004okVM_003o`000?nfV[_o]YZk00Ko]YZk00?o0000ok2G_On`Ukd01?n`Ukd00ol0003o
[9O1ojbG`@03ojbG`@Co000000?oYi;1o`000?nQT/D00onQT/D00ol0003oVI39oiV@b@02oiV@b@05
o`000?n?S/koShk>ohn>c_l000001?n4S=<01Ol0003oMXSGogJ8eomfR=Oo000000?oIX?K00Co0000
oeAng_mDO]ko00000om1Mml01?l0003o;W3Nobi`g_l00003oa]Yg009o`000?l<I=Wo36CIo`000?l1
H=Oo0000o`1Pe_l0003o06;F00;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo02Sooooo00Co0000okS^mOnhk_Go00000onnkO<01Ol0003o`n_`ol?[
l?o3jo3o000000;ob>O]00Co0000ol_SjOo;hnWo00000oo=gN@01Ol0003oc]KOolkFgoo>e]oo0000
00?oc/oJ00Go0000olg8eOo=b=GocLSEo`000003olc1d003o`000?o:^l_ob[_;00;ob[_;00Go0000
olRdaoo8]<Oob;C7o`000003olJ_``07o`000?o4Z[ooa:ZoolBZ_ol0003ob;?6o`000004olF]`@03
o`000?o3Ykgo`jNm00?o`jNm00Co0000ol6R^_o1X[[o00000_o0Y;d00ol0003o_j2ioknP^@04oknP
^@03o`000?nlWk_o_9nk00;o_9nk2_l00008okJJ^`03o`000?n`Ukgo/9Nm00Co/9Nm00Co0000ojbG
`On/Ul7o[9O10ol00005ojNB`@05o`000?nQT/GoXI;5oj6BaOl000001OnIT<T01Ol0003oShk>ohn>
c_n?S/ko000000?oQ8cC00Go0000ogJ8eomfR=OoMXSGo`000003ofJ3f`05o`000?mDO]koE7kNoeAn
g_l000000om1Mml01?l0003o;W3Nobi`g_l00003oa]Yg008o`000?l<I=Wo36CIo`000?l1H=Oo0000
o`1Pe_l00002o`1ReP03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02Kooooo00Co0000okS^mOnhk_Go00000onnkO<01Ol0003o`n_`ol?[l?o3jo3o
000000;ob>O]00Co0000ol_SjOo;hnWo00000oo=gN@01Ol0003oc]KOolkFgoo>e]oo000000?oc/oJ
00?o0000olg8eOo=b=D00_o=b=D01Ol0003oc<7@olc1d?o<`M3o000000?ob[_;00?o0000olRdaoo8
]<L00_o8]<L01Ol0003oaZo3olJ_`oo6[l?o000000Coa:Zo00?o0000olF]`Oo5[L400oo5[L400ol0
003o`jNmol>W_@02ol>W_@07o`000?o1X[[o`J:jol6R^_l0003o`:Bmo`000007oknP^@03o`000?nl
Wk_o000000;o00000_nlW;P00ol0003o^YZhokZJ^004okZJ^003o`000?ngV;So000000Go]YZk00?o
0000ok>F^Ol000001_n`Ukd3o`000004ojbG`Ol0003o[9>mo`0000CoYi;100?o0000oj6BaOnQT/D0
0_nQT/D00ol0003oVI39oiV@b@02oiV@b@05o`000?n?S/koShk>ohn>c_l000001?n4S=<01Ol0003o
MXSGogJ8eomfR=Oo000000?oIX?K00?o0000oeAng_mDO]h00_l00002od5gg`05o`000?l^L=ko;W3N
obi`g_l000000olKJM`00ol0003o36CIo`000002o`5Pe`03o`000?l0H=Ko000000;o06;F00?o0000
ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02Cooooo00Co0000okS^mOnhk_Go00000onnkO<01Ol0003o`n_`ol?[l?o3jo3o0000
00;ob>O]00Go0000ol_SjOo;hnWobn?Yo`000003olgMi004o`000?o>e]ooc]KOo`0000?oc/oJ00?o
0000olg8eOo=b=D00_o=b=D01Ol0003oc<7@olc1d?o<`M3o000000Cob[_;00Go0000olRdaoo8]<Oo
b;C7o`000003olJ_``03o`000?o4Z[ooa:Zo00?oa:Zo0_l00003olF]`@03o`000?o3Ykgo`jNm00;o
`jNm00?o0000ol6R^_o1X[X00oo1X[X00ol0003o_j2ioknP^@05oknP^@?o00001OnlW;P00ol0003o
^YZhokZJ^004okZJ^003o`000?ngV;So]iRh00;o00000onfV[/01?l0003o/iJiok>F^Ol00002ok2G
_@?o000000Co/9Nmo`000?n/Ul7o00000_n/Tkd00ol0003oYi;1ojNB`@03ojNB`@03o`000?nQT/Go
XI;500;oXI;500?o0000oiV@bOnIT<T00_nIT<T01Ol0003oShk>ohn>c_n?S/ko000000?oQ8cC00?o
0000ogJ8eomfR=L00_mfR=L01Ol0003oIX?KofJ3fomVPm_o000000;oE7kN0_l00002od5gg`04o`00
0?l^L=ko;W3No`0000?o6fWL00Co0000o`aTfOl<I=Wo00000_l1H=L00ol0003o063Fo`000002o`1R
eP03o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool000Kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool00oooool3o`00027ooooo00?o0000ooooooooool08_ooool01?l0003o^>keokS^mOl0
0003okk]l`05o`000?o3jo3o`n_`ol?[l?l000000oo8ind01?l0003obn?Yol_SjOl00003olgMi005
o`000?o>e]ooc]KOolkFgol000000oo>cmX00ol0003ocLSEolg8e@02olg8e@04o`000?o<`M3oc<7@
o`0000Cob[_;00?o0000olRdaoo8]<L00_o8]<L01Ol0003oaZo3olJ_`oo6[l?o000000Coa:Zo00Ko
0000ol>V_?o3Y[co0000olF]`Ol00005ol>W_@03o`000?o1X[[o`J:j00?o`J:j00?o0000oknP^Ono
X;T01?noX;T00ol0003o_Ibgo`000006okbL^003o`000?njV[So^YZh00Co^YZh00?o0000okNH^?ng
V;P00_ngV;P01?l0003o]YZkokJJ^ol00003ok>F^@;o00001On`Ukd00ol0003o[9>mojbC_@02ojbC
_@03o`000?nWT/7oYi;100;oYi;100?o0000oj6BaOnQT/D00_nQT/D00ol0003oVI39oiV@b@02oiV@
b@03o`000?n?S/koShk>00;oShk>00Go0000ohB<don4S=?oQ8cCo`000003ogJ8e`05o`000?mVPm_o
IX?KofJ3fol000000omDO]h01Ol0003o@GOOod5ggom1Mmoo000000;o;W3N00Go0000oa]Yg?lKJMco
6fWLo`000002o`aTf@06o`000?l1H=Oo0F3Go`000?l0H=Ko00000_l0H]H00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01oooooo0_l00002okS^m@05o`000?nnkO?o_^gcokk]lol000001?o3
jo001?l0003ob>O]olSWkOl00002ol_Sj@05o`000?o=gNCocMgTolgMi?l000000oo>e]l01Ol0003o
c/oJolk?f_o>cm[o000000CocLSE00Go0000olc1d?o<`M3oc<7@o`000003olZkb`03o`000?o8]<Oo
b;C700;ob;C700Go0000olJ_`oo6[l?oaZo3o`000005olBZ_`05o`000?o3Y[co`jJlol>V_?l00000
1Oo3Ykd00ol0003o`J:jol6R^P03ol6R^P03o`000?noWkOo000000?o_j2i0_l00002okfL]`03o`00
0?nlW;So_9bh00Co_9bh00?o0000okZJ^?njV[P00onjV[P00ol0003o]iRhokNH^004okNH^0;o0000
00Ko/iJio`000?l0003o0000ok>F^Ol00005ok2G_@03o`000?n/Tkgo[9>m00;o[9>m00?o0000ojNB
`OnWT/400onWT/400ol0003oXI;5oj6Ba@02oj6Ba@03o`000?nIT<WoVI3900;oVI3900Go0000ohn>
c_n?S/koShk>o`000003ohB<d`03o`000?mfR=OoMXSG00;oMXSG00Go0000ofJ3fomVPm_oIX?Ko`00
0002oeAngP;o00000om1Mml01?l0003o;W3Nobi`g_l00003oa]Yg004o`000?l<I=Wo36CIo`0000;o
0F3G00?o0000o`1Pe_l000000_l0H]H00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`05
o`000?nhk_Go^>keokS^mOl000000onnkO<00ol0003o`n_`ol?[l002ol?[l004o`000?o8ingob>O]
o`0000;obn?Y00Go0000olgMi?o=gNCocMgTo`000003olkFg`05o`000?o>cm[oc/oJolk?f_l00000
1?o=b=D01Ol0003oc<7@olc1d?o<`M3o000000Cob[_;00Go0000olRdaoo8]<Oob;C7o`000004olJ_
``03o`000?o4Z[ooa:Zo00;oa:Zo00?o0000ol>V_?o3Y[`00_o3Y[`2o`0000?o`jNm00?o0000ol6R
^_o1X[X00oo1X[X01?l0003o_ingoknO]ol00002oknP^@03o`000?nmW;Oo_Ibg00;o_Ibg00?o0000
okbL^?nlW;P01?nlW;P00ol0003o^YZhokZJ^003okZJ^003o`000?ngV;So]iRh00Co]iRh0ol00005
ok>F^@07o`000?n`Ukgo/9Nmok2G_Ol0003o/9Bjo`000004ojbC_@03o`000?nWT/7oYi;100;oYi;1
00?o0000oj6BaOnQT/D00_nQT/D00ol0003oVI39oiV@b@02oiV@b@03o`000?n?S/koShk>01Co0000
0_m1Mml01Ol0003o;W3Nobi`g_l^L=ko000000?o6fWL00Ko0000o`aTfOl<I=Wo0000o`5Peol00002
o`1PeP04o`000?l0H]Ko06;Fo`0002;ooooo0_l0000Mooooo`001_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool09?ooool2o`0001cooooo00Go0000okS^mOnhk_Go^>keo`000003okk]l`03
o`000?o3jo3o`n_`00;o`n_`00Co0000olSWkOo8ingo00000oo;hnT4olgMi005o`000?o>e]ooc]KO
olkFgol000000_o>cmX00ol0003ocLSEolg8e@03olg8e@05o`000?o<`M3oc<7@olc1d?l000000oo:
^l/00ol0003ob;C7olRda`02olRda`05o`000?o6[l?oaZo3olJ_`ol000001Oo4Z[l01Ol0003o`jJl
ol>V_?o3Y[co000000;o`J:j00?o0000ol>W_Ol000001Oo1X[X01ol0003o_ingoknO]onoWkOo0000
oknP^Ol000001_nmW;L00ol0003o_9bhokbL^003okbL^003o`000?njV[So^YZh00?o^YZh00Co0000
okNH^?ngV;So]iRh0ol000000ongV;So0000ok>F^@06ok>F^@03o`000?n`Ukgo000000;o/9Bj00?o
0000ojbC_On/Tkd00on/Tkd00ol0003oYi;1ojNB`@02ojNB`@03o`000?nQT/GoXI;500;oXI;500Co
0000oiV@bOnIT<WoVI390ol00002oib>a@CoUHg81On>Rl`4ohJ9c`?oOHOB1_l00002obi`gP05o`00
0?lKJMco6fWLoa]Yg?l000000_l<I=T01?l0003o0F3Go`5Peol00002o`1PeP04o`000?l0H]Ko06;F
o`00023ooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0002Oooooo00?o0000
ooooooooool06?ooool00ol0003o^>keokS^m@02okS^m@?o_^gc00?o0000ol?[l?o3jo000_o3jo00
1?l0003ob>O]olSWkOl00003ol_Sj@05o`000?o=gNCocMgTolgMi?l000000oo>e]l01Ol0003oc/oJ
olk?f_o>cm[o000000CocLSE00Go0000olc1d?o<`M3oc<7@o`000004olZkb`05o`000?o8]<Oob;C7
olRdaol000001?o6[l<00ol0003oa:ZoolBZ_`02olBZ_`03o`000?o3Y[co`jJl00;o`jJl00Go0000
ol6R^_o1X[[o`J:jo`000005ol6R^P03o`000?noWkOo_ing00?o_ing00?o0000okfL]onmW;L01Onm
W;L00ol0003o_9bhokbL^002okbL^0_o00000ongV;P00ol0003o]YJfo`000007ok>F^@03o`000?n`
U;[o/9Bj00;o/9Bj00?o0000ojbC_On/Tkd00_n/Tkd00ol0003oYi;1ojNB`@02ojNB`@03o`000?nQ
T/GoXI;500;oXI;500Go0000oiV@bOl0003o0000oj:?`P04oib>a@05o`000?nESLSoUHg8oiF=b?l0
00001?n>Rl`01Ol0003oQXW?ohJ9con6RLoo000000?oOHOB00CoM8GFo`000?mdQMKoM8GF1Ol00003
oa]Yg004o`000?l<I=Wo36CIo`0000;o0F3G00Co0000o`1Pe_l0H=Ko00000_l0H]H00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01Kooooo00?o0000okS^mOnhk_D00_nhk_D4okk]l`Co
`n_`00Co0000olSWkOo8ingo00000oo;hnT01Ol0003ocMgTolgMi?o=gNCo000000?oc]KO00Go0000
olk?f_o>cm[oc/oJo`000005olg8e@04o`000?o<`M3oc<7@o`0000Cob[_;00?o0000olRdaoo8]<L0
0_o8]<L01Ol0003oaZo3olJ_`oo6[l?o000000Goa:Zo00Go0000ol>V_?o3Y[co`jJlo`000004ol6R
^P03o`000?o1X[[o`J:j00?o`J:j00?o0000oknO]onoWkL00onoWkL00ol0003o_IbgokfL]`05okfL
]`03o`000?nlW;So000000;o000000?o^iVeo`000?njV;D00_njV;D3o`000003okVG]Ol0003o]iRh
00?o]iRh00Co0000okJF]_nfU[Ko00001_ncU[T00ol0003o/9Bjok2D^P02ok2D^P03o`000?n/Tkgo
[9>m00?o[9>m00?o0000ojNB`OnWT/400_nWT/401?l0003oXI;5oj6BaOnQT/D2o`0000?oXXo200?o
0000oib>aOnLS/D00_nLS/D4oiF=b0GoSX_<1?n6RLl4ogf7dP04ogB5e_l0003oM8GFogB5eP?oJhCI
1_l00002o`aTf@04o`000?l1H=Oo0F3Go`0000;o063F00Co0000o`1Re_l0H]Ko00008Oooool00ol0
003oooooooooo`0Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Cooooo00?o0000okS^mOnhk_D00_nhk_D4okk]l`Co`n_`00Co0000olSWkOo8ingob>O]1?o;
hnT00oo=gNCo0000o`00000<o`0000;ocLSE00Go0000olc1d?o<`M3oc<7@o`000003olZkb`03o`00
0?o8]<Oob;C700;ob;C700?o0000olJ_`oo6[l<00_o6[l<00ol0003oa:ZoolBZ_`02olBZ_`03o`00
0?o3Y[co`jJl00;o`jJl00Oo0000ol6R^_o1X[[o`J:jo`000?noWkOo000000?o`J:j00?o0000oknO
]onoWkL00onoWkL00ol0003o_Y^eo`000005okfL]`?o00001?nkVKD4o`0000;o^YRe00Co0000okVG
]OniUkGo00000_ngV;P00ol0003o]YJfokJF]P02okJF]P03o`000?ncU[Wo/iJi00;o/iJi00?o0000
ok>D]ol000001?n`U;X00ol0003o[9>mojbC_@02ojbC_@03o`000?nWT/7oYi;100;oYi;100Go0000
oj6BaOl0003o0000ojJA_P05oj:?`PCoW8k500Go0000oiF=b?nESLSoUHg8o`000004ohj;c005o`00
0?n6RLooQXW?ohJ9col000000ommQm800ol0003oM8GFo`000002ogB5eP?oJhCI1?mSP]`3o`000005
o`aTfOl0003o0F3Go`5Peol000000_l0H=H01?l0003o06;Fo`1Re_l0000Pooooo`03o`000?oooooo
oooo01[ooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04_ooool00ol0
003o^>keokS^m@02okS^m@Co_^gc1Oo3jo09o`0000;o`;kH00Go0000ol6je?o1^]Co`K[Do`000003
ol6fc`04o`000?o1//_o`K;;ol6bb`So00000_o:^l/00ol0003ob;C7olRda`02olRda`05o`000?o6
[l?oaZo3olJ_`ol000001?o4Z[l00ol0003o`jJlol>V_002ol>V_003o`000?o1X[[o`J:j00;o`J:j
00Ko0000oknO]onoWkOo0000ol6R^_l00006oknO]`03o`000?nnVkGo000000Co_Ibg00?o0000okbI
]?l000000onkVKD3o`0000Go^YRe00Oo0000okVG]OniUkGo^INeo`000?ngV;So000000Co]YJf00Go
0000ok>F^OncU[Wo/iJio`000002ok>D]`03o`000?n`U;[o/9Bj00;o/9Bj00?o0000ojbC_On/Tkd0
0on/Tkd01?l0003oYi;1ojNB`OnWT/42o`0000?oYY6n00?o0000oj:?`_nRSl800_nRSl801Ol0003o
W8k5oib>aOnLS/Go000000?oUHg800?o0000ohj;c?n>Rl`00_n>Rl`01Ol0003oQXW?ohJ9con6RLoo
000000?oOHOB00?o0000ogB5e_l000000_mdQMH4of^4f@CoHh;L0_mJPMh3o`0000;o0F3G00Co0000
o`1Pe_l0H=Ko00000_l0H]H00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Wooooo000W
ooooo`;o0000;?ooool00ol0003oooooooooo`0@ooooo`03o`000?nhk_Go^>ke00;o^>ke00?o_^gc
o`000?l000001ol00002okg7hP05o`000?no`mgo_l?Moko3gOl000000oo0_]P01Ol0003o`K[Dol6j
e?o1^]Co000000?o`KK?00?o0000ol6bboo1///00oo1///01Ol0003o`Jk7ol6^aoo1[/Oo000000;o
`:[40ol00003olRda`03o`000?o6[l?oaZo300;oaZo300?o0000olBZ_oo4Z[l00_o4Z[l00ol0003o
`jJlol>V_002ol>V_005o`000?o1X[[o`J:jol6R^_l000001?noWkL00ol0003o_ingoknO]`04oknO
]`05o`000?nnVkGo_Y^eokjK]Ol000000_nmW;L00ol0003o_9VdokbI]004o`0000;o^iVe00?o0000
okZH]OnjV;D00onjV;D00ol0003o^INeokVG]@02okVG]@03o`000?nfU[Ko]YJf00Co]YJf00?o0000
ok>F^Ol000001?ncU;L00ol0003o/9Bjok2D^P02ok2D^P03o`000?n/Tkgo[9>m00;o[9>m00Go0000
ojNB`Ol0003o0000oj^A_005ojJA_PCoXXo200Go0000oib>aOnLS/GoW8k5o`000004oiF=b003o`00
0?n>RlcoSX_<00;oSX_<00Go0000ohJ9con6RLooQXW?o`000003ogf7dP05o`000?mdQMKo0000ogB5
e_l000000om[Q=T00ol0003oHh;Lof>2g002of>2g0CoFX7N1?l00002o`1PeP04o`000?l0H]Ko06;F
o`00023ooooo00?o0000ooooooooool06?ooool002Oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0>ooooo`Oo00000_nhc^/00ol0003o^l_Vok_;iP02ok_;iP04o`000?nman;o_LOR
o`0000?o_l?M00?o0000ol2nf?o0_]P00_o0_]P01Ol0003o`K[Dol6je?o1^]Co000000?o`KK?00?o
0000ol6bboo1///00_o1///01Ol0003o`Jk7ol6^aoo1[/Oo000000Co`:[400Ko0000oknW`Ol0003o
0000olRdaol00003olJ_``03o`000?o4Z[ooa:Zo00;oa:Zo00?o0000ol>V_?o3Y[`00_o3Y[`00ol0
003o`J:jol6R^P02ol6R^P03o`000?noWkOo_ing00;o_ing00?o0000oknO]onoWkL00onoWkL00ol0
003o_Y^eokjK]@02okjK]@04o`000?nmW;Oo0000okbI]0?o00001OnkVKD00ol0003o^YReokZH]@02
okZH]@03o`000?niUkGo^INe00?o^INe00?o0000okJF]_nfU[H01OnfU[H00ol0003o/iBgok>D]`03
ok>D]`03o`000?n`U;[o/9Bj00;o/9Bj00?o0000ojbC_On/Tkd00_n/Tkd2o`0000?oZi6l00?o0000
ojJA__nVTKh00_nVTKh01Ol0003oXXo2oj:?`_nRSl;o000000CoW8k500Go0000oiF=b?nESLSoUHg8
o`000004ohj;c005o`000?n6RLooQXW?ohJ9col000000ommQm801Ol0003oM8GFogB5e_l0003oM8GF
00?oJhCI00?o0000of>2g?mSP]`00_mSP]`01?l0003oFX7NoeZ1g_mJPMh3oe>1h@?o000000Go063F
o`000?l0H]Ko06;Fo`00000Nooooo`;o00006_ooool002Oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0=ooooo`05o`000?nddNoo]=7_okCAkol000000onhc^/00ol0003o^l_Vok_;
iP02ok_;iP05o`000?nman;o_LORokg7h_l000000ono`md00ol0003o`;kHol2nf002ol2nf005o`00
0?o1^]Co`K[Dol6je?l000000oo1]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1[/Oo`Jk7ol6^
aol000001?o0Z/@01?l0003o_jO1oknW`OnoYl43o`0000;oaZo300?o0000olBZ_oo4Z[l00_o4Z[l0
0ol0003o`jJlol>V_002ol>V_003o`000?o1X[[o`J:j00;o`J:j00Oo0000oknO]onoWkOo_ingo`00
0?nnW;Ko000000Co_ing00?o0000okjK]OnnVkD00onnVkD3o`0000?o_9Vd00?o0000ok^I]OnkVKD0
0_nkVKD00ol0003o^YReokZH]@02okZH]@03o`000?niUkGo^INe00?o^INe0_l00006okJF]P03o`00
0?ncU;Oo/iBg00Co/iBg00?o0000ok2D^_n`U;X00_n`U;X01Ol0003o[9>mojbC_Ol0003o[Y:i00Go
Zi6l1?nVTKh00ol0003oXXo2oj:?`P02oj:?`P05o`000?nLS/GoW8k5oib>aOl000000onESLP00ol0
003oSX_<ohj;c002ohj;c005o`000?n6RLooQXW?ohJ9col000000ommQm801?l0003oM8GFogB5e_md
QMH2o`0000?oJhCI00Go0000of>2g?mSP]coHh;Lo`000004oeZ1gP?oDh7Q0_m>P^@3o`0000;o06;F
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Gooooo`009oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00_ooooo00Go0000okCAkonddNoo]=7_o`000004okS>j`03o`00
0?nkbnKo^l_V00;o^l_V00Co0000okg7h_nman;o00001?no`md01Ol0003o`;kHol2nf?o0_]So0000
00?o`K[D00Go0000ol6fcoo1]/oo`KK?o`000005ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000000oo0
Z/@00ol0003o_jO1oknW`@02oknW`@03o`000?noY;ko_jBn00?o00000oo4Z[l00ol0003o`jJlol>V
_002ol>V_003o`000?o1X[[o`J:j00;o`J:j00?o0000oknO]onoWkL00_noWkL01?l0003o_YbfokjL
]_l00002oknO]`04o`000?nnVkGo_Y^eokjK]@Co00001OnlVK@01?l0003o^iVeok^I]OnkVKD5o`00
0003okZH]Ol0003o^INe00?o^INe00Co0000okRE]?nhUKCo00001?nfU[H00ol0003o]IBeo`000005
ok>D]`03o`000?n`U;[o/9Bj00;o/9Bj00?o0000ojbC_Ol000000_n^T[T00ol0003oZi6loj^A_002
oj^A_005o`000?nVTKkoYY6nojJA__l000001?nRSl801Ol0003oW8k5oib>aOnLS/Go000000CoUHg8
00?o0000ohj;c?n>Rl`00_n>Rl`01Ol0003oQXW?ohJ9con6RLoo000000?oOHOB00?o0000ogB5e_md
QMH00_l00003of^4f@03o`000?mSP]coHh;L00;oHh;L00Go0000oeZ1g_mJPMkoFX7No`000003oe>1
h@CoCX;T0_l000000ol0H]Ko0000ooooo`0Nooooo`03o`000?oooooooooo01Kooooo000Wooooo`;o
0000<?ooool00ol0003oooooooooo`0:ooooo`05o`000?nddNoo]=7_okCAkol000000onhc^/00ol0
003o^l_Vok_;iP02ok_;iP05o`000?nman;o_LORokg7h_l000000ono`md00ol0003o`;kHol2nf002
ol2nf005o`000?o1^]Co`K[Dol6je?l000000oo1]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1
[/Oo`Jk7ol6^aol000001?o0Z/@00ol0003o_jO1oknW`@02oknW`@06o`000?noY;ko_jBnoknT__l0
003o_Z6k0_l000000oo4Z[oo0000ol>V_003ol>V_003o`000?o1X[[o`J:j00;o`J:j00?o0000oknO
]onoWkL00_noWkL01_l0003o_YbfokjL]_nnW;Ko0000oknO]`Co00000_nnVkD2o`0000Go_9Vd1?l0
00000onkUk?o0000okZG/`02okZG/`?o00000oniUkD01Ol0003o^9FdokRE]?nhUKCo000000;o]YJf
00Co0000okFD]OneU;Go00001OncU;L00ol0003o/9Bjok2D^P02ok2D^P;o00001?n^T[T4oj^A_003
o`000?nVTKkoYY6n00;oYY6n00Go0000oj:?`_nRSl;oXXo2o`000004oib>a@05o`000?nESLSoUHg8
oiF=b?l000001?n>Rl`01Ol0003oQXW?ohJ9con6RLoo000000?oOHOB00Co0000ogB5e_mdQMKoM8GF
0_l00002of^4f@03o`000?mSP]coHh;L00;oHh;L00Go0000oeZ1g_mJPMkoFX7No`000003oe>1h@04
o`000?m>P^CoCX;Todj2i0;oBhGV0ol0000Nooooo`03o`000?oooooooooo01Kooooo000Vooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool01Ol0003o]=7_okCAkonddNoo0000
00Co^<k[00?o0000ok_;i_nkbnH00_nkbnH01?l0003o_LORokg7h_l00004oko3g@05o`000?o0_]So
`;kHol2nf?l000001?o1^]@01Ol0003o`KK?ol6fcoo1]/oo000000Co`K;;00Go0000ol6^aoo1[/Oo
`Jk7o`000004ol2Za005o`000?noYl7o_jO1oknW`Ol000001?noY;h01?l0003o_Z6kokjQ^onnXK/2
o`0000?o`jJl00?o0000ol6R^_o1X[X00_o1X[X00ol0003o_ingoknO]`02oknO]`03o`000?nnW;Ko
_Ybf00?o_Ybf0_l00004okjK]@04o`000?nmVK?o_IVco`0000Co_9Vd00?o0000ok^G/onkUk<00_nk
Uk<00ol0003o^YNcokZG/`02okZG/`03o`000?niU[?o000000;o^INe00?o0000okRE]?nhUK@00_nh
UK@00ol0003o]YJfo`000003okFD]@03o`000?ncU;Oo/iBg00?o/iBg00Go0000ok2D^_n`U;[o0000
ok6C]`05ojjB^@05o`000?n[TKcoZi6loj^A_?l000001?nVTKh00ol0003oXXo2oj:?`P02oj:?`P05
o`000?nLS/GoW8k5oib>aOl000000onESLP00ol0003oSX_<ohj;c002ohj;c005o`000?n6RLooQXW?
ohJ9col000001?mmQm801Ol0003oM8GFogB5e_mdQMKo000000?oJhCI00Go0000of>2g?mSP]coHh;L
o`000004oeZ1gP04o`000?mCPN7oDh7Qoe>1h@CoCX;T1?m;QNH00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Gooooo000Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1oooool01Ol0003o]=7_okCAkonddNoo000000?o^<k[00?o0000ok_;i_nkbnH00_nkbnH01Ol0003o
_LORokg7h_nman;o000000?o_l?M00?o0000ol2nf?o0_]P00_o0_]P01Ol0003o`K[Dol6je?o1^]Co
000000?o`KK?00?o0000ol6bboo1///00oo1///01Ol0003o`Jk7ol6^aoo1[/Oo000000?o`:[400?o
0000oknW`OnoYl400_noYl401Ol0003o_jBnoknT__noY;ko000000Co_Z6k00Ko0000okfO^Ol0003o
0000ol>V_?l00004ol6R^P03o`000?noWkOo_ing00;o_ing00?o0000okjL]_nnW;H01?l00005okjK
]@04o`000?nmVK?o_IVco`0000?o_9Vd0_l00004ok^G/`03o`000?njUk?o^YNc00;o^YNc00?o0000
okVF/oniU[<00_l00006okRE]003o`000?neU;Go]IBe00?o]IBe00?o0000ok>D]oncU;L00_ncU;L0
0ol0003o/9Bjo`000002ok6C]`03o`000?n^T[Wo[Y:i00;o[Y:i00?o0000oj^A_?n[TK`00_n[TK`0
1Ol0003oYY6nojJA__nVTKko000000CoXXo200Go0000oib>aOnLS/GoW8k5o`000004oiF=b003o`00
0?n>RlcoSX_<00;oSX_<00Co0000ohJ9con6RLoo00001?mmQm800ol0003oM8GFogB5eP02ogB5eP04
o`000?m[Q=WoJhCIo`0000CoHh;L00Go0000oeZ1g_mJPMkoFX7No`000003oe>1h@05o`000?m>P^Co
CX;Todj2i?l000000om;QNH00ol0003oooooooooo`0Looooo`;o00005_ooool002Kooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?nddNoo]=7_okCAkol000001?nh
c^/00ol0003o^l_Vok_;iP02ok_;iP04o`000?nman;o_LORo`0000Co_l?M00?o0000ol2nf?o0_]P0
0_o0_]P01Ol0003o`K[Dol6je?o1^]Co000000?o`KK?00?o0000ol6bboo1///00_o1///01Ol0003o
`Jk7ol6^aoo1[/Oo000000Co`:[400?o0000oknW`OnoYl400_noYl401Ol0003o_jBnoknT__noY;ko
000000Co_Z6k00Co0000okfO^OnmWkWo_Ini0_l00003ol6R^P03o`000?noWkOo_ing00;o_ing1?l0
0002okjL]P03o`000?nmV[Co000000?o_Y^e00Go0000okfI/onmVK?o_IVco`000002okbI]003o`00
0?nkUk;o000000Co^iNc00Go0000okZG/onjUk?o^YNco`000004okVF/`03o`000?nhUKCo^9Fd00Co
^9Fd00?o0000okFD]OneU;D00oneU;D00ol0003o/iBgok>D]`02ok>D]`;o00001?naTkL01Ol0003o
[Y:iojjB^On^T[Wo000000CoZi6l00Go0000ojJA__nVTKkoYY6no`000004oj:?`P05o`000?nLS/Go
W8k5oib>aOl000001?nESLP00ol0003oSX_<ohj;c002ohj;c005o`000?n6RLooQXW?ohJ9col00000
0ommQm800ol0003oM8GFogB5eP02ogB5eP05o`000?m[Q=WoJhCIof^4fOl000000omSP]`00ol0003o
FX7NoeZ1gP02oeZ1gP04o`000?mCPN7oDh7Qo`0000CoCX;T1?m;QNH00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?ooool00ol0003oooooooooo`04ooooo`05
o`000?nddNoo]=7_okCAkol000000onhc^/00ol0003o^l_Vok_;iP02ok_;iP05o`000?nman;o_LOR
okg7h_l000000ono`md00ol0003o`;kHol2nf002ol2nf005o`000?o1^]Co`K[Dol6je?l000001?o1
]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000001?o0Z/@01Ol0003o_jO1
oknW`OnoYl7o000000Co_jBn00Go0000okjQ^onnXK_o_Z6ko`000004okfO^@03o`000?nmWKOo0000
00;o`J:j00?o0000oknO]onoWkL00ol00005okjL]P04o`000?nmV[Co_IZdo`0000;o_Y^e00?o0000
okfI/onmVK<00_nmVK<2o`0000;o^iNb00?o0000ok^G/onkUk<00_nkUk<01Ol0003o^YNcokZG/onj
Uk?o000000Co^IJc00?o0000okRE]?nhUK@00onhUK@00ol0003o]iBco`000005okFD]@05o`000?nc
U;Oo/iBgo`000?ndTkD01OnaTkL00ol0003o[Y:iojjB^@02ojjB^@05o`000?n[TKcoZi6loj^A_?l0
00000onVTKh00ol0003oXXo2oj:?`P02oj:?`P03o`000?nLS/GoW8k500;oW8k500Go0000oiF=b?nE
SLSoUHg8o`000004ohj;c005o`000?n6RLooQXW?ohJ9col000001?mmQm801?l0003oM8GFogB5e_md
QMH2o`0000;oJhCI00?o0000of>2g?mSP]`00_mSP]`01Ol0003oFX7NoeZ1g_mJPMko000000?oDh7Q
00Go0000odj2i?m>P^CoCX;To`000003od^5iP03o`000?oooooooooo01gooooo00?o0000oooooooo
ool04oooool002Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`05o`00
0?nddNoo]=7_okCAkol000001?nhc^/00ol0003o^l_Vok_;iP02ok_;iP04o`000?nman;o_LORo`00
00Co_l?M00?o0000ol2nf?o0_]P00_o0_]P01Ol0003o`K[Dol6je?o1^]Co000000?o`KK?00?o0000
ol6bboo1///00oo1///01Ol0003o`Jk7ol6^aoo1[/Oo000000?o`:[400?o0000oknW`OnoYl400_no
Yl400ol0003o_jBnoknT_P02oknT_P05o`000?nnXK_o_Z6kokjQ^ol000001?nmWkT01Ol0003o_Ifg
okfM]ol0003o`J:j00?o000000?o_ingo`000?nnW;H01?nnW;H01ol0003o_IZdokfJ]?nmV[Co0000
okjK]Ol000001OnmVK<01Ol0003o^iNbok^G/_nkUk;o000000Co^iNc00Go0000okZG/onjUk?o^YNc
o`000004okVF/`;o00001?nhUK@00ol0003o]iBco`000005okFD]@03o`000?ncU;Oo000000;o]9>e
00?o0000ok6C]onaTkL00_naTkL00ol0003o[Y:iojjB^@02ojjB^@05o`000?n[TKcoZi6loj^A_?l0
00001?nVTKh00ol0003oXXo2oj:?`P02oj:?`P05o`000?nLS/GoW8k5oib>aOl000001?nESLP00ol0
003oSX_<ohj;c002ohj;c004o`000?n6RLooQXW?o`0000CoOHOB00?o0000ogB5e_mdQMH00_mdQMH2
o`000003of^4fOl0003oHh;L00?oHh;L00Go0000oeZ1g_mJPMkoFX7No`000003oe>1h@05o`000?m>
P^CoCX;Todj2i?l000000om;QNH00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo
000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0fooooo`04o`00
0?ooooooooooo`0000?o]=7_00?o0000okS>jonhc^/00_nhc^/00ol0003o^l_Vok_;iP02ok_;iP05
o`000?nman;o_LORokg7h_l000001?no`md01Ol0003o`;kHol2nf?o0_]So000000Co`K[D00Go0000
ol6fcoo1]/oo`KK?o`000004ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000001?o0Z/@00ol0003o_jO1
oknW`@02oknW`@05o`000?noY;ko_jBnoknT__l000001?nnXK/01Ol0003o_IniokfO^OnmWkWo0000
00;o_Ifg1?l00003oknO]`03o`000?nnW;Ko_Ybf00?o_Ybf00?o0000okfJ]?nmV[@00_nmV[@00ol0
003o_IVcokfI/`04okfI/`03o`000?nkUk;o^iNb00;o^iNb00Go0000ok^G/onkUk?o^iNco`000003
okZG/`05o`000?niU[?o^IJcokVF/ol000000_niUK801?l0003o^9FdokRE]?l00003okND/`03o`00
0?neU;Go]IBe00?o]IBe00?o0000okBC]OndTkD00_ndTkD01Ol0003o/I>gok6C]onaTkOo000000Co
[Y:i00?o0000oj^A_?n[TK`00_n[TK`01Ol0003oYY6nojJA__nVTKko000000CoXXo200Go0000oib>
aOnLS/GoW8k5o`000004oiF=b003o`000?n>RlcoSX_<00;oSX_<00Go0000ohJ9con6RLooQXW?o`00
0003ogf7dP03o`000?mdQMKoM8GF00;oM8GF00Go0000of^4fOl0003oJhCIo`000003of>2g003o`00
0?mJPMkoFX7N00;oFX7N00Go0000oe>1hOmCPN7oDh7Qo`000003odj2i005o`000?m;QNKoBhGVod^5
i_l000007oooool00ol0003oooooooooo`0Booooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0>?ooool3o`0000?o]=7_00?o0000okS>jonhc^/00_nhc^/00ol0
003o^l_Vok_;iP02ok_;iP05o`000?nman;o_LORokg7h_l000000ono`md00ol0003o`;kHol2nf002
ol2nf005o`000?o1^]Co`K[Dol6je?l000001?o1]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1
[/Oo`Jk7ol6^aol000001?o0Z/@01Ol0003o_jO1oknW`OnoYl7o000000Co_jBn00Go0000okjQ^onn
XK_o_Z6ko`000004okfO^@?o00000_nmWKL01_l0003o_9^fo`000?l0003o_ingo`0000Co_Ybf00?o
0000okfJ]?nmV[@00onmV[@00ol0003o_IVcokfI/`03okfI/`;o00001?nkUk800ol0003o^iNcok^G
/`05o`0000Co^IJc00Oo0000okVE/_niUK;o^IFbo`000?nhUKCo000000?o]iBc00?o0000okFD]One
U;D00_neU;D2o`0000Co]9>e00Go0000ok6C]onaTkOo/I>go`000004ojjB^@03o`000?n[TKcoZi6l
00;oZi6l00Go0000ojJA__nVTKkoYY6no`000004oj:?`P05o`000?nLS/GoW8k5oib>aOl000001?nE
SLP00ol0003oSX_<ohj;c002ohj;c005o`000?n6RLooQXW?ohJ9col000001?mmQm802Ol0003oM8GF
ogB5e_mdQMKo0000of^4fOl0003oJhCIo`000004of>2g005o`000?mJPMkoFX7NoeZ1g_l000000omC
PN401Ol0003oCX;Todj2i?m>P^Co000000?oBhGV00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`07ooooo`Co000000?o410@ooooooooool00oooool001_ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`?o0000>Oooool01Ol0003o]=7_okCAkonddNoo000000Co^<k[00?o0000ok_;i_nk
bnH00_nkbnH01Ol0003o_LORokg7h_nman;o000000Co_l?M00?o0000ol2nf?o0_]P00_o0_]P01Ol0
003o`K[Dol6je?o1^]Co000000?o`KK?00?o0000ol6bboo1///00oo1///01Ol0003o`Jk7ol6^aoo1
[/Oo000000Co`:[400Go0000oknW`OnoYl7o_jO1o`000004oknT_P06o`000?nnXK_o_Z6kokjQ^ol0
003o_Ini1?l00004okfM]`04o`000?nlVkKo_9^fokbK]P;o00001?nnW;H00ol0003o_IZdokfJ]002
okfJ]003o`000?nlV;;o000000?o_IVc00Co0000okbG/_nlUk;o00000onkUk83o`000004ok^F/Ol0
003o^YJaokZF/@;o00000oniU[<00ol0003o^IFbokVE/P02okVE/P03o`000?ngU;?o]iBc00?o]iBc
00Ko0000okFD]OneU;Go0000okJD]?l00004okBC]@03o`000?naTkOo/I>g00;o/I>g00?o0000ojjB
^On^T[T00_n^T[T01Ol0003oZi6loj^A_?n[TKco000000?oYY6n00?o0000oj:?`_nRSl800_nRSl80
0ol0003oW8k5oib>a@02oib>a@03o`000?nESLSoUHg800;oUHg800?o0000ohj;c?n>Rl`00_n>Rl`0
1?l0003oQXW?ohJ9col00004ogf7dP03o`000?mdQMKoM8GF00;oM8GF00Co0000of^4fOl0003o0000
1?mSP]`01Ol0003oFX7NoeZ1g_mJPMko000000CoDh7Q00Go0000odj2i?m>P^CoCX;To`000003od^5
iP03o`000?oooooooooo01cooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0iooooo`05o`000?nddNoo]=7_
okCAkol000001?nhc^/00ol0003o^l_Vok_;iP02ok_;iP05o`000?nman;o_LORokg7h_l000000ono
`md00ol0003o`;kHol2nf002ol2nf005o`000?o1^]Co`K[Dol6je?l000001?o1]/l00ol0003o`K;;
ol6bb`02ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000001?o0Z/@00ol0003o_jO1oknW`@02oknW`@05
o`000?noY;ko_jBnoknT__l000000onnXK/3o`0000?o_Ini00Go0000okfM]onmWKOo_Ifgo`000004
okbK]P03o`000?nlVKCo000000;o_Ybf00?o0000okfJ]?nmV[@00onmV[@01?l0003o_9RbokbH/_l0
0002okfI/`04o`000?nlUk;o_9Nbo`0000?o^iNb00Go0000ok^F/OnkU[7o^iJao`000002okZF/@03
o`000?njUK7o000000;o00001OniUK800ol0003o]iBcokND/`03okND/`03o`000?neU;Go000000;o
]YBd00?o0000okBC]OndTkD00_ndTkD00ol0003o/I>gok6C]`02ok6C]`03o`000?n^T[Wo[Y:i00;o
[Y:i00Go0000oj^A_?n[TKcoZi6lo`000004ojJA_P03o`000?nRSl;oXXo200;oXXo200?o0000oib>
aOl000003_l000000on6RLoo0000ogf7dP02ogf7dP03o`000?mdQMKoM8GF00;oM8GF00?o0000of^4
fOm[Q=T00_l00003of>2g003o`000?mJPMkoFX7N00;oFX7N00Go0000oe>1hOmCPN7oDh7Qo`000003
odj2i005o`000?m;QNKoBhGVod^5i_l000008?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Gooooo000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`0hooooo`05o`000?nddNoo]=7_okCAkol000001?nhc^/00ol0003o^l_Vok_;iP02ok_;iP05o`00
0?nman;o_LORokg7h_l000001?no`md00ol0003o`;kHol2nf002ol2nf005o`000?o1^]Co`K[Dol6j
e?l000001?o1]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000001?o0Z/@0
1Ol0003o_jO1oknW`OnoYl7o000000Co_jBn1?l000000onnXK_o0000okfO^@02okfO^@03o`000?nm
WKOo_Ifg00;o_Ifg00?o0000okbK]_nlVkH00_nlVkH01_l0003o_9VdokbI]?l0003o_Ybfo`0000Co
_IZd00Oo0000okbH/_nlV;;o_9Rbo`000?nmVK?o000000?o_9Nb00?o0000ok^G/_nkUk800_l00003
ok^F/@04o`000?njU[7o^YJao`0000?o^YFa00?o0000okVE/_niUK800_niUK800ol0003o^IBbo`00
0005okND/`03o`000?nfU;Co]YBd00;o]YBd00?o0000okBC]OndTkD00_ndTkD01Ol0003o/I>gok6C
]onaTkOo000000Co[Y:i00?o0000oj^A_?n[TK`00_n[TK`00ol0003oYY6no`000008o`0000;oZ9?0
1OnUTl<5oj6Ca@?oWI?82ol00003of^4f@03o`000?mSP]coHh;L00;oHh;L00Go0000oeZ1g_mJPMko
FX7No`000004oe>1h@05o`000?m>P^CoCX;Todj2i?l000000om;QNH00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo03Sooooo00Go0000okCAkonddNoo]=7_o`000004
okS>j`03o`000?nkbnKo^l_V00;o^l_V00Go0000okg7h_nman;o_LORo`000003oko3g@03o`000?o0
_]So`;kH00;o`;kH00?o0000ol6je?o1^]@00_o1^]@01Ol0003o`KK?ol6fcoo1]/oo000000Go`K;;
00Go0000ol6^aoo1[/Oo`Jk7o`000004ol2Za005o`000?noYl7o_jO1oknW`Ol000000_noY;h3o`00
00?o_Z6k00?o0000okfO^OnmWkT00_nmWkT00ol0003o_IfgokfM]`02okfM]`05o`000?nlVkKo_9^f
okbK]_l000001?nlVK@00ol0003o_IZdokfJ]003okfJ]003o`000?nlV;;o_9Rb00;o_9Rb00?o0000
okbG/_nlUk800onlUk82o`000003ok^F/Ol0003o^iJa00;o^iJa00Co0000okZF/OnjU[7o00000onj
UK401Ol0003o^IFbokVE/_niUK;o000000;o^IBb00?o0000okND/ongU;<00_ngU;<2o`0000Co]YBd
00?o0000okBC]OndTkD00_ndTkD01Ol0003o/I>gok6C]onaTkOo000000Co[Y:i00Co0000oj^A_?n[
TKcoZi6l0ol00002ojjC^`03o`000?n[TkgoZi>m00;oZi>m00Co0000ojRC`?nXTl3oZ9?01OnUTl<5
oj6Ca@CoWI?81OnITl`4oiFCc`Go00001?mSP]`00ol0003oFX7NoeZ1gP02oeZ1gP05o`000?mCPN7o
Dh7Qoe>1hOl000000om>P^@01Ol0003oBhGVod^5i_m;QNKo0000023ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_l0000hooooo`05o`000?nddNoo]=7_okCAkol000001?nhc^/00ol0003o^l_Vok_;iP02ok_;iP05
o`000?nman;o_LORokg7h_l000001?no`md00ol0003o`;kHol2nf002ol2nf005o`000?o1^]Co`K[D
ol6je?l000001?o1]/l00ol0003o`K;;ol6bb`02ol6bb`05o`000?o1[/Oo`Jk7ol6^aol000001?o0
Z/@00ol0003o_jO1oknW`@02oknW`@?o00000_noY;h01Ol0003o_Z6kokjQ^onnXK_o000000Co_Ini
00?o0000okfM]onmWKL00_nmWKL01Ol0003o_9^fokbK]_nlVkKo000000Co_9Vd0_l00004okfJ]003
o`000?nlV;;o_9Rb00;o_9Rb00?o0000okbG/_nlUk800onlUk801?l0003o^iJaok^F/Ol00003ok^F
/@04o`000?njU[7o^YJao`0000Co^YFa00Co0000okVE/_niUK;o00000oniU;801_l0003o]iBcokND
/ol0003o^9Bbo`0000Co]YBd00?o0000okBC]OndTkD00_ndTkD01Ol0003o/I>gok6C]onaTkOo0000
00Go[Y:i0ol000000onaU;Wo0000ojjC^`02ojjC^`03o`000?n[TkgoZi>m00;oZi>m00Go0000ojRC
`?nXTl3oZ9?0o`000004ojFC``03o`000?nQTlGoXI?500;oXI?500Co0000oifCb?nMTlSoWI?81OnI
Tl`5oiFCc`?oT9CC1_l00004oeZ1gP05o`000?mCPN7oDh7Qoe>1hOl000001?m>P^@01?l0003oBhGV
od^5i_l0000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool001_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo00Go0000okCAkond
dNoo]=7_o`000004okS>j`03o`000?nkbnKo^l_V00;o^l_V00Go0000okg7h_nman;o_LORo`000004
oko3g@03o`000?o0_]So`;kH00;o`;kH00Go0000ol6je?o1^]Co`K[Do`000004ol6fc`03o`000?o1
//_o`K;;00;o`K;;00Go0000ol6^aoo1[/Oo`Jk7o`000004ol2Za003o`000?noYl7o000000;o0000
1?noY;h00ol0003o_Z6kokjQ^`02okjQ^`03o`000?nmWkWo_Ini00;o_Ini00Go0000okfM]onmWKOo
_Ifgo`000004okbK]P03o`000?nlVKCo_9Vd00;o_9Vd00?o0000ok^H/ol000000_nmV[@00ol0003o
_9RbokbH/P02okbH/P03o`000?nkUk7o000000Co_9Nb00Co0000ok^F/OnkU[7o00000onkU[400ol0
003o^YJao`000003okZE/@05o`000?njUK7o0000okVE/_l000001?niU;800ol0003o]iBco`000003
okRD/P05o`000?nfU;Co]YBdokJD]?l000001?ndTkD00ol0003o/I>gok6C]`02ok6C]`03o`000?n^
T[Wo[Y:i00?o00000onaU;T01Ol0003o[Y>kojjC^on^Tk_o000000CoZi>m00Go0000ojRC`?nXTl3o
Z9?0o`000004ojFC``03o`000?nQTlGoXI?500;oXI?500Go0000oifCb?nMTlSoWI?8o`000004oiVC
c003o`000?nETlooUI??00;oUI??1?n@U=<01?n<U=Oo0000ohbDeon<U=L6o`0000CoDh7Q00Go0000
odj2i?m>P^CoCX;To`000003od^5iP03o`000?oooooooooo01kooooo0_l00007ooooo`03o`000?oo
oooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo7ol00002ol6je005o`000?o1]/oo
`KK?ol6fcol000001Oo1///01Ol0003o`Jk7ol6^aoo1[/Oo000000?o`:[40ol00002oknW`@03o`00
0?noY;ko_jBn00;o_jBn00?o0000okjQ^onnXK/00_nnXK/00ol0003o_IniokfO^@02okfO^@05o`00
0?nmWKOo_IfgokfM]ol000001?nlVkH01Ol0003o_9VdokbI]?nlVKCo000000?o^iRc00?o0000okfJ
]?l000001?nlV;801?l0003o^iNaok^G/Ol00002okbG/P;o00000onkU[401_l0003o^iJaok^F/Ol0
003o^YJao`0000?o^YFa00Co0000okZE/OnjUK7o00001_niU;800ol0003o^9BbokRD/P02okRD/P05
o`000?nfU;Co]YBdokJD]?l000001?ndTkD01?l0003o/I>gok6C]onaTkL4o`0000;o/iBg00Go0000
ok6D^OnaU;Wo/IBio`000003ojjC^`03o`000?n[TkgoZi>m00;oZi>m00Go0000ojRC`?nXTl3oZ9?0
o`000004ojFC``03o`000?nQTlGoXI?500;oXI?500Go0000oifCb?nMTlSoWI?8o`000004oiVCc003
o`000?nETlooUI??00;oUI??00Co0000oi2Ddon@U=?oT9CC0_n<U=L00ol0003oS9CGohbDe`04ohRF
fPKo00000om>P^@01Ol0003oBhGVod^5i_m;QNKo000001oooooo00?o0000ooooool000001Oooool0
0omEEEGoIVIVo`000007ooooo`009?ooool00ol0003oooooooooo`0gooooo`CoVkGZ1OnO/^H5oj:_
h@CoYJgM1OnXZ]P5ojZWe0?o[:G@3_l000001?o1[/Oo0000ol2Za?o0Z/@3o`0000Co_jO100?o0000
oknT__noY;h00_noY;h01Ol0003o_Z6kokjQ^onnXK_o000000Co_Ini00?o0000okfM]onmWKL00_nm
WKL00ol0003o_9^fokbK]P02okbK]P05o`000?nlVKCo_9VdokbI]?l000001?nkV;<2o`0000?o_9Rb
00Oo0000ok^G/OnkUk7o^iNao`000?nlUk;o000000;o^iJa00Co0000ok^F/OnkU[7o00000_nkU[40
0ol0003o^YJao`000002okZE/@05o`000?njUK7o^YFaokZE/Ol000001_niU;800ol0003o^9BbokRD
/P02okRD/P05o`000?nfU;Co]YBdokJD]?l000001OndTkD3o`000003okBD]_l0003o/iBg00?o/iBg
00Go0000ok6D^OnaU;Wo/IBio`000003ojjC^`03o`000?n[TkgoZi>m00;oZi>m00?o0000ojRC`?nX
Tl000_nXTl001Ol0003oYI?3ojFC`onUTl?o000000CoXI?500Go0000oifCb?nMTlSoWI?8o`000004
oiVCc003o`000?nETlooUI??00;oUI??00Oo0000oi2Ddon@U=?oT9CCo`000?n<U=Oo000000;oS9CG
1On8U]X4ohBGgP?o00000_m>P^@01Ol0003oBhGVod^5i_m;QNKo0000027ooooo00?o0000oooooooo
ool03?ooool002Cooooo0_l0000hooooo`CoVkGZ1OnO/^H5oj:_h@CoYJgM1OnXZ]P5ojZWe0Co[:G@
1On^Xl`5ok2Qb0?o/Yo52Ol000000onoYl7o0000oknT_P04oknT_P05o`000?nnXK_o_Z6kokjQ^ol0
00001?nmWkT01Ol0003o_IfgokfM]onmWKOo000000Co_9^f00?o0000okbI]?nlVK@00_nlVK@00ol0
003o^iRcok^H/`02ok^H/`03o`000?nkUk;o000000;o_9Rb00?o0000ok^G/OnkUk400_nkUk401Ol0
003o^iJaok^F/OnkU[7o000000;o^iJa00?o0000ok^F/Ol000000ol00002okZE/@06o`000?njUK7o
^YFao`000?njU;7o00001?niU;82o`0000Co^9Bb00?o0000okJD]?nfU;@00_nfU;@01?l0003o]9>e
okBC]OndTkD2o`0000?o]9Bf00?o0000ok>D]oncU;L00_ncU;L01Ol0003o/IBiok6D^OnaU;Wo0000
00Co[Y>k00Go0000oj^C_On[TkgoZi>mo`000004ojRC`005o`000?nUTl?oYI?3ojFC`ol000001?nQ
TlD01Ol0003oWI?8oifCb?nMTlSo000000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CC
oi2Ddon@U=?o000000;oS9CG00?o0000ohbDeol000001?n8U]X5ohBGgP;oP9WR0ol00003od^5iP03
o`000?oooooooooo01kooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`0gooooo`CoVkGZ
1OnO/^H5oj:_h@CoYJgM1OnXZ]P5ojZWe0Co[:G@1On^Xl`5ok2Qb004ok:OaOl0003o0000o`0000Go
/ig200?o0000okBL_ondW;l01Ol000000onoY;ko0000okjQ^`03okjQ^`03o`000?nmWkWo_Ini00;o
_Ini00Go0000okfM]onmWKOo_Ifgo`000004okbK]P03o`000?nlVKCo_9Vd00;o_9Vd00?o0000ok^H
/onkV;<00_nkV;<01_l0003o^iNbok^G/_l0003o_9Rbo`0000Co^iNa00Go0000ok^F/OnkU[7o^iJa
o`000002ok^F/@;o000000?o^YF`o`000?njUK000_l000001OnjUK7o0000okZE/OnjUK7o000000;o
^YBa00Ko0000okVD/_niU;;o0000okVD/Ol00004okRD/P03o`000?nfU;Co]YBd00;o]YBd1?l00000
0onfU;Co0000okBD]P02okBD]P03o`000?ncU;Oo/iBg00;o/iBg00Go0000ok6D^OnaU;Wo/IBio`00
0004ojjC^`05o`000?n[TkgoZi>moj^C_Ol000001?nXTl001Ol0003oYI?3ojFC`onUTl?o000000Co
XI?500Go0000oifCb?nMTlSoWI?8o`000004oiVCc003o`000?nETlooUI??00;oUI??00Go0000oi2D
don@U=?oT9CCo`000003ohbDe`;o00001?n8U]X00ol0003oQ9ONohBGgP02ohBGgPGoP9WR1?l0000M
ooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0goooo
o`05o`000?nK]N[oVkGZoi^ej_l000001?nO/^H00ol0003oXZoQoj:_h@02oj:_h@CoYJgM00?o0000
ojRZf?nXZ]P00_nXZ]P00ol0003oZZODojZWe002ojZWe0Co[:G@1On^Xl`3ok2Qb0?o00000onbWlD5
ok>M`P05o`000?ndW;oo]9bookBL_ol000000onfV[`4o`000003okjQ^ol0003o_Ini00Co_Ini00Go
0000okfM]onmWKOo_Ifgo`000004okbK]P05o`000?nlVKCo_9VdokbI]?l000001?nkV;<00ol0003o
^iNbok^G/P02ok^G/P03o`000?nkUk7o^iNa00;o^iNa00?o0000ok^F/Ol000000onkU[43o`0000;o
^YF`00Go0000okZE/?l0003o^YF`o`000002okZE/@07o`000?njU;7o^YBaokZD/Ol0003o^IBbo`00
0002okVD/@03o`000?nhU;;o^9Bb00?o^9Bb00?o0000okJD]?nfU;@00_l00004okJD]005o`000?nd
U;Ko]9BfokBD]_l000001?ncU;L01Ol0003o/IBiok6D^OnaU;Wo000000Co[Y>k00Go0000oj^C_On[
TkgoZi>mo`000004ojRC`005o`000?nUTl?oYI?3ojFC`ol000001?nQTlD01Ol0003oWI?8oifCb?nM
TlSo000000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CCoi2Ddon@U=?o000000CoS9CG
00?o0000ohRFf_n8U]X00_n8U]X00ol0003oQ9ONohBGgP02ohBGgP03o`000?n0VN;oP9WR00;oP9WR
0ommW>D2o`0001Wooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oo
oooooooo03Kooooo00?o0000oi^ej_nK]NX00_nK]NX00ol0003oWk;VoinbiP02oinbiP03o`000?nR
[n7oXZoQ00;oXZoQ1?nU[Md00ol0003oZ:[HojRZf002ojRZf003o`000?nZYmCoZZOD00;oZZOD1?n/
YM000ol0003o[Z?<ojjSc002ojjSc0?o000000?o/:78o`000?nbWlD00onbWlD5ok>M`P05o`000?nd
W;oo]9bookBL_ol000001?nfV[`00ol0003o]YVjokJI^P05o`000003okfO^Ol0003o_Ifg00?o_Ifg
00?o0000okbK]_nlVkH00_nlVkH01Ol0003o_9VdokbI]?nlVKCo000000Co^iRc00?o0000ok^G/_nk
Uk800_nkUk82o`0000?o^iNa00?o0000ok^F/Ol000000onkU[400ol0003o^iF`o`000002okZE/004
o`000?njUK3o0000okZE/0;o000000?o^YFao`000?njU;400onjU;400ol0003o^IBaokVD/@02okVD
/@03o`000?nhU;;o^9Bb00;o^9Bb0ol000000ongU;?o0000okJD]003okJD]005o`000?ndU;Ko]9Bf
okBD]_l000001?ncU;L01Ol0003o/IBiok6D^OnaU;Wo000000Co[Y>k00Go0000oj^C_On[TkgoZi>m
o`000004ojRC`005o`000?nUTl?oYI?3ojFC`ol000001?nQTlD01Ol0003oWI?8oifCb?nMTlSo0000
00CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CCoi2Ddon@U=?o000000CoS9CG00?o0000
ohRFf_n8U]X00_n8U]X00ol0003oQ9ONohBGgP02ohBGgP03o`000?n0VN;oP9WR00;oP9WR1?mmW>D0
0ol0003oooooooooo`0Cooooo`Co00002?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
03Oooooo00?o0000oi^ej_nK]NX00_nK]NX01Ol0003oWk;Voinbi_nO/^Ko000000CoXZoQ00Go0000
ojF]gOnU[MgoYJgMo`000004ojRZf003o`000?nZYmCoZZOD00;oZZOD00?o0000ojbUd?n/YM000_n/
YM000ol0003o[Z?<o`000002o`0000Co/:7800?o0000ok:OaOnbWlD00_nbWlD00ol0003o/ig2ok>M
`P02ok>M`P05o`000?ndW;oo]9bookBL_ol000001?nfV[`01Ol0003o]YVjokJI^_nfVK[o000000?o
]iVh1?l000000onmWKOo0000okbK]P04okbK]P05o`000?nlVKCo_9VdokbI]?l000001?nkV;<00ol0
003o^iNbok^G/P02ok^G/P03o`000?nkU[7o000000;o^iNa00Co0000ok^F/OnkU[7o00000_nkU[40
0ol0003o^iF`o`000002okZE/007o`000?njUK3o0000okZE/?l0003o^YB`o`000005okZD/@03o`00
0?niU;7o^IBa00;o^IBa00Co0000okRD/_nhU;;o^9Bb0_l00003okND/`03o`000?nfU;Co]YBd00;o
]YBd00Go0000okBD]_ndU;Ko]9Bfo`000004ok>D]`05o`000?naU;Wo/IBiok6D^Ol000001?n^Tk/0
1Ol0003oZi>moj^C_On[Tkgo000000CoZ9?000?o0000ojFC`onUTl<00_nUTl<00ol0003oXI?5oj6C
a@02oj6Ca@04o`000?nMTlSoWI?8o`0000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CC
oi2Ddon@U=?o000000CoS9CG0_l00003ohRFfP03o`000?n4UmkoQ9ON00;oQ9ON00?o0000oh2Ih_n0
VN800_n0VN801Ol0003oOIcUogfLiOmmW>Go000001;ooooo0ol0000=ooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000oi^ej_nK]NX00_nK]NX01Ol0003o
Wk;Voinbi_nO/^Ko000000CoXZoQ00Go0000ojF]gOnU[MgoYJgMo`000004ojRZf003o`000?nZYmCo
ZZOD00;oZZOD00Co0000ojbUd?n/YM3o[:G@0ol00002ojjSc003o`000?n`XLSo/:7800;o/:7800?o
0000ok:OaOnbWlD00_nbWlD00ol0003o/ig2ok>M`P02ok>M`P05o`000?ndW;oo]9bookBL_ol00000
1?nfV[`01Ol0003o]YVjokJI^_nfVK[o000000Co]iVh00?o0000okRH]onhV;L01Ol000000onlVkKo
0000okbI]003okbI]005o`000?nkV;?o^iRcok^H/ol000001?nkUk801?l0003o^iJaok^F/OnkU[42
o`0000?o^iJa00Ko0000ok^F/Ol0003o0000ok^E/?l00002okZE/0;o000000Go^YF`o`000?njU;3o
^YB`o`000004okZD/@;o00001?niU;44o`000003okVD/_l0003o]iBc00;o]iBc00?o0000okJD]?nf
U;@00_nfU;@01Ol0003o]9BfokBD]_ndU;Ko000000Co/iBg00?o0000ok6D^OnaU;T00_naU;T01Ol0
003o[Y>kojjC^on^Tk_o000000CoZi>m00Go0000ojRC`?nXTl3oZ9?0o`000004ojFC``03o`000?nQ
TlGoXI?500;oXI?500Go0000oifCb?nMTlSoWI?8o`000004oiVCc005o`000?nETlooUI??oiFCcol0
00000on@U=<00ol0003oS9CGohbDe`02ohbDe`03o`000?n8U][o000000;oR9KJ00?o0000ohBGg_n4
Umh00_n4Umh00ol0003oP9WRoh2IhP02oh2IhP05o`000?mmW>GoOIcUogfLiOl000003oooool3o`00
013ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003o
VkGZoi^ejP02oi^ejP05o`000?nO/^KoWk;Voinbi_l000001?nR[n401Ol0003oYJgMojF]gOnU[Mgo
000000CoZ:[H00?o0000ojZWe?nZYm@00_nZYm@5o`0000Co[Z?<00?o0000ok2Qb?n`XLP00_n`XLP0
1Ol0003o/Yo5ok:OaOnbWlGo000000Co/ig200?o0000okBL_ondW;l00_ndW;l00ol0003o]YZlokJJ
_002okJJ_005o`000?nfVK[o]YVjokJI^_l000001?ngVKP01Ol0003o^9RgokRH]onhV;Oo000000?o
^INe1?l000000onlVKCo0000ok^H/`03ok^H/`03o`000?nkUk;o^iNb00;o^iNb00?o0000ok^F/Onk
U[400_nkU[42o`0000?o^iJa00Oo0000ok^E/?nkUK3o0000ok^E/?l0003o^YF`00;o000000?o^YF`
o`000?njU;000_njU;001_l0003o^YBaokZD/Ol0003o^YBao`0000?o^IBa0_l00004okVD/P05o`00
0?ngU;?o]iBcokND/ol000001?nfU;@01Ol0003o]9BfokBD]_ndU;Ko000000Go/iBg00Go0000ok6D
^OnaU;Wo/IBio`000003ojjC^`03o`000?n[TkgoZi>m00;oZi>m00Go0000ojRC`?nXTl3oZ9?0o`00
0004ojFC``03o`000?nQTlGoXI?500;oXI?500Go0000oifCb?nMTlSoWI?8o`000004oiVCc003o`00
0?nETlooUI??00;oUI??00Co0000oi2Ddon@U=?o00001?n<U=L01_l0003oR9KJohRFf_l0003oR9KJ
o`0000CoQ9ON00?o0000oh2Ih_n0VN800_n0VN801Ol0003oOIcUogfLiOmmW>Go000000_ooooo1?l0
000Cooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000
oi^ej_nK]NX00_nK]NX01Ol0003oWk;Voinbi_nO/^Ko000000CoXZoQ00Go0000ojF]gOnU[MgoYJgM
o`000004ojRZf003o`000?nZYmCoZZOD00?o00000on/YM000ol0003o[Z?<ojjSc002ojjSc003o`00
0?n`XLSo/:7800;o/:7800Go0000ok:OaOnbWlGo/Yo5o`000004ok>M`P05o`000?ndW;oo]9bookBL
_ol000001OnfV[`01Ol0003o]YVjokJI^_nfVK[o000000Co]iVh00Go0000okRH]onhV;Oo^9Rgo`00
0004okVG]@03o`000?niU[Co^IJd00?o00000onkV;<00ol0003o^iNbok^G/P02ok^G/P03o`000?nk
U[7o^iJa00;o^iJa00?o0000ok^E/?l000000_nkU[401ol0003o^iF`ok^E/?l0003o^iF`o`000?nj
UK000_l000002?njUK3o0000okZD/?l0003o^YB`o`000?njU;7o00000onjU;401Ol0003o^IBao`00
0?niU;7o000000Co^IBb00Go0000okND/ongU;?o]iBco`000004okJD]003o`000?ndU;Ko]9Bf00;o
]9Bf00?o0000ok>D]oncU;L00_ncU;L01Ol0003o/IBiok6D^OnaU;Wo000000?o[Y>k00?o0000oj^C
_On[Tkd00_n[Tkd01Ol0003oZ9?0ojRC`?nXTl3o000000CoYI?300?o0000oj6CaOnQTlD00_nQTlD0
1Ol0003oWI?8oifCb?nMTlSo000000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CCoi2D
don@U=?o000000?oS9CG00Ko0000ohRFf_n8U][o0000ohRFf_l00004ohBGgP03o`000?n0VN;oP9WR
00;oP9WR00Go0000ogfLiOmmW>GoOIcUo`000008ooooo`?o00005oooool00ol0003oooooooooo`0:
ooooo`008oooool3o`0003Oooooo00Go0000oi^ej_nK]N[oVkGZo`000004oinbiP03o`000?nR[n7o
XZoQ00;oXZoQ00Go0000ojF]gOnU[MgoYJgMo`000004ojRZf0?o00000_nZYm@01Ol0003o[:G@ojbU
d?n/YM3o000000Co[Z?<00?o0000ok2Qb?n`XLP00_n`XLP01Ol0003o/Yo5ok:OaOnbWlGo000000Co
/ig200Go0000okBL_ondW;oo]9boo`000004okJJ_005o`000?nfVK[o]YVjokJI^_l000001OngVKP0
1Ol0003o^9RgokRH]onhV;Oo000000Co^INe00Ko0000okVF]?niU[Co^IJdo`000?niU[<3o`0000Go
^iNb00Go0000ok^F/OnkU[7o^iJao`000003ok^E/0;o000000Go^iF`o`000?nkUK3o0000ok^E/005
o`000003okZD/?l0003o^YB`00;o^YB`00?o0000okZD/OnjU;400_njU;42o`0000;o^IBa00?o0000
okVD/_niU;800_niU;801Ol0003o]iBcokND/ongU;?o000000Co]YBd00?o0000okBD]_ndU;H00_nd
U;H00ol0003o/iBgok>D]`02ok>D]`05o`000?naU;Wo/IBiok6D^Ol000000on^Tk/00ol0003oZi>m
oj^C_@02oj^C_@05o`000?nXTl3oZ9?0ojRC`?l000001?nUTl<00ol0003oXI?5oj6Ca@02oj6Ca@05
o`000?nMTlSoWI?8oifCb?l000001?nITl`00ol0003oUI??oiFCc`02oiFCc`05o`000?n@U=?oT9CC
oi2Ddol000001?n<U=L00ol0003oR9KJohRFfP02o`0000CoQ9ON00?o0000oh2Ih_n0VN800_n0VN80
1Ol0003oOIcUogfLiOmmW>Go000000Gooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000S
ooooo`03o`000?oooooooooo03Oooooo00Go0000oi^ej_nK]N[oVkGZo`000004oinbiP03o`000?nR
[n7oXZoQ00;oXZoQ00Ko0000ojF]gOnU[MgoYJgMo`000?nXZ]P4o`0000CoZZOD00Go0000ojbUd?n/
YM3o[:G@o`000004ojjSc003o`000?n`XLSo/:7800;o/:7800Go0000ok:OaOnbWlGo/Yo5o`000004
ok>M`P05o`000?ndW;oo]9bookBL_ol000001?nfV[`01Ol0003o]YVjokJI^_nfVK[o000000Co]iVh
00?o0000okRH]onhV;L00_nhV;L00ol0003o^INeokVG]@02okVG]@05o`000?niU[Co^IJdokVF]?l0
00000oniU[<2o`0000Co^iNb00Go0000ok^F/OnkU[7o^iJao`000004ok^E/005o`000?nkUK3o^iF`
o`000?nkUK000_l000001_njU;3o0000o`000?l0003o^YB`o`0000;o^YB`0_l00003okZD/@;o0000
0oniU;400ol0003o^IBbokVD/P02okVD/P03o`000?ngU;?o]iBc00;o]iBc00Go0000okJD]?nfU;Co
]YBdo`000004okBD]P03o`000?ncU;Oo/iBg00;o/iBg00Go0000ok6D^OnaU;Wo/IBio`000004ojjC
^`05o`000?n[TkgoZi>moj^C_Ol000000onXTl000ol0003oYI?3ojFC``02ojFC``03o`000?nQTlGo
XI?500;oXI?500Go0000oifCb?nMTlSoWI?8o`000004oiVCc003o`000?nETlooUI??00;oUI??00Go
0000oi2Ddon@U=?oT9CCo`000004ohbDe`05o`000?n8U][oR9KJohRFf_l000001?n4Umh00ol0003o
P9WRoh2IhP02oh2IhP05o`000?mmW>GoOIcUogfLiOl000000_ooool3o`0001gooooo00?o0000oooo
ooooool02_ooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0hooooo`05o`000?nK]N[o
VkGZoi^ej_l000001?nO/^H00ol0003oXZoQoj:_h@02oj:_h@03o`000?nU[MgoYJgM00?o00000onX
Z]P00ol0003oZZODojZWe002ojZWe005o`000?n/YM3o[:G@ojbUd?l000001?n^Xl`01Ol0003o/:78
ok2Qb?n`XLSo000000Co/Yo500?o0000ok>M`_ncWL800_ncWL801Ol0003o]9bookBL_ondW;oo0000
00Co]YZl00Go0000okJI^_nfVK[o]YVjo`000004okNI^003o`000?nhV;Oo^9Rg00;o^9Rg00?o0000
okVG]OniUkD00_niUkD01Ol0003o^IJdokVF]?niU[Co000000?o^IJc00?o0000okZF/_l000000ol0
0004ok^F/@03o`000?nkUK3o^iF`00;o^iF`0_l000000onkUK3o0000ok^E/002o`00000;okZD/?l0
003o0000o`000?njU;3o0000okZD/?l0003o^YB`o`000?njU;400_l000000onjU;3o0000okVD/@02
okVD/@03o`000?niU;;o^IBb00;o^IBb00?o0000okND/ongU;<00_ngU;<01Ol0003o]YBdokJD]?nf
U;Co000000Co]9Bf00?o0000ok>D]oncU;L00_ncU;L01Ol0003o/IBiok6D^OnaU;Wo000000Co[Y>k
00Go0000oj^C_On[TkgoZi>mo`000004ojRC`005o`000?nUTl?oYI?3ojFC`ol000001?nQTlD01Ol0
003oWI?8oifCb?nMTlSo000000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CCoi2Ddon@
U=?o000000CoS9CG00Go0000ohRFf_n8U][oR9KJo`000004ohBGgP03o`000?n0VN;oP9WR00;oP9WR
00Co0000ogfLiOmmW>GoOIcU0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00Go0000oi^ej_nK]N[oVkGZo`000004
oinbiP03o`000?nR[n7oXZoQ00;oXZoQ0ol000000onU[Mgo0000ojRZf003ojRZf003o`000?nZYmCo
ZZOD00;oZZOD00Go0000ojbUd?n/YM3o[:G@o`000004ojjSc005o`000?n`XLSo/:78ok2Qb?l00000
1?nbWlD00ol0003o/ig2ok>M`P02ok>M`P05o`000?ndW;oo]9bookBL_ol000001?nfV[`01Ol0003o
]YVjokJI^_nfVK[o000000Co]iVh00?o0000okRH]onhV;L00_nhV;L01Ol0003o^INeokVG]OniUkGo
000000Co^IJd00Go0000okVF/oniU[?o^IJco`000004okZF/P?o000000?o^iJao`000?nkUK001?nk
UK001?l0003o^YF`o`000?nkUK03o`000003okZD/?l0003o000000;o000000Co^YB`o`000?njU;3o
^YB`0_l00003okZD/003o`000?niU;7o^IBa00;o^IBa00Go0000okVD/_niU;;o^IBbo`000004okND
/`05o`000?nfU;Co]YBdokJD]?l000001?ndU;H00ol0003o/iBgok>D]`02ok>D]`05o`000?naU;Wo
/IBiok6D^Ol000001?n^Tk/01Ol0003oZi>moj^C_On[Tkgo000000CoZ9?000Go0000ojFC`onUTl?o
YI?3o`000004oj6Ca@05o`000?nMTlSoWI?8oifCb?l000001?nITl`00ol0003oUI??oiFCc`02oiFC
c`05o`000?n@U=?oT9CCoi2Ddol000001?n<U=L01?l0003oR9KJohRFf_n8U]X2o`0000?oQ9ON00?o
0000oh2Ih_n0VN800_n0VN801Ol0003oOIcUogfLiOmmW>Go000002?ooooo00?o0000ooooooooool0
2Oooool00005oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00;ooooo0_l0000hooooo`03o`000?nK]N[oVkGZ00;oVkGZ00?o0000oinbi_nO/^H0
0_nO/^H00ol0003oXZoQoj:_h@03o`0000?oYJgM00?o0000ojRZf?nXZ]P00_nXZ]P00ol0003oZZOD
ojZWe002ojZWe005o`000?n/YM3o[:G@ojbUd?l000001?n^Xl`01Ol0003o/:78ok2Qb?n`XLSo0000
00Co/Yo500?o0000ok>M`_ncWL800_ncWL801Ol0003o]9bookBL_ondW;oo000000Co]YZl00Go0000
okJI^_nfVK[o]YVjo`000004okNI^003o`000?nhV;Oo^9Rg00;o^9Rg00Go0000okVG]OniUkGo^INe
o`000004okVF]005o`000?niU[?o^IJcokVF/ol000001?njU[800ol0003o^YFaokZE/@03o`0000?o
^iF`00Co0000okZE/?njUK3o^YF`0_l000000onjU;3o0000o`000002o`000003okZD/?l0003o0000
00;o^YB`0_l00004okZD/003o`000?niU;7o^IBa00;o^IBa00Go0000okVD/_niU;;o^IBbo`000004
okND/`05o`000?nfU;Co]YBdokJD]?l000001?ndU;H00ol0003o/iBgok>D]`02ok>D]`05o`000?na
U;Wo/IBiok6D^Ol000001?n^Tk/01Ol0003oZi>moj^C_On[Tkgo000000CoZ9?000Go0000ojFC`onU
Tl?oYI?3o`000004oj6Ca@05o`000?nMTlSoWI?8oifCb?l000001?nITl`00ol0003oUI??oiFCc`02
oiFCc`05o`000?n@U=?oT9CCoi2Ddol000001?n<U=L01ol0003oR9KJohRFf_n8U][o0000ohBGg_l0
00000_n4Umh00ol0003oP9WRoh2IhP02oh2IhP05o`000?mmW>GoOIcUogfLiOl000008oooool00ol0
003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0gooooo`03o`000?nK]N[oVkGZ
00;oVkGZ00Co0000oinbi_nO/^KoWk;V1?l000000onR[n7o0000ojF]g@03ojF]g@03o`000?nXZ]So
Z:[H00;oZ:[H00?o0000ojZWe?nZYm@00_nZYm@01Ol0003o[:G@ojbUd?n/YM3o000000Co[Z?<00Go
0000ok2Qb?n`XLSo/:78o`000004ok:Oa@03o`000?ncWL;o/ig200;o/ig200Go0000okBL_ondW;oo
]9boo`000004okJJ_005o`000?nfVK[o]YVjokJI^_l000001?ngVKP00ol0003o^9RgokRH]`02okRH
]`05o`000?niUkGo^INeokVG]Ol000001?niU[@01Ol0003o^IJcokVF/oniU[?o000000Co^YJb00Ko
0000okZE/OnjUK7o^YFao`000?njUK04o`0000Co^YF`1ol000001_njU;3o0000o`000?l0003o^YB`
o`0000Co^YB`00?o0000okVD/OniU;400_niU;401Ol0003o^IBbokVD/_niU;;o000000Co]iBc00Go
0000okJD]?nfU;Co]YBdo`000004okBD]P03o`000?ncU;Oo/iBg00;o/iBg00?o0000ok6D^Ol00000
2Ol000000on[Tkgo0000ojRC`003ojRC`005o`000?nUTl?oYI?3ojFC`ol000001?nQTlD01Ol0003o
WI?8oifCb?nMTlSo000000CoVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CCoi2Ddon@U=?o
000000CoS9CG00Go0000ohRFf_n8U][oR9KJo`000002ohBGgP03o`000?n4Umko000000CoP9WR00Go
0000ogfLiOmmW>GoOIcUo`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0=oooool00ol0003oVkGZoi^ejP02oi^ejP03o`000?nO/^Ko000000;o
00001?nR[n401Ol0003oYJgMojF]gOnU[Mgo000000CoZ:[H00?o0000ojZWe?nZYm@00onZYm@01Ol0
003o[:G@ojbUd?n/YM3o000000Co[Z?<00Go0000ok2Qb?n`XLSo/:78o`000004ok:Oa@03o`000?nc
WL;o/ig200;o/ig200Go0000okBL_ondW;oo]9boo`000004okJJ_005o`000?nfVK[o]YVjokJI^_l0
00001?ngVKP01Ol0003o^9RgokRH]onhV;Oo000000Co^INe00Go0000okVF]?niU[Co^IJdo`000004
okVF/`03o`000?njU[;o^YJb00;o^YJb00Go0000okZE/OnjUK7o^YFao`000004okZE/0;o00000onj
UK09o`0000?o^YB`00?o0000okZD/?njU;000_njU;000ol0003o^IBaokVD/@02okVD/@05o`000?ni
U;;o^IBbokVD/_l000000_ngU;<Bo`0000;o]iRh00?o0000okJI^_nfVKX00_nfVKX00ol0003o]YZl
okJJ_00Bo`000003oifCb?l0003oVI?<00?oVI?<00?o0000oiFCconETll00_nETll01Ol0003oT9CC
oi2Ddon@U=?o000000CoS9CG00Go0000ohRFf_n8U][oR9KJo`000002ohBGgP03o`000?n4Umko0000
00CoP9WR00Go0000ogfLiOmmW>GoOIcUo`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Oooooo1ol00002oinbiP03o`000?nR[n7oXZoQ00;oXZoQ00Go0000
ojF]gOnU[MgoYJgMo`000004ojRZf003o`000?nZYmCoZZOD00;oZZOD00?o0000ojbUd?n/YM000_n/
YM000ol0003o[Z?<ojjSc002ojjSc005o`000?n`XLSo/:78ok2Qb?l000001?nbWlD00ol0003o/ig2
ok>M`P02ok>M`P05o`000?ndW;oo]9bookBL_ol000001?nfV[`01Ol0003o]YVjokJI^_nfVK[o0000
00Co]iVh00Go0000okRH]onhV;Oo^9Rgo`000004okVG]@05o`000?niU[Co^IJdokVF]?l000001?ni
U[<00ol0003o^YJbokZF/P02okZF/P05o`000?njUK7o^YFaokZE/Ol000001?njUK000ol0003o^YB`
o`000002o`0000;o^YB`1Ol000000onjU;3o0000okZD/003okZD/005o`000?njU;3o^YB`okZD/?l0
00000_niU;49o`0000;o^IJc00Go0000okVF]?niU[Co^IJdo`000004okVG]@03o`000?nhV;Oo^9Rg
00;o^9Rg00Go0000okNH^?ngV;So]iRho`000004okJI^P05o`000?nfV[co]YZlokJJ_?l000001?nd
W;h01Ol0003o/ig1ok>M`OncWL7o000000Co/Yk400?o0000ok2Paon`X<L02_l000000onETloo0000
oi2Dd`02oi2Dd`03o`000?n<U=OoS9CG00;oS9CG00Go0000ohRFf_n8U][oR9KJo`000003ohBGgP;o
00001?n0VN801Ol0003oOIcUogfLiOmmW>Go000002?ooooo00?o0000ooooooooool02Oooool00005
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01_ooool2o`0003Sooooo00?oK9[[o`000?l000001Ol000000onO/^Ko0000oj:_h@03
oj:_h@05o`000?nU[MgoYJgMojF]gOl000001?nXZ]P00ol0003oZZODojZWe002ojZWe005o`000?n/
YM3o[:G@ojbUd?l000001?n^Xl`00ol0003o/:78ok2Qb002ok2Qb003o`000?nbWlGo/Yo500;o/Yo5
00?o0000ok>M`_ncWL800_ncWL801Ol0003o]9bookBL_ondW;oo000000Co]YZl00Go0000okJI^_nf
VK[o]YVjo`000004okNI^005o`000?nhV;Oo^9RgokRH]ol000001?niUkD01Ol0003o^IJdokVF]?ni
U[Co000000Co^IJc00Go0000okZF/_njU[;o^YJbo`000004okZE/@03o`000?njUK3o^YF`00;o^YF`
00Co0000okZD/?njU;3o^YB`1ol00002okZD/003o`000?njU;3o^YB`00Wo00000_njUK401Ol0003o
^YJbokZF/_njU[;o000000Co^IJc00Go0000okVF]?niU[Co^IJdo`000004okVG]@03o`000?nhV;Oo
^9Rg00;o^9Rg00Go0000okNH^?ngV;So]iRho`000004okJI^P05o`000?nfV[co]YZlokJJ_?l00000
1?ndW;h01Ol0003o/ig1ok>M`OncWL7o000000Co/Yk400Go0000ok2Paon`X<Oo/:37o`000004ojnR
b`04o`000?n]Y<oo[JC?ojfTc`Wo000000?oS9CGo`000?n8U]X00_n8U]X00ol0003oQ9ONohBGgP02
ohBGgP03o`000?n0VN;oP9WR00;oP9WR00Go0000ogfLiOmmW>GoOIcUo`00000Sooooo`03o`000?oo
oooooooo00Wooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001?ooool2o`0003Oooooo0ol00004ofbJj`?oLIOW2Ol000000onU[Mgo0000
ojRZf003ojRZf003o`000?nZYmCoZZOD00;oZZOD00Go0000ojbUd?n/YM3o[:G@o`000004ojjSc005
o`000?n`XLSo/:78ok2Qb?l000001?nbWlD00ol0003o/ig2ok>M`P02ok>M`P05o`000?ndW;oo]9bo
okBL_ol000001?nfV[`01Ol0003o]YVjokJI^_nfVK[o000000Go]iVh00Go0000okRH]onhV;Oo^9Rg
o`000004okVG]@05o`000?niU[Co^IJdokVF]?l000001?niU[<01Ol0003o^YJbokZF/_njU[;o0000
00Co^YFa00Go0000okZE/?njUK3o^YF`o`000004okZD/003o`000?njU;3o^YB`00Wo00000_njU;00
1Ol0003o^YF`okZE/?njUK3o000000Co^YFa00Go0000okZF/_njU[;o^YJbo`000004okVF/`05o`00
0?niU[Co^IJdokVF]?l000001?niUkD00ol0003o^9RgokRH]`02okRH]`05o`000?ngV;So]iRhokNH
^?l000000onfVKX00ol0003o]YZlokJJ_002okJJ_003o`000?ndW;ko]9bn00;o]9bn00Go0000ok>M
`OncWL7o/ig1o`000004ok:Na005o`000?n`X<Oo/:37ok2Paol000001?n_X//00ol0003o[JC?ojfT
c`02ojfTc`05o`000?n[Y]?oZjKCoj^Vdol000000onXZML9o`000003ohBGg_l0003o000000?oP9WR
00Go0000ogfLiOmmW>GoOIcUo`00000Sooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`00
0?oooooooooo03?ooooo0ol00003ooooo`CoK9[[00Co0000og6GiomaUnOoLIOW1OmgUN<3ogfDg`[o
000000?oZZODo`000?n/YM000_n/YM000ol0003o[Z?<ojjSc002ojjSc005o`000?n`XLSo/:78ok2Q
b?l000001?nbWlD00ol0003o/ig2ok>M`P02ok>M`P05o`000?ndW;oo]9bookBL_ol000001?nfV[`0
1Ol0003o]YVjokJI^_nfVK[o000000Co]iVh00?o0000okRH]onhV;L00_nhV;L01Ol0003o^INeokVG
]OniUkGo000000Co^IJd00?o0000okVF/oniU[<00_niU[<01Ol0003o^YJbokZF/_njU[;o000000Co
^YFa00?o0000okZE/?l000003?l000001?njU;3o0000o`000?l00004okZD/005o`000?njUK3o^YF`
okZE/?l000001?njUK401Ol0003o^YJbokZF/_njU[;o000000Co^IJc00Go0000okVF]?niU[Co^IJd
o`000004okVG]@03o`000?nhV;Oo^9Rg00;o^9Rg00Go0000okNH^?ngV;So]iRho`000003okJI^P03
o`000?nfV[co]YZl00;o]YZl00Go0000okBL__ndW;ko]9bno`000003ok>M`@03o`000?nbW/Co/Yk4
00;o/Yk400?o0000ok2Paon`X<L00_n`X<L01Ol0003o[j;;ojnRbon_X/_o000000Go[JC?00Go0000
oj^Vdon[Y]?oZjKCo`000004ojRYe`05o`000?nV[=_oYZcKojJ/fol000000onS[]l9o`000003ogfL
iOl0003ooooo02?ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0<?oo
ool3o`0000Kooooo00?o0000ofbJjom/V^/00_m/V^/3og6Gi`03o`000?mgUN?oMiGS00;oMiGS00Co
0000ogfDgommU=ooOICO1On3Tm/4ohZCePCo000000?o[:G@o`000?n^Xl`00on^Xl`01Ol0003o/:78
ok2Qb?n`XLSo000000Co/Yo500?o0000ok>M`_ncWL800_ncWL801Ol0003o]9bookBL_ondW;oo0000
00Co]YZl00Go0000okJI^_nfVK[o]YVjo`000004okNI^003o`000?nhV;Oo^9Rg00;o^9Rg00Go0000
okVG]OniUkGo^INeo`000004okVF]003o`000?niU[?o^IJc00;o^IJc00?o0000okZF/_l000002?l0
0002okZD/003o`000?njU;3o^YB`00;o^YB`0_l000000onjU;3o0000o`000002o`0000;o^YB`0_l0
0002okZD/003o`000?njUK3o^YF`00;o^YF`00?o0000okZE/OnjUK400_njUK401Ol0003o^YJbokZF
/_njU[;o000000Co^IJc00Go0000okVF]?niU[Co^IJdo`000004okVG]@05o`000?nhV;Oo^9RgokRH
]ol000000ongV;P00ol0003o]YVjokJI^P02okJI^P03o`000?nfV[co]YZl00;o]YZl00Go0000okBL
__ndW;ko]9bno`000003ok>M`@03o`000?nbW/Co/Yk400;o/Yk400Go0000ok2Paon`X<Oo/:37o`00
0004ojnRb`03o`000?n]Y<oo[JC?00;o[JC?00Go0000oj^Vdon[Y]?oZjKCo`000004ojRYe`05o`00
0?nV[=_oYZcKojJ/fol000001OnS[]l00ol0003oXK7To`000002oj6ai003o`000?nM]>SoWKCX00;o
00009?ooool00ol0003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`05o`00
0?m/V^_oK9[[ofbJjol000000omaUnL5ogNEh`?oOICO00?o0000oh>Cfon3Tm/00_n3Tm/00ol0003o
RY?FohZCeP02ohZCeP?oT9?B3_l000000onbWlGo0000ok>M`P03ok>M`P05o`000?ndW;oo]9bookBL
_ol000001?nfV[`01Ol0003o]YVjokJI^_nfVK[o000000Co]iVh00?o0000okRH]onhV;L00_nhV;L0
1Ol0003o^INeokVG]OniUkGo000000;o^IJd2Ol00002okVD/P03o`000?niU;7o^IBa00;o^IBa00Go
0000okZD/?njU;3o^YB`o`000003okZD/0;o000000?o^YB`o`000?njU;001?l000000onjU;3o0000
okZE/003o`0000Co^YF`00Go0000okZE/OnjUK7o^YFao`000004okZF/P03o`000?niU[?o^IJc00;o
^IJc00Go0000okVF]?niU[Co^IJdo`000004okVG]@05o`000?nhV;Oo^9RgokRH]ol000000ongV;P0
0ol0003o]YVjokJI^P02okJI^P05o`000?nfV[co]YZlokJJ_?l000001?ndW;h01Ol0003o/ig1ok>M
`OncWL7o000000Co/Yk400Go0000ok2Paon`X<Oo/:37o`000004ojnRb`03o`000?n]Y<oo[JC?00;o
[JC?00Go0000oj^Vdon[Y]?oZjKCo`000004ojRYe`05o`000?nV[=_oYZcKojJ/fol000001?nS[]l0
1?l0003oXK7Toj6ai?nQ/N@2o`0000CoWKCX00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`08ooooo`008Oooool00ol0003oooooooooo`0Zooooo`?o00003Oooool01Ol0003oK9[[ofbJjom/
V^_o000000?oLIOW00?o0000ogNEhomgUN<00_mgUN<01?l0003oOICOogfDgommU=l5oh>Cf`CoRY?F
00Co0000oi2Cd_n@Tm;oT9?B1OnFT/h4oi^CbPCoX9?69?l00002okJD]003o`000?ngU;?o]iBc00;o
]iBc00Go0000okVD/_niU;;o^IBbo`000004okVD/@03o`000?njU;3o^YB`00;o^YB`00Co0000okZD
/?l0003o^YB`0_l000000onjU;3o0000o`000004o`0000Co^YF`1?l000000onjUK3o0000okZE/@02
okZE/@05o`000?njU[;o^YJbokZF/_l000001?niU[<00ol0003o^IJdokVF]002okVF]003o`000?ni
UkGo^INe00;o^INe00Go0000okRH]onhV;Oo^9Rgo`000003okNH^003o`000?nfVK[o]YVj00;o]YVj
00Go0000okJJ_?nfV[co]YZlo`000004okBL_P05o`000?ncWL7o/ig1ok>M`Ol000001?nbW/@01Ol0
003o/:37ok2Paon`X<Oo000000Co[j;;00?o0000ojfTcon]Y<l00_n]Y<l01Ol0003oZjKCoj^Vdon[
Y]?o000000CoZ:WG00Go0000ojJ/fonV[=_oYZcKo`000004oj>^g`03o`000?nQ/NCoXK7T00;oXK7T
00Go0000oifdj?nM]>SoWKCXo`00000Uooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`00
0?oooooooooo02Oooooo0ol0000@ooooo`03o`000?m/V^_oK9[[00;oK9[[00Co0000og6GiomaUnOo
00001?mgUN<01Ol0003oOICOogfDgommU=oo000000CoPi?K1?n:TmH01Ol0003oT9?Boi2Cd_n@Tm;o
000000CoUY;>00Go0000oi^Cb_nKTl[oVi?:o`000004oj2CaPGoY9?31?nXTl05oj^C_PCo[Y>k1On`
U;T5ok>D]`05o`000?ndU;Ko]9BfokBD]_l000001?nfU;@00ol0003o]iBcokND/`02okND/`05o`00
0?niU;;o^IBbokVD/_l000001?niU;400ol0003o^YB`okZD/002okZD/0;o00000_njU;000ol0003o
^YB`o`000002o`000003okZD/?l0003o000000;o00000onjUK001?l0003o^iF`ok^E/?nkUK03o`00
00;o^YFa00Go0000okZF/_njU[;o^YJbo`000004okVF/`05o`000?niU[Co^IJdokVF]?l000001Oni
UkD01Ol0003o^9RgokRH]onhV;Oo000000?o]iRh00?o0000okJI^_nfVKX00_nfVKX01Ol0003o]YZl
okJJ_?nfV[co000000Co]9bn00Go0000ok>M`OncWL7o/ig1o`000004ok:Na005o`000?n`X<Oo/:37
ok2Paol000001?n_X//00ol0003o[JC?ojfTc`02ojfTc`05o`000?n[Y]?oZjKCoj^Vdol000000onX
ZML01Ol0003oYZcKojJ/fonV[=_o000000GoXjkO00?o0000oj6ai?nQ/N@00_nQ/N@01Ol0003oWKCX
oifdj?nM]>So000002Gooooo00?o0000ooooooooool02?ooool0023ooooo00?o0000ooooooooool0
9Oooool3o`0001Cooooo00Go0000ofbJjom/V^_oK9[[o`000003og6Gi`05o`000?mgUN?oMiGSogNE
hol000000ommU=l00ol0003oPi?Koh>Cf`02oh>Cf`03o`000?n:TmKoRY?F00;oRY?F0on@Tm800ol0
003oUY;>oiJBcP02oiJBcP05o`000?nKTl[oVi?:oi^Cb_l000001?nPTlH00ol0003oY9?3ojBC``02
ojBC``CoZ9?01On[Tkh01Ol0003o[Y>kojjC^on^Tk_o000000Co/9Bi00?o0000ok>D]oncU;L00_nc
U;L01Ol0003o]9BfokBD]_ndU;Ko000000Co]YBd00?o0000okND/ongU;<00_ngU;<01Ol0003o^IBb
okVD/_niU;;o000000Co^IBa00Co0000okZD/?njU;3o^YB`0_l00003okZD/003o`000?njU;3o0000
00;o000000Ko^YB`o`000?njU;3o0000ok^E/?l00002okZE/003o`000?nkUK3o^iF`00;o^iF`00?o
0000ok^F/Ol000000_l00003okZF/P03o`000?niU[?o^IJc00;o^IJc00Go0000okVF]?niU[Co^IJd
o`000004okVG]@03o`000?nhV;Oo^9Rg00;o^9Rg00Go0000okNH^?ngV;So]iRho`000004okJI^P05
o`000?nfV[co]YZlokJJ_?l000001?ndW;h01Ol0003o/ig1ok>M`OncWL7o000000Co/Yk400Go0000
ok2Paon`X<Oo/:37o`000003ojnRb`03o`000?n]Y<oo[JC?00;o[JC?00Go0000oj^Vdon[Y]?oZjKC
o`000004ojRYe`05o`000?nV[=_oYZcKojJ/fol000001?nS[]l00ol0003oXK7Toj6ai002oj6ai005
o`000?nM]>So0000oifdj?l000009_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003o
ooooooooo`0Rooooo`?o00005oooool01Ol0003oK9[[ofbJjom/V^_o000000?oLIOW00?o0000ogNE
homgUN<00_mgUN<01?l0003oOICOogfDgol00004oh>Cf`03o`000?n:TmKoRY?F00;oRY?F00Co0000
oi2Cd_n@Tm;oT9?B1OnFT/h4oi^CbPCoX9?600?o0000ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC
`?nXTl3o000000CoZi>n00Go0000ojjC^on^Tk_o[Y>ko`000004ok2D^@03o`000?ncU;Oo/iBg00;o
/iBg00Go0000okBD]_ndU;Ko]9Bfo`000004okJD]003o`000?ngU;?o]iBc00;o]iBc00?o0000okVD
/_niU;800_niU;801_l0003o^IBaokVD/OniU;7o0000okZD/0;o000000So^YBao`000?njU;3o^YB`
o`000?njU;3o0000okZD/0;o000000Co^YB`o`000?l0003o00000_nkUK02o`0000Go^iF`00Co0000
ok^F/OnkU[7o^iJa0_l00002okZF/P03o`000?niU[?o^IJc00;o^IJc00Go0000okVF]?niU[Co^IJd
o`000004okVG]@03o`000?nhV;Oo^9Rg00;o^9Rg00Go0000okNH^?ngV;So]iRho`000003okJI^P03
o`000?nfV[co]YZl00;o]YZl00?o0000okBL__ndW;h00_ndW;h01Ol0003o/ig1ok>M`OncWL7o0000
00Co/Yk400Go0000ok2Paon`X<Oo/:37o`000003ojnRb`03o`000?n]Y<oo[JC?00;o[JC?00Go0000
oj^Vdon[Y]?oZjKCo`000004ojRYe`05o`000?nV[=_oYZcKojJ/fol000001?nS[]l00ol0003oXK7T
oj6ai002oj6ai003o`000?nM]>SoWKCX00;o00009_ooool00ol0003oooooooooo`08ooooo`008?oo
ool2o`00027ooooo0_l0000Jooooo`03o`000?m/V^_oK9[[00;oK9[[00Co0000og6GiomaUnOo0000
1?mgUN<01Ol0003oOICOogfDgommU=oo000000?oPi?K00?o0000ohZCe_n:TmH00_n:TmH01Ol0003o
T9?Boi2Cd_n@Tm;o000000CoUY;>00Go0000oi^Cb_nKTl[oVi?:o`000003oj2CaP03o`000?nTTl?o
Y9?300;oY9?300Go0000ojRC`?nXTl3oZ9?0o`000004oj^C_P05o`000?n^Tk_o[Y>kojjC^ol00000
1?n`U;T00ol0003o/iBgok>D]`02ok>D]`05o`000?ndU;Ko]9BfokBD]_l000001?nfU;@00ol0003o
]iBcokND/`02okND/`03o`000?niU;;o^IBb00;o^IBb00Co0000okVD/OniU;7o^IBa0_l00003okZD
/@03o`000?njU;3o000000;o^YB`1?l000001OnjU;3o0000o`000?nkUK3o000000;o^iF`00?o0000
ok^E/?nkUK000_nkUK000ol0003o^iJaok^F/@02ok^F/@03o`000?nkUk;o000000;o00001?niU[<0
1Ol0003o^IJdokVF]?niU[Co000000Co^INe00?o0000okRH]onhV;L00_nhV;L01Ol0003o]iRhokNH
^?ngV;So000000?o]YVj00?o0000okJJ_?nfV[`00_nfV[`01Ol0003o]9bnokBL__ndW;ko000000?o
/ig100?o0000ok:Na?nbW/@00_nbW/@00ol0003o/:37ok2Pa`02ok2Pa`05o`000?n_X/_o[j;;ojnR
bol000001?n]Y<l01Ol0003oZjKCoj^Vdon[Y]?o000000?oZ:WG00Go0000ojJ/fonV[=_oYZcKo`00
0005oj>^g`05o`000?nQ/NCoXK7Toj6ai?l000001?nM]>P00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`05o`000?m/
V^_oK9[[ofbJjol000000omaUnL01Ol0003oMiGSogNEhomgUN?o000000?oOICO00?o0000oh>Cfon3
Tm/00_n3Tm/01Ol0003oRY?FohZCe_n:TmKo000000?oT9?B00?o0000oiJBc_nFT/h00_nFT/h01Ol0
003oVi?:oi^Cb_nKTl[o000000?oX9?600?o0000ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC`?nX
Tl3o000000CoZi>n00?o0000ojjC^on^Tk/00_n^Tk/01Ol0003o/9Biok2D^On`U;Wo000000Co/iBg
00Go0000okBD]_ndU;Ko]9Bfo`000004okJD]003o`000?ngU;?o]iBc00;o]iBc00?o0000okVD/_ni
U;800_niU;800ol0003o^IBaokVD/@02o`0000Co^YBa0_l00002okZD/003o`000?njU;3o000000Go
000000Co^iF`o`000?nkUK3o^iF`0_l00003ok^E/003o`000?nkU[7o^iJa00;o^iJa00Co0000ok^G
/_nkUk;o^iNb1?l000000oniU[?o0000okVF]002okVF]003o`000?niUkGo^INe00;o^INe00?o0000
okRH]onhV;L00_nhV;L01Ol0003o]iRhokNH^?ngV;So000000?o]YVj00?o0000okJJ_?nfV[`00_nf
V[`01Ol0003o]9bnokBL__ndW;ko000000?o/ig100?o0000ok:Na?nbW/@00_nbW/@01Ol0003o/:37
ok2Paon`X<Oo000000Co[j;;00Go0000ojfTcon]Y<oo[JC?o`000003oj^Vd`03o`000?nXZMOoZ:WG
00;oZ:WG00Go0000ojJ/fonV[=_oYZcKo`000004oj>^g`03o`000?nQ/NCoXK7T00;oXK7T00Co0000
oifdj?nM]>SoWKCX0_l0000Wooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooo
oooo01[ooooo0ol0000Pooooo`05o`000?m/V^_oK9[[ofbJjol000000omaUnL00ol0003oMiGSogNE
h`02ogNEh`04o`000?mmU=ooOICOo`0000CoPi?K00Go0000ohZCe_n:TmKoRY?Fo`000003oi2CdP03
o`000?nFT/koUY;>00;oUY;>00Go0000oi^Cb_nKTl[oVi?:o`000004oj2CaP03o`000?nTTl?oY9?3
00;oY9?300Go0000ojRC`?nXTl3oZ9?0o`000003oj^C_P03o`000?n^Tk_o[Y>k00;o[Y>k00Go0000
ok2D^On`U;Wo/9Bio`000004ok>D]`05o`000?ndU;Ko]9BfokBD]_l000001OnfU;@01Ol0003o]iBc
okND/ongU;?o000000Co^IBb0ol000000oniU;7o0000okZD/@03okZD/@06o`000?njU;3o^YB`okZD
/?l0003o^YB`0ol000000onkUK3o0000o`000002ok^E/005o`000?nkUK3o0000ok^F/Ol000000_nk
UK001Ol0003o^iJaok^F/OnkU[7o000000Co^iNb00Co0000ok^H/onkV;?o^iRc1?l000000oniU[Co
0000okVG]@03okVG]@03o`000?nhV;Oo^9Rg00;o^9Rg00Go0000okNH^?ngV;So]iRho`000003okJI
^P03o`000?nfV[co]YZl00;o]YZl00Go0000okBL__ndW;ko]9bno`000003ok>M`@03o`000?nbW/Co
/Yk400;o/Yk400Go0000ok2Paon`X<Oo/:37o`000004ojnRb`05o`000?n]Y<oo[JC?ojfTcol00000
0on[Y]<00ol0003oZ:WGojRYe`02ojRYe`05o`000?nV[=_oYZcKojJ/fol000001?nS[]l01Ol0003o
XK7Toj6ai?nQ/NCo000000CoWKCX00?o0000ooooool000009_ooool00ol0003oooooooooo`07oooo
o`008?ooool3o`0001Oooooo0ol0000Sooooo`05o`000?m/V^_oK9[[ofbJjol000000omaUnL00ol0
003oMiGSogNEh`02ogNEh`05o`000?mmU=ooOICOogfDgol000000on3Tm/01Ol0003oRY?FohZCe_n:
TmKo000000?oT9?B00?o0000oiJBc_nFT/h00_nFT/h01Ol0003oVi?:oi^Cb_nKTl[o000000CoX9?6
00?o0000ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC`?nXTl3o000000?oZi>n00?o0000ojjC^on^
Tk/00_n^Tk/01Ol0003o/9Biok2D^On`U;Wo000000Co/iBg00Go0000okBD]_ndU;Ko]9Bfo`000005
okJD]005o`000?ngU;?o]iBcokND/ol000000oniU;82o`0000?o^IBa00?o0000okZD/OnjU;400_nj
U;401ol0003o^YB`okZD/?l0003o^YB`o`000?njUK000_l000001OnkUK3o0000ok^E/?l0003o^iF`
00;o00000onkU[42o`0000Co^iJa00?o0000ok^G/_nkUk800_nkUk800ol0003o^iRcok^H/`02ok^H
/`03o`000?nlVKCo_9Vd00?o00000oniUkD01Ol0003o^9RgokRH]onhV;Oo000000?o]iRh00?o0000
okJI^_nfVKX00_nfVKX00ol0003o]YZlokJJ_002okJJ_005o`000?ndW;ko]9bnokBL__l000000onc
WL400ol0003o/Yk4ok:Na002ok:Na005o`000?n`X<Oo/:37ok2Paol000000on_X//00ol0003o[JC?
ojfTc`02ojfTc`05o`000?n[Y]?oZjKCoj^Vdol000000onXZML01Ol0003oYZcKojJ/fonV[=_o0000
00GoXjkO00Go0000oj6ai?nQ/NCoXK7To`000003oifdj005o`000?ooooooooooooooool000009Ooo
ool00ol0003oooooooooo`07ooooo`007oooool2o`0001Kooooo0ol0000Wooooo`05o`000?m/V^_o
K9[[ofbJjol000000_maUnL00ol0003oMiGSogNEh`02ogNEh`05o`000?mmU=ooOICOogfDgol00000
0on3Tm/01Ol0003oRY?FohZCe_n:TmKo000000?oT9?B00?o0000oiJBc_nFT/h00_nFT/h01Ol0003o
Vi?:oi^Cb_nKTl[o000000CoX9?600?o0000ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC`?nXTl3o
000000?oZi>n00?o0000ojjC^on^Tk/00_n^Tk/01Ol0003o/9Biok2D^On`U;Wo000000Co/iBg00?o
0000okBD]_ndU;H00_ndU;H00ol0003o]YBdokJD]002okJD]006o`000?ngU;?o]iBcokND/ol0003o
^IBb0_l000000onhU;;o0000okVD/@02okVD/@0<o`000?njU;7o^YBaokZD/Ol0003o^YBao`000?nj
U;3o0000okZD/?l0003o^YF`0_l000001?nkUK3o0000ok^E/?l00002ok^E/003o`000?nkU[7o^iJa
00;o^iJa0_l00003ok^F/@05o`000?nkUk;o^iNbok^G/_l000001OnkV;<01_l0003o_9VdokbI]?nl
VKCo0000okbK]PCo00000onhV;L01Ol0003o]iRhokNH^?ngV;So000000Co]YVj00Go0000okJJ_?nf
V[co]YZlo`000004okBL_P05o`000?ncWL7o/ig1ok>M`Ol000001?nbW/@01Ol0003o/:37ok2Paon`
X<Oo000000?o[j;;00?o0000ojfTcon]Y<l00_n]Y<l01Ol0003oZjKCoj^Vdon[Y]?o000000?oZ:WG
00Go0000ojJ/fonV[=_oYZcKo`000004oj>^g`03o`000?nQ/NCoXK7T00;oXK7T00Go0000oifdj?nM
]>SoWKCXo`000004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool04_ooool3o`0002[ooooo00Go0000ofbJjom/V^_oK9[[o`00
0003og6Gi`05o`000?mgUN?oMiGSogNEhol000000ommU=l01Ol0003oPi?Koh>Cfon3Tm_o000000Co
RY?F00Co0000oi2Cd_n@Tm;o00001?nFT/h01Ol0003oVi?:oi^Cb_nKTl[o000000CoX9?600?o0000
ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC`?nXTl3o000000?oZi>n00?o0000ojjC^on^Tk/00_n^
Tk/00ol0003o/9Biok2D^@02ok2D^@03o`000?ncU;Oo/iBg00;o/iBg00Go0000okBD]_ndU;Ko]9Bf
o`000004okJD]004o`000?ngU;?o]iBcokND/`;o00000onhU;800ol0003o^IBaokVD/@02okVD/@03
o`000?njU;7o000000?o^YBa00Go0000okZD/?njU;3o0000okZE/002o`000004ok^E/?l0003o^iF`
o`0000;o^iF`00?o0000ok^F/OnkU[400_nkU[400ol0003o^iNao`000002ok^F/@05o`000?nkUk;o
^iNbok^G/_l000001?nkV;<00ol0003o_9VdokbI]002okbI]003o`000?nlVkKo_9^f00;o_9^f0ol0
00000onhV;Oo0000okNH^002okNH^003o`000?nfVK[o]YVj00;o]YVj00Go0000okJJ_?nfV[co]YZl
o`000004okBL_P05o`000?ncWL7o/ig1ok>M`Ol000001?nbW/@01Ol0003o/:37ok2Paon`X<Oo0000
00?o[j;;00Go0000ojfTcon]Y<oo[JC?o`000003oj^Vd`03o`000?nXZMOoZ:WG00;oZ:WG00Go0000
ojJ/fonV[=_oYZcKo`000004oj>^g`05o`000?nQ/NCoXK7Toj6ai?l000000onM]>P00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo00oooooo0ol0000]ooooo`05o`000?m/V^_oK9[[ofbJjol000000omaUnL00ol0003o
MiGSogNEh`02ogNEh`04o`000?mmU=ooOICOo`0000CoPi?K00Go0000ohZCe_n:TmKoRY?Fo`000003
oi2CdP03o`000?nFT/koUY;>00;oUY;>00Go0000oi^Cb_nKTl[oVi?:o`000003oj2CaP03o`000?nT
Tl?oY9?300;oY9?300Go0000ojRC`?nXTl3oZ9?0o`000004oj^C_P05o`000?n^Tk_o[Y>kojjC^ol0
00001?n`U;T00ol0003o/iBgok>D]`02ok>D]`05o`000?ndU;Ko]9BfokBD]_l000001?nfU;@00ol0
003o]iBcokND/`02o`0000Co^9Bb00?o0000okVD/OniU;400_niU;42o`0000Co^YBa00?o0000okZD
/?njU;000_l000001_njUK3o0000ok^E/?nkUK3o0000ok^E/0;o000000Go^iJao`000?nkU[7o^iJa
o`000003ok^G/@;o00001?nkUk800ol0003o^iRcok^H/`02ok^H/`05o`000?nlVKCo_9VdokbI]?l0
00001OnlVkH00ol0003o_IfgokfM]`04o`000003okNH^?l0003o]YVj00;o]YVj00?o0000okJJ_?nf
V[`00_nfV[`00ol0003o]9bnokBL_P02okBL_P05o`000?ncWL7o/ig1ok>M`Ol000001?nbW/@01Ol0
003o/:37ok2Paon`X<Oo000000?o[j;;00Go0000ojfTcon]Y<oo[JC?o`000003oj^Vd`05o`000?nX
ZMOoZ:WGojRYeol000000onV[=/00ol0003oXjkOoj>^g`03oj>^g`05o`000?nQ/NCoXK7Toj6ai?l0
00000onM]>P00ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01oooool000Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool3o`00037ooooo0ol000001Om/V^_o0000og6GiomaUnOo0000
00CoMiGS00Go0000ogfDgommU=ooOICOo`000003oh>Cf`05o`000?n:TmKoRY?FohZCe_l000000on@
Tm800ol0003oUY;>oiJBcP02oiJBcP05o`000?nKTl[oVi?:oi^Cb_l000000onPTlH00ol0003oY9?3
ojBC``02ojBC``05o`000?nXTl3oZ9?0ojRC`?l000001?n[Tkh01Ol0003o[Y>kojjC^on^Tk_o0000
00Co/9Bi00?o0000ok>D]oncU;L00_ncU;L01Ol0003o]9BfokBD]_ndU;Ko000000Co]YBd0ol00000
0onfU;Co0000okRD/P03okRD/P03o`000?niU;7o^IBa00;o^IBa00?o0000okZD/OnjU;400_njU;40
2?l0003o^YFao`000?l0003o^YF`o`000?njUK3o00000_nkUK000ol0003o^iF`o`000003ok^F/@03
o`000?nkU[7o000000Co^iNa00?o0000ok^G/_nkUk800_nkUk800ol0003o^iRcok^H/`02ok^H/`05
o`000?nlVKCo_9VdokbI]?l000001OnlVkH01Ol0003o_IfgokfM]onmWKOo000000;o_Yni1?l00000
0onfVK[o0000okJJ_003okJJ_005o`000?ndW;ko]9bnokBL__l000000oncWL400ol0003o/Yk4ok:N
a002ok:Na003o`000?n`X<Oo/:3700;o/:3700Go0000ojnRbon_X/_o[j;;o`000003ojfTc`05o`00
0?n[Y]?oZjKCoj^Vdol000000onXZML01Ol0003oYZcKojJ/fonV[=_o000000CoXjkO00Go0000oj6a
i?nQ/NCoXK7To`000004oifdj003o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool2o`0000[ooooo0ol0000dooooo`03o`000?l9J=co2FSL00Co000000?oLIOW
o`000?mgUN<00_mgUN<01Ol0003oOICOogfDgommU=oo000000?oPi?K00Go0000ohZCe_n:TmKoRY?F
o`000003oi2CdP03o`000?nFT/koUY;>00;oUY;>00Go0000oi^Cb_nKTl[oVi?:o`000003oj2CaP03
o`000?nTTl?oY9?300;oY9?300Go0000ojRC`?nXTl3oZ9?0o`000004oj^C_P05o`000?n^Tk_o[Y>k
ojjC^ol000001?n`U;T00ol0003o/iBgok>D]`02ok>D]`05o`000?ndU;Ko]9BfokBD]_l000000onf
U;@2o`0000?o]YBd00?o0000okRD/_nhU;800onhU;800ol0003o^IBaokVD/@02o`0000Co^YBa00?o
0000okZE/OnjUK400ol000001?njUK3o0000ok^E/?nkUK03o`0000?o^iJa00?o0000ok^F/Ol00000
1?nkUk42o`0000?o^iNb00?o0000ok^H/onkV;<00_nkV;<01Ol0003o_9VdokbI]?nlVKCo000000Co
_9^f00?o0000okfM]onmWKL00_nmWKL01Ol0003o_YniokjO^OnnWkWo000000;o_Z6k2Ol000000ond
W;ko0000ok>M`@02ok>M`@03o`000?nbW/Co/Yk400;o/Yk400Go0000ok2Paon`X<Oo/:37o`000003
ojnRb`03o`000?n]Y<oo[JC?00;o[JC?00Go0000oj^Vdon[Y]?oZjKCo`000003ojRYe`05o`000?nV
[=_oYZcKojJ/fol000001?nS[]l01Ol0003oXK7Toj6ai?nQ/NCo000000?oWKCX00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool01_ooool3o`0003Sooooo00?o0000o`UXg?l9J=`00ol@J=`3o`0000;oMiGS00Go0000ogfD
gommU=ooOICOo`000003oh>Cf`05o`000?n:TmKoRY?FohZCe_l000000on@Tm800ol0003oUY;>oiJB
cP02oiJBcP05o`000?nKTl[oVi?:oi^Cb_l000000onPTlH00ol0003oY9?3ojBC``02ojBC``05o`00
0?nXTl3oZ9?0ojRC`?l000001?n[Tkh01Ol0003o[Y>kojjC^on^Tk_o000000Co/9Bi00?o0000ok>D
]oncU;L00_ncU;L01?l0003o]9BfokBD]_ndU;H4o`000003okBC]Ol0003o]YBd00?o]YBd00?o0000
okRD/_nhU;800_nhU;800ol0003o^IBao`000002okVD/P04o`000?njU;7o^YBao`0000?o^YFa00?o
0000okZE/Ol000000_l000001OnkUK3o0000o`000?nkU[7o000000Co^iJa00?o0000ok^G/OnkUk40
0_nkUk401_l0003o_9RbokbH/_l0003o^iNbo`0000Co^iRc00?o0000okbI]?nlVK@00_nlVK@00ol0
003o_9^fokbK]P02okbK]P05o`000?nmWKOo_IfgokfM]ol000001?nnWkT01Ol0003o_Z6kokjQ^onn
XK_o000000Co_jBn00?o0000oknW`OnoYl402Ol000000onbW/Co0000ok2Pa`02ok2Pa`05o`000?n_
X/_o[j;;ojnRbol000000on]Y<l01Ol0003oZjKCoj^Vdon[Y]?o000000?oZ:WG00Go0000ojJ/fonV
[=_oYZcKo`000005oj>^g`05o`000?nQ/NCoXK7Toj6ai?l000000onM]>P00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3
o`0003cooooo00?o0000o`UXg?l9J=`00ol@J=`2oaaZg0;o000000GoMiGSo`000?mmU=ooOICOo`00
0003oh>Cf`05o`000?n:TmKoRY?FohZCe_l000000on@Tm800ol0003oUY;>oiJBcP02oiJBcP05o`00
0?nKTl[oVi?:oi^Cb_l000000onPTlH00ol0003oY9?3ojBC``02ojBC``05o`000?nXTl3oZ9?0ojRC
`?l000001?n[Tkh00ol0003o[Y>kojjC^`02ojjC^`05o`000?n`U;Wo/9Biok2D^Ol000001?ncU;L0
0ol0003o]9BfokBD]P02o`0000Co]9>e00?o0000okJD]?nfU;@00_nfU;@00ol0003o^9BbokRD/P02
okRD/P;o00001?niU;800ol0003o^YBao`000002okZE/@05o`000?njUK7o^YFao`000?njU[400_l0
00001OnkU[7o0000ok^F/OnkU[7o000000?o^iJa00?o0000ok^G/OnkUk400_nkUk401?l0003o_9Rb
okbH/_nlV;82o`0000Co^iRc00?o0000okbI]?nlVK@00_nlVK@00ol0003o_9^fokbK]P02okbK]P05
o`000?nmWKOo_IfgokfM]ol000000onnWkT00ol0003o_Z6kokjQ^`02okjQ^`03o`000?noY;ko_jBn
00;o_jBn00Go0000oknW`OnoYl7o_jO1o`000003ol2[a004o`000?o1[lSo`Jo8ol6_b2Oo00002ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o0000
@?ooool00ol0003o2FSLo`UXg003oa1Xg0Co76[L0ol000000ommU=oo0000oh>Cf`02oh>Cf`04o`00
0?n:TmKoRY?Fo`0000?oT9?B00?o0000oiJBc_nFT/h00_nFT/h01Ol0003oVi?:oi^Cb_nKTl[o0000
00?oX9?600?o0000ojBC`onTTl<00_nTTl<01Ol0003oZ9?0ojRC`?nXTl3o000000CoZi>n00?o0000
ojjC^on^Tk/00_n^Tk/01Ol0003o/9Biok2D^On`U;Wo000000Co/iBg0ol000000onaTkOo]9>eokBC
]@03okBC]@03o`000?nfU;Co]YBd00;o]YBd00?o0000okRD/_nhU;800_nhU;800ol0003o^IBbokVD
/P03okVD/P03o`000?njU;7o000000;o^YFa00Ko0000okZE/OnjUK7o0000okZF/Ol00002ok^F/@04
o`000?nkU[7o^iJao`0000;o^iJa00?o0000okbG/_l000000onkUk400ol0003o_9RbokbH/P02okbH
/P;o00000onkV;<01Ol0003o_9VdokbI]?nlVKCo000000Go_9^f00Go0000okfM]onmWKOo_Ifgo`00
0003okjO^@05o`000?nnXK_o_Z6kokjQ^ol000001?noY;h00ol0003o_jO1oknW`@02oknW`@04o`00
0?o0ZlCo`:_4o`0000Go`Jo800Go0000ol6cc?o1/lco`K?<o`000003ol6gd005o`000?o1_=Go`KcE
ol6leOl000000oo1`MX01Ol0003o_lKOoko6gonoa]oo000000?o_L_U00?o0000ok[?jOnjcnT00_nj
cnT01Ol0003o]m;^okOBk_ngd^ko000000;o/]Gb00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo1?l00014ooooo`03o`000?l9J=co2FSL00?o46SL0olLJ]`3ob]^g@Co0000
00?oPi?Ko`000?n:TmH00_n:TmH01?l0003oT9?Boi2Cd_l00004oiJBcP05o`000?nKTl[oVi?:oi^C
b_l000001?nPTlH00ol0003oY9?3ojBC``02ojBC``05o`000?nXTl3oZ9?0ojRC`?l000000on[Tkh0
0ol0003o[Y>kojjC^`02ojjC^`05o`000?n`U;Wo/9Biok2D^Ol000000_ncU;L3o`0000?o/I>g00?o
0000okBC]OndTkD00ondTkD01Ol0003o]YBdokJD]?nfU;Co000000?o^9Bb0_l00006okVD/P05o`00
0?njUK7o^YFaokZE/Ol000000_njUK400ol0003o^YJao`000002ok^F/@06o`000?nkU[7o^iJao`00
0?nkU[7o00000_nlUk801?l0003o^iNaok^G/Ol00005okbH/P03o`000?nmV[Co000000;o^iRc00Go
0000okbI]?nlVKCo_9Vdo`000004okbK]P05o`000?nmWKOo_IfgokfM]ol000001?nnWkT01Ol0003o
_Z6kokjQ^onnXK_o000000Co_jBn00Go0000oknW`OnoYl7o_jO1o`000003ol2[a003o`000?o1[lSo
`Jo800;o`Jo800Go0000ol6cc?o1/lco`K?<o`000003ol6gd005o`000?o1_=Go`KcEol6leOl00000
0oo1`MX01Ol0003o_lKOoko6gonoa]oo000000?o_L_U00?o0000ok[?jOnjcnT00_njcnT01Ol0003o
]m;^okOBk_ngd^ko000000;o/]Gb00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Kooooo000Nooooo`;o0000Aoooool00ol0003o2FSLo`UXg003oa1Xg0?o
76[L0ol[K]d3ocacg@Co000000?oRY?Fo`000?n@Tm800_n@Tm800ol0003oUY;>oiJBcP02oiJBcP05
o`000?nKTl[oVi?:oi^Cb_l000000onPTlH00ol0003oY9?3ojBC``02ojBC``05o`000?nXTl3oZ9?0
ojRC`?l000000on[Tkh00ol0003o[Y>kojjC^`02ojjC^`03o`000?n`U;Wo000000Co00000_n^T[T5
ok6C]`03o`000?ndTkGo]9>e00;o]9>e00Go0000okJD]?nfU;Co]YBdo`000002okRD/P04o`000?ng
U;?o]iBco`0000Go^IBb00Co0000okZE/OnjUK7o00000onjUK400ol0003o^YJao`000002ok^F/@04
o`000?nkU[7o^iJaok^F/@;o00000onlUk800ol0003o^iNao`000004okbH/P04o`000?nmV[Co_IZd
okfJ]0;o00001?nlVK@00ol0003o_9^fokbK]P02okbK]P05o`000?nmWKOo_IfgokfM]ol000000onn
WkT00ol0003o_Z6kokjQ^`02okjQ^`03o`000?noY;ko_jBn00;o_jBn00Go0000oknW`OnoYl7o_jO1
o`000003ol2[a003o`000?o1[lSo`Jo800;o`Jo800Go0000ol6cc?o1/lco`K?<o`000003ol6gd005
o`000?o1_=Go`KcEol6leOl000000oo1`MX01Ol0003o_lKOoko6gonoa]oo000000;o_L_U00?o0000
ok[?jOnjcnT00_njcnT01Ol0003o]m;^okOBk_ngd^ko000000;o/]Gb00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`000?oooooo
oooo04Gooooo00?o0000o`UXg?l000000_l@J=`01?l0003o76[LoaaZg?lLJ]`3ob]^g@?o?7?M0om>
NM`4o`000003oi2Cd_l0003oUY;>00?oUY;>00Go0000oi^Cb_nKTl[oVi?:o`000003oj2CaP03o`00
0?nTTl?oY9?300;oY9?300Go0000ojRC`?nXTl3oZ9?0o`000003oj^C_P03o`000?n^Tk_o[Y>k00Co
00000_nZTK`5ojjB^@03o`000?naTkOo/I>g00;o/I>g00?o0000okBC]OndTkD00_ndTkD00ol0003o
]YBdokJD]002okJD]0;o00000ongU;<00ol0003o^IBbokVD/P02okVD/P05o`000?niUK;o0000okZE
/Ol000000_njUK401?l0003o^YJaokZF/Ol00003ok^F/@04o`000?nkU[7o^iJao`0000Co_9Nb00?o
0000ok^G/Ol000001?nlV;800ol0003o_IZdokfJ]002okfJ]0;o00000onlVK@00ol0003o_9^fokbK
]P02okbK]P05o`000?nmWKOo_IfgokfM]ol000000onnWkT01Ol0003o_Z6kokjQ^onnXK_o000000Co
_jBn00?o0000oknW`OnoYl400_noYl401?l0003o`:_4ol2[a?l00005ol6_b005o`000?o1/lco`K?<
ol6cc?l000000_o1]m001Ol0003o`KcEol6leOo1_=Go000000?o`L7J00Go0000oko6gonoa]oo_lKO
o`000003okg;i@05o`000?njcnWo^/oYok[?jOl000000ongd^h01?l0003o/]Gbok;El_l0000Boooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0AOooool00ol0003o2FSLo`000002oa1Xg004o`000?lLJ]co76[Lo`0000;o:fkM00Co0000ocac
gOllLmgo?7?M0om>NM`3oemnfPGo000000?oUY;>o`000?nKTlX00_nKTlX01Ol0003oX9?6oj2Ca_nP
TlKo000000CoY9?300Ko0000ojRC`?nXTl3oZ9?0o`000?n[Tkh5o`0000;oYY2o1?nZTK`00ol0003o
[Y:iojjB^@03ojjB^@05o`000?naTkOo/I>gok6C]ol000001?ndTkD00ol0003o]YBdokJD]002okJD
]003o`000?ngU;?o]iBc00?o]iBc00Co0000okVD/_niU;;o00000_niUK800ol0003o^YFao`000002
okZE/@04o`000?njU[7o^YJao`0000?o^iJa00Co0000ok^F/Ol0003o00001OnlUk800ol0003o_9Rb
okbH/P02okbH/P03o`000?nmV[Co_IZd00?o_IZd00?o0000okjL]_l000000_nlVK@01Ol0003o_9^f
okbK]_nlVkKo000000?o_Ifg00?o0000okjO^OnnWkT00_nnWkT01Ol0003o_Z6kokjQ^onnXK_o0000
00Co_jBn00Go0000oknW`OnoYl7o_jO1o`000003ol2[a003o`000?o1[lSo`Jo800;o`Jo800Go0000
ol6cc?o1/lco`K?<o`000003ol6gd005o`000?o1_=Go`KcEol6leOl000000_o1`MX01Ol0003o_lKO
oko6gonoa]oo000000?o_L_U00Go0000ok[?jOnjcnWo^/oYo`000003okOBkP04o`000?nbeO;o/]Gb
o`0001Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`008_ooool00ol0
003oooooooooo`14ooooo`04o`000?l9J=co2FSLo`0000;o46SL0olLJ]`01?l0003o:fkMob]^gOl0
0002ocacg@04o`000?m>NMcoCWWLodiig0?oGgkJ1?m_P]HDo`0000;oX8o21OnVT;l00ol0003oZY6l
ojZA_002ojZA_003o`000?n^T[Wo[Y:i00;o[Y:i00Go0000ok6C]onaTkOo/I>go`000004okBC]@04
o`000?nfU;Co]YBdokJD]0;o00001OngU;<01?l0003o^IBbokVD/_l00003okVE/P;o00000_njUK40
1?l0003o^YJaokZF/Ol00003ok^F/@;o000000?o^iNbo`000?nlUk801?nlUk800ol0003o_9RbokbH
/P02okbH/P03o`000?nmV[Co_IZd00;o_IZd00Co0000okjL]_nnW;Ko_Ybf0_l00004okbK]P05o`00
0?nmWKOo_IfgokfM]ol000000onnWkT00ol0003o_Z6kokjQ^`02okjQ^`03o`000?noY;ko_jBn00;o
_jBn00Go0000oknW`OnoYl7o_jO1o`000003ol2[a003o`000?o1[lSo`Jo800;o`Jo800Go0000ol6c
c?o1/lco`K?<o`000002ol6gd005o`000?o1_=Go`KcEol6leOl000000oo1`MX01Ol0003o_lKOoko6
gonoa]oo000000;o_L_U00?o0000ok[?jOnjcnT00_njcnT01?l0003o]m;^okOBk_l00002ok;ElP03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`00
8oooool2o`0004Gooooo00Co0000o`UXg?l9J=co00000_l@J=`2oaaZg004o`000?l[K]go:fkMob]^
g@?o?7?M0om>NM`01?l0003oGgkJoemnf_mOO]X4ofn2ePCoO8KB1?n7RLh5oi6<bPCoVHk61?nPSl80
0ol0003oYY2oojJ@_`03ojJ@_`CoZY6l00?o0000ojjB^On^T[T00_n^T[T00ol0003o/I>gok6C]`02
ok6C]`03o`000?ndTkGo]9>e00;o]9>e00?o0000okJD]?l000000_neU;D00ol0003o]iBcokND/`02
okND/`03o`000?niU;;o000000Co^IFb00?o0000okVF/ol000000_l00002okZF/@03o`000?nkU[7o
000000;o00000onkUk801ol0003o_9NbokbG/_nlUk;o0000okfI/ol000000onlV;800ol0003o_IZd
okfJ]002okfJ]003o`000?nnW;Ko_Ybf00;o_Ybf0_l00003okbK]P05o`000?nmWKOo_IfgokfM]ol0
00000onnWkT00ol0003o_Z6kokjQ^`02okjQ^`05o`000?noY;ko_jBnoknT__l000001?noYl401?l0
003o`:_4ol2[a?l00004ol6_b005o`000?o1/lco`K?<ol6cc?l000000oo1]m001Ol0003o`KcEol6l
eOo1_=Go000000;o`L7J00Go0000oko6gonoa]oo_lKOo`000003okg;i@05o`000?njcnWo^/oYok[?
jOl000000_ngd^h01?l0003o/]Gbok;El_l0000Gooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool01Oooool002Gooooo00?o0000ooooooooool0@oooool01_l0003o2FSLo`UXg?l0003o
46SLo`0000;o76[L00Co0000ob]^gOl[K]go00000_llLmd01?l0003oCWWLodiig?m>NM`3oemnfP03
o`000?m_P]KoKh;F00;oKh;F1?mlQ]84ohN9cPCoTHc:00Go0000oiV>a_nIS/KoVHk6o`000004oj2?
`PGoYY2o00Go0000ojZA_?nZTKcoZY6lo`000004ojjB^@03o`000?naTkOo/I>g00;o/I>g00?o0000
okBC]OndTkD00_ndTkD2o`0000?o]IBe00?o0000okND/ongU;<00ongU;<00ol0003o^IFbokVE/P03
okVE/P04o`000?niU[?o^IJcokVF/`Go00000_nkUk<01Ol0003o^iNbok^G/_nkUk;o000000;o_9Nb
00Oo0000okfI/onmVK?o_IVco`000?nlV;;o000000Co_IZd00?o0000okjL]_nnW;H00onnW;H00ol0
003o_ingo`000002okbK]P04o`000?nmWKOo_Ifgo`0000Co_Yni00Go0000okjQ^onnXK_o_Z6ko`00
0004oknT_P05o`000?noYl7o_jO1oknW`Ol000000oo0Zl@00ol0003o`Jo8ol6_b002ol6_b005o`00
0?o1/lco`K?<ol6cc?l000000_o1]m001Ol0003o`KcEol6leOo1_=Go000000?o`L7J00Go0000oko6
gonoa]oo_lKOo`000002okg;i@05o`000?njcnWo^/oYok[?jOl000000_ngd^h01?l0003o/]Gbok;E
l_l0000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o
0000ooooooooool0@oooool00ol0003o2FSLo`000002oa1Xg004o`000?lLJ]co76[Lo`0000;o:fkM
00Co0000ocacgOllLmgo00000_m>NM`01?l0003oGgkJoemnf_mOO]X4ofn2ePCoO8KB1?n7RLh5oi6<
bPCoVHk61?nPSl800ol0003oYY2oojJ@_`02ojJ@_`05o`000?nZTKcoZY6lojZA_?l000001?n^T[T0
0ol0003o/I>gok6C]`02ok6C]`03o`000?ndTkGo]9>e00;o]9>e00?o0000okFD]OneU;D00oneU;D0
0ol0003o]iBcokND/`02okND/`03o`000?niUK;o^IFb00;o^IFb00?o0000okVF/oniU[<00_niU[<0
1?l0003o^YNcokZG/ol00003ok^G/`05o`000?nkUk;o^iNbok^G/_l000000_nlUk801ol0003o_IVc
okfI/onmVK?o0000okbH/_l000001?nmV[@00ol0003o_YbfokjL]P02okjL]P04o`000?noWkOo_ing
oknO]`;o00000onmWKL00ol0003o_YniokjO^@02okjO^@05o`000?nnXK_o_Z6kokjQ^ol000001?no
Y;h01Ol0003o_jO1oknW`OnoYl7o000000?o`:_400Go0000ol6_b?o1[lSo`Jo8o`000003ol6cc005
o`000?o1]m3o`KO@ol6gd?l000000oo1_=D01?l0003o`L7Jol71f_l00003oko6g`04o`000?nmbnGo
_L_Uo`0000?o^/oY00Oo0000okOBk_ngd^ko]m;^o`000?nbeO;o000001_ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`05ooooo`009oooool00ol0003oooooooooo`13ooooo`03o`00
0?l9J=co000000;o46SL00?o0000oaaZg?l000000_l[K]d01?l0003o?7?MocacgOl00003odiig0?o
GgkJ00Go0000ofn2e_m_P]KoKh;Fo`000003ogb6dP05o`000?n7RLkoQhW>ohN9c_l000001?nAS<X0
1Ol0003oVHk6oiV>a_nIS/Ko000000?oX8o200?o0000ojJ@_onVT;l00_nVT;l00ol0003oZY6lojZA
_002ojZA_003o`000?n^T[Wo[Y:i00;o[Y:i00Go0000ok6C]onaTkOo/I>go`000003okBC]@;o0000
1OneU;D01ol0003o]iBcokND/ongU;?o0000okRF]?l000000oniUK800ol0003o^IJcokVF/`02okVF
/`04o`000?njUk?o^YNco`0000?o^iNc00?o0000ok^G/_nkUk800_nkUk82o`0000Go_IVc00?o0000
okfJ]?nmV[@00_nmV[@00ol0003o_YbfokjL]P03okjL]P03o`000?noWkOo_ing00;o_ing0_l00002
okfM]`05o`000?nnWkWo_YniokjO^Ol000001?nnXK/01Ol0003o_jBnoknT__noY;ko000000Co_jO1
00Co0000ol2[a?o0ZlCo00001?o1[lP01Ol0003o`K?<ol6cc?o1/lco000000;o`KO@00Go0000ol6l
eOo1_=Go`KcEo`000003ol71fP04o`000?noa]oo_lKOo`0000?o_L_U00Co0000ok[?jOnjcnWo0000
0ongd^h00ol0003o/]Gbo`00000Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1Oooool002Sooooo0_l00014ooooo`03o`000?l9J=co000000;o46SL00?o0000oaaZg?l000000_l[
K]d01?l0003o?7?MocacgOl00002odiig004o`000?mOO][oGgkJo`0000CoKh;F00Go0000ogb6d_ml
Q];oO8KBo`000003ohN9cPCoTHc:00Go0000oiV>a_nIS/KoVHk6o`000004oj2?`P03o`000?nVT;oo
YY2o00;oYY2o00Go0000ojZA_?nZTKcoZY6lo`000004ojjB^@05o`000?naTkOo/I>gok6C]ol00000
0_ndTkD01?l0003o/iBgok>D]ol00004okFD]@05o`000?ngU;?o]iBcokND/ol000000_nhU[@01?l0
003o^IFbokVE/_l00003okVF/`05o`000?njUk?o^YNcokZG/ol000000onkUk<00ol0003o^iNbok^G
/P02ok^G/P03o`000?nmVK?o_IVc00Co_IVc00?o0000okfJ]?nmV[@00_nmV[@00ol0003o_YbfokjL
]P03okjL]P03o`000?noWkOo_ing00;o_ing00Co0000ol6R^_l0003o00001?nnWkT00ol0003o_Z6k
okjQ^`02okjQ^`05o`000?noY;ko_jBnoknT__l000000onoYl401Ol0003o`:_4ol2[a?o0ZlCo0000
00Co`Jo800Go0000ol6cc?o1/lco`K?<o`000002ol6gd005o`000?o1_=Go`KcEol6leOl000000_o1
`MX01Ol0003o_lKOoko6gonoa]oo000000;o_L_U00Co0000ok[?jOnjcnWo00000ongd^h00ol0003o
/]Gbo`00000Nooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002[ooooo
00?o0000ooooooooool0@_ooool3o`000005oa1Xg?l0003o76[LoaaZg?l000000_l[K]d01?l0003o
?7?MocacgOl00002odiig004o`000?mOO][oGgkJo`0000?oKh;F00Go0000ogb6d_mlQ];oO8KBo`00
0003ohN9cP05o`000?nAS<[oTHc:oi6<b_l000001?nIS/H01Ol0003oX8o2oj2?`_nPSl;o000000Co
YY2o00Go0000ojZA_?nZTKcoZY6lo`000004ojjB^@03o`000?naTkOo/I>g00;o/I>g0_l00003ok>D
]`03o`000?neU;Go]IBe00?o]IBe00?o0000okND/ol000001?nhU[@2o`0000Co^IJc00Go0000okZG
/onjUk?o^YNco`000004ok^G/`03o`000?nkUk;o^iNb00;o00001OnmVK<00ol0003o_Ybeo`000003
okfJ]003o`000?nnW;Ko_Ybf00;o_Ybf00?o0000oknO]onoWkL00_noWkL01?l0003o`J:jol6R^_o1
X[X2o`0000?o_Yni00Go0000okjQ^onnXK_o_Z6ko`000004oknT_P05o`000?noYl7o_jO1oknW`Ol0
00000oo0Zl@01Ol0003o`Jo8ol6_b?o1[lSo000000?o`K?<00Go0000ol6gd?o1]m3o`KO@o`000003
ol6le@04o`000?o1`M[o`L7Jo`0000;o_lKO00Go0000okg;iOnmbnGo_L_Uo`000002ok[?j@06o`00
0?ngd^ko]m;^o`000?nbeO;o00008?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Cooooo000[ooooo`03o`000?oooooooooo04?ooooo00KoP`00o`000?l0003o0000oaaZg?l00002
ob]^g@04o`000?llLmgo?7?Mo`0000;oCWWL00Co0000oemnf_mOO][o00001?m_P]H01?l0003oO8KB
ogb6d_l00003ohN9cP03o`000?nAS<[oTHc:00;oTHc:00Go0000oiV>a_nIS/KoVHk6o`000003oj2?
`P03o`000?nVT;ooYY2o00;oYY2o00Go0000ojZA_?nZTKcoZY6lo`000004ojjB^@04o`000?naTkOo
/I>gok6C]`;o00001?ncU;L00ol0003o]IBeokFD]@03okFD]@03o`000?ngU;?o000000Go^9Jd0_l0
0003okVF/`05o`000?njUk?o^YNcokZG/ol000001?nkUk<00ol0003o^iNbo`000002okbJ]005o`00
0?nmVK?o_IVcokfI/ol000000onnW;D00ol0003o_IZdo`000005okjL]P03o`000?noWkOo_ing00;o
_ing00Ko0000ol6R^_o1X[[o`J:jo`000?o3Y[`3o`0000Co_Z6k00Go0000oknT__noY;ko_jBno`00
0004oknW`@04o`000?o0ZlCo`:_4o`0000Co`Jo800Go0000ol6cc?o1/lco`K?<o`000002ol6gd005
o`000?o1_=Go`KcEol6leOl000000_o1`MX01Ol0003o_lKOoko6gonoa]oo000000;o_L_U00Co0000
ok[?jOnjcnWo00000_ngd^h00ol0003o/]Gbo`00000Rooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@oooool2oh<000;o000000Go76[L
o`000?l[K]go:fkMo`000002ocacg@04o`000?m>NMcoCWWLo`0000;oGgkJ00Go0000ofn2e_m_P]Ko
Kh;Fo`000003ogb6dP05o`000?n7RLkoQhW>ohN9c_l000000onAS<X01Ol0003oVHk6oiV>a_nIS/Ko
000000?oX8o200?o0000ojJ@_onVT;l00_nVT;l00ol0003oZY6lojZA_002ojZA_005o`000?n^T[Wo
[Y:iojjB^Ol000000_naTkL00ol0003o[iBjo`000005ok>D]`03o`000?neU;Go]IBe00?o]IBe00?o
0000okRF]?nhU[@01?nhU[@00ol0003o^INeo`000002okVF/`05o`000?njUk?o^YNcokZG/ol00000
1?nkUk<2o`0000?o_9Zd00Co0000okfI/onmVK?o00001?nnW;D00ol0003o_IZdo`000004okjL]P03
o`000?noWkOo_ing00;o_ing00Go0000ol6R^_o1X[[o`J:jo`000004ol>V_0;o00000onnXK/01Ol0
003o_jBnoknT__noY;ko000000?o_jO100Go0000ol2[a?o0ZlCo`:_4o`000003ol6_b005o`000?o1
/lco`K?<ol6cc?l000000oo1]m001ol0003o`KcEol6leOo1_=Go0000ol71f_l000000onoa]l01?l0
003o_L_Uokg;iOl00002ok[?j@03o`000?ngd^ko]m;^00?o00008oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Cooooo000]ooooo`;o0000AOooool2oh<000;o00000_l[K]d01?l0
003o?7?MocacgOl00002odiig004o`000?mOO][oGgkJo`0000?oKh;F00Go0000ogb6d_mlQ];oO8KB
o`000003ohN9cP05o`000?nAS<[oTHc:oi6<b_l000000onIS/H00ol0003oX8o2oj2?`P02oj2?`P05
o`000?nVT;ooYY2oojJ@_ol000001?nZTK`00ol0003o[Y:iojjB^@02ojjB^@;o00000on_U;X00ol0
003o/iBgok>D]`02ok>D]`03o`000?neU;Go]IBe00?o]IBe00?o0000okRF]?nhU[@00onhU[@01?l0
003o^INeokVG]OniUkD2o`0000Co^YNc00?o0000ok^G/onkUk<00ol00004okbJ]004o`000?nmVK?o
_IVco`0000Go_Ybe00?o0000okjL]_nnW;H00onnW;H00ol0003o_ingoknO]`02oknO]`05o`000?o1
X[[o`J:jol6R^_l000001?o3Y[`00ol0003oaJ_0o`000002o`0000Co_jBn00Go0000oknW`OnoYl7o
_jO1o`000003ol2[a005o`000?o1[lSo`Jo8ol6_b?l000000oo1/l`01?l0003o`KO@ol6gd?l00003
ol6le@04o`000?o1`M[o`L7Jo`0000;o_lKO00Ko0000okg;iOnmbnGo_L_Uo`000?njcnT5o`0002Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`00;oooool00ol0003ooooo
ooooo`13ooooo`?oP`0000Co0000ob]^gOl[K]go00000_llLmd01?l0003oCWWLodiig?l00002oemn
fP05o`000?m_P]KoKh;Fofn2e_l000000omlQ]801Ol0003oQhW>ohN9c_n7RLko000000?oTHc:00Go
0000oiV>a_nIS/KoVHk6o`000003oj2?`P03o`000?nVT;ooYY2o00;oYY2o00Go0000ojZA_?nZTKco
ZY6lo`000003ojjB^@;o00001?n_U;X00ol0003o/iBgok>D]`03ok>D]`07o`000?neU;Go]IBeokFD
]Ol0003o]YJgo`000004okRF]003o`000?niUkGo^INe00;o^INe2?l00002ok^I]@03o`000?nlV[Co
_9Zd00?o_9Zd0_l00006okjL]@;o00000onnW;H00ol0003o_ingoknO]`02oknO]`05o`000?o1X[[o
`J:jol6R^_l000001?o3Y[`00ol0003oaJ_0olF[`002olF[`0?o000000?o_jBno`000?noYl400ono
Yl401?l0003o`:_4ol2[a?l00003ol6_b005o`000?o1/lco`K?<ol6cc?l000000oo1]m001ol0003o
`KcEol6leOo1_=Go0000ol71f_l000000onoa]l00ol0003o_L_Uokg;i@07o`0002Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`13oooo
o`?oP`000_l000001?l[K]go0000ocacgOl00002odiig004o`000?mOO][oGgkJo`0000?oKh;F00Go
0000ogb6d_mlQ];oO8KBo`000003ohN9cP05o`000?nAS<[oTHc:oi6<b_l000000onIS/H01Ol0003o
X8o2oj2?`_nPSl;o000000CoYY2o00Go0000ojZA_?nZTKcoZY6lo`000002ojjB^@03o`000?n[Tkgo
000000Go[iBj00?o0000ok>D]oncU;L00_ncU;L01?l0003o]IBeokFD]Ol00003okJF]`04o`000?nh
U[Co^9Jdo`0000Go^INe00?o0000okZH]OnjV;D00_njV;D00ol0003o^iVeok^I]@02ok^I]@03o`00
0?nlV[Co_9Zd00?o_9Zd00?o0000okjL]OnnW;D01?nnW;D01?l0003o_ingoknO]ol00002okjL]P03
o`000?noWkOo_ing00;o_ing00Go0000ol6R^_o1X[[o`J:jo`000004ol>V_003o`000?o5Zl3oaJ_0
00;oaJ_000?o0000olN``oo7/<<01?l000000onoYl7o0000ol2[a002ol2[a005o`000?o1[lSo`Jo8
ol6_b?l000000oo1/l`01?l0003o`KO@ol6gd?l00003ol6le@03o`000?o1`M[o`L7J00So000000Co
[OK`o`000?l0003o0000:oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo
000aooooo`;o0000AOooool2oh<00003og/00?l0003o000000;o?7?M00Co0000odiig?m>NMco0000
0_mOO]X01?l0003oKh;Fofn2e_l00003ogb6dP05o`000?n7RLkoQhW>ohN9c_l000000onAS<X01Ol0
003oVHk6oiV>a_nIS/Ko000000?oX8o200?o0000ojJ@_onVT;l00_nVT;l00ol0003oZY6lojZA_002
ojZA_0;o00000on[Tkd00ol0003o[iBjojnD^P02ojnD^P03o`000?ncU;Oo/iBg00;o/iBg00?o0000
okFD]Ol000001?nfU[L01?l0003o^9JdokRF]?l00005okVG]@03o`000?njV;Go^YRe00;o^YRe00?o
0000ok^I]OnkVKD00_nkVKD00ol0003o_9ZdokbJ]002okbJ]0;o00001OnnW;D00ol0003o_ingoknO
]`02oknO]`03o`000?nnW;Ko000000Co_ing00Go0000ol6R^_o1X[[o`J:jo`000003ol>V_003o`00
0?o5Zl3oaJ_000;oaJ_000?o0000olN``oo7/<<00_o7/<<00ol0003obKO8olVgb004o`000003ol2[
a?l0003o`Jo800;o`Jo800Go0000ol6cc?o1/lco`K?<o`000002ol6gd004o`000?o1_=Go`KcEol6l
e@Go00000_o1m?001?l0003o]oK`o`000?n]m_02o`0002gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`03ooooo`00<oooool00ol0003oooooooooo`13ooooo`;oP`0000?oN`00o`0G
T_l000000_l00002odiig004o`000?mOO][oGgkJo`0000?oKh;F00Go0000ogb6d_mlQ];oO8KBo`00
0003ohN9cP04o`000?nAS<[oTHc:o`0000?oVHk600?o0000oj2?`_nPSl800_nPSl801Ol0003oYY2o
ojJ@_onVT;oo000000?oZY6l0_l00004oj^C_@03o`000?n_U;[o[iBj00?o[iBj00?o0000ok>D]onc
U;L00_ncU;L00ol0003o]YJgokJF]`04okJF]`03o`000?nhU[Co000000Go^INe00?o0000okZH]Onj
V;D00_njV;D00ol0003o^iVeok^I]@03ok^I]@04o`000?nlV[Co_9Zdo`0000;o_Ibg00?o0000okjL
]OnnW;D00_nnW;D00ol0003o_ingoknO]`03oknO]`03o`000?noWkOo_ing00;o_ing00Go0000ol6R
^_o1X[[o`J:jo`000004ol>V_003o`000?o5Zl3oaJ_000;oaJ_000Go0000olN``oo7/<?oak33o`00
0004olVgb003o`000?o<_Lgoc;g=017o000000?oc^WYo`000?l000000_o1m?06o`0002oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?ooool00ol0003oooooooooo`14
ooooo`05oh<00?mk003o01NBo`000?l0::L00_l000001?m>NMco0000oemnf_l00003ofn2eP05o`00
0?mlQ];oO8KBogb6d_l000000on7RLh01Ol0003oTHc:oi6<b_nAS<[o000000?oVHk600Go0000oj2?
`_nPSl;oX8o2o`000004ojJ@_`?o000000?oYY;1o`000?n[Tkd01?n[Tkd00ol0003o[iBjojnD^P02
ojnD^P03o`000?ncU;Oo/iBg00;o/iBg00?o0000okJF]onfU[L01OnfU[L2o`0000Co^INe00?o0000
okZH]OnjV;D00onjV;D00ol0003o^iVeok^I]@03ok^I]@03o`000?nlV[Co000000?o_Ibg00Go0000
okjL]OnnW;Go_Ybeo`000006oknO]`03o`000?noWkOo_ing00;o_ing00Go0000ol6R^_o1X[[o`J:j
o`000003ol>V_003o`000?o5Zl3oaJ_000;oaJ_000?o0000olN``oo7/<<00_o7/<<01Ol0003obKO8
olVgb?o9]lSo000000?oc;g=00Go0000olk5d_o>aM;oc/GBo`000003om3>f004o`000?o@emkod=ON
o`0000?od>3T00Co0000olkYjOl0003o00000_o1m?05o`0003;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003oooooooooo`14ooooo`03oh<00?mk003o
01NB00;o000000?o03fmo`000?l000000_mOO]X01Ol0003oKh;Fofn2e_m_P]Ko000000;oO8KB00Go
0000ohN9c_n7RLkoQhW>o`000003oi6<bP05o`000?nIS/KoVHk6oiV>a_l000000onPSl801?l0003o
YY2oojJ@_onVT;l2o`0000CoYY;100?o0000oj^C_On[Tkd00_n[Tkd00ol0003o[iBjojnD^P02ojnD
^P07o`000?ncU;Oo/iBgok>D]ol0003o/iJio`000006okJF]`04o`000?ngV;So0000o`0000;o^INe
00?o0000okZH]OnjV;D00onjV;D00ol0003o^iVeok^I]@03ok^I]@;o00001OnmW;L01?l0003o_Ybe
okjL]Ol00005oknO]`03o`000?o1Xk[o000000;o_ing00Go0000ol6R^_o1X[[o`J:jo`000004ol>V
_003o`000?o5Zl3oaJ_000;oaJ_000Go0000olN``oo7/<?oak33o`000003olVgb005o`000?o<_Lgo
c;g=olbmcOl000000oo>aM801Ol0003od<kHom3>f?o@c]So000000;od=ON00Ko0000om3Pi?o@h>Co
d>3To`000?o>jNT2o`000003ol7dl?l0003o000000Co0000=?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00?ooooo000fooooo`;o0000AOooool00ol0003oN`00o`0GTP02o`0000;o
03fm0ol00003ofn2eP05o`000?mlQ];oO8KBogb6d_l000000on7RLh01?l0003oTHc:oi6<b_l00003
oiV>aP03o`000?nPSl;oX8o200;oX8o20ol000000onOTLKo0000ojJB`@03ojJB`@03o`000?n[Tkgo
Zi>m00?oZi>m00?o0000ojnD^_n_U;X00_n_U;X00ol0003o/iBgo`000003ok>F^@03o`000?nfU[Oo
]YJg00;o]YJg00?o0000okNH^?ngV;P00_ngV;P3o`0000Go^YRe00?o0000ok^I]OnkVKD00_nkVKD2
o`0000Ko_Ibg00?o0000okjL]Ol000001OnoWkL01ol0003o`J>jol6S^_o1Xk[o0000oknO]ol00000
0oo1X[X01Ol0003o`jJlol>V_?o3Y[co000000CoaJ_000Go0000olN``oo7/<?oak33o`000004olVg
b004o`000?o<_Lgoc;g=o`0000?oc/GB00Go0000om3>f?o@c]Sod<kHo`000002om3GgP06o`000?o@
h>Cod>3Tom3Pi?l0003oc^WY0_l000000oo1m?3o0000o`000003o`0003Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`06og/0
0?l05i;o0000o`000?l0?Kgo00000_l0Dll4o`0000?oO8KB00Go0000ohN9c_n7RLkoQhW>o`000002
oi6<bP03o`000?nIS/KoVHk600;oVHk600?o0000oj2?`_l000000_l00004oinAaP03o`000?nVT/7o
YY;100;oYY;100?o0000oj^C_On[Tkd00_n[Tkd00ol0003o[iBjojnD^P02ojnD^P03o`000?ncU;Oo
000000Co/iJi00Go0000okJF]onfU[Oo]YJgo`000006okNH^0Co00000_njV;D00ol0003o^iVeo`00
0002o`000003okbL^?l0003o_Ibg00Go_Ibg0_l00005oknO]`03o`000?o1Xk[o`J>j00?o`J>j00Go
0000ol6R^_o1X[[o`J:jo`000004ol>V_003o`000?o5Zl3oaJ_000;oaJ_000Go0000olN``oo7/<?o
ak33o`000003olVgb005o`000?o<_Lgoc;g=olbmcOl000000oo>aM801?l0003od<kHom3>f?l00002
om3GgP06o`000?o@h>Cod>3Tom3Pi?l0003oc^WY0_l000000oo1m?3o0000o`000003o`0003Sooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00>Oooool00ol0003ooooooooo
o`14ooooo`07oh<00?l05i;o0000o`000?l0?Kgo0000o`1Cc`03ob1WfPGo00000on7RLh01_l0003o
THc:oi6<b_nAS<[o0000oiV>aPCo00000_nFT</5oinAaP03o`000?nVT/7oYY;100;oYY;100?o0000
oj^C_On[Tkd00on[Tkd00ol0003o[iBjojnD^P02ojnD^P03o`000?ncU[Wo/iJi00Co/iJi00Co0000
okJF]onfU[Oo00001_ngV;P01?l0003o^YZhokZJ^?njV[P4o`0000Co_9bh00?o0000okfL]onmW;L0
0onmW;L00ol0003o_j2jo`000004oknO]`03o`000?o1Xk[o`J>j00Co`J>j0_l00002ol6R^P03o`00
0?o3Y[co`jJl00;o`jJl00Go0000olF[`?o5Zl3oaJ_0o`000003olN```03o`000?o9]lSobKO800;o
bKO800Co0000olbmcOo<_Lgo00000oo>aM801?l0003od<kHom3>f?l00002om3GgP06o`000?o@h>Co
d>3Tom3Pi?l0003oc^WY0_l000000oo1m?3o0000o`000002o`0003_ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`03ooooo`00>_ooool00ol0003oooooooooo`15ooooo`06o`0GT_l0
003o0000o`0m_Ol0003o05??0olPImX3odEgg@[o00000_n9SM45oiJ@b`GoWi7600?o0000ojJB`OnV
T/400_nVT/400ol0003oZi>moj^C_@02oj^C_@03o`000?n_U;[o[iBj00;o[iBj00?o0000ok>F^Onc
U[T01OncU[T2o`0000Oo]iRh00?o0000okZJ^?njV[P00onjV[P00ol0003o_9bhokbL^003okbL^003
o`000?nmW;Oo_Ibg00;o_Ibg00Go0000oknP^_noX;[o_j2jo`000003oknO]`03o`000?o1Xk[o`J>j
00?o`J>j00Ko0000ol>X__o3Z;ko0000ol6R^_l00003ol>V_005o`000?o5Zl3oaJ_0olF[`?l00000
1?o7/<<01Ol0003obKO8olVgb?o9]lSo000000?oc;g=00Co0000olk5d_o>aM;o00000oo@c]P01?l0
003od=ONom3Gg_l00002om3Pi005o`000?o>jNWo0000o`000?o1m?000ol0000nooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool003_ooooo0_l00016ooooo`?o000000?o03fm
o`000?l0Dll00olPImX3odEgg@CoHX7K0omiR=L5ohV=d@CoUY3;00?o0000oinAa_nOTLH00_nOTLH0
0ol0003oYY;1ojJB`@03ojJB`@03o`000?n[TkgoZi>m00;oZi>m00Ko0000ojnD^_n_U;[o0000ok2G
_Ol00007ok>F^@;o00001_ngV;P00ol0003o^YZhokZJ^003okZJ^003o`000?nlW;So_9bh00Co_9bh
00Co0000okfL]onmW;Oo00001?noX;X01?l0003o_ingoknO]ol00005ol6S^P03o`000?o3Z;ko`jRn
00;o`jRn00?o0000ol>V_?o3Y[`00_o3Y[`01Ol0003oaJ_0olF[`?o5Zl3o000000?oak3300Go0000
olVgb?o9]lSobKO8o`000003olbmc@05o`000?o>aM;oc/GBolk5d_l000000_o@c]P01?l0003od=ON
om3Gg_l00002om3Pi003o`000?o>jNWo000000Go0000?oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo000mooooo`03o`000?oooooooooo04Cooooo0ol000000ol0?Kgo0000
o`1Cc`03ob1WfP?oAGOM1?mRPM/3ogV8e`GoRHgA1?nFT</00ol0003oWi76oinAaP02oinAaP03o`00
0?nVT/7oYY;100;oYY;100?o0000oj^C_On[Tkd00_n[Tkd00ol0003o[iBjo`000003ok2G_@03o`00
0?ncU[Wo/iJi00Co/iJi00Co0000okJJ^ol0003o00000ongV;P00ol0003o^YZhokZJ^004okZJ^003
o`000?nlW;So_9bh00Co_9bh00?o0000okfL]ol000001OnoX;X00ol0003o_ingo`000005ol6S^P03
o`000?o3Z;ko`jRn00?o`jRn0_l00002ol>V_005o`000?o5Zl3oaJ_0olF[`?l000001?o7/<<01Ol0
003obKO8olVgb?o9]lSo000000;oc;g=00Go0000olk5d_o>aM;oc/GBo`000002om3>f004o`000?o@
emkod=ONo`0000;od>3T00?o0000olkYjOl000001?l00012ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool003kooooo00?o0000ooooooooool0A?ooool3o`000003o`0m_Ol0
003o05??00?o86OJ0om5Mmd4of:1f`?oNHSG1?n9SM400ol0003oUY3;oiJ@b`02oiJ@b`05o`000?nO
TLKoWi76oinAa_l000001OnVT/400ol0003oZi>moj^C_@02oj^C_@03o`000?n`Ukgo/9Nm00?o/9Nm
00?o0000ok>F^OncU[T00_ncU[T00ol0003o]YZkokJJ^`02okJJ^`04o`000?ngV;So]iRho`0000Ko
^YZh00?o0000okbL^?nlW;P01?nlW;P2o`0000Ko_j2j0_l00005ol6S^P03o`000?o3Z;ko`jRn00?o
`jRn00Ko0000olJ^`_o6[/;o0000ol>V_?l00003olF[`005o`000?o7/<?oak33olN``ol000000oo9
]lP01Ol0003oc;g=olbmcOo<_Lgo000000;oc/GB00Co0000om3>f?o@c]So00000_o@emh01Ol0003o
d>3Tom3Pi?l0003oc^WY00Go0000A?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo000oooooo`03o`000?oooooooooo04Cooooo0ol000000ol0?Kgo0000o`1Cc`02ob1WfP04
o`000?m5MmgoAGOModEgg@?oHX7K00Co0000ogV8eomiR=Oo00001?n9SM401Ol0003oUY3;oiJ@bonF
T<_o000000CoWi7600?o0000ojJB`OnVT/400_nVT/400ol0003oZi>moj^C_@02oj^C_@03o`000?n`
Ukgo/9Nm00Co/9Nm00Go0000ok>F^OncU[Wo/iJio`000005okJJ^`?o00001_njV[P00ol0003o_9bh
okbL^002okbL^0?o00001_noX;X00ol0003o`JFmo`000005ol6S^P03o`000?o3Z;ko`jRn00;o`jRn
00?o0000olJ^`_o6[/800_o6[/82o`0000;oaJ_000?o0000olN``oo7/<<00_o7/<<01?l0003obKO8
olVgb?l00003olbmc@07o`000?o>aM;oc/GBolk5d_l0003od<kHo`000002om3GgP05o`000?o@h>Co
d>3To`000?o>jNT01Ol00016ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool0043ooooo0_l00015ooooo`?o000000?o03fmo`000?l0Dll00_lPImX01?l0003oAGOModEggOl0
0003of:1f`04o`000?miR=OoNHSGo`0000?oRHgA00?o0000oiJ@bonFT</00_nFT</01Ol0003oWi76
oinAa_nOTLKo000000GoYY;100Ko0000oj^C_On[Tkgo0000ojbH`_l00006ok2G_@04o`000?ncU[Wo
/iJio`0000Oo]YZk1Ol00002okZJ^003o`000?nlW;So000000;o00000_nlWk/00ol0003o_j2joknP
^P03oknP^P05o`000?o1YKgo`JFmol6U_Ol000000oo1XkX00ol0003o`jRnol>X_P02ol>X_P03o`00
0?o6[/;oaZk200?oaZk200Go0000olVeaol0003oaJ_0o`000003olN```05o`000?o9]lSobKO8olVg
b?l000000_o<_Ld01ol0003oc/GBolk5d_o>aM;o0000om3>f?l000000_o@emh01Ol0003od>3Tom3P
i?l0003oc^WY00?o0000BOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
0012ooooo`03o`000?oooooooooo04?ooooo1?l00002o`1Cc`;o86OJ00Co0000odEggOm5Mmgo0000
0omRPM/01?l0003oNHSGogV8eol00003ohV=d@05o`000?nFT<_oUY3;oiJ@bol000001?nOTLH00ol0
003oYY;1ojJB`@02ojJB`@03o`000?n[Tkgo000000?o[9S200?o0000ok2G_On`Ukd01?n`Ukd2o`00
00So]YZk00?o0000okVM_?niWK`00_niWK`4o`0000Go_9nk00?o0000oknP^_noX;X00_noX;X00ol0
003o`JFmol6U_@02ol6U_@04o`000?o1Xk[o`J>jo`0000Go`jRn00?o0000olJ^`_o6[/800_o6[/80
1?l0003obKG7olVeaoo9]LL2o`0000;oak3300Go0000olVgb?o9]lSobKO8o`000003olbmc@07o`00
0?o>aM;oc/GBolk5d_l0003od<kHo`000002om3GgP04o`000?o@h>Co0000olkYj@;o0000C?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo
04Cooooo0ol000001Ol0Dloo0000ob1Wf_lPIm[o000000;oAGOM00Co0000of:1fomRPM_o00000_mi
R=L00ol0003oRHgAohV=d@02ohV=d@05o`000?nFT<_oUY3;oiJ@bol000000onOTLH00ol0003oYY;1
ojJB`@02ojJB`@;o00001On/V<800ol0003o/9Nmok2G_@04ok2G_@03o`000?nfV[_o]YZk00Ko]YZk
00?o0000okVM_?niWK`01?niWK`00ol0003o_9nkokbO^`04okbO^`05o`000?noX;[o_j2joknP^_l0
00001Oo1YKd00ol0003o`J>jo`000005ol>X_P03o`000?o6[/;oaZk200;oaZk200?o0000olVeaoo9
]LL00_o9]LL01Ol0003oc;k=o`000?o7/<?o000000?obKO800Co0000olbmcOo<_Lgo00000oo>aM80
0ol0003od<kHo`000002om3GgP04o`000?o@h>Co0000olkYj@;o0000C_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo04Cooooo0ol00000
1?l0Dloo0000ob1Wf_l00003odEgg@04o`000?mRPM_oHX7Ko`0000;oNHSG00Go0000ohV=dOn9SM7o
RHgAo`000003oiJ@b`03o`000?nOTLKoWi7600;oWi7600Ko0000ojJB`OnVT/7o0000ojFHb?l00006
ojbH`P03o`000?n`Ukgo/9Nm00?o/9Nm00?o0000ok>L`?l000001OnfV[/00ol0003o^IflokVM_005
okVM_003o`000?nlWk_o_9nk00Go_9nk00?o0000oknP^_l000001_o1YKd2o`0000Go`jRn00?o0000
olJ^`_o6[/800_o6[/800ol0003obKG7olVea`02olVea`04o`000?o<_/goc;k=olbnc@?o000000?o
bKO8o`000?o<_Ld00_o<_Ld01_l0003oc/GBolk5d_l0003od<kHo`0000;od=ON00?o0000om3Pi?l0
00000_l0001Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Gooooo
0_l00016ooooo`;o000000Co05??o`000?lPIm[o00000_m5Mmd01Ol0003oHX7Kof:1fomRPM_o0000
00;oNHSG00Go0000ohV=dOn9SM7oRHgAo`000003oiJ@b`07o`000?nOTLKoWi76oinAa_l0003oYY;1
o`000003ojFHb003o`000?n/V<;o[9S200?o[9S200?o0000ok2G_On`Ukd00_n`Ukd01?l0003o/ic0
ok>L`?ncW<02o`0000?o]YZk00?o0000okVM_?niWK`01OniWK`00ol0003o_9nkokbO^`05okbO^`;o
00001_o1YKd00ol0003o`j_2o`000004ol>X_P03o`000?o6[/;oaZk200;oaZk200?o0000olVeaoo9
]LL00_o9]LL00ol0003oc;k=olbnc@02olbnc@03o`000?o?bMCoclWD00?o000000?oc;g=o`000?o>
aM800_o>aM82o`0000;od=ON1?l0001Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00Oooool004Oooooo00?o0000ooooooooool0A?ooool2o`000004o`1Ccol0003o86OJo`0000;o
AGOM00Co0000of:1fomRPM_o00000_miR=L01Ol0003oRHgAohV=dOn9SM7o000000CoUY3;00?o0000
oinAa_nOTLH00_l00005ojFHb003o`000?n/V<;o[9S200?o[9S200Co0000ok2G_On`Ukgo00001_nc
W<001?l0003o]YZkokJJ^ol00007okVM_003o`000?nlWk_o_9nk00Co_9nk0_l00006ol6U_@05o`00
0?o3Zl;o`j_2ol>[`_l000000oo3Z;h01Ol0003oaZk2olJ^`_o6[/;o000000CobKG700?o0000olbn
cOo<_/d00_o<_/d01?l0003oclWDolo9e?l00002om;Fg0Co000000?oc/GBo`000?l000001_l0001E
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool004Sooooo00?o0000oooo
ooooool0AOooool01Ol0003o05??o`000?lPIm[o000000;oAGOM00Co0000of:1fomRPM_o00000_mi
R=L01Ol0003oRHgAohV=dOn9SM7o000000?oUY3;00?o0000oinAa_l000000_nLV<l00ol0003oYIS8
ojFHb003ojFHb003o`000?n/V<;o[9S200?o[9S200?o0000ok2G_Ol000001oncW<02o`0000So^Ifl
00Co0000okbO^onlWk_o_9nk0ol000000onmY<3o0000ol6U_@03ol6U_@;o00001?o3Zl801?l0003o
`jRnol>X__l00004olJ^`P05o`000?o9]LOobKG7olVeaol000001?o<_/d01?l0003oclWDolo9e?l0
0002om;Fg004o`000?oBi>Cod^CTom;Ti0;o00000_o4n^T4o`0005Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`01ooooo`00BOooool00ol0003oooooooooo`15ooooo`Co00000_m5
Mmd01Ol0003oHX7Kof:1fomRPM_o000000;oNHSG00Go0000ohV=dOn9SM7oRHgAo`000002oiJ@b`;o
00001?nLV<l00ol0003oYIS8ojFHb003ojFHb003o`000?n/V<;o[9S200?o[9S200?o0000ok>L`?nc
W<001oncW<06o`0000?o^Ifl00Co0000okbO^ol0003o00001?nmY<001Ol0003o`JFmol6U_Oo1YKgo
000000Ko`j_200?o0000ol>X__l000001?o6[/801Ol0003obKG7olVeaoo9]LOo000000Coc;k=00Co
0000olo9e?o?bMCo00000_oBe]`01?l0003od^CTom;Ti?oBi>@2o`0000;oa?[Y0ol0001Kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004[ooooo0_l00016ooooo`04oj<D
0?n:003o0000o`0000;oAGOM00Co0000of:1fomRPM_o00000_miR=L02Ol0003oRHgAohV=dOn9SM7o
0000oiJ@bol0003oSYSHo`000005oibHc`03o`000?nUV<SoYIS800;oYIS800?o0000ojbH`_n/V<80
0on/V<801?l0003o/9k6o`000?l00006ok>L`003o`000?nhXL7o^:7100?o^:711?l00008okfT`003
o`000?o1YKgo000000Oo`j_20_l00004olJ^`P05o`000?o9]LOobKG7olVeaol000001?o<_/d01?l0
003oclWDolo9e?l00002om;Fg004o`000?oBi>Cod^CTom;Ti0;o000000?oa?[Yo`000?l000000_l0
001Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004cooooo00?o0000
ooooooooool0AOooool2ohX00004o`000?m5MmgoAGOMo`0000;oHX7K00Co0000ogV8eomiR=Oo0000
0_n9SM42o`0000?oSYSH00?o0000oibHconLV<l00onLV<l00ol0003oYIS8ojFHb002ojFHb005o`00
0?n/V<;o[9S2ojbH`_l000001?n`W/H2o`0000Co/ic000?o0000okRQ`OnhXL401_nhXL400ol0003o
_JC0okfT`006okfT`0;o00001oo3Zl800ol0003oaK?9o`000003olJ^`P03o`000?o9]LOobKG700;o
bKG700Go0000olbncOo<_/goc;k=o`000002olo9e004o`000?oBe]cod]KLo`0000?od^CT0_l00000
1?o4n^Wo0000o`000?l0001Oooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001=
ooooo`03o`000?oooooooooo04Gooooo0_n:000;o`0000;oNICQ00Go0000ohjHf?n>V=SoSYSHo`00
0005oibHc`03o`000?nUV<SoYIS800;oYIS800Co0000ojbH`_n/V<;o00001_n`W/H01?l0003o/ic0
ok>L`?l00009okRQ`@03o`000?nmY<3o_JC000Go_JC00_l00006ol>[`P;o00000oo5/lT00ol0003o
aZk2o`000004olVea`05o`000?o<_/goc;k=olbncOl000000_o?bM@01?l0003od]KLom;Fg?l00002
om;Ti0?o000000?oa?[Yo`000?l00000H_ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00C_ooool00ol0003oooooooooo`15ooooo`03oj<D0?n:003o02bN00?o05O<0olTNND3oeN<
j0?oNICQ00Go0000ohjHf?n>V=SoSYSHo`000005oibHc`03o`000?nUV<SoYIS800;oYIS800?o0000
ojbH`_l000001on`W/H3o`0000Wo^:7100?o0000okfT`?nmY<000_nmY<03o`000003okj[aol0003o
`j_200Co`j_200?o0000olFcbOo5/lT00oo5/lT2o`0000CobKG700Go0000olbncOo<_/goc;k=o`00
0002olo9e004o`000?oBe]cod]KLo`0000;od^CT1_l0001Sooooo`03o`000?oooooooooo00Oooooo
0Ol00001ooooo`7ooooo001?ooooo`;o0000Aoooool00on:003o0000o`1Gc002o`1Gc0?o97WU0omG
S>P3ogVDh@05o`000?n>V=SoSYSHohjHf?l000001OnLV<l00ol0003oYIS8ojFHb002ojFHb003o`00
0?n`W/Ko/9k600So/9k61_l00004okRQ`@03o`000?nmY<3o000000;o00001?nnZlL00ol0003o`j_2
ol>[`P02ol>[`P03o`000?o5/lWoaK?900?oaK?900?o0000olNmdOl000000oo9]LL01Ol0003oc;k=
olbncOo<_/go000000;oclWD00Co0000om;Fg?oBe]co00000_oBi>@2o`000003olCjjOl0003o0000
06Kooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0057ooooo00?o0000oooooooo
ool0AOooool00onS503oRP00o`1Gc002o`1Gc0?o97WU0omGS>P01?l0003oNICQogVDhOl00003ohjH
f003o`000?nLV<ooW9S?00?oW9S?00Ko0000ojFHb?nUV<SoYIS8o`000?nZX/l2o`0000Oo/9k600?o
0000okNVb?ngY/P00ongY/P6o`0000So_Z_700Co0000ol>[`_l0003o00001Oo5/lT01ol0003oakgA
olNmdOo7_M7o0000olVeaol000000oo<_/d01?l0003oclWDolo9e?l00002om;Fg003o`000?oBi>Co
d^CT00;o000000?oa?[Yo`000?l00000J?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1
ooooo`00D_ooool00ol0003oooooooooo`16ooooo`05ohX00?l0003o05O<o`1Gc?l000000_lTNND0
1?l0003oEhcXoeN<j?l00002ogVDh@05o`000?n>V=SoSYSHohjHf?l000001OnLV<l00ol0003oYIS8
o`000004ojZRc`;o00001On`W/H00ol0003o]jK8okNVb007okNVb003o`000?nnZlOo_Z_700Oo_Z_7
00?o0000ol>[`_o5/lT01?o5/lT2o`0000CoakgA0_l00003olbnc@04o`000?o?bMCoclWDo`0000;o
d]KL00?o0000om;Ti?l000001Ol0001Zooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo001Cooooo`;o0000Aoooool01On:003o0000o`1Gc?l0Elco000000;o97WU00Co0000oeN<j?mG
S>So00000_miU>401Ol0003oSYSHohjHf?n>V=So000000GoW9S?00?o0000ojZRconZX/l01OnZX/l2
o`0000;o/9k600?o0000okNVb?ngY/P02?ngY/P00ol0003o_Z_7okj[a`05okj[a`?o00001Oo5/lT0
0ol0003oakgAolNmd@03olNmd@06o`000?o9bm_obL_Ko`000?o<_/go00000_o?bM@01ol0003od]KL
om;Fg?l0003od^CTo`000?o?lNT00ol0001/ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`7ooooo001Eooooo`03o`000?oooooooooo04Kooooo00Co0000o`1Gc?l0Elco00000_lTNND01?l0
003oEhcXoeN<j?l00002ogVDh@05o`000?n>V=SoSYSHohjHf?l000000onLV<l00ol0003oXJKIoj6V
f@02o`0000KoZZ;?0ol00009okNVb003o`000?nnZlOo_Z_700;o_Z_71?l00002okjcc`03o`000?o5
/lWoaK?900;oaK?900?o0000olNmdOo7_M400_o7_M42o`0000?obL_K0ol000002?o?bMCo0000om;F
g?oBe]co0000om;Ti?l0003oco7Y0ol0001^ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00E_ooool00ol0003oooooooooo`16ooooo`04ohX00?l0003o05O<o`0000;o97WU00Co0000oeN<
j?mGS>So00000_miU>401ol0003oSYSHohjHf?n>V=So0000oibHcol000001OnQY]T2o`0000KoZZ;?
1_l00004okNVb003o`000?nnZlOo000000;o00001_nn/ll01?l0003oaK?9olFcbOo5/lT5olNmd@03
o`000?o9bm_obL_K00;obL_K00?o0000ol[Ki_o:fnH00ol000001OoBe]co0000om;Ti?l0003oco7Y
00;o0000LOooool00ol0003oooooooooo`03ooooo`7o00000Oooool005Oooooo00?o0000oooooooo
ool0Aoooool00ol0;9ko05O<o`000002obAii@04o`000?mGS>SoEhcXo`0000;oNICQ00Go0000ohjH
f?n>V=SoSYSHo`000008oj6Vf@03o`000?nZX/ooZZ;?00?oZZ;?00?o0000okB]d_nd[M800ond[M86
o`0000[o_[??00?o0000olFcbOo7_M400oo7_M42o`0000?obL_K0_l00002ol[KiP03o`000?o4kO3o
a>g`00Ko0000M?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00018oooo
o`03o`000?l0Elco000000;o97WU00Co0000oeN<j?mGS>So00000_miU>400ol0003oSYSHo`000002
oi6Zi`03o`000?nQY]WoXJKI00GoXJKI0_l00003ojZRc`03o`000?nd[M;o]:gB00Oo]:gB00?o0000
okjcconn/ll01onn/ll3o`0000CoakgA00Co0000olW;foo9bm_obL_K0_l00002ol[KiP;o000000?o
a>g`o`000?l000001?l0001fooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F_ooool0
0ol0003oooooooooo`16ooooo`?o00000_lTNND01Ol0003oEhcXoeN<j?l0003oNICQ00;o00001OnA
Z^L2o`0000KoXJKI0ol0000:okB]dP03o`000?nn/loo_[??00?o_[??1?l00002okjofP05o`000?o7
_M7oakgAolNmdOl000000oo9bm/01Ol0003ob]_Vol[Ki_o:fnKo000000;oa>g`0ol000000omoim?o
0000ooooo`1hooooo`05o`000?ooooooooooooooool000000Oooool005_ooooo00?o0000oooooooo
ool0AOooool01?l0003oooooo`000?l00002obAii@04o`000?mGS>So0000o`0000?oLZ[d00?o0000
oi6ZionAZ^L00onAZ^L2o`0000KoXJKI00?o0000okB]d_l000001?l00004okB]dP03o`000?nn/loo
000000?o00001onn_mX00ol0003oakgAolW;f`02olW;f`;o00000_o:fnH2o`000003olC]l?l0003o
000000?o0000O?ooool01?l0003oooooooooool00001ooooo`00G?ooool00ol0003oooooooooo`14
ooooo`04o`000?ooooooooooooooo`Co00000olhVo<4og:Zm0;o00001?nAZ^L2o`0000CoXJKI00?o
0000ojjfg_n^]]h01?n^]]h6o`0000Wo_[oJ0ol00002olW;f`;o00000_o:fnH2o`000003olC]l?l0
003o000000;o000000?oOnOCooooooooool0OOooool00ol0003oooooo`000001ooooo`00GOooool2
o`0004Cooooo00?o0000ooooooooool00oooool3o`1^b@Co>9_c00Co0000og:Zm?mbZ_CoLZ[d0_l0
0004oi6Zi`;o000000?oXJKIo`000?n^]]h02_n^]]h00ol0003o_[oJokjofP05okjofP?o00000_nk
c^T00ol0003obL_Ko`000003ol[KiP03o`000?o4kO3oa>g`00?o000000?oOnOCooooooooool0Oooo
ool00ol0003oooooooooo`01o`000000Goooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00Kooooo0_l0K/T01Ol0003o>9_cocRKlolhVo?o000000?oLZ[d00?o0000oi6ZionAZ^L00onA
Z^L01?l0003o[[KNojjfg_l00009ojjfgP03o`000?nn_m[o_[oJ00;o_[oJ0ol00004ok_>j@?o0000
0_o:fnH2o`000005olC]l?l0003o0000o`000?moim<0Q?ooool1o`00007ooooo0Ol00000063ooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`08ooooo`;o06k90_l00002ocRKl`;o0000
00?oLZ[do`000?l000000onAZ^L01?l0003oX/7_oj;1konR`Nl7o`0000;o[[KN00?o0000okjof_nn
_mX00_l00004ok_>j@?o00000_n^goP01?l0003ob]_Vo`000?o4kO03o`0008Sooooo0_l00000067o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;ooooo`;o06k900?o0000ocRKlolh
Vo<00_l000001?mbZ_Co0000o`000?l0000;oj;1k`Co00000onkc^T4o`0000Co[]oh0ol000001?o4
kO3o0000o`000?l00028ooooo`?o0000001Rooooo`;o0000?oooool00ol0003oooooooooo`0=oooo
o`05o`000?l0K/Wo0000o`000?lhVo<00_l000000ombZ_Co0000oj;1k`05oj;1k`03o`000?nR`Noo
X/7_00CoX/7_00?o0000ok_>jOnkc^T00_l00004ojkOn0Wo0000Q_ooool4o`0000?ooooo001Toooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool04?ooool01Ol0K/Wo0000o`000?lhVo?o
000000SoQLWn2?l00004ojkOn0So0000Q_ooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool04oooool00ol0003oA;_bodBklP03odBklPOo00000on5bOh00ol0
003o[]ohojkOn005o`0008Sooooo1?l0000;ooooo`00I_ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo01cooooo1?m4^o86o`0008[ooooo0ol0000?ooooo`00Ioooool2o`0003[ooooo
00?o0000ooooooooool0[?ooool4o`0001;ooooo001Yooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0Z?ooool4o`0001Kooooo001Zooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0Y?ooool4o`0001[ooooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0XOooool4o`0001kooooo001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Mooooo`Co
00008_ooool006kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Iooooo`Co0000
9_ooool006oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Eooooo`Co0000:_oo
ool0073ooooo0_l0000`ooooo`03o`000?oooooooooo097ooooo1?l0000^ooooo`00L_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo08kooooo0ol0000booooo`00Loooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo08[ooooo1?l0000eooooo`00M?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000iooooo`00MOooool2o`0002_ooooo00?o
0000ooooooooool0P_ooool4o`0003gooooo001gooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0O_ooool4o`00047ooooo001hooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0N_ooool4o`0004Gooooo001iooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0M_ooool4o`0004Wooooo001jooooo`;o00009_ooool00ol0003oooooooooo`1booooo`Co0000
COooool007cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1_ooooo`?o0000DOoo
ool007gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000E?ooool0
07kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000F?ooool007oo
oooo0_l0000Qooooo`03o`000?oooooooooo06?ooooo1?l0001Looooo`00POooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo05oooooo1?l0001Pooooo`00P_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo05_ooooo1?l0001Tooooo`00Poooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo05Oooooo1?l0001Xooooo`00Q?ooool2o`0001cooooo00?o0000oooo
ooooool0Doooool4o`0006cooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0Coooool4o`00073ooooo0027ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
C?ooool3o`0007Cooooo0028ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?oo
ool4o`0007Oooooo0029ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000Noooool0
08_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Ooooool008co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`Co0000Poooool008gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`Co0000Qoooool008kooooo0_l0
000Booooo`03o`000?oooooooooo03Cooooo1?l0002;ooooo`00T?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo037ooooo1?l0002?ooooo`00TOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02kooooo0ol0002Cooooo`00T_ooool2o`0000gooooo00?o0000oooooooo
ool0:_ooool4o`0009Kooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9_ooool4o`0009[ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_oo
ool4o`0009kooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4
o`000:;ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Y_ooool009Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003
ooooo`03o`000?oooooooooo00_ooooo0ol0002fooooo`00W_ooool01?l0003oooooooooool00009
ooooo`Co0000^Oooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o
000000?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.68821e-16 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51721 .66492 m .51694 .65827 L .43899 .65168 L p .611 .144 .121 r
F P
0 g
s
.51694 .65827 m .51721 .66492 L .59285 .65876 L p .454 0 0 r
F P
0 g
s
.59285 .65876 m .59527 .65394 L .51694 .65827 L p .454 0 0 r
F P
0 g
s
.59527 .65394 m .59285 .65876 L .66507 .64141 L p .077 0 0 r
F P
0 g
s
.66507 .64141 m .67023 .63881 L .59527 .65394 L p .077 0 0 r
F P
0 g
s
.44189 .65967 m .43899 .65168 L .36521 .63435 L p .7 .229 .13 r
F P
0 g
s
.43899 .65168 m .44189 .65967 L .51721 .66492 L p .611 .144 .121 r
F P
0 g
s
.51749 .67196 m .51721 .66492 L .44189 .65967 L p .613 .152 .136 r
F P
0 g
s
.51721 .66492 m .51749 .67196 L .5904 .66388 L p .45 0 .001 r
F P
0 g
s
.5904 .66388 m .59285 .65876 L .51721 .66492 L p .45 0 .001 r
F P
0 g
s
.59285 .65876 m .5904 .66388 L .65984 .64422 L p .05 0 0 r
F P
0 g
s
.65984 .64422 m .66507 .64141 L .59285 .65876 L p .05 0 0 r
F P
0 g
s
.73009 .61348 m .73799 .61332 L .67023 .63881 L p .537 .909 .954 r
F P
0 g
s
.67023 .63881 m .66507 .64141 L .73009 .61348 L p .537 .909 .954 r
F P
0 g
s
.36521 .63435 m .37065 .64311 L .44189 .65967 L p .7 .229 .13 r
F P
0 g
s
.44483 .66809 m .44189 .65967 L .37065 .64311 L p .704 .239 .144 r
F P
0 g
s
.44189 .65967 m .44483 .66809 L .51749 .67196 L p .613 .152 .136 r
F P
0 g
s
.37065 .64311 m .36521 .63435 L .29943 .6068 L p .746 .245 .032 r
F P
0 g
s
.51778 .6791 m .51749 .67196 L .44483 .66809 L p .608 .148 .136 r
F P
0 g
s
.51749 .67196 m .51778 .6791 L .58791 .66907 L p .434 0 0 r
F P
0 g
s
.58791 .66907 m .5904 .66388 L .51749 .67196 L p .434 0 0 r
F P
0 g
s
.5904 .66388 m .58791 .66907 L .65455 .64706 L p 0 0 0 r
F P
0 g
s
.65455 .64706 m .65984 .64422 L .5904 .66388 L p 0 0 0 r
F P
0 g
s
.72212 .61375 m .73009 .61348 L .66507 .64141 L p .584 .927 .956 r
F P
0 g
s
.66507 .64141 m .65984 .64422 L .72212 .61375 L p .584 .927 .956 r
F P
0 g
s
.37065 .64311 m .37615 .65232 L .44483 .66809 L p .704 .239 .144 r
F P
0 g
s
.44782 .67664 m .44483 .66809 L .37615 .65232 L p .704 .239 .144 r
F P
0 g
s
.44483 .66809 m .44782 .67664 L .51778 .6791 L p .608 .148 .136 r
F P
0 g
s
.29943 .6068 m .30729 .61575 L .37065 .64311 L p .746 .245 .032 r
F P
0 g
s
.37615 .65232 m .37065 .64311 L .30729 .61575 L p .754 .257 .044 r
F P
0 g
s
.51807 .68605 m .51778 .6791 L .44782 .67664 L p .596 .131 .12 r
F P
0 g
s
.51778 .6791 m .51807 .68605 L .58538 .67407 L p .403 0 0 r
F P
0 g
s
.58538 .67407 m .58791 .66907 L .51778 .6791 L p .403 0 0 r
F P
0 g
s
.65984 .64422 m .65455 .64706 L .71408 .61402 L p .637 .941 .96 r
F P
0 g
s
.71408 .61402 m .72212 .61375 L .65984 .64422 L p .637 .941 .96 r
F P
0 g
s
.58791 .66907 m .58538 .67407 L .64918 .64973 L p 0 0 0 r
F P
0 g
s
.64918 .64973 m .65455 .64706 L .58791 .66907 L p 0 0 0 r
F P
0 g
s
.73799 .61332 m .73009 .61348 L .78414 .57601 L p .67 .809 .95 r
F P
0 g
s
.78414 .57601 m .79464 .57831 L .73799 .61332 L p .67 .809 .95 r
F P
0 g
s
.37615 .65232 m .38176 .66167 L .44782 .67664 L p .704 .239 .144 r
F P
0 g
s
.45087 .68501 m .44782 .67664 L .38176 .66167 L p .698 .227 .129 r
F P
0 g
s
.44782 .67664 m .45087 .68501 L .51807 .68605 L p .596 .131 .12 r
F P
0 g
s
.30729 .61575 m .31524 .62512 L .37615 .65232 L p .754 .257 .044 r
F P
0 g
s
.38176 .66167 m .37615 .65232 L .31524 .62512 L p .755 .257 .038 r
F P
0 g
s
.65455 .64706 m .64918 .64973 L .70595 .61418 L p .69 .946 .959 r
F P
0 g
s
.70595 .61418 m .71408 .61402 L .65455 .64706 L p .69 .946 .959 r
F P
0 g
s
.30729 .61575 m .29943 .6068 L .24558 .56996 L p .683 .145 0 r
F P
0 g
s
.73009 .61348 m .72212 .61375 L .77358 .57373 L p .692 .805 .935 r
F P
0 g
s
.77358 .57373 m .78414 .57601 L .73009 .61348 L p .692 .805 .935 r
F P
0 g
s
.5828 .67864 m .58538 .67407 L .51807 .68605 L p .352 0 0 r
F P
0 g
s
.58538 .67407 m .5828 .67864 L .64373 .65205 L p 0 0 0 r
F P
0 g
s
.64373 .65205 m .64918 .64973 L .59213 .6715 L p 0 0 0 r
F P
0 g
s
.64373 .65205 m .59213 .6715 L .59574 .67016 L 0 0 0 r
F
.63819 .65383 m .64373 .65205 L .59128 .67494 L p .372 .829 .739 r
F P
0 g
s
.59128 .67494 m .5828 .67864 L p .59513 .67312 L .372 .829 .739 r
F P
0 g
s
.63819 .65383 m .59128 .67494 L .59513 .67312 L .372 .829 .739 r
F
.5828 .67864 m .58017 .68251 L .63299 .6564 L p F P
0 g
s
.62992 .65753 m .5828 .67864 L .63299 .6564 L .372 .829 .739 r
F
.63299 .6564 m .63819 .65383 L p .62992 .65753 L F P
0 g
s
.63256 .65486 m .63819 .65383 L .5902 .67755 L p .536 .925 .845 r
F P
0 g
s
.5902 .67755 m .58017 .68251 L p .594 .67521 L .536 .925 .845 r
F P
0 g
s
.63256 .65486 m .5902 .67755 L .594 .67521 L .536 .925 .845 r
F
.58017 .68251 m .57748 .68542 L .62605 .65847 L p F P
0 g
s
.62278 .66002 m .58017 .68251 L .62605 .65847 L .536 .925 .845 r
F
.62605 .65847 m .63256 .65486 L p .62278 .66002 L F P
0 g
s
.62683 .65498 m .63256 .65486 L .57748 .68542 L p .674 .972 .911 r
F P
0 g
s
.57748 .68542 m .57474 .68713 L .61914 .65972 L p .674 .972 .911 r
F P
0 g
s
.61914 .65972 m .62683 .65498 L p .61592 .66171 L .674 .972 .911 r
F P
0 g
s
.61592 .66171 m .57748 .68542 L .61914 .65972 L .674 .972 .911 r
F
.59213 .6715 m .58538 .67407 L p .59574 .67016 L 0 0 0 r
F P
0 g
s
.51837 .69251 m .51807 .68605 L .45087 .68501 L p .574 .098 .087 r
F P
0 g
s
.51807 .68605 m .51837 .69251 L .5828 .67864 L p .352 0 0 r
F P
0 g
s
.72212 .61375 m .71408 .61402 L .76296 .57143 L p .712 .798 .918 r
F P
0 g
s
.76296 .57143 m .77358 .57373 L .72212 .61375 L p .712 .798 .918 r
F P
0 g
s
.64918 .64973 m .64373 .65205 L .69772 .61409 L p .737 .941 .951 r
F P
0 g
s
.69772 .61409 m .70595 .61418 L .64918 .64973 L p .737 .941 .951 r
F P
0 g
s
.38176 .66167 m .38746 .67083 L .45087 .68501 L p .698 .227 .129 r
F P
0 g
s
.45399 .69286 m .45087 .68501 L .38746 .67083 L p .686 .203 .097 r
F P
0 g
s
.45087 .68501 m .45399 .69286 L .51837 .69251 L p .574 .098 .087 r
F P
0 g
s
.25568 .57854 m .30729 .61575 L p .24634 .57052 L .683 .145 0 r
F P
0 g
s
.31524 .62512 m .30729 .61575 L .25568 .57854 L p .69 .157 0 r
F P
0 g
s
.25568 .57854 m .26587 .58748 L .31524 .62512 L p .69 .157 0 r
F P
0 g
s
.25568 .57854 m .2196 .53305 L p .26531 .58682 L 0 .151 .675 r
F P
0 g
s
.26587 .58748 m .25568 .57854 L p .26531 .58682 L 0 .151 .675 r
F P
0 g
s
.24558 .56996 m .25568 .57854 L p .24634 .57052 L .683 .145 0 r
F P
0 g
s
.31524 .62512 m .32331 .63461 L .38176 .66167 L p .755 .257 .038 r
F P
0 g
s
.38746 .67083 m .38176 .66167 L .32331 .63461 L p .749 .244 .014 r
F P
0 g
s
.58017 .68251 m .5828 .67864 L .51837 .69251 L p .271 0 0 r
F P
0 g
s
.51867 .69816 m .51837 .69251 L .45399 .69286 L p .539 .044 .03 r
F P
0 g
s
.51837 .69251 m .51867 .69816 L .58017 .68251 L p .271 0 0 r
F P
0 g
s
.71408 .61402 m .70595 .61418 L .75227 .56909 L p .729 .788 .9 r
F P
0 g
s
.75227 .56909 m .76296 .57143 L .71408 .61402 L p .729 .788 .9 r
F P
0 g
s
.64373 .65205 m .63819 .65383 L .68941 .61366 L p .773 .925 .936 r
F P
0 g
s
.68941 .61366 m .69772 .61409 L .64373 .65205 L p .773 .925 .936 r
F P
0 g
s
.38746 .67083 m .39329 .67947 L .45399 .69286 L p .686 .203 .097 r
F P
0 g
s
.45718 .69985 m .45399 .69286 L .39329 .67947 L p .663 .16 .042 r
F P
0 g
s
.45399 .69286 m .45718 .69985 L .51867 .69816 L p .539 .044 .03 r
F P
0 g
s
.32331 .63461 m .31524 .62512 L .26587 .58748 L p .68 .149 0 r
F P
0 g
s
.70595 .61418 m .69772 .61409 L .74152 .56667 L p .743 .777 .88 r
F P
0 g
s
.74152 .56667 m .75227 .56909 L .70595 .61418 L p .743 .777 .88 r
F P
0 g
s
.32331 .63461 m .33152 .64393 L .38746 .67083 L p .749 .244 .014 r
F P
0 g
s
.39329 .67947 m .38746 .67083 L .33152 .64393 L p .734 .215 0 r
F P
0 g
s
.57748 .68542 m .58017 .68251 L .51867 .69816 L p .141 0 0 r
F P
0 g
s
.51898 .70271 m .51867 .69816 L .45718 .69985 L p .478 0 0 r
F P
0 g
s
.51867 .69816 m .51898 .70271 L .57748 .68542 L p .141 0 0 r
F P
0 g
s
.79464 .57831 m .78414 .57601 L .82346 .53057 L p .615 .679 .887 r
F P
0 g
s
.82346 .53057 m .83625 .53514 L .79464 .57831 L p .615 .679 .887 r
F P
0 g
s
.63819 .65383 m .63256 .65486 L .68099 .61276 L p .798 .901 .914 r
F P
0 g
s
.68099 .61276 m .68941 .61366 L .63819 .65383 L p .798 .901 .914 r
F P
0 g
s
.69772 .61409 m .68941 .61366 L .73071 .56413 L p .755 .765 .861 r
F P
0 g
s
.73071 .56413 m .74152 .56667 L .69772 .61409 L p .755 .765 .861 r
F P
0 g
s
.78414 .57601 m .77358 .57373 L .81066 .52595 L p .628 .672 .873 r
F P
0 g
s
.81066 .52595 m .82346 .53057 L .78414 .57601 L p .628 .672 .873 r
F P
0 g
s
.26587 .58748 m .27619 .59651 L .32331 .63461 L p .68 .149 0 r
F P
0 g
s
.33152 .64393 m .32331 .63461 L .27619 .59651 L p .65 .119 0 r
F P
0 g
s
.39329 .67947 m .39925 .68725 L .45718 .69985 L p .663 .16 .042 r
F P
0 g
s
.46045 .70565 m .45718 .69985 L .39925 .68725 L p .621 .09 0 r
F P
0 g
s
.45718 .69985 m .46045 .70565 L .51898 .70271 L p .478 0 0 r
F P
0 g
s
.25568 .57854 m .24558 .56996 L .20758 .52532 L p 0 .152 .667 r
F P
0 g
s
.57474 .68713 m .57748 .68542 L .51898 .70271 L p 0 0 0 r
F P
0 g
s
.77358 .57373 m .76296 .57143 L .79783 .52132 L p .642 .667 .858 r
F P
0 g
s
.79783 .52132 m .81066 .52595 L .77358 .57373 L p .642 .667 .858 r
F P
0 g
s
.33152 .64393 m .33988 .65274 L .39329 .67947 L p .734 .215 0 r
F P
0 g
s
.39925 .68725 m .39329 .67947 L .33988 .65274 L p .701 .163 0 r
F P
0 g
s
.63256 .65486 m .62683 .65498 L .67247 .61129 L p .814 .872 .889 r
F P
0 g
s
.67247 .61129 m .68099 .61276 L .63256 .65486 L p .814 .872 .889 r
F P
0 g
s
.68941 .61366 m .68099 .61276 L .71982 .56144 L p .764 .752 .842 r
F P
0 g
s
.71982 .56144 m .73071 .56413 L .68941 .61366 L p .764 .752 .842 r
F P
0 g
s
.5193 .70586 m .51898 .70271 L .46045 .70565 L p .372 0 0 r
F P
0 g
s
.51898 .70271 m .5193 .70586 L .57474 .68713 L p 0 0 0 r
F P
0 g
s
.76296 .57143 m .75227 .56909 L .785 .51674 L p .656 .662 .844 r
F P
0 g
s
.785 .51674 m .79783 .52132 L .76296 .57143 L p .656 .662 .844 r
F P
0 g
s
.20758 .52532 m .2196 .53305 L .25568 .57854 L p 0 .152 .667 r
F P
0 g
s
.75227 .56909 m .74152 .56667 L .77216 .51226 L p .669 .658 .83 r
F P
0 g
s
.77216 .51226 m .785 .51674 L .75227 .56909 L p .669 .658 .83 r
F P
0 g
s
.27619 .59651 m .28665 .60537 L .31383 .62872 L p .65 .119 0 r
F P
0 g
s
.31553 .63022 m .27619 .59651 L .31383 .62872 L .65 .119 0 r
F
.31383 .62872 m .33152 .64393 L p .31553 .63022 L F P
0 g
s
.33988 .65274 m .33152 .64393 L .28665 .60537 L p .592 .064 0 r
F P
0 g
s
.28665 .60537 m .29727 .61378 L .33988 .65274 L p .592 .064 0 r
F P
0 g
s
.34842 .66074 m .33988 .65274 L .30789 .6235 L p .494 0 0 r
F P
0 g
s
.30789 .6235 m .29727 .61378 L p .30678 .62252 L .494 0 0 r
F P
0 g
s
.34842 .66074 m .30789 .6235 L .30678 .62252 L .494 0 0 r
F
.68099 .61276 m .67247 .61129 L .70887 .55858 L p .771 .738 .823 r
F P
0 g
s
.70887 .55858 m .71982 .56144 L .68099 .61276 L p .771 .738 .823 r
F P
0 g
s
.57194 .68742 m .57474 .68713 L .5193 .70586 L p .329 .809 .764 r
F P
0 g
s
.57474 .68713 m .57194 .68742 L .621 .65401 L p .764 .967 .928 r
F P
0 g
s
.621 .65401 m .62683 .65498 L .57474 .68713 L p .764 .967 .928 r
F P
0 g
s
.62683 .65498 m .621 .65401 L .66385 .60916 L p .821 .841 .864 r
F P
0 g
s
.66385 .60916 m .67247 .61129 L .62683 .65498 L p .821 .841 .864 r
F P
0 g
s
.39925 .68725 m .40535 .69383 L .46045 .70565 L p .621 .09 0 r
F P
0 g
s
.46379 .70994 m .46045 .70565 L .40535 .69383 L p .542 0 0 r
F P
0 g
s
.46045 .70565 m .46379 .70994 L .5193 .70586 L p .372 0 0 r
F P
0 g
s
.33988 .65274 m .34842 .66074 L .39925 .68725 L p .701 .163 0 r
F P
0 g
s
.40535 .69383 m .39925 .68725 L .34842 .66074 L p .639 .078 0 r
F P
0 g
s
.74152 .56667 m .73071 .56413 L .75932 .50793 L p .681 .654 .816 r
F P
0 g
s
.75932 .50793 m .77216 .51226 L .74152 .56667 L p .681 .654 .816 r
F P
0 g
s
.51962 .70734 m .5193 .70586 L .46379 .70994 L p .179 0 0 r
F P
0 g
s
.5193 .70586 m .51962 .70734 L .57194 .68742 L p .329 .809 .764 r
F P
0 g
s
.67247 .61129 m .66385 .60916 L .69784 .55551 L p .776 .726 .806 r
F P
0 g
s
.69784 .55551 m .70887 .55858 L .67247 .61129 L p .776 .726 .806 r
F P
0 g
s
.2196 .53305 m .2317 .54103 L .26587 .58748 L p 0 .151 .675 r
F P
0 g
s
.27619 .59651 m .26587 .58748 L .2317 .54103 L p 0 .172 .698 r
F P
0 g
s
.73071 .56413 m .71982 .56144 L .74647 .50379 L p .693 .651 .803 r
F P
0 g
s
.74647 .50379 m .75932 .50793 L .73071 .56413 L p .693 .651 .803 r
F P
0 g
s
.61507 .65182 m .621 .65401 L .57194 .68742 L p .811 .93 .912 r
F P
0 g
s
.621 .65401 m .61507 .65182 L .65512 .60627 L p .823 .811 .838 r
F P
0 g
s
.65512 .60627 m .66385 .60916 L .621 .65401 L p .823 .811 .838 r
F P
0 g
s
.56908 .68608 m .57194 .68742 L .51962 .70734 L p .579 .939 .918 r
F P
0 g
s
.57194 .68742 m .56908 .68608 L .61507 .65182 L p .811 .93 .912 r
F P
0 g
s
.71982 .56144 m .70887 .55858 L .73362 .49988 L p .705 .648 .791 r
F P
0 g
s
.73362 .49988 m .74647 .50379 L .71982 .56144 L p .705 .648 .791 r
F P
0 g
s
.40535 .69383 m .41159 .69889 L .46379 .70994 L p .542 0 0 r
F P
0 g
s
.46722 .71243 m .46379 .70994 L .41159 .69889 L p .385 0 0 r
F P
0 g
s
.46379 .70994 m .46722 .71243 L .51962 .70734 L p .179 0 0 r
F P
0 g
s
.66385 .60916 m .65512 .60627 L .68675 .55221 L p .78 .714 .79 r
F P
0 g
s
.68675 .55221 m .69784 .55551 L .66385 .60916 L p .78 .714 .79 r
F P
0 g
s
.34842 .66074 m .35713 .66761 L .40535 .69383 L p .639 .078 0 r
F P
0 g
s
.41159 .69889 m .40535 .69383 L .35713 .66761 L p .518 0 0 r
F P
0 g
s
.51996 .7069 m .51962 .70734 L .46722 .71243 L p .136 .683 .764 r
F P
0 g
s
.51962 .70734 m .51996 .7069 L .56908 .68608 L p .579 .939 .918 r
F P
0 g
s
.70887 .55858 m .69784 .55551 L .72076 .49625 L p .715 .646 .779 r
F P
0 g
s
.72076 .49625 m .73362 .49988 L .70887 .55858 L p .715 .646 .779 r
F P
0 g
s
.2317 .54103 m .2439 .54908 L .27619 .59651 L p 0 .172 .698 r
F P
0 g
s
.28665 .60537 m .27619 .59651 L .2439 .54908 L p 0 .211 .733 r
F P
0 g
s
.60905 .64828 m .61507 .65182 L .56908 .68608 L p .829 .882 .881 r
F P
0 g
s
.61507 .65182 m .60905 .64828 L .6463 .60257 L p .822 .783 .815 r
F P
0 g
s
.6463 .60257 m .65512 .60627 L .61507 .65182 L p .822 .783 .815 r
F P
0 g
s
.65512 .60627 m .6463 .60257 L .67559 .54867 L p .782 .702 .776 r
F P
0 g
s
.67559 .54867 m .68675 .55221 L .65512 .60627 L p .782 .702 .776 r
F P
0 g
s
.56617 .68296 m .56908 .68608 L .51996 .7069 L p .727 .948 .952 r
F P
0 g
s
.56908 .68608 m .56617 .68296 L .60905 .64828 L p .829 .882 .881 r
F P
0 g
s
.69784 .55551 m .68675 .55221 L .7079 .49292 L p .725 .644 .768 r
F P
0 g
s
.7079 .49292 m .72076 .49625 L .69784 .55551 L p .725 .644 .768 r
F P
0 g
s
.29727 .61378 m .30807 .62147 L .34842 .66074 L p .494 0 0 r
F P
0 g
s
.35713 .66761 m .34842 .66074 L .30807 .62147 L p 0 .138 .639 r
F P
0 g
s
.83625 .53514 m .82346 .53057 L .84457 .4794 L p .517 .585 .862 r
F P
0 g
s
.84457 .4794 m .85906 .48583 L .83625 .53514 L p .517 .585 .862 r
F P
0 g
s
.82346 .53057 m .81066 .52595 L .83013 .47287 L p .529 .579 .85 r
F P
0 g
s
.83013 .47287 m .84457 .4794 L .82346 .53057 L p .529 .579 .85 r
F P
0 g
s
.81066 .52595 m .79783 .52132 L .81574 .46636 L p .543 .576 .838 r
F P
0 g
s
.81574 .46636 m .83013 .47287 L .81066 .52595 L p .543 .576 .838 r
F P
0 g
s
.41159 .69889 m .41798 .70214 L .46722 .71243 L p .385 0 0 r
F P
0 g
s
.46722 .71243 m .47073 .71285 L .51996 .7069 L p .136 .683 .764 r
F P
0 g
s
.47073 .71285 m .46722 .71243 L .41798 .70214 L p 0 .488 .737 r
F P
0 g
s
.79783 .52132 m .785 .51674 L .80141 .46002 L p .559 .574 .826 r
F P
0 g
s
.80141 .46002 m .81574 .46636 L .79783 .52132 L p .559 .574 .826 r
F P
0 g
s
.68675 .55221 m .67559 .54867 L .69503 .48992 L p .733 .642 .758 r
F P
0 g
s
.69503 .48992 m .7079 .49292 L .68675 .55221 L p .733 .642 .758 r
F P
0 g
s
.5203 .70436 m .51996 .7069 L .47073 .71285 L p .468 .868 .963 r
F P
0 g
s
.51996 .7069 m .5203 .70436 L .56617 .68296 L p .727 .948 .952 r
F P
0 g
s
.785 .51674 m .77216 .51226 L .78715 .45397 L p .576 .575 .815 r
F P
0 g
s
.78715 .45397 m .80141 .46002 L .785 .51674 L p .576 .575 .815 r
F P
0 g
s
.63738 .59798 m .6463 .60257 L .60905 .64828 L p .819 .757 .794 r
F P
0 g
s
.6463 .60257 m .63738 .59798 L .66436 .54486 L p .784 .692 .763 r
F P
0 g
s
.66436 .54486 m .67559 .54867 L .6463 .60257 L p .784 .692 .763 r
F P
0 g
s
.60294 .64329 m .60905 .64828 L .56617 .68296 L p .833 .835 .848 r
F P
0 g
s
.60905 .64828 m .60294 .64329 L .63738 .59798 L p .819 .757 .794 r
F P
0 g
s
.35713 .66761 m .36603 .67305 L .41159 .69889 L p .518 0 0 r
F P
0 g
s
.41798 .70214 m .41159 .69889 L .36603 .67305 L p 0 .258 .66 r
F P
0 g
s
.2439 .54908 m .25621 .55696 L .28665 .60537 L p 0 .211 .733 r
F P
0 g
s
.29727 .61378 m .28665 .60537 L .25621 .55696 L p 0 .263 .772 r
F P
0 g
s
.77216 .51226 m .75932 .50793 L .77298 .44833 L p .593 .577 .804 r
F P
0 g
s
.77298 .44833 m .78715 .45397 L .77216 .51226 L p .593 .577 .804 r
F P
0 g
s
.75932 .50793 m .74647 .50379 L .75888 .44322 L p .612 .58 .794 r
F P
0 g
s
.75888 .44322 m .77298 .44833 L .75932 .50793 L p .612 .58 .794 r
F P
0 g
s
.67559 .54867 m .66436 .54486 L .68215 .48727 L p .741 .641 .748 r
F P
0 g
s
.68215 .48727 m .69503 .48992 L .67559 .54867 L p .741 .641 .748 r
F P
0 g
s
.5632 .67791 m .56617 .68296 L .5203 .70436 L p .789 .898 .92 r
F P
0 g
s
.56617 .68296 m .5632 .67791 L .60294 .64329 L p .833 .835 .848 r
F P
0 g
s
.74647 .50379 m .73362 .49988 L .74487 .43874 L p .63 .584 .784 r
F P
0 g
s
.74487 .43874 m .75888 .44322 L .74647 .50379 L p .63 .584 .784 r
F P
0 g
s
.73362 .49988 m .72076 .49625 L .73093 .43499 L p .648 .589 .775 r
F P
0 g
s
.73093 .43499 m .74487 .43874 L .73362 .49988 L p .648 .589 .775 r
F P
0 g
s
.2196 .53305 m .20758 .52532 L .18911 .47507 L p .191 .429 .86 r
F P
0 g
s
.62837 .59249 m .63738 .59798 L .60294 .64329 L p .815 .735 .776 r
F P
0 g
s
.63738 .59798 m .62837 .59249 L .65306 .54079 L p .785 .682 .751 r
F P
0 g
s
.65306 .54079 m .66436 .54486 L .63738 .59798 L p .785 .682 .751 r
F P
0 g
s
.72076 .49625 m .7079 .49292 L .71707 .43205 L p .665 .594 .766 r
F P
0 g
s
.71707 .43205 m .73093 .43499 L .72076 .49625 L p .665 .594 .766 r
F P
0 g
s
.30807 .62147 m .31905 .62817 L .35713 .66761 L p 0 .138 .639 r
F P
0 g
s
.36603 .67305 m .35713 .66761 L .31905 .62817 L p 0 .275 .768 r
F P
0 g
s
.66436 .54486 m .65306 .54079 L .66925 .48499 L p .748 .64 .74 r
F P
0 g
s
.66925 .48499 m .68215 .48727 L .66436 .54486 L p .748 .64 .74 r
F P
0 g
s
.59675 .6368 m .60294 .64329 L .5632 .67791 L p .829 .794 .818 r
F P
0 g
s
.60294 .64329 m .59675 .6368 L .62837 .59249 L p .815 .735 .776 r
F P
0 g
s
.7079 .49292 m .69503 .48992 L .70328 .42999 L p .681 .599 .757 r
F P
0 g
s
.70328 .42999 m .71707 .43205 L .7079 .49292 L p .681 .599 .757 r
F P
0 g
s
.41798 .70214 m .42452 .7033 L .47073 .71285 L p 0 .488 .737 r
F P
0 g
s
.47432 .71098 m .47073 .71285 L .42452 .7033 L p .272 .715 .962 r
F P
0 g
s
.47073 .71285 m .47432 .71098 L .5203 .70436 L p .468 .868 .963 r
F P
0 g
s
.69503 .48992 m .68215 .48727 L .68955 .42884 L p .696 .604 .749 r
F P
0 g
s
.68955 .42884 m .70328 .42999 L .69503 .48992 L p .696 .604 .749 r
F P
0 g
s
.52064 .69954 m .5203 .70436 L .47432 .71098 L p .661 .887 .98 r
F P
0 g
s
.5203 .70436 m .52064 .69954 L .5632 .67791 L p .789 .898 .92 r
F P
0 g
s
.25621 .55696 m .26866 .56448 L .29727 .61378 L p 0 .263 .772 r
F P
0 g
s
.30807 .62147 m .29727 .61378 L .26866 .56448 L p .046 .324 .807 r
F P
0 g
s
.36603 .67305 m .37511 .67677 L .41798 .70214 L p 0 .258 .66 r
F P
0 g
s
.42452 .7033 m .41798 .70214 L .37511 .67677 L p .009 .472 .87 r
F P
0 g
s
.6417 .53644 m .65306 .54079 L .62837 .59249 L p .785 .674 .741 r
F P
0 g
s
.65306 .54079 m .6417 .53644 L .65634 .48308 L p .755 .639 .732 r
F P
0 g
s
.65634 .48308 m .66925 .48499 L .65306 .54079 L p .755 .639 .732 r
F P
0 g
s
.61927 .58607 m .62837 .59249 L .59675 .6368 L p .81 .715 .76 r
F P
0 g
s
.62837 .59249 m .61927 .58607 L .6417 .53644 L p .785 .674 .741 r
F P
0 g
s
.68215 .48727 m .66925 .48499 L .67587 .42864 L p .711 .608 .741 r
F P
0 g
s
.67587 .42864 m .68955 .42884 L .68215 .48727 L p .711 .608 .741 r
F P
0 g
s
.56018 .67085 m .5632 .67791 L .52064 .69954 L p .809 .84 .874 r
F P
0 g
s
.5632 .67791 m .56018 .67085 L .59675 .6368 L p .829 .794 .818 r
F P
0 g
s
.18911 .47507 m .20253 .48154 L .2196 .53305 L p .191 .429 .86 r
F P
0 g
s
.2317 .54103 m .2196 .53305 L .20253 .48154 L p .216 .428 .853 r
F P
0 g
s
.66925 .48499 m .65634 .48308 L .66222 .42941 L p .724 .613 .733 r
F P
0 g
s
.66222 .42941 m .67587 .42864 L .66925 .48499 L p .724 .613 .733 r
F P
0 g
s
.59047 .62877 m .59675 .6368 L .56018 .67085 L p .823 .759 .792 r
F P
0 g
s
.59675 .6368 m .59047 .62877 L .61927 .58607 L p .81 .715 .76 r
F P
0 g
s
.63028 .53181 m .6417 .53644 L .61927 .58607 L p .786 .666 .732 r
F P
0 g
s
.6417 .53644 m .63028 .53181 L .6434 .48154 L p .761 .638 .725 r
F P
0 g
s
.6434 .48154 m .65634 .48308 L .6417 .53644 L p .761 .638 .725 r
F P
0 g
s
.65634 .48308 m .6434 .48154 L .6486 .43114 L p .735 .617 .727 r
F P
0 g
s
.6486 .43114 m .66222 .42941 L .65634 .48308 L p .735 .617 .727 r
F P
0 g
s
.6101 .57873 m .61927 .58607 L .59047 .62877 L p .806 .699 .747 r
F P
0 g
s
.61927 .58607 m .6101 .57873 L .63028 .53181 L p .786 .666 .732 r
F P
0 g
s
.31905 .62817 m .33022 .63361 L .36603 .67305 L p 0 .275 .768 r
F P
0 g
s
.37511 .67677 m .36603 .67305 L .33022 .63361 L p .076 .404 .858 r
F P
0 g
s
.70328 .42999 m .68955 .42884 L .68596 .37333 L p .65 .58 .763 r
F P
0 g
s
.68955 .42884 m .67587 .42864 L .6724 .37538 L p .674 .59 .754 r
F P
0 g
s
.6724 .37538 m .68596 .37333 L .68955 .42884 L p .674 .59 .754 r
F P
0 g
s
.47432 .71098 m .47799 .70665 L .52064 .69954 L p .661 .887 .98 r
F P
0 g
s
.521 .69235 m .52064 .69954 L .47799 .70665 L p .74 .841 .926 r
F P
0 g
s
.52064 .69954 m .521 .69235 L .56018 .67085 L p .809 .84 .874 r
F P
0 g
s
.67587 .42864 m .66222 .42941 L .65893 .37891 L p .694 .599 .745 r
F P
0 g
s
.65893 .37891 m .6724 .37538 L .67587 .42864 L p .694 .599 .745 r
F P
0 g
s
.71707 .43205 m .70328 .42999 L .69963 .37272 L p .625 .57 .772 r
F P
0 g
s
.68596 .37333 m .69963 .37272 L .70328 .42999 L p .65 .58 .763 r
F P
0 g
s
.42452 .7033 m .4312 .70215 L .47432 .71098 L p .272 .715 .962 r
F P
0 g
s
.47799 .70665 m .47432 .71098 L .4312 .70215 L p .528 .786 .992 r
F P
0 g
s
.63043 .48036 m .6434 .48154 L .63028 .53181 L p .766 .637 .719 r
F P
0 g
s
.6434 .48154 m .63043 .48036 L .63499 .43381 L p .746 .621 .72 r
F P
0 g
s
.63499 .43381 m .6486 .43114 L .6434 .48154 L p .746 .621 .72 r
F P
0 g
s
.20253 .48154 m .21599 .48816 L .2317 .54103 L p .216 .428 .853 r
F P
0 g
s
.2439 .54908 m .2317 .54103 L .21599 .48816 L p .253 .435 .848 r
F P
0 g
s
.6188 .52692 m .63028 .53181 L .6101 .57873 L p .786 .659 .724 r
F P
0 g
s
.63028 .53181 m .6188 .52692 L .63043 .48036 L p .766 .637 .719 r
F P
0 g
s
.26866 .56448 m .28125 .57143 L .30807 .62147 L p .046 .324 .807 r
F P
0 g
s
.31905 .62817 m .30807 .62147 L .28125 .57143 L p .164 .385 .832 r
F P
0 g
s
.55712 .66174 m .56018 .67085 L .521 .69235 L p .812 .791 .832 r
F P
0 g
s
.56018 .67085 m .55712 .66174 L .59047 .62877 L p .823 .759 .792 r
F P
0 g
s
.66222 .42941 m .6486 .43114 L .64553 .38389 L p .713 .606 .736 r
F P
0 g
s
.64553 .38389 m .65893 .37891 L .66222 .42941 L p .713 .606 .736 r
F P
0 g
s
.73093 .43499 m .71707 .43205 L .71343 .37352 L p .598 .559 .782 r
F P
0 g
s
.69963 .37272 m .71343 .37352 L .71707 .43205 L p .625 .57 .772 r
F P
0 g
s
.58413 .61922 m .59047 .62877 L .55712 .66174 L p .816 .73 .77 r
F P
0 g
s
.59047 .62877 m .58413 .61922 L .6101 .57873 L p .806 .699 .747 r
F P
0 g
s
.6486 .43114 m .63499 .43381 L .63219 .39031 L p .728 .612 .728 r
F P
0 g
s
.63219 .39031 m .64553 .38389 L .6486 .43114 L p .728 .612 .728 r
F P
0 g
s
.74487 .43874 m .73093 .43499 L .72737 .37567 L p .569 .547 .791 r
F P
0 g
s
.71343 .37352 m .72737 .37567 L .73093 .43499 L p .598 .559 .782 r
F P
0 g
s
.37511 .67677 m .38439 .67854 L .42452 .7033 L p .009 .472 .87 r
F P
0 g
s
.4312 .70215 m .42452 .7033 L .38439 .67854 L p .3 .613 .956 r
F P
0 g
s
.60085 .57048 m .6101 .57873 L .58413 .61922 L p .802 .684 .735 r
F P
0 g
s
.6101 .57873 m .60085 .57048 L .6188 .52692 L p .786 .659 .724 r
F P
0 g
s
.61743 .47952 m .63043 .48036 L .6188 .52692 L p .77 .636 .713 r
F P
0 g
s
.63043 .48036 m .61743 .47952 L .62139 .43737 L p .755 .624 .715 r
F P
0 g
s
.62139 .43737 m .63499 .43381 L .63043 .48036 L p .755 .624 .715 r
F P
0 g
s
.75888 .44322 m .74487 .43874 L .74146 .37905 L p .539 .536 .8 r
F P
0 g
s
.72737 .37567 m .74146 .37905 L .74487 .43874 L p .569 .547 .791 r
F P
0 g
s
.63499 .43381 m .62139 .43737 L .61887 .39808 L p .742 .618 .721 r
F P
0 g
s
.61887 .39808 m .63219 .39031 L .63499 .43381 L p .742 .618 .721 r
F P
0 g
s
.60727 .52177 m .6188 .52692 L .60085 .57048 L p .785 .653 .717 r
F P
0 g
s
.6188 .52692 m .60727 .52177 L .61743 .47952 L p .77 .636 .713 r
F P
0 g
s
.77298 .44833 m .75888 .44322 L .75571 .38357 L p .508 .524 .808 r
F P
0 g
s
.74146 .37905 m .75571 .38357 L .75888 .44322 L p .539 .536 .8 r
F P
0 g
s
.65893 .37891 m .64553 .38389 L .63433 .34289 L p .697 .608 .754 r
F P
0 g
s
.64553 .38389 m .63219 .39031 L .62216 .3527 L p .718 .615 .742 r
F P
0 g
s
.62216 .3527 m .63433 .34289 L .64553 .38389 L p .718 .615 .742 r
F P
0 g
s
.60776 .44177 m .62139 .43737 L .61743 .47952 L p .763 .627 .71 r
F P
0 g
s
.62139 .43737 m .60776 .44177 L .60557 .40714 L p .754 .622 .714 r
F P
0 g
s
.60557 .40714 m .61887 .39808 L .62139 .43737 L p .754 .622 .714 r
F P
0 g
s
.6724 .37538 m .65893 .37891 L .64659 .33489 L p .671 .599 .767 r
F P
0 g
s
.63433 .34289 m .64659 .33489 L .65893 .37891 L p .697 .608 .754 r
F P
0 g
s
.60439 .479 m .61743 .47952 L .60727 .52177 L p .774 .636 .709 r
F P
0 g
s
.61743 .47952 m .60439 .479 L .60776 .44177 L p .763 .627 .71 r
F P
0 g
s
.63219 .39031 m .61887 .39808 L .61004 .36423 L p .735 .621 .731 r
F P
0 g
s
.61004 .36423 m .62216 .3527 L .63219 .39031 L p .735 .621 .731 r
F P
0 g
s
.55712 .66174 m .55402 .65059 L .58413 .61922 L p .816 .73 .77 r
F P
0 g
s
.57772 .60817 m .58413 .61922 L .55402 .65059 L p .81 .707 .752 r
F P
0 g
s
.58413 .61922 m .57772 .60817 L .60085 .57048 L p .802 .684 .735 r
F P
0 g
s
.68596 .37333 m .6724 .37538 L .65895 .32872 L p .641 .589 .78 r
F P
0 g
s
.64659 .33489 m .65895 .32872 L .6724 .37538 L p .671 .599 .767 r
F P
0 g
s
.59154 .56137 m .60085 .57048 L .57772 .60817 L p .798 .672 .725 r
F P
0 g
s
.60085 .57048 m .59154 .56137 L .60727 .52177 L p .785 .653 .717 r
F P
0 g
s
.521 .69235 m .52136 .68273 L .55712 .66174 L p .812 .791 .832 r
F P
0 g
s
.55402 .65059 m .55712 .66174 L .52136 .68273 L p .81 .751 .798 r
F P
0 g
s
.21599 .48816 m .22949 .49481 L .2439 .54908 L p .253 .435 .848 r
F P
0 g
s
.25621 .55696 m .2439 .54908 L .22949 .49481 L p .297 .448 .843 r
F P
0 g
s
.61887 .39808 m .60557 .40714 L .59795 .37738 L p .749 .625 .722 r
F P
0 g
s
.59795 .37738 m .61004 .36423 L .61887 .39808 L p .749 .625 .722 r
F P
0 g
s
.47799 .70665 m .48172 .69974 L .521 .69235 L p .74 .841 .926 r
F P
0 g
s
.52136 .68273 m .521 .69235 L .48172 .69974 L p .771 .79 .869 r
F P
0 g
s
.59568 .51638 m .60727 .52177 L .59154 .56137 L p .785 .648 .711 r
F P
0 g
s
.60727 .52177 m .59568 .51638 L .60439 .479 L p .774 .636 .709 r
F P
0 g
s
.33022 .63361 m .34159 .63757 L .37511 .67677 L p .076 .404 .858 r
F P
0 g
s
.38439 .67854 m .37511 .67677 L .34159 .63757 L p .274 .501 .893 r
F P
0 g
s
.78715 .45397 m .77298 .44833 L .77013 .38907 L p .478 .514 .817 r
F P
0 g
s
.75571 .38357 m .77013 .38907 L .77298 .44833 L p .508 .524 .808 r
F P
0 g
s
.59411 .44693 m .60776 .44177 L .60439 .479 L p .769 .629 .705 r
F P
0 g
s
.60776 .44177 m .59411 .44693 L .59226 .41736 L p .763 .626 .709 r
F P
0 g
s
.59226 .41736 m .60557 .40714 L .60776 .44177 L p .763 .626 .709 r
F P
0 g
s
.69963 .37272 m .68596 .37333 L .67144 .32442 L p .605 .575 .794 r
F P
0 g
s
.65895 .32872 m .67144 .32442 L .68596 .37333 L p .641 .589 .78 r
F P
0 g
s
.4312 .70215 m .43802 .69852 L .47799 .70665 L p .528 .786 .992 r
F P
0 g
s
.48172 .69974 m .47799 .70665 L .43802 .69852 L p .653 .774 .937 r
F P
0 g
s
.59131 .47876 m .60439 .479 L .59568 .51638 L p .777 .635 .704 r
F P
0 g
s
.60439 .479 m .59131 .47876 L .59411 .44693 L p .769 .629 .705 r
F P
0 g
s
.28125 .57143 m .294 .57758 L .31905 .62817 L p .164 .385 .832 r
F P
0 g
s
.33022 .63361 m .31905 .62817 L .294 .57758 L p .277 .44 .844 r
F P
0 g
s
.60557 .40714 m .59226 .41736 L .58588 .39201 L p .76 .628 .714 r
F P
0 g
s
.58588 .39201 m .59795 .37738 L .60557 .40714 L p .76 .628 .714 r
F P
0 g
s
.63433 .34289 m .62216 .3527 L .60551 .3235 L p .718 .631 .759 r
F P
0 g
s
.62216 .3527 m .61004 .36423 L .59543 .33807 L p .737 .633 .744 r
F P
0 g
s
.59543 .33807 m .60551 .3235 L .62216 .3527 L p .737 .633 .744 r
F P
0 g
s
.80141 .46002 m .78715 .45397 L .78471 .39541 L p .45 .506 .825 r
F P
0 g
s
.77013 .38907 m .78471 .39541 L .78715 .45397 L p .478 .514 .817 r
F P
0 g
s
.61004 .36423 m .59795 .37738 L .58539 .35448 L p .751 .634 .73 r
F P
0 g
s
.58539 .35448 m .59543 .33807 L .61004 .36423 L p .751 .634 .73 r
F P
0 g
s
.57772 .60817 m .57125 .59569 L .59154 .56137 L p .798 .672 .725 r
F P
0 g
s
.58217 .55146 m .59154 .56137 L .57125 .59569 L p .794 .662 .717 r
F P
0 g
s
.59154 .56137 m .58217 .55146 L .59568 .51638 L p .785 .648 .711 r
F P
0 g
s
.64659 .33489 m .63433 .34289 L .61566 .31089 L p .693 .627 .778 r
F P
0 g
s
.60551 .3235 m .61566 .31089 L .63433 .34289 L p .718 .631 .759 r
F P
0 g
s
.58404 .51077 m .59568 .51638 L .58217 .55146 L p .785 .644 .706 r
F P
0 g
s
.59568 .51638 m .58404 .51077 L .59131 .47876 L p .777 .635 .704 r
F P
0 g
s
.71343 .37352 m .69963 .37272 L .68408 .32195 L p .564 .559 .807 r
F P
0 g
s
.67144 .32442 m .68408 .32195 L .69963 .37272 L p .605 .575 .794 r
F P
0 g
s
.38439 .67854 m .39384 .67814 L .4312 .70215 L p .3 .613 .956 r
F P
0 g
s
.43802 .69852 m .4312 .70215 L .39384 .67814 L p .493 .669 .941 r
F P
0 g
s
.58042 .45275 m .59411 .44693 L .59131 .47876 L p .775 .631 .702 r
F P
0 g
s
.59411 .44693 m .58042 .45275 L .57893 .42861 L p .771 .629 .704 r
F P
0 g
s
.57893 .42861 m .59226 .41736 L .59411 .44693 L p .771 .629 .704 r
F P
0 g
s
.55402 .65059 m .55088 .63745 L .57772 .60817 L p .81 .707 .752 r
F P
0 g
s
.57125 .59569 m .57772 .60817 L .55088 .63745 L p .804 .688 .737 r
F P
0 g
s
.59795 .37738 m .58588 .39201 L .57537 .37257 L p .762 .634 .719 r
F P
0 g
s
.57537 .37257 m .58539 .35448 L .59795 .37738 L p .762 .634 .719 r
F P
0 g
s
.59226 .41736 m .57893 .42861 L .5738 .40795 L p .769 .63 .707 r
F P
0 g
s
.5738 .40795 m .58588 .39201 L .59226 .41736 L p .769 .63 .707 r
F P
0 g
s
.57818 .47878 m .59131 .47876 L .58404 .51077 L p .78 .635 .701 r
F P
0 g
s
.59131 .47876 m .57818 .47878 L .58042 .45275 L p .775 .631 .702 r
F P
0 g
s
.52136 .68273 m .52172 .67069 L .55402 .65059 L p .81 .751 .798 r
F P
0 g
s
.55088 .63745 m .55402 .65059 L .52172 .67069 L p .805 .72 .771 r
F P
0 g
s
.65895 .32872 m .64659 .33489 L .62591 .30033 L p .662 .621 .799 r
F P
0 g
s
.61566 .31089 m .62591 .30033 L .64659 .33489 L p .693 .627 .778 r
F P
0 g
s
.81574 .46636 m .80141 .46002 L .79946 .40242 L p .424 .5 .833 r
F P
0 g
s
.78471 .39541 m .79946 .40242 L .80141 .46002 L p .45 .506 .825 r
F P
0 g
s
.58588 .39201 m .5738 .40795 L .56537 .39216 L p .771 .634 .71 r
F P
0 g
s
.56537 .39216 m .57537 .37257 L .58588 .39201 L p .771 .634 .71 r
F P
0 g
s
.22949 .49481 m .24306 .50133 L .25621 .55696 L p .297 .448 .843 r
F P
0 g
s
.26866 .56448 m .25621 .55696 L .24306 .50133 L p .347 .464 .837 r
F P
0 g
s
.48172 .69974 m .48552 .69019 L .52136 .68273 L p .771 .79 .869 r
F P
0 g
s
.52172 .67069 m .52136 .68273 L .48552 .69019 L p .782 .748 .822 r
F P
0 g
s
.57125 .59569 m .56474 .58191 L .58217 .55146 L p .794 .662 .717 r
F P
0 g
s
.57275 .54084 m .58217 .55146 L .56474 .58191 L p .791 .653 .71 r
F P
0 g
s
.58217 .55146 m .57275 .54084 L .58404 .51077 L p .785 .644 .706 r
F P
0 g
s
.57234 .50497 m .58404 .51077 L .57275 .54084 L p .785 .641 .702 r
F P
0 g
s
.58404 .51077 m .57234 .50497 L .57818 .47878 L p .78 .635 .701 r
F P
0 g
s
.72737 .37567 m .71343 .37352 L .6969 .32126 L p .518 .541 .819 r
F P
0 g
s
.68408 .32195 m .6969 .32126 L .71343 .37352 L p .564 .559 .807 r
F P
0 g
s
.56669 .45914 m .58042 .45275 L .57818 .47878 L p .779 .632 .699 r
F P
0 g
s
.58042 .45275 m .56669 .45914 L .56556 .44073 L p .777 .631 .7 r
F P
0 g
s
.56556 .44073 m .57893 .42861 L .58042 .45275 L p .777 .631 .7 r
F P
0 g
s
.57893 .42861 m .56556 .44073 L .5617 .425 L p .776 .632 .702 r
F P
0 g
s
.5617 .425 m .5738 .40795 L .57893 .42861 L p .776 .632 .702 r
F P
0 g
s
.60551 .3235 m .59543 .33807 L .57597 .3214 L p .747 .652 .755 r
F P
0 g
s
.59543 .33807 m .58539 .35448 L .56868 .34 L p .759 .648 .738 r
F P
0 g
s
.56868 .34 m .57597 .3214 L .59543 .33807 L p .759 .648 .738 r
F P
0 g
s
.58539 .35448 m .57537 .37257 L .56142 .36037 L p .768 .644 .724 r
F P
0 g
s
.56142 .36037 m .56868 .34 L .58539 .35448 L p .768 .644 .724 r
F P
0 g
s
.67144 .32442 m .65895 .32872 L .63627 .29186 L p .621 .612 .821 r
F P
0 g
s
.62591 .30033 m .63627 .29186 L .65895 .32872 L p .662 .621 .799 r
F P
0 g
s
.55088 .63745 m .54771 .62242 L .57125 .59569 L p .804 .688 .737 r
F P
0 g
s
.56474 .58191 m .57125 .59569 L .54771 .62242 L p .799 .673 .725 r
F P
0 g
s
.565 .47901 m .57818 .47878 L .57234 .50497 L p .782 .635 .698 r
F P
0 g
s
.57818 .47878 m .565 .47901 L .56669 .45914 L p .779 .632 .699 r
F P
0 g
s
.61566 .31089 m .60551 .3235 L .58329 .30474 L p .731 .657 .777 r
F P
0 g
s
.57597 .3214 m .58329 .30474 L .60551 .3235 L p .747 .652 .755 r
F P
0 g
s
.5738 .40795 m .5617 .425 L .55535 .41301 L p .777 .634 .704 r
F P
0 g
s
.55535 .41301 m .56537 .39216 L .5738 .40795 L p .777 .634 .704 r
F P
0 g
s
.43802 .69852 m .44496 .6923 L .48172 .69974 L p .653 .774 .937 r
F P
0 g
s
.48552 .69019 m .48172 .69974 L .44496 .6923 L p .712 .744 .877 r
F P
0 g
s
.83013 .47287 m .81574 .46636 L .81436 .40989 L p .402 .497 .842 r
F P
0 g
s
.79946 .40242 m .81436 .40989 L .81574 .46636 L p .424 .5 .833 r
F P
0 g
s
.34159 .63757 m .35314 .63984 L .38439 .67854 L p .274 .501 .893 r
F P
0 g
s
.39384 .67814 m .38439 .67854 L .35314 .63984 L p .425 .562 .889 r
F P
0 g
s
.57537 .37257 m .56537 .39216 L .55418 .3823 L p .774 .64 .713 r
F P
0 g
s
.55418 .3823 m .56142 .36037 L .57537 .37257 L p .774 .64 .713 r
F P
0 g
s
.294 .57758 m .3069 .58275 L .33022 .63361 L p .277 .44 .844 r
F P
0 g
s
.34159 .63757 m .33022 .63361 L .3069 .58275 L p .378 .487 .844 r
F P
0 g
s
.52172 .67069 m .52209 .6563 L .55088 .63745 L p .805 .72 .771 r
F P
0 g
s
.54771 .62242 m .55088 .63745 L .52209 .6563 L p .8 .697 .75 r
F P
0 g
s
.56474 .58191 m .55819 .56694 L .57275 .54084 L p .791 .653 .71 r
F P
0 g
s
.56329 .52958 m .57275 .54084 L .55819 .56694 L p .789 .646 .704 r
F P
0 g
s
.57275 .54084 m .56329 .52958 L .57234 .50497 L p .785 .641 .702 r
F P
0 g
s
.56061 .49901 m .57234 .50497 L .56329 .52958 L p .785 .638 .699 r
F P
0 g
s
.57234 .50497 m .56061 .49901 L .565 .47901 L p .782 .635 .698 r
F P
0 g
s
.62591 .30033 m .61566 .31089 L .59068 .29014 L p .708 .663 .803 r
F P
0 g
s
.58329 .30474 m .59068 .29014 L .61566 .31089 L p .731 .657 .777 r
F P
0 g
s
.56537 .39216 m .55535 .41301 L .54694 .40556 L p .779 .638 .705 r
F P
0 g
s
.54694 .40556 m .55418 .3823 L .56537 .39216 L p .779 .638 .705 r
F P
0 g
s
.55214 .45355 m .56556 .44073 L .56669 .45914 L p .781 .633 .697 r
F P
0 g
s
.56556 .44073 m .55214 .45355 L .54955 .44294 L p .781 .633 .698 r
F P
0 g
s
.54955 .44294 m .5617 .425 L .56556 .44073 L p .781 .633 .698 r
F P
0 g
s
.55289 .46598 m .56669 .45914 L .565 .47901 L p .782 .633 .696 r
F P
0 g
s
.56669 .45914 m .55289 .46598 L .55214 .45355 L p .781 .633 .697 r
F P
0 g
s
.74146 .37905 m .72737 .37567 L .7099 .32228 L p .467 .52 .829 r
F P
0 g
s
.6969 .32126 m .7099 .32228 L .72737 .37567 L p .518 .541 .819 r
F P
0 g
s
.54771 .62242 m .54452 .60564 L .56474 .58191 L p .799 .673 .725 r
F P
0 g
s
.55819 .56694 m .56474 .58191 L .54452 .60564 L p .794 .66 .715 r
F P
0 g
s
.68408 .32195 m .67144 .32442 L .64676 .2855 L p .568 .598 .843 r
F P
0 g
s
.63627 .29186 m .64676 .2855 L .67144 .32442 L p .621 .612 .821 r
F P
0 g
s
.5617 .425 m .54955 .44294 L .54531 .43487 L p .781 .634 .699 r
F P
0 g
s
.54531 .43487 m .55535 .41301 L .5617 .425 L p .781 .634 .699 r
F P
0 g
s
.39384 .67814 m .40346 .67543 L .43802 .69852 L p .493 .669 .941 r
F P
0 g
s
.44496 .6923 m .43802 .69852 L .40346 .67543 L p .604 .681 .896 r
F P
0 g
s
.84457 .4794 m .83013 .47287 L .82941 .41765 L p .384 .498 .851 r
F P
0 g
s
.81436 .40989 m .82941 .41765 L .83013 .47287 L p .402 .497 .842 r
F P
0 g
s
.55176 .4794 m .565 .47901 L .56061 .49901 L p .783 .634 .696 r
F P
0 g
s
.565 .47901 m .55176 .4794 L .55289 .46598 L p .782 .633 .696 r
F P
0 g
s
.48552 .69019 m .48937 .67803 L .52172 .67069 L p .782 .748 .822 r
F P
0 g
s
.52209 .6563 m .52172 .67069 L .48937 .67803 L p .786 .717 .787 r
F P
0 g
s
.57597 .3214 m .56868 .34 L .54891 .33497 L p .772 .663 .742 r
F P
0 g
s
.56868 .34 m .56142 .36037 L .54494 .35625 L p .777 .653 .726 r
F P
0 g
s
.54494 .35625 m .54891 .33497 L .56868 .34 L p .777 .653 .726 r
F P
0 g
s
.56142 .36037 m .55418 .3823 L .54098 .37907 L p .78 .646 .714 r
F P
0 g
s
.54098 .37907 m .54494 .35625 L .56142 .36037 L p .78 .646 .714 r
F P
0 g
s
.24306 .50133 m .25671 .5076 L .26866 .56448 L p .347 .464 .837 r
F P
0 g
s
.28125 .57143 m .26866 .56448 L .25671 .5076 L p .398 .483 .83 r
F P
0 g
s
.55819 .56694 m .55161 .55094 L .56329 .52958 L p .789 .646 .704 r
F P
0 g
s
.55379 .51779 m .56329 .52958 L .55161 .55094 L p .787 .641 .7 r
F P
0 g
s
.56329 .52958 m .55379 .51779 L .56061 .49901 L p .785 .638 .699 r
F P
0 g
s
.55535 .41301 m .54531 .43487 L .53968 .42988 L p .782 .636 .699 r
F P
0 g
s
.53968 .42988 m .54694 .40556 L .55535 .41301 L p .782 .636 .699 r
F P
0 g
s
.58329 .30474 m .57597 .3214 L .55291 .31543 L p .766 .674 .761 r
F P
0 g
s
.54891 .33497 m .55291 .31543 L .57597 .3214 L p .772 .663 .742 r
F P
0 g
s
.63627 .29186 m .62591 .30033 L .59815 .27769 L p .675 .667 .835 r
F P
0 g
s
.59068 .29014 m .59815 .27769 L .62591 .30033 L p .708 .663 .803 r
F P
0 g
s
.54882 .49291 m .56061 .49901 L .55379 .51779 L p .785 .636 .696 r
F P
0 g
s
.56061 .49901 m .54882 .49291 L .55176 .4794 L p .783 .634 .696 r
F P
0 g
s
.55418 .3823 m .54694 .40556 L .53702 .40318 L p .782 .641 .706 r
F P
0 g
s
.53702 .40318 m .54098 .37907 L .55418 .3823 L p .782 .641 .706 r
F P
0 g
s
.52209 .6563 m .52246 .63968 L .54771 .62242 L p .8 .697 .75 r
F P
0 g
s
.54452 .60564 m .54771 .62242 L .52246 .63968 L p .796 .678 .734 r
F P
0 g
s
.54452 .60564 m .5413 .5873 L .55819 .56694 L p .794 .66 .715 r
F P
0 g
s
.55161 .55094 m .55819 .56694 L .5413 .5873 L p .791 .651 .708 r
F P
0 g
s
.53866 .46686 m .55214 .45355 L .55289 .46598 L p .784 .633 .695 r
F P
0 g
s
.55214 .45355 m .53866 .46686 L .53736 .46151 L p .783 .634 .695 r
F P
0 g
s
.53736 .46151 m .54955 .44294 L .55214 .45355 L p .783 .634 .695 r
F P
0 g
s
.53904 .47313 m .55289 .46598 L .55176 .4794 L p .784 .634 .695 r
F P
0 g
s
.55289 .46598 m .53904 .47313 L .53866 .46686 L p .784 .633 .695 r
F P
0 g
s
.85906 .48583 m .84457 .4794 L .84458 .42548 L p .372 .504 .862 r
F P
0 g
s
.82941 .41765 m .84458 .42548 L .84457 .4794 L p .384 .498 .851 r
F P
0 g
s
.44496 .6923 m .45201 .68343 L .48552 .69019 L p .712 .744 .877 r
F P
0 g
s
.48937 .67803 m .48552 .69019 L .45201 .68343 L p .742 .717 .828 r
F P
0 g
s
.59068 .29014 m .58329 .30474 L .55693 .29779 L p .756 .688 .787 r
F P
0 g
s
.55291 .31543 m .55693 .29779 L .58329 .30474 L p .766 .674 .761 r
F P
0 g
s
.54955 .44294 m .53736 .46151 L .53523 .45745 L p .784 .634 .695 r
F P
0 g
s
.53523 .45745 m .54531 .43487 L .54955 .44294 L p .784 .634 .695 r
F P
0 g
s
.54694 .40556 m .53968 .42988 L .53305 .42832 L p .783 .637 .699 r
F P
0 g
s
.53305 .42832 m .53702 .40318 L .54694 .40556 L p .783 .637 .699 r
F P
0 g
s
.53847 .4799 m .55176 .4794 L .54882 .49291 L p .784 .634 .694 r
F P
0 g
s
.55176 .4794 m .53847 .4799 L .53904 .47313 L p .784 .634 .695 r
F P
0 g
s
.75571 .38357 m .74146 .37905 L .72311 .32488 L p .412 .497 .836 r
F P
0 g
s
.7099 .32228 m .72311 .32488 L .74146 .37905 L p .467 .52 .829 r
F P
0 g
s
.55161 .55094 m .54501 .5341 L .55379 .51779 L p .787 .641 .7 r
F P
0 g
s
.54426 .5056 m .55379 .51779 L .54501 .5341 L p .786 .637 .697 r
F P
0 g
s
.55379 .51779 m .54426 .5056 L .54882 .49291 L p .785 .636 .696 r
F P
0 g
s
.54531 .43487 m .53523 .45745 L .53241 .45496 L p .784 .634 .695 r
F P
0 g
s
.53241 .45496 m .53968 .42988 L .54531 .43487 L p .784 .634 .695 r
F P
0 g
s
.6969 .32126 m .68408 .32195 L .65742 .28123 L p .502 .578 .864 r
F P
0 g
s
.64676 .2855 m .65742 .28123 L .68408 .32195 L p .568 .598 .843 r
F P
0 g
s
.35314 .63984 m .36488 .64024 L .39384 .67814 L p .425 .562 .889 r
F P
0 g
s
.40346 .67543 m .39384 .67814 L .36488 .64024 L p .531 .597 .865 r
F P
0 g
s
.48937 .67803 m .49327 .66332 L .52209 .6563 L p .786 .717 .787 r
F P
0 g
s
.52246 .63968 m .52209 .6563 L .49327 .66332 L p .787 .693 .761 r
F P
0 g
s
.5413 .5873 m .53808 .5676 L .55161 .55094 L p .791 .651 .708 r
F P
0 g
s
.54501 .5341 m .55161 .55094 L .53808 .5676 L p .788 .644 .702 r
F P
0 g
s
.53699 .48672 m .54882 .49291 L .54426 .5056 L p .785 .634 .695 r
F P
0 g
s
.54882 .49291 m .53699 .48672 L .53847 .4799 L p .784 .634 .694 r
F P
0 g
s
.52246 .63968 m .52284 .621 L .54452 .60564 L p .796 .678 .734 r
F P
0 g
s
.5413 .5873 m .54452 .60564 L .52284 .621 L p .793 .664 .721 r
F P
0 g
s
.54891 .33497 m .54494 .35625 L .52701 .36058 L p .786 .661 .725 r
F P
0 g
s
.54494 .35625 m .54098 .37907 L .52663 .38273 L p .786 .651 .714 r
F P
0 g
s
.52663 .38273 m .52701 .36058 L .54494 .35625 L p .786 .651 .714 r
F P
0 g
s
.54098 .37907 m .53702 .40318 L .52625 .40606 L p .785 .644 .705 r
F P
0 g
s
.52625 .40606 m .52663 .38273 L .54098 .37907 L p .785 .644 .705 r
F P
0 g
s
.3069 .58275 m .31995 .58677 L .34159 .63757 L p .378 .487 .844 r
F P
0 g
s
.35314 .63984 m .34159 .63757 L .31995 .58677 L p .463 .524 .835 r
F P
0 g
s
.64676 .2855 m .63627 .29186 L .60572 .26745 L p .627 .668 .87 r
F P
0 g
s
.59815 .27769 m .60572 .26745 L .63627 .29186 L p .675 .667 .835 r
F P
0 g
s
.53968 .42988 m .53241 .45496 L .52909 .45419 L p .784 .635 .695 r
F P
0 g
s
.52909 .45419 m .53305 .42832 L .53968 .42988 L p .784 .635 .695 r
F P
0 g
s
.55291 .31543 m .54891 .33497 L .52739 .33983 L p .786 .673 .74 r
F P
0 g
s
.52701 .36058 m .52739 .33983 L .54891 .33497 L p .786 .661 .725 r
F P
0 g
s
.84458 .42548 m .85986 .43317 L .85906 .48583 L p .372 .504 .862 r
F P
0 g
s
.59815 .27769 m .59068 .29014 L .56099 .28218 L p .74 .705 .819 r
F P
0 g
s
.55693 .29779 m .56099 .28218 L .59068 .29014 L p .756 .688 .787 r
F P
0 g
s
.53702 .40318 m .53305 .42832 L .52587 .43031 L p .785 .638 .699 r
F P
0 g
s
.52587 .43031 m .52625 .40606 L .53702 .40318 L p .785 .638 .699 r
F P
0 g
s
.54501 .5341 m .53839 .5166 L .54426 .5056 L p .786 .637 .697 r
F P
0 g
s
.5347 .49311 m .54426 .5056 L .53839 .5166 L p .785 .635 .695 r
F P
0 g
s
.54426 .5056 m .5347 .49311 L .53699 .48672 L p .785 .634 .695 r
F P
0 g
s
.40346 .67543 m .41324 .67029 L .44496 .6923 L p .604 .681 .896 r
F P
0 g
s
.45201 .68343 m .44496 .6923 L .41324 .67029 L p .668 .677 .85 r
F P
0 g
s
.53808 .5676 m .53484 .54681 L .54501 .5341 L p .788 .644 .702 r
F P
0 g
s
.53839 .5166 m .54501 .5341 L .53484 .54681 L p .786 .639 .698 r
F P
0 g
s
.52511 .48046 m .53866 .46686 L .53904 .47313 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .53736 .46151 L .53866 .46686 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .53904 .47313 L .53847 .4799 L closepath p .785 .634 .694 r
F P
0 g
s
.52284 .621 m .52322 .60049 L .5413 .5873 L p .793 .664 .721 r
F P
0 g
s
.53808 .5676 m .5413 .5873 L .52322 .60049 L p .79 .653 .711 r
F P
0 g
s
.52511 .48046 m .53523 .45745 L .53736 .46151 L closepath p .785 .634 .694 r
F P
0 g
s
.25671 .5076 m .27043 .51349 L .28125 .57143 L p .398 .483 .83 r
F P
0 g
s
.294 .57758 m .28125 .57143 L .27043 .51349 L p .449 .503 .822 r
F P
0 g
s
.52511 .48046 m .53847 .4799 L .53699 .48672 L closepath p .785 .634 .694 r
F P
0 g
s
.53305 .42832 m .52909 .45419 L .52549 .45522 L p .785 .635 .695 r
F P
0 g
s
.52549 .45522 m .52587 .43031 L .53305 .42832 L p .785 .635 .695 r
F P
0 g
s
.55693 .29779 m .55291 .31543 L .52777 .32068 L p .785 .69 .759 r
F P
0 g
s
.52739 .33983 m .52777 .32068 L .55291 .31543 L p .786 .673 .74 r
F P
0 g
s
.52511 .48046 m .53241 .45496 L .53523 .45745 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .53699 .48672 L .5347 .49311 L closepath p .785 .634 .694 r
F P
0 g
s
.45201 .68343 m .45915 .67193 L .48937 .67803 L p .742 .717 .828 r
F P
0 g
s
.49327 .66332 m .48937 .67803 L .45915 .67193 L p .758 .695 .791 r
F P
0 g
s
.49327 .66332 m .4972 .6462 L .52246 .63968 L p .787 .693 .761 r
F P
0 g
s
.52284 .621 m .52246 .63968 L .4972 .6462 L p .787 .675 .741 r
F P
0 g
s
.52511 .48046 m .52909 .45419 L .53241 .45496 L closepath p .785 .634 .694 r
F P
0 g
s
.53484 .54681 m .5316 .52517 L .53839 .5166 L p .786 .639 .698 r
F P
0 g
s
.53176 .49865 m .53839 .5166 L .5316 .52517 L p .785 .635 .695 r
F P
0 g
s
.53839 .5166 m .53176 .49865 L .5347 .49311 L p .785 .635 .695 r
F P
0 g
s
.52322 .60049 m .5236 .5784 L .53808 .5676 L p .79 .653 .711 r
F P
0 g
s
.53484 .54681 m .53808 .5676 L .5236 .5784 L p .788 .645 .704 r
F P
0 g
s
.52511 .48046 m .5347 .49311 L .53176 .49865 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .52549 .45522 L .52909 .45419 L closepath p .785 .634 .694 r
F P
0 g
s
.52663 .38273 m .52625 .40606 L .51537 .41402 L p .787 .645 .704 r
F P
0 g
s
.52625 .40606 m .52587 .43031 L .51862 .43573 L p .786 .639 .699 r
F P
0 g
s
.51862 .43573 m .51537 .41402 L .52625 .40606 L p .786 .639 .699 r
F P
0 g
s
.77013 .38907 m .75571 .38357 L .73653 .32892 L p .356 .473 .841 r
F P
0 g
s
.72311 .32488 m .73653 .32892 L .75571 .38357 L p .412 .497 .836 r
F P
0 g
s
.52701 .36058 m .52663 .38273 L .51211 .39308 L p .789 .652 .711 r
F P
0 g
s
.51537 .41402 m .51211 .39308 L .52663 .38273 L p .787 .645 .704 r
F P
0 g
s
.52587 .43031 m .52549 .45522 L .52187 .45796 L p .785 .635 .695 r
F P
0 g
s
.52187 .45796 m .51862 .43573 L .52587 .43031 L p .785 .635 .695 r
F P
0 g
s
.5316 .52517 m .52836 .50296 L .53176 .49865 L p .785 .635 .695 r
F P
0 g
s
.52511 .48046 m .53176 .49865 L .52836 .50296 L closepath p .785 .634 .694 r
F P
0 g
s
.5236 .5784 m .52397 .55504 L .53484 .54681 L p .788 .645 .704 r
F P
0 g
s
.5316 .52517 m .53484 .54681 L .52397 .55504 L p .786 .639 .699 r
F P
0 g
s
.52739 .33983 m .52701 .36058 L .50885 .37312 L p .792 .663 .721 r
F P
0 g
s
.51211 .39308 m .50885 .37312 L .52701 .36058 L p .789 .652 .711 r
F P
0 g
s
.7099 .32228 m .6969 .32126 L .66826 .27899 L p .42 .549 .879 r
F P
0 g
s
.65742 .28123 m .66826 .27899 L .6969 .32126 L p .502 .578 .864 r
F P
0 g
s
.52511 .48046 m .52187 .45796 L .52549 .45522 L closepath p .785 .634 .694 r
F P
0 g
s
.56099 .28218 m .55693 .29779 L .52816 .30328 L p .783 .71 .784 r
F P
0 g
s
.52777 .32068 m .52816 .30328 L .55693 .29779 L p .785 .69 .759 r
F P
0 g
s
.60572 .26745 m .59815 .27769 L .5651 .2687 L p .715 .725 .858 r
F P
0 g
s
.56099 .28218 m .5651 .2687 L .59815 .27769 L p .74 .705 .819 r
F P
0 g
s
.52397 .55504 m .52435 .53071 L .5316 .52517 L p .786 .639 .699 r
F P
0 g
s
.52836 .50296 m .5316 .52517 L .52435 .53071 L p .785 .635 .695 r
F P
0 g
s
.4972 .6462 m .50117 .62686 L .52284 .621 L p .787 .675 .741 r
F P
0 g
s
.52322 .60049 m .52284 .621 L .50117 .62686 L p .787 .662 .725 r
F P
0 g
s
.52435 .53071 m .52473 .50574 L .52836 .50296 L p .785 .635 .695 r
F P
0 g
s
.52511 .48046 m .52836 .50296 L .52473 .50574 L closepath p .785 .634 .694 r
F P
0 g
s
.65742 .28123 m .64676 .2855 L .6134 .25943 L p .558 .662 .907 r
F P
0 g
s
.60572 .26745 m .6134 .25943 L .64676 .2855 L p .627 .668 .87 r
F P
0 g
s
.52511 .48046 m .51846 .46225 L .52187 .45796 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .5155 .46778 L .51846 .46225 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .51319 .47419 L .5155 .46778 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .5117 .48103 L .51319 .47419 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .51112 .48783 L .5117 .48103 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .5115 .49414 L .51112 .48783 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .51281 .4995 L .5115 .49414 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .51496 .50357 L .51281 .4995 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .51779 .50606 L .51496 .50357 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .52113 .5068 L .51779 .50606 L closepath p .785 .634 .694 r
F P
0 g
s
.52511 .48046 m .52473 .50574 L .52113 .5068 L closepath p .785 .634 .694 r
F P
0 g
s
.36488 .64024 m .37678 .63865 L .40346 .67543 L p .531 .597 .865 r
F P
0 g
s
.41324 .67029 m .40346 .67543 L .37678 .63865 L p .605 .615 .835 r
F P
0 g
s
.51862 .43573 m .52187 .45796 L .51846 .46225 L p .785 .635 .695 r
F P
0 g
s
.52777 .32068 m .52739 .33983 L .50557 .35435 L p .795 .676 .734 r
F P
0 g
s
.50885 .37312 m .50557 .35435 L .52739 .33983 L p .792 .663 .721 r
F P
0 g
s
.51537 .41402 m .51862 .43573 L .51179 .44421 L p .786 .638 .698 r
F P
0 g
s
.51846 .46225 m .51179 .44421 L .51862 .43573 L p .785 .635 .695 r
F P
0 g
s
.41324 .67029 m .42315 .66269 L .45201 .68343 L p .668 .677 .85 r
F P
0 g
s
.45915 .67193 m .45201 .68343 L .42315 .66269 L p .707 .67 .811 r
F P
0 g
s
.45915 .67193 m .46638 .65788 L .49327 .66332 L p .758 .695 .791 r
F P
0 g
s
.4972 .6462 m .49327 .66332 L .46638 .65788 L p .768 .677 .763 r
F P
0 g
s
.51714 .53283 m .52113 .5068 L .52473 .50574 L p .785 .635 .695 r
F P
0 g
s
.52473 .50574 m .52435 .53071 L .51714 .53283 L p .785 .635 .695 r
F P
0 g
s
.31995 .58677 m .33316 .58947 L .35314 .63984 L p .463 .524 .835 r
F P
0 g
s
.36488 .64024 m .35314 .63984 L .33316 .58947 L p .533 .552 .821 r
F P
0 g
s
.50117 .62686 m .50515 .60555 L .52322 .60049 L p .787 .662 .725 r
F P
0 g
s
.5236 .5784 m .52322 .60049 L .50515 .60555 L p .786 .651 .714 r
F P
0 g
s
.51211 .39308 m .51537 .41402 L .50511 .42655 L p .788 .644 .702 r
F P
0 g
s
.51179 .44421 m .50511 .42655 L .51537 .41402 L p .786 .638 .698 r
F P
0 g
s
.51179 .44421 m .51846 .46225 L .5155 .46778 L p .785 .635 .695 r
F P
0 g
s
.51314 .5582 m .51714 .53283 L .52435 .53071 L p .785 .639 .699 r
F P
0 g
s
.52435 .53071 m .52397 .55504 L .51314 .5582 L p .785 .639 .699 r
F P
0 g
s
.50515 .60555 m .50914 .58256 L .5236 .5784 L p .786 .651 .714 r
F P
0 g
s
.52397 .55504 m .5236 .5784 L .50914 .58256 L p .785 .644 .705 r
F P
0 g
s
.27043 .51349 m .28423 .51885 L .294 .57758 L p .449 .503 .822 r
F P
0 g
s
.3069 .58275 m .294 .57758 L .28423 .51885 L p .497 .521 .813 r
F P
0 g
s
.50914 .58256 m .51314 .5582 L .52397 .55504 L p .785 .644 .705 r
F P
0 g
s
.51045 .53138 m .51779 .50606 L .52113 .5068 L p .784 .635 .695 r
F P
0 g
s
.52113 .5068 m .51714 .53283 L .51045 .53138 L p .784 .635 .695 r
F P
0 g
s
.5155 .46778 m .50586 .45519 L .51179 .44421 L p .785 .635 .695 r
F P
0 g
s
.50586 .45519 m .5155 .46778 L .51319 .47419 L p .785 .634 .695 r
F P
0 g
s
.50885 .37312 m .51211 .39308 L .49841 .40945 L p .791 .651 .708 r
F P
0 g
s
.50511 .42655 m .49841 .40945 L .51211 .39308 L p .788 .644 .702 r
F P
0 g
s
.50511 .42655 m .51179 .44421 L .50586 .45519 L p .786 .637 .697 r
F P
0 g
s
.50476 .52644 m .51496 .50357 L .51779 .50606 L p .784 .634 .695 r
F P
0 g
s
.51779 .50606 m .51045 .53138 L .50476 .52644 L p .784 .634 .695 r
F P
0 g
s
.52816 .30328 m .52777 .32068 L .50227 .33692 L p .798 .694 .749 r
F P
0 g
s
.50557 .35435 m .50227 .33692 L .52777 .32068 L p .795 .676 .734 r
F P
0 g
s
.5651 .2687 m .56099 .28218 L .52855 .28775 L p .778 .736 .815 r
F P
0 g
s
.52816 .30328 m .52855 .28775 L .56099 .28218 L p .783 .71 .784 r
F P
0 g
s
.51319 .47419 m .50123 .46792 L .50586 .45519 L p .785 .634 .695 r
F P
0 g
s
.50123 .46792 m .51319 .47419 L .5117 .48103 L p .784 .634 .694 r
F P
0 g
s
.50044 .51834 m .51281 .4995 L .51496 .50357 L p .784 .634 .695 r
F P
0 g
s
.51496 .50357 m .50476 .52644 L .50044 .51834 L p .784 .634 .695 r
F P
0 g
s
.46638 .65788 m .47366 .64141 L .4972 .6462 L p .768 .677 .763 r
F P
0 g
s
.50117 .62686 m .4972 .6462 L .47366 .64141 L p .774 .664 .742 r
F P
0 g
s
.50309 .55606 m .51045 .53138 L .51714 .53283 L p .784 .637 .699 r
F P
0 g
s
.51714 .53283 m .51314 .5582 L .50309 .55606 L p .784 .637 .699 r
F P
0 g
s
.5117 .48103 m .49823 .48154 L .50123 .46792 L p .784 .634 .694 r
F P
0 g
s
.49823 .48154 m .5117 .48103 L .51112 .48783 L p .784 .634 .695 r
F P
0 g
s
.78471 .39541 m .77013 .38907 L .75018 .33425 L p .302 .45 .843 r
F P
0 g
s
.73653 .32892 m .75018 .33425 L .77013 .38907 L p .356 .473 .841 r
F P
0 g
s
.49782 .50765 m .5115 .49414 L .51281 .4995 L p .783 .634 .695 r
F P
0 g
s
.51281 .4995 m .50044 .51834 L .49782 .50765 L p .783 .634 .695 r
F P
0 g
s
.50557 .35435 m .50885 .37312 L .49169 .39309 L p .794 .66 .715 r
F P
0 g
s
.49841 .40945 m .49169 .39309 L .50885 .37312 L p .791 .651 .708 r
F P
0 g
s
.51112 .48783 m .49706 .49509 L .49823 .48154 L p .784 .634 .695 r
F P
0 g
s
.49706 .49509 m .51112 .48783 L .5115 .49414 L p .784 .633 .695 r
F P
0 g
s
.5115 .49414 m .49782 .50765 L .49706 .49509 L p .784 .633 .695 r
F P
0 g
s
.49841 .40945 m .50511 .42655 L .49619 .44281 L p .787 .641 .7 r
F P
0 g
s
.50586 .45519 m .49619 .44281 L .50511 .42655 L p .786 .637 .697 r
F P
0 g
s
.6134 .25943 m .60572 .26745 L .56926 .25739 L p .673 .746 .905 r
F P
0 g
s
.5651 .2687 m .56926 .25739 L .60572 .26745 L p .715 .725 .858 r
F P
0 g
s
.49619 .44281 m .50586 .45519 L .50123 .46792 L p .785 .636 .696 r
F P
0 g
s
.49572 .57974 m .50309 .55606 L .51314 .5582 L p .782 .641 .706 r
F P
0 g
s
.51314 .5582 m .50914 .58256 L .49572 .57974 L p .782 .641 .706 r
F P
0 g
s
.42315 .66269 m .43318 .65263 L .45915 .67193 L p .707 .67 .811 r
F P
0 g
s
.46638 .65788 m .45915 .67193 L .43318 .65263 L p .732 .662 .781 r
F P
0 g
s
.20253 .48154 m .18911 .47507 L .19318 .42214 L p .461 .576 .883 r
F P
0 g
s
.47366 .64141 m .48099 .62272 L .50117 .62686 L p .774 .664 .742 r
F P
0 g
s
.50515 .60555 m .50117 .62686 L .48099 .62272 L p .778 .654 .726 r
F P
0 g
s
.49452 .54872 m .50476 .52644 L .51045 .53138 L p .782 .636 .699 r
F P
0 g
s
.51045 .53138 m .50309 .55606 L .49452 .54872 L p .782 .636 .699 r
F P
0 g
s
.37678 .63865 m .38884 .63497 L .41324 .67029 L p .605 .615 .835 r
F P
0 g
s
.42315 .66269 m .41324 .67029 L .38884 .63497 L p .656 .625 .807 r
F P
0 g
s
.72311 .32488 m .7099 .32228 L .67929 .27869 L p .325 .51 .885 r
F P
0 g
s
.66826 .27899 m .67929 .27869 L .7099 .32228 L p .42 .549 .879 r
F P
0 g
s
.48835 .60206 m .49572 .57974 L .50914 .58256 L p .78 .647 .714 r
F P
0 g
s
.50914 .58256 m .50515 .60555 L .48835 .60206 L p .78 .647 .714 r
F P
0 g
s
.48099 .62272 m .48835 .60206 L .50515 .60555 L p .778 .654 .726 r
F P
0 g
s
.50227 .33692 m .50557 .35435 L .48494 .37761 L p .798 .672 .725 r
F P
0 g
s
.49169 .39309 m .48494 .37761 L .50557 .35435 L p .794 .66 .715 r
F P
0 g
s
.50123 .46792 m .48922 .46171 L .49619 .44281 L p .785 .636 .696 r
F P
0 g
s
.48922 .46171 m .50123 .46792 L .49823 .48154 L p .783 .634 .696 r
F P
0 g
s
.49169 .39309 m .49841 .40945 L .48648 .43077 L p .789 .646 .704 r
F P
0 g
s
.49619 .44281 m .48648 .43077 L .49841 .40945 L p .787 .641 .7 r
F P
0 g
s
.52855 .28775 m .52816 .30328 L .49894 .32099 L p .801 .715 .769 r
F P
0 g
s
.50227 .33692 m .49894 .32099 L .52816 .30328 L p .798 .694 .749 r
F P
0 g
s
.66826 .27899 m .65742 .28123 L .62121 .25361 L p .458 .643 .937 r
F P
0 g
s
.6134 .25943 m .62121 .25361 L .65742 .28123 L p .558 .662 .907 r
F P
0 g
s
.33316 .58947 m .34651 .59073 L .36488 .64024 L p .533 .552 .821 r
F P
0 g
s
.37678 .63865 m .36488 .64024 L .34651 .59073 L p .589 .573 .804 r
F P
0 g
s
.48803 .53669 m .50044 .51834 L .50476 .52644 L p .781 .634 .698 r
F P
0 g
s
.50476 .52644 m .49452 .54872 L .48803 .53669 L p .781 .634 .698 r
F P
0 g
s
.48648 .43077 m .49619 .44281 L .48922 .46171 L p .785 .638 .699 r
F P
0 g
s
.28423 .51885 m .29812 .52356 L .3069 .58275 L p .497 .521 .813 r
F P
0 g
s
.31995 .58677 m .3069 .58275 L .29812 .52356 L p .54 .539 .802 r
F P
0 g
s
.49823 .48154 m .48469 .48194 L .48922 .46171 L p .783 .634 .696 r
F P
0 g
s
.48469 .48194 m .49823 .48154 L .49706 .49509 L p .782 .633 .696 r
F P
0 g
s
.48426 .57009 m .49452 .54872 L .50309 .55606 L p .779 .638 .705 r
F P
0 g
s
.50309 .55606 m .49572 .57974 L .48426 .57009 L p .779 .638 .705 r
F P
0 g
s
.48408 .52078 m .49782 .50765 L .50044 .51834 L p .781 .633 .698 r
F P
0 g
s
.50044 .51834 m .48803 .53669 L .48408 .52078 L p .781 .633 .698 r
F P
0 g
s
.43318 .65263 m .4433 .64019 L .46638 .65788 L p .732 .662 .781 r
F P
0 g
s
.47366 .64141 m .46638 .65788 L .4433 .64019 L p .749 .655 .757 r
F P
0 g
s
.56926 .25739 m .5651 .2687 L .52895 .27419 L p .767 .768 .853 r
F P
0 g
s
.52855 .28775 m .52895 .27419 L .5651 .2687 L p .778 .736 .815 r
F P
0 g
s
.19318 .42214 m .20721 .42708 L .20253 .48154 L p .461 .576 .883 r
F P
0 g
s
.21599 .48816 m .20253 .48154 L .20721 .42708 L p .479 .571 .87 r
F P
0 g
s
.49706 .49509 m .48294 .50209 L .48469 .48194 L p .782 .633 .696 r
F P
0 g
s
.48294 .50209 m .49706 .49509 L .49782 .50765 L p .781 .633 .697 r
F P
0 g
s
.49782 .50765 m .48408 .52078 L .48294 .50209 L p .781 .633 .697 r
F P
0 g
s
.48494 .37761 m .49169 .39309 L .47674 .41916 L p .791 .653 .71 r
F P
0 g
s
.48648 .43077 m .47674 .41916 L .49169 .39309 L p .789 .646 .704 r
F P
0 g
s
.49894 .32099 m .50227 .33692 L .47814 .36315 L p .802 .686 .737 r
F P
0 g
s
.48494 .37761 m .47814 .36315 L .50227 .33692 L p .798 .672 .725 r
F P
0 g
s
.47399 .5902 m .48426 .57009 L .49572 .57974 L p .775 .641 .713 r
F P
0 g
s
.49572 .57974 m .48835 .60206 L .47399 .5902 L p .775 .641 .713 r
F P
0 g
s
.48922 .46171 m .47716 .45558 L .48648 .43077 L p .785 .638 .699 r
F P
0 g
s
.47716 .45558 m .48922 .46171 L .48469 .48194 L p .782 .635 .698 r
F P
0 g
s
.38884 .63497 m .40102 .62918 L .42315 .66269 L p .656 .625 .807 r
F P
0 g
s
.43318 .65263 m .42315 .66269 L .40102 .62918 L p .692 .63 .783 r
F P
0 g
s
.4433 .64019 m .45349 .62551 L .47366 .64141 L p .749 .655 .757 r
F P
0 g
s
.48099 .62272 m .47366 .64141 L .45349 .62551 L p .761 .649 .738 r
F P
0 g
s
.47558 .55425 m .48803 .53669 L .49452 .54872 L p .777 .634 .703 r
F P
0 g
s
.49452 .54872 m .48426 .57009 L .47558 .55425 L p .777 .634 .703 r
F P
0 g
s
.47674 .41916 m .48648 .43077 L .47716 .45558 L p .785 .641 .702 r
F P
0 g
s
.79946 .40242 m .78471 .39541 L .76406 .34065 L p .251 .429 .843 r
F P
0 g
s
.75018 .33425 m .76406 .34065 L .78471 .39541 L p .302 .45 .843 r
F P
0 g
s
.46373 .60877 m .47399 .5902 L .48835 .60206 L p .769 .644 .724 r
F P
0 g
s
.48835 .60206 m .48099 .62272 L .46373 .60877 L p .769 .644 .724 r
F P
0 g
s
.45349 .62551 m .46373 .60877 L .48099 .62272 L p .761 .649 .738 r
F P
0 g
s
.52895 .27419 m .52855 .28775 L .49558 .30665 L p .804 .741 .794 r
F P
0 g
s
.49894 .32099 m .49558 .30665 L .52855 .28775 L p .801 .715 .769 r
F P
0 g
s
.48469 .48194 m .4711 .48218 L .47716 .45558 L p .782 .635 .698 r
F P
0 g
s
.4711 .48218 m .48469 .48194 L .48294 .50209 L p .779 .632 .699 r
F P
0 g
s
.20721 .42708 m .22122 .43206 L .21599 .48816 L p .479 .571 .87 r
F P
0 g
s
.22949 .49481 m .21599 .48816 L .22122 .43206 L p .501 .568 .856 r
F P
0 g
s
.62121 .25361 m .6134 .25943 L .57349 .24828 L p .603 .762 .955 r
F P
0 g
s
.56926 .25739 m .57349 .24828 L .6134 .25943 L p .673 .746 .905 r
F P
0 g
s
.47028 .5333 m .48408 .52078 L .48803 .53669 L p .776 .632 .702 r
F P
0 g
s
.48803 .53669 m .47558 .55425 L .47028 .5333 L p .776 .632 .702 r
F P
0 g
s
.34651 .59073 m .35999 .59045 L .37678 .63865 L p .589 .573 .804 r
F P
0 g
s
.38884 .63497 m .37678 .63865 L .35999 .59045 L p .633 .589 .787 r
F P
0 g
s
.47814 .36315 m .48494 .37761 L .46695 .40809 L p .794 .661 .717 r
F P
0 g
s
.47674 .41916 m .46695 .40809 L .48494 .37761 L p .791 .653 .71 r
F P
0 g
s
.29812 .52356 m .31209 .52753 L .31995 .58677 L p .54 .539 .802 r
F P
0 g
s
.33316 .58947 m .31995 .58677 L .31209 .52753 L p .58 .555 .791 r
F P
0 g
s
.48294 .50209 m .46876 .5087 L .4711 .48218 L p .779 .632 .699 r
F P
0 g
s
.46876 .5087 m .48294 .50209 L .48408 .52078 L p .777 .631 .7 r
F P
0 g
s
.48408 .52078 m .47028 .5333 L .46876 .5087 L p .777 .631 .7 r
F P
0 g
s
.4631 .57074 m .47558 .55425 L .48426 .57009 L p .771 .635 .71 r
F P
0 g
s
.48426 .57009 m .47399 .5902 L .4631 .57074 L p .771 .635 .71 r
F P
0 g
s
.40102 .62918 m .41332 .62129 L .43318 .65263 L p .692 .63 .783 r
F P
0 g
s
.4433 .64019 m .43318 .65263 L .41332 .62129 L p .718 .633 .762 r
F P
0 g
s
.47716 .45558 m .46505 .44957 L .47674 .41916 L p .785 .641 .702 r
F P
0 g
s
.46505 .44957 m .47716 .45558 L .4711 .48218 L p .78 .635 .701 r
F P
0 g
s
.46695 .40809 m .47674 .41916 L .46505 .44957 L p .785 .644 .706 r
F P
0 g
s
.49558 .30665 m .49894 .32099 L .4713 .34982 L p .807 .703 .751 r
F P
0 g
s
.47814 .36315 m .4713 .34982 L .49894 .32099 L p .802 .686 .737 r
F P
0 g
s
.73653 .32892 m .72311 .32488 L .69055 .2802 L p .219 .463 .879 r
F P
0 g
s
.67929 .27869 m .69055 .2802 L .72311 .32488 L p .325 .51 .885 r
F P
0 g
s
.45061 .5859 m .4631 .57074 L .47399 .5902 L p .763 .635 .719 r
F P
0 g
s
.47399 .5902 m .46373 .60877 L .45061 .5859 L p .763 .635 .719 r
F P
0 g
s
.67929 .27869 m .66826 .27899 L .62918 .24993 L p .321 .6 .946 r
F P
0 g
s
.62121 .25361 m .62918 .24993 L .66826 .27899 L p .458 .643 .937 r
F P
0 g
s
.22122 .43206 m .23521 .43703 L .22949 .49481 L p .501 .568 .856 r
F P
0 g
s
.24306 .50133 m .22949 .49481 L .23521 .43703 L p .524 .569 .843 r
F P
0 g
s
.57349 .24828 m .56926 .25739 L .52935 .26264 L p .745 .805 .9 r
F P
0 g
s
.52895 .27419 m .52935 .26264 L .56926 .25739 L p .767 .768 .853 r
F P
0 g
s
.45645 .545 m .47028 .5333 L .47558 .55425 L p .77 .631 .707 r
F P
0 g
s
.47558 .55425 m .4631 .57074 L .45645 .545 L p .77 .631 .707 r
F P
0 g
s
.41332 .62129 m .4257 .61136 L .4433 .64019 L p .718 .633 .762 r
F P
0 g
s
.45349 .62551 m .4433 .64019 L .4257 .61136 L p .737 .634 .745 r
F P
0 g
s
.4711 .48218 m .45746 .4822 L .46505 .44957 L p .78 .635 .701 r
F P
0 g
s
.45746 .4822 m .4711 .48218 L .46876 .5087 L p .775 .631 .702 r
F P
0 g
s
.4713 .34982 m .47814 .36315 L .45711 .39763 L p .797 .671 .725 r
F P
0 g
s
.46695 .40809 m .45711 .39763 L .47814 .36315 L p .794 .661 .717 r
F P
0 g
s
.35999 .59045 m .37358 .58857 L .38884 .63497 L p .633 .589 .787 r
F P
0 g
s
.40102 .62918 m .38884 .63497 L .37358 .58857 L p .668 .601 .771 r
F P
0 g
s
.43814 .59951 m .45061 .5859 L .46373 .60877 L p .752 .635 .731 r
F P
0 g
s
.46373 .60877 m .45349 .62551 L .43814 .59951 L p .752 .635 .731 r
F P
0 g
s
.4257 .61136 m .43814 .59951 L .45349 .62551 L p .737 .634 .745 r
F P
0 g
s
.45452 .51478 m .46876 .5087 L .47028 .5333 L p .771 .629 .704 r
F P
0 g
s
.47028 .5333 m .45645 .545 L .45452 .51478 L p .771 .629 .704 r
F P
0 g
s
.46876 .5087 m .45452 .51478 L .45746 .4822 L p .775 .631 .702 r
F P
0 g
s
.31209 .52753 m .32615 .53064 L .33316 .58947 L p .58 .555 .791 r
F P
0 g
s
.34651 .59073 m .33316 .58947 L .32615 .53064 L p .614 .568 .779 r
F P
0 g
s
.46505 .44957 m .45289 .4437 L .46695 .40809 L p .785 .644 .706 r
F P
0 g
s
.45289 .4437 m .46505 .44957 L .45746 .4822 L p .777 .636 .704 r
F P
0 g
s
.45711 .39763 m .46695 .40809 L .45289 .4437 L p .785 .648 .711 r
F P
0 g
s
.52935 .26264 m .52895 .27419 L .49219 .29399 L p .805 .773 .824 r
F P
0 g
s
.49558 .30665 m .49219 .29399 L .52895 .27419 L p .804 .741 .794 r
F P
0 g
s
.81436 .40989 m .79946 .40242 L .77816 .34792 L p .207 .413 .843 r
F P
0 g
s
.76406 .34065 m .77816 .34792 L .79946 .40242 L p .251 .429 .843 r
F P
0 g
s
.44259 .55568 m .45645 .545 L .4631 .57074 L p .761 .628 .714 r
F P
0 g
s
.4631 .57074 m .45061 .5859 L .44259 .55568 L p .761 .628 .714 r
F P
0 g
s
.23521 .43703 m .24919 .44195 L .24306 .50133 L p .524 .569 .843 r
F P
0 g
s
.25671 .5076 m .24306 .50133 L .24919 .44195 L p .548 .571 .829 r
F P
0 g
s
.37358 .58857 m .38727 .58507 L .40102 .62918 L p .668 .601 .771 r
F P
0 g
s
.41332 .62129 m .40102 .62918 L .38727 .58507 L p .696 .61 .756 r
F P
0 g
s
.49219 .29399 m .49558 .30665 L .4644 .33771 L p .812 .724 .768 r
F P
0 g
s
.4713 .34982 m .4644 .33771 L .49558 .30665 L p .807 .703 .751 r
F P
0 g
s
.45746 .4822 m .44377 .48197 L .45289 .4437 L p .777 .636 .704 r
F P
0 g
s
.44377 .48197 m .45746 .4822 L .45452 .51478 L p .769 .629 .705 r
F P
0 g
s
.44025 .5202 m .45452 .51478 L .45645 .545 L p .763 .627 .708 r
F P
0 g
s
.45645 .545 m .44259 .55568 L .44025 .5202 L p .763 .627 .708 r
F P
0 g
s
.42872 .56516 m .44259 .55568 L .45061 .5859 L p .75 .626 .722 r
F P
0 g
s
.45061 .5859 m .43814 .59951 L .42872 .56516 L p .75 .626 .722 r
F P
0 g
s
.4644 .33771 m .4713 .34982 L .44721 .38787 L p .8 .682 .735 r
F P
0 g
s
.45711 .39763 m .44721 .38787 L .4713 .34982 L p .797 .671 .725 r
F P
0 g
s
.45452 .51478 m .44025 .5202 L .44377 .48197 L p .769 .629 .705 r
F P
0 g
s
.62918 .24993 m .62121 .25361 L .57781 .24133 L p .487 .757 .99 r
F P
0 g
s
.57349 .24828 m .57781 .24133 L .62121 .25361 L p .603 .762 .955 r
F P
0 g
s
.32615 .53064 m .34027 .53283 L .34651 .59073 L p .614 .568 .779 r
F P
0 g
s
.35999 .59045 m .34651 .59073 L .34027 .53283 L p .645 .58 .768 r
F P
0 g
s
.45289 .4437 m .44067 .43801 L .45711 .39763 L p .785 .648 .711 r
F P
0 g
s
.44067 .43801 m .45289 .4437 L .44377 .48197 L p .774 .636 .709 r
F P
0 g
s
.38727 .58507 m .40104 .57997 L .41332 .62129 L p .696 .61 .756 r
F P
0 g
s
.4257 .61136 m .41332 .62129 L .40104 .57997 L p .718 .617 .743 r
F P
0 g
s
.44721 .38787 m .45711 .39763 L .44067 .43801 L p .785 .653 .717 r
F P
0 g
s
.41486 .5733 m .42872 .56516 L .43814 .59951 L p .736 .622 .732 r
F P
0 g
s
.43814 .59951 m .4257 .61136 L .41486 .5733 L p .736 .622 .732 r
F P
0 g
s
.24919 .44195 m .26316 .44675 L .25671 .5076 L p .548 .571 .829 r
F P
0 g
s
.27043 .51349 m .25671 .5076 L .26316 .44675 L p .573 .575 .817 r
F P
0 g
s
.40104 .57997 m .41486 .5733 L .4257 .61136 L p .718 .617 .743 r
F P
0 g
s
.42594 .52486 m .44025 .5202 L .44259 .55568 L p .754 .623 .714 r
F P
0 g
s
.44259 .55568 m .42872 .56516 L .42594 .52486 L p .754 .623 .714 r
F P
0 g
s
.75018 .33425 m .73653 .32892 L .70203 .28337 L p .112 .41 .859 r
F P
0 g
s
.69055 .2802 m .70203 .28337 L .73653 .32892 L p .219 .463 .879 r
F P
0 g
s
.44377 .48197 m .43002 .48144 L .44067 .43801 L p .774 .636 .709 r
F P
0 g
s
.43002 .48144 m .44377 .48197 L .44025 .5202 L p .763 .627 .71 r
F P
0 g
s
.57781 .24133 m .57349 .24828 L .52975 .25311 L p .702 .843 .95 r
F P
0 g
s
.52935 .26264 m .52975 .25311 L .57349 .24828 L p .745 .805 .9 r
F P
0 g
s
.34027 .53283 m .35446 .53404 L .35999 .59045 L p .645 .58 .768 r
F P
0 g
s
.37358 .58857 m .35999 .59045 L .35446 .53404 L p .671 .591 .757 r
F P
0 g
s
.44025 .5202 m .42594 .52486 L .43002 .48144 L p .763 .627 .71 r
F P
0 g
s
.26316 .44675 m .27712 .45138 L .27043 .51349 L p .573 .575 .817 r
F P
0 g
s
.28423 .51885 m .27043 .51349 L .27712 .45138 L p .597 .579 .804 r
F P
0 g
s
.69055 .2802 m .67929 .27869 L .63732 .2483 L p .152 .527 .919 r
F P
0 g
s
.62918 .24993 m .63732 .2483 L .67929 .27869 L p .321 .6 .946 r
F P
0 g
s
.44067 .43801 m .42839 .43251 L .44721 .38787 L p .785 .653 .717 r
F P
0 g
s
.42839 .43251 m .44067 .43801 L .43002 .48144 L p .77 .637 .713 r
F P
0 g
s
.52975 .25311 m .52935 .26264 L .48875 .28305 L p .802 .812 .859 r
F P
0 g
s
.49219 .29399 m .48875 .28305 L .52935 .26264 L p .805 .773 .824 r
F P
0 g
s
.41162 .52865 m .42594 .52486 L .42872 .56516 L p .743 .619 .721 r
F P
0 g
s
.42872 .56516 m .41486 .5733 L .41162 .52865 L p .743 .619 .721 r
F P
0 g
s
.82941 .41765 m .81436 .40989 L .79248 .35582 L p .173 .402 .844 r
F P
0 g
s
.77816 .34792 m .79248 .35582 L .81436 .40989 L p .207 .413 .843 r
F P
0 g
s
.48875 .28305 m .49219 .29399 L .45743 .32688 L p .817 .749 .788 r
F P
0 g
s
.4644 .33771 m .45743 .32688 L .49219 .29399 L p .812 .724 .768 r
F P
0 g
s
.44721 .38787 m .43723 .37885 L .4644 .33771 L p .8 .682 .735 r
F P
0 g
s
.43723 .37885 m .44721 .38787 L .42839 .43251 L p .785 .659 .724 r
F P
0 g
s
.35446 .53404 m .36871 .53423 L .37358 .58857 L p .671 .591 .757 r
F P
0 g
s
.38727 .58507 m .37358 .58857 L .36871 .53423 L p .694 .6 .747 r
F P
0 g
s
.45743 .32688 m .4644 .33771 L .43723 .37885 L p .804 .696 .746 r
F P
0 g
s
.3973 .53151 m .41162 .52865 L .41486 .5733 L p .729 .613 .729 r
F P
0 g
s
.41486 .5733 m .40104 .57997 L .3973 .53151 L p .729 .613 .729 r
F P
0 g
s
.43002 .48144 m .41624 .48058 L .42839 .43251 L p .77 .637 .713 r
F P
0 g
s
.41624 .48058 m .43002 .48144 L .42594 .52486 L p .755 .624 .715 r
F P
0 g
s
.36871 .53423 m .38299 .53338 L .38727 .58507 L p .694 .6 .747 r
F P
0 g
s
.40104 .57997 m .38727 .58507 L .38299 .53338 L p .713 .607 .737 r
F P
0 g
s
.42594 .52486 m .41162 .52865 L .41624 .48058 L p .755 .624 .715 r
F P
0 g
s
.38299 .53338 m .3973 .53151 L .40104 .57997 L p .713 .607 .737 r
F P
0 g
s
.27712 .45138 m .29108 .45581 L .28423 .51885 L p .597 .579 .804 r
F P
0 g
s
.29812 .52356 m .28423 .51885 L .29108 .45581 L p .619 .584 .792 r
F P
0 g
s
.42839 .43251 m .41606 .42722 L .43723 .37885 L p .785 .659 .724 r
F P
0 g
s
.41606 .42722 m .42839 .43251 L .41624 .48058 L p .766 .637 .719 r
F P
0 g
s
.40242 .47935 m .41624 .48058 L .41162 .52865 L p .746 .621 .721 r
F P
0 g
s
.41162 .52865 m .3973 .53151 L .40242 .47935 L p .746 .621 .721 r
F P
0 g
s
.29108 .45581 m .30504 .45997 L .29812 .52356 L p .619 .584 .792 r
F P
0 g
s
.31209 .52753 m .29812 .52356 L .30504 .45997 L p .641 .589 .781 r
F P
0 g
s
.41624 .48058 m .40242 .47935 L .41606 .42722 L p .766 .637 .719 r
F P
0 g
s
.43723 .37885 m .42718 .37063 L .45743 .32688 L p .804 .696 .746 r
F P
0 g
s
.42718 .37063 m .43723 .37885 L .41606 .42722 L p .785 .665 .731 r
F P
0 g
s
.63732 .2483 m .62918 .24993 L .58221 .2365 L p .308 .706 .978 r
F P
0 g
s
.57781 .24133 m .58221 .2365 L .62918 .24993 L p .487 .757 .99 r
F P
0 g
s
.30504 .45997 m .31899 .46384 L .31209 .52753 L p .641 .589 .781 r
F P
0 g
s
.32615 .53064 m .31209 .52753 L .31899 .46384 L p .661 .595 .77 r
F P
0 g
s
.38856 .47774 m .40242 .47935 L .3973 .53151 L p .736 .618 .727 r
F P
0 g
s
.3973 .53151 m .38299 .53338 L .38856 .47774 L p .736 .618 .727 r
F P
0 g
s
.45743 .32688 m .45038 .31736 L .48875 .28305 L p .817 .749 .788 r
F P
0 g
s
.45038 .31736 m .45743 .32688 L .42718 .37063 L p .808 .711 .759 r
F P
0 g
s
.31899 .46384 m .33293 .46737 L .32615 .53064 L p .661 .595 .77 r
F P
0 g
s
.34027 .53283 m .32615 .53064 L .33293 .46737 L p .679 .6 .76 r
F P
0 g
s
.37468 .47574 m .38856 .47774 L .38299 .53338 L p .724 .614 .734 r
F P
0 g
s
.38299 .53338 m .36871 .53423 L .37468 .47574 L p .724 .614 .734 r
F P
0 g
s
.48875 .28305 m .48526 .27385 L .52975 .25311 L p .802 .812 .859 r
F P
0 g
s
.48526 .27385 m .48875 .28305 L .45038 .31736 L p .822 .778 .811 r
F P
0 g
s
.76406 .34065 m .75018 .33425 L .71375 .288 L p .011 .357 .831 r
F P
0 g
s
.70203 .28337 m .71375 .288 L .75018 .33425 L p .112 .41 .859 r
F P
0 g
s
.41606 .42722 m .40365 .42215 L .42718 .37063 L p .785 .665 .731 r
F P
0 g
s
.40365 .42215 m .41606 .42722 L .40242 .47935 L p .761 .638 .725 r
F P
0 g
s
.84458 .42548 m .82941 .41765 L .80701 .3641 L p .15 .4 .847 r
F P
0 g
s
.79248 .35582 m .80701 .3641 L .82941 .41765 L p .173 .402 .844 r
F P
0 g
s
.40242 .47935 m .38856 .47774 L .40365 .42215 L p .761 .638 .725 r
F P
0 g
s
.58221 .2365 m .57781 .24133 L .53017 .2456 L p .619 .869 .989 r
F P
0 g
s
.52975 .25311 m .53017 .2456 L .57781 .24133 L p .702 .843 .95 r
F P
0 g
s
.33293 .46737 m .34686 .47055 L .34027 .53283 L p .679 .6 .76 r
F P
0 g
s
.35446 .53404 m .34027 .53283 L .34686 .47055 L p .696 .605 .751 r
F P
0 g
s
.36078 .47334 m .37468 .47574 L .36871 .53423 L p .711 .61 .742 r
F P
0 g
s
.36871 .53423 m .35446 .53404 L .36078 .47334 L p .711 .61 .742 r
F P
0 g
s
.53017 .2456 m .52975 .25311 L .48526 .27385 L p .791 .855 .899 r
F P
0 g
s
.34686 .47055 m .36078 .47334 L .35446 .53404 L p .696 .605 .751 r
F P
0 g
s
.70203 .28337 m .69055 .2802 L .64563 .24858 L p 0 .429 .851 r
F P
0 g
s
.63732 .2483 m .64563 .24858 L .69055 .2802 L p .152 .527 .919 r
F P
0 g
s
.42718 .37063 m .41704 .36321 L .45038 .31736 L p .808 .711 .759 r
F P
0 g
s
.41704 .36321 m .42718 .37063 L .40365 .42215 L p .785 .673 .74 r
F P
0 g
s
.39118 .41732 m .40365 .42215 L .38856 .47774 L p .756 .639 .732 r
F P
0 g
s
.38856 .47774 m .37468 .47574 L .39118 .41732 L p .756 .639 .732 r
F P
0 g
s
.40365 .42215 m .39118 .41732 L .41704 .36321 L p .785 .673 .74 r
F P
0 g
s
.45038 .31736 m .44324 .30917 L .48526 .27385 L p .822 .778 .811 r
F P
0 g
s
.44324 .30917 m .45038 .31736 L .41704 .36321 L p .811 .729 .774 r
F P
0 g
s
.37863 .41272 m .39118 .41732 L .37468 .47574 L p .749 .641 .74 r
F P
0 g
s
.37468 .47574 m .36078 .47334 L .37863 .41272 L p .749 .641 .74 r
F P
0 g
s
.85986 .43317 m .84458 .42548 L .82172 .37249 L p .139 .406 .853 r
F P
0 g
s
.80701 .3641 m .82172 .37249 L .84458 .42548 L p .15 .4 .847 r
F P
0 g
s
.48526 .27385 m .48171 .26637 L .53017 .2456 L p .791 .855 .899 r
F P
0 g
s
.48171 .26637 m .48526 .27385 L .44324 .30917 L p .824 .81 .838 r
F P
0 g
s
.36601 .40835 m .37863 .41272 L .36078 .47334 L p .742 .642 .749 r
F P
0 g
s
.36078 .47334 m .34686 .47055 L .36601 .40835 L p .742 .642 .749 r
F P
0 g
s
.41704 .36321 m .4068 .35662 L .44324 .30917 L p .811 .729 .774 r
F P
0 g
s
.4068 .35662 m .41704 .36321 L .39118 .41732 L p .784 .681 .751 r
F P
0 g
s
.39118 .41732 m .37863 .41272 L .4068 .35662 L p .784 .681 .751 r
F P
0 g
s
.64563 .24858 m .63732 .2483 L .5867 .23369 L p .083 .594 .887 r
F P
0 g
s
.58221 .2365 m .5867 .23369 L .63732 .2483 L p .308 .706 .978 r
F P
0 g
s
.77816 .34792 m .76406 .34065 L .72572 .29388 L p 0 .311 .799 r
F P
0 g
s
.71375 .288 m .72572 .29388 L .76406 .34065 L p .011 .357 .831 r
F P
0 g
s
.53017 .2456 m .53059 .24004 L .58221 .2365 L p .619 .869 .989 r
F P
0 g
s
.53059 .24004 m .53017 .2456 L .48171 .26637 L p .762 .899 .938 r
F P
0 g
s
.35331 .4042 m .36601 .40835 L .34686 .47055 L p .734 .644 .759 r
F P
0 g
s
.34686 .47055 m .33293 .46737 L .35331 .4042 L p .734 .644 .759 r
F P
0 g
s
.5867 .23369 m .58221 .2365 L .53059 .24004 L p .474 .852 .984 r
F P
0 g
s
.34052 .40027 m .35331 .4042 L .33293 .46737 L p .725 .646 .77 r
F P
0 g
s
.33293 .46737 m .31899 .46384 L .34052 .40027 L p .725 .646 .77 r
F P
0 g
s
.44324 .30917 m .436 .3023 L .48171 .26637 L p .824 .81 .838 r
F P
0 g
s
.436 .3023 m .44324 .30917 L .4068 .35662 L p .814 .748 .791 r
F P
0 g
s
.39645 .35083 m .4068 .35662 L .37863 .41272 L p .783 .69 .762 r
F P
0 g
s
.37863 .41272 m .36601 .40835 L .39645 .35083 L p .783 .69 .762 r
F P
0 g
s
.71375 .288 m .70203 .28337 L .65414 .25061 L p 0 .325 .756 r
F P
0 g
s
.64563 .24858 m .65414 .25061 L .70203 .28337 L p 0 .429 .851 r
F P
0 g
s
.32765 .39652 m .34052 .40027 L .31899 .46384 L p .715 .648 .781 r
F P
0 g
s
.31899 .46384 m .30504 .45997 L .32765 .39652 L p .715 .648 .781 r
F P
0 g
s
.4068 .35662 m .39645 .35083 L .436 .3023 L p .814 .748 .791 r
F P
0 g
s
.82172 .37249 m .8366 .38074 L .85986 .43317 L p .139 .406 .853 r
F P
0 g
s
.31469 .39295 m .32765 .39652 L .30504 .45997 L p .704 .651 .794 r
F P
0 g
s
.30504 .45997 m .29108 .45581 L .31469 .39295 L p .704 .651 .794 r
F P
0 g
s
.30165 .38953 m .31469 .39295 L .29108 .45581 L p .692 .654 .808 r
F P
0 g
s
.29108 .45581 m .27712 .45138 L .30165 .38953 L p .692 .654 .808 r
F P
0 g
s
.48171 .26637 m .47809 .26056 L .53059 .24004 L p .762 .899 .938 r
F P
0 g
s
.47809 .26056 m .48171 .26637 L .436 .3023 L p .822 .847 .867 r
F P
0 g
s
.38599 .34584 m .39645 .35083 L .36601 .40835 L p .781 .7 .775 r
F P
0 g
s
.36601 .40835 m .35331 .4042 L .38599 .34584 L p .781 .7 .775 r
F P
0 g
s
.28851 .38622 m .30165 .38953 L .27712 .45138 L p .679 .658 .822 r
F P
0 g
s
.27712 .45138 m .26316 .44675 L .28851 .38622 L p .679 .658 .822 r
F P
0 g
s
.27529 .38299 m .28851 .38622 L .26316 .44675 L p .665 .662 .837 r
F P
0 g
s
.26316 .44675 m .24919 .44195 L .27529 .38299 L p .665 .662 .837 r
F P
0 g
s
.79248 .35582 m .77816 .34792 L .73793 .30077 L p 0 .275 .77 r
F P
0 g
s
.72572 .29388 m .73793 .30077 L .77816 .34792 L p 0 .311 .799 r
F P
0 g
s
.65414 .25061 m .64563 .24858 L .5913 .23277 L p 0 .446 .738 r
F P
0 g
s
.5867 .23369 m .5913 .23277 L .64563 .24858 L p .083 .594 .887 r
F P
0 g
s
.436 .3023 m .42865 .29671 L .47809 .26056 L p .822 .847 .867 r
F P
0 g
s
.42865 .29671 m .436 .3023 L .39645 .35083 L p .816 .77 .809 r
F P
0 g
s
.39645 .35083 m .38599 .34584 L .42865 .29671 L p .816 .77 .809 r
F P
0 g
s
.26198 .37982 m .27529 .38299 L .24919 .44195 L p .651 .667 .852 r
F P
0 g
s
.24919 .44195 m .23521 .43703 L .26198 .37982 L p .651 .667 .852 r
F P
0 g
s
.53059 .24004 m .53102 .23634 L .5867 .23369 L p .474 .852 .984 r
F P
0 g
s
.53102 .23634 m .53059 .24004 L .47809 .26056 L p .704 .932 .964 r
F P
0 g
s
.3754 .34159 m .38599 .34584 L .35331 .4042 L p .778 .711 .789 r
F P
0 g
s
.35331 .4042 m .34052 .40027 L .3754 .34159 L p .778 .711 .789 r
F P
0 g
s
.24858 .37667 m .26198 .37982 L .23521 .43703 L p .635 .672 .868 r
F P
0 g
s
.23521 .43703 m .22122 .43206 L .24858 .37667 L p .635 .672 .868 r
F P
0 g
s
.5913 .23277 m .5867 .23369 L .53102 .23634 L p .267 .763 .899 r
F P
0 g
s
.2351 .37349 m .24858 .37667 L .22122 .43206 L p .619 .678 .884 r
F P
0 g
s
.22122 .43206 m .20721 .42708 L .2351 .37349 L p .619 .678 .884 r
F P
0 g
s
.22154 .37026 m .2351 .37349 L .20721 .42708 L p .603 .684 .899 r
F P
0 g
s
.20721 .42708 m .19318 .42214 L .22154 .37026 L p .603 .684 .899 r
F P
0 g
s
.72572 .29388 m .71375 .288 L .66284 .25419 L p 0 .234 .659 r
F P
0 g
s
.65414 .25061 m .66284 .25419 L .71375 .288 L p 0 .325 .756 r
F P
0 g
s
.36468 .33803 m .3754 .34159 L .34052 .40027 L p .774 .722 .804 r
F P
0 g
s
.34052 .40027 m .32765 .39652 L .36468 .33803 L p .774 .722 .804 r
F P
0 g
s
.47809 .26056 m .47441 .25634 L .53102 .23634 L p .704 .932 .964 r
F P
0 g
s
.47441 .25634 m .47809 .26056 L .42865 .29671 L p .813 .884 .896 r
F P
0 g
s
.42117 .29233 m .42865 .29671 L .38599 .34584 L p .816 .792 .83 r
F P
0 g
s
.38599 .34584 m .3754 .34159 L .42117 .29233 L p .816 .792 .83 r
F P
0 g
s
.42865 .29671 m .42117 .29233 L .47441 .25634 L p .813 .884 .896 r
F P
0 g
s
.80701 .3641 m .79248 .35582 L .75037 .3084 L p 0 .254 .749 r
F P
0 g
s
.73793 .30077 m .75037 .3084 L .79248 .35582 L p 0 .275 .77 r
F P
0 g
s
.35383 .33509 m .36468 .33803 L .32765 .39652 L p .769 .734 .82 r
F P
0 g
s
.32765 .39652 m .31469 .39295 L .35383 .33509 L p .769 .734 .82 r
F P
0 g
s
.53102 .23634 m .53146 .23439 L .5913 .23277 L p .267 .763 .899 r
F P
0 g
s
.53146 .23439 m .53102 .23634 L .47441 .25634 L p .603 .933 .958 r
F P
0 g
s
.5913 .23277 m .59601 .23358 L .65414 .25061 L p 0 .446 .738 r
F P
0 g
s
.66284 .25419 m .65414 .25061 L .59601 .23358 L p .295 0 0 r
F P
0 g
s
.41357 .28909 m .42117 .29233 L .3754 .34159 L p .814 .816 .852 r
F P
0 g
s
.3754 .34159 m .36468 .33803 L .41357 .28909 L p .814 .816 .852 r
F P
0 g
s
.59601 .23358 m .5913 .23277 L .53146 .23439 L p .05 .617 .748 r
F P
0 g
s
.34284 .33269 m .35383 .33509 L .31469 .39295 L p .763 .746 .837 r
F P
0 g
s
.31469 .39295 m .30165 .38953 L .34284 .33269 L p .763 .746 .837 r
F P
0 g
s
.47441 .25634 m .47064 .25361 L .53146 .23439 L p .603 .933 .958 r
F P
0 g
s
.47064 .25361 m .47441 .25634 L .42117 .29233 L p .793 .919 .923 r
F P
0 g
s
.73793 .30077 m .72572 .29388 L .67175 .2591 L p .396 0 0 r
F P
0 g
s
.66419 .25493 m .67175 .2591 L .69454 .27379 L p 0 .234 .659 r
F P
0 g
s
.67175 .2591 m .68087 .26507 L .73793 .30077 L p .396 0 0 r
F P
0 g
s
.75037 .3084 m .74184 .30317 L p .68087 .26507 L .448 0 0 r
F P
0 g
s
.74184 .30317 m .73793 .30077 L .73046 .2961 L p .448 0 0 r
F P
0 g
s
.73046 .2961 m .68087 .26507 L p .74184 .30317 L .448 0 0 r
F P
0 g
s
.66284 .25419 m .66419 .25493 L p .72572 .29388 L 0 .234 .659 r
F P
0 g
s
.69454 .27379 m .72572 .29388 L p .66419 .25493 L 0 .234 .659 r
F P
0 g
s
.42117 .29233 m .41357 .28909 L .47064 .25361 L p .793 .919 .923 r
F P
0 g
s
.33171 .33073 m .34284 .33269 L .30165 .38953 L p .754 .758 .855 r
F P
0 g
s
.30165 .38953 m .28851 .38622 L .33171 .33073 L p .754 .758 .855 r
F P
0 g
s
.82172 .37249 m .80701 .3641 L .76305 .31647 L p 0 .248 .74 r
F P
0 g
s
.75037 .3084 m .76305 .31647 L .80701 .3641 L p 0 .254 .749 r
F P
0 g
s
.40584 .28686 m .41357 .28909 L .36468 .33803 L p .808 .84 .874 r
F P
0 g
s
.36468 .33803 m .35383 .33509 L .40584 .28686 L p .808 .84 .874 r
F P
0 g
s
.53146 .23439 m .53191 .23403 L .59601 .23358 L p .05 .617 .748 r
F P
0 g
s
.53191 .23403 m .53146 .23439 L .47064 .25361 L p .46 .885 .903 r
F P
0 g
s
.32043 .32912 m .33171 .33073 L .28851 .38622 L p .743 .769 .874 r
F P
0 g
s
.28851 .38622 m .27529 .38299 L .32043 .32912 L p .743 .769 .874 r
F P
0 g
s
.67175 .2591 m .66284 .25419 L .60084 .23591 L p .402 0 0 r
F P
0 g
s
.59601 .23358 m .60084 .23591 L .66284 .25419 L p .295 0 0 r
F P
0 g
s
.60084 .23591 m .59601 .23358 L .53191 .23403 L p .127 0 0 r
F P
0 g
s
.4668 .25223 m .47064 .25361 L .41357 .28909 L p .758 .946 .941 r
F P
0 g
s
.41357 .28909 m .40584 .28686 L .4668 .25223 L p .758 .946 .941 r
F P
0 g
s
.47064 .25361 m .4668 .25223 L .53191 .23403 L p .46 .885 .903 r
F P
0 g
s
.39797 .28553 m .40584 .28686 L .35383 .33509 L p .799 .863 .897 r
F P
0 g
s
.35383 .33509 m .34284 .33269 L .39797 .28553 L p .799 .863 .897 r
F P
0 g
s
.30902 .32773 m .32043 .32912 L .27529 .38299 L p .73 .779 .892 r
F P
0 g
s
.27529 .38299 m .26198 .37982 L .30902 .32773 L p .73 .779 .892 r
F P
0 g
s
.8366 .38074 m .82172 .37249 L .77594 .32469 L p 0 .258 .744 r
F P
0 g
s
.77594 .32469 m .82172 .37249 L p .76378 .31717 L 0 .248 .74 r
F P
0 g
s
.77594 .32469 m .78901 .33274 L .8366 .38074 L p 0 .258 .744 r
F P
0 g
s
.77594 .32469 m .7094 .28642 L p .78806 .33219 L .463 0 0 r
F P
0 g
s
.78901 .33274 m .77594 .32469 L p .78806 .33219 L .463 0 0 r
F P
0 g
s
.76305 .31647 m .77594 .32469 L p .76378 .31717 L 0 .248 .74 r
F P
0 g
s
.29747 .32645 m .30902 .32773 L .26198 .37982 L p .715 .788 .909 r
F P
0 g
s
.26198 .37982 m .24858 .37667 L .29747 .32645 L p .715 .788 .909 r
F P
0 g
s
.53191 .23403 m .53238 .23507 L .60084 .23591 L p .127 0 0 r
F P
0 g
s
.53238 .23507 m .53191 .23403 L .4668 .25223 L p .298 .794 .806 r
F P
0 g
s
.38995 .28494 m .39797 .28553 L .34284 .33269 L p .783 .883 .918 r
F P
0 g
s
.34284 .33269 m .33171 .33073 L .38995 .28494 L p .783 .883 .918 r
F P
0 g
s
.46287 .25204 m .4668 .25223 L .40584 .28686 L p .704 .958 .947 r
F P
0 g
s
.40584 .28686 m .39797 .28553 L .46287 .25204 L p .704 .958 .947 r
F P
0 g
s
.68087 .26507 m .67175 .2591 L .60579 .23955 L p .468 0 0 r
F P
0 g
s
.60084 .23591 m .60579 .23955 L .67175 .2591 L p .402 0 0 r
F P
0 g
s
.28579 .32516 m .29747 .32645 L .24858 .37667 L p .697 .795 .926 r
F P
0 g
s
.24858 .37667 m .2351 .37349 L .28579 .32516 L p .697 .795 .926 r
F P
0 g
s
.4668 .25223 m .46287 .25204 L .53238 .23507 L p .298 .794 .806 r
F P
0 g
s
.60579 .23955 m .60084 .23591 L .53238 .23507 L p .25 0 0 r
F P
0 g
s
.76305 .31647 m .75037 .3084 L .69018 .27182 L p .475 0 0 r
F P
0 g
s
.68087 .26507 m .69018 .27182 L .75037 .3084 L p .448 0 0 r
F P
0 g
s
.27399 .32374 m .28579 .32516 L .2351 .37349 L p .677 .799 .94 r
F P
0 g
s
.2351 .37349 m .22154 .37026 L .27399 .32374 L p .677 .799 .94 r
F P
0 g
s
.3818 .28493 m .38995 .28494 L .33171 .33073 L p .763 .9 .937 r
F P
0 g
s
.33171 .33073 m .32043 .32912 L .3818 .28493 L p .763 .9 .937 r
F P
0 g
s
.45886 .25285 m .46287 .25204 L .39797 .28553 L p .635 .953 .938 r
F P
0 g
s
.39797 .28553 m .38995 .28494 L .45886 .25285 L p .635 .953 .938 r
F P
0 g
s
.53238 .23507 m .53285 .23731 L .60579 .23955 L p .25 0 0 r
F P
0 g
s
.53285 .23731 m .53238 .23507 L .46287 .25204 L p .149 .687 .696 r
F P
0 g
s
.46287 .25204 m .45886 .25285 L .53285 .23731 L p .149 .687 .696 r
F P
0 g
s
.69018 .27182 m .68087 .26507 L .61085 .24423 L p .505 0 0 r
F P
0 g
s
.60579 .23955 m .61085 .24423 L .68087 .26507 L p .468 0 0 r
F P
0 g
s
.3735 .28533 m .3818 .28493 L .32043 .32912 L p .737 .91 .953 r
F P
0 g
s
.32043 .32912 m .30902 .32773 L .3735 .28533 L p .737 .91 .953 r
F P
0 g
s
.77594 .32469 m .76305 .31647 L .6997 .27904 L p .479 0 0 r
F P
0 g
s
.69018 .27182 m .6997 .27904 L .76305 .31647 L p .475 0 0 r
F P
0 g
s
.61085 .24423 m .60579 .23955 L .53285 .23731 L p .329 0 0 r
F P
0 g
s
.38995 .28494 m .3818 .28493 L .45476 .25445 L p .556 .93 .915 r
F P
0 g
s
.45476 .25445 m .45886 .25285 L .39412 .283 L p .556 .93 .915 r
F P
0 g
s
.39677 .28173 m .45476 .25445 L .39412 .283 L .556 .93 .915 r
F
.45058 .25661 m .45476 .25445 L .38409 .28397 L p .478 .896 .886 r
F P
0 g
s
.38409 .28397 m .3818 .28493 L p .38579 .28329 L .478 .896 .886 r
F P
0 g
s
.38579 .28329 m .45058 .25661 L .38409 .28397 L .478 .896 .886 r
F
.3818 .28493 m .3735 .28533 L .44494 .25871 L p F P
0 g
s
.3818 .28493 m .44494 .25871 L .4416 .2603 L .478 .896 .886 r
F
.44494 .25871 m .45058 .25661 L p .4416 .2603 L F P
0 g
s
.44459 .25884 m .37359 .28529 L p .44329 .26017 L .41 .861 .86 r
F P
0 g
s
.37367 .28526 m .44631 .25908 L .37359 .28529 L .41 .861 .86 r
F
.37359 .28529 m .3735 .28533 L p .37367 .28526 L F P
0 g
s
.3735 .28533 m .36507 .28593 L .4432 .26011 L p .41 .861 .86 r
F P
0 g
s
.3735 .28533 m .4432 .26011 L .44105 .26098 L .41 .861 .86 r
F
.44329 .26017 m .44631 .25908 L .44459 .25884 L F
.4432 .26011 m .44631 .25908 L p .44105 .26098 L F P
0 g
s
.44197 .26161 m .44631 .25908 L .36507 .28593 L p .359 .832 .844 r
F P
0 g
s
.36507 .28593 m .3565 .28656 L .44184 .26164 L p .359 .832 .844 r
F P
0 g
s
.36507 .28593 m .44184 .26164 L .44174 .26168 L .359 .832 .844 r
F
.43754 .26392 m .44178 .2617 L p .3565 .28656 L .328 .813 .842 r
F P
0 g
s
.44184 .26164 m .44197 .26161 L p .44174 .26168 L .359 .832 .844 r
F P
0 g
s
.44178 .2617 m .44197 .26161 L .44184 .26164 L p .328 .813 .842 r
F P
0 g
s
.44184 .26164 m .3565 .28656 L p .44178 .2617 L .328 .813 .842 r
F P
0 g
s
.44631 .25908 m .45058 .25661 L .44459 .25884 L p .41 .861 .86 r
F P
0 g
s
.39412 .283 m .38995 .28494 L p .39677 .28173 L .556 .93 .915 r
F P
0 g
s
.36507 .28593 m .3735 .28533 L .30902 .32773 L p .707 .915 .966 r
F P
0 g
s
.30902 .32773 m .29747 .32645 L .36507 .28593 L p .707 .915 .966 r
F P
0 g
s
.53285 .23731 m .53334 .24049 L .61085 .24423 L p .329 0 0 r
F P
0 g
s
.53334 .24049 m .53285 .23731 L .45886 .25285 L p 0 0 0 r
F P
0 g
s
.45886 .25285 m .45476 .25445 L .53334 .24049 L p 0 0 0 r
F P
0 g
s
.6997 .27904 m .69018 .27182 L .61604 .24967 L p .522 0 0 r
F P
0 g
s
.61085 .24423 m .61604 .24967 L .69018 .27182 L p .505 0 0 r
F P
0 g
s
.6997 .27904 m .7094 .28642 L .77594 .32469 L p .479 0 0 r
F P
0 g
s
.61604 .24967 m .61085 .24423 L .53334 .24049 L p .376 0 0 r
F P
0 g
s
.3565 .28656 m .36507 .28593 L .29747 .32645 L p .675 .914 .975 r
F P
0 g
s
.29747 .32645 m .28579 .32516 L .3565 .28656 L p .675 .914 .975 r
F P
0 g
s
.53334 .24049 m .53383 .24436 L .61604 .24967 L p .376 0 0 r
F P
0 g
s
.53383 .24436 m .53334 .24049 L .45476 .25445 L p .051 0 0 r
F P
0 g
s
.45476 .25445 m .45058 .25661 L .53383 .24436 L p .051 0 0 r
F P
0 g
s
.34782 .287 m .3565 .28656 L .28579 .32516 L p .644 .907 .982 r
F P
0 g
s
.28579 .32516 m .27399 .32374 L .34782 .287 L p .644 .907 .982 r
F P
0 g
s
.7094 .28642 m .71927 .29362 L .78901 .33274 L p .463 0 0 r
F P
0 g
s
.7094 .28642 m .6997 .27904 L .62134 .25557 L p .523 0 0 r
F P
0 g
s
.61604 .24967 m .62134 .25557 L .6997 .27904 L p .522 0 0 r
F P
0 g
s
.62134 .25557 m .61604 .24967 L .53383 .24436 L p .402 0 0 r
F P
0 g
s
.53434 .24862 m .53383 .24436 L .45058 .25661 L p .103 0 0 r
F P
0 g
s
.45058 .25661 m .44631 .25908 L .53434 .24862 L p .103 0 0 r
F P
0 g
s
.53383 .24436 m .53434 .24862 L .62134 .25557 L p .402 0 0 r
F P
0 g
s
.71927 .29362 m .7094 .28642 L .62675 .2616 L p .508 0 0 r
F P
0 g
s
.62134 .25557 m .62675 .2616 L .7094 .28642 L p .523 0 0 r
F P
0 g
s
.62675 .2616 m .62134 .25557 L .53434 .24862 L p .409 0 0 r
F P
0 g
s
.3565 .28656 m .34782 .287 L .43754 .26392 L p .328 .813 .842 r
F P
0 g
s
.53486 .25298 m .53434 .24862 L .44631 .25908 L p .129 0 0 r
F P
0 g
s
.44631 .25908 m .44197 .26161 L .53486 .25298 L p .129 0 0 r
F P
0 g
s
.53434 .24862 m .53486 .25298 L .62675 .2616 L p .409 0 0 r
F P
0 g
s
.62675 .2616 m .63227 .26744 L .71927 .29362 L p .508 0 0 r
F P
0 g
s
.63227 .26744 m .62675 .2616 L .53486 .25298 L p .4 0 0 r
F P
0 g
s
.53539 .25714 m .53486 .25298 L .44197 .26161 L p .133 0 0 r
F P
0 g
s
.44197 .26161 m .43754 .26392 L .53539 .25714 L p .133 0 0 r
F P
0 g
s
.53486 .25298 m .53539 .25714 L .63227 .26744 L p .4 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`0008_ooooo6_l0000Oooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@02cooooo
000kooooo`;o0000R_oooolQo`0001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00>?ooool3o`000003ooooool0003ooooo08Kooooo4Ol0
0005oe@0017o00006Oooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00=_ooool2o`0008Sooooo2_l00003o`d00003o`00
0?mP003oH00000GoH0003Ol00004oe@00003o`000?mg003o000000Go00005_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000Q_ooool9o`0000Go3@004_l0
0006of0000So000000?oM`00o`000?l000001?l0000Cooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0<_ooool0037ooooo0_l00025ooooo`So00000ol=000Co`0000KoIP004Ol00000
0omg003o0000o`000005o`0000oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`00;_ooool3o`000003ooooool0003ooooo087ooooo1_l000000ol=003o0000o`00000<o`00
00Co8@0000?o0000ofP00?mX00001OmX000>o`0000GoIP0000?o0000ohD00?l000001?l000000omg
003o0000o`000005o`0000cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aoooo
o`00;Oooool2o`0000Cooooo00?o0000ooooooooool0O?oooolAo`0000?o8@004Ol0000=ofP000Wo
000000?oQ@00o`000?l000002_l0000:ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000OooooolUo`0000?oIP003ol00005ofP00003o`00
0?n5003o000000;o000000?oQ@00o`000?l000002?l00009ooooo`03o`000?oooooooooo02gooooo
0ol0000aooooo`00;Oooool01?l0003oooooooooool0001koooooaco00001?o=cm/01?l0003o_/kV
okk>i_nnc^H?o`0000OoIP002Ol000001On5003o0000o`000?l0003oQ@0000Wo00001oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo000]ooooo`;o00000_ooool00ol0003o
ooooooooo`1fooooo`ko000000Cod>;Uo`000?oBf=go00000oo3i_04ol[JiP?o00001Oo=cm/4o`00
00[oa<CJ00?o0000okNifong^M/00ong^M/;o`0000?oIP0000?o0000oh800?l000000_l000001On5
003o0000o`000?l0003oQ@0000So00001Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02kooooo000/ooooo`;o00001?ooool00ol0003oooooooooo`1booooo`Ko000000CoX_?`okCe
l_o2l_3o`_;`0_l000000oo;jnco0000o`000002om3Ri@03o`000?oBf=god]SM00;o00001?o:f^H2
o`0000KocLoK0_l000000oo>aM;o0000olC4fP0:olC4fP03o`000?ng^M_o]kWK00Wo]kWK0_l00004
oj2[gPOo000000GoPP00o`000?l0003o0000ohD0000:o`0000Cooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo06kooooo1?l000001omCd=OoN^GRo`000?nRlo3o]?Gbo`000?o2l_000_l00002ol_[k003o`00
0?o@h^God>;U00;o00000_oBf=d00ol0003od/oFo`000002ol[JiP;o00001_o=cm/2o`0000?oc/GB
00?o0000olC4f_o4a=X01_o4a=X4o`0000co]kWK00?o0000ojbZeOnPZmh01?nPZmh00ol0003oSZWX
ohjYj002ohjYj0?o000000CoPP00o`000?l0003o00000_n50008o`0000;ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo06[ooooo1?l000000omCd=OoN^GRo`000002oj;cl0;o]?Gb0_o2l_000ol0003obn_/
ol_[k002o`0000;od>;U00Go0000om;HgOoBf=god]SMo`000002om;?eP;o00001_o=cm/3o`0000Go
c/GB00?o0000olC4f_o4a=X01_l00003olNld003o`000?nm]=7o_KCA00Co00001Ong^M/01Ol0003o
[:[EojbZeOn/Z]Go000000CoX:_N0_l00003ohjYj0Go000000CoPP00o`000?l0003o00000_n50008
o`0003Cooooo00?o0000ooooooooool0;?ooool002cooooo0ol00006ooooo`03o`000?oooooooooo
06Gooooo1?l000001OmCd=OoJ=cLog[Uh_mjiN;o000000;oX_?`0_ndmO82ol;bl0;o00000_o;jn`0
1Ol0003od>;Uom3RiOo@h^Go000000?od]SM00Ko0000om;?e_oBcmKo0000om;7col00005olg?f`03
o`000?o>aM;oc/GB00Goc/GB1?l00008olNld003o`000?nm]=7o_KCA00Go_KCA0ol00002okNif`03
o`000?n/Z]Go[:[E00;o[:[E00?o0000oj2[g_nPZmh00onPZmh00ol0003oSZWXohjYj002ohjYj003
o`000?meY>ooMJC_00?o000000CoPP00o`000?l0003o00000_n50005o`0003Cooooo0_l0000]oooo
o`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo1?l00002oe?@e`05
ofSLg?mjiN;o0000og[Uh_l000000_nRlo03okCelP;o`_;`00Co0000ol_[k?o;jnco00000oo@h^D2
o`0000;od]SM0_l00002om;?eP05o`000?oBalood/O?om;7col000000_o=cm/00ol0003oc/GBolk5
dP05olk5dP;o000000?ocKg;o`000?o7_=002Oo7_=000ol0003o_KCAokfdd@08okfdd@;o00001_n/
Z]D2o`0000CoX:_N00?o0000ohjYj?n>ZNP00_n>ZNP00ol0003oMJC_ogFTk`05o`000004oh800?l0
003o0000o`0000;oQ@001?l0000cooooo`03o`000?oooooooooo02_ooooo000Aooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0000;oDm3G0_mXg=`2og[UhP;o
00000onRlo03okCelP?o`_;`0oo;jn`01Ol0003od>;Uom3RiOo@h^Go000000?od]SM00Go0000om;?
e_oBcmKod/oFo`000004om;7c`;o00001oo>aM82o`0000?ocKg;00?o0000olNld?o7_=001Oo7_=03
o`0000co_KCA00?o0000okFYcOl000001_n/Z]D00ol0003oX:_Noj2[gP02oj2[gP03o`000?n>ZNSo
SZWX00Co00000_n0Tmd3of^<h@?o000000GoPP00o`000?l0003o0000ohD00003o`0003?ooooo00?o
0000ooooooooool0:_ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eooo
ool4o`0000;oDm3G1Ol000000omjiN;o0000o`000003o`0000;o]?Gb0oo2l_001?l0003obn_/ol_[
k?o;jn`4om3Ri@05o`000?oBf=god]SMom;HgOl000000ooBcmH00ol0003od/O?om;7c`02om;7c`03
o`000?oA_lWo000000Goc/GB0_l00005olfmb`03o`000?o7_=3oakc@00Go00000_o8]LP00ol0003o
`K39ol6`b@03o`0000Ko_KCA00Go0000okFYcOneZLgo]JW=o`000006ojbZe@04o`000?nPZmkoX:_N
oj2[gP?o00000_nAVML00ol0003oP9?Moh2Cg@02oh2Cg@?oJhcQ00?o0000oe>2h_l000000_l00000
1On2003o0000o`000?l0003oNP0000;o0000<Oooool00ol0003oooooooooo`0Zooooo`002Oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0
000;ooooo`03o`000?oooooooooo05?ooooo1Ol000001_mCd=Oo]>[gokCZmol0003o_>Sco`0000;o
`nK_00Co0000olSRjoo8h^_o00000_o<g>D6o`0000;obn_/1Oo@h^D01Ol0003od]SMom;HgOoBf=go
000000?od/oF00?o0000om;7cooBall00_oBall01?l0003odKo9om6obOl00003olk5dP;o00001_o=
_L/4o`0000Oob;G800?o0000ol6`bOo1/<T00oo1/<T3o`0000;o_KCA00?o0000okFYcOneZLd00one
ZLd2o`0000Go[:[E00Go0000oj2[g_l0003oWYcBo`000004oi6Ie`03o`000?n0TmgoP9?M00;oP9?M
0om[S>401?l0003oDh;Roe>2h_mCP^83o`000003oh800?l0003o000000;o0000<Oooool00ol0003o
ooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo0_l000000onTj?_o
0000o`000002o`000005okCZmol0003o0000okcXlol000000_o3i^l01?l0003ob>;[olSRjol00002
olcLi@05o`000?o>emooc]OOolkGgol000000_o@d=X2o`0000Cod>;U1?oBf=d01Ol0003od/oFom;?
e_oBcmKo000000Cod/O?00?o0000om6obOoA_lT00_oA_lT00ol0003oc/GBo`000006olfmb`;o0000
00?ocKO4o`000?o8]LP01oo8]LP00ol0003o`K39ol6`b@07ol6`b@;o00002?neZLd00ol0003o[:[E
ojbZe@03ojbZe@05o`000?nNW=;oWYcBoijLd_l000001?nAVML01Ol0003oP9?Moh2CgOn0Tmgo0000
00?oJhcQ00Go0000oe>2h_mCP^;oDh;RocQfh@08o`00033ooooo00?o0000ooooooooool0:?ooool0
017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04gooooo0_l000001OnTj?_o0000o`00
0?n/jOWo000000;o]>[g00Co0000okcXlol0003o00000_o3i^l01?l0003ob>;[olSRjol00002olcL
i@05o`000?o>emooc]OOolkGgol000000oo@d=X00ol0003od<[Do`000002om3Ri@Cod]SM1OoBcmH4
om;7c`03o`000?oA_lWodKo900;odKo90_l00006olfmb`;o00000oo=]l@00ol0003ob;G8olReb006
olReb003o`000?o1/<Wo`K3900So`K3900?o0000ok^Xa_l000001oneZLd01?l0003o[:[EojbZeOn/
Z]D2o`0000CoWYcB00Go0000oi6IeonAVMOoTIWGo`000004oh2Cg@04o`000?m[S>7oJhcQo`0000?o
Dh;R0_l000000olhM^7o76SKoaaXf`06o`0002kooooo0_l0000Yooooo`004Oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000oooooooo
ool0B_ooool2o`000005ojCXnol0003o0000ojcYnOl000000_ndj_L2o`000004okcXlol0003o`nK_
ol?Vk`;o00000_o8h^/01?l0003oc=cUolcLiOl00003olkGg`05o`000?o@d=[od=3Jom3@f_l00000
0oo@b]@00ol0003od]SMom;Hg@02om;Hg@God/oF1?oBall00ol0003odKo9om6ob@02om6ob@03o`00
0?o?^LCo000000GocKg;00?o0000olfga?o=]l@00oo=]l@00ol0003ob;G8olReb004olReb0?o0000
2Oo1/<T01Ol0003o^jS6ok^Xa_nkZ<Ko000000Oo]JW=00?o0000ojbZeOl000000_nYW/`01Ol0003o
WYcBoijLd_nNW=;o000000CoTIWG00?o0000oh2CgOn0Tmd00_n0Tmd01?l0003oJhcQof^<hOl00003
oe>2hP03o`000?lhM^7o>7KQ00;o76SK00Ko0000o`9Ke?l0003o0000ogX00?l0000]ooooo`;o0000
:Oooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`;o000000?oY>Sko`000?l00000
0_n/jOT01?l0003o]>[gokCZmol00002okcXl`04o`000?o3i^oo`nK_o`0000?ob>;[00Co0000olcL
iOo<g>Go00000oo>eml01Ol0003od=3Jom3@f_o@d=[o000000Cod<[D0_l00002om;Hg@God/oF1?oB
all00ol0003odKo9om6ob@02om6ob@04o`000?o?^LCockW4o`0000?ocKg;0_l00006olfga003o`00
0?o8]LSo000000Co00000_o8/<800ol0003oa:c2olB/`P03o`0000Co`K3900?o0000ok^Xa_nkZ<H0
0_nkZ<H00ol0003o]JW=okFYc@05okFYc@05o`000?nYW/coZIk<ojVNc?l000001?nNW=800ol0003o
TIWGoi6Ie`02oi6Ie`05o`000?n0TmgoP9?Moh2CgOl000000om[S>400ol0003oDh;Roe>2hP02o`00
00;o>7KQ0_lLJ=/00ol0003o0U_Do`000004o`0002gooooo00?o0000ooooooooool09_ooool0017o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@oooo
o`;o0000AOooool2o`000003ojCXnol0003o000000;o[>Wi00?o0000okCZmondj_L00_l000000onl
j??o0000o`000002ol?Vk`05o`000?o8h^_ob>;[olSRjol000000_o<g>D01Ol0003oc]OOolkGgoo>
emoo000000?od=3J00?o0000om3:e?o@b]@00_o@b]@00ol0003od<G?om35c`02o`0000Cod/oF1?oB
all00ol0003odKo9om6ob@02om6ob@03o`000?o?^LCockW400;ockW400?o0000olfmbol000001oo=
]l@3o`0000Oob;3200?o0000olB/`_o4[<800oo4[<83o`000003ol6`bOl0003o^jS600Co^jS600?o
0000okFYcOneZLd00oneZLd2o`0000CoZIk<00?o0000oijLd_nNW=800_nNW=800ol0003oTIWGoi6I
e`02oi6Ie`05o`000?n0TmgoP9?Moh2CgOl000000_m[S>402?l0003oDh;Ro`000?l0003oDh;Ro`00
0?lhM^7o00000_lLJ=/00ol0003o0U_Do`000005o`0002_ooooo00?o0000ooooooooool09_ooool0
02[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`10ooooo`;o00000_nTj?/01Ol0
003o[>WiojcYnOn/jOWo000000;o]>[g00Co0000okcXlonlj??o00000_o3i^l2o`0000?ob>;[00Co
0000olcLiOo<g>Go00000oo>eml01Ol0003od=3Jom3@f_o@d=[o000000Cod<[D00Oo0000om35coo@
aLood<G?o`000?o@_l[o000000;od/oF1?oBall00ol0003odKo9om6ob@02om6ob@03o`000?o?^LCo
ckW400?ockW400?o0000olfga?o=]l@01Oo=]l@2o`000003olba_ol0003ob;3200Oob;3200?o0000
olB/`_o4[<801_o4[<800ol0003o^jS6ok^XaP05ok^XaP05o`000?neZLgo]JW=okFYcOl000000_na
X<L00ol0003oZIk<ojVNc002ojVNc003o`000?nNW=;oWYcB00;oWYcB00Go0000oi6IeonAVMOoTIWG
o`000003oh2Cg@03o`000?m[S>7o000000;o000000CoDh;Ro`000?mCP^;o00000_lhM^400ol0003o
76SKo`000002o`9Ke003o`000?l0Clco000000Co0000:_ooool00ol0003oooooooooo`0Uooooo`00
:_ooool2o`0001Gooooo00?o0000ooooooooool0?Oooool2o`0000;oY>Sk0_l00002ojcYn@03o`00
0?ndj_Oo]>[g00;o00000_nlj?<01?l0003o`nK_ol?Vkol00004olSRj`04o`000?o<g>Goc=cUo`00
00?oc]OO00Go0000om3@f_o@d=[od=3Jo`000004om3:e005o`000?o@aLood<G?om35col000000oo@
_lX00ol0003od/O?om;7c`02om;7c`03o`000?oA_lWodKo900;odKo900?o0000olnia?o?^L@00oo?
^L@2o`0000KocKO400Go0000olba_oo</Kooc;6oo`000007olR``P03o`000?o4[<;oa:c200Ooa:c2
00?o0000oknV`Ol000001_nkZ<H00ol0003o]JW=o`000003ok6Pa`03o`000?nYW/coZIk<00;oZIk<
00?o0000oijLd_nNW=800_nNW=800ol0003oTIWGoi6Ie`02oi6Ie`03o`000?n0Tmgo000000;o0000
0om[S>401Ol0003oDh;Ro`000?mCP^;o000000;o>7KQ00?o0000oaaXfol000000_l2Fm@00ol0003o
04o<o`000004o`0002[ooooo00?o0000ooooooooool09?ooool002[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0jooooo`;o00000_nTj?/2o`0000?o[>Wi00Co0000okCZmondj_Oo
00000onlj?<01?l0003o`nK_ol?Vkol00004olSRj`?oc=cU00Go0000olkGgoo>emooc]OOo`000003
om3@fP03o`000?o@b]Cod<[D00;od<[D00Go0000om35coo@aLood<G?o`000004om2obP03o`000?oB
alood/O?00;od/O?1?oA_lT00ol0003ockW4olnia003olnia003o`000?o>/l3o000000CocKO40_l0
0004olba_`03o`000?o8/<;ob;3200Gob;3200?o0000olB/`_o4[<801_o4[<801Ol0003o_jK1oknV
`OnoY/7o000000Ko^jS600?o0000ok6PaonaX<L00onaX<L00ol0003oZIk<ojVNc002ojVNc003o`00
0?nNW=;oWYcB00;oWYcB00?o0000oi6IeonAVML00ol00003oh2Cg@09o`000?m[S>7oJhcQof^<hOl0
003oDh;Ro`000?mCP^;o000000;o>7KQ00?o0000oaaXfol000000_l2Fm@01?l0003o04o<o`000?l0
A/D4o`0002Sooooo0_l0000Uooooo`00:_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo03Oooooo0_l00003ojCXn`03o`000?n/jOWo[>Wi00;o[>Wi0ondj_L01?l0003o_>ScokcXlonl
j?<3ol?Vk`03o`000?o8h^_ob>;[00;ob>;[0oo<g>D01Ol0003oc]OOolkGgoo>emoo000000?od=3J
00?o0000om3:e?o@b]@00_o@b]@01Ol0003od<G?om35coo@aLoo000000Cod;o:00?o0000olnja_l0
00000_oBall4om6ob@03o`000?o?^LCockW400?ockW400Go0000oljc`?o>/l3oc[?0o`000002olfg
a003o`000?o</Kooc;6o00?oc;6o00?o0000olR``_o8/<801?o8/<83o`000003olB/`_l0003oa:c2
00Coa:c200?o0000oknV`OnoY/400onoY/400ol0003o^jS6ok^XaP03ok^XaP03o`000?naX<Oo/J37
00?o/J3700?o0000ojVNc?nYW/`00_nYW/`00ol0003oWYcBoijLdP02oijLdP?o00000_nAVML01Ol0
003oP9?Moh2CgOn0Tmgo000000?oJhcQ00?o0000oe>2h_mCP^800_l00002ocQfh@04o`000?lLJ=_o
76SKo`0000;o0U_D00Co0000o`1?c?l0003o04K51Ol0000Vooooo`;o00002?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00000onTj?/00ol0003o
[>WiojcYn@02ojcYn@?o]>[g00Go0000okcXlonlj??o_>Sco`000003ol?Vk`03o`000?o8h^_ob>;[
00;ob>;[1?o<g>D3olkGg`05o`000?o@d=[od=3Jom3@f_l000001?o@b]@01Ol0003od<G?om35coo@
aLoo000000Cod;o:00Go0000olnja_o?^/Kock[6o`000004om6ob@03o`000?o?^LCockW400?ockW4
00?o0000oljc`?o>/l000_o>/l000ol0003ocKO4olba_`06olba_`03o`000?o8/<;o000000Co0000
0_o9[;d00ol0003oaJVmolFY_@03o`0000;oa:c200?o0000oknV`OnoY/401?noY/401ol0003o^jS6
ok^Xa_nkZ<Ko0000okNQ`_l000001OnaX<L00ol0003oZIk<ojVNc002ojVNc0Co000000?oWYcBo`00
0?nAVML00onAVML01Ol0003oP9?Moh2CgOn0Tmgo000000?oJhcQ00Go0000oe>2h_l0003oDh;Ro`00
0002ocQfh@04o`000?lLJ=_o76SKo`0000;o0U_D00Co0000o`1?c?l0003o04K51Ol0000Vooooo`03
o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`06ooooo`00:_ooool2o`0001Wooooo00?o0000ooooooooool0<Oooool2o`0000?o
Y>Sk00?o0000ojcYnOn/jOT00on/jOT3okCZm`05o`000?nlj??o_>ScokcXlol000000oo3i^l5olSR
j`Coc=cU0oo>eml00ol0003od=3Jom3@fP02om3@fP05o`000?o@b]Cod<[Dom3:e?l000001?o@aLl0
1Ol0003od;o:om2ob_o@_l[o000000Cock[600?o0000om6obOoA_lT00_oA_lT5olnia003o`000?o>
/l3oc[?000?oc[?000?o0000olba_oo</Kl01Oo</Kl3o`0000KobJbm00?o0000olFY_Oo5ZKd01?o5
ZKd2o`0000So_jK100?o0000ok^Xa_l000000ongXL800ol0003o/J37ok6Pa`03ok6Pa`03o`000?nY
W/co000000?o00001?nNW=800ol0003oTIWGoi6Ie`0?o`0000;o>7KQ00?o0000oaaXfol000000_l2
Fm@01ol0003o04o<o`1?c?l0003o04K5o`000?l0@Kl00ol0000Vooooo`03o`000?oooooooooo00Go
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo000Yooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0;_ooool8o`0000?o[>Wi1?ndj_L4okcXl`Co
`nK_1Oo8h^/4olcLi@?oc]OO00?o0000om3@f_o@d=X00_o@d=X00ol0003od<[Dom3:e002om3:e005
o`000?o@aLood<G?om35col000001?o@_lX01ol0003ock[6olnja_o?^/Ko0000oljf`_l000000_oA
_lT5olnia003o`000?o>/l3oc[?000?oc[?00_l00006olba_`03o`000?o;[K_o000000OobJbm00?o
0000olFY_Oo5ZKd01Oo5ZKd00ol0003o`ZFlo`000007oknV`@03o`000?ngXL;o]j7200;o]j7200?o
0000ok6PaonaX<L00_naX<L3o`0000?oZIk<00Co0000oijLd_nNW=;oWYcB1?l00002oiZCb`CoT8o>
1?n4R]43ogN5e0Ko000000Go76SKo`000?l2FmCo0U_Do`000002o`1?c004o`000?l0A/Go0000o`11
_`Co00009Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`06ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02cooooo00Go0000ojg<l?n]c?3o[Lc`o`000004ok;;k@So00000_nlj?<4ol?Vk`Gob>;[1?o<g>D4
olkGg`Cod=3J00?o0000om3:e?o@b]@00_o@b]@01Ol0003od<G?om35coo@aLoo000000Cod;o:00Go
0000olnja_o?^/Kock[6o`000003oljf`P03o`000?o?^LCockW400?ockW400?o0000oljc`?o>/l00
0oo>/l000ol0003ocJnlo`000004olba_`;o00000_o;[K/00ol0003obJbmolV/_@05olV/_@03o`00
0?o5ZKgoaJVm00CoaJVm00Co0000ol:U_?o2YKco`ZFl0_l00005oknV`@03o`000?ngXL;o]j7200?o
]j721?l00002ok6Pa`04o`000?nYW/coZIk<ojVNc0Co00000_nTU/L4oiZCb`05o`000?n@SlkoT8o>
oi2?c_l000001?n4R]43ogN5e004o`000?mYOmKoJGoFofUoePCo00000_l2Fm@00ol0003o04o<o`00
0002o`16a@03o`000?l0@Koo000000?o00009?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo000Yooooo`?o0000
7?ooool00ol0003oooooooooo`0Zooooo`05o`000?n]c?3o[Lc`ojg<l?l000001Onbbnd00ol0003o
]lWXokO9j002okO9j003o`000?njanCo^/OT00Oo00000oo8h^/4olcLi@Coc]OO1?o@d=X00ol0003o
d<[Dom3:e002om3:e005o`000?o@aLood<G?om35col000001?o@_lX01Ol0003ock[6olnja_o?^/Ko
000000Coc[K20_l00003olnia003o`000?o>/l3oc[?000?oc[?000Go0000olf__?o=[kcocJnlo`00
0002olba_`03o`000?o;[K_objfk00;objfk00?o0000olV/_Oo9[;d01?o9[;d00ol0003oaJVmolFY
_@05olFY_@03o`000?o2YKco`ZFl00?o`ZFl00Oo0000oknV`OnoY/7o_jK1o`000?nlX[ko000000;o
]j720ol00005ok6Pa`05o`000?nYW/co0000o`000?n[VL@01OnTU/L00ol0003oVY?;oiZCb`02oiZC
b`CoT8o>1?n4R]43ogN5e003o`000?mgQMCoJGoF00;oJGoF0_mKNML2o`0000;o0U_D00?o0000o`1?
c?l000000_l0A/D00ol0003o046oo`000003o`0002Cooooo00?o0000ooooooooool00oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Xooooo`05o`000?n]c?3o[Lc`ojg<l?l000001Onbbnd0
0ol0003o]lWXokO9j002okO9j005o`000?njanCo^/OTok[7i?l000000onna=l00ol0003o`L;Jol72
fP04o`0000;oc=cU1?o>eml4om3@fP03o`000?o@b]Cod<[D00;od<[D00Go0000om35coo@aLood<G?
o`000004om2obP03o`000?o?^/Kock[600;ock[600Go0000oljf`_o>]/;oc[K2o`000002olfb_P03
o`000?o?^LCockW400Goc[?000?o0000olf__?o=[k`00_o=[k`00ol0003oc;6ool^]^`05ol^]^`03
o`000?o9[;gobJbm00;obJbm1Ol00005olFY_@03o`000?o2YKco`ZFl00Co`ZFl00?o0000oknV`Ol0
00000_nlX[h3o`0000?o]j7200?o0000ok6PaonaX<L00_naX<L2o`0000?oZiW400?o0000ojBFaonT
U/L00onTU/L4oiZCb`05o`000?n@SlkoT8o>oi2?c_l000000on4R]401Ol0003oMhGDogN5e?mgQMCo
000000CoJGoF0omKNML2o`000004o`9Ke?l0003o04o<o`0000;o04K500Ko0000o`11_ol0003o0000
o`12__l0000Rooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool02Oooool002Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`05
o`000?n]c?3o[Lc`ojg<l?l000001Onbbnd00ol0003o]lWXokO9j002okO9j005o`000?njanCo^/OT
ok[7i?l000000onna=l00ol0003o`L;Jol72fP02ol72fP03o`000?o3_]Ko`kkF00Ko00001?o@d=X4
om3:e005o`000?o@aLood<G?om35col000001Oo@_lX01Ol0003ock[6olnja_o?^/Ko000000?oc[K2
00?o0000olfb__o=/[h00_o=/[h00ol0003oc[?0oljc`003oljc`003o`000?o=[kcocJnl00?ocJnl
00?o0000ol^]^oo;[K/01Oo;[K/00ol0003obJbmo`000002o`0000;obJVi00?o0000olJW^Oo6YkT0
0ol000000oo5ZKgo0000ol:U_007ol:U_0Co000000?o_::no`000?ngXL801?ngXL801Ol0003o/J37
ok6Paol0003o/Y_100GoZiW400?o0000ojBFaonTU/L00_nTU/L01Ol0003oVY?;oiZCbonJTl_o0000
00?oT8o>00?o0000ohB:dOn4R]400_n4R]401Ol0003oMhGDogN5e?mgQMCo000000?oJGoF0omKNML2
odece`?o000000Co04o<o`000?l0A/Go00000_l0@Kl2o`000003o`12__l0003ooooo02;ooooo00?o
0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`05
o`000?n]c?3o[Lc`ojg<l?l000001Onbbnd00ol0003o]lWXokO9j002okO9j005o`000?njanCo^/OT
ok[7i?l000000onna=l00ol0003o`L;Jol72fP02ol72fP05o`000?o3_]Ko`kkFol>ne_l000000oo4
^m400ol0003oa[S=o`000002om3@fPCod<[D00?o0000om35coo@aLl00_o@aLl00ol0003od;o:om2o
bP02om2obP05o`000?o?^/Kock[6olnja_l000000oo>]/800ol0003ocK:nolfb_P03olfb_P03o`00
0?o>/l3oc[?000;oc[?000?o0000olf__?o=[k`01?o=[k`00ol0003objfkol^]^`04ol^]^`?o0000
1Oo9ZKT00ol0003oaZNiolJW^@03olJW^@;o00001_o2YK`3o`0000Go_::n00?o0000okNQ`_ngXL80
0_ngXL800ol0003o/J37o`000002ok:K`@03o`000?n[VLCoZiW400;oZiW400?o0000ojBFaonTU/L0
0_nTU/L00ol0003oVY?;oiZCb`02oiZCb`05o`000?n@SlkoT8o>oi2?c_l000000on4R]400ol0003o
MhGDogN5e002ogN5e004o`000?mYOmKoJGoFo`0000?oFgWG1?m=LmL3o`000004o`16aOl0003o046o
o`11_`;o000000?o04:no`000?ooool08_ooool00ol0003oooooooooo`0Nooooo`001_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`03ooooo`?o00008Oooool00ol0003oooooooooo`0Rooooo`05o`000?n]
c?3o[Lc`ojg<l?l000001Onbbnd00ol0003o]lWXokO9j002okO9j005o`000?njanCo^/OTok[7i?l0
00000onna=l00ol0003o`L;Jol72fP02ol72fP05o`000?o3_]Ko`kkFol>ne_l000000oo4^m401?l0
003oa[S=olJhcOo6^<d3o`0000?od<[D1?o@aLl00ol0003od;o:om2obP02om2obP05o`000?o?^/Ko
ck[6olnja_l000001?o>]/800ol0003ocK:nolfb_P02olfb_P03o`000?o<[[co000000;oc[?000?o
0000olf__?o=[k`01?o=[k`2o`0000Gobjfk00?o0000olZY^?l000001_o9ZKT00ol0003oaZNiolJW
^@04olJW^@;o00000oo2YK`2o`000004ol:U_?l0003o`::jo`0000Co_::n00?o0000okNQ`_ngXL80
0_ngXL82o`0000Co/Y_100Go0000oj^Ia?n[VLCoZiW4o`000004ojBFa`03o`000?nJTl_oVY?;00;o
VY?;00Go0000oi2?c_n@SlkoT8o>o`000003ohB:d@03o`000?mgQMCoMhGD00;oMhGD00Co0000ofUo
e_mYOmKoJGoF0omKNML01?l0003oCG?Godeceom=LmL2od1]e`;o000000So04K5o`000?l0@Koo0000
o`0o_Ol0003o04:no`0002?ooooo00?o0000ooooooooool07Oooool000Co00000_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07oooool2o`0000?o[Lc`00?o0000ok;;
kOnbbnd00onbbnd00ol0003o]lWXokO9j002okO9j005o`000?njanCo^/OTok[7i?l000000onna=l0
0ol0003o`L;Jol72fP02ol72fP05o`000?o3_]Ko`kkFol>ne_l000000oo4^m400ol0003oa[S=olJh
c@02olJhc@03o`000?o7]/WoakK900?o00000oo@aLl00ol0003od;o:om2obP02om2obP03o`000?o?
^/Kock[600;ock[600Go0000oljf`_o>]/;oc[K2o`000004olfb_P06o`000?o<[[coc:jlo`000?o>
/l3o00001_o=[k`00ol0003oc:bio`000003ol^]^`;o00000_o:ZKP00ol0003obJViolVY^@03olVY
^@03o`000?o6YkWoaZNi00CoaZNi00?o0000olBT^Oo4Y;T00ol00002ol:U_004o`000?o0X[[o`::j
o`0000Go_::n00Go0000okNQ`_ngXL;o0000okNM_@05ok:K`@03o`000?n[VLCoZiW400;oZiW400?o
0000ojBFaonTU/L00_nTU/L01Ol0003oVY?;oiZCbonJTl_o000000?oT8o>00?o0000ohB:dOn4R]40
0_n4R]401?l0003oMhGDogN5e?mgQM@2o`0000;oJGoF00Co0000oe]ieomKNMOo00001?m=LmL3od1]
e`09o`000?l0A/Go0000o`11_ol0003o03nmo`000?l0@[ko000002;ooooo00?o0000ooooooooool0
7Oooool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo
00?o0000ojg<l?n]c?000_n]c?000ol0003o//_]ok;;k@03ok;;k@03o`000?ngbNSo]lWX00;o]lWX
00Go0000ok[7i?njanCo^/OTo`000004okk4g`05o`000?o1`][o`L;Jol72f_l000001?o3_]H01Ol0
003oa;_AolBkdOo4^m7o000000?oa[S=00?o0000olNfbOo7]/T00_o7]/T00ol0003oak?6o`000002
om35c`God;o:00Go0000olnja_o?^/Kock[6o`000003oljf`P03o`000?o=/[kocK:n00?ocK:n00Go
0000olb^_?o<[[coc:jlo`000006olf__007o`000?o<[;Woc:biolb/^Ol0003objfko`000004olZY
^003o`000?o9ZKWobJVi00?obJVi00?o0000olJW^Oo6YkT01?o6YkT3o`000003olBT^Ol0003o`ZFl
00;o`ZFl00Go0000ol2R^_o0X[[o`::jo`000004okbR_P03o`000?ngXL;o000000;o]ifm00?o0000
ok:K`OnbVl400_nbVl400ol0003oZiW4oj^Ia002oj^Ia003o`000?nTU/OoY9K700;oY9K700?o0000
oiZCbonJTl/00_nJTl/01Ol0003oT8o>oi2?c_n@Slko000000?oQ8[A00?o0000ogN5e?mgQM@00_mg
QM@2o`000003ofUoe_l0003oFgWG00;oFgWG00Co0000odeceom=LmOoCG?G1?m0KML3o`000006o`11
_ol0003o03nmo`000?l0@[ko00008_ooool2o`0001gooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003o[Lc`ojg<l002ojg<l003o`000?nbbngo
//_]00?o//_]00?o0000okO9j?ngbNP00_ngbNP01Ol0003o^/OTok[7i?njanCo000000Co_/CO00?o
0000ol72f_o1`]X00_o1`]X01Ol0003o`kkFol>ne_o3_]Ko000000?oa;_A00?o0000olJhcOo6^<d0
0_o6^<d01Ol0003oakK9olNfbOo7]/Wo000000?oak?60_l00004om2obP05o`000?o?^/Kock[6olnj
a_l000001?o>]/800ol0003ocK:nolfb_P02olfb_P03o`000?o<[[coc:jl00;oc:jl00?o0000olf_
_?o=[k`00oo=[k`00ol0003oc:biolb/^@02olb/^@03o`000?o;[K_obZVh00CobZVh00?o0000olVY
^Oo9ZKT00oo9ZKT01?l0003oaZNiolJW^Oo6YkT3o`0000Goa:Bi00?o0000ol:U_?l000001?o0X[X0
0ol0003o_::nokbR_P03okbR_P03o`000?ngWKgo]ifm00;o]ifm00Go0000ok:K`OnbVl7o/Y_1o`00
0004oj^Ia003o`000?nTU/OoY9K700;oY9K700?o0000oiZCbonJTl/00_nJTl/01Ol0003oT8o>oi2?
c_n@Slko000000?oQ8[A00?o0000ogN5e?mgQM@00_mgQM@01Ol0003oJGoFo`000?mYOmKo000000;o
FgWG00Go0000odeceom=LmOoCG?Go`000003od1]e`;o=6WG0_l000001_l0@Koo0000o`0o_Ol0003o
04:no`00023ooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0002Oooooo00?o
0000ooooooooool06?ooool00ol0003o[Lc`ojg<l002ojg<l003o`000?nbbngo//_]00?o//_]00?o
0000okO9j?ngbNP00_ngbNP01Ol0003o^/OTok[7i?njanCo000000Co_/CO00?o0000ol72f_o1`]X0
0_o1`]X01Ol0003o`kkFol>ne_o3_]Ko000000Coa;_A00Go0000olJhcOo6^<goa[S=o`000004olNf
b@06o`000?o7/lKoak?6olNca_l0003ob;330_l000000oo@_l[o0000olnjaP03olnjaP05o`000?o>
]/;oc[K2oljf`_l000001?o=/[h00ol0003oc:jlolb^_002olb^_003o`000?o<ZkWo000000?ocJnl
00?o0000olb/^Oo<[;T00oo<[;T00ol0003obZVholZY^004olZY^003o`000?o9ZKWobJVi00;obJVi
1Ol00002olJW^@03o`000?o4Y;Woa:Bi00Coa:Bi00?o0000ol2R^_o0X[X00oo0X[X00ol0003o_::n
okbR_P02okbR_P;o00001?ngWKd00ol0003o/Y_1ok:K`@02ok:K`@03o`000?n[VLCoZiW400;oZiW4
00Go0000ojBFaonTU/OoY9K7o`000004oiZCb`05o`000?n@SlkoT8o>oi2?c_l000001?n4R]402Ol0
003oMhGDogN5e?mgQMCo0000ofUoe_l0003oJGoFo`000003oe]ie`05o`000?m=LmOoCG?Godeceol0
00000om0KML3ocAYe`?o000000Co03nmo`000?l0@[ko00008Oooool00ol0003oooooooooo`0Koooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0F
ooooo`03o`000?n]c?3o[Lc`00;o[Lc`00?o0000ok;;kOnbbnd00onbbnd00ol0003o]lWXokO9j002
okO9j005o`000?njanCo^/OTok[7i?l000001?nna=l00ol0003o`L;Jol72fP02ol72fP03o`000?o3
_]Ko`kkF00;o`kkF00Go0000olBkdOo4^m7oa;_Ao`000003olJhc@03o`000?o7]/WoakK900;oakK9
00Go0000olNca_o7/lKoak?6o`000004olR```;o00000oo?^/H01Ol0003oc[K2oljf`_o>]/;o0000
00GocK:n00Go0000olb^_?o<[[coc:jlo`000002olb[^@04o`000?o=[kcocJnlo`0000Goc:bi0_l0
0006olZY^003o`000?o9ZKWo000000Co000000KoajFfo`000?l0003o0000olJW^Ol00006olBT^@03
o`000?o0X[[o`::j00Co`::j00Ko0000okbR__nlX[ko0000okbN^ol00004okNM_@03o`000?nbVl7o
/Y_100;o/Y_100?o0000oj^Ia?n[VL@00_n[VL@00ol0003oY9K7ojBFa`02ojBFa`05o`000?nJTl_o
VY?;oiZCbol000000on@Slh00ol0003oQ8[AohB:d@02ohB:d@03o`000?mgQMCoMhGD00;oMhGD00Co
0000ofUoe_l0003o00000omKNML01Ol0003oCG?Godeceom=LmOo000000?o@6gG00?o0000ocAYeold
JML00_l/I]P2o`000004o`0o_Ol0003o04:no`00027ooooo00?o0000ooooooooool06_ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4
o`0000Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Dooooo`03o`000?n]c?3o
[Lc`00;o[Lc`00?o0000ok;;kOnbbnd00onbbnd00ol0003o]lWXokO9j002okO9j003o`000?njanCo
^/OT00;o^/OT00?o0000okk4gonna=l00_nna=l01Ol0003o`L;Jol72f_o1`][o000000Co`kkF00Go
0000olBkdOo4^m7oa;_Ao`000004olJhc@05o`000?o7]/WoakK9olNfbOl000001?o7/lH00ol0003o
b;33olR```02olR```05o`000?o8[/3o0000olnja_l000000oo>]/800ol0003ocK:nolfb_P03olfb
_P03o`000?o<[[coc:jl00;oc:jl00Ko0000olb[^Oo<ZkWo0000olf__?l00005olb/^@03o`000?o;
Z;Oo000000GobZVh1Ol00002olVV]P03o`000?o7YKKoajFf00;oajFf0_l00005olBT^@03o`000?o3
X[So000000Go`::j00?o0000okbR__l000000onlW[/00ol0003o]ifmokNM_@02okNM_@05o`000?nb
Vl7o/Y_1ok:K`Ol000001?n[VL@00ol0003oY9K7ojBFa`02ojBFa`03o`000?nJTl_oVY?;00;oVY?;
00Go0000oi2?c_n@SlkoT8o>o`000003ohB:d@03o`000?mgQMCoMhGD00;oMhGD00?o0000ofUoe_mY
OmH00_l00002oe]ie`03o`000?m=LmOoCG?G00;oCG?G00Co0000od1]eom0KMOo00000oldJML3obaV
f005o`000?l0?kgo0000o`12__l000008?ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ojg<l?n]c?000on]c?05ok;;
k@03o`000?ngbNSo]lWX00;o]lWX00?o0000ok[7i?njan@00_njan@00ol0003o_/COokk4g`02okk4
g`03o`000?o1`][o`L;J00;o`L;J00Go0000ol>ne_o3_]Ko`kkFo`000004olBkd@05o`000?o6^<go
a[S=olJhcOl000001?o7]/T01Ol0003oak?6olNca_o7/lKo000000Cob;3300Co0000olR^`?o8[/3o
b:k00_l00003oljf`P03o`000?o=/[kocK:n00?ocK:n00Go0000olb^_?o<[[coc:jlo`000004olb[
^@03o`000?o<[;Woc:bi00?oc:bi00Co0000ol^X]oo;Z;Oo00001?o:ZKP3o`0000GobJJf00?o0000
olNU]_o7YKH00_o7YKH00ol0003oaZ>fo`000004olBT^@03o`000?o3X[So000000Ko`::j00?o0000
okbN^onlW[/00_nlW[/00ol0003o]ifmokNM_@02okNM_@03o`000?nbVl7o/Y_100;o/Y_100?o0000
oj^Ia?n[VL@00_n[VL@01Ol0003oY9K7ojBFaonTU/Oo000000CoVY?;00Go0000oi2?c_n@SlkoT8o>
o`000004ohB:d@05o`000?mgQMCoMhGDogN5e?l000000_mYOmH2o`0000?oFgWG00Go0000odeceom=
LmOoCG?Go`000003od1]e`03o`000?ldJMOo=6WG00Co;6KH0ol000000ol0@[ko0000ooooo`0Ooooo
o`03o`000?oooooooooo01Wooooo000Wooooo`;o0000;?ooool00ol0003oooooooooo`0@ooooo`03
o`000?n]c?3o[Lc`00?o[Lc`1Onbbnd00ol0003o]lWXokO9j002okO9j003o`000?njanCo^/OT00;o
^/OT00?o0000okk4gonna=l00_nna=l00ol0003o`L;Jol72fP02ol72fP05o`000?o3_]Ko`kkFol>n
e_l000001?o4^m400ol0003oa[S=olJhc@02olJhc@05o`000?o7]/WoakK9olNfbOl000001?o7/lH0
0ol0003ob;33olR```02olR```09o`000?o8[/3ob:k0olR^`?l0003ob:bmo`000?o>]/;o000000Go
cK:n00?o0000olb^_?o<[[`00_o<[[`00ol0003oc:^iolb[^@02olb[^@03o`000?o<[;Woc:bi00;o
c:bi00?o0000ol^X]oo;Z;L00_o;Z;L4o`0000;obJJf00?o0000olVV]_o9Y[H00oo9Y[H00ol0003o
ajFfolNU]P02olNU]P04o`000?o6XkKoaZ>fo`0000;oa:Bi00Go0000ol>R^?o3X[So`j:ho`000004
ol2R^P;o00001?nlW[/00ol0003o]ifmokNM_@02okNM_@03o`000?nbVl7o/Y_100;o/Y_100?o0000
oj^Ia?n[VL@00_n[VL@01Ol0003oY9K7ojBFaonTU/Oo000000CoVY?;00Go0000oi2?c_n@SlkoT8o>
o`000004ohB:d@03o`000?mgQMCoMhGD00;oMhGD00Co0000ofUoe_mYOmKo00000omKNML01Ol0003o
CG?Godeceom=LmOo000000?o@6gG00Co0000ocAYeoldJMOo=6WG0ol/I]P2obIVf0;o000000?o04:n
o`000?ooool07oooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00kooooo0ol00003ojg<l0Go//_]00?o0000okO9j?ngbNP00_ngbNP00ol0
003o^/OTok[7i002ok[7i003o`000?nna=oo_/CO00;o_/CO00?o0000ol72f_o1`]X00_o1`]X00ol0
003o`kkFol>neP02ol>neP03o`000?o4^m7oa;_A00;oa;_A00Go0000olJhcOo6^<goa[S=o`000004
olNfb@05o`000?o7/lKoak?6olNca_l000001?o8/<<01Ol0003ob:k0olR^`?o8[/3o000000?ob:bm
0_l00004olfb_P03o`000?o<[[coc:jl00;oc:jl00?o0000olb[^Oo<ZkT00_o<ZkT00ol0003objVg
o`000002olb/^@04o`000?o;Z;OobjRgol^X]`Co00001?o9Y[H00ol0003obJJfolVV]P02olVV]P03
o`000?o7YKKoajFf00;oajFf00?o0000olJS]_o6XkH00_o6XkH00ol0003oa:Bio`000004ol>R^006
o`000?o0X[[o`::jo`000?noWkSo00001OnlW[/01Ol0003o]ifmokNM_OngWKgo000000Co/Y_100?o
0000oj^Ia?n[VL@00_n[VL@00ol0003oY9K7ojBFa`02ojBFa`03o`000?nJTl_oVY?;00;oVY?;00Go
0000oi2?c_n@SlkoT8o>o`000003ohB:d@03o`000?mgQMCoMhGD00;oMhGD00Go0000ofUoe_mYOmKo
JGoFo`000002oe]ie`03o`000?m=LmOoCG?G00;oCG?G00Go0000od1]eom0KMOo@6gGo`000002ocAY
e`04o`000?l/I]So;6KHobaVf0?o9VKH00?o0000o`12__l000007_ooool2o`0001[ooooo000Woooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003oVZoVoiZ_iP05o`00
00?o//_]1?ngbNP00ol0003o^/OTok[7i002ok[7i003o`000?nna=oo_/CO00;o_/CO00?o0000ol72
f_o1`]X00_o1`]X00ol0003o`kkFol>neP02ol>neP03o`000?o4^m7oa;_A00;oa;_A00Go0000olJh
cOo6^<goa[S=o`000004olNfb@03o`000?o7/lKoak?600;oak?600Go0000olR``oo8/<?ob;33o`00
0004olR^`007o`000?o8[;gob:bmolR/_Ol0003ob:Zko`000003olfb_P05o`000?o<[[coc:jlolb^
_?l000001?o<ZkT01ol0003objVgol^Y]ol0003oc:bio`000?o;Z;L00ol00002ol^X]`03o`000?o9
Y[KobJJf00?obJJf00?o0000olVV]_o9Y[H00_o9Y[H00ol0003oajFfolNU]P02olNU]P03o`000?o6
XkKoaZ>f00?oaZ>f00?o0000ol>R^?o3X[P00oo3X[P00ol0003o`::jo`000003oknO^003o`000?nl
W[_o_9jk00;o_9jk00?o0000okNM_OngWKd00_ngWKd01Ol0003o/Y_1ok:K`OnbVl7o000000GoZiW4
00?o0000ojBFaol000003_l000000on4R]7o0000ogN5e002ogN5e004o`000?mYOmKoJGoFofUoeP;o
00000_mKNML01Ol0003oCG?Godeceom=LmOo000000?o@6gG00Co0000ocAYeoldJMOo00000ol/I]P0
1?l0003o9VKHobIVf?lVI]P3o`0001oooooo00?o0000ooooooooool05oooool002Oooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03o`000?nJ[nKoVZoV00;oVZoV00Co0000
oij]h_nN[N;oWZgR1?l00003okO9j0Co^/OT00?o0000okk4gonna=l00onna=l01Ol0003o`L;Jol72
f_o1`][o000000Co`kkF00?o0000olBkdOo4^m400_o4^m400ol0003oa[S=olJhc@02olJhc@05o`00
0?o7]/WoakK9olNfbOl000001?o7/lH00ol0003ob;33olR```02olR```05o`000?o8[/3ob:k0olR^
`?l000000oo8[;d01ol0003ob:ZkolRZ^oo8Z[_o0000olfb__l000001?o<[[`00ol0003oc:^iolb[
^@02olb[^@04o`000?o;ZKOobjVgol^Y]`?o00001Oo;Z;L00ol0003obJJfolVV]P03olVV]P03o`00
0?o9Y[KobJJf00;obJJf00?o0000olNU]_o7YKH00_o7YKH00ol0003oaZ>folJS]P03olJS]P03o`00
0?o3X[So`j:h00Co`j:h00?o0000oknO^?noWkP00_noWkP00ol0003o_9jkokbN^`02okbN^`03o`00
0?ngWKgo]ifm00;o]ifm00?o0000ok:K`OnbVl400_nbVl400ol0003oZiW4oj^Ia004o`0000;o[9O1
1OnVU<<4oinAa@CoVHo81Ol000001?mgQMCo0000ofUoe_mYOmH2o`0000;oFgWG00Go0000odeceom=
LmOoCG?Go`000003od1]e`05o`000?ldJMOo=6WGocAYeol000000_l/I]P01?l0003o9VKHobIVf?lV
I]P2ob=WfP;o00007oooool00ol0003oooooooooo`0Fooooo`009oooool2o`00033ooooo00?o0000
ooooooooool02_ooool01Ol0003oVZoVoiZ_i_nJ[nKo000000GoWZgR00?o0000oj:/g_nR[=h01?l0
0003ok[7i0Go_/CO00?o0000ol72f_o1`]X00_o1`]X00ol0003o`kkFol>neP02ol>neP03o`000?o4
^m7oa;_A00;oa;_A00Go0000olJhcOo6^<goa[S=o`000004olNfb@03o`000?o7/lKoak?600;oak?6
00Go0000olR``oo8/<?ob;33o`000004olR^`005o`000?o8[;gob:bmolR/_Ol000001?o8Z[/00ol0
003oc:jlolb^_002olb^_003o`000?o<ZkWoc:^i00;oc:^i00?o0000ol^Y]ol000000ol00006ol^X
]`;o00001Oo9Y[H00ol0003obJJfolVV]P05o`000003olNU]_l0003oaZ>f00CoaZ>f00?o0000olFR
]Ol000001Oo3X[P00ol0003o_inhoknO^002oknO^003o`000?nlW[_o_9jk00?o_9jk00Go0000okNM
_OngWKgo]ifmo`000003ok:K`@Co00000_naVKh01?l0003o[9O1ojbG`On/Ul45ojJD``CoWi751OnI
SlP4oi6<bPCo000000?oJGoFo`000?l000000_mKNML01Ol0003oCG?Godeceom=LmOo000000?o@6gG
00Co0000ocAYeoldJMOo00000ol/I]P01?l0003o9VKHobIVf?lVI]P3ob=WfP03o`000?oooooooooo
01cooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`08ooooo`03o`000?nJ[nKoVZoV00;oVZoV00?o0000oij]h_nN[N800_nN[N800ol0003o
XZcNoj:/gP02oj:/gP03o`000?nVZ][oYZ[J00Go00000_nna=l00ol0003o`L;Jol72fP02ol72fP03
o`000?o3_]Ko`kkF00;o`kkF00?o0000olBkdOo4^m400_o4^m400ol0003oa[S=olJhc@02olJhc@05
o`000?o7]/WoakK9olNfbOl000001?o7/lH00ol0003ob;33olR```02olR```03o`000?o8[/3ob:k0
00;ob:k000Go0000olR/_Oo8[;gob:bmo`000004olRZ^`;o00000oo<[[`01?l0003oc:^iolb[^Oo<
ZkT3o`0000;objVg00?o0000olZW]Ol000001?o;Z;L00ol0003obZJeo`000004olVV]PCo00000_o8
Y;@00ol0003ob:BdolRT]003o`0000CoaZ>f00?o0000olFR]Ol000001?o3X[P2o`0000Go_inh00?o
0000okbN^onlW[/00_nlW[/00ol0003o]ifmokNM_@02okNM_@?o000000?o]Y^lo`000?naVKh00ona
VKh01Ol0003o[9O1ojbG`On/Ul7o000000CoYYC300Go0000oinAaOnOTLGoWi75o`000004oiV?b0Go
THc:0on9RL`4o`000003oe]ieol0003oCG?G00;oCG?G00Go0000od1]eom0KMOo@6gGo`000003ocAY
e`04o`000?l/I]So;6KHo`0000?o9VKH00Go0000ob=Wf_lSIm[o8fOJo`00000Nooooo`03o`000?oo
oooooooo01Gooooo000Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0
1Ol0003oVZoVoiZ_i_nJ[nKo000000GoWZgR00Go0000oj:/g_nR[=koXZcNo`000004ojJZfP04o`00
0?nZZMKoZZWFojZYePCo00000_o1`]X00ol0003o`kkFol>neP02ol>neP03o`000?o4^m7oa;_A00?o
a;_A00Go0000olJhcOo6^<goa[S=o`000004olNfb@05o`000?o7/lKoak?6olNca_l000001?o8/<<0
0ol0003ob:k0olR^`002olR^`005o`000?o8[;gob:bmolR/_Ol000001?o8Z[/01_l0003ob:RiolRX
^Ol0003oc:jlo`0000;oc:^i0ol00003ol^Y]`04o`000?o:YkGobZNeo`0000?objRg00Go0000olZV
]Oo:Y[GobZJeo`000002olVV]P03o`000?o9YKCo000000Cob:Bd00Oo0000olRT]?o8Y;Cob:Bdo`00
0?o7XkCo000000;oaZ>f00Go0000olFR]Oo5X[GoaJ:eo`000002ol>R^004o`000?o2X;Ko`Z2fo`00
00Co_inh00?o0000okbN^onlW[/00_nlW[/01?l0003o]ifmokNM_OngWKd2o`0000?o]Y^l00?o0000
ok6I__naVKh00_naVKh01Ol0003o[9O1ojbG`On/Ul7o000000CoYYC300Go0000oinAaOnOTLGoWi75
o`000004oiV?b003o`000?nAS<[oTHc:00;oTHc:1?n9RL`2oh:6cP?o00001?m=LmL01?l0003o@6gG
od1]eol00003ocAYe`05o`000?l/I]So;6KHobaVf?l000000_lVI]P01Ol0003o8fOJob=Wf_lSIm[o
000001kooooo0_l0000Fooooo`009_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Gooooo00?o0000oiZ_i_nJ[nH00_nJ[nH00ol0003oWZgRoij]hP02oij]hP03o`000?nR[=koXZcN
00;oXZcN00Go0000ojJZf_nVZ][oYZ[Jo`000005ojZYeP03o`000?n]Z=;o[JSB00?o00001?o3_]H0
0ol0003oa;_AolBkd@02olBkd@03o`000?o6^<goa[S=00;oa[S=00Go0000olNfbOo7]/WoakK9o`00
0004olNcaP03o`000?o8/<?ob;3300;ob;3300?o0000olR^`?o8[/000_o8[/001Ol0003ob:bmolR/
_Oo8[;go000000Cob:Zk00Co0000olRX^Oo8Z;Wob:Ri1?l000000oo<ZkWo0000ol^Y]`03ol^Y]`05
o`000?o:YkGobZNeolZW]Ol000000_o;Z;L01ol0003obZJeolZV]Oo:Y[Go0000olVV]_l000000_o9
YK@01Ol0003ob:BdolRT]?o8Y;Co000000Cob:Bd00Ko0000olNS]?o7XkCo0000olJS]_l00003olFR
]@03o`000?o3X[So000000?o`Z2f00?o0000oknO^?noWkP00_noWkP00ol0003o_9jkokbN^`03okbN
^`?o000000?o^Ybjo`000?nfVk`00_nfVk`00ol0003o/IVnok6I_P02ok6I_P03o`000?n/Ul7o[9O1
00;o[9O11?nVU<<01Ol0003oWi75oinAaOnOTLGo000000CoVHo800?o0000oi6<b_nAS<X00_nAS<X0
1?l0003oRHW<ohV9c?n9RL`3oh:6cP04o`000?n2Q/ko0000o`0000;oCG?G00Go0000od1]eom0KMOo
@6gGo`000003ocAYe`04o`000?l/I]So;6KHo`0000?o9VKH00Go0000ob=Wf_lSIm[o8fOJo`00000N
ooooo`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?ooool00ol0003oooooooooo`04oooo
o`05o`000?nJ[nKoVZoVoiZ_i_l000001OnN[N801Ol0003oXZcNoj:/g_nR[=ko000000CoYZ[J00?o
0000ojZYe_nZZMH00_nZZMH00ol0003o[JSBojfXdP02ojfXdP06o`000?naYlko0000o`000?o3_]Ko
00001?o4^m400ol0003oa[S=olJhc@02olJhc@03o`000?o7]/WoakK900;oakK900Go0000olNca_o7
/lKoak?6o`000004olR```03o`000?o8[/3ob:k000;ob:k000Go0000olR/_Oo8[;gob:bmo`000004
olRZ^`03o`000?o8Z;Wob:Ri00Co00000oo<ZkT01Ol0003objVgol^Y]oo;ZKOo000000CobZNe00?o
0000ol^X]ol000001?o:Y[D2o`0000?obJFd00Go0000olRT]?o8Y;Cob:Bdo`000003olRT]003o`00
0?o7XkCoaj>d00;oaj>d00?o0000olFR]Oo5X[D00oo5X[D00ol0003o`Z2fol:P]P02ol:P]P03o`00
0?noWkSo_inh00;o_inh00?o0000okbN^onlW[/00_nlW[/2o`0000?o^Ybj00Go0000okJK_?nfVkco
]Y^lo`000004ok6I_P03o`000?n/Ul7o[9O100;o[9O100Go0000ojJD`onVU<?oYYC3o`000004oinA
a@05o`000?nISlSoVHo8oiV?b?l000001?nAS<X01Ol0003oRHW<ohV9c?n9RLco000000?oPXK>00?o
0000ogZ3dOmjPm400ol00003od1]e`05o`000?ldJMOo=6WGocAYeol000000_l/I]P01Ol0003o9VKH
obIVf?lVI]So000000?o8fOJ00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`00
9_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000oiZ_i_nJ[nH0
0_nJ[nH00ol0003oWZgRoij]hP02oij]hP03o`000?nR[=koXZcN00;oXZcN00?o0000ojJZf_nVZ]X0
0_nVZ]X00ol0003oZZWFojZYeP02ojZYeP05o`000?n]Z=;o[JSBojfXd_l000001?naYlh4o`0000;o
a;_A00Go0000olJhcOo6^<goa[S=o`000004olNfb@03o`000?o7/lKoak?600;oak?600?o0000olR`
`oo8/<<00_o8/<<00ol0003ob:k0olR^`002olR^`005o`000?o8[;gob:bmolR/_Ol000001?o8Z[/3
o`000007olRX^Ol0003ob:NgolRW]ol0003oc:^io`000004ol^Y]`03o`000?o:YkGobZNe00?obZNe
00?o0000olZV]Oo:Y[D00oo:Y[D00ol0003obJFdolVU]002olVU]005o`000?o8Y;Cob:BdolRT]?l0
00000oo8Y;@00ol0003oaj>dolNS]002olNS]003o`000?o5X[GoaJ:e00?oaJ:e00?o0000ol:P]_o2
X;H00oo2X;H00ol0003o_inhoknO^002oknO^0Co000000?o_Ijho`000?njW;X00_njW;X00ol0003o
]Y^lokJK_002okJK_005o`000?naVKko/IVnok6I__l000001?n/Ul401Ol0003oYYC3ojJD`onVU<?o
000000CoWi7500Go0000oiV?b?nISlSoVHo8o`000004oi6<bP05o`000?n9RLcoRHW<ohV9c?l00000
1?n2Q/h00ol0003oNX?AogZ3d@02ogZ3d@;o00000_m0KML01Ol0003o=6WGocAYeoldJMOo000000;o
;6KH00Go0000obIVf?lVI]So9VKHo`000002ob=WfP03o`000?oooooooooo01kooooo00?o0000oooo
ooooool04_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo
03Kooooo00Co0000oooooooooooo00001?nJ[nH00ol0003oWZgRoij]hP03oij]hP05o`000?nR[=ko
XZcNoj:/g_l000001?nVZ]X00ol0003oZZWFojZYeP02ojZYeP03o`000?n]Z=;o[JSB00;o[JSB00?o
0000ok6Wc_naYlh00_naYlh01?l0003o]:K;okBVbondY//4o`0000;oa[S=00Go0000olNfbOo7]/Wo
akK9o`000004olNcaP03o`000?o8/<?ob;3300;ob;3300?o0000olR^`?o8[/000_o8[/001Ol0003o
b:bmolR/_Oo8[;go000000;ob:Zk1?l00003olRX^@05o`000?o8YkOob:NgolRW]ol000001?o;ZKL0
0ol0003obZNeolZW]@04olZW]@03o`000?o:Y[GobZJe00?obZJe00?o0000olVU]?o9YK@00_o9YK@0
1Ol0003ob:BdolRT]?o8Y;Co000000?ob:Bd00Oo0000olNS]?o7XkCoaj>do`000?o6X[Co000000?o
aJ:e00?o0000olBQ]?l000001?o2X;H01?l0003o_inhoknO^?noWkP2o`0000Co_Ijh00Go0000okZL
^_njW;[o^Ybjo`000004okJK_005o`000?naVKko/IVnok6I__l000001?n/Ul401Ol0003oYYC3ojJD
`onVU<?o000000CoWi7500Go0000oiV?b?nISlSoVHo8o`000004oi6<bP05o`000?n9RLcoRHW<ohV9
c?l000001?n2Q/h2o`0000?oNX?A0_mcPM<3o`0000?o=6WG00Co0000obaVf?l/I]So00000olVI]P0
1Ol0003o8fOJob=Wf_lSIm[o000001oooooo00?o0000ooooooooool04_ooool001_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo0ol00004oiZ_iP03o`000?nN
[N;oWZgR00;oWZgR00?o0000oj:/g_nR[=h00_nR[=h00ol0003oYZ[JojJZfP02ojJZfP03o`000?nZ
ZMKoZZWF00;oZZWF00?o0000ojfXd_n]Z=800_n]Z=801Ol0003o/JO>ok6Wc_naYlko000000Go]:K;
00?o0000okNUaongYLL01?l00002olNfb@03o`000?o7/lKoak?600;oak?600Go0000olR``oo8/<?o
b;33o`000005olR^`004o`000?o8[;gob:bmolR/_@?o00000_o8Z[/00ol0003ob:RiolRX^@02olRX
^@04o`000?o8YkOob:NgolRW]`;o00000_o;ZKL00ol0003obZNeolZW]@04olZW]@03o`000?o9YKCo
000000?obZJe0_l00004olVU]004o`000?o8Y;Cob:Bdo`0000Cob:Bd00Go0000olNS]?o7XkCoaj>d
o`000002olJR]003o`000?o5X[Go000000;oa:6d00?o0000ol:P]_o2X;H00_o2X;H01_l0003o_inh
oknO^?l0003o`Info`0000Co_Ijh00Go0000okZL^_njW;[o^Ybjo`000004okJK_005o`000?naVKko
/IVnok6I__l000001?n/Ul401Ol0003oYYC3ojJD`onVU<?o000000CoWi7500Go0000oiV?b?nISlSo
VHo8o`000004oi6<bP05o`000?n9RLcoRHW<ohV9c?l000001?n2Q/h2o`0000?oNX?A1?mcPM<01Ol0
003o=6WGocAYeoldJMOo000000;o;6KH00?o0000obIVf?lVI]P00_lVI]P01?l0003o8fOJob=Wf_l0
000Pooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`006oooool0
1Ol@413ooooooooooooooooo410@00Gooooo0ol0000iooooo`03o`000?nJ[nKoVZoV00;oVZoV00?o
0000oij]h_nN[N800onN[N801Ol0003oXZcNoj:/g_nR[=ko000000CoYZ[J00?o0000ojZYe_nZZMH0
0onZZMH01Ol0003o[JSBojfXd_n]Z=;o000000Co/JO>00?o0000okBVbondY//00_ndY//00ol0003o
]jG7okNUa`02okNUa`03o`000?niYLGo^JG500?o00000oo7/lH00ol0003ob;33olR```02olR```03
o`000?o8[/3ob:k000;ob:k000?o0000olR/_Ol000000ol00004olRZ^`05o`000?o8Z;Wob:RiolRX
^Ol000000oo8YkL01_l0003ob:FfolRU]_l0003objVgo`0000GobZNe00Co0000olVU]?o9YKCo0000
0_o:Y[D00ol0003obJBco`000004olVU]003o`000?o8Y;Co000000?o000000?ob:Bdo`000?o7Xk@0
0_o7Xk@01ol0003oaZ:dolJR]?o6X[Co0000olFR]Ol000000_o4XK@00ol0003o`Z2fol:P]P03ol:P
]P;o00000_o1WkH00ol0003o_IjhokfN^002okfN^005o`000?njW;[o^YbjokZL^_l000001?nfVk`0
0ol0003o/IVnok6I_P02ok6I_P05o`000?n/Ul7o[9O1ojbG`Ol000001?nVU<<01Ol0003oWi75oinA
aOnOTLGo000000?oVHo800?o0000oi6<b_nAS<X00_nAS<X01Ol0003oRHW<ohV9c?n9RLco000000Co
PXK>00?o0000ogZ3dOl000000_mjPm400ol0003oLh7Cog>1d`02og>1d`;o00000_ldJML01?l0003o
;6KHobaVf?l00003obIVf005o`000?lSIm[o8fOJob=Wf_l000007_ooool3o`0000[ooooo00?o0000
ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000oiZ_i_nJ[nH00_nJ[nH00ol0003oWZgRoij]hP02oij]hP03o`000?nR[=ko
XZcN00;oXZcN00?o0000ojJZf_nVZ]X00_nVZ]X00ol0003oZZWFojZYeP02ojZYeP03o`000?n]Z=;o
[JSB00;o[JSB00?o0000ok6Wc_naYlh00_naYlh00ol0003o]:K;okBVb`02okBVb`05o`000?ngYLOo
]jG7okNUaol000001?niYLD01_l0003o^jC2o`000?l0003oak?6o`0000?ob;3300?o0000olR^`?o8
[/000_o8[/03o`0000;ob:bm00?o0000olRZ^oo8Z[/00_o8Z[/00ol0003ob:RiolRX^@02olRX^@05
o`000?o8YkOob:NgolRW]ol000000oo8YKH00ol0003obZNeolZW]@04olZW]@06o`000?o9YKCobJFd
o`000?o:Y[Go00000oo9Y;<00ol0003obJFdolVU]003o`000004olRS/_l0003ob:>bolRS/P;o0000
0_o7Xk@00ol0003oaZ:dolJR]003olJR]003o`000?o4XKCoa:6d00;oa:6d00?o0000ol:P]_o2X;H0
0_o2X;H01Ol0003o`Infol6O]_o1WkKo000000Co_Ijh00Go0000okZL^_njW;[o^Ybjo`000004okJK
_003o`000?naVKko/IVn00;o/IVn00Go0000ojbG`On/Ul7o[9O1o`000004ojJD``05o`000?nOTLGo
Wi75oinAaOl000001?nISlP01Ol0003oTHc:oi6<b_nAS<[o000000?oRHW<00?o0000oh:6c_n2Q/h0
0_n2Q/h01_l0003oNX?AogZ3dOl0003oNX?Ao`0000CoLh7C0_m/OmD3o`0000;o;6KH00Go0000obIV
f?lVI]So9VKHo`000003ob=WfP03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`006oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0>?ooool00ol0003oVZoVoiZ_iP02oiZ_iP03o`000?nN[N;oWZgR00?oWZgR00Go0000
oj:/g_nR[=koXZcNo`000005ojJZfP03o`000?nZZMKoZZWF00;oZZWF00?o0000ojfXd_n]Z=800_n]
Z=801Ol0003o/JO>ok6Wc_naYlko000000Go]:K;00Go0000okNUaongYLOo]jG7o`000003okVUa@03
o`000?nkY<;o^jC200;o^jC20ol00002olR```03o`000?o8[/3o000000;o000000?ob:k0o`000?o8
[;d00_o8[;d00ol0003ob:ZkolRZ^`02olRZ^`05o`000?o8Z;Wob:RiolRX^Ol000001?o8YkL01?l0
003ob:FfolRU]_o8YKH2o`0000CobZNe00?o0000olVU]?o9YK@00_o9YK@00ol0003obJBcolVT/`02
olVT/`?o000000GobJ>bo`000?o8Xk;ob:>bo`000003olRS/P;o000000?oaj>do`000?o6X[@01?o6
X[@00ol0003oa:6dolBQ]002olBQ]004o`000?o2X;Ko`Z2fol:P]P;o00000oo1WkH00ol0003o_Ijh
okfN^002okfN^003o`000?njW;[o^Ybj00;o^Ybj00Go0000okJK_?nfVkco]Y^lo`000004ok6I_P05
o`000?n/Ul7o[9O1ojbG`Ol000001?nVU<<01Ol0003oWi75oinAaOnOTLGo000000CoVHo800Go0000
oi6<b_nAS<[oTHc:o`000003ohV9c003o`000?n2Q/koPXK>00;oPXK>00Co0000ogZ3dOmjPm7oNX?A
0_l00004og>1d`GoK7oE0_l000000ol/I]So0000obIVf002obIVf005o`000?lSIm[o8fOJob=Wf_l0
00008?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0hooooo`03o`000?nJ[nKoVZoV00;o
VZoV00?o0000oij]h_nN[N800_nN[N800ol0003oXZcNoj:/gP02oj:/gP03o`000?nVZ][oYZ[J00;o
YZ[J00?o0000ojZYe_nZZMH00_nZZMH00ol0003o[JSBojfXdP02ojfXdP03o`000?naYlko/JO>00;o
/JO>00?o0000okBVbondY//00_ndY//00ol0003o]jG7okNUa`02okNUa`05o`000?niYLGo^JG5okVU
aOl000001?nkY<800ol0003o_JBookfT_`04o`0000?ob:k000Go0000olR/_Oo8[;gob:bmo`000004
olRZ^`03o`000?o8Z;Wob:Ri00;ob:Ri00Go0000olRW]oo8YkOob:Ngo`000003olRU]P04o`000?o8
Y;Cob:Bdo`0000?obZNe00?o0000olVU]?o9YK@00_o9YK@00ol0003obJBcolVT/`02olVT/`05o`00
0?o9Xk;obJ>bolVS/_l000000_o8Xk801?l0003ob:>bolRS/_o8Xk82olRR/P03o`000?o6X[CoaZ:d
00?oaZ:d0_l00004olBQ]006o`000?o2X;Ko`Z2fo`000?o3X;Go00000oo1WkH00ol0003o_IjhokfN
^002okfN^003o`000?njW;[o^Ybj00;o^Ybj00Go0000okJK_?nfVkco]Y^lo`000004ok6I_P05o`00
0?n/Ul7o[9O1ojbG`Ol000001?nVU<<01Ol0003oWi75oinAaOnOTLGo000000CoVHo800?o0000oi6<
b_nAS<X00_nAS<X01?l0003oRHW<ohV9c?l00004oh:6cP04o`000?mjPm7oNX?AogZ3d@;o00001?mc
PM<00ol0003oK7oEofaoe@02ofaoe@;oIWoG0_l00003obIVf005o`000?lSIm[o8fOJob=Wf_l00000
8?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`0003Sooooo00?o0000oiZ_i_nJ[nH00_nJ[nH00ol0003oWZgR
oij]hP03oij]hP03o`000?nR[=koXZcN00;oXZcN00?o0000ojJZf_nVZ]X00_nVZ]X00ol0003oZZWF
ojZYeP02ojZYeP03o`000?n]Z=;o[JSB00;o[JSB00?o0000ok6Wc_naYlh00_naYlh00ol0003o]:K;
okBVb`02okBVb`05o`000?ngYLOo]jG7okNUaol000001?niYLD00ol0003o^jC2ok^T`P02ok^T`PGo
000000Ko_jBmo`000?l0003o0000olR^`?l00003olR/_@03o`000?o8Z[_ob:Zk00;ob:Zk00?o0000
olRX^Oo8Z;T00_o8Z;T01Ol0003ob:NgolRW]oo8YkOo000000?ob:Ff00Oo0000olRT]?o8Y;Cob:Bd
o`000?o:YkGo000000CobJFd00?o0000olVT/ol000000oo9Y;<01Ol0003obJ>bolVS/_o9Xk;o0000
00;ob:>b00Co0000olRS/_o8Xk;o00000_o8X[800ol0003oaZ:dolJR]002olJR]003o`000?o6XK?o
000000Goa:6d0_l00002ol>P]@05o`000?o1WkKo`Infol6O]_l000001OnmW[P01Ol0003o^YbjokZL
^_njW;[o000000?o]Y^l00?o0000ok6I__naVKh00_naVKh00ol0003o[9O1ojbG`@02ojbG`@05o`00
0?nVU<?oYYC3ojJD`ol000000onOTLD00ol0003oVHo8oiV?b002oiV?b003o`000?nAS<[oTHc:00;o
THc:00Go0000ohV9c?n9RLcoRHW<o`000003oh:6cP03o`000?mjPm7oNX?A00;oNX?A00?o0000og>1
domcPM<00_mcPM<00ol0003oK7oEofaoe@02ofaoe@?oIWoG00?o0000obIVf?lVI]P00_lVI]P01?l0
003o8fOJob=Wf_l0000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
01_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo00?o0000
oiZ_i_nJ[nH00_nJ[nH00ol0003oWZgRoij]hP02oij]hP03o`000?nR[=koXZcN00;oXZcN00?o0000
ojJZf_nVZ]X00_nVZ]X00ol0003oZZWFojZYeP02ojZYeP03o`000?n]Z=;o[JSB00;o[JSB00?o0000
ok6Wc_naYlh00_naYlh00ol0003o]:K;okBVb`03okBVb`05o`000?ngYLOo]jG7okNUaol000000oni
YLD01?l0003o^jC2ok^T`_nkY<83o`0000?o_JBo00?o0000oknT_OnoY;d00_noY;d3o`0000;ob:bm
00?o0000olRZ^oo8Z[/00_o8Z[/01Ol0003ob:RiolRX^Oo8Z;Wo000000?ob:Ng00?o0000olRU]_o8
YKH00_o8YKH00ol0003ob:BdolRT]002olRT]003o`000?o9YKCobJFd00?obJFd00?o0000olVT/ol0
00000_o9Y;<2o`0000?obJ>b00?o0000olRS/_l000000oo8Xk801Ol0003ob::bolRR/_o7X[;o0000
00?oaZ:d00Co0000olJQ/oo6XK?o00000oo4XK@2o`0000?o`j2e00?o0000ol6O]_o1WkH00_o1WkH0
0ol0003o_IjhokfN^002okfN^005o`000?njW;[o^YbjokZL^_l000001?nfVk`01Ol0003o/IVnok6I
__naVKko000000Co[9O100Go0000ojJD`onVU<?oYYC3o`000004oinAa@05o`000?nISlSoVHo8oiV?
b?l000001?nAS<X01Ol0003oRHW<ohV9c?n9RLco000000?oPXK>00?o0000ogZ3dOmjPm400_mjPm42
o`0000?oLh7C00?o0000ofaoeOm/OmD00_m/OmD01?l0003oIWoGofIoeomVOmL2o`0000;o9VKH00Go
0000ob=Wf_lSIm[o8fOJo`00000Pooooo`;o00001oooool00ol0003oooooooooo`05ooooo`009?oo
ool00ol0003oooooooooo`0gooooo`;o00000onJ[nH00ol0003oWZgRoij]hP03oij]hP03o`000?nR
[=koXZcN00;oXZcN00?o0000ojJZf_nVZ]X00_nVZ]X00ol0003oZZWFojZYeP02ojZYeP03o`000?n]
Z=;o[JSB00;o[JSB00?o0000ok6Wc_naYlh00_naYlh00ol0003o]:K;okBVb`02okBVb`03o`000?ng
YLOo]jG700;o]jG700Co0000okVUaOniYLGo^JG51?l000000onkY<;o0000okfT_`02okfT_`03o`00
0?noY;go_jBm00?o_jBm00?o0000ol6S^oo1Xk/00ol00003olRZ^`03o`000?o8Z;Wob:Ri00;ob:Ri
00Go0000olRW]oo8YkOob:Ngo`000003olRU]P03o`000?o8Y;Cob:Bd00?ob:Bd00?o0000olVU]?o9
YK@00_o9YK@02?l0003obJBcolVT/ol0003obJBco`000?o9Xk;o00000oo9Xk800ol0003ob:>bo`00
0002olRS/P04o`000?o8X[;ob::bo`0000;oaj:b00?o0000olJR]?l000000oo6XK<01_l0003oa:6d
o`000?l0003oaJ6do`0000?o`j2e00?o0000ol6O]_o1WkH00_o1WkH00ol0003o_IjhokfN^002okfN
^005o`000?njW;[o^YbjokZL^_l000001?nfVk`01Ol0003o/IVnok6I__naVKko000000Co[9O100Go
0000ojJD`onVU<?oYYC3o`000004oinAa@05o`000?nISlSoVHo8oiV?b?l000001?nAS<X01Ol0003o
RHW<ohV9c?n9RLco000000CoPXK>00Oo0000ogZ3dOmjPm7oNX?Ao`000?mcPM?o000000;oLh7C00?o
0000ofaoeOm/OmD00_m/OmD01?l0003oIWoGofIoeomVOmL2of9of@?o00000olSImX00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool002Cooooo00?o
0000ooooooooool0=oooool2ogJChP;o000000?oVZoVo`000?nN[N800onN[N800ol0003oXZcNoj:/
gP02oj:/gP03o`000?nVZ][oYZ[J00?oYZ[J00Go0000ojZYe_nZZMKoZZWFo`000005ojfXdP03o`00
0?naYlko/JO>00;o/JO>00?o0000okBVbondY//00_ndY//01Ol0003o]jG7okNUaongYLOo000000?o
^JG50_l00004ok^T`P05o`000?nmY;oo_JBookfT_ol000001OnoY;d01_l0003o`J>kol6S^oo1Xk_o
0000ol:S^@;o000000?ob:Zko`000?o8Z;T00_o8Z;T00ol0003ob:NgolRW]`02olRW]`05o`000?o8
YKKob:FfolRU]_l000001?o8Y;@00ol0003ob:Bco`000002olVU]003o`000?o9Y;?obJBc00;obJBc
0_l000000oo9Xk;o0000olVS/P02olVS/P03o`000?o8Xk;o000000;ob:>b00?o0000olRR/_l00000
1?o7X[800ol0003oaZ6colJQ/`02olJQ/`;o00000oo5XK@01Ol0003o`j2eol>P]Oo3X;Go000000Co
`Inf00?o0000okfN^?nmW[P00_nmW[P01Ol0003o^YbjokZL^_njW;[o000000Co]Y^l00Go0000ok6I
__naVKko/IVno`000004ojbG`@05o`000?nVU<?oYYC3ojJD`ol000001?nOTLD01Ol0003oVHo8oiV?
b?nISlSo000000CoTHc:00Go0000ohV9c?n9RLcoRHW<o`000004oh:6cP07o`000?mjPm7oNX?AogZ3
dOl0003oLh7Co`000002og>1d`03o`000?m/OmGoK7oE00;oK7oE00Co0000ofIoeomVOmOoIWoG1OmR
OmT2o`0000;o8fOJ00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`009?ooool2
o`0003Sooooo1?mfTn84o`0000;oWZgR00?o0000oj:/g_nR[=h00_nR[=h00ol0003oYZ[JojJZfP02
ojJZfP03o`000?nZZMKoZZWF00;oZZWF00?o0000ojfXd_n]Z=800_n]Z=800ol0003o/JO>ok6WcP02
ok6WcP03o`000?ndY/_o]:K;00;o]:K;00?o0000okNUaongYLL00_ngYLL5o`0000Co^jC200?o0000
okfT_onmY;l00_nmY;l00ol0003o_jBmoknT_@02oknT_@03o`000?o1Xk_o`J>k00;o`J>k00Co0000
ol:S^Oo2XkWo`Z>i0_l00003olRX^@05o`000?o8YkOob:NgolRW]ol000001?o8YKH00ol0003ob:Bd
olRT]002olRT]006o`000?o8Y;?ob:Bco`000?o9YKCo00001?o9Y;<01Ol0003obJ>bolVS/_o9Xk;o
000000;obJ>b1?l000001?o8Xk;o0000olRR/_l00004olNR/P03o`000?o6XK?oaZ6c00;oaZ6c00?o
0000olFQ]?o5XK@00_o5XK@00ol0003o`j2eol>P]@02ol>P]@05o`000?o1WkKo`Infol6O]_l00000
1?nmW[P01Ol0003o^YbjokZL^_njW;[o000000;o]Y^l3_l000000onVU<?o0000oinAa@03oinAa@05
o`000?nISlSoVHo8oiV?b?l000001?nAS<X01Ol0003oRHW<ohV9c?n9RLco000000CoPXK>00?o0000
ogZ3dOmjPm400_mjPm401Ol0003oLh7Co`000?mcPM?o000000CoK7oE00Go0000ofIoeomVOmOoIWoG
o`000004of9of@;oGh7L0ol0000Pooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0=ooo
ool4ogJChPCoNY;N0ol00003oj:/gP03o`000?nVZ][oYZ[J00?oYZ[J00Go0000ojZYe_nZZMKoZZWF
o`000005ojfXdP03o`000?naYlko/JO>00;o/JO>00?o0000okBVbondY//00_ndY//00ol0003o]jG7
okNUa`03o`0000?o^JG500?o0000ok^T`_nkY<800_nkY<800ol0003o_JBookfT_`02okfT_`03o`00
0?noY;go_jBm00;o_jBm00Go0000ol6S^oo1Xk_o`J>ko`000004ol:S^@06o`000?o4XkSo0000o`00
0?o8Z;Wo00000oo8YkL01Ol0003ob:FfolRU]_o8YKKo000000Gob:Bd00Go0000olRT/oo8Y;?ob:Bc
o`000005olVT/`06o`000?o9Xk;obJ>bolVS/_l0003obJ>b0_l000000oo8X[7o0000olRR/@02o`00
0003olRR/_l0003oaj:b00;oaj:b0_l00003olJQ/`;o00001?o5XK@00ol0003o`j2eol>P]@02ol>P
]@05o`000?o1WkKo`Infol6O]_l000001?nmW[P00ol0003o^Ybjo`000004o`0000;o_9fj00Go0000
okVL^oniW;_o^Ibko`000004okJK_@03o`000?nbV[oo/YZo00Wo000000?oVHo8o`000?nAS<X00onA
S<X01Ol0003oRHW<ohV9c?n9RLco000000CoPXK>00?o0000ogZ3dOmjPm400_mjPm400ol0003oLh7C
og>1d`02o`0000CoK7oE00Go0000ofIoeomVOmOoIWoGo`000004of9of@CoGh7L00?o0000oooooooo
ool06oooool3o`0000;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0
=oooool01?l0003oMY?RogJCh_mfTn85ogZBgP;oP97K0_l000000onR[=ko0000ojJZfP03ojJZfP03
o`000?nZZMKoZZWF00;oZZWF00?o0000ojfXd_n]Z=800_n]Z=800ol0003o/JO>ok6WcP03ok6WcP03
o`000?ndY/_o]:K;00;o]:K;0ol000000ongYLOo0000okVUa@03okVUa@03o`000?nkY<;o^jC200;o
^jC200Go0000okfT_onmY;oo_JBoo`000005oknT_@05o`000?o1Xk_o`J>kol6S^ol000001?o2XkT0
1?l0003oa:>holBS^?o4XkP3o`0000;ob:Ng00Go0000olRU]_o8YKKob:Ffo`000004olRT]003o`00
0?o8Y;?ob:Bc00;ob:Bc00?o0000olVT/oo9Y;<00_o9Y;<00ol0003obJ>bo`000002olVS/P;o0000
00Sob::ao`000?o8X[7o0000olRR/Ol0003ob::ao`0000?oaj:b00So0000olNR/_o7X[;o0000olJQ
/ol0003oaZ6co`0000CoaJ6d00?o0000ol>P]Oo3X;D00_o3X;D01Ol0003o`Infol6O]_o1WkKo0000
00;o_Ijh1?l00002okjN^003o`000?nlWK[o_9fj00;o_9fj00Go0000okVL^oniW;_o^Ibko`000004
okJK_@05o`000?nbV[oo/YZook:J_ol000001?n^VL400ol0003oZYS4ojZHa003o`0000?oTHc:00Go
0000ohV9c?n9RLcoRHW<o`000004oh:6cP03o`000?mjPm7oNX?A00;oNX?A00Go0000og>1domcPM?o
Lh7Co`000004ofaoe@05o`000?mVOmOoIWoGofIoeol000001?mROmT00ol0003oGh7Loen1g002oen1
g003o`000?oooooooooo01Oooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ogJCh_mfTn800_mfTn85ogZBgPCoP97K0_l00004ojJZfP03
o`000?nZZMKoZZWF00;oZZWF00?o0000ojfXd_n]Z=800_n]Z=800ol0003o/JO>ok6WcP02ok6WcP03
o`000?ndY/_o]:K;00?o00001?ngYLL01Ol0003o^JG5okVUaOniYLGo000000Co^jC200?o0000okfT
_onmY;l00_nmY;l00ol0003o_jBmoknT_@02oknT_@03o`000?o1Xk_o`J>k00;o`J>k00Go0000ol:S
^Oo2XkWo`Z>io`000004olBS^003o`000?o5XkKoaJ>f00?o00000oo8YKH00ol0003ob:BdolRT]002
olRT]007o`000?o8Y;?ob:BcolRT/ol0003ob:>bo`000002olVT/`04o`000?o9Xk;obJ>bo`0000;o
bJ>b00[o0000olRR/Oo8X[7o0000olRR/Ol0003ob::ao`000?o8X[7o00000oo7X[800ol0003oaj:b
olNR/P02o`0000;oaZ6c00?o0000olFQ]?o5XK@00_o5XK@00ol0003o`j2eol>P]@02ol>P]@03o`00
0?o1WkKo`Inf00Co00000_o1WkL01Ol0003o_YjhokjN^?nnW[So000000Co_9fj00Go0000okVL^oni
W;_o^Ibko`000004okJK_@05o`000?nbV[oo/YZook:J_ol000001?n^VL401_l0003oZYS4ojZHa?nZ
V<Co0000ojFFaPCo00000on9RL`00ol0003oPXK>oh:6cP02oh:6cP03o`000?mjPm7oNX?A00;oNX?A
00Go0000og>1domcPM?oLh7Co`000004ofaoe@05o`000?mVOmOoIWoGofIoeol000001?mROmT00ol0
003oGh7Loen1g002oen1g003o`000?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo
00_ooooo000Sooooo`?o0000=oooool00ol0003oMY?RogJChP02ogJChP03o`000?mjT]koNY;N00;o
NY;N1?n0TM/2ohJAe`?o000000?oYZ[Jo`000?nZZMH00_nZZMH00ol0003o[JSBojfXdP03ojfXdP03
o`000?naYlko/JO>00;o/JO>0ol00002okBVb`03o`000?ngYLOo]jG700;o]jG700Go0000okVUaOni
YLGo^JG5o`000004ok^T`P03o`000?nmY;oo_JBo00;o_JBo00?o0000oknT_OnoY;d00_noY;d01Ol0
003o`J>kol6S^oo1Xk_o000000Co`Z>i00?o0000olBS^?o4XkP00_o4XkP01_l0003oaJ>folFS]_o5
XkKo0000olJR]@?o00001?o8Y;@00ol0003ob:BcolRT/`02olRT/`06o`000?o8Xk;ob:>bo`000?o9
Y;?o00000_o9Xk801?l0003obJ>bo`000?l00002olRR/@04o`000?o8X[7o0000o`0000?ob::a00?o
0000olNR/_l000000oo7X[801Ol0003oaZ6colJQ/oo6XK?o000000CoaJ6d00?o0000ol>P]Oo3X;D0
0_o3X;D3o`000003ol>P]Ol0003o`Ing00?o`Ing00Go0000okjN^?nnW[So_Yjho`000004okbM^P05
o`000?niW;_o^IbkokVL^ol000000onfVkd00ol0003o/YZook:J_`02ok:J_`03o`000?n^VL7o[YW1
00;o[YW100Go0000ojZHa?nZV<CoZYS4o`000004ojFFaP?o000000?oRHW<o`000?n2Q/h00on2Q/h0
0ol0003oNX?AogZ3d@02ogZ3d@04o`000?mcPM?oLh7Cog>1d`;o00000om/OmD01Ol0003oIWoGofIo
eomVOmOo000000CoHWoI00?o0000oen1g?mOPM`00_mOPM`00ol0003oooooooooo`0@ooooo`?o0000
3Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`000?mf
Tn;oMY?R00;oMY?R00?o0000ogZBg_mjT]h00_mjT]h4oh2Af`GoQY7G0ol00002ojZYeP03o`000?n]
Z=;o[JSB00;o[JSB00?o0000ok6Wc_naYlh01?l00003okBVb`03o`000?ngYLOo]jG700;o]jG700?o
0000okVUaOniYLD00_niYLD00ol0003o^jC2ok^T`P02ok^T`P03o`000?nmY;oo_JBo00;o_JBo00?o
0000oknT_OnoY;d00_noY;d01Ol0003o`J>kol6S^oo1Xk_o000000Co`Z>i00Go0000olBS^?o4XkSo
a:>ho`000004olFS]P04o`000?o6X[GoaZ:eolJR]@;o00000oo8Y;@00ol0003ob:BcolRT/`02olRT
/`05o`000?o8Xk;ob:>bolRS/_l000001?o9Xk800ol0003ob::ao`000002olRR/@;o000000Cob::a
o`000?o8X[7o00000_o8X[401_l0003oaj:bolNR/_l0003oaj:bo`0000CoaZ6c00Go0000olFQ]?o5
XKCoaJ6do`000002ol>P]@?o00000oo3X;D00ol0003o`Ingol6O]`02ol6O]`05o`000?nnW[So_Yjh
okjN^?l000000onlWKX00ol0003o^IbkokVL^`02okVL^`05o`000?nfVkgo]Y^mokJK_Ol000000onb
V[l00ol0003o[YW1ojjI`@02ojjI`@03o`000?nZV<CoZYS400;oZYS400?o0000ojFFa_nUU/H00_nU
U/H00ol0003oXIG8oj6Eb003o`0000?oPXK>00?o0000ogZ3dOmjPm400_mjPm401ol0003oLh7Cog>1
domcPM?o0000ofaoeOl000000_m/OmD01Ol0003oIWoGofIoeomVOmOo000000CoHWoI00?o0000oen1
g?mOPM`00_mOPM`00ol0003oooooooooo`0=ooooo`?o00004?ooool00ol0003oooooooooo`0:oooo
o`008oooool00ol0003oooooooooo`0gooooo`03o`000?mfTn;oMY?R00;oMY?R00?o0000ogZBg_mj
T]h00_mjT]h4oh2Af`GoQY7G0on<T]@3o`0000Co[JSB0ol00002ok6WcP03o`000?ndY/_o]:K;00;o
]:K;00?o0000okNUaongYLL00_ngYLL01Ol0003o^JG5okVUaOniYLGo000000Go^jC200Go0000okfT
_onmY;oo_JBoo`000004oknT_@03o`000?o1Xk_o`J>k00;o`J>k00Go0000ol:S^Oo2XkWo`Z>io`00
0004olBS^005o`000?o5XkKoaJ>folFS]_l000001?o6X[D01_l0003oaZ:do`000?l0003ob:Bdo`00
00?ob:Bc00?o0000olRS/_o8Xk800_o8Xk800ol0003obJ>bolVS/P02olVS/P03o`000?o8X[7o0000
00;ob::a0_l000001?o8X[7o0000olRR/Ol00002olRR/@03o`000?o7X[;o000000;oaj:b00?o0000
olJQ/oo6XK<00_o6XK<00ol0003oaJ6dolFQ]004o`0000;oa:6d00Go0000ol>P]Oo3X;Go`j2eo`00
0004ol6O]`04o`000?nnW[So_Yjho`0000Co_9fj00Go0000okVL^oniW;_o^Ibko`000004okJK_@05
o`000?nbV[oo/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co000000GoYIK600Ko0000
oj6Eb?nQULSoXIG8o`000?nLU</4o`0000CoNX?A00Go0000og>1domcPM?oLh7Co`000002ofaoe@03
o`000?m/OmGo000000?oIWoG00?o0000of9ofOmROmT00_mROmT00ol0003oGh7Loen1g002oen1g003
o`000?oooooooooo00Wooooo1?l0000Cooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo03Oooooo00?o0000ogJCh_mfTn800_mfTn801Ol0003oNY;NogZBg_mjT]ko000000Co
P97K00?o0000ohJAeon6TML00_n6TML4ohbBe0;oTY?A1Ol00004ok6WcP03o`000?ndY/_o]:K;00;o
]:K;00?o0000okNUaongYLL00_ngYLL01Ol0003o^JG5okVUaOniYLGo000000Co^jC200?o0000okfT
_onmY;l00_nmY;l00ol0003o_jBmoknT_@02oknT_@03o`000?o1Xk_o`J>k00;o`J>k00Go0000ol:S
^Oo2XkWo`Z>io`000004olBS^005o`000?o5XkKoaJ>folFS]_l000001?o6X[D01?l0003oaZ:dolJR
]?o6X[@2o`0000?ob:Bc00Oo0000olRS/_o8Xk;ob:>bo`000?o8X[;o000000;obJ>b00Ko0000olRR
/Ol0003ob::ao`000?o8X[42o`000003olRR/Ol0003o000000;ob::a0ol00003olNR/P03o`000?o6
XK?oaZ6c00;oaZ6c0ol000000oo6XK?o0000olBQ]003olBQ]005o`000?o3X;Go`j2eol>P]Ol00000
0oo1WkL01Ol0003o_YjhokjN^?nnW[So000000Co_9fj00Go0000okVL^oniW;_o^Ibko`000004okJK
_@05o`000?nbV[oo/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co000000CoYIK600?o
0000oj6Eb?nQULP00_nQULP00ol0003oW9C;oibDb`02oibDb`;o00000omjPm401Ol0003oLh7Cog>1
domcPM?o000000;oK7oE00?o0000ofaoeOl000001?mVOmL01Ol0003oHWoIof9ofOmROmWo000000Co
Gh7L00?o0000ooooooooool01_ooool3o`0001Oooooo00?o0000ooooooooool02_ooool002?ooooo
0ol0000gooooo`03o`000?mfTn;oMY?R00;oMY?R00Go0000ogZBg_mjT]koNY;No`000004oh2Af`03
o`000?n6TMOoQY7G00;oQY7G1?n<T]@3o`0000;oTY?A1?l00002ok6WcP05o`000?ndY/_o]:K;okBV
bol000001?ngYLL00ol0003o^JG5okVUa@02okVUa@03o`000?nkY<;o^jC200;o^jC200?o0000okfT
_onmY;l00_nmY;l00ol0003o_jBmoknT_@02oknT_@05o`000?o1Xk_o`J>kol6S^ol000001?o2XkT0
0ol0003oa:>holBS^002olBS^005o`000?o5XkKoaJ>folFS]_l000000oo6X[D00ol0003oaZ:dolJR
]002olJR]006o`000?o7X[?o0000o`000?o8Y;?o00000oo8Xk802ol0003ob::bolRR/_l0003obJ>b
o`000?o8X[7o0000olRR/Ol0003ob::a00?o000000Kob::ao`000?o8X[7o0000olRR/Ol00004olNR
/P04o`000?o6XK?oaZ6colJQ/`;o00000oo6XK<00ol0003oa:6dolBQ]002olBQ]005o`000?o3X;Go
`j2eol>P]Ol000000oo1WkL01Ol0003o_YjhokjN^?nnW[So000000Co_9fj00Go0000okVL^oniW;_o
^Ibko`000004okJK_@05o`000?nbV[oo/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co
000000CoYIK600Go0000oj6Eb?nQULSoXIG8o`000005oibDb`03o`000?nGTlgo000000?o00000omc
PM<01?l0003oK7oEofaoeOm/OmD2o`0000CoIWoG00Go0000of9ofOmROmWoHWoIo`000004oen1g003
o`000?oooooooooo00?ooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`00
0?oooooooooo03Oooooo00?o0000ogJCh_mfTn800_mfTn801Ol0003oNY;NogZBg_mjT]ko000000?o
P97K00?o0000ohJAeon6TML00on6TML01?n<T]Co0000o`000?l00005oi:Cd@CoV9C=0ol00003okBV
b`03o`000?ngYLOo]jG700;o]jG700Go0000okVUaOniYLGo^JG5o`000005ok^T`P03o`000?nmY;oo
_JBo00;o_JBo00Go0000oknT_OnoY;go_jBmo`000004ol6S^`05o`000?o2XkWo`Z>iol:S^Ol00000
1?o4XkP00ol0003oaJ>folFS]P02olFS]P05o`000?o6X[GoaZ:eolJR]Ol000001?o6X[@01?l0003o
aj:colNR/oo7X[<2o`0000?ob:>b00Go0000olRR/_o8X[;ob::bo`000002olRR/@03o`000?o8X[7o
000000Co000000Kob::ao`000?o8X[7o0000olRR/Ol00004olNR/PCo000000?oaj6bo`000?o6XK<0
0_o6XK<00ol0003oa:6dolBQ]002olBQ]005o`000?o3X;Go`j2eol>P]Ol000000oo1WkL01Ol0003o
_YjhokjN^?nnW[So000000Co_9fj00Go0000okVL^oniW;_o^Ibko`000004okJK_@05o`000?nbV[oo
/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co000000CoYIK600Go0000oj6Eb?nQULSo
XIG8o`000005oibDb`03o`000?nGTlgoUi?=00;oUi?=0_l00002og>1d`03o`000?m/OmGoK7oE00;o
K7oE00?o0000ofIoeomVOmL00_mVOmL01Ol0003oHWoIof9ofOmROmWo000000CoGh7L00?o0000oooo
ooooool00ol0000Mooooo`03o`000?oooooooooo00[ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000
ooooooooool0>?ooool01Ol0003oMY?RogJCh_mfTn;o000000CoNY;N00Go0000oh2Afon0TM_oP97K
o`000003ohJAe`?o00000on<T]@5oi:Cd@GoV9C=0_nNULX2o`000003okBVbol0003o]jG700?o]jG7
00Go0000okVUaOniYLGo^JG5o`000004ok^T`P03o`000?nmY;oo_JBo00;o_JBo00?o0000oknT_Ono
Y;d00_noY;d00ol0003o`J>kol6S^`02ol6S^`05o`000?o2XkWo`Z>iol:S^Ol000001?o4XkP01Ol0
003oaJ>folFS]_o5XkKo000000CoaZ:e00Go0000olJR]?o6X[CoaZ:do`000004olNR/`03o`000?o8
X[;o000000;o00001?o8X[801?l0003ob::aolRR/Oo8X[42o`000003olRR/Ol0003o000000;o0000
00?ob::ao`000?o8X[400_l00003olNR/P;o00001?o7XK801Ol0003oaZ6colJQ/oo6XK?o000000Co
a:6d00Go0000ol>P]Oo3X;Go`j2eo`000003ol6O]`05o`000?nnW[So_YjhokjN^?l000001?nlWKX0
1Ol0003o^IbkokVL^oniW;_o000000Co]Y^m00Go0000ok:J_onbV[oo/YZoo`000004ojjI`@05o`00
0?nZV<CoZYS4ojZHa?l000001?nUU/H01Ol0003oXIG8oj6Eb?nQULSo000000CoW9C;00?o0000oiNC
cOnGTld00onGTld00ol0003oTi?@o`000002o`0000CoK7oE00?o0000ofIoeomVOmL00_mVOmL01Ol0
003oHWoIof9ofOmROmWo000000CoGh7L0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00Go0000ogJCh_mfTn;oMY?R
o`000004ogZBgP04o`000?n0TM_oP97Koh2Af`Co000000?oQY7Go`000?n<T]@00on<T]@00ol0003o
TY?Aoi:Cd@02oi:Cd@GoV9C=1?nNULX4o`000003okNUaol0003o^JG500?o^JG500?o0000ok^T`_nk
Y<800_nkY<800ol0003o_JBookfT_`02okfT_`03o`000?noY;go_jBm00;o_jBm00?o0000ol6S^oo1
Xk/00_o1Xk/01Ol0003o`Z>iol:S^Oo2XkWo000000Coa:>h00Go0000olFS]_o5XkKoaJ>fo`000004
olJR]@05o`000?o6X[CoaZ:dolJR]?l000001?o7X[<01?l0003ob::bolRR/_o8X[82o`0000?ob::b
0_l00002olRR/@;o000000?ob::ao`000?l000000ol000002Oo8X[7o0000olRR/Oo8X[7o0000olNR
/_l0003ob::bo`000004olNQ/P05o`000?o6XK?oaZ6colJQ/ol000001?o4XK@01?l0003o`j2eol>P
]Ol00004ol6O]`05o`000?nnW[So_YjhokjN^?l000001?nlWKX01Ol0003o^IbkokVL^oniW;_o0000
00?o]Y^m00Go0000ok:J_onbV[oo/YZoo`000005ojjI`@05o`000?nZV<CoZYS4ojZHa?l000001?nU
U/H01Ol0003oXIG8oj6Eb?nQULSo000000CoW9C;00?o0000oiNCcOnGTld00onGTld01?l0003oTi?@
oi>Cd?nCTm02o`0000?oK7oE0_l00003ofIoe`05o`000?mROmWoHWoIof9ofOl000001?mOPM`00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000>?ooool00ol0
003oMY?RogJChP02ogJChP03o`000?mjT]koNY;N00;oNY;N00?o0000oh2Afon0TM/00_l00004ohJA
e`05o`000?n<T]CoS9;DohbBe?l000001OnBTm45oiRDc@CoWYG:1?nTU/L4o`000003okVUaOl0003o
^jC200Co^jC200?o0000okfT_onmY;l00_nmY;l01Ol0003o_jBmoknT_OnoY;go000000Co`J>k00?o
0000ol:S^Oo2XkT00_o2XkT01Ol0003oa:>holBS^?o4XkSo000000CoaJ>f00Go0000olJR]Oo6X[Go
aZ:eo`000004olJR]005o`000?o7X[?oaj:colNR/ol000001?o8X[800ol0003ob::bo`000002o`00
00;ob::a00Go0000olRR/Ol0003o0000olRR/@03o`000003olRR/Ol0003o000000?ob::a0_l00002
olRR/P03o`000?o7XK;oaj6b00;oaj6b00Co0000olJQ/oo6XK?o00001?o4XK@01Ol0003o`j2eol>P
]Oo3X;Go000000Co`Ing00Go0000okjN^?nnW[So_Yjho`000004okbM^P05o`000?niW;_o^IbkokVL
^ol000000onfVkd01Ol0003o/YZook:J_onbV[oo000000Co[YW100?o0000ojZHa?nZV<@00_nZV<@0
1Ol0003oYIK6ojFFa_nUU/Ko000000CoXIG800?o0000oibDbonLU</00_nLU</00ol0003oUi?=oiNC
c@02oiNCc@03o`000?nCTm3oTi?@00;oTi?@00?o0000ohnBdol000000ol000001OmVOmOo0000ofIo
eomVOmOo000000?oHWoI00?o0000oen1g?mOPM`00_mOPM`00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Wooooo00001Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ogJCh_mfTn80
0_mfTn800ol0003oNY;NogZBgP02ogZBgP?o000000?oP97Ko`000?n6TML00on6TML01Ol0003oS9;D
ohbBe?n<T]Co000000GoTY?A1?nHU<d00ol0003oWYG:oijEbP02oijEbPGoY9K70onYV<D5o`000003
ok^T`_l0003o_JBo00Co_JBo00Go0000oknT_OnoY;go_jBmo`000004ol6S^`05o`000?o2XkWo`Z>i
ol:S^Ol000001?o4XkP01Ol0003oaJ>folFS]_o5XkKo000000CoaZ:e00Go0000olJR]?o6X[CoaZ:d
o`000004olNR/`03o`000?o8X[;ob::b00;ob::b00Co0000olRR/_o8X[;ob::b0_l00002olRR/@03
o`000?o8X[7o000000Ko00000oo8X[42o`0000?ob::b00Go0000olNQ/_o7XK;oaj6bo`000003olJQ
/`03o`000?o4XKCoa:6d00;oa:6d00Go0000ol>P]Oo3X;Go`j2eo`000004ol6O]`05o`000?nnW[So
_YjhokjN^?l000001?nlWKX01Ol0003o^IbkokVL^oniW;_o000000?o]Y^m00Go0000ok:J_onbV[oo
/YZoo`000004ojjI`@05o`000?nZV<CoZYS4ojZHa?l000001?nUU/H01Ol0003oXIG8oj6Eb?nQULSo
000000GoW9C;00?o0000oiNCcOnGTld00_nGTld00ol0003oTi?@oi>Cd002oi>Cd003o`000?n?T]?o
Si;C00;oSi;C0_l000001?mVOmOo0000ofIoeol00003of9of@03o`000?mOPMcoGh7L00;oGh7L00?o
0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ogJCh_mfTn800_mfTn800ol0003oNY;No`000003o`0000?oP97K
00?o0000ohJAeon6TML00_n6TML01Ol0003oS9;DohbBe?n<T]Co000000CoTY?A00?o0000oiRDcOnH
U<d00_nHU<d00ol0003oWYG:oijEbP02oijEbPGoY9K71?nYV<D4ojfI`PGo000000?o_JBoo`000?no
Y;d00onoY;d00ol0003o`J>kol6S^`02ol6S^`05o`000?o2XkWo`Z>iol:S^Ol000001?o4XkP01Ol0
003oaJ>folFS]_o5XkKo000000CoaZ:e00Go0000olJR]?o6X[CoaZ:do`000004olNR/`05o`000?o8
X[;ob::bolRR/_l000001?o8X[800ol0003ob::ao`00000=o`000003olRR/Ol0003ob::b00;ob::b
00Go0000olNQ/_o7XK;oaj6bo`000003olJQ/`03o`000?o4XKCoa:6d00;oa:6d00Go0000ol>P]Oo3
X;Go`j2eo`000003ol6O]`03o`000?nnW[So_Yjh00;o_Yjh00Go0000okbM^_nlWK[o_9fjo`000004
okVL^`05o`000?nfVkgo]Y^mokJK_Ol000000onbV[l00ol0003o[YW1ojjI`@02ojjI`@05o`000?nZ
V<CoZYS4ojZHa?l000001?nUU/H01Ol0003oXIG8oj6Eb?nQULSo000000CoW9C;00?o0000oiNCcOnG
Tld00onGTld01Ol0003oTi?@oi>Cd?nCTm3o000000GoSi;C00?o0000oh^Ce_l000000ol00003of9o
f@03o`000?mOPMcoGh7L00;oGh7L00?o0000ooooooooool08Oooool00ol0003oooooooooo`09oooo
o`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0gooooo`;o00000_mfTn83o`0000?oNY;N00Go0000oh2A
fon0TM_oP97Ko`000004ohJAe`05o`000?n<T]CoS9;DohbBe?l000001?nBTm400ol0003oV9C=oiRD
c@02oiRDc@03o`000?nNUL[oWYG:00;oWYG:1OnTU/L4ojVHa@Go[IW21?nbV/04o`000003oknT_Ol0
003o`J>k00?o`J>k00?o0000ol:S^Oo2XkT00_o2XkT00ol0003oa:>holBS^002olBS^005o`000?o5
XkKoaJ>folFS]_l000001?o6X[D01Ol0003oaZ:dolJR]?o6X[Co000000Coaj:c00Go0000olRR/_o8
X[;ob::bo`000004olRR/P04o`000?o8X[7ob::aolRR/@Wo00001?o8X[401Ol0003ob::bolRR/_o8
X[;o000000?oaj6b00Go0000olJQ/oo6XK?oaZ6co`000004olBQ]005o`000?o3X;Go`j2eol>P]Ol0
00000oo1WkL01Ol0003o_YjhokjN^?nnW[So000000Co_9fj00Go0000okVL^oniW;_o^Ibko`000004
okJK_@05o`000?nbV[oo/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co000000CoYIK6
00Go0000oj6Eb?nQULSoXIG8o`000004oibDb`03o`000?nGTlgoUi?=00?oUi?=00Go0000oi>Cd?nC
Tm3oTi?@o`000004ohnBd`03o`000?n;TmKoRi?F00;oRi?F0ol00002of9of@03o`000?mOPMcoGh7L
00;oGh7L00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06
ooooo`;o0000>?ooool01_l`KMco0000o`000?l0003oMY?Ro`0000?oNY;N00?o0000oh2Afon0TM/0
0_n0TM/00ol0003oQY7GohJAe`02ohJAe`05o`000?n<T]CoS9;DohbBe?l000001?nBTm400ol0003o
V9C=oiRDc@02oiRDc@03o`000?nNUL[oWYG:00;oWYG:00?o0000ojBFaonTU/L00_nTU/L4ojVHa@Go
[IW21OnbV/000ol0003o]YbmokJL_@09o`000003ol:S^Ol0003oa:>h00?oa:>h00?o0000olFS]_o5
XkH00_o5XkH00ol0003oaZ:eolJR]@02olJR]@05o`000?o6X[CoaZ:dolJR]?l000001?o7X[<01Ol0
003ob::bolRR/_o8X[;o000000?ob::b00?o0000olRR/Oo8X[400_o8X[400ol0003ob::ao`000004
o`000003olRR/Ol0003ob::a00;ob::a00?o0000olRR/_o8X[800_o8X[801Ol0003oaj6bolNQ/_o7
XK;o000000?oaZ6c00?o0000olBQ]?o4XK@00_o4XK@01Ol0003o`j2eol>P]Oo3X;Go000000?o`Ing
00Go0000okjN^?nnW[So_Yjho`000004okbM^P05o`000?niW;_o^IbkokVL^ol000001?nfVkd01Ol0
003o/YZook:J_onbV[oo000000Co[YW100Go0000ojZHa?nZV<CoZYS4o`000004ojFFaP05o`000?nQ
ULSoXIG8oj6Eb?l000001?nLU</00ol0003oUi?=oiNCc@02oiNCc@03o`000?nCTm3oTi?@00;oTi?@
00?o0000ohnBdon?T]<00_n?T]<00ol0003oRi?Foh^CeP03oh^CeP03o`000?n7U=Wo000000;o0000
1?mOPM`00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool2o`0003Oo
oooo0ol00003oc1]g0;o00000omjT]h00ol0003oP97Koh2Af`02oh2Af`03o`000?n6TMOoQY7G00;o
QY7G00Go0000ohbBe?n<T]CoS9;Do`000004oi:Cd@03o`000?nHU<goV9C=00;oV9C=00Go0000oijE
b_nNUL[oWYG:o`000005ojBFa`CoZIS500?o0000ojfI`_n]VL800_n]VL85ok:J`005o`000?nfW;go
]YbmokJL_Ol000001?niWK/00ol0003o_9jjokbN^P09o`000003olFS]_l0003oaZ:e00?oaZ:e00Go
0000olJR]?o6X[CoaZ:do`000004olNR/`05o`000?o8X[;ob::bolRR/_l000001?o8X[800ol0003o
b::ao`00000[o`000003okjN^?l0003o_9fj00?o_9fj00Go0000okVL^oniW;_o^Ibko`000004okJK
_@05o`000?nbV[oo/YZook:J_ol000001?n^VL401Ol0003oZYS4ojZHa?nZV<Co000000?oYIK600?o
0000oj6Eb?nQULP00_nQULP01Ol0003oW9C;oibDbonLU<_o000000GoUi?=00Go0000oi>Cd?nCTm3o
Ti?@o`000005ohnBd`03o`000?n;TmKoRi?F00;oRi?F00?o0000ohNDfOl000000_n7U=T2o`0000?o
Gh7L00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003ooooo
ooooo`0cooooo`?o00000oooool4oc1]g0;o00000_mjT]h01Ol0003oP97Koh2Afon0TM_o000000Go
QY7G00Go0000ohbBe?n<T]CoS9;Do`000004oi:Cd@03o`000?nHU<goV9C=00;oV9C=00Go0000oijE
b_nNUL[oWYG:o`000004ojBFa`03o`000?nYV<GoZIS500;oZIS500?o0000ojfI`_n]VL800_n]VL85
ok:J`005o`000?nfW;go]YbmokJL_Ol000001?niWK/01Ol0003o_9jjokbN^_nlW[[o000000Co_Yjh
00?o0000ol6O]oo1WkL06_l00002olRR/@03o`000?o8X[7o000000?o000000Cob::ao`000?o8X[7o
00000oo8X[400ol0003ob::bolRR/P02olRR/P05o`000?o8X[;ob::bolRR/_l000000oo7X[<00ol0
003oaZ:dolJR]002olJR]005o`000?o6X[GoaZ:eolJR]Ol000000oo5X[H00ol0003oa:>holBS^009
o`000003okVL^ol0003o]Y^m00;o]Y^m00Go0000ok:J_onbV[oo/YZoo`000005ojjI`@05o`000?nZ
V<CoZYS4ojZHa?l000000onUU/H01Ol0003oXIG8oj6Eb?nQULSo000000CoW9C;00?o0000oiNCcOnG
Tld00onGTld01Ol0003oTi?@oi>Cd?nCTm3o000000CoSi;C00?o0000oh^Ce_n;TmH00on;TmH00ol0
003oQiCIo`000002ohNDf@03o`000?n4UMco000000?o00009?ooool00ol0003oooooooooo`08oooo
o`008Oooool00ol0003oooooooooo`0`ooooo`?o00001_ooool01?l0003o<6gLoc1]g?l`KM`2ocM]
fP?o00000on0TM/00ol0003oQY7GohJAe`03ohJAe`05o`000?n<T]CoS9;DohbBe?l000001?nBTm40
0ol0003oV9C=oiRDc@02oiRDc@05o`000?nNUL[oWYG:oijEb_l000001?nTU/L01Ol0003oZIS5ojVH
aOnYV<Go000000Go[IW21?nbV/000ol0003o]YbmokJL_@02okJL_@03o`000?niWK_o^Ifk00;o^Ifk
00Go0000okbN^_nlW[[o_9jjo`000004okjN^005o`000?o1WkOo`Ingol6O]ol000001?o3X;D01Ol0
003oa:6dolBQ]?o4XKCo000000CoaZ6c00Go0000olNQ/_o7XK;oaj6bo`000004olRR/P04o`000?o8
X[7ob::aolRR/@;o000000?ob::ao`000?l000000_l000000oo8X[7o0000o`000003olRR/@05o`00
0?o8X[;ob::bolRR/_l000001?o8X[801Ol0003oaj:colNR/oo7X[?o000000CoaZ:d00Go0000olJR
]Oo6X[GoaZ:eo`000003olFR]P05o`000?o4XkSoa:>holBS^?l000001?o2XkT00ol0003o`J>kol6S
^`04o`000003okJK_Ol0003o/YZo00;o/YZo00?o0000ojjI`On^VL400_n^VL400ol0003oZYS4ojZH
a002ojZHa005o`000?nUU/KoYIK6ojFFa_l000000onQULP00ol0003oW9C;oibDb`02oibDb`03o`00
0?nGTlgoUi?=00;oUi?=00?o0000oi>Cd?nCTm000_nCTm000ol0003oSi;CohnBd`02ohnBd`03o`00
0?n;TmKoRi?F00?oRi?F00?o0000ohNDfOn7U=T00_l00005ohBEg003o`000?oooooooooo02;ooooo
00?o0000ooooooooool02?ooool0027ooooo0_l0000^ooooo`?o00002_ooool3oc1]g004o`000?lg
KM[o=fgJocM]fP;o00000_n0TM/00ol0003oQY7GohJAe`02ohJAe`03o`000?n<T]CoS9;D00;oS9;D
00?o0000oi:CdOnBTm400_nBTm401Ol0003oV9C=oiRDcOnHU<go000000CoWYG:00?o0000ojBFaonT
U/L00_nTU/L01Ol0003oZIS5ojVHaOnYV<Go000000Co[IW200?o0000ok:J`?nbV/000_nbV/000ol0
003o]YbmokJL_@02okJL_@03o`000?niWK_o^Ifk00;o^Ifk00Go0000okbN^_nlW[[o_9jjo`000004
okjN^005o`000?o1WkOo`Ingol6O]ol000001?o3X;D01Ol0003oa:6dolBQ]?o4XKCo000000CoaZ6c
00Go0000olNQ/_o7XK;oaj6bo`000004olRR/P03o`000?o8X[7ob::a00;o000000?ob::ao`000?l0
00001Ol000001?o8X[7o0000o`000?l00004olRR/P05o`000?o8X[;ob::bolRR/_l000000oo7X[<0
0ol0003oaZ:dolJR]002olJR]005o`000?o6X[GoaZ:eolJR]Ol000000oo5X[H00ol0003oa:>holBS
^002olBS^003o`000?o2XkWo`Z>i00;o`Z>i00Go0000ol6S^oo1Xk_o`J>ko`000002oknS_@Wo0000
00?o[YW1o`000?nZV<@00_nZV<@00ol0003oYIK6ojFFaP02ojFFaP05o`000?nQULSoXIG8oj6Eb?l0
00001?nLU</00ol0003oUi?=oiNCc@02oiNCc@03o`000?nCTm3oTi?@00;oTi?@00?o0000ohnBdon?
T]<00_n?T]<00ol0003oRi?Foh^CeP02oh^CeP03o`000?n7U=WoQiCI00;oQiCI00?o0000ohBEg?n4
UM`00on4UM`00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`00
0?oooooooooo02[ooooo0ol0000=ooooo`04o`000?l`KMco<6gLoc1]g0?o=fgJ0_m0KmT3o`0000Co
QY7G00?o0000ohbBe?n<T]@00_n<T]@00ol0003oTY?Aoi:Cd@02oi:Cd@05o`000?nHU<goV9C=oiRD
cOl000001?nNULX00ol0003oY9K7ojBFa`02ojBFa`05o`000?nYV<GoZIS5ojVHaOl000001?n]VL80
0ol0003o/Y[0ok:J`002ok:J`003o`000?nfW;go]Ybm00;o]Ybm00?o0000okVM^oniWK/00_niWK/0
1Ol0003o_9jjokbN^_nlW[[o000000Co_Yjh00Go0000ol6O]oo1WkOo`Ingo`000004ol>P]@05o`00
0?o4XKCoa:6dolBQ]?l000001?o6XK<01Ol0003oaj6bolNQ/_o7XK;o000000?ob::b1?l000000oo8
X[7o0000o`000005o`000003olRR/Ol0003ob::a00;ob::a0_l00003olRR/P05o`000?o8X[;ob::b
olRR/_l000000oo7X[<00ol0003oaZ:dolJR]002olJR]005o`000?o6X[GoaZ:eolJR]Ol000000oo5
X[H01Ol0003oa:>holBS^?o4XkSo000000Co`Z>i00?o0000ol6S^oo1Xk/00_o1Xk/01Ol0003o_j>m
oknS_OnoXkgo000000?o_JBo00Co0000ok^T`_nkY<;o^jC21?l000000onZV<Co0000ojFFaP03ojFF
aP05o`000?nQULSoXIG8oj6Eb?l000000onLU</00ol0003oUi?=oiNCc@03oiNCc@05o`000?nCTm3o
Ti?@oi>Cd?l000001?n?T]<00ol0003oRi?Foh^CeP03oh^CeP03o`000?n7U=WoQiCI00;oQiCI0_l0
0003ohBEg003o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000
ooooooooool09oooool3o`00013ooooo00Go0000oc1]g?l`KMco<6gLo`000002ocM]fP04o`000?m0
KmWo@6oIod1_f@;o00000on6TML01Ol0003oS9;DohbBe?n<T]Co000000GoTY?A00Go0000oiRDcOnH
U<goV9C=o`000004oijEbP03o`000?nTU/OoY9K700;oY9K700Go0000ojVHaOnYV<GoZIS5o`000004
ojfI`P03o`000?nbV/3o/Y[000;o/Y[000Go0000okJL_OnfW;go]Ybmo`000004okVM^`03o`000?nl
W[[o_9jj00;o_9jj00Go0000okjN^?nnW[So_Yjho`000004ol6O]`03o`000?o3X;Go`j2e00;o`j2e
00Go0000olBQ]?o4XKCoa:6do`000004olJQ/`05o`000?o7XK;oaj6bolNQ/_l000000_o8X[82o`00
00Cob::a00?o0000olRR/Ol000000_l000001?o8X[7o0000o`000?l00003olRR/@03o`000?o8X[;o
000000;o00001?o8X[801Ol0003oaj:colNR/oo7X[?o000000CoaZ:d00Go0000olJR]Oo6X[GoaZ:e
o`000003olFR]P05o`000?o4XkSoa:>holBS^?l000001?o2XkT01Ol0003o`J>kol6S^oo1Xk_o0000
00?o_j>m00?o0000okfT_onmY;l00_nmY;l00ol0003o^jC2ok^T`P02ok^T`P03o`000?niY<Co^JC4
00?o00000_nUU/H00ol0003oXIG8oj6Eb002oj6Eb005o`000?nLU<_oW9C;oibDbol000001OnGTld0
1Ol0003oTi?@oi>Cd?nCTm3o000000CoSi;C00?o0000oh^Ce_n;TmH00_n;TmH00ol0003oQiCIohND
f@02ohNDf@03o`000?n4UMco000000?oQ9GL00?o0000ooooooooool08oooool00ol0003ooooooooo
o`08ooooo`008?ooool00ol0003oooooooooo`0Uooooo`?o00005?ooool01?l0003o<6gLoc1]g?l0
0003ocM]fP?o@6oI0_m<L]L4o`0000?oS9;D00?o0000oi:CdOnBTm400onBTm401Ol0003oV9C=oiRD
cOnHU<go000000CoWYG:00?o0000ojBFaonTU/L00_nTU/L01Ol0003oZIS5ojVHaOnYV<Go000000Co
[IW200?o0000ok:J`?nbV/000_nbV/001Ol0003o]YbmokJL_OnfW;go000000Co^Ifk00?o0000okbN
^_nlW[X00_nlW[X01Ol0003o_YjhokjN^?nnW[So000000Co`Ing00?o0000ol>P]Oo3X;D00_o3X;D0
1Ol0003oa:6dolBQ]?o4XKCo000000?oaZ6c00?o0000olNQ/_o7XK800_o7XK83o`000003olNR/_l0
003ob::a00;ob::a1_l000001Oo8X[7o0000o`000?o8X[7o000000;ob::a00Co0000olRR/_o8X[;o
b::b0_l00003olRR/P05o`000?o7X[?oaj:colNR/ol000001?o6X[@01Ol0003oaZ:eolJR]Oo6X[Go
000000?oaJ:f00Go0000olBS^?o4XkSoa:>ho`000004ol:S^@05o`000?o1Xk_o`J>kol6S^ol00000
0onoXkd01Ol0003o_JBookfT_onmY;oo000000Co^jC200?o0000okVTa?niY<@00_niY<@00ol0003o
]jG7o`000002o`0000?oXIG800?o0000oibDbonLU</00_nLU</00ol0003oUi?=oiNCc@02oiNCc@03
o`000?nCTm3oTi?@00;oTi?@00?o0000ohnBdon?T]<00_n?T]<00ol0003oRi?Foh^CeP02oh^CeP03
o`000?n7U=WoQiCI00;oQiCI00Ko0000ohBEg?n4UMco0000ohBEg?l0000Vooooo`03o`000?oooooo
oooo00Sooooo000Pooooo`03o`000?oooooooooo02;ooooo0ol0000Gooooo`05o`000?l`KMco<6gL
oc1]g?l000000_lgKMX01?l0003o@6oIod1_fOl00004odabe`;o00000_n<T]@00ol0003oTY?Aoi:C
d@02oi:Cd@03o`000?nHU<goV9C=00;oV9C=00?o0000oijEb_nNULX00_nNULX00ol0003oY9K7ojBF
a`02ojBFa`05o`000?nYV<GoZIS5ojVHaOl000001?n]VL800ol0003o/Y[0ok:J`002ok:J`005o`00
0?nfW;go]YbmokJL_Ol000001?niWK/00ol0003o_9jjokbN^P02okbN^P05o`000?nnW[So_YjhokjN
^?l000001?o1WkL00ol0003o`j2eol>P]@02ol>P]@04o`000?o4XKCoa:6do`0000CoaZ6c00Co0000
olNQ/_o7XK;oaj6b0_l00003olNR/P07o`000?o8X[7ob::ao`000?o8X[7o0000olRR/@03o`000003
olRR/Ol0003o000000;ob::a0_l00004olRR/P03o`000?o8Xk;o000000;o00001?o7X[<01Ol0003o
aZ:dolJR]?o6X[Co000000CoaZ:e00Co0000olFR]_o5X[Ko00001?o4XkP01Ol0003o`Z>iol:S^Oo2
XkWo000000Co`J>k00Go0000oknS_OnoXkgo_j>mo`000003okfT_`03o`000?nkY<;o^jC200;o^jC2
00Go0000okVTa?niY<Co^JC4o`000004okNUa`?o000000?oXIG8o`000?nLU</00onLU</00ol0003o
Ui?=oiNCc@02oiNCc@03o`000?nCTm3oTi?@00;oTi?@00Go0000ohnBdon?T]?oSi;Co`000004oh^C
eP03o`000?n7U=WoQiCI00?oQiCI00Co0000ohBEg?n4UMcoQ9GL0_l0000Vooooo`03o`000?oooooo
oooo00Sooooo000Pooooo`;o00008Oooool2o`0001[ooooo00Go0000oc1]g?l`KMco<6gLo`000002
ocM]fP04o`000?m0KmWo@6oIod1_f@CoC7;G0_mHM]H3o`0000CoTY?A00?o0000oiRDcOnHU<d00_nH
U<d00ol0003oWYG:oijEbP02oijEbP03o`000?nTU/OoY9K700;oY9K700Go0000ojVHaOnYV<GoZIS5
o`000004ojfI`P03o`000?nbV/3o/Y[000;o/Y[000Go0000okJL_OnfW;go]Ybmo`000004okVM^`03
o`000?nlW[[o_9jj00;o_9jj00Go0000okjN^?nnW[So_Yjho`000004ol6O]`05o`000?o3X;Go`j2e
ol>P]Ol000000oo4XK@00ol0003oaZ6colJQ/`02olJQ/`06o`000?o7XK;o0000o`000?o6XK?o0000
1?o7X[82o`0000;ob::a1ol000000oo8X[7o0000olRR/@02o`0000Cob::b00Co0000olRS/_o8Xk;o
b:>b0_l00002olNR/`03o`000?o6X[CoaZ:d00;oaZ:d00Go0000olJR]Oo6X[GoaZ:eo`000003olFR
]P05o`000?o4XkSoa:>holBS^?l000001?o2XkT01Ol0003o`J>kol6S^oo1Xk_o000000?o_j>m00?o
0000okfT_onmY;l00_nmY;l00ol0003o^jC2ok^T`P02ok^T`P05o`000?niY<Co^JC4okVTa?l00000
1?ngYLL00ol0003o]:G:okBUbP04o`000003oibDbol0003oUi?=00CoUi?=00Go0000oi>Cd?nCTm3o
Ti?@o`000004ohnBd`03o`000?n;TmKoRi?F00;oRi?F00?o0000ohNDfOn7U=T00_n7U=T00ol0003o
Q9GLohBEg003ohBEg003o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool0023ooooo
00?o0000ooooooooool07Oooool3o`0001gooooo00Co0000oc1]g?l`KMco00000olgKMX3od1_f@05
o`000?m<L]OoC7;Godabeol000000omHM]H2o`0000?oTY?A00?o0000oiRDcOnHU<d00_nHU<d00ol0
003oWYG:oijEbP02oijEbP03o`000?nTU/OoY9K700;oY9K700Go0000ojVHaOnYV<GoZIS5o`000004
ojfI`P05o`000?nbV/3o/Y[0ok:J`?l000001?nfW;d00ol0003o^IfkokVM^`02okVM^`05o`000?nl
W[[o_9jjokbN^_l000001?nnW[P01Ol0003o`Ingol6O]oo1WkOo000000Co`j2e00Go0000olBQ]?o4
XKCoa:6do`000004olJQ/`;o00000oo6XK<00ol0003oaj:bolNR/P02olNR/P05o`000?o8X[7ob::a
o`000?o8X[401?l000001?o8X[7o0000olRR/Ol00002olRR/@05o`000?o8X[;ob::bolRR/_l00000
1?o8Xk800ol0003ob:Bco`000002o`0000CoaZ:d00Go0000olJR]Oo6X[GoaZ:eo`000003olFR]P05
o`000?o4XkSoa:>holBS^?l000001?o2XkT01Ol0003o`J>kol6S^oo1Xk_o000000?o_j>m00Go0000
okfT_onmY;oo_JBoo`000004ok^T`P03o`000?niY<Co^JC400;o^JC400Go0000okNUaongYLOo]jG7
o`000004okBUbP03o`000?naY/go/JK=00?o00001?nGTld01Ol0003oTi?@oi>Cd?nCTm3o000000Co
Si;C00?o0000oh^Ce_n;TmH00_n;TmH00ol0003oQiCIohNDf@02ohNDf@03o`000?n4UMcoQ9GL00;o
Q9GL0_l0000Wooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo
0ol0000Pooooo`05o`000?l`KMco<6gLoc1]g?l000000_lgKMX01?l0003o@6oIod1_fOl00004odab
e`?oF7KF0_mUNm@4o`0000?oV9C=00?o0000oijEb_nNULX00_nNULX00ol0003oY9K7ojBFa`03ojBF
a`05o`000?nYV<GoZIS5ojVHaOl000001?n]VL801Ol0003o/Y[0ok:J`?nbV/3o000000Co]Ybm00?o
0000okVM^oniWK/00_niWK/01Ol0003o_9jjokbN^_nlW[[o000000Co_Yjh00Go0000ol6O]oo1WkOo
`Ingo`000004ol>P]@05o`000?o4XKCoa:6dolBQ]?l000000oo6XK<2o`0000CoaZ6c00Co0000olNR
/_o7X[;oaj:b0_l000001Oo8X[7o0000olRR/Ol0003ob::a00?o000000Cob::ao`000?o8X[7o0000
0_o8X[401Ol0003ob::bolRR/_o8X[;o000000?ob:>b00?o0000olRT/oo8Y;<00_o8Y;<2o`0000?o
aZ:d00Go0000olJR]Oo6X[GoaZ:eo`000003olFR]P05o`000?o4XkSoa:>holBS^?l000001?o2XkT0
1Ol0003o`J>kol6S^oo1Xk_o000000?o_j>m00Go0000okfT_onmY;oo_JBoo`000004ok^T`P05o`00
0?niY<Co^JC4okVTa?l000001?ngYLL01Ol0003o]:G:okBUb_ndYL[o000000Co/JK=00?o0000ojjW
d?l000000ol00004oi>Cd005o`000?n?T]?oSi;CohnBdol000001?n;TmH00ol0003oQiCIohNDf@03
ohNDf@03o`000?n4UMcoQ9GL00;oQ9GL00?o0000ooooool000009_ooool00ol0003oooooooooo`07
ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`05o`000?l`KMco<6gLoc1]g?l000000_lgKMX0
1?l0003o@6oIod1_fOm0KmT4odabe`?oF7KF00?o0000ofEke?mUNm@00_mUNm@2o`0000;oV9C=00?o
0000oijEb_nNULX00_nNULX00ol0003oY9K7ojBFa`03ojBFa`05o`000?nYV<GoZIS5ojVHaOl00000
1?n]VL801Ol0003o/Y[0ok:J`?nbV/3o000000Co]Ybm00?o0000okVM^oniWK/00_niWK/01Ol0003o
_9jjokbN^_nlW[[o000000Co_Yjh00Go0000ol6O]oo1WkOo`Ingo`000004ol>P]@04o`000?o4XKCo
a:6dolBQ]0Co000000?oaJ6do`000?o6XK<00oo6XK<02ol0003oaj:bolNR/_l0003oaj:bo`000?o8
X[7o0000olRR/Ol0003ob::a00?o000000Cob::ao`000?o8X[7ob::a0_l000001Oo9Xk;o0000olRR
/_o8X[;o000000?ob:>b00?o0000olRT/oo8Y;<00_o8Y;<00ol0003ob:Bdo`000002o`0000CoaZ:e
00Co0000olFR]_o5X[Ko00001?o4XkP01Ol0003o`Z>iol:S^Oo2XkWo000000Co`J>k00Co0000oknS
_OnoXkgo00001?nmY;l00ol0003o^jC2ok^T`P02ok^T`P05o`000?niY<Co^JC4okVTa?l000001?ng
YLL01Ol0003o]:G:okBUb_ndYL[o000000?o/JK=00?o0000ojjWd?n^Ym000on^Ym03o`000003oi>C
d?l0003oSi;C00?oSi;C00?o0000oh^Ce_n;TmH00_n;TmH00ol0003oQiCIohNDf@02ohNDf@03o`00
0?n4UMcoQ9GL00;oQ9GL00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Oo
oooo000Oooooo`;o00005_ooool3o`0002Oooooo00Co0000oc1]g?l`KMco00000olgKMX01?l0003o
@6oIod1_fOl00003odabe`04o`000?mHM]KoF7KFoeQfePCoIG_D0_mbP=83o`0000CoWYG:00?o0000
ojBFaonTU/L00_nTU/L00ol0003oZIS5ojVHa@02ojVHa@03o`000?n]VL;o[IW200;o[IW200Go0000
ok:J`?nbV/3o/Y[0o`000004okJL_@03o`000?niWK_o^Ifk00;o^Ifk00Go0000okbN^_nlW[[o_9jj
o`000004okjN^005o`000?o1WkOo`Ingol6O]ol000001?o3X;D00ol0003oa:6do`000002o`0000Co
aJ6d00?o0000olJQ/oo6XK<00_o6XK<00ol0003oaj:bo`000002olNR/P;o000000Gob::ao`000?o8
X[7o0000olRR/@02o`0000;ob::a00?o0000olRR/Ol000000oo9Xk82o`0000Cob:>b00Go0000olRT
/oo8Y;?ob:Bco`000004olRT]0;o00000oo6X[D01?l0003oaJ:folFR]_l00003olBS^003o`000?o2
XkWo`Z>i00;o`Z>i00Go0000ol6S^oo1Xk_o`J>ko`000003oknS_@05o`000?nmY;oo_JBookfT_ol0
00001?nkY<801Ol0003o^JC4okVTa?niY<Co000000Co]jG700Go0000okBUb_ndYL[o]:G:o`000004
ok6Vc@03o`000?n^Ym3o[ZO@00?o[ZO@00?o0000oj^Xe?n[Z=@00ol00003ohnBd`05o`000?n;TmKo
Ri?Foh^Ce_l000001On7U=T00ol0003oQ9GLohBEg002ohBEg003o`000?oooooooooo00;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Booooo`?o0000:_ooool01?l0003o<6gLoc1]g?l00003ocM]fP04o`000?m0KmWo@6oIo`00
00?oC7;G00Co0000oeQfe_mHM]KoF7KF1?mUNm@01?l0003oLX3Bog:0d_mbP=84o`000003oijEb_l0
003oY9K700?oY9K700Go0000ojVHaOnYV<GoZIS5o`000004ojfI`P03o`000?nbV/3o/Y[000;o/Y[0
00?o0000okJL_OnfW;d00_nfW;d00ol0003o^IfkokVM^`02okVM^`05o`000?nlW[[o_9jjokbN^_l0
00000onnW[P00ol0003o`Ingol6O]`02ol6O]`04o`000?o3X;Go`j2eol>P]@?o00000_o3X;D00ol0
003oaJ6dolFQ]002olFQ]003o`000?o6XK?oaZ6c00;oaZ6c0_l00003olNR/P07o`000?o8X[7ob::a
o`000?o8X[7o0000olRR/@02o`0000;ob::a00?o0000olRR/Ol000001?o9Xk801Ol0003ob:>bolRS
/_o8Xk;o000000Cob:Bc00?o0000olRT]?o8Y;@00_o8Y;@00ol0003ob:Ffo`000002o`0000?oaJ:f
00Go0000olBS^?o4XkSoa:>ho`000004ol:S^@05o`000?o1Xk_o`J>kol6S^ol000000onoXkd01Ol0
003o_JBookfT_onmY;oo000000Co^jC200Go0000okVTa?niY<Co^JC4o`000004okNUa`05o`000?nd
YL[o]:G:okBUb_l000000onaY/d00ol0003o[ZO@ojjWd003ojjWd003o`000?n[Z=CoZjSD00;oZjSD
00?o0000ojNYf?l000000_l00004oh^CeP03o`000?n7U=WoQiCI00?oQiCI00Go0000ohBEg?n4UMco
Q9GLo`000005ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo00oooooo0ol0000]ooooo`05o`000?l`KMco<6gLoc1]g?l000000_lgKMX01?l0
003o@6oIod1_fOl00003odabe`05o`000?mHM]KoF7KFoeQfe_l000000omUNm@01?l0003oLX3Bog:0
d_mbP=84ogn5d0?o00000onTU/L01Ol0003oZIS5ojVHaOnYV<Go000000Co[IW200?o0000ok:J`?nb
V/000_nbV/001Ol0003o]YbmokJL_OnfW;go000000Co^Ifk00?o0000okbN^_nlW[X00_nlW[X01Ol0
003o_YjhokjN^?nnW[So000000Co`Ing1?l000000oo1WkKo0000ol>P]@02ol>P]@03o`000?o5XKCo
aJ6d00;oaJ6d00?o0000olJQ/oo6XK<00_o6XK<00ol0003oaj:bolNR/P02olNR/P;o000000?ob::a
o`000?o8X[400_l000001?o8X[7o0000olRR/Oo8X[42o`000003olVS/_l0003obJ>b00;obJ>b0_l0
0002olRS/P03o`000?o8Y;?ob:Bc00;ob:Bc00Go0000olRT]?o8Y;Cob:Bdo`000004olRU]P;o0000
0_o5X[H01Ol0003oa:>holBS^?o4XkSo000000Co`Z>i00Go0000ol6S^oo1Xk_o`J>ko`000002oknS
_@03o`000?nmY;oo_JBo00;o_JBo00?o0000ok^T`_nkY<800_nkY<801Ol0003o^JC4okVTa?niY<Co
000000?o]jG700Go0000okBUb_ndYL[o]:G:o`000004ok6Vc@03o`000?n^Ym3o[ZO@00?o[ZO@00Go
0000oj^Xe?n[Z=CoZjSDo`000004ojNYf0?o00000_n;TmH00ol0003oQiCIohNDf@02ohNDf@03o`00
0?n4UMcoQ9GL00;oQ9GL00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Oooooo0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00cooooo0ol0000aooooo`;o000000Go<6gLo`000?lgKM[o
=fgJo`000003od1_f@05o`000?m<L]OoC7;Godabeol000000_mHM]H00ol0003oIG_DofEke002ofEk
e0?oLX3B00?o0000ogn5d?moQM000_moQM02ohZ9c@Co00000onYV<D00ol0003o[IW2ojfI`P02ojfI
`P03o`000?nbV/3o/Y[000;o/Y[000Go0000okJL_OnfW;go]Ybmo`000004okVM^`03o`000?nlW[[o
_9jj00;o_9jj00Go0000okjN^?nnW[So_Yjho`000002ol6O]`?o00001?o1WkH01Ol0003o`j2eol>P
]Oo3X;Go000000GoaJ6d00?o0000olJQ/oo6XK<00_l00003olNR/P04o`000?o7X[;oaj:bo`0000;o
b::a0_l000000oo8X[7o0000olRR/@02o`0000;obJ>b00Co0000olVS/_o9Xk;o00000_o9Y;<00ol0
003ob:>bo`000003olRT/`03o`000?o8Y;Cob:Bd00;ob:Bd00?o0000olRU]_o8YKH00_o8YKH01?l0
003ob:Ngo`000?l00004olBS^005o`000?o2XkWo`Z>iol:S^Ol000001?o1Xk/01?l0003o_j>moknS
_Ol00004okfT_`05o`000?nkY<;o^jC2ok^T`_l000000oniY<@00ol0003o]jG7okNUa`02okNUa`05
o`000?ndYL[o]:G:okBUb_l000000onaY/d00ol0003o[ZO@ojjWd003ojjWd005o`000?n[Z=CoZjSD
oj^Xe?l000001OnWZMP00ol0003oY:[KojBZf`03o`0000CoQiCI00?o0000ohBEg?n4UM`00_n4UM`0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool0
00Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000:
ooooo`?o0000=?ooool2o`0VZP;o00000olgKMX01?l0003o@6oIod1_fOl00003odabe`04o`000?mH
M]KoF7KFo`0000CoIG_D00Co0000og:0d_mbP=;oLX3B1?moQM000ol0003oRXW=ohZ9c@02ohZ9c@?o
000000?oZIS5o`000?n]VL800on]VL801Ol0003o/Y[0ok:J`?nbV/3o000000Co]Ybm00?o0000okVM
^oniWK/00_niWK/00ol0003o_9jjokbN^P02okbN^P03o`000?nnW[So000000Co00000_nnW[P00ol0
003o`Infol6O]P02ol6O]P05o`000?o3X;Go`j2eol>P]Ol000001Oo5XK@01Ol0003oaZ6co`000?o6
XK?o000000;oaj:b00Co0000olNR/_o7X[;oaj:b0ol000000oo8X[7o0000olRR/@02o`000007olVS
/_l0003obJ>bolVS/_l0003obJ>bo`000004olVT/`03o`000?o8Y;?ob:Bc00;ob:Bc00?o0000olRT
]?o8Y;@00_o8Y;@01Ol0003ob:FfolRU]_o8YKKo000000?ob:Ng0ol000000oo4XkSo0000ol:S^@03
ol:S^@05o`000?o1Xk_o`J>kol6S^ol000000onoXkd01Ol0003o_JBookfT_onmY;oo000000Co^jC2
00Go0000okVTa?niY<Co^JC4o`000003okNUa`05o`000?ndYL[o]:G:okBUb_l000001?naY/d00ol0
003o[ZO@ojjWd002ojjWd003o`000?n[Z=CoZjSD00;oZjSD00?o0000ojNYf?nWZMP00_nWZMP00ol0
003oY:[KojBZf`02ojBZf`03o`000?nP[=oo000000;o000000?oQiCIo`000?n4UM`00_n4UM`00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Co
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool0
0ol0003oooooooooo`06ooooo`?o0000>?ooool2o`0VZP05oc1]g?l0003o=fgJocM]f_l000000_m0
KmT01Ol0003oC7;Godabeom<L]Oo000000?oF7KF00Go0000ofEke?mUNmCoIG_Do`000003og:0dPCo
OhG@00?o0000ohZ9cOn:RLd00_n:RLd3oiB>bPWo000000?o/Y[0o`000?nfW;d00onfW;d00ol0003o
^IfkokVM^`02okVM^`03o`000?nlW[[o_9jj00Co00000_njW;X00ol0003o_YjhokjN^002okjN^003
o`000?o1WkKo`Inf00;o`Inf00?o0000ol>P]Oo3X;D00_o3X;D00ol0003oaJ6dolFQ]002olFQ]0;o
00000oo6XK<00ol0003oaj:bo`000002olNR/P03o`000?o8X[;ob::b00Go00000_o9Xk801?l0003o
bJ>bolVS/_o9Xk82o`0000CobJBc00Go0000olRT/oo8Y;?ob:Bco`000004olRT]003o`000?o8YKKo
b:Ff00;ob:Ff00Go0000olRW]oo8YkOob:Ngo`000002olVX^@?o00000oo2XkT01Ol0003o`J>kol6S
^oo1Xk_o000000;o_j>m00?o0000okfT_onmY;l00_nmY;l00ol0003o^jC2ok^T`P02ok^T`P04o`00
0?niY<Co^JC4o`0000Co]jG700Go0000okBUb_ndYL[o]:G:o`000003ok6Vc@03o`000?n^Ym3o[ZO@
00?o[ZO@00Go0000oj^Xe?n[Z=CoZjSDo`000004ojNYf003o`000?nTZ]_oY:[K00;oY:[K00?o0000
oj2/gonP[=l00onP[=l3o`0000;oQ9GL00?o0000ooooooooool01oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000looooo`;o02JZ0_l00000
1OlgKM[o0000od1_fOm0KmWo000000?oC7;G00Go0000oeQfe_mHM]KoF7KFo`000003ofEke005o`00
0?mbP=;oLX3Bog:0d_l000001?moQM04ohZ9c@CoU8k:1OnMTLL3ojFDa0ko00000_nfVk`01Ol0003o
^YbjokZL^_njW;[o000000Co_Yjh00?o0000ol6O]_o1WkH00_o1WkH00ol0003o`j2eol>P]@02ol>P
]@04o`000?o5XKCoaJ6dolFQ]0;o00001?o6XK<2o`0000?oaj:b00So0000olRR/_o8X[;o0000olRS
/_l0003ob:>bo`0000;obJ>b00Go0000olVS/_o9Xk;obJ>bo`000004olVT/`03o`000?o9YKCo0000
00;ob:Bc00?o0000olRT]?o8Y;@00_o8Y;@01Ol0003ob:FfolRU]_o8YKKo000000?ob:Ng00?o0000
olVX^Oo9Z;T00_o9Z;T00ol0003obJZko`000002o`0000Co`J>k00Co0000oknS_OnoXkgo00001?nm
Y;l01Ol0003o^jC2ok^T`_nkY<;o000000?o^JC400?o0000okNUaongYLL00_ngYLL01?l0003o]:G:
okBUb_l00004ok6Vc@03o`000?n^Ym3o[ZO@00;o[ZO@00Go0000oj^Xe?n[Z=CoZjSDo`000005ojNY
f005o`000?nTZ]_oY:[KojBZfol000001_nP[=l00ol0003oWJgSoif]h`02o`0000_ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo00Ko
02JZo`0V[?l09Zco0000ocM]f_l00002od1_f@05o`000?m<L]OoC7;Godabeol000000_mHM]H01Ol0
003oIG_DofEke?mUNmCo000000?oLX3B00?o0000ogn5d?moQM000_moQM001Ol0003oRXW=ohZ9cOn:
RLgo000000?oU8k:00?o0000oifAaonMTLL00_nMTLL4ojFDa0GoZiO11OnaVKl5okJK_005o`000?nj
W;[o^YbjokZL^_l000001?nnW[P00ol0003o`Infol6O]P02ol6O]P03o`000?o3X;Go`j2e00;o`j2e
00Ko0000olFQ]?l0003o0000olFQ]?l00004olJQ/`05o`000?o7X[;oaj:bolNR/_l000000_o8X[80
1_l0003ob:>bolRS/_l0003ob:>bo`0000?obJ>b00Co0000olVS/_o9Xk;o00001?o9Y;<01_l0003o
bJFdolVU]?l0003ob:Bco`0000?ob:Bd00?o0000olRU]_o8YKH00_o8YKH01Ol0003ob:NgolRW]oo8
YkOo000000?obJRi00?o0000olVZ^oo9Z[/00_o9Z[/3o`000003ol6S^ol0003o_j>m00;o_j>m00Go
0000okfT_onmY;oo_JBoo`000004ok^T`P05o`000?niY<Co^JC4okVTa?l000000ongYLL01Ol0003o
]:G:okBUb_ndYL[o000000?o/JK=00?o0000ojjWd?n^Ym000on^Ym001Ol0003oZjSDoj^Xe?n[Z=Co
000000CoYjWH00Go0000ojBZfonTZ]_oY:[Ko`000006oj2/g`05o`000?nM[N?oWJgSoif]hol00000
3Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo0004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014ooooo`04o`0VZ_l09Zco02J/o`0V[0;o
000000?o@6oIo`000?m<L]L00_m<L]L01?l0003oF7KFoeQfe_l00003ofEke005o`000?mbP=;oLX3B
og:0d_l000001?moQM001Ol0003oRXW=ohZ9cOn:RLgo000000?oU8k:00?o0000oifAaonMTLL00_nM
TLL01Ol0003oYIC4ojFDa?nUU<Co000000CoZiO100?o0000ok6I_onaVKl00_naVKl00ol0003o]Y^l
okJK_002okJK_005o`000?njW;[o^YbjokZL^_l000001?nnW[P00ol0003o`Infol6O]P02ol6O]P03
o`000?o3X;Go`j2e00;o`j2e0_l00003olFQ]003o`000?o6XK?oaZ6c00;oaZ6c00Go0000olNR/_o7
X[;oaj:bo`000002olRR/P06o`000?o8Xk;ob:>bo`000?o8Xk;o00000oo9Xk801Ol0003obJ>bo`00
0?o9Y;?o000000;obJBc00?o0000olVU]?o9YK@00_o9YK@00ol0003ob:BdolRT]002olRT]005o`00
0?o8YKKob:FfolRU]_l000000oo8YkL00ol0003obJRiolVX^@02olVX^@03o`000?o9Z[_obJZk00;o
bJZk00?o0000olR/_Oo8[;d01Ol00004okfT_`03o`000?nkY<;o^jC200;o^jC200Co0000okVTa?ni
Y<Co00001?ngYLL01Ol0003o]:G:okBUb_ndYL[o000000?o/JK=00?o0000ojjWd?n^Ym000_n^Ym00
1Ol0003oZjSDoj^Xe?n[Z=Co000000CoYjWH00?o0000ojBZfonTZ]/00_nTZ]/00ol0003oX:cOoj2/
g`03oj2/g`05o`000?nM[N?oWJgSoif]hol000003oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Kooooo000Nooooo`;o0000Aoooool00ol09Z[o02J/o`0V[002o`0//P;o00000om<
L]L01?l0003oF7KFoeQfe_l00004ofEke005o`000?mbP=;oLX3Bog:0d_l000000omoQM001Ol0003o
RXW=ohZ9cOn:RLgo000000?oU8k:00?o0000oifAaonMTLL00_nMTLL01Ol0003oYIC4ojFDa?nUU<Co
000000CoZiO100?o0000ok6I_onaVKl00_naVKl00ol0003o]Y^lokJK_002okJK_005o`000?njW;[o
^YbjokZL^_l000001?nnW[P00ol0003o`Infol6O]P02ol6O]P04o`000?o3X;Go`j2eol>P]@;o0000
1?o5XK@02Ol0003oaZ6colJQ/oo6XK?o0000olJR/ol0003oaj:bo`000003olRR/P06o`000?o8Xk;o
b:>bo`000?o8Xk;o00000oo9Xk82o`0000;obJBc00?o0000olVT/ol000001Oo9YK@01Ol0003ob:Bd
olRT]?o8Y;Co000000Cob:Ff00Go0000olRW]oo8YkOob:Ngo`000003olVX^@03o`000?o9Z[_obJZk
00;obJZk00?o0000olR/_Oo8[;d00_o8[;d00ol0003ob:k0olR^`002o`0000?o_JBo00Go0000ok^T
`_nkY<;o^jC2o`000003okVTa005o`000?ngYLOo]jG7okNUaol000000ondYLX00ol0003o/JK=ok6V
c@02ok6Vc@03o`000?n^Ym3o[ZO@00;o[ZO@00Co0000oj^Xe?n[Z=Co00001OnWZMP01Ol0003oY:[K
ojBZfonTZ]_o000000GoX:cO00Go0000oif]honM[N?oWJgSo`00000@ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0AOooool00ol09Z[o
02J/o`0V[002o`0//P05od1_fOl0003oC7;Godabeol000000omHM]H01Ol0003oIG_DofEke?mUNmCo
000000?oLX3B00Go0000ogn5d?moQM3oOhG@o`000004ohZ9c@04o`000?nDS/[oU8k:o`0000CoWI77
00Go0000ojFDa?nUU<CoYIC4o`000004oj^G`@03o`000?naVKoo/IVo00;o/IVo00?o0000okJK_?nf
Vk`00_nfVk`01Ol0003o^YbjokZL^_njW;[o000000Go_Yjh00Go0000ol6O]_o1WkKo`Info`000002
ol>P]@03o`000?o2X;Ko000000GoaJ6d00?o0000olJQ/ol000000_o6X[<00ol0003oaj:bo`000002
olRR/P04o`000?o8Xk;ob:>bo`0000;ob:>b00?o0000olVS/_o9Xk800_l00003olVT/`03o`000?o9
Y;?o000000CobJFd00?o0000olZW]Ol000000_o8Y;@00ol0003ob:FfolRU]P02olRU]P05o`000?o8
YkOob:NgolRW]ol000000oo9Z;T00ol0003obJZkolVZ^`02olVZ^`05o`000?o8[;gob:bmolR/_Ol0
00000oo8[/000ol0003ob;73o`000002o`0000Co^jC200Co0000okVTa?niY<Co00001?ngYLL01Ol0
003o]:G:okBUb_ndYL[o000000?o/JK=00?o0000ojjWd?n^Ym000_n^Ym001Ol0003oZjSDoj^Xe?n[
Z=Co000000CoYjWH00Go0000ojBZfonTZ]_oY:[Ko`000005oj2/g`05o`000?nM[N?oWJgSoif]hol0
00004_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`00
0?oooooooooo04Gooooo00?o02JZo`0V[?l09Z`00_l0;;82o`000003odabeol0003oF7KF00;oF7KF
00Go0000ofEke?mUNmCoIG_Do`000003og:0dP05o`000?moQM3oOhG@ogn5d?l000001?n:RLd01Ol0
003oU8k:oiB>b_nDS/[o000000CoWI7700Go0000ojFDa?nUU<CoYIC4o`000004oj^G`@05o`000?na
VKoo/IVook6I_ol000001?nfVk`01Ol0003o^YbjokZL^_njW;[o000000Go_Yjh00Oo0000ol6O]_o1
WkKo`Info`000?o3X;Go000000;o`Z2f00?o0000olFQ]?o5XK@00oo5XK@2o`0000CoaZ:c0_l00002
olRR/P04o`000?o8Xk;ob:>bo`0000;ob:>b00Go0000olVS/_l0003obJFdo`000004olVT/`03o`00
0?o9YKCobJFd00?obJFd00Ko0000olZW]Oo:YkGo0000olRT]?l00003olRU]P05o`000?o8YkOob:Ng
olRW]ol000001?o9Z;T01Ol0003obJZkolVZ^oo9Z[_o000000Cob:bm00Co0000olR^`?o8[/3o0000
1?o8/L<3o`0000;o^jC200Co0000okVTa?niY<Co00000ongYLL01Ol0003o]:G:okBUb_ndYL[o0000
00Co/JK=00?o0000ojjWd?n^Ym000_n^Ym001?l0003oZjSDoj^Xe?l00004ojNYf005o`000?nTZ]_o
Y:[KojBZfol000001OnP[=l01Ol0003oWJgSoif]honM[N?o000001Cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`05ooooo`008_ooool00ol0003oooooooooo`14ooooo`05o`000?l0
9Z[o02J/o`0V[?l0;;800_l0=[/00ol0003oC7;Go`000002oeQfeP05o`000?mUNmCoIG_DofEke?l0
00000ombP=801Ol0003oOhG@ogn5d?moQM3o000000CoRXW=00Go0000oiB>b_nDS/[oU8k:o`000004
oifAa`05o`000?nUU<CoYIC4ojFDa?l000001?n[Ul401Ol0003o/IVook6I_onaVKoo000000Co]Y^l
00?o0000okZL^_njW;X00_njW;X00ol0003o_YjhokjN^002okjN^004o`000?o1WkKo`Infol6O]P;o
00001?o2X;H00ol0003oaJ6dolFQ]002olFQ]003o`000?o6X[?oaZ:c00?oaZ:c00Go0000olNS]?l0
003ob::bo`000002olRS/P03o`000?o8Xk;ob:>b00;o00000_o9YK@00ol0003obJBcolVT/`02olVT
/`03o`000?o9YKCobJFd00;obJFd00?o0000olZW]Oo:YkD00_o:YkD00ol0003ob:FfolRU]P02olRU
]P05o`000?o8YkOob:NgolRW]ol000000oo9Z;T00ol0003obJZkolVZ^`02olVZ^`05o`000?o8[;go
b:bmolR/_Ol000000oo8[/000ol0003ob;73olRa``02olRa``03o`000?o8/lKob;?600Co000000?o
^JC4o`000?ngYLL00_ngYLL01Ol0003o]:G:okBUb_ndYL[o000000?o/JK=00?o0000ojjWd?n^Ym00
0_n^Ym001Ol0003oZjSDoj^Xe?n[Z=Co000000?oYjWH00?o0000ojBZfonTZ]/00_nTZ]/00ol0003o
X:cOoj2/g`02oj2/g`05o`000?nM[N?oWJgSoif]hol000005_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Gooooo000Sooooo`;o0000AOooool01Ol0003o02JZo`0V[?l0003o02bb
00?o03Jk0_l000000omHM]Ko0000ofEke002ofEke005o`000?mbP=;oLX3Bog:0d_l000001?moQM00
1Ol0003oRXW=ohZ9cOn:RLgo000000?oU8k:00?o0000oifAaonMTLL00_nMTLL01Ol0003oYIC4ojFD
a?nUU<Co000000CoZiO100Go0000ok6I_onaVKoo/IVoo`000004okJK_003o`000?njW;[o^Ybj00;o
^Ybj00?o0000okjN^?nnW[P00_nnW[P00ol0003o`Infol6O]P02o`0000Go`Z2f00?o0000olFQ]?o5
XK@00_o5XK@00ol0003oaZ:colJR/`02olJR/`04o`000?o7XkCoaj>dolNS]0?o000000?ob:>bo`00
0?o8Xk800_l00003olVU]007o`000?o9Y;?obJBcolVT/ol0003obZJeo`000002olVU]003o`000?o:
YkGobZNe00?obZNe0_l00002olRU]P05o`000?o8YkOob:NgolRW]ol000001?o9Z;T01Ol0003obJZk
olVZ^oo9Z[_o000000Cob:bm00Co0000olR^`?o8[/3o00001?o8/L<00ol0003ob;?6olRcaP02olRc
aP03o`000?o7]/[oakK:00?o00000_ngYLL01?l0003o]:G:okBUb_l00004ok6Vc@05o`000?n^Ym3o
[ZO@ojjWd?l000000on[Z=@00ol0003oYjWHojNYf002ojNYf005o`000?nTZ]_oY:[KojBZfol00000
1?nP[=l01Ol0003oWJgSoif]honM[N?o000001Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`05ooooo`009Oooool00ol0003oooooooooo`13ooooo`;o000000?o02J/o`000?l0;;80
0_l0=[/2o`13a@;o00000omUNm@00ol0003oLX3Bog:0dP02og:0dP05o`000?moQM3oOhG@ogn5d?l0
00000on:RLd01Ol0003oU8k:oiB>b_nDS/[o000000CoWI7700Go0000ojFDa?nUU<CoYIC4o`000004
oj^G`@05o`000?naVKoo/IVook6I_ol000001OnfVk`01Ol0003o^YbjokZL^_njW;[o000000Co_Yjh
00Go0000ol6O]_l0003o_j2ho`000005ol:P]P07o`000?o5XKCoaJ6dolFQ]?l0003oaJ:eo`000003
olJR/`05o`000?o7XkCoaj>dolNS]?l000000_o8Y;@3o`000003olRT]?l0003obJFd00?obJFd00?o
0000olVT/ol000000_o:Y[D01?l0003obJFdolVU]?l00004olZW]@06o`000?o;ZKOobjVgo`000?o8
YKKo00000oo8YkL01Ol0003obJRiolVX^Oo9Z;Wo000000CobJZk00Go0000olR/_Oo8[;gob:bmo`00
0003olR^`003o`000?o8/L?ob;7300;ob;7300Go0000olRca_o8/lKob;?6o`000003olNfbP03o`00
0?o6^Lkoa[W>00Co000000?o]:G:o`000?naY/d00_naY/d00ol0003o[ZO@ojjWd002ojjWd004o`00
0?n[Z=CoZjSDo`0000CoYjWH00Go0000ojBZfonTZ]_oY:[Ko`000005oj2/g`04o`000?nM[N?oWJgS
o`0001Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`009_ooool00ol0
003oooooooooo`13ooooo`;o000000?o02J/o`0//_l0;;800_l0=[/2o`13a@05oeQfe_l0003oIG_D
ofEke?l000001?mbP=801Ol0003oOhG@ogn5d?moQM3o000000?oRXW=00Go0000oiB>b_nDS/[oU8k:
o`000004oifAa`05o`000?nUU<CoYIC4ojFDa?l000001?n[Ul400ol0003o/IVook6I_`02ok6I_`03
o`000?nfVkco]Y^l00;o]Y^l00Go0000okZL^_njW;[o^Ybjo`000004okjN^0;o00000_noX;P00ol0
003o`Z2fol:P]P03ol:P]P04o`000?o5XKCoaJ6do`0000;oaJ:e00Co0000olJR/oo6X[?o00001?o7
Xk@01Ol0003ob:BdolRT]?o8Y;Co000000;ob:Bd00?o0000olVU]?o9YK@00_o9YK@00ol0003obJBc
o`000002olZV]@03o`000?o9YKCo000000GobZNe00Go0000ol^Y]oo;ZKOobjVgo`000003olRW]`03
o`000?o9Z;WobJRi00;obJRi00Go0000olVZ^oo9Z[_obJZko`000004olR/_@04o`000?o8[/3ob:k0
o`0000Cob;7300Go0000olRca_o8/lKob;?6o`000003olNfbP03o`000?o6^Lkoa[W>00;oa[W>00?o
0000olFld_o5_=800ol00002ok6Vc@05o`000?n^Ym3o[ZO@ojjWd?l000000on[Z=@01Ol0003oYjWH
ojNYf?nWZMSo000000?oY:[K00?o0000oj2/gonP[=l00onP[=l01?l0003oWJgSoif]hol0000Koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000oooooooo
ool0@oooool01Ol0003o02J/o`0V[?l0;;;o000000;o03Jk0_l0@lD2o`0000;oIG_D00Go0000og:0
d_mbP=;oLX3Bo`000003ogn5d005o`000?n:RLgoRXW=ohZ9cOl000000onDS/X00ol0003oWI77oifA
a`02oifAa`05o`000?nUU<CoYIC4ojFDa?l000001?n[Ul400ol0003o/IVook6I_`02ok6I_`03o`00
0?nfVkco]Y^l00;o]Y^l00Go0000okZL^_njW;[o^Ybjo`000003okjN^0;o00001?noX;P00ol0003o
`Z2fol:P]P02ol:P]P04o`000?o5XKCoaJ6do`0000?oaJ:e00?o0000olJR/ol000000oo7Xk@00ol0
003ob:BdolRT]002olRT]004o`000?o8Y;Cob:Bdo`0000CobJFd0_l00004olZV]@;o00001?o:YkD0
0ol0003objVgol^Y]`02ol^Y]`;o00000_o8YkL01Ol0003obJRiolVX^Oo9Z;Wo000000CobJZk00Go
0000olR/_Oo8[;gob:bmo`000003olR^`005o`000?o8/L?ob;73olRa`ol000001?o8/lH01?l0003o
akK:olNfb_l00004olJicP05o`000?o5_=;oaKcBolFld_l000000_o3`=L4o`0000;o[ZO@00Co0000
oj^Xe?n[Z=Co00001?nWZMP01Ol0003oY:[KojBZfonTZ]_o000000CoX:cO00Co0000oif]honM[N?o
00007?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Xooooo`;o0000
A?ooool01?l0003o02J/o`000?l0;;82o`0f^`07o`000?l0@lGo2e;>o`]Bc_l0003oIG_Do`000003
og:0dP05o`000?moQM3oOhG@ogn5d?l000000on:RLd01Ol0003oU8k:oiB>b_nDS/[o000000CoWI77
00Go0000ojFDa?nUU<CoYIC4o`000004oj^G`@03o`000?naVKoo/IVo00;o/IVo00?o0000okJK_?nf
Vk`00_nfVk`01_l0003o^YbjokZL^_njW;[o0000okjN^0;o000000?o_9nko`000?noX;P00onoX;P0
0ol0003o`Z2fol:P]P03ol:P]P;o00001?o5X[D00ol0003oaZ:co`000003olNS]005o`000?o8Y;Co
b:BdolRT]?l000000oo8Y;@01?l0003obJFdolVU]?o9YK@2o`0000GobZJe00?o0000olZW]Oo:YkD0
0oo:YkD01Ol0003objVgol^Y]oo;ZKOo000000;oc:bi00?o0000olRW]ol000000oo9Z;T01Ol0003o
bJZkolVZ^oo9Z[_o000000?ob:bm00Go0000olR^`?o8[/3ob:k0o`000004olRa``05o`000?o8/lKo
b;?6olRca_l000000oo7]/X01Ol0003oa[W>olJic_o6^Lko000000?oaKcB00?o0000ol?0eoo3`=L0
0_o3`=L00ol0003o`L?Lol73g007o`0000;oYjWH00Go0000ojBZfonTZ]_oY:[Ko`000004oj2/g`04
o`000?nM[N?oWJgSo`0001kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04oooo
o`00:_ooool00ol0003oooooooooo`12ooooo`04o`000?l09Zco0000o`0//P;o03Jk0_l0@lD3o`]B
cP;o00000_mbP=801Ol0003oOhG@ogn5d?moQM3o000000?oRXW=00Go0000oiB>b_nDS/[oU8k:o`00
0004oifAa`05o`000?nUU<CoYIC4ojFDa?l000001?n[Ul400ol0003o/IVook6I_`02ok6I_`03o`00
0?nfVkco]Y^l00;o]Y^l00Co0000okZL^_njW;[o^Ybj0_l00003okbO^`03o`000?noX;So_j2h00;o
_j2h00?o0000ol:P]_o2X;H00oo2X;H00ol0003oaJ:eolFR]@04olFR]@;o00000oo7Xk@01Ol0003o
b:BdolRT]?o8Y;Co000000?ob:Bd00Ko0000olVU]?l0003o0000olZW]_l00005olZV]@03o`000?o:
YkGobZNe00;obZNe00?o0000ol^Y]oo;ZKL00_o;ZKL01Ol0003oc:biolb/^Oo<[;Wo000000CobJRi
00Go0000olVZ^oo9Z[_obJZko`000003olR/_@05o`000?o8[/3ob:k0olR^`?l000000oo8/L<00ol0
003ob;?6olRcaP02olRcaP04o`000?o7]/[oakK:o`0000Coa[W>00Co0000olFld_o5_=;o00001?o3
`=L01Ol0003o`L?Lol73g?o1`mco000000;o_/KQ00Co0000ok[9i_njbNKo^/WV1?l000000onTZ]_o
0000oj2/g`03oj2/g`04o`000?nM[N?oWJgSo`00023ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`04ooooo`00:oooool00ol0003oooooooooo`13ooooo`05o`0V[?l0003o02bbo`0f
^ol000000_l0@lD2o`]BcP;o:F;D0_l000001OmbP=;o0000ogn5d?moQM3o000000CoRXW=00Co0000
oiB>b_nDS/[o00001?nMTLL01Ol0003oYIC4ojFDa?nUU<Co000000CoZiO100?o0000ok6I_onaVKl0
0_naVKl00ol0003o]Y^lokJK_002okJK_003o`000?njW;[o^Ybj00;o00001OnlWk/00ol0003o_j2h
oknP^002oknP^003o`000?o2X;Ko`Z2f00;o`Z2f00?o0000olFR]Oo5X[D01?o5X[D00ol0003oaZBf
o`000002olNS]005o`000?o8Y;Cob:BdolRT]?l000000oo8Y;@2o`0000?obZNf00?o0000olZV]Oo:
Y[D00_o:Y[D00ol0003objRgo`000003olZW]@05o`000?o;ZKOobjVgol^Y]ol000001?o<[;T2o`00
00;obJRi00Go0000olVZ^oo9Z[_obJZko`000003olR/_@05o`000?o8[/3ob:k0olR^`?l000001?o8
/L<01Ol0003ob;?6olRca_o8/lKo000000?oakK:00Go0000olJic_o6^Lkoa[W>o`000003olFldP05
o`000?o3`=Oo`l3Gol?0eol000000oo1`m`01?l0003o_/KQokk6hOl00003ok[9iP04o`000?nfc>_o
]/c[okK<j`Co00000_nP[=l01?l0003oWJgSoif]hol0000Rooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@oooool01_l0003o02bbo`00
0?l0=[_o0000o`13a@?o2e;>1?lYH]@2o`0000;oOhG@00Go0000ohZ9cOn:RLgoRXW=o`000003oiB>
bP03o`000?nMTLOoWI7700;oWI7700Go0000ojFDa?nUU<CoYIC4o`000004oj^G`@05o`000?naVKoo
/IVook6I_ol000001?nfVk`3o`000003okNM__l0003o_9nk00Co_9nk00?o0000oknP^?noX;P00_no
X;P01ol0003o`Z2fol:P]_o2X;Ko0000ol>R^?l000001?o5X[D01?l0003oaZBfolJT]_o6Y;H2o`00
00Cob:Bd00?o0000olRT]?o8Y;@00_l00004olZW]P05o`000?o:Y[GobZJeolZV]Ol000000oo;Z;L0
0ol0003obZNeo`000004ol^Y]`05o`000?o<[;Woc:biolb/^Ol000000_o=[k`00ol0003obJRio`00
0003olVZ^`05o`000?o8[;gob:bmolR/_Ol000000oo8[/001Ol0003ob;73olRa`oo8/L?o000000?o
b;?600Go0000olNfb_o7]/[oakK:o`000003olJicP05o`000?o5_=;oaKcBolFld_l000000oo3`=L0
1Ol0003o`L?Lol73g?o1`mco000000;o_/KQ00Go0000ok[9i_njbNKo^/WVo`000003okK<j`03o`00
0?nac^oo/Lk_00;o/Lk_1Ol0000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
1?ooool002gooooo0_l00014ooooo`06o`000?l0;;;o03Jko`0f^ol0003o04?50_l;D/h01?l0003o
:F;DobURe?lYH]@2odI`f003o`000?moQM3o000000?oRXW=00Go0000oiB>b_nDS/[oU8k:o`000004
oifAa`05o`000?nUU<CoYIC4ojFDa?l000001?n[Ul401Ol0003o/IVook6I_onaVKoo000000?o]Y^l
0_l00004okNM_P03o`000?nlWk_o_9nk00;o_9nk00?o0000oknP^?noX;P00_noX;P01?l0003o`Z2f
ol:P]_l00003ol>R^005o`000?o5X[GoaJ:eolFR]Ol000001?o6Y;H3o`000003olRT]?l0003o0000
00;o000000?obJJfo`000?o:YkH01?o:YkH00ol0003obZJeo`000004ol^X]`03o`000?o:YkGo0000
00?objVg00?o0000olb/^Oo<[;T00_o<[;T01?l0003ocJnlolf__?o=[k`2o`0000;obJZk00Go0000
olR/_Oo8[;gob:bmo`000003olR^`005o`000?o8/L?ob;73olRa`ol000001?o8/lH01?l0003oakK:
olNfb_l00003olJicP05o`000?o5_=;oaKcBolFld_l000000oo3`=L01Ol0003o`L?Lol73g?o1`mco
000000;o_/KQ00Go0000ok[9i_njbNKo^/WVo`000003okK<j`03o`000?nac^oo/Lk_00;o/Lk_00Co
0000oj_?lon[co?o00009_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo
000_ooooo`03o`000?oooooooooo04;ooooo00Ko0000o`0//_l0=[_o0000o`13aOl00002o`]BcPCo
:F;D0om6L=P3o`000003ohZ9cOl0003oU8k:00;oU8k:00?o0000oifAaonMTLL00_nMTLL01Ol0003o
YIC4ojFDa?nUU<Co000000CoZiO100Co0000ok6I_onaVKoo/IVo1?l000000onbW<7o]ifnokNM_P03
okNM_P03o`000?nlWk_o_9nk00?o_9nk00?o0000oknP^?noX;P00_noX;P2o`0000Co`j:h00Co0000
olFR]Oo5X[Go00001Oo6Y;H00ol0003oajFfolNU]P02o`0000CobJJf00?o0000olZW]_o:YkH00oo:
YkH2o`0000KobjRg00Go0000ol^Y]oo;ZKOobjVgo`000004olb/^@03o`000?o=[kcocJnl00;ocJnl
00Go0000oljb_ol0003obJZko`000003olR/_@05o`000?o8[/3ob:k0olR^`?l000000oo8/L<01Ol0
003ob;?6olRca_o8/lKo000000?oakK:00Go0000olJic_o6^Lkoa[W>o`000002olFldP05o`000?o3
`=Oo`l3Gol?0eol000000oo1`m`01?l0003o_/KQokk6hOl00003ok[9iP03o`000?nfc>_o]/c[00;o
00000onac^l2o`000003oj_?lol0003o000002Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`12ooooo`;o000000?o03Jko`000?l0@lD0
0_l;D/h01Ol0003o:F;DobURe?lYH]Co000000;oAW3H0omPO=P4o`000003oiB>b_l0003oWI7700?o
WI7700Go0000ojFDa?nUU<CoYIC4o`000004oj^G`@03o`000?naVKoo000000;o00001?nbW<400ol0
003o]ifnokNM_P02okNM_P03o`000?nlWk_o_9nk00?o_9nk00?o0000oknP^?noX;P00_noX;P00ol0
003o`j:hol>R^004ol>R^003o`000?o5X[Go000000CoaZBf00?o0000olNU]_o7YKH00_o7YKH00ol0
003obJJfolVV]P02olVV]P03o`000?o:YkKobZNf00;obZNf0_l00006ol^X]`;o00000oo;ZKL01Ol0
003oc:biolb/^Oo<[;Wo000000CocJnl00Co0000oljb_oo>/[ooc[:o0_l00002olR/_@05o`000?o8
[/3ob:k0olR^`?l000000oo8/L<00ol0003ob;?6olRcaP02olRcaP04o`000?o7]/[oakK:o`0000?o
a[W>00Go0000olFld_o5_=;oaKcBo`000002ol?0e`05o`000?o1`mco`L?Lol73g?l000000_nna^40
1Ol0003o^/WVok[9i_njbNKo000000;o]/c[00?o0000ok7>konac^l00_nac^l01?l0003oZloco`00
0?l0000[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0037ooooo0_l0
0014ooooo`04o`000?l0=[_o0000o`13a@;o2e;>00Co0000obURe?lYH]Co:F;D0om6L=P3of1lf0?o
MXKE4Ol00002oj^Ia@Ko/Yc100?o0000okNM__ngWKh00_ngWKh00ol0003o_9nkokbO^`02okbO^`04
o`000?noX;So_j2hoknP^0;o00001oo3X[P00ol0003oaZBfolJT]P03olJT]P03o`000?o7YKKoajFf
00;oajFf00?o0000olVV]_o9Y[H00_o9Y[H01ol0003obZNfolZW]_o:YkKo0000ol^Y^?l000001Oo;
Z;L01_l0003oc:biolb/^Ol0003objVgo`0000Coc:bi00Go0000olf__?o=[kcocJnlo`000004oljb
_`05o`000?o?]l;o0000olR/_Ol000000oo8[/001Ol0003ob;73olRa`oo8/L?o000000?ob;?600Go
0000olNfb_o7]/[oakK:o`000002olJicP05o`000?o5_=;oaKcBolFld_l000000_o3`=L01Ol0003o
`L?Lol73g?o1`mco000000;o_/KQ00Go0000ok[9i_njbNKo^/WVo`000002okK<j`04o`000?nac^oo
/Lk_ok7>k`;o000000?oZloco`000?ooool0;?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo000cooooo`03o`000?oooooooooo04;ooooo0_l000001?l0@lGo0000o`]Bc_l0
0003obURe004o`000?m6L=SoAW3Ho`0000?oH7cH0omfQ]D5ohR=dPCoUY;=1OnRU/T5oj^Ia@Go/Yc1
00?o0000okNM__ngWKh00_ngWKh00ol0003o_9nkokbO^`02okbO^`04o`000?noX;So_j2ho`0000;o
`::k00?o0000ol>R^?o3X[P01?o3X[P2o`0000?oaZBf00?o0000olNU]_o7YKH00oo7YKH00ol0003o
bJJfolVV]P02olVV]P04o`000?o:YkKobZNfo`0000;objVh00?o0000ol^X]oo;Z;L00_o;Z;L01ol0
003oc:biolb/^Oo<[;Wo0000ol^Y]ol000000oo<[;T00ol0003ocJnlolf__002olf__005o`000?o>
/[ooc[:ooljb_ol000000oo?]l82o`0000;ob:k000Go0000olRa`oo8/L?ob;73o`000003olRcaP05
o`000?o7]/[oakK:olNfb_l000000oo6^Lh01?l0003oaKcBolFld_l00003ol?0e`04o`000?o1`mco
`L?Lo`0000;o_/KQ00?o0000ok[9i_njbNH00_l000000onfc>_o0000o`000003ok7>k`04o`000?n[
co?o0000o`0002oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?oo
ool00ol0003oooooooooo`12ooooo`06o`0f^ol0003o04?5o`000?l;D/ko00000olYH]@3odI`f0?o
H7cH00Co0000ogJ6eOmfQ]GoMXKE1On8SM84oiJBc@GoXYK91?n[VLD00ol0003o/Yc1ok:L`@02ok:L
`@03o`000?ngWKko]ifn00;o]ifn00?o0000okbO^onlWk/00onlWk/2o`0000?o`::k00?o0000ol>R
^?o3X[P00oo3X[P01?l0003oa:BiolBT^Ol00002olJT]P03o`000?o7YKKoajFf00;oajFf00?o0000
olVV]_o9Y[H00oo9Y[H00ol0003obZNfo`000003ol^Y^005o`000?o;Z;OobjRgol^X]ol000001Oo<
[;T00ol0003oc:biolb/^@02olb/^@05o`000?o=[kcocJnlolf__?l000000oo>/[l00ol0003ockO2
olng`P02olng`P05o`000?o@_<Ko0000olR^`?l000000_o8/L<00ol0003ob;?6olRcaP02olRcaP04
o`000?o7]/[oakK:o`0000?oa[W>00Go0000olFld_o5_=;oaKcBo`000002ol?0e`04o`000?o1`mco
`L?Lo`0000;o_/KQ00Co0000ok[9i_njbNKo00000_nfc>/01?l0003o/Lk_ok7>konac^l2o`000003
oj_?lol0003ooooo037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00
=Oooool00ol0003oooooooooo`12ooooo`03o`000?l0@lGo04?500;o2e;>00Co0000obURe?lYH]Co
00000_m6L=P01?l0003oH7cHof1lf?l00003ogJ6e@03o`000?n8SM;oR8gB00;oR8gB00Go0000oiJB
cOnFT/goUY;=o`000004oj:Fb@05o`000?n[VLGoZiW5oj^IaOl000001OnbW<400ol0003o]ifnokNM
_P02okNM_P03o`000?nlWk_o_9nk00;o_9nk00?o0000ol2R^oo0X[/00oo0X[/01Ol0003o`j:hol>R
^?o3X[So000000Coa:Bi00?o0000olJT]_l000001?o7YKH00ol0003obJJfolVV]P03olVV]P;o0000
1Oo;ZKP00ol0003objRgo`000006olb/^@05o`000?o<[;Woc:biolb/^Ol000001?o=[k`01Ol0003o
c[:ooljb_oo>/[oo000000?ockO200Co0000om2la_o@_<Kod;c60ol000000oo8/L?o0000olRcaP02
olRcaP05o`000?o7]/[oakK:olNfb_l000000_o6^Lh01Ol0003oaKcBolFld_o5_=;o000000;o`l3G
00Co0000ol73g?o1`mco00000_nna^401?l0003o^/WVok[9i_l00002okK<j`06o`000?nac^oo/Lk_
ok7>kol0003oZloc0_l0000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool003Kooooo0_l00013ooooo`05o`000?l0@lGo0000o`]Bc_l000000olYH]@00ol0003oAW3HodI`
f003of1lf004o`000?mfQ]GoMXKEo`0000CoR8gB00Go0000oiJBcOnFT/goUY;=o`000004oj:Fb@03
o`000?n[VLGoZiW500;oZiW500?o0000ok:L`OnbW<400_nbW<400ol0003o]ifnokNM_P02okNM_P04
o`000?nlWk_o_9nkokbO^`;o00001_o0X[/01?l0003o`j:hol>R^?l00005olBT^@Co00000_o7YKH0
0ol0003obJJfolVV]P04o`0000KobjVh0_l00006olb/^@05o`000?o=/;co0000olb/^Ol000001?o=
[k`01Ol0003oc[:ooljb_oo>/[oo000000?ockO200?o0000om2la_o@_<H00_o@_<H00ol0003odL7;
om71b`02o`0000?ob;?600Co0000olNfb_o7]/[o00000_o6^Lh01Ol0003oaKcBolFld_o5_=;o0000
00;o`l3G00Co0000ol73g?o1`mco00000_nna^401?l0003o^/WVok[9i_l00002okK<j`03o`000?na
c^oo/Lk_00;o000000?oZloco`000?ooool0=Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00?ooooo000hooooo`03o`000?oooooooooo047ooooo00Go0000o`13aOl0003o2e;>o`00
0002obURe004o`000?m6L=SoAW3Ho`0000;oH7cH00Go0000ogJ6eOmfQ]GoMXKEo`000004ohR=dP05
o`000?nFT/goUY;=oiJBcOl000001?nRU/T01Ol0003oZiW5oj^IaOn[VLGo000000Co/Yc100?o0000
okNM__ngWKh00_ngWKh01?l0003o_9nkokbO^ol00002okbR_P03o`000?o0X[_o`::k00?o`::k00?o
0000ol>R^?l000001_o4Y;T01?l0003oajNiolNW^Oo7YkT5o`0000?obJVi00?o0000ol^Y^?o;ZKP0
0oo;ZKP2o`0000Koc:bi00Ko0000olf`_?o=/;co0000olb/^Ol00003olf__005o`000?o>/[ooc[:o
oljb_ol000001?o?]l801Ol0003od;c6om2la_o@_<Ko000000?odL7;00Go0000om;8d?l0003ob;?6
o`000003olNfbP04o`000?o6^Lkoa[W>o`0000;oaKcB00Co0000ol?0eoo3`=Oo00000_o1`m`01?l0
003o_/KQokk6hOl00002ok[9iP04o`000?nfc>_o0000o`0000;o/Lk_00Co0000oj_?lol0003o0000
>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`000?oo
oooooooo04;ooooo00?o0000o`]Bc_l000000_lYH]@01Ol0003oAW3HodI`f?m6L=So000000;oH7cH
00Co0000ogJ6eOmfQ]Go00001?n8SM801Ol0003oUY;=oiJBcOnFT/go000000CoXYK900Go0000oj^I
aOn[VLGoZiW5o`000004ok:L`@03o`000?ngWKko]ifn00?o]ifn0_l00003okbR_P03o`000?o0X[_o
`::k00Co`::k0_l00006olBT^@03o`000?o7YkWoajNi00?oajNi00?o0000olVY^Oo9ZKT00oo9ZKT0
0ol0003objVhol^Y^002ol^Y^003o`000?o;[K_o000000Goc:bi00?o0000olf`_?o=/;`00_o=/;`0
0ol0003ocJnlolf__002olf__005o`000?o>/[ooc[:ooljb_ol000000oo?]l801Ol0003od;c6om2l
a_o@_<Ko000000?odL7;00Co0000om;8d?oBb=3od/S@0ol000001Oo7]/[o0000olJic_o6^Lko0000
00?oaKcB00?o0000ol?0eol000000_o1`m`01?l0003o_/KQokk6hOl00002ok[9iP03o`000?nfc>_o
000000;o/Lk_1?l0000kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0
03[ooooo00?o0000ooooooooool0@_ooool00ol0003o2e;>o`000002obURe004o`000?m6L=SoAW3H
o`0000;oH7cH00Go0000ogJ6eOmfQ]GoMXKEo`000003ohR=dP05o`000?nFT/goUY;=oiJBcOl00000
1?nRU/T00ol0003oZiW5oj^Ia@02oj^Ia@03o`000?nbW<7o/Yc100;o/Yc100?o0000okNM__ngWKh0
0_ngWKh00ol0003o_::nokbR_P03okbR_P03o`000?o0X[_o`::k00?o`::k00?o0000ol:V_?l00000
1?o4Y;T00ol0003oajNiolNW^@04olNW^@03o`000?o9ZKWobJVi00?obJVi00?o0000ol^Y^?o;ZKP0
0_l00002ol^]^`03o`000?o<[;Woc:bi00;oc:bi00?o0000olf`_?o=/;`00oo=/;`01Ol0003ocJnl
olf__?o=[kco000000?oc[:o00Go0000olng`_o?]l;ockO2o`000003om2laP05o`000?oA`L_odL7;
om71bol000001?oBb=000ol0003od/oFom;?eP06o`000004olFld_l0003o`l3Go`0000;o`L?L00Co
0000okk6hOnna^7o00000_njbNH00ol0003o]/c[o`000002ok7>k`03o`000?n[co?o000003kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00>oooool2o`0004?ooooo0_l0
0002obURe004o`000?m6L=SoAW3Ho`0000?oH7cH00Co0000ogJ6eOmfQ]Go00001?n8SM801Ol0003o
UY;=oiJBcOnFT/go000000CoXYK900Go0000oj^IaOn[VLGoZiW5o`000004ok:L`@04o`000?ngWKko
]ifnokNM_P;o00001_nlX[h01Ol0003o`::kol2R^oo0X[_o000000?o`ZJl00Go0000olBT^Oo4Y;Wo
a:Bio`000006olNW^@03o`000?o9ZKWobJVi00?obJVi00?o0000ol^Y^?l000001?o;[K/01Ol0003o
c:biolb/^Oo<[;Wo000000GocK2l00?o0000olnd`?l000000_o=[k`01Ol0003oc[:ooljb_oo>/[oo
000000?ockO200Go0000om2la_o@_<Kod;c6o`000002om71b`03o`000?oBb=3od/S@00;od/S@00Co
0000om;?e_oBcmKo00000_oBemd00ol0003od=oSom3Oh`0Do`0003oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`00?Oooool00ol0003oooooooooo`11ooooo`05o`]Bc_l0
003o:F;DobURe?l000000_m6L=P01?l0003oH7cHof1lf?l00003ogJ6e@05o`000?n8SM;oR8gBohR=
d_l000000onFT/d00ol0003oXYK9oj:Fb@02oj:Fb@05o`000?n[VLGoZiW5oj^IaOl000001?nbW<40
1?l0003o]ifnokNM__l00002okNR``03o`000?nlX[ko_::n00?o_::n00Go0000ol2R^oo0X[_o`::k
o`000004ol:V_004o`000?o4Y;Woa:Bio`0000GoajNi00?o0000olVY^Oo9ZKT01?o9ZKT2o`0000Ko
bjfk00?o0000olb/^Ol000001Oo=/;`01_l0003ockC0olnd`?l0003ocJnlo`0000?oc[:o00Go0000
olng`_o?]l;ockO2o`000003om2laP04o`000?oA`L_odL7;o`0000Cod/S@00Co0000om;?e_oBcmKo
00000_oBemd01_l0003od=oSom3Ohol0003oc>KYo`0000;oaNc_00Go0000okc`lonll??o0000ok3b
m@09o`0004;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00?_ooool0
0ol0003oooooooooo`11ooooo`04o`000?lYH]Co:F;Do`0000;oAW3H00Co0000of1lf?mPO=So0000
0omfQ]D01Ol0003oR8gBohR=d_n8SM;o000000CoUY;=00Go0000oj:FbOnRU/WoXYK9o`000004oj^I
a@03o`000?nbW<7o/Yc100;o/Yc10_l00004okNR``03o`000?nlX[ko_::n00?o_::n00?o0000ol2R
^ol000001_o2Y[`2o`0000KoajNi00?o0000olVY^Oo9ZKT00_o9ZKT3o`0000Oobjfk0_l00005olf`
_003o`000?o?]<3ockC000;ockC000Go0000oljb_oo>/[ooc[:oo`000003olng`P05o`000?o@_<Ko
d;c6om2la_l000000ooA`L/01Ol0003od/S@om;8d?oBb=3o000000;od/oF00Co0000om;GgOoBemgo
00000_o@gn<00ol0003oc>KYo`000002olG/k`03o`000?nll??o000000Wo0000A_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo047ooooo
0_l000001OlYH]Co0000odI`f?m6L=So000000;oH7cH00Co0000ogJ6eOmfQ]Go00001?n8SM801Ol0
003oUY;=oiJBcOnFT/go000000CoXYK900Go0000oj^IaOn[VLGoZiW5o`000003ok:L`@;o00001Ong
X/<00ol0003o_::nokbR_P03okbR_P03o`000?o0X[_o000000Oo`ZJl1Ol00002olNW^@03o`000?o9
ZKWo000000;o00000_o9[;d00ol0003objfkol^]^`04ol^]^`;o00001Oo=/;`00ol0003ockC0olnd
`002olnd`0;o00000oo>/[l01Ol0003ockO2olng`_o?]l;o000000;od;c600Go0000om71booA`L_o
dL7;o`000003om;8d004o`000?oBcmKod/oFo`0000;od]OM00Oo0000om3Ohoo@gn?o0000olcVjOl0
003oaNc_00Co000000?o/?;eo`000?l000001?l0001:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool0043ooooo0_l00012ooooo`03oiL@0?l0003o000000;oAW3H00Co0000
of1lf?mPO=So00000omfQ]D01Ol0003oR8gBohR=d_n8SM;o000000?oUY;=00?o0000oj:FbOnRU/T0
0_nRU/T01_l0003oZiW5oj^IaOn[VLGo0000ok:L`@;o000000?o/J78o`000?ngX/<01OngX/<00ol0
003o_::nokbR_P03okbR_P03o`000?o2Y[co`ZJl00Ko`ZJl00?o0000olJY_Oo6ZKd00_o6ZKd4o`00
00GobJbm00?o0000ol^]^oo;[K/00oo;[K/00ol0003oc;:oo`000004olf`_003o`000?o?]<3ockC0
00;ockC000Ko0000om2jaOo@^/Go0000oljb_ol00003olng`P05o`000?o@_<Kod;c6om2la_l00000
0_oA`L/01Ol0003od/S@om;8d?oBb=3o000000;od/oF00Co0000om;GgOoBemgo00000_o@gn<3o`00
0005olG/kol0003o_?3co`000?n`l_D01Ol0001=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00_ooool004;ooooo00?o0000ooooooooool0@?ooool01_nG403o02>So`000?l0003o
AW3Ho`0000;oH7cH00Co0000ogJ6eOmfQ]Go00000on8SM800ol0003oUY;=oiJBc@02oiJBc@05o`00
0?nRU/WoXYK9oj:FbOl000000on[VLD2o`0000Co/J7800?o0000okNR`ongX/<00ongX/<00ol0003o
_::nokbR_P03okbR_P03o`000?noYl7o000000Go`ZJl00?o0000olJY_Oo6ZKd01Oo6ZKd00ol0003o
bJbmolV/_@04olV/_@03o`000?o;[K_objfk00;objfk00Co0000olbb_oo</[oo00000oo=/;`00ol0
003ockC0olnd`002olnd`003o`000?o@^/God;[500;od;[500Go0000olng`_o?]l;ockO2o`000003
om2laP04o`000?oA`L_odL7;o`0000?od/S@00Co0000om;?e_oBcmKo00000_oBemd00ol0003od=oS
om3Oh`02o`000003olG/kol0003o000000Oo0000D?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo047ooooo00Co0000o`16a?l0003o0000
0_mPO=P01Ol0003oMXKEogJ6eOmfQ]Go000000?oR8gB00Go0000oiJBcOnFT/goUY;=o`000004oj:F
b@?o000000?oYio>o`000?naXLP01?naXLP00ol0003o]j;3okNR``03okNR``05o`000?nlX[ko_::n
okbR__l000000onoYl42o`0000?o`ZJl00?o0000olJY_Oo6ZKd01Oo6ZKd00ol0003obJbmolV/_@04
olV/_@03o`000?o;[K_objfk00;o00001?o</[l00ol0003ocK2lo`000004olnd`003o`000?o@^/Go
d;[500;od;[50_l00003olng`P04o`000?o@_<Kod;c6o`0000;odL7;00Go0000om;8d?oBb=3od/S@
o`000002om;?eP04o`000?oBemgod]OMo`0000;od=oS0_l000000oo5k>oo0000okc`l`05o`0005Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?l0A/Co04K400?o00000omfQ]D01Ol0003oR8gBohR=d_n8SM;o000000?o
UY;=00?o0000oj:FbOnRU/T00ol00004ojNOcP03o`000?naXLSo/J7800;o/J7800?o0000okNR`ong
X/<01?ngX/<00ol0003o_::no`000006oknW`@04o`000?o2Y[co`ZJlo`0000KoaZVm00?o0000olV/
_Oo9[;d01Oo9[;d00ol0003objfko`000006olbb_`;o00001?o?]<000ol0003od;[5om2ja@02om2j
a@06o`000?oB`/[od/;:o`000?o?]l;o00000oo@_<H01?l0003odL7;om71bol00003om;8d003o`00
0?oBcmKo000000;od]OM00?o0000om3Ohol000000_l000000oo5k>oo0000o`000003o`0005Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2o`0004;ooooo00?o
0000o`16a?l000000_lCIm/4o`0000?oR8gB00?o0000oiJBcOnFT/d01?l00002oiZMe@03o`000?nW
WlkoYio>00?oYio>00?o0000ok6Qb?naXLP00_naXLP00ol0003o]j;3okNR``03okNR``03o`000?nl
X[ko000000Oo_jO10_l00007olJY_@03o`000?o9[;gobJbm00GobJbm0_l00006olbb_`;o00001?o?
]<000ol0003od;[5om2ja@02om2ja@04o`000?oB`/[od/;:om;2bP;o00000oo@_<H01?l0003odL7;
om71bol00003om;8d003o`000?oBcmKo000000;od]OM00Co0000om3Ohol0003oc>KY1_l0001Joooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Oooooo00?o0000oooooooo
ool0@?ooool01Ol0003o04K4o`000?lCIm_o000000;oAX3T1ol00002ohNHg@03o`000?nJWMGoVYgE
00;oVYgE00?o0000ojNOc_nWWlh00_nWWlh00ol0003o/J78ok6Qb002ok6Qb003o`000?ngX/?o]j;3
00Co]j;300?o0000oknW`OnoYl401onoYl43o`0000GoaZVm00?o0000olV/_Oo9[;d00oo9[;d3o`00
00Koc;:o00?o0000oljhaOl000000oo?]<000ol0003od;[5om2ja@02om2ja@05o`000?oB`/[od/;:
om;2b_l000000_oDbm400ol0003od;c6o`000002om71b`07o`000?oBb=3od/S@om;8d?l0003od/oF
o`000002om;Gg@03o`000?o@gn?o000000Ko0000GOooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo043ooooo00Go0000o`16a?l0003o4fOK
o`000002odJ0i005o`000?m/Sn?oK8oSofb?hol000001?n7V=d00ol0003oVYgEoiZMe@02oiZMe@03
o`000?nWWlkoYio>00;oYio>00?o0000ok6Qb?naXLP00_naXLP00ol0003o]j;3okNR``02okNR``04
o`000?nkZLOo^jW7o`0000Oo_jO100?o0000olB]`oo4[L<00ol000000oo6ZKgo0000olV/_@05o`00
00;obK7200?o0000olbb_oo</[l00_o</[l2o`0000;oc[S500Co0000olnd`?o?]<3o00001?o@^/D0
1Ol0003od/;:om;2b_oB`/[o000000?oe<_A0ol000000ooA`L_o0000om;8d002om;8d003o`000?oB
cmKo000000;od]OM00?o0000om3Ohol000001Ol0001Pooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00Oooool004Wooooo00?o0000ooooooooool0@?ooool01Ol0003o04K4o`000?lC
Im_o000000;oAX3T00Go0000ofb?hom/Sn?oK8oSo`000004ohNHg@05o`000?nJWMGoVYgEoiZMeOl0
00001OnWWlh00ol0003o/J78ok6Qb002ok6Qb004o`000?ngX/?o]j;3o`0000Co^jW700?o0000oknW
`OnoYl400onoYl400ol0003oa:g3olB]``04olB]``?o00001oo9/L801Ol0003oc;:oolbb_oo</[oo
000000Goc[S50_l00004om2ja@05o`000?oB`/[od/;:om;2b_l000000ooDbm400ol0003oeMGIomGE
f@02o`0000?od/S@00?o0000om;?e_l000000_oBemd00ol0003od=oSo`000004o`0006?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00B_ooool2o`00047ooooo00Go0000
o`16a?l0003o4fOKo`000002odJ0i005o`000?m/Sn?oK8oSofb?hol000001?n7V=d01Ol0003oVYgE
oiZMeOnJWMGo000000CoYio>00?o0000ok6Qb?naXLP00_naXLP00ol0003o]j;3o`000006ok^Ya`03
o`000?noYl7o_jO100;o_jO100?o0000olB]`oo4[L<01Oo4[L<00ol0003obK72olVa`P06olVa`P04
o`000?o</[ooc;:oo`0000Goc[S50_l00004om2ja@05o`000?oB`/[od/;:om;2b_l000000ooDbm40
1?l0003oeMGIomGEfOl00002omCQh@05o`000?oBb=3o0000om;?e_l000000_oBemd00ol0003od=oS
o`000003o`0006Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?oo
ool00ol0003oooooooooo`0oooooo`05o`000?l0A/Co0000oa=Wfol000000_m6P>@01Ol0003oK8oS
ofb?hom/Sn?o000000?oQiSM00?o0000oiZMeOnJWMD00_nJWMD00ol0003oYio>ojNOcP02ojNOcP03
o`000?naXLSo/J7800;o/J7800?o0000ok^YaonkZLL01_nkZLL01?l0003o_jO1oknW`Ol00008olB]
``03o`000?o9/L;obK7200KobK7200?o0000olbb_oo>^<D01Oo>^<D00ol0003ocl3<o`000003om2j
a@05o`000?oB`/[od/;:om;2b_l000000ooDbm401?l0003oeMGIomGEfOl00003omCQh@Go000000?o
d]OMo`000?o@gn<00ol0001Xooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001=
ooooo`03o`000?oooooooooo03oooooo00Go0000o`16a?l0003o4fOKo`000002odJ0i004o`000?m/
Sn?oK8oSo`0000CoQiSM00Go0000oiZMeOnJWMGoVYgEo`000004ojNOcP05o`000?naXLSo/J78ok6Q
b?l000000_ndZll00ol0003o^jW7ok^Ya`05ok^Ya`03o`000?noYl7o000000Ooa:g300?o0000olVa
`_o9/L801Oo9/L83o`0000Goc[S50_l00002olo0c004o`000?o@^/God;[5o`0000?od/;:00Go0000
omC;dOoDbm7oe<_Ao`000002omGEf@07o`000?oDhN7oe>7QomCQhOl0003ocnkYo`000002ol?gk@Go
0000Joooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00C_ooool00ol0003ooooo
ooooo`0oooooo`;o00000_lCIm/01?l0003oAX3TodJ0i?l00002ofb?h`03o`000?n7V=goQiSM00;o
QiSM00Go0000oiZMeOnJWMGoVYgEo`000004ojNOcP03o`000?naXLSo000000Co]:_?0_l00006ok^Y
a`Ko00000oo4[L<00ol0003obK72olVa`P05o`0000;obKO900Co0000oljhaOo>^<Goc[S50_l00005
olo0c003o`000?o@^/God/;:00;od/;:00?o0000omC;dOoDbm400_l00002omGEf@04o`000?oDhN7o
e>7QomCQh@?o000000?o`oO]o`000?l000000_l0001^ooooo`03o`000?oooooooooo00Oooooo0Ol0
0001ooooo`7ooooo001?ooooo`;o0000@?ooool2o`000005oa=Wfol0003oAX3TodJ0i?l000000om/
Sn<00ol0003oQiSMohNHg@02ohNHg@05o`000?nJWMGoVYgEoiZMeOl000001?nWWlh00ol0003o]:_?
okB[c`05okB[c`03o`000?nkZLOo^jW700?o^jW700?o0000ol:ab_o2/LX00oo2/LX6o`0000OobKO9
00Co0000oljhaOo>^<Go00001_o?`<`2o`0000?od/;:00Co0000omC;dOoDbm7o00000ooEeMT00ol0
003oe>7QomCQh@03o`0000;o`oO]0ol0001aooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo001Aooooo`03o`000?oooooooooo03kooooo0_l000001OlCIm_o0000odJ0i?m6P>Co0000
00?oK8oS00Go0000ohNHgOn7V=goQiSMo`000003oiZMe@05o`000?nWWlkoYio>ojNOc_l000000_n[
[MT00ol0003o]:_?okB[c`04okB[c`;o00000_nkZLL00ol0003o`[7:ol:abP07ol:abP03o`000?o9
]lWobKO900KobKO900Co0000oljhaOo>^<Go00001Oo?`<`2o`000005olo:e?l0003od/;:om;2b_l0
00000ooDbm43omGEf@07o`000?oDhN7oe>7Qo`000?o?k^Wo0000ol?gk@03o`0007Cooooo00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool005;ooooo00?o0000ooooooooool0?_ooool2o`00
0005oa=Wfol0003oAX3TodJ0i?l000000_m/Sn<00ol0003oQiSMohNHg@02ohNHg@07o`000?nJWMGo
VYgEoiZMeOl0003oYio>o`000004oj^]f@;o00001_ndZll00ol0003o^jW7o`000009ol:abP03o`00
0?o9]lWobKO900KobKO900?o0000oljhaOo?`<`01Oo?`<`00ol0003ocl[Dolo:e002olo:e003o`00
0?oB`/[oe<_A00;oe<_A0ooEeMT2omCQh@?o000000?o`oO]o`000?l000000_l0001fooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Cooooo`;o0000@?ooool00ol0003o4fOKo`00
0002odJ0i004o`000?m/Sn?oK8oSo`0000CoQiSM00?o0000oiZMeOnJWMD00_l00007oj^]f@03o`00
0?ndZloo]:_?00Co]:_?00Co0000ol:ab_l0003o00001_o2/LX00ol0003obKO9olVgb@05olVgb@?o
00001Oo?`<`2o`0000Cocl[D0_l00003omC;d@?oeMGI0_oDhN401?l0003ocnkYo`000?o3mnd3o`00
07Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005Gooooo00?o0000oooooooo
ool0?_ooool3o`0000;oAX3T00Co0000ofb?hom/Sn?o00000_n7V=d4o`0000?oVZkU00?o0000oj^]
fOn[[MT01?n[[MT00ol0003o]:_?okB[c`03okB[c`04o`000?nm]m?o_KOCokfgd`Go000000Co`[7:
o`000?o9]lWobKO91Ol00002olRodP04o`000?o?`<cocl3<olo0c0;o00001?o?b]@2o`000004oloG
gol0003oe<_AomC;d@?oeMGI0_oDhN400ol0003ocnkYo`000003o`0007_ooooo00?o0000oooooooo
ool01?ooool1o`00007ooooo001Fooooo`03o`000?oooooooooo03oooooo00?o04:Xo`000?l00000
1_l00004ogj[l0CoVZkU0_l00005oj^]f@;o00000_ndZll00ol0003o_KOCokfgd`07okfgd`Co0000
1oo8_m801?l0003ocl3<olo0c?l00004olo:e0;o00000oo?eml2o`0000?oeMGI0_oDhN45o`0007ko
oooo00?o0000ooooooooool00oooool1o`00007ooooo001Gooooo`03o`000?oooooooooo043ooooo
00Co04:Xo`9hg_l2N=ko0WSN0om<W?@5ogj[l003o`000?nJ[^GoVZkU00;oVZkU00?o0000oj^]fOn[
[MT01?n[[MT00ol0003o]:_?o`00000:okfgd`03o`000?o8_m;ob;oB00Oob;oB00?o0000olo0c?l0
00000oo?b]@2o`0000?ocmOO0_l000001?o9iN_o0000omGEfOoEeMT2omCQh@04olo^jOl0003o0000
ojchjH7ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Hooooo`;o0000@_ooool01?l0
@ZSo0WSNo`9hg_l00002odbLm003o`000?mnZo3oOZ_`00;oOZ_`0_l00003oiZ^i@03o`000?n[[MWo
ZjgI00CoZjgI00Co0000okfgdonm]m?o00002?nm]m<00ol0003ob;oBolRodP04olRodPCo00001?o?
b]@01?l0003ocmOOoloGgoo?eml2o`0000?obNG[0_l00002omCQh@04olo^jOl0003o0000o`0008;o
oooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooooooo047ooooo
00Co0000o`9hg_l2N=ko00000_m<W?@00ol0003oOZ_`ogj[l002ogj[l004o`000?nJ[^GoVZkUoiZ^
i@;o00000on[[MT00ol0003o][kPokJnh002okJnh0Go00000_nm]m<00ol0003ob;oBolRodP05o`00
00?oaL[N00?o0000olo:e?o?b]@00_l00002oloGg`;o00000oo9iN/2o`000003ok[blol0003o0000
00?o0000QOooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`000?oooooooooo
047ooooo0_l00002o`9hgP04o`000?m<W?CoC9cdo`0000?oOZ_`0_l00003oiZ^i@03o`000?n[[MWo
000000[o][kP1Ol00008olG:gP03o`000?o?b]Co000000;ocmOO0_l00003olWUj`;o000000?o^_;c
o`000?l000000_l00029ooooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooo
oooo04;ooooo00?o04:Xo`000?l2N=h00_l000000om<W?Co0000o`000003ogj[l005o`000?nJ[^Go
VZkUoiZ^iOl000003Onf_^000ol0003oaL[NolG:gP05olG:gPCo00000oo?eml00ol0003obNG[olWU
j`07o`0008gooooo00?o0000ooooool000000Oooool005gooooo0_l00014ooooo`03o`12Z?l0003o
0WSN00;o000000?oC9cdo`000?l000000_mnZo000ol0003oVZkUo`000004ojO6k`Ko00000onf_^00
0ol0003oaL[NolG:gP06o`0000?o_MO]00?o0000oloGgol000000_o9iN/2o`000004ok[blol0003o
0000o`00093ooooo00?o0000ooooooooool00Ol0000005oooooo00?o0000ooooooooool0@Oooool0
1_l0003oooooo`000?l0003o0WSNo`0000;oC9cd00Co0000ogj[l?l0003o00002onWa^l5o`0000So
_MO]0ol00003olWUj`04o`000?njl_?o^_;co`0009Cooooo0Ol00001ooooo`7o0000001Pooooo`03
o`000?oooooooooo043ooooo00Co0000oooooooooooooooo1_l00004ohO9o@Go00001_nWa^l00ol0
003o_MO]okgGk@03okgGk@Go00000_nYhoX00ol0003obNG[o`000002ok[bl`03o`000?oooooooooo
09Gooooo0_l00000067ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`;o
07bl00?o0000odFgm_m5]oH00_l00005ohO9o@Co000000?oYlK_o`000?nmend00_nmend3o`0000?o
ZN?j1Ol00002ok[bl`03o`000?oooooooooo09Kooooo0ol0000006;ooooo0_l0000oooooo`03o`00
0?oooooooooo00Wooooo00Go07blo`000?l0003o0000odFgmP04o`0000;oQlWm0ol00003ojWSnPGo
000000?oMmkfo`000?l000000_l0002Gooooo`Co00000oooool006Cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0=ooooo`03o`1l_?l0003o000000;o000000CoAKOfo`000?l0003o
ZN?j0_l00003ogONmPCo0000V?ooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool04_ooool2o`0000;oMmkf00?o0000ooooooooool0V_ooool4o`0000_ooooo
001Vooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0/?ooool3o`0000oooooo001W
ooooo`;o0000>_ooool00ol0003oooooooooo`2/ooooo`Co00004_ooool006Wooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`2Xooooo`Co00005_ooool006[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2Tooooo`Co00006_ooool006_ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`2Qooooo`Co00007_ooool006cooooo0_l0000dooooo`03o`000?oo
oooooooo09gooooo1?l0000Rooooo`00K_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo09Wooooo1?l0000Vooooo`00Koooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
09Gooooo1?l0000Zooooo`00L?ooool2o`00033ooooo00?o0000ooooooooool0TOooool4o`0002ko
oooo001booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0S_ooool3o`0003;ooooo
001cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0R_ooool4o`0003Gooooo001d
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_ooool4o`0003Wooooo001eoooo
o`;o0000:oooool00ol0003oooooooooo`22ooooo`Co0000?Oooool007Oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1nooooo`Co0000@Oooool007Sooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1jooooo`Co0000AOooool007Wooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1fooooo`Co0000BOooool007[ooooo0_l0000Vooooo`03o`000?oooooo
oooo07;ooooo1?l0001=ooooo`00O?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06oooooo0ol0001Aooooo`00OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06_o
oooo1?l0001Dooooo`00O_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Oooooo
1?l0001Hooooo`00Ooooool2o`00027ooooo00?o0000ooooooooool0Hoooool4o`0005cooooo0021
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Goooool4o`00063ooooo0022oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Foooool4o`0006Cooooo0023ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Eoooool4o`0006Sooooo0024ooooo`;o0000
7?ooool00ol0003oooooooooo`1Cooooo`Co0000K?ooool008Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1?ooooo`Co0000L?ooool008Oooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1<ooooo`?o0000M?ooool008Sooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`18ooooo`Co0000Moooool008Wooooo0_l0000Gooooo`03o`000?oooooooooo04Co
oooo1?l0001kooooo`00Roooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo043ooooo
1?l0001oooooo`00S?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03cooooo1?l0
0023ooooo`00SOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Sooooo1?l00027
ooooo`00S_ooool2o`0001;ooooo00?o0000ooooooooool0=?ooool4o`0008_ooooo002@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool4o`0008oooooo002Aooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;_ooool3o`0009?ooooo002Booooo`;o00003Ooo
ool00ol0003oooooooooo`0Zooooo`Co0000U_ooool009Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Vooooo`Co0000V_ooool009Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Rooooo`Co0000W_ooool009Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Nooooo`Co0000X_ooool009Oooooo0_l00008ooooo`03o`000?oooooooooo01[ooooo
1?l0002Vooooo`00VOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0
002Zooooo`00V_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002^
ooooo`00Voooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002boooo
o`00W?ooool2o`0000?ooooo00?o0000ooooooooool02oooool3o`000;Kooooo002Nooooo`04o`00
0?ooooooooooo`0000Wooooo1?l0002iooooo`00Woooool00ol0003oooooo`000005ooooo`Co0000
_Oooool00:3ooooo0_l000000ooooooo0000o`000002o`000<7ooooo002Qooooo`;o0000aOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51722 .66238 m .51694 .65827 L .43899 .65168 L p .523 0 0 r
F P
0 g
s
.51694 .65827 m .51722 .66238 L .59278 .65532 L p .159 0 0 r
F P
0 g
s
.59278 .65532 m .59527 .65394 L .51694 .65827 L p .159 0 0 r
F P
0 g
s
.6649 .6373 m .67023 .63881 L .59527 .65394 L p .485 .866 .978 r
F P
0 g
s
.59027 .65688 m .58772 .65845 L .59059 .65741 L p .579 .908 .978 r
F P
0 g
s
.59527 .65394 m .59289 .65526 L p .6649 .6373 L .485 .866 .978 r
F P
0 g
s
.59284 .65531 m .6649 .6373 L p .59289 .65526 L .485 .866 .978 r
F P
0 g
s
.65951 .63586 m .6649 .6373 L .59485 .6548 L p .527 .888 .978 r
F P
0 g
s
.65951 .63586 m .59485 .6548 L .59557 .65451 L .527 .888 .978 r
F
.65951 .63586 m .59284 .65531 L .59289 .65529 L F
.59485 .6548 m .59284 .65531 L p .59557 .65451 L F P
0 g
s
.59027 .65688 m .65951 .63586 L p .59289 .65529 L .527 .888 .978 r
F P
0 g
s
.59289 .65526 m .59278 .65532 L .59284 .65531 L p .485 .866 .978 r
F P
0 g
s
.59284 .65531 m .59278 .65532 L p .59289 .65529 L .527 .888 .978 r
F P
0 g
s
.59278 .65532 m .59027 .65688 L p .59289 .65529 L .527 .888 .978 r
F P
0 g
s
.65407 .6344 m .65951 .63586 L .59174 .65643 L p .579 .908 .978 r
F P
0 g
s
.59174 .65643 m .59027 .65688 L p .59288 .65596 L .579 .908 .978 r
F P
0 g
s
.65407 .6344 m .59174 .65643 L .59288 .65596 L .579 .908 .978 r
F
.59059 .65741 m .65404 .63442 L p .5917 .65638 L F P
0 g
s
.654 .63443 m .5917 .65638 L .65404 .63442 L .579 .908 .978 r
F
.5917 .65638 m .59027 .65688 L .59059 .65741 L F
.65404 .63442 m .65407 .6344 L p .654 .63443 L F P
0 g
s
.64857 .63283 m .65407 .6344 L .59042 .65747 L p .635 .922 .976 r
F P
0 g
s
.59042 .65747 m .58772 .65845 L p .59235 .6565 L .635 .922 .976 r
F P
0 g
s
.64857 .63283 m .59042 .65747 L .59235 .6565 L .635 .922 .976 r
F
.58772 .65845 m .58513 .65986 L .64772 .63319 L p F P
0 g
s
.64753 .63327 m .58772 .65845 L .64772 .63319 L .635 .922 .976 r
F
.64767 .63321 m .58772 .65845 L .64793 .6331 L F
.51751 .66678 m .5178 .67123 L .58772 .65845 L p .1 0 0 r
F P
0 g
s
.58772 .65845 m .59027 .65688 L .51751 .66678 L p .1 0 0 r
F P
0 g
s
.58513 .65986 m .58772 .65845 L .5178 .67123 L p .025 0 0 r
F P
0 g
s
.5178 .67123 m .51809 .6755 L .58513 .65986 L p .025 0 0 r
F P
0 g
s
.5825 .66093 m .58513 .65986 L .51809 .6755 L p 0 0 0 r
F P
0 g
s
.58513 .65986 m .5825 .66093 L .64145 .63181 L p .689 .929 .968 r
F P
0 g
s
.64145 .63181 m .643 .63104 L p .6402 .63243 L .689 .929 .968 r
F P
0 g
s
.6402 .63243 m .58513 .65986 L .64145 .63181 L .689 .929 .968 r
F
.64772 .63319 m .64793 .6331 L p .64753 .63327 L .635 .922 .976 r
F P
0 g
s
.64793 .6331 m .64857 .63283 L p .64767 .63321 L .635 .922 .976 r
F P
0 g
s
.44193 .6582 m .43899 .65168 L .36521 .63435 L p .667 .166 .045 r
F P
0 g
s
.43899 .65168 m .44193 .6582 L .51722 .66238 L p .523 0 0 r
F P
0 g
s
.51751 .66678 m .51722 .66238 L .44193 .6582 L p .522 0 0 r
F P
0 g
s
.51722 .66238 m .51751 .66678 L .59027 .65688 L p .144 0 0 r
F P
0 g
s
.59027 .65688 m .59278 .65532 L .51722 .66238 L p .144 0 0 r
F P
0 g
s
.36521 .63435 m .37066 .64281 L .44193 .6582 L p .667 .166 .045 r
F P
0 g
s
.4449 .66508 m .44193 .6582 L .37066 .64281 L p .67 .176 .066 r
F P
0 g
s
.44193 .6582 m .4449 .66508 L .51751 .66678 L p .522 0 0 r
F P
0 g
s
.67023 .63881 m .6649 .6373 L .72982 .60896 L p .656 .779 .939 r
F P
0 g
s
.72982 .60896 m .73799 .61332 L .67023 .63881 L p .656 .779 .939 r
F P
0 g
s
.5178 .67123 m .51751 .66678 L .4449 .66508 L p .509 0 0 r
F P
0 g
s
.37066 .64281 m .36521 .63435 L .29943 .6068 L p .739 .231 .013 r
F P
0 g
s
.6649 .6373 m .65951 .63586 L .72159 .60458 L p .679 .781 .927 r
F P
0 g
s
.72159 .60458 m .72982 .60896 L .6649 .6373 L p .679 .781 .927 r
F P
0 g
s
.37066 .64281 m .37618 .65171 L .4449 .66508 L p .67 .176 .066 r
F P
0 g
s
.44793 .67207 m .4449 .66508 L .37618 .65171 L p .666 .173 .069 r
F P
0 g
s
.4449 .66508 m .44793 .67207 L .5178 .67123 L p .509 0 0 r
F P
0 g
s
.51809 .6755 m .5178 .67123 L .44793 .67207 L p .481 0 0 r
F P
0 g
s
.65951 .63586 m .65407 .6344 L .7133 .60017 L p .701 .781 .914 r
F P
0 g
s
.7133 .60017 m .72159 .60458 L .65951 .63586 L p .701 .781 .914 r
F P
0 g
s
.29943 .6068 m .30723 .61666 L .37066 .64281 L p .739 .231 .013 r
F P
0 g
s
.37618 .65171 m .37066 .64281 L .30723 .61666 L p .745 .244 .033 r
F P
0 g
s
.65407 .6344 m .64857 .63283 L .70496 .59572 L p .721 .779 .898 r
F P
0 g
s
.70496 .59572 m .7133 .60017 L .65407 .6344 L p .721 .779 .898 r
F P
0 g
s
.37618 .65171 m .38179 .66073 L .44793 .67207 L p .666 .173 .069 r
F P
0 g
s
.45101 .67887 m .44793 .67207 L .38179 .66073 L p .653 .156 .055 r
F P
0 g
s
.44793 .67207 m .45101 .67887 L .51809 .6755 L p .481 0 0 r
F P
0 g
s
.73799 .61332 m .72982 .60896 L .78378 .57137 L p .624 .658 .863 r
F P
0 g
s
.78378 .57137 m .79464 .57831 L .73799 .61332 L p .624 .658 .863 r
F P
0 g
s
.643 .63104 m .64857 .63283 L .58513 .65986 L p .689 .929 .968 r
F P
0 g
s
.51839 .67934 m .51809 .6755 L .45101 .67887 L p .436 0 0 r
F P
0 g
s
.51809 .6755 m .51839 .67934 L .5825 .66093 L p 0 0 0 r
F P
0 g
s
.30723 .61666 m .31513 .62697 L .37618 .65171 L p .745 .244 .033 r
F P
0 g
s
.38179 .66073 m .37618 .65171 L .31513 .62697 L p .745 .243 .034 r
F P
0 g
s
.72982 .60896 m .72159 .60458 L .77288 .56434 L p .638 .656 .851 r
F P
0 g
s
.77288 .56434 m .78378 .57137 L .72982 .60896 L p .638 .656 .851 r
F P
0 g
s
.30723 .61666 m .29943 .6068 L .24558 .56996 L p .726 .2 0 r
F P
0 g
s
.64857 .63283 m .643 .63104 L .69656 .5912 L p .74 .776 .882 r
F P
0 g
s
.69656 .5912 m .70496 .59572 L .64857 .63283 L p .74 .776 .882 r
F P
0 g
s
.72159 .60458 m .7133 .60017 L .76195 .5573 L p .652 .655 .84 r
F P
0 g
s
.76195 .5573 m .77288 .56434 L .72159 .60458 L p .652 .655 .84 r
F P
0 g
s
.57983 .66149 m .5825 .66093 L .51839 .67934 L p .23 .742 .713 r
F P
0 g
s
.5825 .66093 m .57983 .66149 L .63737 .62893 L p .736 .927 .954 r
F P
0 g
s
.63737 .62893 m .643 .63104 L .5825 .66093 L p .736 .927 .954 r
F P
0 g
s
.38179 .66073 m .38751 .66957 L .45101 .67887 L p .653 .156 .055 r
F P
0 g
s
.45415 .68519 m .45101 .67887 L .38751 .66957 L p .63 .122 .022 r
F P
0 g
s
.45101 .67887 m .45415 .68519 L .51839 .67934 L p .436 0 0 r
F P
0 g
s
.5187 .68251 m .51839 .67934 L .45415 .68519 L p .362 0 0 r
F P
0 g
s
.51839 .67934 m .5187 .68251 L .57983 .66149 L p .23 .742 .713 r
F P
0 g
s
.643 .63104 m .63737 .62893 L .68809 .5866 L p .757 .772 .865 r
F P
0 g
s
.68809 .5866 m .69656 .5912 L .643 .63104 L p .757 .772 .865 r
F P
0 g
s
.7133 .60017 m .70496 .59572 L .75099 .55031 L p .667 .655 .829 r
F P
0 g
s
.75099 .55031 m .76195 .5573 L .7133 .60017 L p .667 .655 .829 r
F P
0 g
s
.31513 .62697 m .32314 .63743 L .38179 .66073 L p .745 .243 .034 r
F P
0 g
s
.38751 .66957 m .38179 .66073 L .32314 .63743 L p .736 .229 .017 r
F P
0 g
s
.25551 .58062 m .30723 .61666 L p .24634 .57053 L .726 .2 0 r
F P
0 g
s
.31513 .62697 m .30723 .61666 L .25551 .58062 L p .736 .215 0 r
F P
0 g
s
.25551 .58062 m .26555 .59172 L .31513 .62697 L p .736 .215 0 r
F P
0 g
s
.25551 .58062 m .21931 .53619 L p .26499 .59105 L 0 0 .52 r
F P
0 g
s
.26555 .59172 m .25551 .58062 L p .26499 .59105 L 0 0 .52 r
F P
0 g
s
.24558 .56996 m .25551 .58062 L p .24634 .57053 L .726 .2 0 r
F P
0 g
s
.57712 .66135 m .57983 .66149 L .5187 .68251 L p .399 .854 .818 r
F P
0 g
s
.57983 .66149 m .57712 .66135 L .63166 .62641 L p .774 .916 .934 r
F P
0 g
s
.63166 .62641 m .63737 .62893 L .57983 .66149 L p .774 .916 .934 r
F P
0 g
s
.70496 .59572 m .69656 .5912 L .74001 .54344 L p .682 .657 .819 r
F P
0 g
s
.74001 .54344 m .75099 .55031 L .70496 .59572 L p .682 .657 .819 r
F P
0 g
s
.63737 .62893 m .63166 .62641 L .67957 .5819 L p .771 .766 .849 r
F P
0 g
s
.67957 .5819 m .68809 .5866 L .63737 .62893 L p .771 .766 .849 r
F P
0 g
s
.38751 .66957 m .39335 .6779 L .45415 .68519 L p .63 .122 .022 r
F P
0 g
s
.45736 .69073 m .45415 .68519 L .39335 .6779 L p .593 .067 0 r
F P
0 g
s
.45415 .68519 m .45736 .69073 L .5187 .68251 L p .362 0 0 r
F P
0 g
s
.51901 .68477 m .5187 .68251 L .45736 .69073 L p .247 0 0 r
F P
0 g
s
.5187 .68251 m .51901 .68477 L .57712 .66135 L p .399 .854 .818 r
F P
0 g
s
.69656 .5912 m .68809 .5866 L .72902 .53674 L p .697 .659 .808 r
F P
0 g
s
.72902 .53674 m .74001 .54344 L .69656 .5912 L p .697 .659 .808 r
F P
0 g
s
.32314 .63743 m .31513 .62697 L .26555 .59172 L p .733 .212 0 r
F P
0 g
s
.32314 .63743 m .33131 .64771 L .38751 .66957 L p .736 .229 .017 r
F P
0 g
s
.39335 .6779 m .38751 .66957 L .33131 .64771 L p .719 .2 0 r
F P
0 g
s
.57435 .66037 m .57712 .66135 L .51901 .68477 L p .563 .935 .897 r
F P
0 g
s
.57712 .66135 m .57435 .66037 L .62589 .62338 L p .803 .898 .91 r
F P
0 g
s
.62589 .62338 m .63166 .62641 L .57712 .66135 L p .803 .898 .91 r
F P
0 g
s
.63166 .62641 m .62589 .62338 L .67098 .57709 L p .783 .76 .832 r
F P
0 g
s
.67098 .57709 m .67957 .5819 L .63166 .62641 L p .783 .76 .832 r
F P
0 g
s
.68809 .5866 m .67957 .5819 L .718 .53028 L p .711 .661 .799 r
F P
0 g
s
.718 .53028 m .72902 .53674 L .68809 .5866 L p .711 .661 .799 r
F P
0 g
s
.79464 .57831 m .78378 .57137 L .82306 .52612 L p .55 .571 .829 r
F P
0 g
s
.82306 .52612 m .83625 .53514 L .79464 .57831 L p .55 .571 .829 r
F P
0 g
s
.78378 .57137 m .77288 .56434 L .80988 .51698 L p .561 .569 .818 r
F P
0 g
s
.80988 .51698 m .82306 .52612 L .78378 .57137 L p .561 .569 .818 r
F P
0 g
s
.45736 .69073 m .46064 .69518 L .51901 .68477 L p .247 0 0 r
F P
0 g
s
.51933 .68588 m .51901 .68477 L .46064 .69518 L p .067 0 0 r
F P
0 g
s
.51901 .68477 m .51933 .68588 L .57435 .66037 L p .563 .935 .897 r
F P
0 g
s
.39335 .6779 m .39932 .68538 L .45736 .69073 L p .593 .067 0 r
F P
0 g
s
.46064 .69518 m .45736 .69073 L .39932 .68538 L p .53 0 0 r
F P
0 g
s
.67957 .5819 m .67098 .57709 L .70696 .52411 L p .725 .664 .789 r
F P
0 g
s
.70696 .52411 m .718 .53028 L .67957 .5819 L p .725 .664 .789 r
F P
0 g
s
.77288 .56434 m .76195 .5573 L .79672 .50786 L p .574 .569 .809 r
F P
0 g
s
.79672 .50786 m .80988 .51698 L .77288 .56434 L p .574 .569 .809 r
F P
0 g
s
.62004 .61977 m .62589 .62338 L .57435 .66037 L p .822 .876 .885 r
F P
0 g
s
.62589 .62338 m .62004 .61977 L .66233 .57216 L p .794 .754 .816 r
F P
0 g
s
.66233 .57216 m .67098 .57709 L .62589 .62338 L p .794 .754 .816 r
F P
0 g
s
.76195 .5573 m .75099 .55031 L .78359 .4989 L p .589 .571 .801 r
F P
0 g
s
.78359 .4989 m .79672 .50786 L .76195 .5573 L p .589 .571 .801 r
F P
0 g
s
.57154 .65837 m .57435 .66037 L .51933 .68588 L p .691 .968 .932 r
F P
0 g
s
.57435 .66037 m .57154 .65837 L .62004 .61977 L p .822 .876 .885 r
F P
0 g
s
.25551 .58062 m .24558 .56996 L .20758 .52532 L p 0 0 .521 r
F P
0 g
s
.26555 .59172 m .27571 .60295 L .32314 .63743 L p .733 .212 0 r
F P
0 g
s
.33131 .64771 m .32314 .63743 L .27571 .60295 L p .717 .191 0 r
F P
0 g
s
.33131 .64771 m .33963 .65747 L .39335 .6779 L p .719 .2 0 r
F P
0 g
s
.39932 .68538 m .39335 .6779 L .33963 .65747 L p .686 .149 0 r
F P
0 g
s
.75099 .55031 m .74001 .54344 L .77051 .49025 L p .605 .575 .794 r
F P
0 g
s
.77051 .49025 m .78359 .4989 L .75099 .55031 L p .605 .575 .794 r
F P
0 g
s
.67098 .57709 m .66233 .57216 L .69591 .51829 L p .738 .667 .78 r
F P
0 g
s
.69591 .51829 m .70696 .52411 L .67098 .57709 L p .738 .667 .78 r
F P
0 g
s
.74001 .54344 m .72902 .53674 L .75747 .48204 L p .622 .581 .787 r
F P
0 g
s
.75747 .48204 m .77051 .49025 L .74001 .54344 L p .622 .581 .787 r
F P
0 g
s
.61412 .6155 m .62004 .61977 L .57154 .65837 L p .835 .853 .859 r
F P
0 g
s
.62004 .61977 m .61412 .6155 L .65361 .56708 L p .803 .747 .802 r
F P
0 g
s
.65361 .56708 m .66233 .57216 L .62004 .61977 L p .803 .747 .802 r
F P
0 g
s
.72902 .53674 m .718 .53028 L .74448 .47441 L p .64 .588 .78 r
F P
0 g
s
.74448 .47441 m .75747 .48204 L .72902 .53674 L p .64 .588 .78 r
F P
0 g
s
.46064 .69518 m .464 .69828 L .51933 .68588 L p .067 0 0 r
F P
0 g
s
.51966 .68564 m .51933 .68588 L .464 .69828 L p .184 .713 .716 r
F P
0 g
s
.51933 .68588 m .51966 .68564 L .57154 .65837 L p .691 .968 .932 r
F P
0 g
s
.66233 .57216 m .65361 .56708 L .68483 .51286 L p .751 .67 .772 r
F P
0 g
s
.68483 .51286 m .69591 .51829 L .66233 .57216 L p .751 .67 .772 r
F P
0 g
s
.39932 .68538 m .40542 .69169 L .46064 .69518 L p .53 0 0 r
F P
0 g
s
.464 .69828 m .46064 .69518 L .40542 .69169 L p .422 0 0 r
F P
0 g
s
.56869 .65524 m .57154 .65837 L .51966 .68564 L p .775 .959 .929 r
F P
0 g
s
.57154 .65837 m .56869 .65524 L .61412 .6155 L p .835 .853 .859 r
F P
0 g
s
.718 .53028 m .70696 .52411 L .73155 .46746 L p .658 .596 .774 r
F P
0 g
s
.73155 .46746 m .74448 .47441 L .718 .53028 L p .658 .596 .774 r
F P
0 g
s
.20758 .52532 m .21931 .53619 L .25551 .58062 L p 0 0 .521 r
F P
0 g
s
.70696 .52411 m .69591 .51829 L .71867 .4613 L p .676 .605 .768 r
F P
0 g
s
.71867 .4613 m .73155 .46746 L .70696 .52411 L p .676 .605 .768 r
F P
0 g
s
.27571 .60295 m .28604 .614 L .33131 .64771 L p .717 .191 0 r
F P
0 g
s
.33963 .65747 m .33131 .64771 L .28604 .614 L p .682 .149 0 r
F P
0 g
s
.60813 .61051 m .61412 .6155 L .56869 .65524 L p .843 .831 .835 r
F P
0 g
s
.61412 .6155 m .60813 .61051 L .64484 .56186 L p .81 .741 .788 r
F P
0 g
s
.64484 .56186 m .65361 .56708 L .61412 .6155 L p .81 .741 .788 r
F P
0 g
s
.65361 .56708 m .64484 .56186 L .67374 .50784 L p .763 .673 .763 r
F P
0 g
s
.67374 .50784 m .68483 .51286 L .65361 .56708 L p .763 .673 .763 r
F P
0 g
s
.33963 .65747 m .34813 .66636 L .39932 .68538 L p .686 .149 0 r
F P
0 g
s
.40542 .69169 m .39932 .68538 L .34813 .66636 L p .629 .067 0 r
F P
0 g
s
.69591 .51829 m .68483 .51286 L .70583 .45602 L p .695 .615 .763 r
F P
0 g
s
.70583 .45602 m .71867 .4613 L .69591 .51829 L p .695 .615 .763 r
F P
0 g
s
.464 .69828 m .46743 .69975 L .51966 .68564 L p .184 .713 .716 r
F P
0 g
s
.51999 .68384 m .51966 .68564 L .46743 .69975 L p .456 .885 .887 r
F P
0 g
s
.51966 .68564 m .51999 .68384 L .56869 .65524 L p .775 .959 .929 r
F P
0 g
s
.56579 .65085 m .56869 .65524 L .51999 .68384 L p .821 .928 .904 r
F P
0 g
s
.56869 .65524 m .56579 .65085 L .60813 .61051 L p .843 .831 .835 r
F P
0 g
s
.68483 .51286 m .67374 .50784 L .69304 .45169 L p .713 .624 .757 r
F P
0 g
s
.69304 .45169 m .70583 .45602 L .68483 .51286 L p .713 .624 .757 r
F P
0 g
s
.636 .55648 m .64484 .56186 L .60813 .61051 L p .816 .735 .775 r
F P
0 g
s
.64484 .56186 m .636 .55648 L .66261 .50328 L p .774 .677 .756 r
F P
0 g
s
.66261 .50328 m .67374 .50784 L .64484 .56186 L p .774 .677 .756 r
F P
0 g
s
.40542 .69169 m .41167 .69651 L .464 .69828 L p .422 0 0 r
F P
0 g
s
.46743 .69975 m .464 .69828 L .41167 .69651 L p .233 0 0 r
F P
0 g
s
.60206 .60476 m .60813 .61051 L .56579 .65085 L p .847 .809 .813 r
F P
0 g
s
.60813 .61051 m .60206 .60476 L .636 .55648 L p .816 .735 .775 r
F P
0 g
s
.67374 .50784 m .66261 .50328 L .68027 .44837 L p .73 .634 .751 r
F P
0 g
s
.68027 .44837 m .69304 .45169 L .67374 .50784 L p .73 .634 .751 r
F P
0 g
s
.21931 .53619 m .23113 .54742 L .26555 .59172 L p 0 0 .52 r
F P
0 g
s
.27571 .60295 m .26555 .59172 L .23113 .54742 L p 0 .003 .541 r
F P
0 g
s
.62709 .55094 m .636 .55648 L .60206 .60476 L p .821 .729 .764 r
F P
0 g
s
.636 .55648 m .62709 .55094 L .65145 .49918 L p .785 .68 .748 r
F P
0 g
s
.65145 .49918 m .66261 .50328 L .636 .55648 L p .785 .68 .748 r
F P
0 g
s
.28604 .614 m .29655 .62455 L .33963 .65747 L p .682 .149 0 r
F P
0 g
s
.34813 .66636 m .33963 .65747 L .29655 .62455 L p .619 .08 0 r
F P
0 g
s
.66261 .50328 m .65145 .49918 L .66753 .44609 L p .747 .643 .746 r
F P
0 g
s
.66753 .44609 m .68027 .44837 L .66261 .50328 L p .747 .643 .746 r
F P
0 g
s
.34813 .66636 m .35681 .67405 L .40542 .69169 L p .629 .067 0 r
F P
0 g
s
.41167 .69651 m .40542 .69169 L .35681 .67405 L p .525 0 0 r
F P
0 g
s
.51999 .68384 m .52033 .68034 L .56579 .65085 L p .821 .928 .904 r
F P
0 g
s
.56284 .64513 m .56579 .65085 L .52033 .68034 L p .844 .89 .872 r
F P
0 g
s
.56579 .65085 m .56284 .64513 L .60206 .60476 L p .847 .809 .813 r
F P
0 g
s
.74448 .47441 m .73155 .46746 L .74293 .41048 L p .58 .545 .781 r
F P
0 g
s
.73155 .46746 m .71867 .4613 L .72898 .40458 L p .606 .56 .776 r
F P
0 g
s
.72898 .40458 m .74293 .41048 L .73155 .46746 L p .606 .56 .776 r
F P
0 g
s
.71867 .4613 m .70583 .45602 L .71515 .4 L p .633 .575 .772 r
F P
0 g
s
.71515 .4 m .72898 .40458 L .71867 .4613 L p .633 .575 .772 r
F P
0 g
s
.75747 .48204 m .74448 .47441 L .75701 .41755 L p .554 .532 .785 r
F P
0 g
s
.74293 .41048 m .75701 .41755 L .74448 .47441 L p .58 .545 .781 r
F P
0 g
s
.59594 .59821 m .60206 .60476 L .56284 .64513 L p .849 .79 .794 r
F P
0 g
s
.60206 .60476 m .59594 .59821 L .62709 .55094 L p .821 .729 .764 r
F P
0 g
s
.46743 .69975 m .47094 .69937 L .51999 .68384 L p .456 .885 .887 r
F P
0 g
s
.52033 .68034 m .51999 .68384 L .47094 .69937 L p .658 .95 .952 r
F P
0 g
s
.70583 .45602 m .69304 .45169 L .70143 .39681 L p .66 .591 .767 r
F P
0 g
s
.70143 .39681 m .71515 .4 L .70583 .45602 L p .66 .591 .767 r
F P
0 g
s
.77051 .49025 m .75747 .48204 L .77123 .42566 L p .53 .52 .789 r
F P
0 g
s
.75701 .41755 m .77123 .42566 L .75747 .48204 L p .554 .532 .785 r
F P
0 g
s
.78359 .4989 m .77051 .49025 L .78558 .43464 L p .507 .51 .794 r
F P
0 g
s
.77123 .42566 m .78558 .43464 L .77051 .49025 L p .53 .52 .789 r
F P
0 g
s
.69304 .45169 m .68027 .44837 L .68782 .39511 L p .685 .606 .761 r
F P
0 g
s
.68782 .39511 m .70143 .39681 L .69304 .45169 L p .685 .606 .761 r
F P
0 g
s
.64026 .49556 m .65145 .49918 L .62709 .55094 L p .794 .683 .742 r
F P
0 g
s
.65145 .49918 m .64026 .49556 L .6548 .44486 L p .762 .652 .74 r
F P
0 g
s
.6548 .44486 m .66753 .44609 L .65145 .49918 L p .762 .652 .74 r
F P
0 g
s
.61813 .54524 m .62709 .55094 L .59594 .59821 L p .825 .724 .753 r
F P
0 g
s
.62709 .55094 m .61813 .54524 L .64026 .49556 L p .794 .683 .742 r
F P
0 g
s
.79672 .50786 m .78359 .4989 L .80007 .44431 L p .487 .502 .799 r
F P
0 g
s
.78558 .43464 m .80007 .44431 L .78359 .4989 L p .507 .51 .794 r
F P
0 g
s
.68027 .44837 m .66753 .44609 L .67428 .39493 L p .71 .62 .756 r
F P
0 g
s
.67428 .39493 m .68782 .39511 L .68027 .44837 L p .71 .62 .756 r
F P
0 g
s
.80988 .51698 m .79672 .50786 L .81467 .45448 L p .47 .498 .805 r
F P
0 g
s
.80007 .44431 m .81467 .45448 L .79672 .50786 L p .487 .502 .799 r
F P
0 g
s
.41167 .69651 m .41806 .69954 L .46743 .69975 L p .233 0 0 r
F P
0 g
s
.47094 .69937 m .46743 .69975 L .41806 .69954 L p .064 .628 .763 r
F P
0 g
s
.82306 .52612 m .80988 .51698 L .82938 .46493 L p .456 .497 .813 r
F P
0 g
s
.81467 .45448 m .82938 .46493 L .80988 .51698 L p .47 .498 .805 r
F P
0 g
s
.23113 .54742 m .24308 .55875 L .27571 .60295 L p 0 .003 .541 r
F P
0 g
s
.28604 .614 m .27571 .60295 L .24308 .55875 L p 0 .04 .582 r
F P
0 g
s
.66753 .44609 m .6548 .44486 L .6608 .3963 L p .732 .634 .749 r
F P
0 g
s
.6608 .3963 m .67428 .39493 L .66753 .44609 L p .732 .634 .749 r
F P
0 g
s
.62903 .4924 m .64026 .49556 L .61813 .54524 L p .803 .686 .735 r
F P
0 g
s
.64026 .49556 m .62903 .4924 L .64206 .44469 L p .776 .66 .735 r
F P
0 g
s
.64206 .44469 m .6548 .44486 L .64026 .49556 L p .776 .66 .735 r
F P
0 g
s
.83625 .53514 m .82306 .52612 L .84418 .47545 L p .445 .5 .822 r
F P
0 g
s
.82938 .46493 m .84418 .47545 L .82306 .52612 L p .456 .497 .813 r
F P
0 g
s
.56284 .64513 m .55985 .63802 L .59594 .59821 L p .849 .79 .794 r
F P
0 g
s
.58974 .59085 m .59594 .59821 L .55985 .63802 L p .849 .772 .777 r
F P
0 g
s
.59594 .59821 m .58974 .59085 L .61813 .54524 L p .825 .724 .753 r
F P
0 g
s
.52033 .68034 m .52068 .67501 L .56284 .64513 L p .844 .89 .872 r
F P
0 g
s
.55985 .63802 m .56284 .64513 L .52068 .67501 L p .854 .853 .841 r
F P
0 g
s
.84418 .47545 m .85906 .48583 L .83625 .53514 L p .445 .5 .822 r
F P
0 g
s
.6091 .53938 m .61813 .54524 L .58974 .59085 L p .828 .719 .744 r
F P
0 g
s
.61813 .54524 m .6091 .53938 L .62903 .4924 L p .803 .686 .735 r
F P
0 g
s
.6548 .44486 m .64206 .44469 L .64737 .39921 L p .753 .646 .743 r
F P
0 g
s
.64737 .39921 m .6608 .3963 L .6548 .44486 L p .753 .646 .743 r
F P
0 g
s
.47094 .69937 m .47453 .69694 L .52033 .68034 L p .658 .95 .952 r
F P
0 g
s
.52068 .67501 m .52033 .68034 L .47453 .69694 L p .766 .936 .939 r
F P
0 g
s
.29655 .62455 m .30725 .63426 L .34813 .66636 L p .619 .08 0 r
F P
0 g
s
.35681 .67405 m .34813 .66636 L .30725 .63426 L p .513 0 0 r
F P
0 g
s
.35681 .67405 m .36569 .68022 L .41167 .69651 L p .525 0 0 r
F P
0 g
s
.41167 .69651 m .36569 .68022 L p .41079 .69686 L .338 0 0 r
F P
0 g
s
.41806 .69954 m .4246 .70054 L .47094 .69937 L p .064 .628 .763 r
F P
0 g
s
.36569 .68022 m .37477 .68456 L .41806 .69954 L p .338 0 0 r
F P
0 g
s
.38405 .68682 m .4246 .70054 L p .38185 .68683 L 0 .504 .816 r
F P
0 g
s
.37477 .68456 m .37655 .685 L p .38185 .68683 L 0 .504 .816 r
F P
0 g
s
.37655 .685 m .38405 .68682 L p .38185 .68683 L 0 .504 .816 r
F P
0 g
s
.41806 .69954 m .41679 .69894 L p .41079 .69686 L .338 0 0 r
F P
0 g
s
.41679 .69894 m .41167 .69651 L p .41079 .69686 L .338 0 0 r
F P
0 g
s
.61775 .48971 m .62903 .4924 L .6091 .53938 L p .81 .688 .729 r
F P
0 g
s
.62903 .4924 m .61775 .48971 L .6293 .44555 L p .789 .668 .73 r
F P
0 g
s
.6293 .44555 m .64206 .44469 L .62903 .4924 L p .789 .668 .73 r
F P
0 g
s
.64206 .44469 m .6293 .44555 L .63396 .40363 L p .771 .657 .737 r
F P
0 g
s
.63396 .40363 m .64737 .39921 L .64206 .44469 L p .771 .657 .737 r
F P
0 g
s
.70143 .39681 m .68782 .39511 L .68461 .34684 L p .641 .596 .787 r
F P
0 g
s
.68782 .39511 m .67428 .39493 L .67116 .34893 L p .676 .615 .779 r
F P
0 g
s
.67116 .34893 m .68461 .34684 L .68782 .39511 L p .676 .615 .779 r
F P
0 g
s
.67428 .39493 m .6608 .3963 L .65783 .35293 L p .708 .632 .77 r
F P
0 g
s
.65783 .35293 m .67116 .34893 L .67428 .39493 L p .708 .632 .77 r
F P
0 g
s
.71515 .4 m .70143 .39681 L .69818 .34666 L p .603 .574 .794 r
F P
0 g
s
.68461 .34684 m .69818 .34666 L .70143 .39681 L p .641 .596 .787 r
F P
0 g
s
.55985 .63802 m .55682 .62948 L .58974 .59085 L p .849 .772 .777 r
F P
0 g
s
.58349 .58267 m .58974 .59085 L .55682 .62948 L p .848 .757 .762 r
F P
0 g
s
.58974 .59085 m .58349 .58267 L .6091 .53938 L p .828 .719 .744 r
F P
0 g
s
.60001 .53335 m .6091 .53938 L .58349 .58267 L p .831 .715 .736 r
F P
0 g
s
.6091 .53938 m .60001 .53335 L .61775 .48971 L p .81 .688 .729 r
F P
0 g
s
.6608 .3963 m .64737 .39921 L .64457 .35884 L p .736 .646 .76 r
F P
0 g
s
.64457 .35884 m .65783 .35293 L .6608 .3963 L p .736 .646 .76 r
F P
0 g
s
.47453 .69694 m .47094 .69937 L .4246 .70054 L p .394 .83 .951 r
F P
0 g
s
.72898 .40458 m .71515 .4 L .71192 .34831 L p .562 .552 .8 r
F P
0 g
s
.69818 .34666 m .71192 .34831 L .71515 .4 L p .603 .574 .794 r
F P
0 g
s
.52068 .67501 m .52103 .66777 L .55985 .63802 L p .854 .853 .841 r
F P
0 g
s
.55682 .62948 m .55985 .63802 L .52103 .66777 L p .857 .821 .813 r
F P
0 g
s
.61652 .44739 m .6293 .44555 L .61775 .48971 L p .801 .675 .725 r
F P
0 g
s
.6293 .44555 m .61652 .44739 L .62055 .4095 L p .787 .667 .731 r
F P
0 g
s
.62055 .4095 m .63396 .40363 L .6293 .44555 L p .787 .667 .731 r
F P
0 g
s
.60641 .48746 m .61775 .48971 L .60001 .53335 L p .817 .69 .724 r
F P
0 g
s
.61775 .48971 m .60641 .48746 L .61652 .44739 L p .801 .675 .725 r
F P
0 g
s
.64737 .39921 m .63396 .40363 L .63138 .36662 L p .759 .659 .751 r
F P
0 g
s
.63138 .36662 m .64457 .35884 L .64737 .39921 L p .759 .659 .751 r
F P
0 g
s
.24308 .55875 m .25517 .56991 L .28604 .614 L p 0 .04 .582 r
F P
0 g
s
.29655 .62455 m .28604 .614 L .25517 .56991 L p 0 .098 .64 r
F P
0 g
s
.74293 .41048 m .72898 .40458 L .72583 .35171 L p .521 .529 .804 r
F P
0 g
s
.71192 .34831 m .72583 .35171 L .72898 .40458 L p .562 .552 .8 r
F P
0 g
s
.21931 .53619 m .20758 .52532 L .18911 .47507 L p 0 .275 .777 r
F P
0 g
s
.63396 .40363 m .62055 .4095 L .61822 .37619 L p .78 .669 .741 r
F P
0 g
s
.61822 .37619 m .63138 .36662 L .63396 .40363 L p .78 .669 .741 r
F P
0 g
s
.47453 .69694 m .47818 .69231 L .52068 .67501 L p .766 .936 .939 r
F P
0 g
s
.52103 .66777 m .52068 .67501 L .47818 .69231 L p .816 .895 .899 r
F P
0 g
s
.58349 .58267 m .57718 .57371 L .60001 .53335 L p .831 .715 .736 r
F P
0 g
s
.59086 .52717 m .60001 .53335 L .57718 .57371 L p .833 .711 .729 r
F P
0 g
s
.60001 .53335 m .59086 .52717 L .60641 .48746 L p .817 .69 .724 r
F P
0 g
s
.55682 .62948 m .55375 .61952 L .58349 .58267 L p .848 .757 .762 r
F P
0 g
s
.57718 .57371 m .58349 .58267 L .55375 .61952 L p .847 .744 .75 r
F P
0 g
s
.75701 .41755 m .74293 .41048 L .73993 .35675 L p .479 .505 .807 r
F P
0 g
s
.72583 .35171 m .73993 .35675 L .74293 .41048 L p .521 .529 .804 r
F P
0 g
s
.60369 .45016 m .61652 .44739 L .60641 .48746 L p .811 .681 .72 r
F P
0 g
s
.61652 .44739 m .60369 .45016 L .60712 .41672 L p .801 .675 .725 r
F P
0 g
s
.60712 .41672 m .62055 .4095 L .61652 .44739 L p .801 .675 .725 r
F P
0 g
s
.59502 .48562 m .60641 .48746 L .59086 .52717 L p .823 .692 .72 r
F P
0 g
s
.60641 .48746 m .59502 .48562 L .60369 .45016 L p .811 .681 .72 r
F P
0 g
s
.30725 .63426 m .31816 .64282 L .35681 .67405 L p .513 0 0 r
F P
0 g
s
.36569 .68022 m .35681 .67405 L .31816 .64282 L p 0 .173 .639 r
F P
0 g
s
.4246 .70054 m .41806 .69954 L .37477 .68456 L p 0 .504 .816 r
F P
0 g
s
.52103 .66777 m .52138 .65858 L .55682 .62948 L p .857 .821 .813 r
F P
0 g
s
.55375 .61952 m .55682 .62948 L .52138 .65858 L p .856 .793 .789 r
F P
0 g
s
.62055 .4095 m .60712 .41672 L .60507 .38745 L p .796 .677 .733 r
F P
0 g
s
.60507 .38745 m .61822 .37619 L .62055 .4095 L p .796 .677 .733 r
F P
0 g
s
.67116 .34893 m .65783 .35293 L .64591 .31758 L p .695 .651 .802 r
F P
0 g
s
.65783 .35293 m .64457 .35884 L .63375 .3262 L p .729 .664 .785 r
F P
0 g
s
.63375 .3262 m .64591 .31758 L .65783 .35293 L p .729 .664 .785 r
F P
0 g
s
.77123 .42566 m .75701 .41755 L .75423 .36328 L p .438 .483 .809 r
F P
0 g
s
.73993 .35675 m .75423 .36328 L .75701 .41755 L p .479 .505 .807 r
F P
0 g
s
.64457 .35884 m .63138 .36662 L .62167 .33692 L p .757 .674 .77 r
F P
0 g
s
.62167 .33692 m .63375 .3262 L .64457 .35884 L p .757 .674 .77 r
F P
0 g
s
.68461 .34684 m .67116 .34893 L .65819 .3111 L p .652 .633 .818 r
F P
0 g
s
.64591 .31758 m .65819 .3111 L .67116 .34893 L p .695 .651 .802 r
F P
0 g
s
.4246 .70054 m .43128 .69927 L .47453 .69694 L p .394 .83 .951 r
F P
0 g
s
.47818 .69231 m .47453 .69694 L .43128 .69927 L p .622 .894 .988 r
F P
0 g
s
.63138 .36662 m .61822 .37619 L .60964 .34964 L p .78 .682 .755 r
F P
0 g
s
.60964 .34964 m .62167 .33692 L .63138 .36662 L p .78 .682 .755 r
F P
0 g
s
.57718 .57371 m .57082 .56399 L .59086 .52717 L p .833 .711 .729 r
F P
0 g
s
.58165 .52084 m .59086 .52717 L .57082 .56399 L p .835 .707 .723 r
F P
0 g
s
.59086 .52717 m .58165 .52084 L .59502 .48562 L p .823 .692 .72 r
F P
0 g
s
.5908 .45377 m .60369 .45016 L .59502 .48562 L p .82 .686 .716 r
F P
0 g
s
.60369 .45016 m .5908 .45377 L .59365 .42519 L p .813 .682 .72 r
F P
0 g
s
.59365 .42519 m .60712 .41672 L .60369 .45016 L p .813 .682 .72 r
F P
0 g
s
.55375 .61952 m .55066 .60817 L .57718 .57371 L p .847 .744 .75 r
F P
0 g
s
.57082 .56399 m .57718 .57371 L .55066 .60817 L p .846 .733 .739 r
F P
0 g
s
.69818 .34666 m .68461 .34684 L .67061 .30677 L p .602 .611 .833 r
F P
0 g
s
.65819 .3111 m .67061 .30677 L .68461 .34684 L p .652 .633 .818 r
F P
0 g
s
.18911 .47507 m .20213 .48554 L .21931 .53619 L p 0 .275 .777 r
F P
0 g
s
.23113 .54742 m .21931 .53619 L .20213 .48554 L p .019 .276 .775 r
F P
0 g
s
.60712 .41672 m .59365 .42519 L .5919 .40025 L p .81 .684 .725 r
F P
0 g
s
.5919 .40025 m .60507 .38745 L .60712 .41672 L p .81 .684 .725 r
F P
0 g
s
.58356 .48415 m .59502 .48562 L .58165 .52084 L p .828 .694 .716 r
F P
0 g
s
.59502 .48562 m .58356 .48415 L .5908 .45377 L p .82 .686 .716 r
F P
0 g
s
.47818 .69231 m .4819 .68537 L .52103 .66777 L p .816 .895 .899 r
F P
0 g
s
.52138 .65858 m .52103 .66777 L .4819 .68537 L p .837 .851 .856 r
F P
0 g
s
.61822 .37619 m .60507 .38745 L .59765 .36425 L p .798 .687 .742 r
F P
0 g
s
.59765 .36425 m .60964 .34964 L .61822 .37619 L p .798 .687 .742 r
F P
0 g
s
.78558 .43464 m .77123 .42566 L .76874 .37112 L p .4 .463 .81 r
F P
0 g
s
.75423 .36328 m .76874 .37112 L .77123 .42566 L p .438 .483 .809 r
F P
0 g
s
.25517 .56991 m .26742 .5806 L .29655 .62455 L p 0 .098 .64 r
F P
0 g
s
.30725 .63426 m .29655 .62455 L .26742 .5806 L p 0 .176 .708 r
F P
0 g
s
.71192 .34831 m .69818 .34666 L .68319 .30457 L p .543 .583 .845 r
F P
0 g
s
.67061 .30677 m .68319 .30457 L .69818 .34666 L p .602 .611 .833 r
F P
0 g
s
.52138 .65858 m .52174 .64744 L .55375 .61952 L p .856 .793 .789 r
F P
0 g
s
.55066 .60817 m .55375 .61952 L .52174 .64744 L p .854 .77 .769 r
F P
0 g
s
.60507 .38745 m .5919 .40025 L .58566 .38059 L p .811 .691 .731 r
F P
0 g
s
.58566 .38059 m .59765 .36425 L .60507 .38745 L p .811 .691 .731 r
F P
0 g
s
.57082 .56399 m .5644 .55355 L .58165 .52084 L p .835 .707 .723 r
F P
0 g
s
.57237 .51438 m .58165 .52084 L .5644 .55355 L p .837 .704 .718 r
F P
0 g
s
.58165 .52084 m .57237 .51438 L .58356 .48415 L p .828 .694 .716 r
F P
0 g
s
.57784 .45812 m .5908 .45377 L .58356 .48415 L p .827 .69 .713 r
F P
0 g
s
.5908 .45377 m .57784 .45812 L .58011 .43475 L p .822 .688 .715 r
F P
0 g
s
.58011 .43475 m .59365 .42519 L .5908 .45377 L p .822 .688 .715 r
F P
0 g
s
.55066 .60817 m .54753 .5955 L .57082 .56399 L p .846 .733 .739 r
F P
0 g
s
.5644 .55355 m .57082 .56399 L .54753 .5955 L p .844 .723 .73 r
F P
0 g
s
.59365 .42519 m .58011 .43475 L .57869 .41442 L p .821 .689 .718 r
F P
0 g
s
.57869 .41442 m .5919 .40025 L .59365 .42519 L p .821 .689 .718 r
F P
0 g
s
.80007 .44431 m .78558 .43464 L .78345 .38008 L p .366 .446 .811 r
F P
0 g
s
.76874 .37112 m .78345 .38008 L .78558 .43464 L p .4 .463 .81 r
F P
0 g
s
.57203 .48301 m .58356 .48415 L .57237 .51438 L p .832 .695 .712 r
F P
0 g
s
.58356 .48415 m .57203 .48301 L .57784 .45812 L p .827 .69 .713 r
F P
0 g
s
.43128 .69927 m .4246 .70054 L .38405 .68682 L p .286 .7 .972 r
F P
0 g
s
.72583 .35171 m .71192 .34831 L .69596 .30444 L p .477 .55 .852 r
F P
0 g
s
.68319 .30457 m .69596 .30444 L .71192 .34831 L p .543 .583 .845 r
F P
0 g
s
.31816 .64282 m .32929 .64992 L .36569 .68022 L p 0 .173 .639 r
F P
0 g
s
.37477 .68456 m .36569 .68022 L .32929 .64992 L p 0 .347 .801 r
F P
0 g
s
.43128 .69927 m .43809 .69559 L .47818 .69231 L p .622 .894 .988 r
F P
0 g
s
.4819 .68537 m .47818 .69231 L .43809 .69559 L p .736 .877 .946 r
F P
0 g
s
.63375 .3262 m .62167 .33692 L .60533 .31656 L p .769 .703 .79 r
F P
0 g
s
.62167 .33692 m .60964 .34964 L .59528 .33166 L p .79 .704 .769 r
F P
0 g
s
.59528 .33166 m .60533 .31656 L .62167 .33692 L p .79 .704 .769 r
F P
0 g
s
.64591 .31758 m .63375 .3262 L .61545 .30356 L p .74 .701 .814 r
F P
0 g
s
.60533 .31656 m .61545 .30356 L .63375 .3262 L p .769 .703 .79 r
F P
0 g
s
.4819 .68537 m .48568 .67608 L .52138 .65858 L p .837 .851 .856 r
F P
0 g
s
.52174 .64744 m .52138 .65858 L .48568 .67608 L p .844 .814 .82 r
F P
0 g
s
.60964 .34964 m .59765 .36425 L .58528 .3487 L p .806 .703 .752 r
F P
0 g
s
.58528 .3487 m .59528 .33166 L .60964 .34964 L p .806 .703 .752 r
F P
0 g
s
.5919 .40025 m .57869 .41442 L .57366 .39848 L p .822 .693 .722 r
F P
0 g
s
.57366 .39848 m .58566 .38059 L .5919 .40025 L p .822 .693 .722 r
F P
0 g
s
.52174 .64744 m .52211 .63441 L .55066 .60817 L p .854 .77 .769 r
F P
0 g
s
.54753 .5955 m .55066 .60817 L .52211 .63441 L p .851 .751 .753 r
F P
0 g
s
.65819 .3111 m .64591 .31758 L .62566 .29272 L p .701 .695 .841 r
F P
0 g
s
.61545 .30356 m .62566 .29272 L .64591 .31758 L p .74 .701 .814 r
F P
0 g
s
.20213 .48554 m .21521 .49629 L .23113 .54742 L p .019 .276 .775 r
F P
0 g
s
.24308 .55875 m .23113 .54742 L .21521 .49629 L p .056 .29 .779 r
F P
0 g
s
.5644 .55355 m .55795 .54248 L .57237 .51438 L p .837 .704 .718 r
F P
0 g
s
.56304 .50779 m .57237 .51438 L .55795 .54248 L p .838 .702 .713 r
F P
0 g
s
.57237 .51438 m .56304 .50779 L .57203 .48301 L p .832 .695 .712 r
F P
0 g
s
.59765 .36425 m .58566 .38059 L .57529 .36755 L p .817 .702 .737 r
F P
0 g
s
.57529 .36755 m .58528 .3487 L .59765 .36425 L p .817 .702 .737 r
F P
0 g
s
.54753 .5955 m .54438 .5816 L .5644 .55355 L p .844 .723 .73 r
F P
0 g
s
.55795 .54248 m .5644 .55355 L .54438 .5816 L p .843 .715 .722 r
F P
0 g
s
.5648 .4631 m .57784 .45812 L .57203 .48301 L p .832 .693 .71 r
F P
0 g
s
.57784 .45812 m .5648 .4631 L .56651 .44526 L p .83 .692 .711 r
F P
0 g
s
.56651 .44526 m .58011 .43475 L .57784 .45812 L p .83 .692 .711 r
F P
0 g
s
.81467 .45448 m .80007 .44431 L .79838 .38992 L p .337 .434 .813 r
F P
0 g
s
.78345 .38008 m .79838 .38992 L .80007 .44431 L p .366 .446 .811 r
F P
0 g
s
.58011 .43475 m .56651 .44526 L .56542 .42977 L p .829 .692 .713 r
F P
0 g
s
.56542 .42977 m .57869 .41442 L .58011 .43475 L p .829 .692 .713 r
F P
0 g
s
.73993 .35675 m .72583 .35171 L .70894 .30628 L p .406 .514 .855 r
F P
0 g
s
.69596 .30444 m .70894 .30628 L .72583 .35171 L p .477 .55 .852 r
F P
0 g
s
.67061 .30677 m .65819 .3111 L .63598 .28411 L p .649 .684 .87 r
F P
0 g
s
.62566 .29272 m .63598 .28411 L .65819 .3111 L p .701 .695 .841 r
F P
0 g
s
.56042 .48213 m .57203 .48301 L .56304 .50779 L p .835 .696 .709 r
F P
0 g
s
.57203 .48301 m .56042 .48213 L .5648 .4631 L p .832 .693 .71 r
F P
0 g
s
.26742 .5806 m .27986 .59054 L .30725 .63426 L p 0 .176 .708 r
F P
0 g
s
.31816 .64282 m .30725 .63426 L .27986 .59054 L p 0 .268 .775 r
F P
0 g
s
.58566 .38059 m .57366 .39848 L .56531 .38798 L p .826 .7 .726 r
F P
0 g
s
.56531 .38798 m .57529 .36755 L .58566 .38059 L p .826 .7 .726 r
F P
0 g
s
.57869 .41442 m .56542 .42977 L .56161 .41767 L p .83 .695 .715 r
F P
0 g
s
.56161 .41767 m .57366 .39848 L .57869 .41442 L p .83 .695 .715 r
F P
0 g
s
.52211 .63441 m .52248 .61957 L .54753 .5955 L p .851 .751 .753 r
F P
0 g
s
.54438 .5816 m .54753 .5955 L .52248 .61957 L p .848 .736 .739 r
F P
0 g
s
.48568 .67608 m .48951 .66445 L .52174 .64744 L p .844 .814 .82 r
F P
0 g
s
.52211 .63441 m .52174 .64744 L .48951 .66445 L p .847 .784 .791 r
F P
0 g
s
.43809 .69559 m .44503 .68936 L .4819 .68537 L p .736 .877 .946 r
F P
0 g
s
.48568 .67608 m .4819 .68537 L .44503 .68936 L p .788 .841 .891 r
F P
0 g
s
.54438 .5816 m .54121 .56658 L .55795 .54248 L p .843 .715 .722 r
F P
0 g
s
.55145 .53083 m .55795 .54248 L .54121 .56658 L p .842 .709 .716 r
F P
0 g
s
.55795 .54248 m .55145 .53083 L .56304 .50779 L p .838 .702 .713 r
F P
0 g
s
.55365 .50108 m .56304 .50779 L .55145 .53083 L p .839 .7 .71 r
F P
0 g
s
.56304 .50779 m .55365 .50108 L .56042 .48213 L p .835 .696 .709 r
F P
0 g
s
.68319 .30457 m .67061 .30677 L .64645 .27774 L p .58 .665 .896 r
F P
0 g
s
.63598 .28411 m .64645 .27774 L .67061 .30677 L p .649 .684 .87 r
F P
0 g
s
.38405 .68682 m .39351 .68677 L .43128 .69927 L p .286 .7 .972 r
F P
0 g
s
.43809 .69559 m .43128 .69927 L .39351 .68677 L p .525 .784 .991 r
F P
0 g
s
.82938 .46493 m .81467 .45448 L .8135 .40041 L p .314 .426 .816 r
F P
0 g
s
.79838 .38992 m .8135 .40041 L .81467 .45448 L p .337 .434 .813 r
F P
0 g
s
.57366 .39848 m .56161 .41767 L .55532 .40978 L p .832 .699 .717 r
F P
0 g
s
.55532 .40978 m .56531 .38798 L .57366 .39848 L p .832 .699 .717 r
F P
0 g
s
.55167 .46858 m .5648 .4631 L .56042 .48213 L p .836 .695 .707 r
F P
0 g
s
.5648 .4631 m .55167 .46858 L .55281 .45652 L p .835 .695 .708 r
F P
0 g
s
.55281 .45652 m .56651 .44526 L .5648 .4631 L p .835 .695 .708 r
F P
0 g
s
.56651 .44526 m .55281 .45652 L .55208 .44607 L p .835 .695 .709 r
F P
0 g
s
.55208 .44607 m .56542 .42977 L .56651 .44526 L p .835 .695 .709 r
F P
0 g
s
.75423 .36328 m .73993 .35675 L .72215 .30996 L p .333 .474 .852 r
F P
0 g
s
.70894 .30628 m .72215 .30996 L .73993 .35675 L p .406 .514 .855 r
F P
0 g
s
.32929 .64992 m .34063 .65527 L .37477 .68456 L p 0 .347 .801 r
F P
0 g
s
.38405 .68682 m .37477 .68456 L .34063 .65527 L p .146 .507 .911 r
F P
0 g
s
.60533 .31656 m .59528 .33166 L .576 .32355 L p .808 .729 .778 r
F P
0 g
s
.59528 .33166 m .58528 .3487 L .56871 .34194 L p .819 .721 .757 r
F P
0 g
s
.56871 .34194 m .576 .32355 L .59528 .33166 L p .819 .721 .757 r
F P
0 g
s
.21521 .49629 m .22838 .50709 L .24308 .55875 L p .056 .29 .779 r
F P
0 g
s
.25517 .56991 m .24308 .55875 L .22838 .50709 L p .108 .315 .788 r
F P
0 g
s
.61545 .30356 m .60533 .31656 L .58334 .30706 L p .792 .739 .804 r
F P
0 g
s
.576 .32355 m .58334 .30706 L .60533 .31656 L p .808 .729 .778 r
F P
0 g
s
.58528 .3487 m .57529 .36755 L .56144 .36205 L p .826 .714 .74 r
F P
0 g
s
.56144 .36205 m .56871 .34194 L .58528 .3487 L p .826 .714 .74 r
F P
0 g
s
.52248 .61957 m .52285 .60306 L .54438 .5816 L p .848 .736 .739 r
F P
0 g
s
.54121 .56658 m .54438 .5816 L .52285 .60306 L p .846 .724 .729 r
F P
0 g
s
.54874 .48146 m .56042 .48213 L .55365 .50108 L p .838 .697 .707 r
F P
0 g
s
.56042 .48213 m .54874 .48146 L .55167 .46858 L p .836 .695 .707 r
F P
0 g
s
.56542 .42977 m .55208 .44607 L .54952 .43793 L p .835 .696 .71 r
F P
0 g
s
.54952 .43793 m .56161 .41767 L .56542 .42977 L p .835 .696 .71 r
F P
0 g
s
.48951 .66445 m .49339 .65054 L .52211 .63441 L p .847 .784 .791 r
F P
0 g
s
.52248 .61957 m .52211 .63441 L .49339 .65054 L p .846 .76 .768 r
F P
0 g
s
.57529 .36755 m .56531 .38798 L .55419 .3837 L p .832 .708 .727 r
F P
0 g
s
.55419 .3837 m .56144 .36205 L .57529 .36755 L p .832 .708 .727 r
F P
0 g
s
.62566 .29272 m .61545 .30356 L .59073 .2926 L p .769 .75 .835 r
F P
0 g
s
.58334 .30706 m .59073 .2926 L .61545 .30356 L p .792 .739 .804 r
F P
0 g
s
.54121 .56658 m .53801 .55061 L .55145 .53083 L p .842 .709 .716 r
F P
0 g
s
.54492 .51871 m .55145 .53083 L .53801 .55061 L p .841 .704 .712 r
F P
0 g
s
.55145 .53083 m .54492 .51871 L .55365 .50108 L p .839 .7 .71 r
F P
0 g
s
.69596 .30444 m .68319 .30457 L .65709 .27358 L p .49 .633 .916 r
F P
0 g
s
.64645 .27774 m .65709 .27358 L .68319 .30457 L p .58 .665 .896 r
F P
0 g
s
.5442 .49428 m .55365 .50108 L .54492 .51871 L p .839 .698 .707 r
F P
0 g
s
.55365 .50108 m .5442 .49428 L .54874 .48146 L p .838 .697 .707 r
F P
0 g
s
.84418 .47545 m .82938 .46493 L .8288 .4113 L p .297 .423 .821 r
F P
0 g
s
.8135 .40041 m .8288 .4113 L .82938 .46493 L p .314 .426 .816 r
F P
0 g
s
.56161 .41767 m .54952 .43793 L .54529 .43266 L p .836 .698 .711 r
F P
0 g
s
.54529 .43266 m .55532 .40978 L .56161 .41767 L p .836 .698 .711 r
F P
0 g
s
.44503 .68936 m .45207 .68055 L .48568 .67608 L p .788 .841 .891 r
F P
0 g
s
.48951 .66445 m .48568 .67608 L .45207 .68055 L p .813 .806 .844 r
F P
0 g
s
.56531 .38798 m .55532 .40978 L .54694 .40664 L p .835 .703 .718 r
F P
0 g
s
.54694 .40664 m .55419 .3837 L .56531 .38798 L p .835 .703 .718 r
F P
0 g
s
.52285 .60306 m .52322 .58505 L .54121 .56658 L p .846 .724 .729 r
F P
0 g
s
.53801 .55061 m .54121 .56658 L .52322 .58505 L p .844 .714 .72 r
F P
0 g
s
.27986 .59054 m .29249 .59944 L .31816 .64282 L p 0 .268 .775 r
F P
0 g
s
.32929 .64992 m .31816 .64282 L .29249 .59944 L p .092 .363 .829 r
F P
0 g
s
.63598 .28411 m .62566 .29272 L .59821 .28024 L p .734 .759 .873 r
F P
0 g
s
.59073 .2926 m .59821 .28024 L .62566 .29272 L p .769 .75 .835 r
F P
0 g
s
.53845 .47442 m .55167 .46858 L .54874 .48146 L p .839 .696 .705 r
F P
0 g
s
.55167 .46858 m .53845 .47442 L .53902 .46833 L p .839 .696 .706 r
F P
0 g
s
.53902 .46833 m .55281 .45652 L .55167 .46858 L p .839 .696 .706 r
F P
0 g
s
.55281 .45652 m .53902 .46833 L .53864 .46306 L p .839 .696 .706 r
F P
0 g
s
.53864 .46306 m .55208 .44607 L .55281 .45652 L p .839 .696 .706 r
F P
0 g
s
.49339 .65054 m .4973 .63447 L .52248 .61957 L p .846 .76 .768 r
F P
0 g
s
.52285 .60306 m .52248 .61957 L .4973 .63447 L p .845 .742 .749 r
F P
0 g
s
.39351 .68677 m .40315 .68423 L .43809 .69559 L p .525 .784 .991 r
F P
0 g
s
.44503 .68936 m .43809 .69559 L .40315 .68423 L p .66 .795 .947 r
F P
0 g
s
.76874 .37112 m .75423 .36328 L .73561 .31533 L p .262 .435 .845 r
F P
0 g
s
.72215 .30996 m .73561 .31533 L .75423 .36328 L p .333 .474 .852 r
F P
0 g
s
.53801 .55061 m .53481 .53383 L .54492 .51871 L p .841 .704 .712 r
F P
0 g
s
.53835 .5062 m .54492 .51871 L .53481 .53383 L p .841 .7 .708 r
F P
0 g
s
.54492 .51871 m .53835 .5062 L .5442 .49428 L p .839 .698 .707 r
F P
0 g
s
.53697 .48093 m .54874 .48146 L .5442 .49428 L p .839 .697 .705 r
F P
0 g
s
.54874 .48146 m .53697 .48093 L .53845 .47442 L p .839 .696 .705 r
F P
0 g
s
.55208 .44607 m .53864 .46306 L .53735 .45897 L p .839 .697 .706 r
F P
0 g
s
.53735 .45897 m .54952 .43793 L .55208 .44607 L p .839 .697 .706 r
F P
0 g
s
.55532 .40978 m .54529 .43266 L .53968 .43062 L p .838 .7 .711 r
F P
0 g
s
.53968 .43062 m .54694 .40664 L .55532 .40978 L p .838 .7 .711 r
F P
0 g
s
.52322 .58505 m .5236 .56576 L .53801 .55061 L p .844 .714 .72 r
F P
0 g
s
.53481 .53383 m .53801 .55061 L .5236 .56576 L p .842 .707 .714 r
F P
0 g
s
.53469 .4874 m .5442 .49428 L .53835 .5062 L p .84 .697 .705 r
F P
0 g
s
.5442 .49428 m .53469 .4874 L .53697 .48093 L p .839 .697 .705 r
F P
0 g
s
.54952 .43793 m .53735 .45897 L .53523 .45633 L p .839 .697 .706 r
F P
0 g
s
.53523 .45633 m .54529 .43266 L .54952 .43793 L p .839 .697 .706 r
F P
0 g
s
.22838 .50709 m .24165 .51773 L .25517 .56991 L p .108 .315 .788 r
F P
0 g
s
.26742 .5806 m .25517 .56991 L .24165 .51773 L p .171 .348 .799 r
F P
0 g
s
.85906 .48583 m .84418 .47545 L .84426 .42231 L p .289 .427 .828 r
F P
0 g
s
.8288 .4113 m .84426 .42231 L .84418 .47545 L p .297 .423 .821 r
F P
0 g
s
.34063 .65527 m .3522 .65863 L .38405 .68682 L p .146 .507 .911 r
F P
0 g
s
.39351 .68677 m .38405 .68682 L .3522 .65863 L p .369 .616 .947 r
F P
0 g
s
.70894 .30628 m .69596 .30444 L .66791 .27158 L p .381 .586 .924 r
F P
0 g
s
.65709 .27358 m .66791 .27158 L .69596 .30444 L p .49 .633 .916 r
F P
0 g
s
.64645 .27774 m .63598 .28411 L .60578 .27005 L p .681 .765 .915 r
F P
0 g
s
.59821 .28024 m .60578 .27005 L .63598 .28411 L p .734 .759 .873 r
F P
0 g
s
.45207 .68055 m .45921 .66915 L .48951 .66445 L p .813 .806 .844 r
F P
0 g
s
.49339 .65054 m .48951 .66445 L .45921 .66915 L p .825 .777 .807 r
F P
0 g
s
.576 .32355 m .56871 .34194 L .54899 .34453 L p .833 .734 .756 r
F P
0 g
s
.56871 .34194 m .56144 .36205 L .54499 .36456 L p .836 .723 .739 r
F P
0 g
s
.54499 .36456 m .54899 .34453 L .56871 .34194 L p .836 .723 .739 r
F P
0 g
s
.56144 .36205 m .55419 .3837 L .54101 .38596 L p .838 .713 .727 r
F P
0 g
s
.54101 .38596 m .54499 .36456 L .56144 .36205 L p .838 .713 .727 r
F P
0 g
s
.4973 .63447 m .50124 .6164 L .52285 .60306 L p .845 .742 .749 r
F P
0 g
s
.52322 .58505 m .52285 .60306 L .50124 .6164 L p .844 .727 .735 r
F P
0 g
s
.58334 .30706 m .576 .32355 L .553 .32605 L p .828 .749 .777 r
F P
0 g
s
.54899 .34453 m .553 .32605 L .576 .32355 L p .833 .734 .756 r
F P
0 g
s
.55419 .3837 m .54694 .40664 L .53704 .40851 L p .839 .707 .717 r
F P
0 g
s
.53704 .40851 m .54101 .38596 L .55419 .3837 L p .839 .707 .717 r
F P
0 g
s
.53481 .53383 m .53159 .51641 L .53835 .5062 L p .841 .7 .708 r
F P
0 g
s
.53175 .49342 m .53835 .5062 L .53159 .51641 L p .84 .698 .706 r
F P
0 g
s
.53835 .5062 m .53175 .49342 L .53469 .4874 L p .84 .697 .705 r
F P
0 g
s
.54529 .43266 m .53523 .45633 L .53241 .45533 L p .839 .698 .707 r
F P
0 g
s
.53241 .45533 m .53968 .43062 L .54529 .43266 L p .839 .698 .707 r
F P
0 g
s
.5236 .56576 m .52398 .54539 L .53481 .53383 L p .842 .707 .714 r
F P
0 g
s
.53159 .51641 m .53481 .53383 L .52398 .54539 L p .841 .702 .709 r
F P
0 g
s
.54694 .40664 m .53968 .43062 L .53306 .43196 L p .839 .702 .711 r
F P
0 g
s
.53306 .43196 m .53704 .40851 L .54694 .40664 L p .839 .702 .711 r
F P
0 g
s
.59073 .2926 m .58334 .30706 L .55705 .30929 L p .82 .767 .803 r
F P
0 g
s
.553 .32605 m .55705 .30929 L .58334 .30706 L p .828 .749 .777 r
F P
0 g
s
.50124 .6164 m .5052 .59657 L .52322 .58505 L p .844 .727 .735 r
F P
0 g
s
.5236 .56576 m .52322 .58505 L .5052 .59657 L p .843 .716 .724 r
F P
0 g
s
.52511 .48046 m .53902 .46833 L .53845 .47442 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53864 .46306 L .53902 .46833 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53845 .47442 L .53697 .48093 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53735 .45897 L .53864 .46306 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53697 .48093 L .53469 .4874 L closepath p .84 .697 .704 r
F P
0 g
s
.40315 .68423 m .41295 .6791 L .44503 .68936 L p .66 .795 .947 r
F P
0 g
s
.45207 .68055 m .44503 .68936 L .41295 .6791 L p .733 .783 .893 r
F P
0 g
s
.78345 .38008 m .76874 .37112 L .74931 .3222 L p .196 .399 .835 r
F P
0 g
s
.73561 .31533 m .74931 .3222 L .76874 .37112 L p .262 .435 .845 r
F P
0 g
s
.45921 .66915 m .46642 .65526 L .49339 .65054 L p .825 .777 .807 r
F P
0 g
s
.4973 .63447 m .49339 .65054 L .46642 .65526 L p .832 .755 .778 r
F P
0 g
s
.52511 .48046 m .53523 .45633 L .53735 .45897 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53469 .4874 L .53175 .49342 L closepath p .84 .697 .704 r
F P
0 g
s
.29249 .59944 m .30532 .60704 L .32929 .64992 L p .092 .363 .829 r
F P
0 g
s
.34063 .65527 m .32929 .64992 L .30532 .60704 L p .243 .45 .863 r
F P
0 g
s
.84426 .42231 m .85986 .43317 L .85906 .48583 L p .289 .427 .828 r
F P
0 g
s
.52398 .54539 m .52436 .52422 L .53159 .51641 L p .841 .702 .709 r
F P
0 g
s
.52836 .49856 m .53159 .51641 L .52436 .52422 L p .84 .698 .706 r
F P
0 g
s
.53159 .51641 m .52836 .49856 L .53175 .49342 L p .84 .698 .706 r
F P
0 g
s
.53968 .43062 m .53241 .45533 L .52909 .45604 L p .84 .698 .706 r
F P
0 g
s
.52909 .45604 m .53306 .43196 L .53968 .43062 L p .84 .698 .706 r
F P
0 g
s
.5052 .59657 m .50918 .5752 L .5236 .56576 L p .843 .716 .724 r
F P
0 g
s
.52398 .54539 m .5236 .56576 L .50918 .5752 L p .841 .708 .716 r
F P
0 g
s
.65709 .27358 m .64645 .27774 L .61347 .26204 L p .601 .76 .955 r
F P
0 g
s
.60578 .27005 m .61347 .26204 L .64645 .27774 L p .681 .765 .915 r
F P
0 g
s
.52511 .48046 m .53241 .45533 L .53523 .45633 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .53175 .49342 L .52836 .49856 L closepath p .84 .697 .704 r
F P
0 g
s
.59821 .28024 m .59073 .2926 L .56113 .29434 L p .807 .789 .836 r
F P
0 g
s
.55705 .30929 m .56113 .29434 L .59073 .2926 L p .82 .767 .803 r
F P
0 g
s
.50918 .5752 m .51316 .5526 L .52398 .54539 L p .841 .708 .716 r
F P
0 g
s
.52436 .52422 m .52398 .54539 L .51316 .5526 L p .841 .702 .71 r
F P
0 g
s
.72215 .30996 m .70894 .30628 L .67894 .27163 L p .255 .525 .913 r
F P
0 g
s
.66791 .27158 m .67894 .27163 L .70894 .30628 L p .381 .586 .924 r
F P
0 g
s
.52511 .48046 m .52909 .45604 L .53241 .45533 L closepath p .84 .697 .704 r
F P
0 g
s
.52436 .52422 m .52473 .50248 L .52836 .49856 L p .84 .698 .706 r
F P
0 g
s
.52511 .48046 m .52836 .49856 L .52473 .50248 L closepath p .84 .697 .704 r
F P
0 g
s
.3522 .65863 m .36396 .65978 L .39351 .68677 L p .369 .616 .947 r
F P
0 g
s
.40315 .68423 m .39351 .68677 L .36396 .65978 L p .527 .674 .931 r
F P
0 g
s
.46642 .65526 m .4737 .63901 L .4973 .63447 L p .832 .755 .778 r
F P
0 g
s
.50124 .6164 m .4973 .63447 L .4737 .63901 L p .835 .738 .756 r
F P
0 g
s
.54101 .38596 m .53704 .40851 L .52625 .4153 L p .841 .708 .716 r
F P
0 g
s
.53704 .40851 m .53306 .43196 L .52587 .43662 L p .841 .702 .71 r
F P
0 g
s
.52587 .43662 m .52625 .4153 L .53704 .40851 L p .841 .702 .71 r
F P
0 g
s
.24165 .51773 m .25504 .52798 L .26742 .5806 L p .171 .348 .799 r
F P
0 g
s
.27986 .59054 m .26742 .5806 L .25504 .52798 L p .243 .387 .809 r
F P
0 g
s
.54499 .36456 m .54101 .38596 L .52664 .3947 L p .842 .716 .724 r
F P
0 g
s
.52625 .4153 m .52664 .3947 L .54101 .38596 L p .841 .708 .716 r
F P
0 g
s
.51316 .5526 m .51715 .52906 L .52436 .52422 L p .841 .702 .71 r
F P
0 g
s
.52473 .50248 m .52436 .52422 L .51715 .52906 L p .84 .699 .706 r
F P
0 g
s
.53306 .43196 m .52909 .45604 L .52549 .45842 L p .84 .699 .706 r
F P
0 g
s
.52549 .45842 m .52587 .43662 L .53306 .43196 L p .84 .699 .706 r
F P
0 g
s
.54899 .34453 m .54499 .36456 L .52702 .37503 L p .843 .726 .735 r
F P
0 g
s
.52664 .3947 m .52702 .37503 L .54499 .36456 L p .842 .716 .724 r
F P
0 g
s
.52511 .48046 m .52549 .45842 L .52909 .45604 L closepath p .84 .697 .704 r
F P
0 g
s
.51715 .52906 m .52113 .50491 L .52473 .50248 L p .84 .699 .706 r
F P
0 g
s
.52511 .48046 m .52473 .50248 L .52113 .50491 L closepath p .84 .697 .704 r
F P
0 g
s
.41295 .6791 m .42289 .67134 L .45207 .68055 L p .733 .783 .893 r
F P
0 g
s
.45921 .66915 m .45207 .68055 L .42289 .67134 L p .773 .765 .846 r
F P
0 g
s
.553 .32605 m .54899 .34453 L .5274 .35647 L p .843 .739 .749 r
F P
0 g
s
.52702 .37503 m .5274 .35647 L .54899 .34453 L p .843 .726 .735 r
F P
0 g
s
.52511 .48046 m .52186 .46231 L .52549 .45842 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51845 .46745 L .52186 .46231 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51548 .47348 L .51845 .46745 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51317 .48 L .51548 .47348 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51168 .48656 L .51317 .48 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .5111 .4927 L .51168 .48656 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51148 .498 L .5111 .4927 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .5128 .5021 L .51148 .498 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .51495 .50472 L .5128 .5021 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .5178 .50567 L .51495 .50472 L closepath p .84 .697 .704 r
F P
0 g
s
.52511 .48046 m .52113 .50491 L .5178 .50567 L closepath p .84 .697 .704 r
F P
0 g
s
.4737 .63901 m .48102 .62058 L .50124 .6164 L p .835 .738 .756 r
F P
0 g
s
.5052 .59657 m .50124 .6164 L .48102 .62058 L p .837 .724 .74 r
F P
0 g
s
.60578 .27005 m .59821 .28024 L .56526 .28132 L p .785 .813 .875 r
F P
0 g
s
.56113 .29434 m .56526 .28132 L .59821 .28024 L p .807 .789 .836 r
F P
0 g
s
.52587 .43662 m .52549 .45842 L .52186 .46231 L p .84 .698 .706 r
F P
0 g
s
.51046 .53061 m .5178 .50567 L .52113 .50491 L p .84 .698 .706 r
F P
0 g
s
.52113 .50491 m .51715 .52906 L .51046 .53061 L p .84 .698 .706 r
F P
0 g
s
.48102 .62058 m .48837 .60023 L .5052 .59657 L p .837 .724 .74 r
F P
0 g
s
.50918 .5752 m .5052 .59657 L .48837 .60023 L p .838 .714 .727 r
F P
0 g
s
.5031 .55492 m .51046 .53061 L .51715 .52906 L p .84 .702 .711 r
F P
0 g
s
.51715 .52906 m .51316 .5526 L .5031 .55492 L p .84 .702 .711 r
F P
0 g
s
.52625 .4153 m .52587 .43662 L .5186 .44429 L p .841 .702 .709 r
F P
0 g
s
.52186 .46231 m .5186 .44429 L .52587 .43662 L p .84 .698 .706 r
F P
0 g
s
.48837 .60023 m .49573 .57824 L .50918 .5752 L p .838 .714 .727 r
F P
0 g
s
.51316 .5526 m .50918 .5752 L .49573 .57824 L p .839 .707 .717 r
F P
0 g
s
.79838 .38992 m .78345 .38008 L .76327 .33034 L p .14 .368 .824 r
F P
0 g
s
.74931 .3222 m .76327 .33034 L .78345 .38008 L p .196 .399 .835 r
F P
0 g
s
.49573 .57824 m .5031 .55492 L .51316 .5526 L p .839 .707 .717 r
F P
0 g
s
.55705 .30929 m .553 .32605 L .52779 .33919 L p .843 .756 .767 r
F P
0 g
s
.5274 .35647 m .52779 .33919 L .553 .32605 L p .843 .739 .749 r
F P
0 g
s
.66791 .27158 m .65709 .27358 L .6213 .25618 L p .482 .734 .982 r
F P
0 g
s
.61347 .26204 m .6213 .25618 L .65709 .27358 L p .601 .76 .955 r
F P
0 g
s
.5186 .44429 m .52186 .46231 L .51845 .46745 L p .84 .698 .706 r
F P
0 g
s
.50474 .52873 m .51495 .50472 L .5178 .50567 L p .84 .698 .707 r
F P
0 g
s
.5178 .50567 m .51046 .53061 L .50474 .52873 L p .84 .698 .707 r
F P
0 g
s
.30532 .60704 m .31835 .6131 L .34063 .65527 L p .243 .45 .863 r
F P
0 g
s
.3522 .65863 m .34063 .65527 L .31835 .6131 L p .377 .521 .874 r
F P
0 g
s
.52664 .3947 m .52625 .4153 L .51533 .4266 L p .842 .707 .714 r
F P
0 g
s
.5186 .44429 m .51533 .4266 L .52625 .4153 L p .841 .702 .709 r
F P
0 g
s
.42289 .67134 m .43296 .66095 L .45921 .66915 L p .773 .765 .846 r
F P
0 g
s
.46642 .65526 m .45921 .66915 L .43296 .66095 L p .797 .749 .809 r
F P
0 g
s
.51845 .46745 m .51175 .45447 L .5186 .44429 L p .84 .698 .706 r
F P
0 g
s
.51175 .45447 m .51845 .46745 L .51548 .47348 L p .84 .697 .705 r
F P
0 g
s
.50041 .52353 m .5128 .5021 L .51495 .50472 L p .839 .697 .706 r
F P
0 g
s
.51495 .50472 m .50474 .52873 L .50041 .52353 L p .839 .697 .706 r
F P
0 g
s
.36396 .65978 m .37591 .65858 L .40315 .68423 L p .527 .674 .931 r
F P
0 g
s
.41295 .6791 m .40315 .68423 L .37591 .65858 L p .631 .7 .895 r
F P
0 g
s
.52702 .37503 m .52664 .3947 L .51204 .4094 L p .843 .714 .72 r
F P
0 g
s
.51533 .4266 m .51204 .4094 L .52664 .3947 L p .842 .707 .714 r
F P
0 g
s
.49449 .55213 m .50474 .52873 L .51046 .53061 L p .838 .7 .711 r
F P
0 g
s
.51046 .53061 m .5031 .55492 L .49449 .55213 L p .838 .7 .711 r
F P
0 g
s
.51533 .4266 m .5186 .44429 L .51175 .45447 L p .84 .7 .708 r
F P
0 g
s
.20213 .48554 m .18911 .47507 L .19318 .42214 L p .329 .452 .833 r
F P
0 g
s
.73561 .31533 m .72215 .30996 L .69019 .27362 L p .125 .453 .884 r
F P
0 g
s
.67894 .27163 m .69019 .27362 L .72215 .30996 L p .255 .525 .913 r
F P
0 g
s
.51548 .47348 m .50579 .46647 L .51175 .45447 L p .84 .697 .705 r
F P
0 g
s
.50579 .46647 m .51548 .47348 L .51317 .48 L p .839 .697 .705 r
F P
0 g
s
.49776 .51536 m .51148 .498 L .5128 .5021 L p .839 .697 .706 r
F P
0 g
s
.5128 .5021 m .50041 .52353 L .49776 .51536 L p .839 .697 .706 r
F P
0 g
s
.56113 .29434 m .55705 .30929 L .52818 .32333 L p .842 .776 .788 r
F P
0 g
s
.52779 .33919 m .52818 .32333 L .55705 .30929 L p .843 .756 .767 r
F P
0 g
s
.25504 .52798 m .26856 .53759 L .27986 .59054 L p .243 .387 .809 r
F P
0 g
s
.29249 .59944 m .27986 .59054 L .26856 .53759 L p .317 .428 .817 r
F P
0 g
s
.61347 .26204 m .60578 .27005 L .56945 .27025 L p .747 .838 .921 r
F P
0 g
s
.56526 .28132 m .56945 .27025 L .60578 .27005 L p .785 .813 .875 r
F P
0 g
s
.51317 .48 m .50114 .47946 L .50579 .46647 L p .839 .697 .705 r
F P
0 g
s
.50114 .47946 m .51317 .48 L .51168 .48656 L p .839 .696 .705 r
F P
0 g
s
.49698 .50479 m .5111 .4927 L .51148 .498 L p .839 .696 .706 r
F P
0 g
s
.51148 .498 m .49776 .51536 L .49698 .50479 L p .839 .696 .706 r
F P
0 g
s
.51168 .48656 m .49814 .49253 L .50114 .47946 L p .839 .696 .705 r
F P
0 g
s
.49814 .49253 m .51168 .48656 L .5111 .4927 L p .839 .696 .706 r
F P
0 g
s
.5111 .4927 m .49698 .50479 L .49814 .49253 L p .839 .696 .706 r
F P
0 g
s
.5274 .35647 m .52702 .37503 L .50874 .39285 L p .845 .723 .729 r
F P
0 g
s
.51204 .4094 m .50874 .39285 L .52702 .37503 L p .843 .714 .72 r
F P
0 g
s
.43296 .66095 m .44311 .64801 L .46642 .65526 L p .797 .749 .809 r
F P
0 g
s
.4737 .63901 m .46642 .65526 L .44311 .64801 L p .811 .735 .78 r
F P
0 g
s
.48421 .57457 m .49449 .55213 L .5031 .55492 L p .836 .704 .718 r
F P
0 g
s
.5031 .55492 m .49573 .57824 L .48421 .57457 L p .836 .704 .718 r
F P
0 g
s
.51204 .4094 m .51533 .4266 L .50502 .44165 L p .841 .704 .712 r
F P
0 g
s
.51175 .45447 m .50502 .44165 L .51533 .4266 L p .84 .7 .708 r
F P
0 g
s
.48794 .54441 m .50041 .52353 L .50474 .52873 L p .837 .698 .711 r
F P
0 g
s
.50474 .52873 m .49449 .55213 L .48794 .54441 L p .837 .698 .711 r
F P
0 g
s
.50502 .44165 m .51175 .45447 L .50579 .46647 L p .839 .698 .707 r
F P
0 g
s
.47391 .59569 m .48421 .57457 L .49573 .57824 L p .833 .709 .727 r
F P
0 g
s
.49573 .57824 m .48837 .60023 L .47391 .59569 L p .833 .709 .727 r
F P
0 g
s
.44311 .64801 m .45334 .63268 L .4737 .63901 L p .811 .735 .78 r
F P
0 g
s
.48102 .62058 m .4737 .63901 L .45334 .63268 L p .821 .724 .758 r
F P
0 g
s
.52779 .33919 m .5274 .35647 L .50542 .37709 L p .847 .734 .739 r
F P
0 g
s
.50874 .39285 m .50542 .37709 L .5274 .35647 L p .845 .723 .729 r
F P
0 g
s
.46361 .61516 m .47391 .59569 L .48837 .60023 L p .828 .715 .741 r
F P
0 g
s
.48837 .60023 m .48102 .62058 L .46361 .61516 L p .828 .715 .741 r
F P
0 g
s
.45334 .63268 m .46361 .61516 L .48102 .62058 L p .821 .724 .758 r
F P
0 g
s
.56526 .28132 m .56113 .29434 L .52857 .30897 L p .838 .801 .815 r
F P
0 g
s
.52818 .32333 m .52857 .30897 L .56113 .29434 L p .842 .776 .788 r
F P
0 g
s
.37591 .65858 m .38804 .65492 L .41295 .6791 L p .631 .7 .895 r
F P
0 g
s
.42289 .67134 m .41295 .6791 L .38804 .65492 L p .698 .71 .857 r
F P
0 g
s
.31835 .6131 m .33157 .61739 L .3522 .65863 L p .377 .521 .874 r
F P
0 g
s
.36396 .65978 m .3522 .65863 L .33157 .61739 L p .488 .575 .869 r
F P
0 g
s
.67894 .27163 m .66791 .27158 L .62927 .25242 L p .321 .674 .976 r
F P
0 g
s
.6213 .25618 m .62927 .25242 L .66791 .27158 L p .482 .734 .982 r
F P
0 g
s
.19318 .42214 m .20675 .43168 L .20213 .48554 L p .329 .452 .833 r
F P
0 g
s
.21521 .49629 m .20213 .48554 L .20675 .43168 L p .348 .451 .824 r
F P
0 g
s
.8135 .40041 m .79838 .38992 L .77748 .3395 L p .096 .344 .815 r
F P
0 g
s
.76327 .33034 m .77748 .3395 L .79838 .38992 L p .14 .368 .824 r
F P
0 g
s
.48393 .53225 m .49776 .51536 L .50041 .52353 L p .835 .696 .71 r
F P
0 g
s
.50041 .52353 m .48794 .54441 L .48393 .53225 L p .835 .696 .71 r
F P
0 g
s
.50579 .46647 m .49604 .45945 L .50502 .44165 L p .839 .698 .707 r
F P
0 g
s
.49604 .45945 m .50579 .46647 L .50114 .47946 L p .838 .697 .707 r
F P
0 g
s
.50874 .39285 m .51204 .4094 L .49825 .42909 L p .842 .709 .716 r
F P
0 g
s
.50502 .44165 m .49825 .42909 L .51204 .4094 L p .841 .704 .712 r
F P
0 g
s
.47543 .56439 m .48794 .54441 L .49449 .55213 L p .833 .7 .717 r
F P
0 g
s
.49449 .55213 m .48421 .57457 L .47543 .56439 L p .833 .7 .717 r
F P
0 g
s
.48275 .51649 m .49698 .50479 L .49776 .51536 L p .835 .695 .709 r
F P
0 g
s
.49776 .51536 m .48393 .53225 L .48275 .51649 L p .835 .695 .709 r
F P
0 g
s
.50114 .47946 m .48903 .47876 L .49604 .45945 L p .838 .697 .707 r
F P
0 g
s
.48903 .47876 m .50114 .47946 L .49814 .49253 L p .836 .695 .707 r
F P
0 g
s
.49825 .42909 m .50502 .44165 L .49604 .45945 L p .839 .7 .71 r
F P
0 g
s
.26856 .53759 m .28222 .54636 L .29249 .59944 L p .317 .428 .817 r
F P
0 g
s
.30532 .60704 m .29249 .59944 L .28222 .54636 L p .391 .469 .82 r
F P
0 g
s
.6213 .25618 m .61347 .26204 L .5737 .26116 L p .681 .857 .966 r
F P
0 g
s
.56945 .27025 m .5737 .26116 L .61347 .26204 L p .747 .838 .921 r
F P
0 g
s
.52818 .32333 m .52779 .33919 L .50208 .36226 L p .849 .748 .752 r
F P
0 g
s
.50542 .37709 m .50208 .36226 L .52779 .33919 L p .847 .734 .739 r
F P
0 g
s
.48449 .49823 m .49814 .49253 L .49698 .50479 L p .835 .695 .708 r
F P
0 g
s
.49698 .50479 m .48275 .51649 L .48449 .49823 L p .835 .695 .708 r
F P
0 g
s
.49814 .49253 m .48449 .49823 L .48903 .47876 L p .836 .695 .707 r
F P
0 g
s
.38804 .65492 m .40031 .64875 L .42289 .67134 L p .698 .71 .857 r
F P
0 g
s
.43296 .66095 m .42289 .67134 L .40031 .64875 L p .742 .712 .823 r
F P
0 g
s
.74931 .3222 m .73561 .31533 L .70168 .27737 L p .002 .379 .841 r
F P
0 g
s
.69019 .27362 m .70168 .27737 L .73561 .31533 L p .125 .453 .884 r
F P
0 g
s
.50542 .37709 m .50874 .39285 L .49144 .41686 L p .843 .715 .722 r
F P
0 g
s
.49825 .42909 m .49144 .41686 L .50874 .39285 L p .842 .709 .716 r
F P
0 g
s
.46287 .58314 m .47543 .56439 L .48421 .57457 L p .827 .701 .726 r
F P
0 g
s
.48421 .57457 m .47391 .59569 L .46287 .58314 L p .827 .701 .726 r
F P
0 g
s
.56945 .27025 m .56526 .28132 L .52897 .29621 L p .83 .83 .847 r
F P
0 g
s
.52857 .30897 m .52897 .29621 L .56526 .28132 L p .838 .801 .815 r
F P
0 g
s
.47003 .54836 m .48393 .53225 L .48794 .54441 L p .83 .696 .715 r
F P
0 g
s
.48794 .54441 m .47543 .56439 L .47003 .54836 L p .83 .696 .715 r
F P
0 g
s
.20675 .43168 m .22033 .44138 L .21521 .49629 L p .348 .451 .824 r
F P
0 g
s
.22838 .50709 m .21521 .49629 L .22033 .44138 L p .373 .456 .817 r
F P
0 g
s
.49604 .45945 m .48622 .45244 L .49825 .42909 L p .839 .7 .71 r
F P
0 g
s
.48622 .45244 m .49604 .45945 L .48903 .47876 L p .835 .696 .709 r
F P
0 g
s
.33157 .61739 m .34497 .61974 L .36396 .65978 L p .488 .575 .869 r
F P
0 g
s
.37591 .65858 m .36396 .65978 L .34497 .61974 L p .575 .613 .853 r
F P
0 g
s
.49144 .41686 m .49825 .42909 L .48622 .45244 L p .838 .702 .713 r
F P
0 g
s
.40031 .64875 m .4127 .6401 L .43296 .66095 L p .742 .712 .823 r
F P
0 g
s
.44311 .64801 m .43296 .66095 L .4127 .6401 L p .772 .711 .795 r
F P
0 g
s
.45029 .60035 m .46287 .58314 L .47391 .59569 L p .819 .703 .737 r
F P
0 g
s
.47391 .59569 m .46361 .61516 L .45029 .60035 L p .819 .703 .737 r
F P
0 g
s
.52857 .30897 m .52818 .32333 L .49871 .34845 L p .85 .765 .768 r
F P
0 g
s
.50208 .36226 m .49871 .34845 L .52818 .32333 L p .849 .748 .752 r
F P
0 g
s
.46843 .52757 m .48275 .51649 L .48393 .53225 L p .829 .693 .713 r
F P
0 g
s
.48393 .53225 m .47003 .54836 L .46843 .52757 L p .829 .693 .713 r
F P
0 g
s
.48903 .47876 m .47683 .47785 L .48622 .45244 L p .835 .696 .709 r
F P
0 g
s
.47683 .47785 m .48903 .47876 L .48449 .49823 L p .832 .693 .71 r
F P
0 g
s
.50208 .36226 m .50542 .37709 L .48459 .40507 L p .843 .722 .73 r
F P
0 g
s
.49144 .41686 m .48459 .40507 L .50542 .37709 L p .843 .715 .722 r
F P
0 g
s
.43772 .61573 m .45029 .60035 L .46361 .61516 L p .808 .706 .752 r
F P
0 g
s
.46361 .61516 m .45334 .63268 L .43772 .61573 L p .808 .706 .752 r
F P
0 g
s
.4127 .6401 m .42518 .62905 L .44311 .64801 L p .772 .711 .795 r
F P
0 g
s
.45334 .63268 m .44311 .64801 L .42518 .62905 L p .793 .708 .771 r
F P
0 g
s
.8288 .4113 m .8135 .40041 L .79193 .34942 L p .064 .33 .809 r
F P
0 g
s
.77748 .3395 m .79193 .34942 L .8135 .40041 L p .096 .344 .815 r
F P
0 g
s
.42518 .62905 m .43772 .61573 L .45334 .63268 L p .793 .708 .771 r
F P
0 g
s
.69019 .27362 m .67894 .27163 L .6374 .25066 L p .132 .576 .924 r
F P
0 g
s
.62927 .25242 m .6374 .25066 L .67894 .27163 L p .321 .674 .976 r
F P
0 g
s
.28222 .54636 m .29602 .55408 L .30532 .60704 L p .391 .469 .82 r
F P
0 g
s
.31835 .6131 m .30532 .60704 L .29602 .55408 L p .461 .507 .82 r
F P
0 g
s
.47075 .5035 m .48449 .49823 L .48275 .51649 L p .83 .692 .711 r
F P
0 g
s
.48275 .51649 m .46843 .52757 L .47075 .5035 L p .83 .692 .711 r
F P
0 g
s
.48449 .49823 m .47075 .5035 L .47683 .47785 L p .832 .693 .71 r
F P
0 g
s
.45607 .5634 m .47003 .54836 L .47543 .56439 L p .823 .694 .722 r
F P
0 g
s
.47543 .56439 m .46287 .58314 L .45607 .5634 L p .823 .694 .722 r
F P
0 g
s
.22033 .44138 m .23394 .4511 L .22838 .50709 L p .373 .456 .817 r
F P
0 g
s
.24165 .51773 m .22838 .50709 L .23394 .4511 L p .404 .467 .811 r
F P
0 g
s
.62927 .25242 m .6213 .25618 L .57803 .25404 L p .573 .854 .996 r
F P
0 g
s
.5737 .26116 m .57803 .25404 L .6213 .25618 L p .681 .857 .966 r
F P
0 g
s
.34497 .61974 m .35854 .62002 L .37591 .65858 L p .575 .613 .853 r
F P
0 g
s
.38804 .65492 m .37591 .65858 L .35854 .62002 L p .642 .64 .833 r
F P
0 g
s
.48622 .45244 m .47634 .44546 L .49144 .41686 L p .838 .702 .713 r
F P
0 g
s
.47634 .44546 m .48622 .45244 L .47683 .47785 L p .832 .695 .712 r
F P
0 g
s
.48459 .40507 m .49144 .41686 L .47634 .44546 L p .836 .704 .718 r
F P
0 g
s
.5737 .26116 m .56945 .27025 L .52938 .28509 L p .813 .862 .884 r
F P
0 g
s
.52897 .29621 m .52938 .28509 L .56945 .27025 L p .83 .83 .847 r
F P
0 g
s
.52897 .29621 m .52857 .30897 L .49531 .33574 L p .851 .785 .787 r
F P
0 g
s
.49871 .34845 m .49531 .33574 L .52857 .30897 L p .85 .765 .768 r
F P
0 g
s
.49871 .34845 m .50208 .36226 L .47768 .39378 L p .844 .731 .739 r
F P
0 g
s
.48459 .40507 m .47768 .39378 L .50208 .36226 L p .843 .722 .73 r
F P
0 g
s
.45403 .53781 m .46843 .52757 L .47003 .54836 L p .821 .689 .718 r
F P
0 g
s
.47003 .54836 m .45607 .5634 L .45403 .53781 L p .821 .689 .718 r
F P
0 g
s
.44205 .57709 m .45607 .5634 L .46287 .58314 L p .813 .692 .732 r
F P
0 g
s
.46287 .58314 m .45029 .60035 L .44205 .57709 L p .813 .692 .732 r
F P
0 g
s
.76327 .33034 m .74931 .3222 L .71343 .28268 L p 0 .311 .794 r
F P
0 g
s
.70168 .27737 m .71343 .28268 L .74931 .3222 L p .002 .379 .841 r
F P
0 g
s
.47683 .47785 m .46454 .47664 L .47634 .44546 L p .832 .695 .712 r
F P
0 g
s
.46454 .47664 m .47683 .47785 L .47075 .5035 L p .827 .69 .713 r
F P
0 g
s
.35854 .62002 m .37225 .61814 L .38804 .65492 L p .642 .64 .833 r
F P
0 g
s
.40031 .64875 m .38804 .65492 L .37225 .61814 L p .692 .658 .811 r
F P
0 g
s
.29602 .55408 m .30996 .56055 L .31835 .6131 L p .461 .507 .82 r
F P
0 g
s
.33157 .61739 m .31835 .6131 L .30996 .56055 L p .525 .542 .815 r
F P
0 g
s
.45692 .50818 m .47075 .5035 L .46843 .52757 L p .823 .688 .715 r
F P
0 g
s
.46843 .52757 m .45403 .53781 L .45692 .50818 L p .823 .688 .715 r
F P
0 g
s
.23394 .4511 m .24758 .46067 L .24165 .51773 L p .404 .467 .811 r
F P
0 g
s
.25504 .52798 m .24165 .51773 L .24758 .46067 L p .439 .481 .806 r
F P
0 g
s
.47075 .5035 m .45692 .50818 L .46454 .47664 L p .827 .69 .713 r
F P
0 g
s
.47768 .39378 m .48459 .40507 L .46639 .43852 L p .835 .707 .723 r
F P
0 g
s
.47634 .44546 m .46639 .43852 L .48459 .40507 L p .836 .704 .718 r
F P
0 g
s
.42802 .5892 m .44205 .57709 L .45029 .60035 L p .799 .689 .743 r
F P
0 g
s
.45029 .60035 m .43772 .61573 L .42802 .5892 L p .799 .689 .743 r
F P
0 g
s
.46639 .43852 m .47634 .44546 L .46454 .47664 L p .828 .694 .716 r
F P
0 g
s
.84426 .42231 m .8288 .4113 L .80662 .35981 L p .047 .326 .808 r
F P
0 g
s
.79193 .34942 m .80662 .35981 L .8288 .4113 L p .064 .33 .809 r
F P
0 g
s
.37225 .61814 m .38608 .61407 L .40031 .64875 L p .692 .658 .811 r
F P
0 g
s
.4127 .6401 m .40031 .64875 L .38608 .61407 L p .731 .67 .791 r
F P
0 g
s
.49531 .33574 m .49871 .34845 L .47073 .38306 L p .845 .742 .749 r
F P
0 g
s
.47768 .39378 m .47073 .38306 L .49871 .34845 L p .844 .731 .739 r
F P
0 g
s
.43956 .54697 m .45403 .53781 L .45607 .5634 L p .811 .685 .725 r
F P
0 g
s
.45607 .5634 m .44205 .57709 L .43956 .54697 L p .811 .685 .725 r
F P
0 g
s
.414 .5995 m .42802 .5892 L .43772 .61573 L p .782 .685 .757 r
F P
0 g
s
.43772 .61573 m .42518 .62905 L .414 .5995 L p .782 .685 .757 r
F P
0 g
s
.52938 .28509 m .52897 .29621 L .49187 .3242 L p .85 .808 .809 r
F P
0 g
s
.49531 .33574 m .49187 .3242 L .52897 .29621 L p .851 .785 .787 r
F P
0 g
s
.38608 .61407 m .40001 .60784 L .4127 .6401 L p .731 .67 .791 r
F P
0 g
s
.42518 .62905 m .4127 .6401 L .40001 .60784 L p .76 .679 .773 r
F P
0 g
s
.40001 .60784 m .414 .5995 L .42518 .62905 L p .76 .679 .773 r
F P
0 g
s
.57803 .25404 m .5737 .26116 L .52979 .27562 L p .781 .895 .924 r
F P
0 g
s
.52938 .28509 m .52979 .27562 L .5737 .26116 L p .813 .862 .884 r
F P
0 g
s
.70168 .27737 m .69019 .27362 L .64572 .25079 L p 0 .457 .833 r
F P
0 g
s
.6374 .25066 m .64572 .25079 L .69019 .27362 L p .132 .576 .924 r
F P
0 g
s
.30996 .56055 m .32404 .56561 L .33157 .61739 L p .525 .542 .815 r
F P
0 g
s
.34497 .61974 m .33157 .61739 L .32404 .56561 L p .581 .572 .807 r
F P
0 g
s
.6374 .25066 m .62927 .25242 L .58244 .24881 L p .41 .808 .985 r
F P
0 g
s
.57803 .25404 m .58244 .24881 L .62927 .25242 L p .573 .854 .996 r
F P
0 g
s
.46454 .47664 m .45218 .47508 L .46639 .43852 L p .828 .694 .716 r
F P
0 g
s
.45218 .47508 m .46454 .47664 L .45692 .50818 L p .82 .686 .716 r
F P
0 g
s
.24758 .46067 m .26127 .46994 L .25504 .52798 L p .439 .481 .806 r
F P
0 g
s
.26856 .53759 m .25504 .52798 L .26127 .46994 L p .475 .498 .802 r
F P
0 g
s
.44301 .51213 m .45692 .50818 L .45403 .53781 L p .814 .683 .72 r
F P
0 g
s
.45403 .53781 m .43956 .54697 L .44301 .51213 L p .814 .683 .72 r
F P
0 g
s
.47073 .38306 m .47768 .39378 L .45638 .43163 L p .833 .71 .729 r
F P
0 g
s
.46639 .43852 m .45638 .43163 L .47768 .39378 L p .835 .707 .723 r
F P
0 g
s
.45692 .50818 m .44301 .51213 L .45218 .47508 L p .82 .686 .716 r
F P
0 g
s
.45638 .43163 m .46639 .43852 L .45218 .47508 L p .824 .693 .72 r
F P
0 g
s
.42504 .55488 m .43956 .54697 L .44205 .57709 L p .798 .679 .733 r
F P
0 g
s
.44205 .57709 m .42802 .5892 L .42504 .55488 L p .798 .679 .733 r
F P
0 g
s
.49187 .3242 m .49531 .33574 L .46371 .37295 L p .846 .754 .761 r
F P
0 g
s
.47073 .38306 m .46371 .37295 L .49531 .33574 L p .845 .742 .749 r
F P
0 g
s
.32404 .56561 m .33824 .56912 L .34497 .61974 L p .581 .572 .807 r
F P
0 g
s
.35854 .62002 m .34497 .61974 L .33824 .56912 L p .631 .597 .797 r
F P
0 g
s
.77748 .3395 m .76327 .33034 L .72542 .28932 L p 0 .257 .75 r
F P
0 g
s
.71343 .28268 m .72542 .28932 L .76327 .33034 L p 0 .311 .794 r
F P
0 g
s
.26127 .46994 m .27501 .47877 L .26856 .53759 L p .475 .498 .802 r
F P
0 g
s
.28222 .54636 m .26856 .53759 L .27501 .47877 L p .513 .517 .797 r
F P
0 g
s
.4105 .56137 m .42504 .55488 L .42802 .5892 L p .781 .671 .742 r
F P
0 g
s
.42802 .5892 m .414 .5995 L .4105 .56137 L p .781 .671 .742 r
F P
0 g
s
.52979 .27562 m .52938 .28509 L .48838 .31386 L p .846 .834 .834 r
F P
0 g
s
.49187 .3242 m .48838 .31386 L .52938 .28509 L p .85 .808 .809 r
F P
0 g
s
.45218 .47508 m .43975 .47311 L .45638 .43163 L p .824 .693 .72 r
F P
0 g
s
.43975 .47311 m .45218 .47508 L .44301 .51213 L p .812 .682 .72 r
F P
0 g
s
.42904 .51523 m .44301 .51213 L .43956 .54697 L p .803 .677 .725 r
F P
0 g
s
.43956 .54697 m .42504 .55488 L .42904 .51523 L p .803 .677 .725 r
F P
0 g
s
.85986 .43317 m .84426 .42231 L .82152 .37035 L p .045 .332 .813 r
F P
0 g
s
.80662 .35981 m .82152 .37035 L .84426 .42231 L p .047 .326 .808 r
F P
0 g
s
.33824 .56912 m .35255 .57099 L .35854 .62002 L p .631 .597 .797 r
F P
0 g
s
.37225 .61814 m .35854 .62002 L .35255 .57099 L p .672 .618 .786 r
F P
0 g
s
.46371 .37295 m .47073 .38306 L .44629 .4248 L p .831 .714 .736 r
F P
0 g
s
.45638 .43163 m .44629 .4248 L .47073 .38306 L p .833 .71 .729 r
F P
0 g
s
.44301 .51213 m .42904 .51523 L .43975 .47311 L p .812 .682 .72 r
F P
0 g
s
.44629 .4248 m .45638 .43163 L .43975 .47311 L p .818 .691 .724 r
F P
0 g
s
.39595 .56631 m .4105 .56137 L .414 .5995 L p .761 .662 .752 r
F P
0 g
s
.414 .5995 m .40001 .60784 L .39595 .56631 L p .761 .662 .752 r
F P
0 g
s
.58244 .24881 m .57803 .25404 L .5302 .26778 L p .725 .92 .959 r
F P
0 g
s
.52979 .27562 m .5302 .26778 L .57803 .25404 L p .781 .895 .924 r
F P
0 g
s
.35255 .57099 m .36696 .57115 L .37225 .61814 L p .672 .618 .786 r
F P
0 g
s
.38608 .61407 m .37225 .61814 L .36696 .57115 L p .708 .636 .775 r
F P
0 g
s
.38143 .56959 m .39595 .56631 L .40001 .60784 L p .737 .65 .763 r
F P
0 g
s
.40001 .60784 m .38608 .61407 L .38143 .56959 L p .737 .65 .763 r
F P
0 g
s
.27501 .47877 m .28882 .48699 L .28222 .54636 L p .513 .517 .797 r
F P
0 g
s
.29602 .55408 m .28222 .54636 L .28882 .48699 L p .551 .536 .792 r
F P
0 g
s
.36696 .57115 m .38143 .56959 L .38608 .61407 L p .708 .636 .775 r
F P
0 g
s
.41501 .51736 m .42904 .51523 L .42504 .55488 L p .789 .669 .731 r
F P
0 g
s
.42504 .55488 m .4105 .56137 L .41501 .51736 L p .789 .669 .731 r
F P
0 g
s
.48838 .31386 m .49187 .3242 L .45663 .3635 L p .845 .767 .776 r
F P
0 g
s
.46371 .37295 m .45663 .3635 L .49187 .3242 L p .846 .754 .761 r
F P
0 g
s
.64572 .25079 m .6374 .25066 L .58694 .24541 L p .205 .706 .911 r
F P
0 g
s
.58244 .24881 m .58694 .24541 L .6374 .25066 L p .41 .808 .985 r
F P
0 g
s
.71343 .28268 m .70168 .27737 L .65422 .25262 L p 0 .341 .727 r
F P
0 g
s
.64572 .25079 m .65422 .25262 L .70168 .27737 L p 0 .457 .833 r
F P
0 g
s
.43975 .47311 m .42724 .47069 L .44629 .4248 L p .818 .691 .724 r
F P
0 g
s
.42724 .47069 m .43975 .47311 L .42904 .51523 L p .802 .676 .725 r
F P
0 g
s
.42904 .51523 m .41501 .51736 L .42724 .47069 L p .802 .676 .725 r
F P
0 g
s
.28882 .48699 m .30268 .49448 L .29602 .55408 L p .551 .536 .792 r
F P
0 g
s
.30996 .56055 m .29602 .55408 L .30268 .49448 L p .587 .555 .786 r
F P
0 g
s
.45663 .3635 m .46371 .37295 L .43614 .41805 L p .828 .719 .744 r
F P
0 g
s
.44629 .4248 m .43614 .41805 L .46371 .37295 L p .831 .714 .736 r
F P
0 g
s
.43614 .41805 m .44629 .4248 L .42724 .47069 L p .811 .689 .73 r
F P
0 g
s
.5302 .26778 m .52979 .27562 L .48485 .30472 L p .838 .863 .863 r
F P
0 g
s
.48838 .31386 m .48485 .30472 L .52979 .27562 L p .846 .834 .834 r
F P
0 g
s
.40094 .51845 m .41501 .51736 L .4105 .56137 L p .773 .66 .738 r
F P
0 g
s
.4105 .56137 m .39595 .56631 L .40094 .51845 L p .773 .66 .738 r
F P
0 g
s
.82152 .37035 m .8366 .38074 L .85986 .43317 L p .045 .332 .813 r
F P
0 g
s
.30268 .49448 m .31661 .50111 L .30996 .56055 L p .587 .555 .786 r
F P
0 g
s
.32404 .56561 m .30996 .56055 L .31661 .50111 L p .621 .574 .78 r
F P
0 g
s
.79193 .34942 m .77748 .3395 L .73767 .29704 L p 0 .219 .717 r
F P
0 g
s
.72542 .28932 m .73767 .29704 L .77748 .3395 L p 0 .257 .75 r
F P
0 g
s
.38685 .51842 m .40094 .51845 L .39595 .56631 L p .755 .649 .745 r
F P
0 g
s
.39595 .56631 m .38143 .56959 L .38685 .51842 L p .755 .649 .745 r
F P
0 g
s
.42724 .47069 m .41467 .46777 L .43614 .41805 L p .811 .689 .73 r
F P
0 g
s
.41467 .46777 m .42724 .47069 L .41501 .51736 L p .791 .67 .73 r
F P
0 g
s
.41501 .51736 m .40094 .51845 L .41467 .46777 L p .791 .67 .73 r
F P
0 g
s
.48485 .30472 m .48838 .31386 L .44948 .35471 L p .844 .782 .792 r
F P
0 g
s
.45663 .3635 m .44948 .35471 L .48838 .31386 L p .845 .767 .776 r
F P
0 g
s
.31661 .50111 m .33059 .50678 L .32404 .56561 L p .621 .574 .78 r
F P
0 g
s
.33824 .56912 m .32404 .56561 L .33059 .50678 L p .653 .592 .773 r
F P
0 g
s
.58694 .24541 m .58244 .24881 L .53063 .26153 L p .633 .924 .975 r
F P
0 g
s
.5302 .26778 m .53063 .26153 L .58244 .24881 L p .725 .92 .959 r
F P
0 g
s
.37276 .51724 m .38685 .51842 L .38143 .56959 L p .734 .637 .752 r
F P
0 g
s
.38143 .56959 m .36696 .57115 L .37276 .51724 L p .734 .637 .752 r
F P
0 g
s
.43614 .41805 m .42591 .41137 L .45663 .3635 L p .828 .719 .744 r
F P
0 g
s
.42591 .41137 m .43614 .41805 L .41467 .46777 L p .804 .687 .735 r
F P
0 g
s
.44948 .35471 m .45663 .3635 L .42591 .41137 L p .824 .723 .753 r
F P
0 g
s
.33059 .50678 m .34461 .51139 L .33824 .56912 L p .653 .592 .773 r
F P
0 g
s
.35255 .57099 m .33824 .56912 L .34461 .51139 L p .683 .609 .766 r
F P
0 g
s
.35867 .51489 m .37276 .51724 L .36696 .57115 L p .71 .624 .759 r
F P
0 g
s
.36696 .57115 m .35255 .57099 L .35867 .51489 L p .71 .624 .759 r
F P
0 g
s
.34461 .51139 m .35867 .51489 L .35255 .57099 L p .683 .609 .766 r
F P
0 g
s
.40205 .46434 m .41467 .46777 L .40094 .51845 L p .778 .663 .736 r
F P
0 g
s
.40094 .51845 m .38685 .51842 L .40205 .46434 L p .778 .663 .736 r
F P
0 g
s
.41467 .46777 m .40205 .46434 L .42591 .41137 L p .804 .687 .735 r
F P
0 g
s
.58694 .24541 m .59154 .24371 L .64572 .25079 L p .205 .706 .911 r
F P
0 g
s
.65422 .25262 m .64572 .25079 L .59154 .24371 L p .001 .568 .79 r
F P
0 g
s
.65422 .25262 m .66292 .25598 L .71343 .28268 L p 0 .341 .727 r
F P
0 g
s
.72542 .28932 m .71343 .28268 L .66292 .25598 L p 0 .245 .633 r
F P
0 g
s
.53063 .26153 m .5302 .26778 L .48127 .29679 L p .822 .892 .893 r
F P
0 g
s
.48485 .30472 m .48127 .29679 L .5302 .26778 L p .838 .863 .863 r
F P
0 g
s
.38937 .46036 m .40205 .46434 L .38685 .51842 L p .764 .655 .741 r
F P
0 g
s
.38685 .51842 m .37276 .51724 L .38937 .46036 L p .764 .655 .741 r
F P
0 g
s
.42591 .41137 m .41561 .40478 L .44948 .35471 L p .824 .723 .753 r
F P
0 g
s
.41561 .40478 m .42591 .41137 L .40205 .46434 L p .796 .685 .742 r
F P
0 g
s
.20675 .43168 m .19318 .42214 L .22154 .37026 L p .508 .564 .847 r
F P
0 g
s
.48127 .29679 m .48485 .30472 L .44224 .34661 L p .841 .799 .81 r
F P
0 g
s
.44948 .35471 m .44224 .34661 L .48485 .30472 L p .844 .782 .792 r
F P
0 g
s
.44224 .34661 m .44948 .35471 L .41561 .40478 L p .82 .728 .763 r
F P
0 g
s
.22154 .37026 m .23465 .37839 L .20675 .43168 L p .508 .564 .847 r
F P
0 g
s
.22033 .44138 m .20675 .43168 L .23465 .37839 L p .524 .562 .836 r
F P
0 g
s
.40205 .46434 m .38937 .46036 L .41561 .40478 L p .796 .685 .742 r
F P
0 g
s
.37665 .45583 m .38937 .46036 L .37276 .51724 L p .749 .646 .748 r
F P
0 g
s
.37276 .51724 m .35867 .51489 L .37665 .45583 L p .749 .646 .748 r
F P
0 g
s
.80662 .35981 m .79193 .34942 L .75017 .30556 L p 0 .199 .697 r
F P
0 g
s
.73767 .29704 m .75017 .30556 L .79193 .34942 L p 0 .219 .717 r
F P
0 g
s
.23465 .37839 m .24771 .38655 L .22033 .44138 L p .524 .562 .836 r
F P
0 g
s
.23394 .4511 m .22033 .44138 L .24771 .38655 L p .542 .563 .825 r
F P
0 g
s
.59154 .24371 m .58694 .24541 L .53106 .25679 L p .499 .89 .955 r
F P
0 g
s
.53063 .26153 m .53106 .25679 L .58694 .24541 L p .633 .924 .975 r
F P
0 g
s
.24771 .38655 m .26074 .39469 L .23394 .4511 L p .542 .563 .825 r
F P
0 g
s
.24758 .46067 m .23394 .4511 L .26074 .39469 L p .563 .567 .815 r
F P
0 g
s
.36389 .45076 m .37665 .45583 L .35867 .51489 L p .731 .637 .754 r
F P
0 g
s
.35867 .51489 m .34461 .51139 L .36389 .45076 L p .731 .637 .754 r
F P
0 g
s
.26074 .39469 m .27373 .40273 L .24758 .46067 L p .563 .567 .815 r
F P
0 g
s
.26127 .46994 m .24758 .46067 L .27373 .40273 L p .584 .572 .806 r
F P
0 g
s
.41561 .40478 m .40522 .39827 L .44224 .34661 L p .82 .728 .763 r
F P
0 g
s
.40522 .39827 m .41561 .40478 L .38937 .46036 L p .786 .682 .749 r
F P
0 g
s
.38937 .46036 m .37665 .45583 L .40522 .39827 L p .786 .682 .749 r
F P
0 g
s
.35109 .44517 m .36389 .45076 L .34461 .51139 L p .713 .628 .761 r
F P
0 g
s
.34461 .51139 m .33059 .50678 L .35109 .44517 L p .713 .628 .761 r
F P
0 g
s
.27373 .40273 m .28669 .4106 L .26127 .46994 L p .584 .572 .806 r
F P
0 g
s
.27501 .47877 m .26127 .46994 L .28669 .4106 L p .607 .58 .798 r
F P
0 g
s
.28669 .4106 m .29962 .41823 L .27501 .47877 L p .607 .58 .798 r
F P
0 g
s
.28882 .48699 m .27501 .47877 L .29962 .41823 L p .629 .589 .79 r
F P
0 g
s
.33826 .43908 m .35109 .44517 L .33059 .50678 L p .693 .618 .767 r
F P
0 g
s
.33059 .50678 m .31661 .50111 L .33826 .43908 L p .693 .618 .767 r
F P
0 g
s
.53106 .25679 m .53063 .26153 L .47763 .29003 L p .795 .919 .922 r
F P
0 g
s
.48127 .29679 m .47763 .29003 L .53063 .26153 L p .822 .892 .893 r
F P
0 g
s
.44224 .34661 m .43493 .33918 L .48127 .29679 L p .841 .799 .81 r
F P
0 g
s
.43493 .33918 m .44224 .34661 L .40522 .39827 L p .815 .734 .775 r
F P
0 g
s
.29962 .41823 m .31252 .42556 L .28882 .48699 L p .629 .589 .79 r
F P
0 g
s
.30268 .49448 m .28882 .48699 L .31252 .42556 L p .651 .598 .782 r
F P
0 g
s
.3254 .43253 m .33826 .43908 L .31661 .50111 L p .673 .608 .775 r
F P
0 g
s
.31661 .50111 m .30268 .49448 L .3254 .43253 L p .673 .608 .775 r
F P
0 g
s
.31252 .42556 m .3254 .43253 L .30268 .49448 L p .651 .598 .782 r
F P
0 g
s
.47763 .29003 m .48127 .29679 L .43493 .33918 L p .837 .816 .83 r
F P
0 g
s
.59154 .24371 m .59625 .24356 L .65422 .25262 L p .001 .568 .79 r
F P
0 g
s
.66292 .25598 m .65422 .25262 L .59625 .24356 L p .165 0 0 r
F P
0 g
s
.39476 .39184 m .40522 .39827 L .37665 .45583 L p .776 .679 .757 r
F P
0 g
s
.37665 .45583 m .36389 .45076 L .39476 .39184 L p .776 .679 .757 r
F P
0 g
s
.66292 .25598 m .67182 .26063 L .72542 .28932 L p 0 .245 .633 r
F P
0 g
s
.73767 .29704 m .72542 .28932 L .67182 .26063 L p .399 0 0 r
F P
0 g
s
.40522 .39827 m .39476 .39184 L .43493 .33918 L p .815 .734 .775 r
F P
0 g
s
.82152 .37035 m .80662 .35981 L .7629 .31456 L p 0 .195 .692 r
F P
0 g
s
.75017 .30556 m .7629 .31456 L .80662 .35981 L p 0 .199 .697 r
F P
0 g
s
.38422 .38549 m .39476 .39184 L .36389 .45076 L p .765 .677 .765 r
F P
0 g
s
.36389 .45076 m .35109 .44517 L .38422 .38549 L p .765 .677 .765 r
F P
0 g
s
.43493 .33918 m .42752 .3324 L .47763 .29003 L p .837 .816 .83 r
F P
0 g
s
.42752 .3324 m .43493 .33918 L .39476 .39184 L p .809 .74 .787 r
F P
0 g
s
.53106 .25679 m .5315 .25347 L .59154 .24371 L p .499 .89 .955 r
F P
0 g
s
.59625 .24356 m .59154 .24371 L .5315 .25347 L p .334 .812 .891 r
F P
0 g
s
.39476 .39184 m .38422 .38549 L .42752 .3324 L p .809 .74 .787 r
F P
0 g
s
.37359 .37921 m .38422 .38549 L .35109 .44517 L p .753 .674 .774 r
F P
0 g
s
.35109 .44517 m .33826 .43908 L .37359 .37921 L p .753 .674 .774 r
F P
0 g
s
.47763 .29003 m .47394 .28436 L .53106 .25679 L p .795 .919 .922 r
F P
0 g
s
.47394 .28436 m .47763 .29003 L .42752 .3324 L p .829 .834 .851 r
F P
0 g
s
.5315 .25347 m .53106 .25679 L .47394 .28436 L p .752 .939 .946 r
F P
0 g
s
.36288 .37299 m .37359 .37921 L .33826 .43908 L p .74 .671 .784 r
F P
0 g
s
.33826 .43908 m .3254 .43253 L .36288 .37299 L p .74 .671 .784 r
F P
0 g
s
.67182 .26063 m .66292 .25598 L .60106 .24477 L p .284 0 0 r
F P
0 g
s
.59625 .24356 m .60106 .24477 L .66292 .25598 L p .165 0 0 r
F P
0 g
s
.42002 .32624 m .42752 .3324 L .38422 .38549 L p .802 .746 .801 r
F P
0 g
s
.38422 .38549 m .37359 .37921 L .42002 .32624 L p .802 .746 .801 r
F P
0 g
s
.42752 .3324 m .42002 .32624 L .47394 .28436 L p .829 .834 .851 r
F P
0 g
s
.75017 .30556 m .73767 .29704 L .68093 .26632 L p .444 0 0 r
F P
0 g
s
.67182 .26063 m .68093 .26632 L .73767 .29704 L p .399 0 0 r
F P
0 g
s
.35208 .36682 m .36288 .37299 L .3254 .43253 L p .726 .669 .794 r
F P
0 g
s
.3254 .43253 m .31252 .42556 L .35208 .36682 L p .726 .669 .794 r
F P
0 g
s
.8366 .38074 m .82152 .37035 L .77586 .32373 L p 0 .209 .702 r
F P
0 g
s
.77586 .32373 m .82152 .37035 L p .76364 .31526 L 0 .195 .692 r
F P
0 g
s
.77586 .32373 m .78901 .33274 L .8366 .38074 L p 0 .209 .702 r
F P
0 g
s
.77586 .32373 m .70942 .28674 L p .78806 .33219 L .443 0 0 r
F P
0 g
s
.78901 .33274 m .77586 .32373 L p .78806 .33219 L .443 0 0 r
F P
0 g
s
.7629 .31456 m .77586 .32373 L p .76364 .31526 L 0 .195 .692 r
F P
0 g
s
.34119 .36069 m .35208 .36682 L .31252 .42556 L p .711 .666 .804 r
F P
0 g
s
.31252 .42556 m .29962 .41823 L .34119 .36069 L p .711 .666 .804 r
F P
0 g
s
.47394 .28436 m .47017 .27973 L .5315 .25347 L p .752 .939 .946 r
F P
0 g
s
.47017 .27973 m .47394 .28436 L .42002 .32624 L p .818 .852 .874 r
F P
0 g
s
.5315 .25347 m .53195 .25143 L .59625 .24356 L p .334 .812 .891 r
F P
0 g
s
.60106 .24477 m .59625 .24356 L .53195 .25143 L p .169 .706 .798 r
F P
0 g
s
.41242 .32064 m .42002 .32624 L .37359 .37921 L p .793 .752 .815 r
F P
0 g
s
.37359 .37921 m .36288 .37299 L .41242 .32064 L p .793 .752 .815 r
F P
0 g
s
.53195 .25143 m .5315 .25347 L .47017 .27973 L p .691 .946 .959 r
F P
0 g
s
.33022 .35458 m .34119 .36069 L .29962 .41823 L p .695 .664 .815 r
F P
0 g
s
.29962 .41823 m .28669 .4106 L .33022 .35458 L p .695 .664 .815 r
F P
0 g
s
.42002 .32624 m .41242 .32064 L .47017 .27973 L p .818 .852 .874 r
F P
0 g
s
.31915 .34847 m .33022 .35458 L .28669 .4106 L p .679 .662 .827 r
F P
0 g
s
.28669 .4106 m .27373 .40273 L .31915 .34847 L p .679 .662 .827 r
F P
0 g
s
.40472 .31556 m .41242 .32064 L .36288 .37299 L p .782 .757 .83 r
F P
0 g
s
.36288 .37299 m .35208 .36682 L .40472 .31556 L p .782 .757 .83 r
F P
0 g
s
.308 .34235 m .31915 .34847 L .27373 .40273 L p .662 .661 .839 r
F P
0 g
s
.27373 .40273 m .26074 .39469 L .308 .34235 L p .662 .661 .839 r
F P
0 g
s
.68093 .26632 m .67182 .26063 L .60599 .24714 L p .361 0 0 r
F P
0 g
s
.60106 .24477 m .60599 .24714 L .67182 .26063 L p .284 0 0 r
F P
0 g
s
.7629 .31456 m .75017 .30556 L .69024 .27277 L p .464 0 0 r
F P
0 g
s
.68093 .26632 m .69024 .27277 L .75017 .30556 L p .444 0 0 r
F P
0 g
s
.47017 .27973 m .46634 .27602 L .53195 .25143 L p .691 .946 .959 r
F P
0 g
s
.46634 .27602 m .47017 .27973 L .41242 .32064 L p .802 .868 .897 r
F P
0 g
s
.29675 .33621 m .308 .34235 L .26074 .39469 L p .645 .661 .851 r
F P
0 g
s
.26074 .39469 m .24771 .38655 L .29675 .33621 L p .645 .661 .851 r
F P
0 g
s
.41242 .32064 m .40472 .31556 L .46634 .27602 L p .802 .868 .897 r
F P
0 g
s
.28542 .33001 m .29675 .33621 L .24771 .38655 L p .628 .662 .863 r
F P
0 g
s
.24771 .38655 m .23465 .37839 L .28542 .33001 L p .628 .662 .863 r
F P
0 g
s
.39691 .3109 m .40472 .31556 L .35208 .36682 L p .77 .763 .846 r
F P
0 g
s
.35208 .36682 m .34119 .36069 L .39691 .3109 L p .77 .763 .846 r
F P
0 g
s
.53195 .25143 m .53241 .2505 L .60106 .24477 L p .169 .706 .798 r
F P
0 g
s
.60599 .24714 m .60106 .24477 L .53241 .2505 L p 0 0 0 r
F P
0 g
s
.53241 .2505 m .53195 .25143 L .46634 .27602 L p .613 .936 .958 r
F P
0 g
s
.27399 .32374 m .28542 .33001 L .23465 .37839 L p .612 .664 .876 r
F P
0 g
s
.23465 .37839 m .22154 .37026 L .27399 .32374 L p .612 .664 .876 r
F P
0 g
s
.38899 .3066 m .39691 .3109 L .34119 .36069 L p .756 .768 .863 r
F P
0 g
s
.34119 .36069 m .33022 .35458 L .38899 .3066 L p .756 .768 .863 r
F P
0 g
s
.46244 .27312 m .46634 .27602 L .40472 .31556 L p .781 .882 .919 r
F P
0 g
s
.40472 .31556 m .39691 .3109 L .46244 .27312 L p .781 .882 .919 r
F P
0 g
s
.46634 .27602 m .46244 .27312 L .53241 .2505 L p .613 .936 .958 r
F P
0 g
s
.69024 .27277 m .68093 .26632 L .61103 .25044 L p .408 0 0 r
F P
0 g
s
.60599 .24714 m .61103 .25044 L .68093 .26632 L p .361 0 0 r
F P
0 g
s
.77586 .32373 m .7629 .31456 L .69974 .27969 L p .464 0 0 r
F P
0 g
s
.69024 .27277 m .69974 .27969 L .7629 .31456 L p .464 0 0 r
F P
0 g
s
.38097 .30256 m .38899 .3066 L .33022 .35458 L p .74 .772 .879 r
F P
0 g
s
.33022 .35458 m .31915 .34847 L .38097 .30256 L p .74 .772 .879 r
F P
0 g
s
.53241 .2505 m .53289 .25053 L .60599 .24714 L p 0 0 0 r
F P
0 g
s
.53289 .25053 m .53241 .2505 L .46244 .27312 L p .524 .908 .943 r
F P
0 g
s
.61103 .25044 m .60599 .24714 L .53289 .25053 L p .079 0 0 r
F P
0 g
s
.45847 .27088 m .46244 .27312 L .39691 .3109 L p .755 .892 .94 r
F P
0 g
s
.39691 .3109 m .38899 .3066 L .45847 .27088 L p .755 .892 .94 r
F P
0 g
s
.37284 .29868 m .38097 .30256 L .31915 .34847 L p .722 .775 .894 r
F P
0 g
s
.31915 .34847 m .308 .34235 L .37284 .29868 L p .722 .775 .894 r
F P
0 g
s
.46244 .27312 m .45847 .27088 L .53289 .25053 L p .524 .908 .943 r
F P
0 g
s
.69974 .27969 m .70942 .28674 L .77586 .32373 L p .464 0 0 r
F P
0 g
s
.69974 .27969 m .69024 .27277 L .61618 .2544 L p .432 0 0 r
F P
0 g
s
.61103 .25044 m .61618 .2544 L .69024 .27277 L p .408 0 0 r
F P
0 g
s
.3646 .29487 m .37284 .29868 L .308 .34235 L p .702 .776 .909 r
F P
0 g
s
.308 .34235 m .29675 .33621 L .3646 .29487 L p .702 .776 .909 r
F P
0 g
s
.45442 .26915 m .45847 .27088 L .38899 .3066 L p .724 .897 .957 r
F P
0 g
s
.38899 .3066 m .38097 .30256 L .45442 .26915 L p .724 .897 .957 r
F P
0 g
s
.53289 .25053 m .53337 .25129 L .61103 .25044 L p .079 0 0 r
F P
0 g
s
.53337 .25129 m .53289 .25053 L .45847 .27088 L p .434 .868 .917 r
F P
0 g
s
.61618 .2544 m .61103 .25044 L .53337 .25129 L p .151 0 0 r
F P
0 g
s
.45847 .27088 m .45442 .26915 L .53337 .25129 L p .434 .868 .917 r
F P
0 g
s
.35626 .29101 m .3646 .29487 L .29675 .33621 L p .681 .776 .923 r
F P
0 g
s
.29675 .33621 m .28542 .33001 L .35626 .29101 L p .681 .776 .923 r
F P
0 g
s
.4503 .26777 m .45442 .26915 L .38097 .30256 L p .69 .897 .972 r
F P
0 g
s
.38097 .30256 m .37284 .29868 L .4503 .26777 L p .69 .897 .972 r
F P
0 g
s
.70942 .28674 m .71927 .29362 L .78901 .33274 L p .443 0 0 r
F P
0 g
s
.34782 .287 m .35626 .29101 L .28542 .33001 L p .66 .775 .934 r
F P
0 g
s
.28542 .33001 m .27399 .32374 L .34782 .287 L p .66 .775 .934 r
F P
0 g
s
.70942 .28674 m .69974 .27969 L .62144 .25875 L p .435 0 0 r
F P
0 g
s
.61618 .2544 m .62144 .25875 L .69974 .27969 L p .432 0 0 r
F P
0 g
s
.53337 .25129 m .53386 .25257 L .61618 .2544 L p .151 0 0 r
F P
0 g
s
.53386 .25257 m .53337 .25129 L .45442 .26915 L p .353 .824 .89 r
F P
0 g
s
.45442 .26915 m .4503 .26777 L .53386 .25257 L p .353 .824 .89 r
F P
0 g
s
.62144 .25875 m .61618 .2544 L .53386 .25257 L p .194 0 0 r
F P
0 g
s
.44612 .26656 m .4503 .26777 L .37284 .29868 L p .653 .892 .982 r
F P
0 g
s
.37284 .29868 m .3646 .29487 L .44612 .26656 L p .653 .892 .982 r
F P
0 g
s
.71927 .29362 m .70942 .28674 L .62681 .2632 L p .419 0 0 r
F P
0 g
s
.62144 .25875 m .62681 .2632 L .70942 .28674 L p .435 0 0 r
F P
0 g
s
.44186 .26534 m .44612 .26656 L .3646 .29487 L p .618 .882 .99 r
F P
0 g
s
.3646 .29487 m .35626 .29101 L .44186 .26534 L p .618 .882 .99 r
F P
0 g
s
.53386 .25257 m .53436 .25414 L .62144 .25875 L p .194 0 0 r
F P
0 g
s
.53436 .25414 m .53386 .25257 L .45039 .26776 L p .288 .785 .869 r
F P
0 g
s
.45048 .26774 m .53436 .25414 L .45039 .26776 L .288 .785 .869 r
F
.45039 .26776 m .4503 .26777 L p .45048 .26774 L F P
0 g
s
.4503 .26777 m .44612 .26656 L .53436 .25414 L p .288 .785 .869 r
F P
0 g
s
.53487 .25574 m .53436 .25414 L .44612 .26656 L p .245 .756 .859 r
F P
0 g
s
.44612 .26656 m .44186 .26534 L .53474 .25576 L p .245 .756 .859 r
F P
0 g
s
.53474 .25576 m .53487 .25574 L p .53463 .25577 L .245 .756 .859 r
F P
0 g
s
.44612 .26656 m .53474 .25576 L .53463 .25577 L .245 .756 .859 r
F
.62681 .2632 m .62144 .25875 L .53436 .25414 L p .212 0 0 r
F P
0 g
s
.43754 .26392 m .44186 .26534 L .35626 .29101 L p .586 .869 .994 r
F P
0 g
s
.35626 .29101 m .34782 .287 L .43754 .26392 L p .586 .869 .994 r
F P
0 g
s
.62681 .2632 m .63227 .26744 L .71927 .29362 L p .419 0 0 r
F P
0 g
s
.53436 .25414 m .53487 .25574 L .62681 .2632 L p .212 0 0 r
F P
0 g
s
.63227 .26744 m .62681 .2632 L .53487 .25574 L p .205 0 0 r
F P
0 g
s
.53539 .25714 m .53487 .25574 L .44186 .26534 L p .224 .74 .864 r
F P
0 g
s
.44186 .26534 m .43754 .26392 L .53539 .25714 L p .224 .74 .864 r
F P
0 g
s
.53487 .25574 m .53539 .25714 L .63227 .26744 L p .205 0 0 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
Yoooool7o`0001kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0cooooo`00<ooo
ool3o`000:;ooooo5Ol0000Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<_oo
ool0037ooooo0_l0002Noooooa_o000000?o:P00o`000?l000001?l0000Aooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<Oooool002kooooo0ol000000ooooooo0000ooooo`2Foooo
obOo00000_lZ0004o`0000gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aoooo
o`00;Oooool2o`0000Cooooo00?o0000ooooooooool0Sooooolao`000003obX00?l0003o000000_o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`00;Oooool00ol0003ooooo
o`00002?ooooocco00002Oooool00ol0003oooooooooo`0]ooooo`?o0000<Oooool002gooooo00Co
0000oooooooooooo0000QOooool@o`0000?o>KgM00Go`?3bo`000?l0003o0000oj;/n@05okW[mAGo
00000olf00000ol0003oK`00o`000005o`000003ofP00?l0003o000000;o000000?oG000o`000?l0
00000_l00007ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;oooool002gooooo
00Go0000ooooooooooooooooo`00001jooooo`[o00002?li_Md00om_g^[oQ^SaohKXl@02oic_m@;o
/?;e00So0000ol3`l_o0l?;o0000ol_[k?l0003od^CTo`0000?o^N_e0_l00004olOUk0?o000000?o
d=cRo`000?noe^/00onoe^/@o`0000;oK`003_l00005ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo0ol00003ooooo`03o`000?oooooooooo07?ooooo1?l00000
1?nFg_ko0000o`000?l00004ocVmg@03ock1fom9b=koF];S00;oF];S0_m_g^X3ohKXl@?oW>oe00?o
/?;eo`000?l000000_o0l?800ol0003obn_/o`000002om;Ti0?o00001_o7iN`2o`0000?od=cR00?o
0000okoFjonoe^/02_noe^/01?l0003o[/?Zojk3j_n^`nX8o`0000;oK`002?l000000omX003o0000
o`000002o`0000?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`00;?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo0ol00002oiKNoP?o000000Go
W^7mo`000?l0003o0000ok3Un002o`000003oe[Bhol0003oKmkZ00CoQ^Sa0onLkoD2ok3bm@05o`00
0?o0l?;o`?3bol3`l_l000000_o;jn`01_l0003od^CTom;Ti?l0003oe]cLo`0000GoanG/00?o0000
om3Lh_o@g>800oo@g>82o`0000?o_mK[2Ol00006ojk3jP;o00000onI`_@4o`0000?oK`002ol00000
0ooooooo0000ooooo`0booooo`03o`000?oooooooooo02gooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0J_ooool4o`0000;oU]kn0ol000001_nNhOgo0000o`000?nWi?_o
0000ok3Un0Co000000Co`NC`o`000?l0003oQ^Sa0onLkoD3ok3bm@03o`000?o0l?;o`?3b00;o`?3b
0_o;jn`00ol0003od^CTom;Ti002o`0000;oe]cL00Co0000olOUk?o7iNco00001Oo@g>83o`000003
omCDf?l0003ob=3O00[ob=3O00?o0000ok_2gol000001_n^`nX2o`0000CoVL;d1Ol00003ofl000?o
000000?oKP00o`000?l000000ol0000dooooo`03o`000?oooooooooo02cooooo000/ooooo`?o0000
1_ooool00ol0003oooooooooo`1Uooooo`Co00000onFg_h2o`0000;oW^7m0_l00002ojOTn`;o/>Gh
1?l000001?o1i?3o0000o`000?o7hN/2o`0000?o/?;e00?o0000ol3`l_o0l?800oo0l?82ol_[k003
o`000?oBi>Cod^CT00;o00000ooFg=`2o`0000God=cR0ol00004omCDf003o`000?o8d=oob=3O00So
b=3O00?o0000ok_2gonk`]l00_nk`]l2o`0000Go[/?Z0_l000001?nI`_Co0000o`000?nDZ^D6o`00
00?oK`001ol0000cooooo`;o0000;Oooool002cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Pooooo`Co00001?nFg_h2o`0000;oW^7m0_l00002ojOTn`03o`000?n`iOSo000000;o
000000Go^NGdo`000?o1i?3o`NC`o`000002olOQj`04o`000?o=g^Go0000o`0000Ko`?3b0oo;jn`0
1?l0003od^CTom;Ti?l00004omKLg003o`000?oHeMGo000000?od=cR0_l00006omCDf003o`000?o8
d=oob=3O00Wob=3O00?o0000ok_2gonk`]l01?nk`]l2o`0000Go[/?Z00?o0000oiBZiOnDZ^D00_nD
Z^D00ol0003oOJ;ZogfRjP06o`0000?oK`001Ol0000booooo`03o`000?oooooooooo02_ooooo000A
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0000GoU]kn
00Co0000oikQoOnNhOgoW^7m0_l00003ojOTn`04o`000?n`iOSo0000o`0000;o^NGd00?o0000ol7T
l?o1i?000_l000001Oo7hN_o0000o`000?o=g^Go000000;odM[O00Co0000ol3`l_o0l?;o`?3b0oo;
jn`00ol0003od^CTom;Ti002o`0000?oe]cL0_l00002omSEe@04o`000?o@g>;od=cRo`0000Ooe=CH
0_l000000oo8d=oo0000o`000008o`0000Wo^l;O0_l000001?n^`n[o0000ojJ_g_l00005oiBZi@04
o`000?mmX^[oOJ;ZogfRjPOo00000_m_0005o`00037ooooo00?o0000ooooooooool0:_ooool0017o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool4o`0000GoU]kn00?o0000oikQ
oOnNhOd00_nNhOd00ol0003oYnCkojOTn`02ojOTn`;o/>Gh0_l00002okWUm003o`000?o1i?3o`NC`
00;o00000_o7hN/01?l0003ocMkUolgNiOl00003om7Jg`;o00001?o;jn`3om;Ti003o`000?oFg=co
e]cL00;oe]cL00Co0000omSEeOoHeMGof=GE0_l00007omCDf0?o000000?oe/g@o`000?o>bMH02Oo>
bMH01?l0003oa;oEo`000?l00008ok_2g`05o`000?nV[mkoYZoNojJ_g_l000001OnDZ^D01Ol0003o
OJ;ZogfRj_mmX^[o000000;oHIK/1ol000000omf003o0000o`000002o`0002oooooo00?o0000oooo
ooooool0:_ooool000Wooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`?o00002oooool00ol0003oooooooooo`1Cooooo`Co00001OnFg_h5oikQ
o@03o`000?nWi?_oYnCk00?oYnCk0on`iOP01?l0003o^NGdokWUm?l00003ol7Tl003o`000?o7hN_o
an7[00;o000000?ocMkUo`000?l000000ooAf]l00ol0003oe=GIo`000002ol_[k005o`000?oBi>Co
d^CTom;Ti?l000000ooFg=`2o`0000?of=GE00?o0000omW>col000001OoDe=P2o`0000?oe/g@00?o
0000olk9e_o>bMH02?o>bMH00ol0003oa;oEolBoe@02olBoe@?o00001?nk`]l2o`0000CoYZoN00?o
0000oiBZiOnDZ^D00onDZ^D01Ol0003oOJ;ZogfRj_mmX^[o000000;oHIK/00?o0000od66jOl00000
2_l0000^ooooo`03o`000?oooooooooo02Wooooo000Aooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
D?ooool2o`0000?oZ<K_0_l000000onFg_ko0000oikQo@03oikQo@03o`000?nWi?_oYnCk00CoYnCk
0on`iOP01Ol0003o^NGdokWUm?niiOCo000000;o`NC`0_l00002olOQj`04o`000?o=g^GocMkUo`00
00CodM[O00?o0000omCEfOoDeMT00_l00003om;Ti003o`000?oFg=coe]cL00;oe]cL00Co0000omSE
eOoHeMGof=GE0_l00002omW>c`04o`000?oDe=Soe=CHomCDf0;o00001OoFcM000ol0003oc/WFolk9
eP07olk9eP03o`000?o4_mGoa;oE00Koa;oE0_l000001Onk`]oo0000ok>aeonc/MOo000000CoYZoN
00?o0000oiBZiOnDZ^D00_nDZ^D00ol0003oOJ;ZogfRjP02ogfRjP04o`000?mQU^coHIK/o`0000;o
@HKY2_l0000^ooooo`03o`000?oooooooooo02Sooooo000Aooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1=ooooo`;o00000onXa^l2o`0000?o[/K/0ol00006ojOTn`05o`000?n`iOSo/>Gh
ok3Un?l000000oniiO@01Ol0003o`NC`ol7Tl?o1i?3o000000;oan7[0_l00002olgNi@04o`000?oA
f]oodM[Oom7Jg`;o00000_oDeMT00ol0003oe]3Do`000002om;Ti0Coe]cL0_l00003omSEe@03o`00
0?oIc/oofLk?00;ofLk?00Co0000omCDf?l0003o00001OoFcM02o`000003olk9e_l0003o000000Oo
00002oo4_mD00ol0003o/k7Gok>ae`02ok>ae`03o`000?nV[mkoYZoN00;oYZoN00?o0000oiBZiOnD
Z^D00_nDZ^D00ol0003oOJ;ZogfRjP02ogfRjP05o`000?mQU^coHIK/o`000?m1Q^T00_l00002oamc
hPOo0000;Oooool2o`0002Wooooo000Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_ooool2o`00
00CoZ<K_00?o0000ojk6k?n^a^`00_n^a^`01Ol0003o/lKXok?6j?nca^So000000?oYnCk1?n`iOP4
okWUm005o`000?o1i?3o`NC`ol7Tl?l000000oo7hN/01Ol0003ocMkUolgNiOo=g^Go000000?odM[O
00Go0000omCEfOoDeMWoe=GIo`000002omK@e0;o00001?oFg=`00ol0003of=GEomSEe@02omSEe@03
o`000?oIc/oofLk?00;ofLk?0_l00006omK=d0;o000000?oelK9o`000?oAa<d02?oAa<d00ol0003o
b[g=o`000002o`0000Goa;oE00?o0000okfcd?l000001Onc/ML00ol0003oYZoNojJ_gP02ojJ_gP03
o`000?nDZ^GoU:[U00;oU:[U00?o0000ogfRj_mmX^X00_mmX^X00ol0003oHIK/of6Fk002o`000006
od66jOl0003o7g?Roamch_l0003o067G0_l000001?mf003o0000o`000?l0000[ooooo`;o0000:Ooo
ool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0
000@ooooo`03o`000?oooooooooo04Oooooo0_l00004ojS6k`;o00000on^a^`2o`0000Co/lKX0ol0
0003ok3Un0Co^NGd00?o0000ol7Tl?o1i?000_o1i?001?l0003oan7[olOQjol00003olgNi@;o0000
0ooAf]l01Ol0003oe=GIomCEfOoDeMWo000000;oe]3D00?o0000omO<col000000ooFg=`01?l0003o
f=GEomSEeOoHeMD2o`0000CofLk?00?o0000omW8bOl000001?oFcM02o`0000?oelK900?o0000om74
cOoAa<d01_oAa<d00ol0003ob[g=olZmc@03olZmc@?o000000?oa;oEo`000?nm/m000_nm/m000ol0
003o/k7Gok>ae`03ok>ae`03o`000?nV[mkoYZoN00;oYZoN00?o0000oiBZiOnDZ^D00_nDZ^D00ol0
003oOJ;ZogfRjP02ogfRjP04o`000?mQU^coHIK/o`0000;o@HKY00Go0000oamch_lOLn;o0000o`1Q
e`06o`0002cooooo00?o0000ooooooooool09_ooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`;o0000AOooool2o`0000CoZ<K_0_l0
0003ojk6k0;o00001Onca^P00ol0003o^<KTokS6i004o`0000?o^NGd1?o1i?001Ol0003oan7[olOQ
joo7hN_o000000?ocMkU00?o0000om7JgooAf]l00_oAf]l01Ol0003oe=GIomCEfOoDeMWo000000;o
e]3D00Ko0000omO<cooGc<ooelc?o`000?oFg=`4omSEe@03o`000?oIc/oofLk?00?ofLk?00Co0000
omW8bOoIb<Wo00000_oFcM02o`0000CoelK900?o0000om74cOoAa<d01ooAa<d00ol0003ob[g=olZm
c@06olZmc@03o`000?nm/m3o_K?@00?o_K?@00?o0000ok>aeonc/ML00_nc/ML00ol0003oYZoNojJ_
gP03ojJ_gP03o`000?nDZ^GoU:[U00_o00000_m1Q^T01Ol0003o7g?Roamch_l0003o067G00Ko0000
:oooool00ol0003oooooooooo`0Vooooo`00:_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo043ooooo0_l00004ojS6k`;o00001?n^a^`00ol0003o/lKXok?6j003ok?6j0;o00000_nh
a^@01?l0003o_LGQokg5hOnmaN42o`0000Go`NC`1?o7hN/4olgNi@04o`000?oAf]oodM[Oom7Jg`;o
00000_oDeMT2o`0000;oe]3D00Co0000omO<cooGc<ooelc?0_l00004omSEe@03o`000?oIc/oofLk?
00;ofLk?0_l00003omW8b@03o`000?oFcM3o000000KoelK900?o0000om74cOoAa<d00_oAa<d5o`00
00Wob[g=00?o0000okfcd?nm/m001?nm/m000ol0003o/k7Gok>ae`02ok>ae`03o`000?nV[mkoYZoN
00;oYZoN0ol00002oiZLe@?oRiGH0ol000000omjS=[o0000o`000004o`0000;o7g?R00Co0000o`1Q
eol0003o04o;1Ol0000Zooooo`03o`000?oooooooooo02Gooooo000Zooooo`;o00005Oooool00ol0
003oooooooooo`0mooooo`;o00001?nXa^l2o`0000Co[/K/0_l00004ok?6j0;o00000onha^@01Ol0
003o_LGQokg5hOnmaN7o000000;o`LCL00Co0000ol7Tl?o1i?3o00000oo7hN/00ol0003ocMkUolgN
i@02olgNi@05o`000?oAf]oodM[Oom7Jgol000000ooDeMT01Ol0003oe]3DomK@e?oFd=Co000000?o
elc?00?o0000omS8b_l000000ooHeMD5omW>c`03o`000?oIb<WofLS900;ofLS90_l00007omO6b@Ko
00001?oC_lH00ol0003oc[[7o`000002o`0000Cob[g=00?o0000olBcb_l000001Onm/m000ol0003o
/k7Gok>ae`03ok>ae`05o`000?nV[mko0000o`000?nVX]401?nJW=D3o`0000?oRiGH0_mjS=X01?l0
003oIh?JofN3f_mWPmX3o`000005oamch_l0003o067Go`000?l0Cl/01_l0000Yooooo`03o`000?oo
oooooooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool2
o`0000GoZ<K_00?o0000ojk6k?n^a^`00on^a^`00ol0003o/lKXok?6j003ok?6j004o`000?nha^Co
^<KTokS6i0;o00000onmaN401?l0003o`LCLol74g?o1a=`4o`0000;oan7[1Oo=g^D4om7Jg`05o`00
0?oDeMWoe=GIomCEfOl000000ooFd=@01Ol0003oelc?omO<cooGc<oo000000?of<S:00?o0000omSE
eOoIc/l01?oIc/l00ol0003ofLS9omW8b@02omW8b@03o`000?oI`lCo000000GoelK90_l000000ooG
`LCo0000om>oaP06om>oaP03o`000?o>^/Ooc[[700?oc[[70_l000000oo:_Lgo0000olBcbP02olBc
bP03o`000?nm/m3o_K?@00?o_K?@00?o0000ok>aeonc/ML00_nc/ML2o`0000CoYZ;A0ol000000onJ
W=Go0000oh^Ef003oh^Ef0?oNXcJ00Co0000ofN3f_mWPm[oIh?J0_mENMX3o`000003o`1Qeol0003o
04o;00Ko0000:?ooool2o`0002Gooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0=oooool2o`0000GoZ<K_0_l00004ojk6k0;o00001?nca^P2o`0000?o^<KT00?o0000okg5
hOnmaN400_nmaN401Ol0003o`LCLol74g?o1a=co000000CoaL?H0_l00004olgNi@CodM[O00Go0000
omCEfOoDeMWoe=GIo`000003omK@e005o`000?oGc<ooelc?omO<col000001?oHb<X00ol0003ofLk?
omW>c`03omW>c`03o`000?oIb<WofLS900;ofLS900Co0000omW3a?oI`lCo00000ooGa/T2o`0000?o
el7400?o0000om>oa_oC_lH01OoC_lH00ol0003oc[[7oljja`05oljja`03o`000?o4/l[oa;?:00?o
a;?:00?o0000okfcd?nm/m000onm/m001Ol0003o/k7Go`000?l0003o/JK=00;oYZ;A1?l00003oiZL
e@03o`000?n;UMSoRiGH00;oRiGH00Go0000ogZ<f_mjS=[oNXcJo`000003ofN3fPCoEGWJ0ol00000
1?l0Cl_o0000o`000?l0>;L4o`0002Kooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@07ooooo`00:_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03Cooooo0_l00005ojS6k`;o00001On^a^`00ol0003o/lKX
ok?6j003ok?6j003o`000?nha^Co^<KT00;o^<KT00?o0000okg5hOnmaN400_nmaN401Ol0003o`LCL
ol74g?o1a=co000000CoaL?H00Co0000olS1e?o8`MCo00000_o=g^D4om7Jg`Coe=GI00Go0000omK@
e?oFd=Coe]3Do`000003omO<c`03o`000?oHb<[of<S:00?of<S:00?o0000omW>cooIc/l00_oIc/l5
omW8b@05o`000?oI`lCofL?4omW3a?l000000_oGa/T00ol0003oel74omO1a003omO1a003o`000?oC
_lKodko600Codko600?o0000oljjaoo>^/L01_o>^/L00ol0003oa;?:olBcbP03olBcbP03o`000?nm
/m3o_K?@00?o_K?@0_l00002ok6Vc@?o00000onVX]400ol0003oVYcEoiZLe@02oiZLe@03o`000?n;
UMSoRiGH00;oRiGH00Co0000ogZ<f_mjS=[o00000omWPmX01?l0003oEGWJoeEif_mENMX2od=_f0;o
000000Co04o;o`000?l0003o03Rg1?l0000Vooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`00:_ooool2o`00
01Wooooo00?o0000ooooooooool0<Oooool2o`0000KoZ<K_00?o0000ojk6k?n^a^`00on^a^`2o`00
00Co/lKX0_l00003okS6i0;o00000onmaN42o`0000?o`LCL00?o0000olG3f?o5`mP00_o5`mP00ol0
003ob<7DolS1e002olS1e003o`000?oAf]oodM[O00;odM[O1?oDeMT5omK@e0?oelc?00?o0000omS8
b_oHb<X00ooHb<X00ol0003of<C6o`000002omW>c`CofLS90_l00004omW3a003o`000?oGa/Wo0000
00Goel7400?o0000om>oa_oC_lH01OoC_lH00ol0003oc[[7oljja`05oljja`03o`000?o:]<Co0000
00Goa;?:00Ko0000okfcd?nm/m3o_K?@o`000?njZLP3o`0000;o/JK=00?o0000ojJRdOnVX]400_nV
X]401Ol0003oVYcEoiZLeOnJW=Go000000CoRiGH00Go0000ogZ<f_mjS=[oNXcJo`000002ofN3fP03
o`000?mENM[oEGWJ00;oEGWJ0om3KmP4o`000003o`0h]ol0003o000000;o00009_ooool00ol0003o
ooooooooo`05ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`05oooo
o`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02kooooo0ol00006ojS6k`Ko
[/K/00?o0000ok?6j?nca^P00onca^P00ol0003o^<KTokS6i002okS6i003o`000?nmaN7o_LGQ00;o
_LGQ00?o0000ol74g?o1a=`00_o1a=`00ol0003oaL?HolG3f002olG3f003o`000?o8`MCob<7D00;o
b<7D00?o0000ol_0d?l000000_oAf]l4omCEf@Goe]3D0ooGc<l00ol0003of<S:omS8bP03omS8bP05
o`000?oHa<Kof<C6omS4a_l000001OoIb<T5omW3a0;o00001ooG`L@01?l0003odko6om>oa_oC_lH4
o`000003oljjaol0003oc[[700Coc[[700Go0000olZda?o:]<Cob[C4o`000005olBcbP03o`000?nm
/m3o000000;o000000?o^ZW8ok6VcOnaY/d00_naY/d00ol0003oYZ;AojJRd@02ojJRd@05o`000?nJ
W=GoVYcEoiZLeOl000001?n;UMP01?l0003oNXcJogZ<f_mjS=X2o`0000;oIh?J00Go0000oeEif_mE
NM[oEGWJo`000002od=_f0;o<VKE0ol000000ol0>;Oo0000o`000003o`0002Gooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool0
02Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0/ooooo`04o`000?nLZN3oW:WP
oibYh0;o00000_nXa^l00ol0003o[/K/ojk6k003ojk6k003o`000?nca^So/lKX00?o/lKX0_l00004
okS6i003o`000?nmaN7o_LGQ00;o_LGQ00?o0000ol74g?o1a=`00_o1a=`00ol0003oaL?HolG3f002
olG3f003o`000?o8`MCob<7D00;ob<7D00Go0000ol_0d?o;`=3obl3@o`000004omCEf@Goe]3D0ooG
c<l00ol0003of<S:omS8bP03omS8bP03o`000?oHa<Kof<C600;of<C600?o0000omW8bOoIb<T00_oI
b<T5omW3a003o`000?oI_l3o000000Koel741Ol00003omFk`@03o`000?oA^<7odKS100?o00000_o>
^/L00ol0003ob[C4olZda002olZda004o`000?o4/l[oa;?:olBcbP?o00001?njZLP00ol0003o/JK=
ok6Vc@02ok6Vc@03o`000?nVX]7oYZ;A00;oYZ;A00Go0000oiZLeOnJW=GoVYcEo`000004oh^Ef008
o`000?mjS=[oNXcJo`000?mWPm[o0000ofN3f_l00003oeEifP04o`000?m3KmSo@foHod=_f0?o<VKE
0_l000001?l0>;Oo0000o`000?l0<K42o`0002Cooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3o`00
01cooooo00?o0000ooooooooool0:_ooool00ol0003oW:WPoibYh003oibYh0?o00001On^a^`00ol0
003o/lKXok?6j002ok?6j0;o00001?nha^@2o`0000Co_LGQ00?o0000ol74g?o1a=`00_o1a=`00ol0
003oaL?HolG3f002olG3f003o`000?o8`MCob<7D00;ob<7D00?o0000ol_0d?o;`=000_o;`=02o`00
00;oe=GI1OoFd=@3omO<c`03o`000?oHb<[of<S:00?of<S:00?o0000omS4a_oHa<H00_oHa<H2o`00
00?ofLS91OoI`l@01?l0003ofKo0omVo`?l00004omO1a0;o000000?oekfoo`000?oE^l401?oE^l40
0ol0003odKS1om6h`@04om6h`@;o00001Oo:]<@5o`000003ol6/aOl0003o^ZW800?o^ZW800?o0000
ok6VcOnaY/d00_naY/d00ol0003oYZ;AojJRd@02ojJRd@05o`000?nJW=GoVYcEoiZLeOl000001?n;
UMP01?l0003oNXcJogZ<f_mjS=X2o`000003ofN3f_l0003oEGWJ00?oEGWJ00?o0000od=_f?m3KmP0
1?lbI]D2o`000004o`0h]ol0003o0000o`0a/@;o00009?ooool00ol0003oooooooooo`03ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000oibYh?nLZN000onLZN001?l0003o
X:WLoj2Yg?nPZM`2o`0000;o[/K/1Onca^P00ol0003o^<KTokS6i003okS6i003o`000?nmaN7o_LGQ
00?o_LGQ00?o0000ol74g?o1a=`00_o1a=`00ol0003oaL?HolG3f002olG3f003o`000?o8`MCob<7D
00;ob<7D00?o0000ol_0d?o;`=000_o;`=000ol0003ocKk=olfnc@02o`0000Coe]3D0ooGc<l00ol0
003of<S:omS8bP03omS8bP03o`000?oHa<Kof<C600;of<C600Go0000omS1`_oH`L;o0000omW8b@05
omW3a004o`000?oI_l3ofKo0o`0000;oel740ol00003omNm_`KoeK_100?o0000om6h`OoA^<401OoA
^<401?l0003ob[C4olZda?o:]<@4o`000003olBcb_l0003o`Jc500;o`Jc500?o0000okZYb?njZLP0
0_njZLP00ol0003o/JK=ok6Vc@02ok6Vc@05o`000?nVX]7oYZ;AojJRdOl000000onJW=D00ol0003o
RiGHoh^Ef002oh^Ef009o`000?mjS=[oNXcJogZ<f_l0003oIh?Jo`000?mWPm[o000000?oEGWJ00Co
0000od=_f?m3KmSo@foH0olbI]D2ob=NdP05o`000?l0>;Oo0000o`000?l0<K400_l0000Rooooo`?o
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02Oooool002Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?nLZN3oW:WP00?o
W:WP00?o0000oj2Yg?nPZM`00onPZM`3o`0000Co/lKX00?o0000okS6i?nha^@00onha^@00ol0003o
_LGQokg5h@03okg5h@04o`000?o1a=co`LCLol74g0;o00001?o5`mP00ol0003ob<7DolS1e002olS1
e003o`000?o;`=3obl3@00;obl3@00Oo0000olfncOo=_/gocKk=o`000?o?_LWo000000;oe]3D1?oG
c<l5omS8bP03o`000?oHa<Kof<C600;of<C600Go0000omS1`_oH`L;of<72o`000004omW3a0;o0000
0ooI_l000ol0003oel74o`000005omNm_`03o`000?oE^l7oeK_100CoeK_100?o0000om6h`OoA^<40
1?oA^<400ol0003oc[?0o`000002o`0000Cob[C400?o0000ol6/aOo1[<D00_o1[<D00ol0003o^ZW8
okZYb002okZYb003o`000?naY/go/JK=00;o/JK=00?o0000ojJRdOnVX]400_nVX]401Ol0003oVYcE
oiZLeOnJW=Go000000CoRiGH00Co0000ogZ<f_mjS=[o00000_mWPmX2o`0000?oEGWJ00Go0000od=_
f?m3KmSo@foHo`000003oc9Ve@;o8ekB00Go0000o`0h]ol0003o0000o`0a/@02o`0002?ooooo00?o
0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?nLZN3oW:WP00?oW:WP00?o0000oj2Yg?nPZM`00onPZM`01Ol0003oYJWIojFYfOnUZMWo0000
00;o/lKX1_nha^@00ol0003o_LGQokg5h@03okg5h@03o`000?o1a=co`LCL00;o`LCL1Oo5`mP00ol0
003ob<7DolS1e002olS1e003o`000?o;`=3obl3@00;obl3@00Go0000olfncOo=_/gocKk=o`000003
olnmb@03o`000?oGc<ooelc?00;oelc?1OoHb<X00ol0003of<C6omS4aP02omS4aP03o`000?oH`L;o
f<7200;of<7200Go0000omW3a?oI`lCofL?4o`000004omVo`0;o00001ooG_Kl00ol0003oeK_1omFk
`@03omFk`@03o`000?oA^<7odKS100CodKS10ol000000oo>/l3o0000olZda003olZda0;o00001?o1
[<D00ol0003o^ZW8okZYb002okZYb003o`000?naY/go/JK=00?o/JK=00Go0000ojJRdOnVX]7oYZ;A
o`000003oiZLe@03o`000?n;UMSoRiGH00;oRiGH00Go0000ogZ<f_mjS=[oNXcJo`000002ofN3fP;o
00000omENMX01?l0003o@foHod=_f?l00003oc9Ve@?o8ekB1?l000000ol0<K7o0000o`00000Soooo
o`03o`000?oooooooooo01kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Q
ooooo`03o`000?oooooooooo02;ooooo00?o0000oibYh?nLZN000onLZN000ol0003oX:WLoj2Yg003
oj2Yg003o`000?nUZMWoYJWI00?oYJWI0_l00005okS6i0Ko_LGQ1Oo1a=`5olG3f003o`000?o8`MCo
b<7D00;ob<7D00?o0000ol_0d?o;`=000_o;`=001Ol0003ocKk=olfncOo=_/go000000Cockg90_l0
0002omO<c`Gof<S:00?o0000omS4a_oHa<H00_oHa<H00ol0003of<72omS1`P02omS1`P;o00000ooI
`l@4omVo`003o`000?oH^kgo000000Koekfo00Co0000omFk`OoE^l7oeK_11Ol00003om6h`@?o0000
0oo>/l001ol0003ob[C4olZda?o:]<Co0000olN^`Ol000001Oo1[<D00ol0003o^ZW8okZYb002okZY
b003o`000?naY/go/JK=00;o/JK=00Go0000ojJRdOnVX]7oYZ;Ao`000003oiZLe@03o`000?n;UMSo
RiGH00;oRiGH00Go0000ogZ<f_mjS=[oNXcJo`000002ofN3fP;o00000omENMX01Ol0003o@foHod=_
f?m3KmSo000000;o<VKE00?o0000ob=Nd_lSG]800_lHF=03o`000003o`0a/Ol0003o000002?ooooo
00?o0000ooooooooool07Oooool000Co00000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool07oooool2o`0000GoW:WP00?o0000oj2Yg?nPZM`00onPZM`00ol0003oYJWI
ojFYf@04ojFYf@04o`000?nYZMKo0000o`0000;o^<KT1_nmaN45ol74g0GoaL?H00?o0000olS1e?o8
`M@00_o8`M@00ol0003obl3@ol_0d002ol_0d005o`000?o=_/gocKk=olfncOl000001?o?_LT01?l0
003od;_6om2ka_l00005omS8bP03o`000?oHa<Kof<C600;of<C600?o0000omS1`_oH`L800_oH`L80
1Ol0003of;foomRm_ol0003ofL?400CofKo000Co0000omRk_OoH^kgo00001OoG_Kl5o`0000?oe[Vm
00?o0000om>f_Ol000000_l000000ooA^<7o0000oljc`004oljc`003o`000?o:]<Co000000?oajk1
00?o0000ol6/aOo1[<D00_o1[<D00ol0003o^ZW8okZYb002okZYb003o`000?naY/go/JK=00;o/JK=
00?o0000ojJRdOnVX]402_l000001On;UMSo0000ogZ<f_mjS=[o000000?oIh?J00?o0000oeEif_mE
NMX00_mENMX01?l0003o@foHod=_f?l00003oc9Ve@?o8ekB0olHF=02o`000003o`0a/Ol0003o0000
02;ooooo00?o0000ooooooooool07Oooool000Kooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo01gooooo00?o0000oibYh?nLZN001?nLZN000ol0003oX:WLoj2Yg003oj2Y
g003o`000?nUZMWoYJWI00CoYJWI00?o0000ojVYe_nYZMH00_nYZMH2o`0000Go_LGQ1Oo1a=`5olG3
f003o`000?o8`MCob<7D00;ob<7D00?o0000ol_0d?o;`=000_o;`=001Ol0003ocKk=olfncOo=_/go
000000Cockg900Co0000om2ka_o@^lKod;_60_l00003omS8bP03o`000?oHa<Kof<C600;of<C600?o
0000omS1`_oH`L800_oH`L801Ol0003of;foomRm_ooH_Koo000000CofKo000Go0000omRk_OoH^kgo
f;^mo`000003omNm_`;o000000?oekVlo`000?oF^Kd01?oF^Kd3o`0000?odkJm00?o0000oljc`?o>
/l001Oo>/l000ol0003oajk1olN^`@02olN^`@03o`000?o1[<Go`Jc500?o`Jc500Go0000okZYb?nj
ZLSo^ZW8o`000003ok6Vc@Co00000_n]WLL4ojBHb@CoVY;;1?l000000omjS=[o0000ofN3fP02ofN3
fP05o`000?mENM[oEGWJoeEif_l000000om3KmP01?l0003o<VKEoc9VeOl00002ob=NdP04o`000?lH
F=3o65S@oaQHd0;o000000?o036ao`000?l000008_ooool2o`0001gooooo0006ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oW:WPoibYh004oibYh003
o`000?nPZMcoX:WL00?oX:WL00?o0000ojFYfOnUZMT01?nUZMT00ol0003oZJWFojVYeP03ojVYeP04
o`000?n]ZM?o0000o`0000;o_LGQ1Oo1a=`5olG3f003o`000?o8`MCob<7D00;ob<7D00?o0000ol_0
d?o;`=000_o;`=001Ol0003ocKk=olfncOo=_/go000000Cockg900Go0000om2ka_o@^lKod;_6o`00
0002om6j``03o`000?oHb<[of<S:00Cof<C600?o0000omS1`_oH`L800_oH`L800ol0003of;foomRm
_`02omRm_`05o`000?oI_l3ofKo0omVo`?l000001?oH^kd01?l0003oekfoomNm_ol00003omNi_003
o`000?oF^Kgoe[Vm00Co00001OoC][d00ol0003oc[?0oljc`005oljc`003o`000?o7[/7oajk100;o
ajk100?o0000ol6/aOo1[<D00oo1[<D01?l0003o^ZW8okZYb?njZLP4o`0000;o]J7500Co0000ojfM
aon]WLOo[Ig71?nTV<T00ol0003oVY;;oiZBb`02oiZBb`?oShg<0ol00002ofN3fP;o00000_mENMX0
1Ol0003o@foHod=_f?m3KmSo000000;o<VKE00Co0000ob=Nd_lSG];o00000olHF=02oa1Dc`04o`00
0?l0<K7o0000o`00023ooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0002Oo
oooo00?o0000ooooooooool06?ooool00ol0003oW:WPoibYh004oibYh003o`000?nPZMcoX:WL00?o
X:WL00?o0000ojFYfOnUZMT01?nUZMT00ol0003oZJWFojVYeP03ojVYeP03o`000?n]ZM?o[JWC00;o
[JWC0_l00004ol74g0GoaL?H00?o0000olS1e?o8`M@00_o8`M@00ol0003obl3@ol_0d002ol_0d003
o`000?o=_/gocKk=00;ocKk=00?o0000olnmbOo?_LT00_o?_LT01?l0003od;_6om2ka_l00004om6j
``03o`000?oHa<Kof<C600;of<C600?o0000omS1`_oH`L800_oH`L800ol0003of;foomRm_`02omRm
_`;o00000ooI_l05omRk_@03o`000?oG_Koo000000CoekVl0ol00002omJi_@03o`000?oC][godkJm
00?odkJm00?o0000om6c_?l000001Oo>/l000ol0003oc:nmo`000004olN^`@03o`000?o1[<Go`Jc5
00;o`Jc500Ko0000okZYb?l0003o0000okbU`_l00004okFQa@05o`000?n]WLOo[Ig7ojfMaol00000
0onTV<T00ol0003oVY;;oiZBb`02oiZBb`CoShg<0_n5Qld4o`0000?oEGWJ00Go0000od=_f?m3KmSo
@foHo`000002oc9Ve@04o`000?lSG];o8ekBo`0000?o65S@0_l@E<l01?l0003o036ao`000?l0000Q
ooooo`03o`000?oooooooooo01_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01Kooooo00?o0000oibYh?nLZN001?nLZN000ol0003oX:WLoj2Y
g003oj2Yg003o`000?nUZMWoYJWI00CoYJWI00?o0000ojVYe_nYZMH00onYZMH00ol0003o[JWCojfY
d`03ojfYd`03o`000?naZM3o000000;o`LCL1Oo5`mP00ol0003ob<7DolS1e002olS1e003o`000?o;
`=3obl3@00?obl3@00Go0000olfncOo=_/gocKk=o`000004olnmb@05o`000?o@^lKod;_6om2ka_l0
00001?oA^/<01Ol0003of<C6omS4a_oHa<Ko000000Cof<7200?o0000omRm_ooH_Kl00_oH_Kl01Ol0
003of;^momRk_Ol0003ofKo000Gof;^m0_l00003omNi_0?o00001OoF^Kd00ol0003odkJmom>f_@03
om>f_@04o`000?oA/kcodK>lo`0000?oc[?000Co0000olb__Oo<[kgo00001?o7[/400ol0003o`Jc5
ol6/a@02ol6/a@;o00000onlYL800ol0003o]J75okFQa@02okFQa@05o`000?n]WLOo[Ig7ojfMaol0
00000onTV<T00ol0003oVY;;oiZBb`02oiZBb`04o`000?n?SLcoShg<ohn=c0GoQHO=0_l00002oeEi
fP05o`000?m3KmSo@foHod=_f?l000000_lbI]D01?l0003o8ekBob=Nd_l00003oaQHd0?o45C?00Co
0000o`0a/Ol0003o00008Oooool00ol0003oooooooooo`0Jooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000oibYh?nLZN001?nLZN000ol0003o
X:WLoj2Yg003oj2Yg003o`000?nUZMWoYJWI00CoYJWI00?o0000ojVYe_nYZMH00onYZMH00ol0003o
[JWCojfYd`03ojfYd`04o`000?naZM3o/JW@ok6Yd0;o00001Oo5`mP4olS1e003o`000?o;`=3obl3@
00?obl3@00Go0000olfncOo=_/gocKk=o`000004olnmb@05o`000?o@^lKod;_6om2ka_l000001?oA
^/<00ol0003od[W0o`000002omS4aPCof<7200?o0000omRm_ooH_Kl00_oH_Kl01Ol0003of;^momRk
_OoH^kgo000000Gof;^m00?o0000omRi^_l000000ol00002omNi_003o`000?oF^Kgoe[Vm00Co0000
1?oC][d00ol0003odK>lom6c_002om6c_003o`000?o>/l3o000000?oc:nm00?o0000olN^`Oo7[/40
0_o7[/400ol0003o`Jc5ol6/a@02o`000003ol:X`?l0003o_:G200;o_:G200?o0000okFQaOneXLD0
0_neXLD01Ol0003o[Ig7ojfMaon]WLOo000000?oY9S900?o0000oiZBbonJT//00_nJT//01Ol0003o
Shg<ohn=c?n?SLco000000CoQHO=0_mjPLh3o`0000?o@foH00Go0000oc9VeOlbI]Go<VKEo`000002
ob=NdP04o`000?lHF=3o65S@o`0000?o45C?1?l0000Pooooo`03o`000?oooooooooo01[ooooo000W
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04_ooool00ol0003oW:WPoibYh004
oibYh003o`000?nPZMcoX:WL00?oX:WL00?o0000ojFYfOnUZMT01?nUZMT00ol0003oZJWFojVYeP03
ojVYeP03o`000?n]ZM?o[JWC00?o[JWC00?o0000ok6Yd?naZM000_naZM001?l0003o]Z[=o`000?l0
0002olG3f0Cob<7D00?o0000ol_0d?o;`=000oo;`=001Ol0003ocKk=olfncOo=_/go000000Cockg9
00Go0000om2ka_o@^lKod;_6o`000004om6j``05o`000?oB^L3od[W0om:i`?l000001?oH`L800ol0
003of;foomRm_`02omRm_`03o`000?oH^kgof;^m00;of;^m00?o0000omRk_OoH^kd00_oH^kd4o`00
00CoekVl1?l00002omJf^P03o`000?oD]K[o000000;o000000?odkJmo`000?oA/k`01?oA/k`00ol0
003oc:nmolb__@03olb__@03o`000?o7[/7oajk100;oajk10_l00003ol:X`005o`000?nlYL;o_:G2
okbU`_l000001?neXLD01Ol0003o[Ig7ojfMaon]WLOo000000?oY9S900?o0000oiZBbonJT//00_nJ
T//01Ol0003oShg<ohn=c?n?SLco000000CoQHO=0_mjPLh00ol0003oNX7>ogZ1cP02o`0000;o@foH
00Co0000oc9VeOlbI]Go00000_lSG]801Ol0003o65S@oaQHd?lHF=3o000000;o45C?0_l<Dlh3o`00
023ooooo00?o0000ooooooooool06Oooool002Oooooo0_l0000/ooooo`03o`000?oooooooooo013o
oooo00?o0000oibYh?nLZN001?nLZN000ol0003oX:WLoj2Yg003oj2Yg003o`000?nUZMWoYJWI00Co
YJWI00?o0000ojVYe_nYZMH00onYZMH00ol0003o[JWCojfYd`03ojfYd`03o`000?naZM3o/JW@00;o
/JW@00?o0000okJZcOnfZ/d00_nfZ/d2o`0000Cob<7D1Oo;`=001Ol0003ocKk=olfncOo=_/go0000
00Cockg900Go0000om2ka_o@^lKod;_6o`000005om6j``05o`000?oB^L3od[W0om:i`?l000000ooH
`L800ol0003of;foomRm_`02omRm_`03o`000?oH^kgof;^m00;of;^m0_l00002omRk_@?o00000_oH
^KX01ol0003oekVlomNi_?oG^Kco0000omNg^Ol000001?oF][X00ol0003oe;FjomBe^P02omBe^P03
o`000?oA/kcodK>l00CodK>l00?o0000olb__Oo<[kd00oo<[kd01?l0003oajk1olN^`Oo7[/42o`00
00Co`ZS000Go0000okbU`_nlYL;o_:G2o`000004okFQa@05o`000?n]WLOo[Ig7ojfMaol000000onT
V<T00ol0003oVY;;oiZBb`02oiZBb`05o`000?n?SLcoShg<ohn=c?l000001?n5Qld01Ol0003oNX7>
ogZ1c_l0003oNX7>00;oL7_?0ol00002oc9Ve@05o`000?lSG];o8ekBob=Nd_l000000_lHF=001?l0
003o45C?oa1Dcol@E<l3o`aCcP;o00008?ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo0_l00005oibYh003o`000?nPZMcoX:WL
00?oX:WL00?o0000ojFYfOnUZMT01?nUZMT00ol0003oZJWFojVYeP04ojVYeP03o`000?n]ZM?o[JWC
00;o[JWC00?o0000ok6Yd?naZM000_naZM000ol0003o]Z[=okJZc@03okJZc@03o`000?niZl_o0000
00;ob<7D1Oo;`=000ol0003ocKk=olfnc@02olfnc@03o`000?o?_LWockg900;ockg900Go0000om2k
a_o@^lKod;_6o`000004om6j``07o`000?oB^L3od[W0om:i`?l0003odkRno`000002omS1`PGof;fo
00Ko0000omRk_OoH^kgof;^mo`000?oG^;X4o`0000Cof;Vj00Co0000omNi_?l0003o00000_oG]kT0
1Ol0003oe[JjomJf^_oF][[o000000Goe;Fj00?o0000om6c_?oA/k`00ooA/k`00ol0003ock2ko`00
0004olb__@06o`000?o7[/7oajk1o`000?o7Zkgo00001?o2Z<001Ol0003o_:G2okbU`_nlYL;o0000
00Co]J7500Go0000ojfMaon]WLOo[Ig7o`000003ojBHb@03o`000?nJT/_oVY;;00;oVY;;00Go0000
ohn=c?n?SLcoShg<o`000004ohF7c@05o`000?mjPLkoNX7>ogZ1c_l000001Om`Nll2o`000005oc9V
eOl0003o8ekBob=Nd_l000000olHF=001?l0003o45C?oa1Dcol00003o`aCcP;o00007_ooool2o`00
01[ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool2oh:@f003
o`000?nLZN3oW:WP00;oW:WP1OnPZM`00ol0003oYJWIojFYf@05ojFYf@03o`000?nYZMKoZJWF00?o
ZJWF00?o0000ojfYdon]ZM<00_n]ZM<00ol0003o/JW@ok6Yd002ok6Yd003o`000?nfZ/go]Z[=00?o
]Z[=00Co0000okV[boniZl_o^J_;0_l00004ol_0d003o`000?o=_/gocKk=00;ocKk=00?o0000olnm
bOo?_LT00_o?_LT01Ol0003od;_6om2ka_o@^lKo000000CodK[300Go0000om:i`?oB^L3od[W0o`00
0003om>h_P03o`000?oH_Koof;fo00?of;fo00Co0000omRk_OoH^kgof;^m0ol000000ooG^;[o0000
o`000005omRi^P03o`000?oG^KcoekNi00?oekNi00Go0000omJf^_oF][[oe[Jjo`000004omBe^P03
o`000?oC/kWo000000?odK>l00Co0000oln`^oo?/;_o00001Oo<[kd2o`0000;oaj^m00?o0000ol:X
`?o2Z<000_o2Z<001Ol0003o_:G2okbU`_nlYL;o000000Go]J7500Go0000ojfMaon]WLOo[Ig7o`00
0003ojBHb@05o`000?nJT/_oVY;;oiZBbol000000on?SL`00ol0003oQHO=ohF7c@02ohF7c@03o`00
0?mjPLkoNX7>00;oNX7>00?o0000og1kcom`Nll00_m`Nll2ofIfc`;o00000_lSG]801Ol0003o65S@
oaQHd?lHF=3o000000;o45C?00Co0000o`aCc_l<Dlko35?>0_l;E=000ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Oooooo000Wooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02oooool01Ol0003oPY3Hoh:@f?n2T=So000000;oW:WP1OnPZM`00ol0003oYJWIojFYf@05ojFY
f@03o`000?nYZMKoZJWF00?oZJWF00?o0000ojfYdon]ZM<00on]ZM<00ol0003o/JW@ok6Yd002ok6Y
d003o`000?nfZ/go]Z[=00;o]Z[=00?o0000okV[boniZl/00_niZl/01?l0003o_J_8o`000?l00002
ol_0d0CocKk=00?o0000olnmbOo?_LT00_o?_LT01Ol0003od;_6om2ka_o@^lKo000000GodK[300Go
0000om:i`?oB^L3od[W0o`000003om>h_P;o00000ooH_Kl00ol0003of;^mo`000003o`0000?oekRj
00?o0000omRi^_oH^KX00ooH^KX2o`0000CoekNi00?o0000omJf^_oF][X00_oF][X00ol0003oe;Fj
omBe^P02omBe^P06o`000?oC/kWodk>io`000?oA/kco00000oo?/;/00ol0003oc:nmolb__@03olb_
_@05o`000?o7Zkgoaj^molN[_Ol000001?o2Z<000ol0003o_:G2okbU`P02okbU`P03o`000?neXLGo
]J7500;o]J7500Go0000ojfMaon]WLOo[Ig7o`000003ojBHb@03o`000?nJT/_oVY;;00;oVY;;00Co
0000ohn=c?n?SLco00001?n5Qld00ol0003oNX7>ogZ1cP02ogZ1cP03o`000?m`NlooL7_?00;oL7_?
0omVM/l01Ol0003o8ekBob=Nd_lSG];o000000?o65S@00Co0000oa1Dcol@E<oo00000ol<Dlh2o`]D
d003o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool002Oooooo0_l0000`ooooo`03
o`000?oooooooooo00[ooooo00?o0000oh:@f?n2T=P00_n2T=P2o`0000GoX:WL1onUZMT00ol0003o
ZJWFojVYeP03ojVYeP03o`000?n]ZM?o[JWC00?o[JWC00?o0000ok6Yd?naZM000_naZM000ol0003o
]Z[=okJZc@03okJZc@05o`000?niZl_o^J_;okV[bol000001?nmZlP2o`0000?ocKk=00?o0000olnm
bOo?_LT00_o?_LT00ol0003od;_6om2kaP02om2kaP03o`000?oA^/?odK[300;odK[300Go0000om:i
`?oB^L3od[W0o`000003om>h_P05o`000?oD][coe;Jlo`000?oH_Kl00ol00002omRk_@03o`000?oG
^;[oekRj00;oekRj00?o0000omRi^_oH^KX00_oH^KX00ol0003oekJho`000004omNg^@05o`000?oF
][[oe[JjomJf^_l000001?oD]KX00ol0003odk>iom>c^@02om>c^@03o`000?o?/;_ock2k00?ock2k
00Co0000olb__Oo<[kgoc:nm0_l00003olN[_@03o`000?o2Z<3o`ZS000;o`ZS000?o0000okbU`_nl
YL800_nlYL800ol0003o]J75okFQa@02okFQa@05o`000?n]WLOo[Ig7ojfMaol000000onTV<T00ol0
003oVY;;oiZBb`02oiZBb`05o`000?n?SLcoShg<ohn=c?l000000on5Qld00ol0003oNX7>ogZ1cP02
ogZ1cP;o00000om`Nll01?l0003oIWK?ofIfcomVM/l2o`000003ob=Nd_l0003o65S@00;o65S@00Co
0000oa1Dcol@E<oo00000ol<Dlh3o`]Dd003o`000?oooooooooo01cooooo00?o0000ooooooooool0
5_ooool002Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`03o`000?n2
T=SoPY3H00?oPY3H0_n6SmH2o`0000;oX:WL1onUZMT00ol0003oZJWFojVYeP03ojVYeP03o`000?n]
ZM?o[JWC00?o[JWC00?o0000ok6Yd?naZM000_naZM000ol0003o]Z[=okJZc@03okJZc@05o`000?ni
Zl_o^J_;okV[bol000001OnmZlP00ol0003o`:c6o`000002olfnc@Gockg900Go0000om2ka_o@^lKo
d;_6o`000004om6j``03o`000?oB^L3od[W000;od[W000Co0000om>h__oC^;ko00000ooD][`2o`00
00Cof;^m00?o0000omNh^_oG^;X00_oG^;X2o`0000?of;Vj00Co0000omNf^?oG][So00001?oG]kT0
0ol0003oe[Jjo`000003o`0000?oe;Fj00?o0000om>c^OoC/kT00_oC/kT00ol0003ock2koln`^`03
oln`^`06o`000?o<[kgoc:nmo`000?o;[K_o00000oo7Zkd00ol0003o`ZS0ol:X`003ol:X`005o`00
0?nlYL;o_:G2okbU`_l000001?neXLD01Ol0003o[Ig7ojfMaon]WLOo000000?oY9S900?o0000oiZB
bonJT//00_nJT//01Ol0003oShg<ohn=c?n?SLco000000?oQHO=00?o0000ogZ1c_mjPLh00_mjPLh0
0ol0003oL7_?o`000002og1kc`04o`000?mVM/ooIWK?ofIfc`;oGG;?00?o0000ob=Nd_l000000_lH
F=001Ol0003o45C?oa1Dcol@E<oo000000;o35?>00Go0000o`]Dd?l;E=3o2eC@o`00000Nooooo`03
o`000?oooooooooo01Gooooo000Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1oooool00ol0003oPY3Hoh:@f002oh:@f003o`000?n6SmKoQXoF00;oQXoF0_l00006ojFYf@03o`00
0?nYZMKoZJWF00?oZJWF00?o0000ojfYdon]ZM<00on]ZM<00ol0003o/JW@ok6Yd002ok6Yd003o`00
0?nfZ/go]Z[=00?o]Z[=00?o0000okV[boniZl/00_niZl/00ol0003o_J_8okf[b002okf[b004o`00
0?o0[<Ko`:c6ol2/aP;o00001?o?_LT01Ol0003od;_6om2ka_o@^lKo000000CodK[300?o0000om:i
`?oB^L000_oB^L001?l0003odkRnom>h__oC^;h4o`000003omBf_?l0003of;^m00?of;^m00Go0000
omNh^_oG^;[oekRjo`000002omNg^003o`000?oH^K[o000000?oekJh00Co0000omNg^OoG]kWoekNi
0ol00002omJd]`06o`000?oE/kOo0000o`000?oD]K[o00000ooC/kT2o`0000Gock2k00?o0000olb_
_Ol000000_o;[K/01Ol0003oaj^molN[_Oo7Zkgo000000Go`ZS000Go0000okbU`_nlYL;o_:G2o`00
0004okFQa@05o`000?n]WLOo[Ig7ojfMaol000000onTV<T00ol0003oVY;;oiZBb`02oiZBb`05o`00
0?n?SLcoShg<ohn=c?l000001?n5Qld01Ol0003oNX7>ogZ1c_mjPLko000000;oL7_?00?o0000og1k
col000000omVM/l3oeebc`;o00000olHF=001?l0003o45C?oa1Dcol00003o`aCcP04o`000?l;E=3o
2eC@o`0001kooooo0_l0000Fooooo`009_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo00Gooooo00?o0000oh:@f?n2T=P00on2T=P00ol0003oQXoFohJ?eP02ohJ?eP;oRY3C0_l00003
ojFYf@03o`000?nYZMKoZJWF00CoZJWF00?o0000ojfYdon]ZM<00_n]ZM<00ol0003o/JW@ok6Yd003
ok6Yd003o`000?nfZ/go]Z[=00?o]Z[=00Go0000okV[boniZl_o^J_;o`000004okf[b003o`000?o0
[<Ko`:c600;o`:c600Ko0000ol>]`ol0003o0000olnmbOl00003om2kaP03o`000?oA^/?odK[300?o
dK[300Go0000om:i`?oB^L3od[W0o`000002om>h_P?o00000ooD][`00ol0003oeKFjo`000002omRk
_@03o`000?oG^;[oekRj00;oekRj00?o0000omNg^?oG]kP00_l00004omNf^006o`000?oG]kWo0000
o`000?oG]KOo00000ooF];L01Ol0003oeK>gomFc]ooE/kOo000000?odk>i00Co0000om:a^?oB/KSo
00001?o?/;/2o`0000?objfk00?o0000olN[_Oo7Zkd00_o7Zkd00ol0003o`ZS0ol:X`002ol:X`005
o`000?nlYL;o_:G2okbU`_l000001?neXLD01Ol0003o[Ig7ojfMaon]WLOo000000?oY9S900?o0000
oiZBbonJT//00_nJT//01Ol0003oShg<ohn=c?n?SLco000000CoQHO=00Go0000ogZ1c_mjPLkoNX7>
o`000002og1kc`03o`000?m`Nloo000000?oIWK?00Go0000oeebcomML/ooGG;?o`000003oaQHd005
o`000?l@E<oo45C?oa1Dcol000000_l<Dlh01Ol0003o2eC@o`]Dd?l;E=3o000001kooooo00?o0000
ooooooooool05?ooool002Kooooo0ol0000dooooo`03o`000?oooooooooo00Cooooo00?o0000oh:@
f?n2T=P00_n2T=P00ol0003oQXoFohJ?eP02ohJ?eP03o`000?n:T=?oRY3C00;oRY3C00?o0000ojFY
fOnUZMT01_nYZMH00ol0003o[JWCojfYd`02ojfYd`03o`000?naZM3o/JW@00?o/JW@00?o0000okJZ
cOnfZ/d00onfZ/d00ol0003o^J_;okV[b`02okV[b`03o`000?nmZlSo_J_800;o_J_800Go0000ol2/
a_o0[<Ko`:c6o`000004ol>]``;o00000oo@^lH00ol0003odK[3om6j``02om6j``03o`000?oB^L3o
d[W000;od[W00ol000000ooC^;ko0000omBf_003omBf_005o`000?oE]K[o0000omRk_Ol000001?oG
^;X01Ol0003oekNhomNg^?oG]kSo000000GoekJh0_l00003omNe]`04o`000?oF];Ooe[Bgo`0000Co
eK>g00Go0000om>c^OoC/kWodk>io`000002om:a^007o`000?o?/;_ock2koln`^ol0003ocjnio`00
0003ol^]^`03o`000?o7Zkgoaj^m00;oaj^m00?o0000ol:X`?o2Z<000_o2Z<001Ol0003o_:G2okbU
`_nlYL;o000000Co]J7500Go0000ojfMaon]WLOo[Ig7o`000003ojBHb@03o`000?nJT/_oVY;;00;o
VY;;00Go0000ohn=c?n?SLcoShg<o`000004ohF7c@05o`000?mjPLkoNX7>ogZ1c_l000000om`Nll2
o`0000?oIWK?00?o0000oeebcomML/l00_mML/l2o`0000;o65S@00Co0000oa1Dcol@E<oo00000ol<
Dlh01?l0003o2eC@o`]Dd?l0000Oooooo`03o`000?oooooooooo01?ooooo000Vooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oPY3Hoh:@f003oh:@f003o`000?n6
SmKoQXoF00;oQXoF00?o0000ohZ@don:T=<00on:T=<2o`0000GoZJWF00?o0000ojfYdon]ZM<00on]
ZM<00ol0003o/JW@ok6Yd002ok6Yd003o`000?nfZ/go]Z[=00?o]Z[=00?o0000okV[boniZl/00_ni
Zl/00ol0003o_J_8okf[b002okf[b003o`000?o0[<Ko`:c600;o`:c600?o0000ol>]`oo3[L<00_o3
[L<01Ol0003oaZg1o`000?o@^lKo000000CodK[300?o0000om:i`?oB^L000ol00003om>h_P03o`00
0?oD][coe;Jl00;oe;Jl00Go0000omFe^_oE]K[oeKFjo`000004omNh^P03o`000?oG]kSoekNh00;o
ekNh00?o0000omNf^?oG][P00ooG][P01Ol0003oekFgomNe]ooG]KOo000000?oe[Bg00Wo0000omFc
]ooE/kOoeK>go`000?oD/[Oo0000om>c^Ol000000ooB/KP01?l0003ock2koln`^ol00002oln_^@03
o`000?o;[K_objfk00;objfk00Go0000olN[_Oo7Zkgoaj^mo`000004ol:X`005o`000?nlYL;o_:G2
okbU`_l000000_neXLD9o`000003ojBHbOl0003oVY;;00?oVY;;00Go0000ohn=c?n?SLcoShg<o`00
0004ohF7c@03o`000?mjPLkoNX7>00;oNX7>00Go0000og1kcom`NlooL7_?o`000003ofIfc`03o`00
0?mML/ooGG;?00;oGG;?0_mFKm03o`0000;o45C?00Go0000o`aCc_l<Dlko35?>o`000002o`]Dd003
o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool001_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00001On2T=P00ol0
003oQXoFohJ?eP02ohJ?eP03o`000?n:T=?oRY3C00CoRY3C0_n@TM001Ol0003oZJWFojVYe_nYZMKo
000000Go[JWC00?o0000ok6Yd?naZM000onaZM000ol0003o]Z[=okJZc@02okJZc@03o`000?niZl_o
^J_;00;o^J_;00?o0000okf[b?nmZlP00onmZlP01Ol0003o`:c6ol2/a_o0[<Ko000000Co`jg300Co
0000olJ]`Oo6[L7oaZg10_l00004om6j``?o000000?od[W0o`000?oC^;h00_oC^;h00ol0003oe;Jl
omBf_002omBf_003o`000?oE]K[oeKFj00;oeKFj00Go0000omNh^_oG^;[oekRjo`000004omNg^0;o
00001?oG][P2o`0000?oekFg00Go0000omJd]ooF];Ooe[Bgo`000003omFc]`04o`000?oD/[Ooe;:g
o`0000God[6h0_l00003oln_^@03o`000?o;[K_objfk00;objfk00Go0000olN[_Oo7Zkgoaj^mo`00
0004ol:X`003o`000?nlYL;o000000Co00000_nkX[l01Ol0003o]Ik1okFN`OneW/7o000000;o[i_2
1Ol000000onJT/_o0000ohn=c002ohn=c003o`000?n5QlgoQHO=00;oQHO=00?o0000ogZ1c_mjPLh0
0_mjPLh01?l0003oL7_?og1kcom`Nll2o`0000;oIWK?00?o0000oeebcomML/l00_mML/l4oeI_d005
o`000?l@E<oo45C?oa1Dcol000000ol<Dlh01?l0003o2eC@o`]Dd?l0000Oooooo`03o`000?oooooo
oooo01;ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0h
ooooo`?o00001On2T=P00ol0003oQXoFohJ?eP02ohJ?eP03o`000?n:T=?oRY3C00?oRY3C00Oo0000
oi2Ad?n@TM3oT97@o`000?nYZMKo000000Go[JWC00?o0000ok6Yd?naZM000onaZM000ol0003o]Z[=
okJZc@03okJZc@03o`000?niZl_o^J_;00;o^J_;00?o0000okf[b?nmZlP00_nmZlP00ol0003o`:c6
ol2/aP02ol2/aP03o`000?o3[L?o`jg300;o`jg300Ko0000olJ]`Oo6[L7oaZg1o`000?o9[[l4o`00
00Cod[W000Go0000om>h__oC^;kodkRno`000004omBf_007o`000?oE]K[oeKFjomFe^_l0003oeKBi
o`000002omNh^P07o`000?oG]kSoekNhomNg^?l0003oekFgo`000003omNf^003o`000?oG];Ko0000
00?oekFg00Go0000omJd]ooF];Ooe[Bgo`000002omFc]`05o`000?oD/[Ooe;:gomBb]ol000001OoB
/KP00ol0003ocjnioln_^@02oln_^@03o`000?o;[K_objfk00;objfk00Go0000olN[_Oo7Zkgoaj^m
o`000002ol:X`0Co00000_o0YKh00ol0003o^j:ook^R_`02ok^R_`05o`000?neW/7o]Ik1okFN`Ol0
00000on_Vl801?l0003oZ9O4ojRGa?nXUl@4o`000003ohn=c?l0003oQHO=00?oQHO=00?o0000ogZ1
c_mjPLh00_mjPLh01?l0003oL7_?og1kcom`Nll2o`0000;oIWK?00?o0000oeebcomML/l00_mML/l0
0ol0003oEVo@oeI_d002oeI_d0;o000000?o45C?o`000?l<Dlh00_l<Dlh01?l0003o2eC@o`]Dd?l0
000Pooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`006oooool0
1Ol@413ooooooooooooooooo410@00Gooooo0ol0000iooooo`03o`000?n2T=SoPY3H00?oPY3H00?o
0000ohJ?e_n6SmH00_n6SmH00ol0003oRY3CohZ@d`04ohZ@d`03o`000?n@TM3oT97@00;oT97@0_l0
0004ojfYd`03o`000?naZM3o/JW@00?o/JW@00?o0000okJZcOnfZ/d00onfZ/d00ol0003o^J_;okV[
b`02okV[b`03o`000?nmZlSo_J_800;o_J_800?o0000ol2/a_o0[<H00_o0[<H00ol0003o`jg3ol>]
``02ol>]``04o`000?o6[L7oaZg1olJ]`@Co000000?obJjoo`000?oB^L000ooB^L001Ol0003odkRn
om>h__oC^;ko000000Coe;Jl00?o0000omFe^_oE]KX00_oE]KX01Ol0003oeKBio`000?oG^;[o0000
00?oekNh00Oo0000omNe]ooG]KOoekFgo`000?oG][So000000;oekBf00Go0000omNe]ooG]KOoekFg
o`000002omJd]`04o`000?oE/kOoeK>go`0000?oe;:g00?o0000omBa]ol000001?oB/KP00ol0003o
cjnioln_^@02oln_^@03o`000?o;[K_objfk00;objfk00?o0000olN[_Oo7Zkd01?l00002olFX_005
o`000?o0YKko`:Fnol2U__l000001?nkX[l01Ol0003o]Ik1okFN`OneW/7o000000?o[i_200?o0000
ojRGa?nXUl@00_nXUl@00ol0003oXY?5oj:Ca@03o`0000?oQHO=00?o0000ogZ1c_mjPLh00_mjPLh0
2Ol0003oL7_?og1kcom`Nloo0000ofIfcol0003oIWK?o`000004oeebc`03o`000?mFKm3oEVo@00;o
EVo@0_m@KM000ol0003o45C?o`000002o`aCcP05o`000?l;E=3o2eC@o`]Dd?l000007_ooool3o`00
00[ooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo03Wooooo00?o0000oh:@f?n2T=P00_n2T=P00ol0003oQXoFohJ?eP03ohJ?
eP03o`000?n:T=?oRY3C00?oRY3C00?o0000oi2Ad?n@TM000on@TM02oiFBcP;o000000?o[JWCo`00
0?naZM001?naZM000ol0003o]Z[=okJZc@03okJZc@03o`000?niZl_o^J_;00?o^J_;00?o0000okf[
b?nmZlP00_nmZlP01Ol0003o`:c6ol2/a_o0[<Ko000000Go`jg300?o0000olJ]`Ol000000_l00004
olV^_`;o00000ooB^L001Ol0003odkRnom>h__oC^;ko000000Coe;Jl00Go0000omFe^_oE]K[oeKFj
o`000003omFd^@03o`000?oG]kSoekNh00;oekNh00Co0000omNe]ooG]KOoekFg0_l00003omNd]P05
o`000?oG]KOoekFgo`000?oF];L01?l000000ooE/kOo0000omBb]`02omBb]`03o`000?oD/KOo0000
00?od[6h0_l00004oln_^@03o`000?o;[K_objfk00;objfk0ol000000oo9Z[_o0000olFX_003olFX
_005o`000?o0YKko`:Fnol2U__l000000onkX[l01Ol0003o]Ik1okFN`OneW/7o000000Co[i_200?o
0000ojRGa?nXUl@00_nXUl@01_l0003oXY?5oj:CaOnRTlGo0000oi^?aPCo00001?mjPLh01Ol0003o
L7_?og1kcom`Nloo000000;oIWK?0_l00004oeebc`03o`000?mFKm3oEVo@00;oEVo@0om@KM02o`00
00?o35?>00Co0000o`]Dd?l;E=3o00008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0h
ooooo`03o`000?n2T=SoPY3H00?oPY3H00?o0000ohJ?e_n6SmH00_n6SmH00ol0003oRY3CohZ@d`04
ohZ@d`03o`000?n@TM3oT97@00;oT97@00?o0000oiFBc_nET/h00_nET/h2o`0000Go/JW@00?o0000
okJZcOnfZ/d00onfZ/d00ol0003o^J_;okV[b`02okV[b`03o`000?nmZlSo_J_800;o_J_800?o0000
ol2/a_o0[<H00_o0[<H00ol0003o`jg3ol>]``02ol>]``?o000000?oaZg1o`000?o9[[l00oo9[[l0
1_l0003objnmol^__Ol0003od[W0o`0000?odkRn00?o0000omBf_?oD][`00_oD][`01Ol0003oeKFj
omFe^_oE]K[o000000CoeKBi00Go0000omNg^?oG]kSoekNho`000004omNe]`03o`000?oG];KoekBf
00;oekBf00?o0000omNe]ol000000_l00002omJc]P03o`000?oF/kKo000000?oe;:g00Co0000omBa
]ooD/KOo00000_oB/KP00ol0003od[2go`000004oln_^@04o`000?o;[K_objfkol^]^`;o00000oo9
Z[/00ol0003oaJRlolFX_002olFX_005o`000?o0YKko`:Fnol2U__l000000onkX[l01Ol0003o]Ik1
okFN`OneW/7o000000Co[i_200?o0000ojRGa?nXUl@00_nXUl@01Ol0003oXY?5oj:CaOnRTlGo0000
00CoVho60_l00003ogZ1cP05o`000?m`NlooL7_?og1kcol000000omVM/l2o`0000?oGG;?00?o0000
oeI_d?mFKm000_mFKm001Ol0003oD6g@oe1]d?m@KM3o000000?o35?>00Go0000o`]Dd?l;E=3o2eC@
o`00000Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Sooooo00?o0000oh:@f?n2T=P0
0_n2T=P00ol0003oQXoFohJ?eP03ohJ?eP03o`000?n:T=?oRY3C00?oRY3C00?o0000oi2Ad?n@TM00
0on@TM000ol0003oUI;>oiFBcP02oiFBcP;oViC<00Go0000ok6Yd?naZM3o/JW@o`000005okJZc@03
o`000?niZl_o^J_;00;o^J_;00?o0000okf[b?nmZlP00onmZlP01Ol0003o`:c6ol2/a_o0[<Ko0000
00;o`jg31?l00003olJ]`@03o`000?o9[[oobJjo00;obJjo00Co0000ol^__Oo;[kgobjnm0_l00002
om>h_P03o`000?oD][coe;Jl00?oe;Jl00Go0000omFe^_oE]K[oeKFjo`000003omFd^@05o`000?oF
];Oo0000omNg^?l000001OoG]KL00ol0003oekBfomNd]P02omNd]P;o000000?oek>eo`000?oF/kH0
1?oF/kH2o`0000;oe;:g00Co0000omBa]ooD/KOoe;6g0_l00002om:`]`03o`000?o?[kWocjni00;o
cjni1?l000000oo=[;Wo0000olVZ^`02olVZ^`03o`000?o5Z;coaJRl00;oaJRl00Co0000ol2U__o0
YKko00001?nkX[l01Ol0003o]Ik1okFN`OneW/7o000000?o[i_200?o0000ojRGa?nXUl@00_nXUl@0
0ol0003oXY?5oj:Ca@02oj:Ca@03o`000?nKSlKoVho600;oVho60_nDRlL2o`000003ogZ1c_l0003o
L7_?00;oL7_?00Co0000ofIfcomVM/ooIWK?0_l00003oeebc`03o`000?mFKm3oEVo@00;oEVo@00?o
0000oe1]d?m@KM000_m@KM02o`0000;o35?>00Co0000o`]Dd?l;E=3o00008?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2o`0003Sooooo00?o0000oh:@f?n2T=P00on2T=P00ol0003oQXoFohJ?eP02ohJ?eP03o`00
0?n:T=?oRY3C00CoRY3C00?o0000oi2Ad?n@TM000_n@TM000ol0003oUI;>oiFBcP02oiFBcP07o`00
0?nKU<coViC<oi^Dc?l0003o/JW@o`000005okJZc@03o`000?niZl_o^J_;00?o^J_;00?o0000okf[
b?nmZlP00_nmZlP00ol0003o`:c6ol2/aP02ol2/aP?o00000_o3[L<01Ol0003oaZg1olJ]`Oo6[L7o
000000CobJjo00?o0000ol^__Oo;[kd00_o;[kd01Ol0003ocJnlo`000?oC^;ko000000Coe;Jl00Go
0000omFe^_oE]K[oeKFjo`000003omFd^@05o`000?oF];Ooe[BgomJd]ol000001OoG]KL2o`0000Co
ekBf00Co0000omNc]OoG/kGo00000_oF/kH00ol0003oe[>fomJc]P02omJb]P03o`000?oD/[Oo0000
00?oe;6g00?o0000om:`]ooB/;L00_oB/;L00ol0003ocjnioln_^@02o`0000CocJbi00Go0000olVZ
^oo9Z[_obJZko`000003olFX_005o`000?o0YKko`:Fnol2U__l000001?nkX[l01Ol0003o]Ik1okFN
`OneW/7o000000?o[i_200?o0000ojRGa?nXUl@00_nXUl@01Ol0003oXY?5oj:CaOnRTlGo000000Go
Vho61?nDRlL2o`0000?oL7_?00?o0000ofIfcomVM/l00_mVM/l01Ol0003oGG;?oeebcomML/oo0000
00CoEVo@00?o0000oe1]d?m@KM000_m@KM02oda/dP?o00000_l;E=000ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool001_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo00?o0000oh:@f?n2T=P00_n2T=P00ol0
003oQXoFohJ?eP03ohJ?eP03o`000?n:T=?oRY3C00?oRY3C00?o0000oi2Ad?n@TM000on@TM000ol0
003oUI;>oiFBcP02oiFBcP03o`000?nKU<coViC<00;oViC<0_l00005okJZc@03o`000?niZl_o^J_;
00;o^J_;00?o0000okf[b?nmZlP00_nmZlP00ol0003o`:c6ol2/aP03o`0000Go`jg300Go0000olJ]
`Oo6[L7oaZg1o`000004olV^_`05o`000?o;[kgobjnmol^__Ol000000oo=[k`2o`0000?oe;Jl00?o
0000omFe^_oE]KX00_oE]KX01Ol0003oeKBiomFd^OoE];Wo000000?oe[Bg00?o0000omNe]ooG]KL0
0_oG]KL00ol0003oekBfo`000003omNd]P;o00000_oG/kD01_l0003oe[>fomJc]_l0003oe[>fo`00
00?oe[:f00?o0000omBa]ooD/KL00_oD/KL00ol0003od[2gom:`]`02om:`]`05o`000?o?[kWo0000
om2^^?l000001?o=[;T01Ol0003obJZkolVZ^oo9Z[_o000000?oaJRl00Go0000ol2U__o0YKko`:Fn
o`000004ok^R_`05o`000?neW/7o]Ik1okFN`Ol000000on_Vl800ol0003oZ9O4ojRGa002ojRGa005
o`000?nRTlGoXY?5oj:CaOl000001?nKSlH00ol0003oU8_7oiB;a`03oiB;a`;o00000_m`Nll00ol0
003oIWK?ofIfc`02ofIfc`;o00000omML/l01Ol0003oEVo@oeI_d?mFKm3o000000CoD6g@1?m<K=80
1Ol0003o2eC@o`]Dd?l;E=3o0000023ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000T
ooooo`03o`000?oooooooooo03Oooooo0_l00004oh:@f003o`000?n6SmKoQXoF00;oQXoF00?o0000
ohZ@don:T=<01?n:T=<00ol0003oT97@oi2Ad002oi2Ad003o`000?nET/koUI;>00?oUI;>00?o0000
oi^Dc?nKU<`00_nKU<`2oj6FbP?o000000?o]Z[=o`000?niZl/01?niZl/00ol0003o_J_8okf[b002
okf[b0?o00000_o0[<H00ol0003o`jg3ol>]``02ol>]``05o`000?o6[L7oaZg1olJ]`Ol000001?o9
[[l00ol0003objnmol^__@02ol^__@06o`000?o=[kcocJnlolf__?l0003ock2j0_l000000ooD][co
0000omFe^P02omFe^P05o`000?oE];WoeKBiomFd^Ol000000ooF];L00ol0003oe[>fo`000003omNe
]`0:o`000?oG];KoekBfo`000?oG];Ko0000omNc]Ol0003oek>eo`0000;oe[>f00Co0000omJc]_oF
/kKo00000ooF/[H01?l0003oe;6gomBa]ooD/KL2o`0000Cod[2g0_l00002om2^^003o`000?o=[;Wo
cJbi00;ocJbi00Go0000olVZ^oo9Z[_obJZko`000003olFX_005o`000?o0YKko`:Fnol2U__l00000
0onkX[l00ol0003o]Ik1okFN`@02okFN`@05o`000?n_Vl;o[i_2ojnK`_l000001?nXUl@01Ol0003o
XY?5oj:CaOnRTlGo000000CoVho600?o0000oiB;aonDRlL00onDRlL2ohf8b0?o00001?mVM/l00ol0
003oGG;?o`000002oeebc`05o`000?mFKm3oEVo@oeI_d?l000001?m@KM000ol0003oC6cBoda/dP02
oda/dP;o000000?o2eC@o`000?ooool07_ooool00ol0003oooooo`000005ooooo`03oeEEEOmVIVKo
000000Oooooo000Tooooo`03o`000?oooooooooo03Oooooo0_mDLmD01?l0003oPY3Hoh:@f?l00005
ohJ?eP03o`000?n:T=?oRY3C00?oRY3C00?o0000oi2Ad?n@TM000on@TM000ol0003oUI;>oiFBcP02
oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQU/X00onQU/X2o`0000Co^J_;00Co0000
okf[b?nmZlSo_J_80_l00004ol2/aP03o`000?o3[L?o`jg300?o`jg300Go0000olJ]`Oo6[L7oaZg1
o`000004olV^_`05o`000?o;[kgobjnmol^__Ol000000oo=[k`00ol0003ock2joln`^P02oln`^P;o
00000_oE]KX00ol0003oeKBiomFd^@02omFd^@05o`000?oF];Ooe[BgomJd]ol000000_oF/kH00ol0
003oekFgo`000003omNd]P;o00000_oG/kD00ol0003oek>eo`000002omJc]P03o`000?oF/kKo0000
00?oe[:f0_l00002omBa]`03o`000?oD/KKo000000?od[2g0_l00003om2^^003o`000?o=[;WocJbi
00;ocJbi00Go0000olVZ^oo9Z[_obJZko`000003olFX_005o`000?o0YKko`:Fnol2U__l000000onk
X[l01Ol0003o]Ik1okFN`OneW/7o000000Co[i_200?o0000ojRGa?nXUl@00_nXUl@01Ol0003oXY?5
oj:CaOnRTlGo000000CoVho600?o0000oiB;aonDRlL00onDRlL4ohf8b0;o00000omVM/l00ol0003o
GG;?o`000002oeebc`05o`000?mFKm3oEVo@oeI_d?l000001?m@KM000ol0003oC6cBoda/dP02oda/
dP;oBFgC00?o0000o`]Dd?l000008Oooool00ol0003oooooooooo`0<ooooo`009?ooool2o`0003So
oooo0omDLmD00ol0003oPY3Ho`000004ohJ?eP03o`000?n:T=?oRY3C00CoRY3C00?o0000oi2Ad?n@
TM000_n@TM000ol0003oUI;>oiFBcP03oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQ
U/X00onQU/X2ojJIb005o`000?niZl_o^J_;o`000?nmZlP00ol000000onmZlSo0000ol2/aP03ol2/
aP03o`000?o3[L?o`jg300;o`jg300Go0000olJ]`Oo6[L7oaZg1o`000004olV^_`03o`000?o;[kgo
bjnm00;objnm00Go0000olf__?o=[kcocJnlo`000004oln`^P05o`000?oA/;Wo0000omFe^_l00000
0ooE];T00ol0003oe[BgomJd]`02omJd]`05o`000?oF/kKoe[>fomJc]_l000001?oG];H01ol0003o
ek>eomNc]OoG/kGo0000omNc]Ol000000_oF/kH00ol0003oe[>fo`000002omJb]P03o`000?oE/[Go
eK:e00;o00000ooD/KH01Ol0003od[2go`000?oB/;Oo000000?od:jh00?o0000olf/^Oo=[;T00_o=
[;T01?l0003obJZkolVZ^ol00004olFX_005o`000?o0YKko`:Fnol2U__l000000onkX[l01Ol0003o
]Ik1okFN`OneW/7o000000Co[i_200?o0000ojRGa?nXUl@00_nXUl@01Ol0003oXY?5oj:CaOnRTlGo
000000CoVho600?o0000oiB;aonDRlL00_nDRlL00ol0003oSHS8ohf8b002ohf8b0;oQhG90_l00000
1omVM/oo0000oeebcomML/oo0000oeebcol000000omFKm000ol0003oD6g@oe1]d002oe1]d003o`00
0?m<K=;oC6cB00;oC6cB0om9KM<2o`00023ooooo0ol0000=ooooo`009?ooool00ol0003ooooooooo
o`0gooooo`CoE7?E0_l00004ohJ?eP03o`000?n:T=?oRY3C00CoRY3C00?o0000oi2Ad?n@TM000_n@
TM000ol0003oUI;>oiFBcP02oiFBcP03o`000?nKU<coViC<00?oViC<00?o0000oj6Fb_nQU/X00_nQ
U/X01?l0003oYYW8ojJIb?nVVLP4o`0000?o_J_800?o0000ol2/a_o0[<H00_o0[<H00ol0003o`jg3
ol>]``03ol>]``05o`000?o6[L7oaZg1olJ]`Ol000001?o9[[l01Ol0003objnmol^__Oo;[kgo0000
00?ocJnl00?o0000oln`^_o?/;X00_o?/;X01?l0003odK2iom6`^OoA/;T2o`0000;oeKBi00?o0000
omJd]ooF];L00_oF];L00ol0003oe[>fomJc]P02omJc]P03o`000?oG];KoekBf00;oekBf00Ko0000
omNc]OoG/kGoek>eo`000?oG/kD4o`000005omJc]_l0003oe[:fomJb]_l000000_oE/[D00ol0003o
e;6fomBa]P02omBa]P;o00000_oB/;L01Ol0003od:jhom2^^?o@[[So000000?ocJbi00Go0000olVZ
^oo9Z[_obJZko`000004olFX_005o`000?o0YKko`:Fnol2U__l000000onkX[l01Ol0003o]Ik1okFN
`OneW/7o000000Co[i_200Go0000ojRGa?nXUlCoZ9O4o`000004oj:Ca@03o`000?nKSlKoVho600;o
Vho600?o0000oiB;aonDRlL00_nDRlL00ol0003oSHS8ohf8b002ohf8b0CoQhG90_l00003oeebc`;o
00001?mFKm001Ol0003oD6g@oe1]d?m@KM3o000000CoC6cB00Go0000odU]dom9KM?oBFgCo`00000M
ooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0goooo
o`CoE7?E0_mILm801?l0003oQXoFohJ?e_l00006ohZ@d`03o`000?n@TM3oT97@00;oT97@00?o0000
oiFBc_nET/h00onET/h00ol0003oViC<oi^Dc002oi^Dc003o`000?nQU/[oXIK:00?oXIK:00?o0000
ojJIb?l000001?l00003okf[b003o`000?o0[<Ko`:c600;o`:c600?o0000ol>]`oo3[L<00oo3[L<0
0ol0003oaZg1olJ]`@02olJ]`@05o`000?o9[[oobJjoolV^_ol000001?o;[kd01Ol0003ocJnlolf_
_?o=[kco000000Cock2j00Wo0000om6`^OoA/;WodK2io`000?oB/KSo0000omFd^Ol000001?oF];L0
1ol0003oe[>fomJc]_oF/kKo0000omJc]Ol000000_oG];H2o`0000?oek>e0ol000000ooG/[Co0000
omJb]002o`000004omJb]_l0003oeK:eomFb]@;o00001?oD/KH01Ol0003od[2gom:`]ooB/;Oo0000
00;od:jh00?o0000olf/^Oo=[;T00_o=[;T01Ol0003obJZkolVZ^oo9Z[_o000000CoaJRl00Go0000
ol2U__o0YKko`:Fno`000003ok^R_`05o`000?neW/7o]Ik1okFN`Ol000001?n_Vl801Ol0003oZ9O4
ojRGa?nXUlCo000000?oXY?500?o0000oi^?a_nKSlH00_nKSlH00ol0003oU8_7oiB;a`03oiB;a`05
o`000?n=R<SoSHS8ohf8b?l000001On7QLT2o`0000?oGG;?00?o0000oeI_d?mFKm000_mFKm001Ol0
003oD6g@oe1]d?m@KM3o000000CoC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003oooooooooo`0G
ooooo`?o00001Oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0foooo
o`03o`000?mDLmGoE7?E00;oE7?E0omILm800ol0003oQXoFo`000006ohZ@d`03o`000?n@TM3oT97@
00;oT97@00?o0000oiFBc_nET/h00onET/h00ol0003oViC<oi^Dc002oi^Dc003o`000?nQU/[oXIK:
00;oXIK:0ol00003ojJIb006o`000?n/VlKo0000o`000?nmZlSo00001?o0[<H00ol0003o`jg3ol>]
``03ol>]``05o`000?o6[L7oaZg1olJ]`Ol000001?o9[[l01Ol0003objnmol^__Oo;[kgo000000Co
cJnl00Go0000oln`^_o?/;[ock2jo`000003om6`^@04o`000?oB/KSod[6hom:a^0;o00000ooF];L0
0ol0003oe[>fomJc]P02omJc]P05o`000?oF/kGo0000omNd]_l000000_oG/kD03?l0003oek>eo`00
0?l0003oek:do`000?oG/[Co0000omJb]?l0003oe[:do`0000;oeK:e00?o0000omFa]Ol000000_oD
/KH00ol0003oe;6fo`000003om:`]`04o`000?o@[[Sod:jho`0000CocJbi00Go0000olVZ^oo9Z[_o
bJZko`000003olFX_005o`000?o0YKko`:Fnol2U__l000001?nkX[l01Ol0003o]Ik1okFN`OneW/7o
000000Co[i_200Go0000ojRGa?nXUlCoZ9O4o`000003oj:Ca@03o`000?nKSlKoVho600;oVho600?o
0000oiB;aonDRlL00onDRlL01Ol0003oSHS8ohf8b?n=R<So000000GoQhG90_n1P//2o`000003oeeb
col0003oEVo@00?oEVo@00Go0000oe1]d?m@KM3oD6g@o`000004oda/dP03o`000?m9KM?oBFgC00;o
BFgC00?o0000ooooooooool04oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo
0ol0000gooooo`03o`000?mDLmGoE7?E00;oE7?E1?mILm82o`0000GoRY3C00?o0000oi2Ad?n@TM00
0on@TM000ol0003oUI;>oiFBcP02oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQU/X0
1?l00004ojJIb003o`000?n/VlKo[9_600;o[9_60_l00003ol2/aP03o`000?o3[L?o`jg300?o`jg3
00?o0000olJ]`Oo6[L400_o6[L400ol0003obJjoolV^_`02olV^_`05o`000?o;[kgobjnmol^__Ol0
00000oo=[k`00ol0003ock2joln`^P02oln`^P05o`000?oA/;WodK2iom6`^Ol000000ooB/KP00ol0
003odk6go`000002omJd]`05o`000?oF/kKoe[>fomJc]_l000000_oF/kD00ol0003oekBfo`000002
omNc]@;o000000?oek:do`000?oG/[@00_l00004omJb]003o`000?oE/[Go000000;oeK6e00?o0000
omBa]_l000000_oD/KH01?l0003od[2gom:`]ol00003om2^^003o`000?o=[;WocJbi00;ocJbi00Go
0000olVZ^oo9Z[_obJZko`000003olFX_005o`000?o0YKko`:Fnol2U__l000000onkX[l00ol0003o
]Ik1okFN`@02okFN`@05o`000?n_Vl;o[i_2ojnK`_l000001?nXUl@01Ol0003oXY?5oj:CaOnRTlGo
000000CoVho600?o0000oiB;aonDRlL00onDRlL01Ol0003oSHS8ohf8b?n=R<So000000GoQhG91?n1
P//3o`0000?oEVo@00Go0000oe1]d?m@KM3oD6g@o`000004oda/dP03o`000?m9KM?oBFgC00;oBFgC
00?o0000ooooooooool04?ooool3o`0000gooooo00?o0000ooooooooool02_ooool002?ooooo00?o
0000ooooooooool0=oooool00ol0003oE7?EoeAce@02oeAce@04o`000?mILm;oFG?BoeUcdP;oGgCA
00?o0000ohZ@don:T=<00_n:T=<00ol0003oT97@oi2Ad002oi2Ad003o`000?nET/koUI;>00?oUI;>
00?o0000oi^Dc?nKU<`00_nKU<`3o`0000?oXIK:00?o0000ojJIb?nVVLP00_nVVLP00ol0003o[9_6
ojbKaP02ojbKaP06o`000?naW/Co0000o`000?o0[<Ko00001Oo3[L<01Ol0003oaZg1olJ]`Oo6[L7o
000000CobJjo00?o0000ol^__Oo;[kd00_o;[kd01Ol0003ocJnlolf__?o=[kco000000?ock2j00?o
0000om6`^OoA/;T00_oA/;T01?l0003od[6hom:a^?l00003om>a]`03o`000?oF];Oo000000?oe[>f
00Go0000omJc]OoF/kGoe[>eo`000003omNc]@05o`000?oG/[Coek:do`000?oG/[@00_l000001?oF
/[Co0000omJb]?oF/[@2o`0000?oeK6e0_l00003omBa]P04o`000?oB/;Ood[2go`0000?od:jh00?o
0000olf/^Oo=[;T00_o=[;T01Ol0003obJZkolVZ^oo9Z[_o000000?oaJRl00Go0000ol2U__o0YKko
`:Fno`000003ok^R_`05o`000?neW/7o]Ik1okFN`Ol000001?n_Vl800ol0003oZ9O4ojRGa002ojRG
a005o`000?nRTlGoXY?5oj:CaOl000001?nKSlH00ol0003oU8_7oiB;a`02oiB;a`03o`000?n=R<So
SHS800;oSHS800?o0000ohN5bOn7QLT00_n7QLT00ol0003oPH;;oh62b`03oh62b`?o00000_mFKm00
1Ol0003oD6g@oe1]d?m@KM3o000000CoC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003ooooooooo
o`0=ooooo`?o00004?ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0g
ooooo`05o`000?mDLmGoE7?EoeAceOl000001?mILm83oemdd@04o`000?n:T=?oRY3Co`0000GoT97@
00?o0000oiFBc_nET/h00_nET/h00ol0003oViC<oi^Dc004o`0000CoXIK:00?o0000ojJIb?nVVLP0
0onVVLP01Ol0003o[9_6ojbKa_n/VlKo000000Co/Ik40_l00004ol>]``03o`000?o6[L7oaZg100;o
aZg100?o0000olV^_oo9[[l00_o9[[l01Ol0003objnmol^__Oo;[kgo000000?ocJnl00?o0000oln`
^_o?/;X00_o?/;X01Ol0003odK2iom6`^OoA/;Wo000000?od[6h00?o0000om>a]ooC/KL00_oC/KL2
o`0000;oe[>f00?o0000omJc]OoF/kD00_oF/kD01Ol0003oek>eomNc]OoG/kGo000000;oek:d0_l0
00000ooG/[Co0000omJb]002omJb]0;o00001?oE/KD00ol0003oe;6fomBa]P02omBa]P04o`000?oB
/;Ood[2go`0000?od:jh00?o0000olf/^Oo=[;T05Ol000000oneW/7o0000ojnK`P03ojnK`P03o`00
0?nXUlCoZ9O400;oZ9O400Go0000oj:CaOnRTlGoXY?5o`000004oi^?aP03o`000?nDRlOoU8_700;o
U8_700?o0000ohf8b?n=R<P00_n=R<P00ol0003oQhG9ohN5b@02ohN5b@03o`000?n1P/_oPH;;00?o
PH;;0_mlP<`2o`000003oeI_d?l0003oD6g@00;oD6g@00?o0000oda/d_m<K=800_m<K=800ol0003o
BFgCodU]d`02odU]d`03o`000?oooooooooo00Wooooo1?l0000Cooooo`03o`000?oooooooooo00[o
oooo000Sooooo`03o`000?oooooooooo03Oooooo00Go0000oeAceOmDLmGoE7?Eo`000004oeUcdPCo
GgCA00?o0000ohZ@dol000001?n@TM000ol0003oUI;>oiFBcP03oiFBcP?o00000_nKU<`00ol0003o
XIK:oj6FbP03oj6FbP03o`000?nVVLSoYYW800;oYYW800?o0000ojbKa_n/VlH00_n/VlH00ol0003o
/Ik4ok6Na002ok6Na003o`000?nfX<;o000000;o000000?o`jg3o`000?o6[L400_o6[L400ol0003o
bJjoolV^_`02olV^_`03o`000?o;[kgobjnm00;objnm00Go0000olf__?o=[kcocJnlo`000003oln`
^P03o`000?oA/;WodK2i00;odK2i00Go0000om:a^?oB/KSod[6ho`000004om>a]`05o`000?oD/KKo
0000omJc]_l000000ooF/kD01?l0003oe[:do`000?oG/kD2o`0000;oek:d0_l000001ooG/[Co0000
o`000?oF/[Co0000omJb]?l000000_oE/KD00ol0003oeK6eo`000003omBa]P06o`000?oB/;Ood[2g
om:`]ol0003od:jh1Ol00002oln^^005o`000?o=[;WocJbiolf/^Ol000000oo9ZkX01Ol0003oaZRl
olJX_?o6Z;co000000?o`jJm00?o0000oknT__noY;h01Ol000000on_Vl;o0000ojRGa002ojRGa003
o`000?nRTlGoXY?500;oXY?500Go0000oi^?a_nKSlKoVho6o`000005oiB;a`05o`000?n=R<SoSHS8
ohf8b?l000001On7QLT00ol0003oPH;;oh62b`02oh62b`07o`000?mlP<coO83<ogb0c?l0003oEVo@
o`000003oe1]d003o`000?m<K=;oC6cB00;oC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003ooooo
ooooo`06ooooo`?o00005oooool00ol0003oooooooooo`0:ooooo`008oooool3o`0003Oooooo00Go
0000oeAceOmDLmGoE7?Eo`000004oeUcdPGoGgCA0_l00004oi2Ad003o`000?nET/koUI;>00Co0000
1?nKU<`00ol0003oXIK:oj6FbP03oj6FbP03o`000?nVVLSoYYW800;oYYW800?o0000ojbKa_n/VlH0
0_n/VlH00ol0003o/Ik4ok6Na002ok6Na003o`000?nfX<;o]Z3200;o]Z320ol00002olJ]`@03o`00
0?o9[[oobJjo00;obJjo00Go0000ol^__Oo;[kgobjnmo`000003olf__003o`000?o?/;[ock2j00;o
ck2j00?o0000om6`^OoA/;T00_oA/;T01?l0003od[6hom:a^?l00004om>a]`04o`000?oD/KKoe;6f
omBa]P;o00000_oF/kD01Ol0003oe[:domJb]?l0003oek>e00;o00000_oG/[@3o`000006omJb]?l0
003o0000omJb]?l0003oe[:d0_l00002omFa]@05o`000?oD/KKoe;6fomBa]_l000000_oB/;L3o`00
00;odJng00?o0000oln^^?o?[[P00_o?[[P01Ol0003ocJbiolf/^Oo=[;Wo000000?obJ^j00Go0000
olJX_?o6Z;coaZRlo`000003ol>V_@05o`000?noY;ko_jBnoknT__l000000onjX/04o`000003ojRG
a?l0003oXY?500?oXY?500Go0000oi^?a_nKSlKoVho6o`000005oiB;a`05o`000?n=R<SoSHS8ohf8
b?l000001?n7QLT00ol0003oPH;;oh62b`03oh62b`03o`000?mlP<coO83<00;oO83<0_l00003oe1]
d003o`000?m<K=;oC6cB00;oC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003oooooooooo`03oooo
o`?o00006_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`05
o`000?mDLmGoE7?EoeAceOl000001?mILm800ol0003oGgCAoemdd@02oemdd@;oIgO?00?o0000oi2A
d?n@TM001?l00002oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQU/X00onQU/X00ol0
003oYYW8ojJIb002ojJIb003o`000?n/VlKo[9_600;o[9_600?o0000ok6Na?naW/@00_naW/@00ol0
003o]Z32okJP`P03okJP`P03o`000?nkXl7o^j?100?o00000oo9[[l00ol0003objnmol^__@02ol^_
_@05o`000?o=[kcocJnlolf__?l000001?o?/;X01Ol0003odK2iom6`^OoA/;Wo000000?od[6h00?o
0000om>a]ooC/KL00_oC/KL02Ol0003oe;6fomBa]_oD/KKo0000omFb]Ol0003oe[>eo`000003omJb
]005o`000?oG/[Coek:do`000?oG/[@01?l000000ooF/[Co0000o`000002omJb]005o`000?oE/KGo
eK6eomFa]Ol000000ooD/KH3o`000003om>`]_l0003odJng00;odJng00Go0000oln^^?o?[[Socjjh
o`000003olf/^@05o`000?o9Zk[obJ^jolV[^_l000000oo6Z;`01Ol0003o`jJmol>V_Oo3Y[go0000
00Co_jBn00?o0000okZR`?njX/000_njX/000ol0003o]Yo1okJO`@03o`0000;oXY?500?o0000oi^?
a_nKSlH00_nKSlH00ol0003oU8_7oiB;a`02oiB;a`03o`000?n=R<SoSHS800;oSHS800?o0000ohN5
bOn7QLT00_n7QLT00ol0003oPH;;oh62b`03oh62b`03o`000?mlP<coO83<00?oO83<0_l00002oe1]
d003o`000?m<K=;oC6cB00;oC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003oooooooooo`03o`00
01gooooo00?o0000ooooooooool02_ooool00005onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0h
ooooo`05o`000?mDLmGoE7?EoeAceOl000001?mILm800ol0003oGgCAoemdd@02oemdd@?oIgO?0ol0
0005oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQU/X00onQU/X00ol0003oYYW8ojJI
b002ojJIb003o`000?n/VlKo[9_600;o[9_600?o0000ok6Na?naW/@00_naW/@00ol0003o]Z32okJP
`P02okJP`P03o`000?nkXl7o^j?100;o^j?100Ko0000oknU_ol0003o0000olV^_ol00003ol^__@03
o`000?o=[kcocJnl00;ocJnl00Go0000oln`^_o?/;[ock2jo`000004om6`^@05o`000?oB/KSod[6h
om:a^?l000001?oC/KL01?l0003oe;6fomBa]_l00003omFb]@03o`000?oF/[Coe[:d00;oe[:d00?o
0000omNb]?oG/[@01ol000001OoF/[Co0000omJb]?oF/[Co000000?oeK6e00?o0000omBa]_oD/KH0
0_l00003om>`]P04o`000?oA[kOodJngo`0000Cocjjh00Go0000olf/^Oo=[;WocJbio`000003olV[
^P05o`000?o6Z;coaZRlolJX_?l000000oo3Y[d01Ol0003o_jBnoknT__noY;ko000000Co^Z;000?o
0000okJO`OnfWl400_nfWl400ol0003o/Ig3o`000002o`0000CoVho600?o0000oiB;aonDRlL00_nD
RlL00ol0003oSHS8ohf8b002ohf8b003o`000?n7QLWoQhG900;oQhG900?o0000oh62bon1P//00_n1
P//00ol0003oO83<ogb0c004ogb0c005o`000?mhOlko0000oe1]d?l000001?m<K=800ol0003oBFgC
odU]d`02odU]d`?o00008?ooool00ol0003oooooooooo`0:ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0hooooo`05o`000?mDLmGoE7?EoeAceOl000001?mILm800ol0
003oGgCAoemdd@02oemdd@?o000000?oIgO?o`000?l000001?nET/h00ol0003oViC<oi^Dc003oi^D
c003o`000?nQU/[oXIK:00;oXIK:00?o0000ojJIb?nVVLP00onVVLP00ol0003o[9_6ojbKaP02ojbK
aP03o`000?naW/Co/Ik400;o/Ik400?o0000okJP`_nfX<800_nfX<800ol0003o^j?1ok^S`@02ok^S
`@04o`000?noYKoo_jFooknU_`?o00000_o;[kd01Ol0003ocJnlolf__?o=[kco000000Cock2j00?o
0000om6`^OoA/;T00_oA/;T01?l0003od[6hom:a^?l00004om>a]`05o`000?oD/KKoe;6fomBa]_l0
00000ooE/[D2o`0000;oe[:d00Ko0000omNb]?l0003oek:do`000?oG/[@3o`000004omNb]?l0003o
0000o`0000;oe[:d00Co0000omFa]OoE/KGoeK6e0ol000001OoD/KGo0000om>`]_oC/;Ko000000?o
dJng00?o0000oln^^?o?[[P00_o?[[P01Ol0003ocJbiolf/^Oo=[;Wo000000?obJ^j00Go0000olJX
_?o6Z;coaZRlo`000003ol>V_@05o`000?noY;ko_jBnoknT__l000001?njX/001Ol0003o]Yo1okJO
`OnfWl7o000000Co/Ig30_l00003oi^?aP03o`000?nDRlOoU8_700;oU8_700?o0000ohf8b?n=R<P0
0_n=R<P00ol0003oQhG9ohN5b@02ohN5b@03o`000?n1P/_oPH;;00;oPH;;00?o0000ogb0c?mlP<`0
0omlP<`01?l0003oN7o>o`000?mhOlh2o`0000CoC6cB00?o0000odU]dom9KM<00_m9KM<00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000>?ooool00ol0003o
E7?EoeAce@02oeAce@03o`000?mILm;oFG?B00;oFG?B00?o0000oemddOmOM=400_l00004ofMgc`;o
L7_>0_l00002oiFBcP03o`000?nKU<coViC<00;oViC<00?o0000oj6Fb_nQU/X00onQU/X00ol0003o
YYW8ojJIb002ojJIb003o`000?n/VlKo[9_600;o[9_600?o0000ok6Na?naW/@00_naW/@00ol0003o
]Z32okJP`P03okJP`P05o`000?nkXl7o^j?1ok^S`Ol000001?noYKl00ol0003o`jNmol>W_@04o`00
00;ocJnl00Go0000oln`^_o?/;[ock2jo`000004om6`^@05o`000?oB/KSod[6hom:a^?l000001?oC
/KL01Ol0003oe;6fomBa]_oD/KKo000000?oeK:e00[o0000omJb]?l0003oe[:do`000?oG/[Co0000
omNb]?l0003oek:d1_l00002omJb]003o`000?oE/KGoeK6e00?o00000ooD/KD01?l0003odk2fom>`
]_l00003om6_]`05o`000?o?[[Socjjholn^^?l000000oo=[;T00ol0003obJ^jolV[^P02olV[^P04
o`000?o6Z;coaZRlo`0000?o`jJm00?o0000oknT__noY;h00_noY;h00ol0003o^Z;0okZR`002okZR
`005o`000?nfWl7o]Yo1okJO`Ol000001?naWL<00ol0003o[I[4o`000002o`0000GoU8_700Go0000
ohf8b?n=R<SoSHS8o`000004ohN5b@03o`000?n1P/_oPH;;00?oPH;;00?o0000ogb0c?mlP<`00oml
P<`01Ol0003oN7o>ogQoc_l0003oN7o>00;o00000om<K=800ol0003oBFgCodU]d`02odU]d`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
=oooool00ol0003oE7?EoeAce@02oeAce@03o`000?mILm;oFG?B00;oFG?B0ol000000omOM=7o0000
ofMgc`03ofMgc`CoL7_>00?o0000oiFBc_l000001?nKU<`00ol0003oXIK:oj6FbP03oj6FbP03o`00
0?nVVLSoYYW800;oYYW800?o0000ojbKa_n/VlH00_n/VlH00ol0003o/Ik4ok6Na002ok6Na003o`00
0?nfX<;o]Z3200;o]Z3200?o0000ok^S`OnkXl400_nkXl400ol0003o_jFooknU_`02oknU_`05o`00
0?o3Ykgo`jNmol>W_Ol000000_o7ZK`4o`0000;ock2j00?o0000om6`^OoA/;T00_oA/;T01Ol0003o
d[6hom:a^?oB/KSo000000?odk6g00Go0000omBa]_oD/KKoe;6fo`000003omFb]@04o`000?oF/[Co
e[:domJb]0;o00000_oG/[@00ol0003oek:do`000005o`0000?oe[:d0ol00002omJa]004o`000?oD
/KGoe;6eo`0000?odk2f00Go0000om6_]ooA[kOodJngo`000003oln^^005o`000?o=[;WocJbiolf/
^Ol000000oo9ZkX01Ol0003oaZRlolJX_?o6Z;co000000?o`jJm00Go0000oknT__noY;ko_jBno`00
0004okZR`003o`000?nfWl7o]Yo100;o]Yo100Go0000ok6M`onaWL?o/Ig3o`000004ojfJa0;o0000
1?nDRlL01Ol0003oSHS8ohf8b?n=R<So000000CoQhG900?o0000oh62bon1P//00_n1P//00ol0003o
O83<ogb0c004ogb0c005o`000?mhOlkoN7o>ogQoc_l000000_mdOm001?l0003oC6cBoda/d_l00004
odU]d`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0gooooo`03o`000?mDLmGoE7?E00;oE7?E00?o0000oeUcd_l000000_l0
0004oemdd@03o`000?mWMlooIgO?00;oIgO?1Om`Nlh2o`0000?oViC<00?o0000oj6Fb_nQU/X00onQ
U/X00ol0003oYYW8ojJIb002ojJIb003o`000?n/VlKo[9_600?o[9_600?o0000ok6Na?naW/@00_na
W/@00ol0003o]Z32okJP`P02okJP`P03o`000?nkXl7o^j?100;o^j?100Go0000oknU_onoYKoo_jFo
o`000004ol>W_@05o`000?o7ZKcoajVlolNY_?l000000_o:ZkX5o`0000;odK2i00Co0000om:a^?oB
/KSo00001?oC/KL01Ol0003oe;6fomBa]_oD/KKo000000?oeK:e00[o0000omJb]?oF/[Coe[:do`00
0?oF/[Co0000omNb]?l0003oek:d2?l000000ooF/[Co0000omJa]002omJa]005o`000?oD/KGoe;6e
omBa]Ol000000ooC/;H01?l0003odJngom6_]ol00004oln^^005o`000?o=[;WocJbiolf/^Ol00000
0oo9ZkX01Ol0003oaZRlolJX_?o6Z;co000000?o`jJm00Go0000oknT__noY;ko_jBno`000004okZR
`005o`000?nfWl7o]Yo1okJO`Ol000001?naWL<00ol0003o[I[4ojfJa002ojfJa003o`000?nXV<Ko
000000?o00001?n=R<P00ol0003oQhG9ohN5b@02ohN5b@03o`000?n1P/_oPH;;00;oPH;;00?o0000
ogb0c?mlP<`00omlP<`00ol0003oN7o>ogQocP02ogQocP07o`000?mdOm3oM7o@ogAod?l0003oC6cB
o`000004odU]d`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0=oooool01?l0003oE7?EoeAceOmDLmD3o`0000;oFG?B00?o0000oemddOmO
M=400_mOM=400ol0003oIgO?ofMgc`02ofMgc`GoL7_>0_miOld01?l0003oViC<oi^Dc?l00005oj6F
bP03o`000?nVVLSoYYW800;oYYW800?o0000ojbKa_n/VlH00_n/VlH00ol0003o/Ik4ok6Na002ok6N
a003o`000?nfX<;o]Z3200?o]Z3200Go0000ok^S`OnkXl7o^j?1o`000004oknU_`05o`000?o3Ykgo
`jNmol>W_Ol000001?o7ZK`01Ol0003obZ^jolZ[^_o:Zk[o000000?ocJfi2?l00002om>a]`05o`00
0?oD/KKoe;6fomBa]_l000000ooE/[D01Ol0003oe[:domJb]?oF/[Co000000;oe[:d2Ol00003omJb
]005o`000?oF/KCoe[6domJa]?l000000ooD/KD01Ol0003odk2fom>`]_oC/;Ko000000;odJng00?o
0000oln^^?o?[[P00_o?[[P01Ol0003ocJbiolf/^Oo=[;Wo000000?obJ^j00Co0000olJX_?o6Z;co
00000oo3Y[d00ol0003o_jBnoknT_P02oknT_P05o`000?njX/3o^Z;0okZR`?l000001?nfWl400ol0
003o/Ig3ok6M``02ok6M``05o`000?n]V/Co[I[4ojfJa?l000001OnXV<H2o`0000?oSHS800?o0000
ohN5bOn7QLT00_n7QLT00ol0003oPH;;oh62b`02oh62b`03o`000?mlP<coO83<00?oO83<00?o0000
ogQoc_mhOlh00_mhOlh2o`0000?oM7o@0_l00004odU]d`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool00005ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o04K6o`000?l000000_l0
0004oeUcdP03o`000?mOM=7oGgCA00;oGgCA00?o0000ofMgcomWMll00_mWMll00ol0003oL7_>og1k
cP02og1kcP?oNGo=00?o0000oi^Dc?l000001?nQU/X00ol0003oYYW8ojJIb003ojJIb003o`000?n/
VlKo[9_600;o[9_600?o0000ok6Na?naW/@00_naW/@00ol0003o]Z32okJP`P02okJP`P03o`000?nk
Xl7o^j?100;o^j?100?o0000oknU_onoYKl00_noYKl01Ol0003o`jNmol>W_Oo3Ykgo000000?oajVl
00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003ocJfiolf]^@02olf]^@05o`000?o?[[Socjjholn^^?l0
00000_oA[kL8o`000003omFb]Ol0003oe[:d00;oe[:d00Ko0000omJb]?oF/[Coe[:do`000?oG/[@5
o`000005omNb]?l0003oe[:domJb]?l000001?oF/K@01Ol0003oe;6eomBa]OoD/KGo000000;odk2f
00Go0000om6_]ooA[kOodJngo`000003oln^^005o`000?o=[;WocJbiolf/^Ol000000oo9ZkX01Ol0
003oaZRlolJX_?o6Z;co000000?o`jJm00?o0000oknT__noY;h00_noY;h01Ol0003o^Z;0okZR`?nj
X/3o000000Co]Yo100Go0000ok6M`onaWL?o/Ig3o`000004ojfJa003o`000?nXV<KoZ9S600?oZ9S6
00?o0000oj>Faol000000_n=R<P01Ol0003oQhG9ohN5bOn7QLWo000000CoPH;;00?o0000ogb0c?ml
P<`01?mlP<`00ol0003oN7o>ogQocP02ogQocP03o`000?mdOm3o000000?oM7o@0_l00003odU]d`03
o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`03o`000?oooooooooo
03Kooooo0ol000001?l0A/Ko0000oeAceOl00004oeUcdP03o`000?mOM=7oGgCA00;oGgCA00Go0000
ofMgcomWMlooIgO?o`000005og1kcPCoNGo=0_l00004oj6FbP03o`000?nVVLSoYYW800;oYYW800?o
0000ojbKa_n/VlH00on/VlH00ol0003o/Ik4ok6Na002ok6Na003o`000?nfX<;o]Z3200;o]Z3200?o
0000ok^S`OnkXl400_nkXl401Ol0003o_jFooknU_onoYKoo000000Co`jNm00Go0000olNY_?o7ZKco
ajVlo`000003olZ[^P03o`000?o=[KWocJfi00?ocJfi00Go0000oln^^?o?[[Socjjho`000003om6_
]`05o`000?oC/;Kodk2fom>`]_l000000_oD/KDCo`000003omJb]?l0003oe[6d00;oe[6d00Go0000
omBa]OoD/KGoe;6eo`000003om>`]P05o`000?oA[kOodJngom6_]ol000000oo?[[P01Ol0003ocJbi
olf/^Oo=[;Wo000000?obJ^j00Go0000olJX_?o6Z;coaZRlo`000003ol>V_@05o`000?noY;ko_jBn
oknT__l000001?njX/001Ol0003o]Yo1okJO`OnfWl7o000000Co/Ig300?o0000ojfJa?n]V/@00_n]
V/@00ol0003oZ9S6ojRHaP02ojRHaP04o`000?nSU/OoXiK7oj>Fa`;o00001?n7QLT00ol0003oPH;;
oh62b`02oh62b`03o`000?mlP<coO83<00?oO83<00?o0000ogQoc_mhOlh00_mhOlh01Ol0003oM7o@
ogAod?mdOm3o000000;oM7o@0_maOm82o`000003odU]dol0003ooooo02;ooooo00?o0000oooooooo
ool02Oooool0027ooooo00?o0000ooooooooool0<oooool3o`0000?ooooo0_l0A/H2o`0000CoFG?B
00?o0000oemddOmOM=400_mOM=401Ol0003oIgO?ofMgcomWMloo000000GoL7_>1?miOld2oh>4c0?o
000000?oXIK:o`000?nVVLP00onVVLP00ol0003o[9_6ojbKaP02ojbKaP03o`000?naW/Co/Ik400?o
/Ik400Go0000okJP`_nfX<;o]Z32o`000004ok^S`@03o`000?noYKoo_jFo00;o_jFo00Go0000ol>W
_Oo3Ykgo`jNmo`000004olNY_005o`000?o:Zk[obZ^jolZ[^_l000001?o=[KT01Ol0003ocjjholn^
^?o?[[So000000CodJng00Go0000om>`]_oC/;Kodk2fo`000003omBa]@05o`000?oF/KCoe[6domJa
]?l000000ooF/[@3o`000005omNb]?l0003o0000omNb]?l000000_oF/[@Ao`0000Cocjjh00Go0000
olf/^Oo=[;WocJbio`000003olV[^P04o`000?o6Z;coaZRlo`0000Co`jJm00Go0000oknT__noY;ko
_jBno`000003okZR`003o`000?nfWl7o]Yo100;o]Yo100?o0000ok6M`onaWL<00_naWL<01Ol0003o
[I[4ojfJa?n]V/Co000000GoZ9S600?o0000oj>FaonSU/L00_nSU/L2o`0000?oQhG900?o0000oh62
bon1P//00_n1P//00ol0003oO83<ogb0c003ogb0c003o`000?mhOlkoN7o>00;oN7o>00Oo0000ogAo
d?mdOm3oM7o@o`000?mdOm3o000000CoLGoB0_l0000Tooooo`03o`000?oooooooooo00Sooooo000Q
ooooo`03o`000?oooooooooo033ooooo0ol00006ooooo`03o`000?l0A/Ko04K600;o00000omILm80
0ol0003oGgCAoemdd@02oemdd@05o`000?mWMlooIgO?ofMgcol000001Om`Nlh4ogUoc@GoPhC<0_l0
0003ojJIb003o`000?n/VlKo[9_600?o[9_600?o0000ok6Na?naW/@00_naW/@00ol0003o]Z32okJP
`P02okJP`P03o`000?nkXl7o^j?100;o^j?100?o0000oknU_onoYKl00_noYKl01Ol0003o`jNmol>W
_Oo3Ykgo000000CoajVl00Go0000olZ[^_o:Zk[obZ^jo`000004olf]^@05o`000?o?[[Socjjholn^
^?l000000ooA[kL01Ol0003odk2fom>`]_oC/;Ko000000?oe;6e00?o0000omJa]?oF/K@00_oF/K@0
1ol0003oe[:do`000?l0003oek:do`000?oG/[@01Ol00003omJb]005o`000?oF/[Coe[:domJb]?l0
00000ooE/[D01Ol0003oe;6fomBa]_oD/KKo000000;odk6g0ol000000oo?[[So0000olf/^@02olf/
^@03o`000?o9Zk[obJ^j00;obJ^j00Co0000olJX_?o6Z;co00000oo3Y[d00ol0003o_jBnoknT_P02
oknT_P05o`000?njX/3o^Z;0okZR`?l000000onfWl400ol0003o/Ig3ok6M``02ok6M``03o`000?n]
V/Co[I[400;o[I[400?o0000ojRHa_nXV<H00_nXV<H00ol0003oXiK7oj>Fa`03oj>Fa`03o`000?nO
U<Wo000000;o00001?n1P//00ol0003oO83<ogb0c004ogb0c003o`000?mhOlkoN7o>00;oN7o>00?o
0000ogAod?mdOm000_mdOm02o`0000GoLGoB00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`;o04K60_l4A/H2o`000003oeUcd_l0003o
GgCA00?oGgCA00Go0000ofMgcomWMlooIgO?o`000004og1kcP03o`000?miOlgoNGo=00;oNGo=1On3
Q<`2ohf9bP04o`000?nVVLSoYYW8o`0000Go[9_600?o0000ok6Na?naW/@00_naW/@00ol0003o]Z32
okJP`P02okJP`P03o`000?nkXl7o^j?100;o^j?100?o0000oknU_onoYKl00_noYKl01Ol0003o`jNm
ol>W_Oo3Ykgo000000?oajVl00?o0000olZ[^_o:ZkX00_o:ZkX00ol0003ocJfiolf]^@02olf]^@05
o`000?o?[[Socjjholn^^?l000000ooA[kL01Ol0003odk2fom>`]_oC/;Ko000000?oe;6e00Co0000
omJa]?oF/KCoe[6d0ol000001?oF/[Co0000o`000?oG/[@4o`000003omNb]?l0003o000000;oe[:d
00Co0000omJb]?oF/[Co00000ooE/[D01Ol0003oe;6fomBa]_oD/KKo000000?odk6g00?o0000om:a
^?oB/KP02?l000000oo9Zk[o0000olJX_002olJX_005o`000?o3Y[go`jJmol>V_Ol000001?noY;h0
1Ol0003o^Z;0okZR`?njX/3o000000?o]Yo100?o0000ok6M`onaWL<00_naWL<01Ol0003o[I[4ojfJ
a?n]V/Co000000GoZ9S600?o0000oj>FaonSU/L00_nSU/L00ol0003oWiC9oinDb@02oinDb@;o0000
0on1P//00ol0003oO83<ogb0c003ogb0c003o`000?mhOlkoN7o>00;oN7o>00?o0000ogAod?mdOm00
0omdOm02o`0000GoLGoB00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`008Ooo
ool00ol0003oooooooooo`0Zooooo`?o00003Oooool00ol0003o04K6o`16aP03o`A6aP;o00001?mO
M=401Ol0003oIgO?ofMgcomWMloo000000CoL7_>00?o0000ogUocOmiOld00_miOld5oh>4c0?oSHW:
00?o0000ojJIb?l000001?n/VlH00ol0003o/Ik4ok6Na003ok6Na005o`000?nfX<;o]Z32okJP`_l0
00001OnkXl401Ol0003o_jFooknU_onoYKoo000000Co`jNm00Go0000olNY_?o7ZKcoajVlo`000003
olZ[^P03o`000?o=[KWocJfi00;ocJfi00?o0000oln^^?o?[[P00_o?[[P01Ol0003odJngom6_]ooA
[kOo000000?odk2f00Go0000omBa]OoD/KGoe;6eo`000002omJa]0;o00000_oF/[@2o`000009omNb
]?l0003o0000o`000?oG/[Co0000omNb]?l0003oek:d00;o00000ooF/[@01Ol0003oeK:eomFb]OoE
/[Go000000?oe;6f00Co0000om>a]ooC/KOo00001?oB/KP01Ol0003odK2iom6`^OoA/;Wo000000;o
ck2j1Ol00004ol>V_@05o`000?noY;ko_jBnoknT__l000000onjX/000ol0003o]Yo1okJO`@02okJO
`@05o`000?naWL?o/Ig3ok6M`ol000001?n]V/@00ol0003oZ9S6ojRHaP02ojRHaP03o`000?nSU/Oo
XiK700?oXiK700?o0000oinDbOnOU<T00_nOU<T00ol0003oVY?;o`000002oh62b`03o`000?mlP<co
O83<00?oO83<00?o0000ogQoc_mhOlh00_mhOlh00ol0003oM7o@ogAod003ogAod003o`000?maOm;o
000000?oLGoB00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0
003oooooooooo`0Wooooo`?o00004?ooool00ol0003o04K6o`16aP04o`A6aP05o`000?mOM=7oGgCA
oemddOl000001?mWMll00ol0003oL7_>og1kcP02og1kcP03o`000?miOlgoNGo=00;oNGo=00?o0000
oh>4c?n3Q<`00_n3Q<`4ohf9bP;o00001?n/VlH00ol0003o/Ik4ok6Na002ok6Na003o`000?nfX<;o
]Z3200;o]Z3200?o0000ok^S`OnkXl400_nkXl400ol0003o_jFooknU_`02oknU_`05o`000?o3Ykgo
`jNmol>W_Ol000001?o7ZK`01Ol0003obZ^jolZ[^_o:Zk[o000000CocJfi00Go0000oln^^?o?[[So
cjjho`000003om6_]`03o`000?oC/;Kodk2f00;odk2f00?o0000omBa]OoD/KD01?l000001OoE/KGo
0000omJb]?l0003oe[:d00Go000000?oek:do`000?l000000ooG/[@2o`0000;oe[:d00Go0000omFb
]OoE/[GoeK:eo`000003omBa]P04o`000?oC/KOodk6go`0000?od[6h00Go0000om6`^OoA/;WodK2i
o`000004oln`^P03o`000?o=[kcocJnl00?o000000?o`jJmo`000?noY;h00onoY;h01Ol0003o^Z;0
okZR`?njX/3o000000?o]Yo100?o0000ok6M`onaWL<00_naWL<01Ol0003o[I[4ojfJa?n]V/Co0000
00GoZ9S600?o0000oj>FaonSU/L00_nSU/L00ol0003oWiC9oinDb@02oinDb@04o`000?nJTl_oVY?;
oiZCb`;o00001_mlP<`00ol0003oN7o>ogQocP02ogQocP03o`000?mdOm3oM7o@00?oM7o@00?o0000
og5od_l000000omaOm800ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Poooo
o`03o`000?oooooooooo02Gooooo0ol0000Dooooo`03o`000?l0A/Ko000000?o14K600Go3T[7o`00
0?mOM=7oGgCAo`000004ofMgc`03o`000?m`NlkoL7_>00;oL7_>00Go0000ogUocOmiOlgoNGo=o`00
0005oh>4c0CoSHW:0_nFS/T3o`000003ojbKa_l0003o/Ik400?o/Ik400?o0000okJP`_nfX<800_nf
X<800ol0003o^j?1ok^S`@02ok^S`@03o`000?noYKoo_jFo00;o_jFo00Go0000ol>W_Oo3Ykgo`jNm
o`000004olNY_005o`000?o:Zk[obZ^jolZ[^_l000001?o=[KT01Ol0003ocjjholn^^?o?[[So0000
00?odJng00?o0000om>`]_oC/;H00_oC/;H01?l0003oe;6eo`000?l00004omFa]@;o00000_oF/[@8
o`0000?oek:d00Co0000omJb]?l0003o00000ooE/[D01Ol0003oe;6fomBa]_oD/KKo000000?odk6g
00Go0000om:a^?oB/KSod[6ho`000003om6`^@05o`000?o?/;[ock2joln`^_l000000oo=[k`00ol0
003objjmol^^_@03o`0000?o_jBn00Co0000okZR`?njX/3o00001?nfWl400ol0003o/Ig3ok6M``02
ok6M``05o`000?n]V/Co[I[4ojfJa?l000001?nXV<H00ol0003oXiK7oj>Fa`03oj>Fa`03o`000?nO
U<WoWiC900;oWiC900?o0000oiZCbonJTl/00_nJTl/2o`0000CoO83<00?o0000ogQoc_mhOlh00_mh
Olh00ol0003oM7o@ogAod003ogAod007o`000?maOm;oLGoBog5od_l0003oLGoBo`00000Vooooo`03
o`000?oooooooooo00Sooooo000Pooooo`;o00008oooool3o`0001Oooooo00?o0000o`16a_l0A/H0
0ol4A/H01Ol0003o3T[7o`000?mOM=7o000000CoIgO?00?o0000og1kc_m`Nlh00_m`Nlh01Ol0003o
NGo=ogUocOmiOlgo000000GoPhC<1?n=RLX5oiJ>b@;o00001?naW/@01Ol0003o]Z32okJP`_nfX<;o
000000Go^j?100?o0000oknU_onoYKl00_noYKl01Ol0003o`jNmol>W_Oo3Ykgo000000CoajVl00Co
0000olZ[^_o:Zk[o00001Oo=[KT01Ol0003ocjjholn^^?o?[[So000000?odJng00Co0000om>`]_oC
/;Kodk2f0ol000000ooD/KKo0000omFa]@02omFa]@;o00000ooF/[@00ol0003oek:do`000002o`00
0006omNb]?l0003oek:do`000?oG/[Co00000ooF/[@2o`0000;oeK:e00Go0000omBa]_oD/KKoe;6f
o`000002om>a]`03o`000?oB/KSod[6h00;od[6h00Go0000om6`^OoA/;WodK2io`000003oln`^P04
o`000?o=[kcocJnlo`0000Cobjjm00?o0000olR^_ol000000_l00003okZR`003o`000?nfWl7o]Yo1
00;o]Yo100Go0000ok6M`onaWL?o/Ig3o`000004ojfJa003o`000?nXV<KoZ9S600;oZ9S600?o0000
oj>FaonSU/L00_nSU/L00ol0003oWiC9oinDb@02oinDb@03o`000?nJTl_oVY?;00?oVY?;00Co0000
oiJBcOl0003o00000_mlP<`00ol0003oN7o>ogQocP02ogQocP03o`000?mdOm3oM7o@00?oM7o@00?o
0000og5od_maOm800_maOm82o`0002Kooooo00?o0000ooooooooool02?ooool0023ooooo00?o0000
ooooooooool08?ooool2o`0001[ooooo00Co0000o`16a_l0A/Ko00000ol4A/H2o`i:a`;o00001?mW
Mll00ol0003oL7_>og1kcP02og1kcP05o`000?miOlgoNGo=ogUocOl000001?n3Q<`00ol0003oSHW:
ohf9bP02ohf9bPGoUXk90_nNT/L4o`0000Co]Z3200?o0000ok^S`OnkXl400_nkXl400ol0003o_jFo
oknU_`02oknU_`03o`000?o3Ykgo`jNm00;o`jNm00Go0000olNY_?o7ZKcoajVlo`000003olZ[^P03
o`000?o=[KWocJfi00;ocJfi00?o0000oln^^?o?[[P00_o?[[P01?l0003odJngom6_]ol00002om>`
]P?o00000ooD/KH01Ol0003oeK6eomFa]OoE/KGo000000?oe[:d1_l000001_oG/[Co0000omNb]?l0
003oek:do`0000?oe[:d00Go0000omJc]Ol0003oeK:eo`000002omBa]P05o`000?oC/KOodk6gom>a
]ol000000ooB/KP01Ol0003odK2iom6`^OoA/;Wo000000?ock2j00Go0000olf__?o=[kcocJnlo`00
0003ol^^_@03o`000?o8[[oob:jo00;ob:jo0ol000000onjX/3o0000okJO`@02okJO`@03o`000?na
WL?o/Ig300;o/Ig300Go0000ojfJa?n]V/Co[I[4o`000004ojRHaP03o`000?nSU/OoXiK700?oXiK7
00Go0000oinDbOnOU<WoWiC9o`000005oiZCb`03o`000?nFT/goUY;=00;oUY;=00?o0000ogb0c?l0
00001?mhOlh00ol0003oM7o@ogAod002ogAod003o`000?maOm;oLGoB00CoLGoB00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Mooooo`?o0000
7Oooool00ol0003o04K6o`000003o`A6aP04o`000?l>B/Oo3T[7o`0000?oIgO?00?o0000og1kc_m`
Nlh00om`Nlh01Ol0003oNGo=ogUocOmiOlgo000000CoPhC<00?o0000ohf9b_n=RLX00_n=RLX5oiJ>
b@GoWY;70ol00002okJP`P03o`000?nkXl7o^j?100;o^j?100?o0000oknU_onoYKl00_noYKl01Ol0
003o`jNmol>W_Oo3Ykgo000000CoajVl00Go0000olZ[^_o:Zk[obZ^jo`000004olf]^@03o`000?o?
[[Socjjh00;ocjjh00?o0000om6_]ol000000ol00002om:`]`05o`000?oD/KKoe;6fomBa]_l00000
0_oE/KD2o`0000;oe[:d0_l000000ooF/[Co0000o`000002o`000005omNb]?l0003oek:domNb]?l0
00000ooF/[@01?l0003oe[>eomJc]OoF/kD2o`0000;oe;6f00Go0000om>a]ooC/KOodk6go`000003
om:a^005o`000?oA/;WodK2iom6`^Ol000000oo?/;X01Ol0003ocJnlolf__?o=[kco000000?objjm
00?o0000olR^_oo8[[l00_o8[[l00ol0003oaZg1olJ]`@02o`0000?o]Yo100?o0000ok6M`onaWL<0
0_naWL<01Ol0003o[I[4ojfJa?n]V/Co000000CoZ9S600?o0000oj>FaonSU/L00_nSU/L00ol0003o
WiC9oinDb@02oinDb@03o`000?nJTl_oVY?;00?oVY?;00?o0000oiJBcOnFT/d00onFT/d2o`0000?o
N7o>00?o0000ogAod?mdOm000omdOm000ol0003oLGoBog5odP03og5odP;o00009oooool00ol0003o
ooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o00008?ooool01?l0003o04K6
o`16a_l00002o`A6aP05o`000?l>B/Oo3T[7oa]@bOl000000_mWMll00ol0003oL7_>og1kcP03og1k
cP05o`000?miOlgoNGo=ogUocOl000001?n3Q<`00ol0003oSHW:ohf9bP02ohf9bP03o`000?nFS/Wo
UXk900;oUXk91OnNT/L3ojNGa@?o00001?nkXl400ol0003o_jFooknU_`02oknU_`05o`000?o3Ykgo
`jNmol>W_Ol000001?o7ZK`01Ol0003obZ^jolZ[^_o:Zk[o000000CocJfi00Co0000oln^^?o?[[So
cjjh0ol000000oo@[[So0000om:`]`03om:`]`09o`000?oD/KKoe;6fomBa]_l0003oeK6eo`000?oE
/KGo000000;oe[:d0ol000001?oG/[Co0000o`000?l00002omNb]003o`000?oG/[Co000000?oe[:d
00Wo0000omJc]OoF/kGoe[>eo`000?oF/kKo0000omBa]_l000000_oC/KL01Ol0003od[6hom:a^?oB
/KSo000000?odK2i00?o0000oln`^_o?/;X00_o?/;X01?l0003ocJnlolf__?l00003ol^^_@03o`00
0?o8[[oob:jo00;ob:jo00Ko0000olJ]`Oo6[L7oaZg1o`000?o3[<<2o`000003okJO`Ol0003o/Ig3
00;o/Ig300Go0000ojfJa?n]V/Co[I[4o`000005ojRHaP03o`000?nSU/OoXiK700;oXiK700Go0000
oinDbOnOU<WoWiC9o`000005oiZCb`03o`000?nFT/goUY;=00CoUY;=00?o0000oi:Acol000000_mh
Olh00ol0003oM7o@ogAod002ogAod003o`000?maOm;oLGoB00CoLGoB00?o0000ooooool000009_oo
ool00ol0003oooooooooo`07ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`04o`000?l0A/Ko
04K6o`0000?o14K60_l>B/L01Ol0003o6e39o`000?mWMloo000000GoL7_>00Go0000ogUocOmiOlgo
NGo=o`000004oh>4c005o`000?n=RL[oSHW:ohf9b_l000001OnFS/T00ol0003oWY;7oijBa`02oijB
a`CoYiO50_n^Vl@4o`0000Co_jFo00?o0000ol>W_Oo3Ykd00_o3Ykd00ol0003oajVlolNY_002olNY
_004o`000?o:Zk[obZ^jo`0000CocJfi00?o0000oln^^?o?[[P00ol00003om2^^003o`000?oB/;Oo
d[2g00;od[2g00Co0000omBa]_oD/KKoe;6f0_l00003omFa]@?o000000?oe[:do`000?oG/[@00ol0
0002omNb]0;o000000Coek>eo`000?oF/[Co00000ooF/kD01Ol0003oe[>fomJc]_oF/kKo000000?o
dk6g00Go0000om:a^?oB/KSod[6ho`000003om6`^@05o`000?o?/;[ock2joln`^_l000000oo=[k`0
1Ol0003objjmol^^_Oo;[[go000000Cob:jo00Co0000olJ]`Oo6[L7o00001?o3[<<2o`0000?o/Ig3
00Go0000ojfJa?n]V/Co[I[4o`000004ojRHaP03o`000?nSU/OoXiK700;oXiK700?o0000oinDbOnO
U<T00_nOU<T00ol0003oVY?;oiZCb`02oiZCb`03o`000?nFT/goUY;=00CoUY;=00Oo0000oi:AconB
TLooTY7?o`000?mhOlko000000CoM7o@00?o0000og5od_maOm800omaOm801Ol0003ooooooooooooo
oooo000002Gooooo00?o0000ooooooooool01oooool001oooooo0_l0000Fooooo`?o00009oooool0
0ol0003o04K6o`000003o`A6aP03o`000?l>B/Oo3T[700;o6e390_l00004og1kcP03o`000?miOlgo
NGo=00;oNGo=00?o0000oh>4c?n3Q<`00_n3Q<`01Ol0003oSHW:ohf9b_n=RL[o000000GoUXk900?o
0000oijBaonNT/L00_nNT/L4ojNGa@Go[Y_42?l000000oo3Ykgo0000olNY_003olNY_003o`000?o:
Zk[o000000Wo00000_o=[KT01Ol0003od:jhom2^^?o@[[So000000Cod[2g00?o0000omBa]_oD/KH0
0_l00004omFa]@;o00000_oF/[@2o`000003omNb]?l0003o000000;oek:d00Ko0000omNc]OoG/kGo
0000omJb]?l00003omJc]@04o`000?oF/kKoe[>fomJc]P;o00000_oC/KL01Ol0003od[6hom:a^?oB
/KSo000000?odK2i00Go0000oln`^_o?/;[ock2jo`000002olf__005o`000?o;[[gobjjmol^^_Ol0
00001?o8[[l01Ol0003oaZg1olJ]`Oo6[L7o000000Co`jc300Ko0000ol2[aOl0003o0000ok6M`ol0
0002ojfJa003o`000?nXV<KoZ9S600?oZ9S600?o0000oj>FaonSU/L00_nSU/L01Ol0003oWiC9oinD
bOnOU<Wo000000GoVY?;00?o0000oiJBcOnFT/d00onFT/d00ol0003oTY7?oi:Ac`03oi:Ac`;o0000
1?mdOm000ol0003oLGoBog5odP03og5odP03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`07ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`?o
0000:_ooool01?l0003o04K6o`16a_l00002o`A6aP04o`000?l>B/Oo3T[7o`0000;o6e390_l00003
og1kcP03o`000?miOlgoNGo=00;oNGo=00?o0000oh>4c?n3Q<`00_n3Q<`01Ol0003oSHW:ohf9b_n=
RL[o000000CoUXk900?o0000oijBaonNT/L00onNT/L4ojNGa@Go[Y_400?o0000okFO`_neWl800_ne
Wl800ol0003o^j?0ok^S`008o`0000;oaJRl00?o0000olV[^oo9Zk/00_o9Zk/00ol0003ocJfiolf]
^@02olf]^@05o`000?o@[[Sod:jhom2^^?l000000ooB/;L01_l0003oe;6fomBa]_l0003oe;6fo`00
00?oeK6e0ol000000ooF/[Co0000omNb]002o`000003omNb]?l0003oek:d00;o00000ooG/kD01Ol0
003oe[>eomJc]OoF/kGo000000?oe[>f00?o0000omJd]ooF];L00_l00003om:a^005o`000?oA/;Wo
dK2iom6`^Ol000000oo?/;X01Ol0003ocJnlolf__?o=[kco000000?objjm00?o0000olR^_oo8[[l0
0_o8[[l01?l0003oaZg1olJ]`Ol00004ol>/``03o`000?o0ZlGo`:_500;o`:_50_l00002ojfJa003
o`000?nXV<KoZ9S600;oZ9S600?o0000oj>FaonSU/L00_nSU/L00ol0003oWiC9oinDb@02oinDb@03
o`000?nJTl_oVY?;00;oVY?;00?o0000oiJBcOnFT/d00onFT/d00ol0003oTY7?oi:Ac`04oi:Ac`03
o`000?n?TM7o000000;oM7o@00?o0000og5od_maOm800omaOm800ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oo
oooo0ol0000]ooooo`04o`000?l0A/Ko04K6o`0000?o14K600?o0000o`i:aol000000_lKD<T2ob]I
c0;o000000?oL7_>o`000?miOld00omiOld00ol0003oPhC<oh>4c002oh>4c005o`000?n=RL[oSHW:
ohf9b_l000001?nFS/T00ol0003oWY;7oijBa`03oijBa`CoYiO500?o0000ojjKa?n^Vl@00_n^Vl@0
0ol0003o]Io2okFO`P02okFO`P05o`000?nkXl3o^j?0ok^S`?l000001?o1Y[h01Ol0003oaJRlolFX
_?o5Z;co000000CobJ^k00?o0000olf]^Oo=[KT00_o=[KT01Ol0003od:jhom2^^?o@[[So000000?o
d[2g00?o0000omBa]_l000000_oD/KH01_l0003oeK6eomFa]Ol0003oeK:eo`0000;oe[:d00Go0000
omNb]?l0003o0000omNb]002o`000003omNc]Ol0003oek>e00;oek>e00Go0000omJc]OoF/kGoe[>e
o`000003omJc]P04o`000?oF];Ooe[BgomJd]`;o00000_oB/KP01Ol0003odK2iom6`^OoA/;Wo0000
00?ock2j00Co0000olf__?o=[kco00000oo;[[d00ol0003ob:joolR^_`02olR^_`05o`000?o6[L7o
aZg1olJ]`Ol000001?o3[<<00ol0003o`:_5ol2[a@02ol2[a@05o`000?nlZ/Oo0000ojfJa?l00000
1?nXV<H00ol0003oXiK7oj>Fa`02oj>Fa`05o`000?nOU<WoWiC9oinDbOl000001OnJTl/00ol0003o
UY;=oiJBc@03oiJBc@03o`000?nBTLooTY7?00?oTY7?00Oo0000ohnAdOn?TM7oSi7Ao`000?mdOm3o
000000GoLGoB00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Oooooo0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00cooooo0ol0000aooooo`03o`000?l0A/Ko000000?o14K600?o0000
o`i:aol>B/L00_lKD<T01?l0003o:eW<ob]Ic?l[FL`2o`0000?oNGo=00?o0000oh>4c?n3Q<`00on3
Q<`01Ol0003oSHW:ohf9b_n=RL[o000000CoUXk900?o0000oijBaonNT/L00_nNT/L00ol0003oYiO5
ojNGa@02ojNGa@03o`000?n^VlCo[Y_400;o[Y_400?o0000okFO`_neWl800_neWl801Ol0003o^j?0
ok^S`?nkXl3o000000Co`JJn00Go0000olFX_?o5Z;coaJRlo`000004olV[^`05o`000?o=[KWocJfi
olf]^Ol000000oo@[[P00ol0003od[2gom:`]`02om:`]`;o00000ooD/KH00ol0003oeK6eo`000002
omFb]@;o000000?oe[:do`000?oG/[@01?l00002omNc]@08o`000?oG/kGoek>eo`000?oG];Ko0000
omJc]Ol00003omJc]P03o`000?oF];Ooe[Bg00;oe[Bg00Go0000omFd^Ol0003od[6ho`000002om6`
^@05o`000?o?/;[ock2joln`^_l000000oo=[k`01Ol0003objjmol^^_Oo;[[go000000Cob:jo00Co
0000olJ]`Oo6[L7o00001?o3[<<00ol0003o`:_5ol2[a@02ol2[a@04o`000?nlZ/Oo_:[7okbZa`;o
00000onXV<H00ol0003oXiK7oj>Fa`02oj>Fa`03o`000?nOU<WoWiC900;oWiC900?o0000oiZCbonJ
Tl/00_nJTl/00ol0003oUY;=oiJBc@03oiJBc@03o`000?nBTLooTY7?00?oTY7?00?o0000ohnAdOn?
TM400on?TM42o`0000GoLGoB00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00Co0025o`000?l0A/Ko00000_l4A/H01?l0
003o3T[7o`i:aol00002oa]@b@Co:eW<0_l00002ogUoc@03o`000?n3Q<coPhC<00?oPhC<00Go0000
ohf9b_n=RL[oSHW:o`000004oiJ>b@03o`000?nNT/OoWY;700;oWY;700Go0000ojNGaOnWUlGoYiO5
o`000005ojjKa003o`000?neWl;o]Io200;o]Io200Go0000ok^S`?nkXl3o^j?0o`000004ol6V_P05
o`000?o5Z;coaJRlolFX_?l000001?o9Zk/01Ol0003ocJfiolf]^Oo=[KWo000000?od:jh00Co0000
om:`]ooB/;Ood[2g0_l00004omBa]P;o00000_oE/[D00ol0003oe[:fomJb]P05o`000003omNc]Ol0
003oek>e00;oek>e0_l00002omNd]P03o`000?oF/kGo000000?oe[>f00Go0000omJd]ooF];Ooe[Bg
o`000003omFd^@;o00000_oA/;T01Ol0003ock2joln`^_o?/;[o000000?ocJnl00Go0000ol^^_Oo;
[[gobjjmo`000003olR^_`05o`000?o6[L7oaZg1olJ]`Ol000000oo3[<<00ol0003o`:_5ol2[a@02
ol2[a@03o`000?nlZ/Oo_:[700;o_:[700Ko0000okVYbOl0003o0000ojRHa_l00004oj>Fa`05o`00
0?nOU<WoWiC9oinDbOl000001?nJTl/00ol0003oUY;=oiJBc@03oiJBc@03o`000?nBTLooTY7?00?o
TY7?00?o0000ohnAdOn?TM401?n?TM401?l0003oS9;Do`000?l00002og5odP03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00Kooooo0ol0000hooooo`03o`00QOl0003o000000;o14K600Co0000o`i:aol>B/Oo00000_lK
D<T01?l0003o:eW<ob]Ic?l[FL`2ociSc`03o`000?miOlgo000000GoPhC<00Go0000ohf9b_n=RL[o
SHW:o`000004oiJ>b@03o`000?nNT/OoWY;700;oWY;700Go0000ojNGaOnWUlGoYiO5o`000004ojjK
a003o`000?neWl;o]Io200;o]Io200?o0000ok^S`?nkXl000_nkXl000ol0003o`JJnol6V_P02ol6V
_P05o`000?o5Z;coaJRlolFX_?l000001?o9Zk/01Ol0003ocJfiolf]^Oo=[KWo000000?od:jh00Ko
0000om:`]ol0003o0000om:`]ol00004omBa]P05o`000?oE/[GoeK:eomFb]Ol000000_oF/[H01ol0
003oe[>fo`000?oG/kKo0000omNc]Ol000000ooG/kD2o`0000?oekBf00Go0000omJc]_oF/kKoe[>f
o`000003omJd]`03o`000?oE];WoeKBi00;oeKBi00Go0000omFf^_l0003odK2io`000003oln`^P04
o`000?o=[kcocJnlo`0000?objjm00Go0000olR^_oo8[[oob:joo`000003olJ]`@03o`000?o3[<?o
`jc300;o`jc300?o0000ol2[aOo0ZlD00_o0ZlD01Ol0003o_:[7okbZaonlZ/Oo000000Co^JW90_l0
0003oj>Fa`05o`000?nOU<WoWiC9oinDbOl000001OnJTl/00ol0003oUY;=oiJBc@02oiJBc@03o`00
0?nBTLooTY7?00CoTY7?00?o0000ohnAdOn?TM400on?TM400ol0003oS9;DohbBe002ohbBe003o`00
0?maOm;o000000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`001?oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`?o0000??ooool00ol008Go0000o`A6aP02o`A6aP06o`000?l>B/Oo3T[7o`000?lK
D<Wo00000ol[FL`00ol0003o?V??ociSc`02o`0000CoPhC<00?o0000ohf9b_n=RLX00_n=RLX00ol0
003oUXk9oiJ>b@02oiJ>b@03o`000?nNT/OoWY;700;oWY;700Go0000ojNGaOnWUlGoYiO5o`000004
ojjKa003o`000?neWl;o]Io200;o]Io200Go0000ok^S`?nkXl3o^j?0o`000004ol6V_P03o`000?o5
Z;coaJRl00;oaJRl00?o0000olV[^oo9Zk/00_o9Zk/01Ol0003ocJfiolf]^Oo=[KWo000000?od:jh
0_l00003om:`]`03o`000?oD/KKoe;6f00;oe;6f00Co0000omFb]OoE/[Go00000_oF/[H02?l0003o
e[>fomJc]_l0003oek>fo`000?oG/kGo00000ooG/kD00ol0003oekBfomNd]P02omNd]P05o`000?oF
/kKoe[>fomJc]_l000000ooF];L01Ol0003oeKBiomFd^OoE];Wo000000?oeKJj0_l00002oln`^P05
o`000?o=[kcocJnlolf__?l000000oo;[[d01Ol0003ob:joolR^_oo8[[oo000000?oaZg100Go0000
ol>/`oo3[<?o`jc3o`000004ol2[a@05o`000?nlZ/Oo_:[7okbZaol000001OniZLT01_l0003o]ZW<
o`000?l0003oXiK7o`0000?oWiC900?o0000oiZCbonJTl/00_nJTl/00ol0003oUY;=oiJBc@03oiJB
c@03o`000?nBTLooTY7?00?oTY7?00?o0000ohnAdOn?TM400on?TM400ol0003oS9;DohbBe004ohbB
e003o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06oooo
o`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooooooool3o`00043ooooo00Go0025o`000?l0003o14K6o`000002o`i:a`03o`000?lK
D<Wo6e3900Co:eW<0olnHll2o`0000?oPhC<00?o0000ohf9b_n=RLX00_n=RLX00ol0003oUXk9oiJ>
b@02oiJ>b@03o`000?nNT/OoWY;700;oWY;700Go0000ojNGaOnWUlGoYiO5o`000004ojjKa003o`00
0?neWl;o]Io200;o]Io200Go0000ok^S`?nkXl3o^j?0o`000004ol6V_P03o`000?o5Z;coaJRl00;o
aJRl00Go0000olV[^oo9Zk_obJ^ko`000004olf]^@03o`000?o@[[Sod:jh00;o00001?oB/;L01?l0
003oe;6fomBa]_oD/KH2o`000003omFb]Ol0003oe[:f00;oe[:f00?o0000omJc]_l000000_oG/kH0
0ol0003oek>eo`000002omNc]@;o00000ooG];H01Ol0003oekFgo`000?oF/kKo000000?oe[Bg00?o
0000omFd^OoE];T00_oE];T02Ol0003oeKJjomFf^_oE][[o0000omBg_?l0003ock2jo`000002olf_
_005o`000?o;[[gobjjmol^^_Ol000000oo8[[l01Ol0003oaZg1olJ]`Oo6[L7o000000Co`jc300Go
0000ol2[aOo0ZlGo`:_5o`000004okbZa`03o`000?niZLWo^JW900;o^JW900?o0000okJYc?nfZL`0
0_nfZL`2o`0000;oWiC900?o0000oiZCbonJTl/00onJTl/00ol0003oUY;=oiJBc@02oiJBc@03o`00
0?nBTLooTY7?00?oTY7?00?o0000ohnAdOn?TM400on?TM400ol0003oS9;DohbBe004ohbBe003o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`Co0000A?ooool2o`00Q@;o0000
0_l>B/L01?l0003o6e39oa]@bOl00003ob]Ic0?o?V??0_mAKM42o`000003oh>4c?l0003oSHW:00;o
SHW:00?o0000oiJ>bOnFS/T00onFS/T00ol0003oWY;7oijBa`02oijBa`05o`000?nWUlGoYiO5ojNG
aOl000001?n^Vl@00ol0003o]Io2okFO`P02okFO`P05o`000?nkXl3o^j?0ok^S`?l000001?o1Y[h0
1Ol0003oaJRlolFX_?o5Z;co000000CobJ^k00Ko0000olf]^Oo=[KWocJfio`000?o@[[P2o`000003
oln_^Ol0003od[2g00?od[2g00Co0000omBa]_oD/KKo00000_oD/[L2o`0000;oe[:f00Co0000omJc
]_oF/kKo00000_oG/kH01ol0003oek>eo`000?oG/kGo0000omNd]_l000000_oG];H01_l0003oekFg
omNe]ol0003oe[>fo`0000?oe[Bg00Go0000omFd^OoE];WoeKBio`000003omFf^P04o`000?oD]kco
e;NlomBg_0;o00000_o=[k`01Ol0003objjmol^^_Oo;[[go000000?ob:jo00Go0000olJ]`Oo6[L7o
aZg1o`000003ol>/``03o`000?o0ZlGo`:_500;o`:_500Go0000okbZaonlZ/Oo_:[7o`000004okVY
b@03o`000?nfZLco]ZW<00?o]ZW<00Go0000ok:Xc_l0003oWiC9o`000004oiZCb`03o`000?nFT/go
UY;=00;oUY;=00?o0000oi:AconBTLl00onBTLl00ol0003oSi7AohnAd@03ohnAd@03o`000?n<T]Co
S9;D00CoS9;D00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Kooooo000Nooooo`;o0000Aoooool2o`00Q@04o`A6a_l0003o3T[7o`0000;o6e3900Go0000
ob]Ic?l[FLco:eW<o`000002ociSc`04o`000?mAKM7oDFgAoe5]d@;o00000on=RLX00ol0003oUXk9
oiJ>b@03oiJ>b@03o`000?nNT/OoWY;700;oWY;700Go0000ojNGaOnWUlGoYiO5o`000004ojjKa003
o`000?neWl;o]Io200;o]Io200Go0000ok^S`?nkXl3o^j?0o`000004ol6V_P05o`000?o5Z;coaJRl
olFX_?l000001?o9Zk/01?l0003ocJfiolf]^Oo=[KT2o`0000?ocjni00?o0000om:`]ooB/;L00_oB
/;L00ol0003oe;6fo`000003omBb]`05o`000?oF/[Koe[:fomJb]_l000000_oF/kH00ol0003oek>f
o`000002omNc]@;o00000ooG];H00ol0003oekBfo`000003omNe]`05o`000?oF];Ooe[BgomJd]ol0
00001?oE];T01Ol0003oeKJjomFf^_oE][[o000000?oe;Nl00Go0000om>h__l0003ocJnlo`000002
ol^^_@05o`000?o8[[oob:joolR^_ol000000oo6[L400ol0003o`jc3ol>/``02ol>/``05o`000?o0
ZlGo`:_5ol2[aOl000000onlZ/L00ol0003o^JW9okVYb@02okVYb@03o`000?nfZLco]ZW<00?o]ZW<
00Co0000ok:Xc_nbZ<ko/ZS>0_l00003oiZCb`03o`000?nFT/goUY;=00;oUY;=00?o0000oi:AconB
TLl01?nBTLl00ol0003oSi7AohnAd@02ohnAd@03o`000?n<T]CoS9;D00CoS9;D00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`00
0?oooooooooo04Gooooo0_l008D01?l0003o3T[7o`i:aol00002oa]@b@04o`000?l[FLco:eW<o`00
00?o?V??1?mAKM42o`0000;oSHW:00?o0000oiJ>bOnFS/T00onFS/T00ol0003oWY;7oijBa`02oijB
a`05o`000?nWUlGoYiO5ojNGaOl000001?n^Vl@00ol0003o]Io2okFO`P02okFO`P05o`000?nkXl3o
^j?0ok^S`?l000001?o1Y[h01Ol0003oaJRlolFX_?o5Z;co000000CobJ^k00?o0000olf]^Oo=[KT0
0_l00004oln_^@03o`000?oB/;Ood[2g00;od[2g0_l00004omBb]`04o`000?oF/[Koe[:fo`0000;o
e[>f00Go0000omNc]_oG/kKo0000omNc]@02o`0000CoekBf0_l00004omNe]`04o`000?oF];Ooe[Bg
o`0000CoeKBi00Go0000omFf^_oE][[oeKJjo`000003omBg_004o`000?oC^;kodkRnom>h_P?o0000
00?objjmo`000?o8[[l00_o8[[l01Ol0003oaZg1olJ]`Oo6[L7o000000?o`jc300Go0000ol2[aOo0
ZlGo`:_5o`000003okbZa`03o`000?niZLWo^JW900?o^JW900?o0000okJYc?nfZL`00_nfZL`00ol0
003o/ZS>ok:XcP02ok:XcP06o`000?n^Z=7o0000o`000?nJTl_o00001?nFT/d00ol0003oTY7?oi:A
c`03oi:Ac`03o`000?n?TM7oSi7A00;oSi7A00?o0000ohbBe?n<T]@01?n<T]@00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool0AOooool01Ol008Go002:o`000?l>B/Oo000000;o6e3900Go0000ob]Ic?l[FLco:eW<
o`000002ociSc`CoDFgA0_mTN=43o`0000CoUXk900?o0000oijBaonNT/L00onNT/L01Ol0003oYiO5
ojNGaOnWUlGo000000Co[Y_400?o0000okFO`_neWl800_neWl801Ol0003o^j?0ok^S`?nkXl3o0000
00Co`JJn00Go0000olFX_?o5Z;coaJRlo`000004olV[^`05o`000?o=[KWo0000olb]^ol000001?o?
[kT00ol0003od[2gom:`]`02om:`]`03o`000?oD/[Ooe;:g00;oe;:g00Go0000omFc]ol0003oe[:f
o`000002omJc]P03o`000?oG/kKoek>f00;o000000?oekFgo`000?oG];H00ooG];H00ol0003oekFg
omNe]`02omNe]`05o`000?oG]kSo0000omJd]ol000001?oE];T01Ol0003oeKJjomFf^_oE][[o0000
00?oe;Nl00Go0000om>h__oC^;kodkRno`000002om>i`0;o00000_o8[[l01Ol0003oaZg1olJ]`Oo6
[L7o000000Co`jc300Go0000ol2[aOo0ZlGo`:_5o`000003okbZa`03o`000?niZLWo^JW900;o^JW9
00?o0000okJYc?nfZL`00_nfZL`00ol0003o/ZS>ok:XcP02ok:XcP03o`000?n^Z=7o[ZSA00;o[ZSA
0_l00003oiJBc@03o`000?nBTLooTY7?00?oTY7?00?o0000ohnAdOn?TM400_n?TM400ol0003oS9;D
ohbBe004ohbBe003o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`05ooooo`008_ooool00ol0003oooooooooo`14ooooo`03o`000?l008Go002:00;o00000_lK
D<T01Ol0003o:eW<ob]Ic?l[FLco000000;o?V??00Go0000oe5]dOmAKM7oDFgAo`000003ofAhd@;o
00000onFS/T00ol0003oWY;7oijBa`02oijBa`03o`000?nWUlGoYiO500;oYiO500?o0000ojjKa?n^
Vl@00_n^Vl@00ol0003o]Io2okFO`P02okFO`P05o`000?nkXl3o^j?0ok^S`?l000001?o1Y[h01Ol0
003oaJRlolFX_?o5Z;co000000CobJ^k0_l00002olb]^`03o`000?o?[kWocjni00?ocjni00Go0000
om:`]ooB/;Ood[2go`000004omBb]`03o`000?oE/kOoeK>g00?o000000?oe[>fo`000?l000000_l0
0002omNe]`04o`000?oG];KoekBfomNd]P;o00000ooG]KL01Ol0003oekNhomNg^?oG]kSo000000Co
eKBi00Go0000omFf^_oE][[oeKJjo`000003omBg_005o`000?oC^;kodkRnom>h__l000000ooC^L00
1Ol0003od[[3o`000?o8[[oo000000?oaZg100Go0000ol>/`oo3[<?o`jc3o`000003ol2[a@05o`00
0?nlZ/Oo_:[7okbZaol000001?niZLT00ol0003o]ZW<okJYc002okJYc003o`000?nbZ<ko/ZS>00;o
/ZS>00?o0000ojjXdOn^Z=400_n^Z=401_l0003oZZODojZWe?l0003oUY;=o`0000GoTY7?00?o0000
ohnAdOn?TM400on?TM400ol0003oS9;DohbBe003ohbBe003o`000?oooooooooo01Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`008oooool2o`0004Gooooo0_l008D01Ol0
08[o3T[7o`000?lKD<Wo000000?o:eW<00Co0000ociScolnHloo00000omAKM401?l0003oI7SAofAh
dOmTN=42ogJ1d@;o000000?oUXk9o`000?nNT/L00onNT/L01Ol0003oYiO5ojNGaOnWUlGo000000Go
[Y_400?o0000okFO`_neWl800_neWl801Ol0003o^j?0ok^S`?nkXl3o000000?o`JJn00?o0000olFX
_?o5Z;`00_o5Z;`01?l0003obJ^kolV[^oo9Zk/2o`0000?oc:fk00?o0000oln_^Oo?[kT00oo?[kT0
1_l0003od[2gom:`]ol0003od[6ho`0000;oe;:g00Go0000omFc]ooE/kOoeK>go`000002omJd]`;o
00000_oF];L01?l0003oekFgomNe]ol00002omNd]P03o`000?oH][So000000?oekFg00Go0000omNg
^?oG]kSoekNho`000004omFd^@04o`000?oE][[oeKJjo`0000?oe;Nl00Go0000om>h__oC^;kodkRn
o`000003om>i`004o`000?oB^/?od[[3om:j``;o00000_o6[L401Ol0003o`jc3ol>/`oo3[<?o0000
00Co`:_500Co0000okbZaonlZ/Oo00001?niZLT00ol0003o]ZW<okJYc002okJYc003o`000?nbZ<ko
/ZS>00;o/ZS>00?o0000ojjXdOn^Z=400_n^Z=401?l0003oZZODojZWe?nZYm@3o`0000GoTY7?00?o
0000ohnAdOn?TM400_n?TM400ol0003oS9;DohbBe003ohbBe003o`000?oooooooooo01Gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`009Oooool00ol0003oooooooooo`13
ooooo`;o002500Go002:o`000?lKD<Wo6e39o`000002ob]Ic005o`000?lnHloo?V??ociScol00000
0omAKM43ofAhd@04o`000?mfPM7oMX7AogJ1d@;o00001?nNT/L01Ol0003oYiO5ojNGaOnWUlGo0000
00Co[Y_400?o0000okFO`_neWl800_neWl800ol0003o^j?0ok^S`002ok^S`005o`000?o1Y[ko`JJn
ol6V__l000001?o5Z;`4o`000003olN[_Ol0003oc:fk00;oc:fk00?o0000oln_^Oo?[kT00oo?[kT0
0ol0003od[2go`000002om:a^003o`000?oD/[Oo000000?oeK>g00Go0000omJd]ooF];Ooe[Bgo`00
0003omJd]`06o`000?oG]KOoekFgo`000?oG];Ko00000_oH][P01?l0003oekFgomNe]ol00003omNg
^003o`000?oH^K[o000000;oeKBi00Go0000omFf^_oE][[oeKJjo`000003omBg_005o`000?oC^;ko
dkRnom>h__l000000_oC^L000ol0003od[[3om:j``02om:j``05o`000?o@_<Ko0000olJ]`Ol00000
0oo3[<<01Ol0003o`:_5ol2[aOo0ZlGo000000?o_:[700Go0000okVYbOniZLWo^JW9o`000004okJY
c003o`000?nbZ<ko/ZS>00;o/ZS>00?o0000ojjXdOn^Z=400_n^Z=401Ol0003oZZODojZWe?nZYmCo
000000?oYZOG00Go0000oi:AconBTLooTY7?o`000004ohnAd@03o`000?n<T]CoS9;D00?oS9;D00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo000V
ooooo`03o`000?oooooooooo04?ooooo00Ko0025o`000?l02YCo0000oa]@bOl00002ob]Ic005o`00
0?lnHloo?V??ociScol000000omAKM401?l0003oI7SAofAhdOl00004ogJ1d@Co000000?oWY;7o`00
0?nWUlD00_nWUlD00ol0003o[Y_4ojjKa002ojjKa003o`000?neWl;o]Io200;o]Io200Go0000ok^S
`?nkXl3o^j?0o`000004ol6V_P03o`000?o5Z;coaJRl00?o00001?o7Zkd01Ol0003oc:fkolb]^oo<
[K_o000000Gocjni0_l00003om:a^003o`000?oD/[Oo000000?oeK>g00Go0000omJd]ooF];Ooe[Bg
o`000002omJd]`04o`000?oG]KOoekFgomNe]`;o00001?oH][P00ol0003oekFgo`000002omNg^007
o`000?oH^K[of;VjomRi^_l0003oeKBio`000002omFf^P05o`000?oD]kcoe;NlomBg_?l000000ooC
^;h01Ol0003odkW0om>i`?oC^L3o000000?od[[300Co0000om2la_o@_<Kod;c60_l00002ol>/``05
o`000?o0ZlGo`:_5ol2[aOl000000onlZ/L00ol0003o^JW9okVYb@02okVYb@05o`000?nfZLco]ZW<
okJYc?l000001?nbZ<h00ol0003o[ZSAojjXd@02ojjXd@05o`000?nZYmCoZZODojZWe?l000001OnV
YmL00ol0003oTY7?o`000004ohnAd@03o`000?n<T]CoS9;D00?oS9;D00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooo
oooo04?ooooo00?o0025o`000?l02Y@00_l00003ob]Ic004o`000?lnHloo?V??o`0000?oDFgA00Co
0000ofAhdOmTN=7oI7SA1?mfPM44ohJ:d0Co000000?oYiO5o`000?n^Vl@00on^Vl@00ol0003o]Io2
okFO`P02okFO`P05o`000?nkXl3o^j?0ok^S`?l000000oo1Y[h4o`0000;o`ZW000?o0000olN[_Oo7
Zkd00_o7Zkd00ol0003oc:fkolb]^`02olb]^`04o`000?o?[kWocjnioln_^@;o00001OoB/KP01Ol0
003oeK>gomFc]ooE/kOo000000?oe[Bg00Go0000omJd]ooF];Ooe[Bgo`000002omNe]`;o00001OoH
][P2o`0000?oekNh00?o0000omRi^_oH^KX00_oH^KX01Ol0003oeKJjomFf^_oE][[o000000?oe;Nl
00Go0000om>h__oC^;kodkRno`000002om>i`005o`000?oB^/?od[[3om:j`ol000001?o@_<H01Ol0
003ockg9o`000?o3[<?o000000?o`:_500Co0000okbZaonlZ/Oo00001?niZLT00ol0003o]ZW<okJY
c002okJYc005o`000?nbZ<ko/ZS>ok:Xc_l000001?n^Z=401Ol0003oZZODojZWe?nZYmCo000000Ko
YZOG0ol00003ohnAd@03o`000?n<T]CoS9;D00?oS9;D00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Xooooo`;o0000A?ooool01Ol008Go002:
o`0:U?lKD<Wo000000;o:eW<00Co0000ociScolnHloo00000omAKM401Ol0003oI7SAofAhdOmTN=7o
000000?oMX7A00?o0000ohJ:d?n6R]000_n6R]03oiBBcPGo000000?o[Y_4o`000?neWl800oneWl80
1?l0003o^j?0ok^S`?nkXl04o`000003okbV`ol0003o`ZW000?o`ZW000?o0000olN[_Oo7Zkd00_o7
Zkd00ol0003oc:fkolb]^`02olb]^`06o`000?o?[kWocjnio`000?o@/K_o00001OoB/KP2o`0000;o
eK>g00Go0000omJd]ooF];Ooe[Bgo`000003omJd]`?o000000?oekNio`000?oH][P01?oH][P01Ol0
003oekNhomNg^?oG]kSo000000Gof;Vj00Co0000omFf^_oE][[o00000ooD]k`01Ol0003odkRnom>h
__oC^;ko000000?odkW000Go0000om:j`ooB^/?od[[3o`000003om2laP04o`000?o?_LWockg9olnm
b@?o000000Go`:_5o`000?nlZ/Oo_:[7o`000004okVYb@03o`000?nfZLco]ZW<00;o]ZW<00Go0000
ok:Xc_nbZ<ko/ZS>o`000004ojjXd@05o`000?nZYmCoZZODojZWe?l000001_nVYmL01ol0003oXjOI
oj>WfOnSYmWo0000ohnAdOl000001On<T]@00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0@_ooool00ol008Go
002:o`0:U002o`000005ob]Ic?l0003o?V??ociScol000000omAKM401Ol0003oI7SAofAhdOmTN=7o
000000?oMX7A00?o0000ohJ:d?n6R]000_n6R]001?l0003oU9;>oiBBc_nDT/h4oj6Hc0_o00001?nl
Y/<00ol0003o`ZW0ol:Y`002ol:Y`003o`000?o7Zkgoaj^m00;oaj^m00?o0000olb]^oo<[K/00_o<
[K/00ol0003ocjnio`000003om2a^`05o`000?oB/KSod[6hom:a^?l000000_oC/kT00ol0003oeK>g
o`000003omJd]`03o`000?oF];Ooe[Bg00;o00000ooG]kT00ol0003of;JhomRf^002omRf^0;o0000
0_oG]kP00ol0003of;VjomRi^P03omRi^P05o`000?oH^kgo0000omFf^_l000000ooD]k`01?l0003o
dkRnom>h__l00003om>i`005o`000?oB^/?od[[3om:j`ol000000oo@_<H00ol0003ockg9olnmb@02
olnmb@04o`000?o=_lgocKo=o`0000?o_:[700Go0000okVYbOniZLWo^JW9o`000004okJYc003o`00
0?nbZ<ko/ZS>00;o/ZS>00Go0000ojjXdOn^Z=7o[ZSAo`000003ojZWe003o`000?nVYmOoYZOG00Co
YZOG00?o0000oj>WfOnSYmT00_nSYmT3o`0000CoS9;D00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooooooo04;ooooo
00Co0000o`00R_l06J?o01VS0_l00003ociSc`05o`000?mAKM7oDFgAoe5]dOl000000_mTN=400ol0
003oMX7AogJ1d@02ogJ1d@CoQX[@00Go0000oiBBc_nDT/koU9;>o`000004oj6Hc0Go[9k91?neX/H0
0ol0003o_:K3okbV``02okbV``03o`000?o2ZL3o`ZW000;o`ZW000?o0000olN[_Oo7Zkd00oo7Zkd0
1?l0003oc:fkolb]^oo<[K/2o`0000Cod;6k00Co0000om:a^?oB/KSo00001?oC/kT3o`000003omJd
]ol0003oe[Bg00?o00001?oG]kT01ol0003of;JhomRf^?oH][So0000omRi^_l000000_oG]kP00ol0
003of;VjomRi^P02omRi^P05o`000?oH^kgof;^momRk_Ol000000ooD]k`01Ol0003odkRnom>h__oC
^;ko000000;odkW000Go0000om:j`ooB^/?od[[3o`000003om2laP03o`000?o?_LWockg900;ockg9
00Co0000olfocOo=_lgocKo=0_l000000onlZ/Oo0000okVYb@03okVYb@05o`000?nfZLco]ZW<okJY
c?l000001?nbZ<h01Ol0003o[ZSAojjXdOn^Z=7o000000?oZZOD00?o0000ojJWeonVYmL00onVYmL2
o`0000CoXjOI00Co0000oinXg?nOZ=coWjSL0_l000000on<T]Co0000ooooo`0Qooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@Oooool0
0ol008Go0000o`0:U002o`0IX`05ob]Ic?l0003o?V??ociScol000000omAKM401?l0003oI7SAofAh
dOl00004ogJ1d@05o`000?n6R]3oQX[@ohJ:d?l000000onDT/h00ol0003oXIS<oj6Hc002oj6Hc003
o`000?n/W/Wo[9k900;o[9k900Go0000okFRa_neX/Ko]J;6o`000004okbV``03o`000?o2ZL3o`ZW0
00;o`ZW000?o0000olN[_Oo7Zkd00oo7Zkd01Ol0003oc:fkolb]^oo<[K_o000000God;6k00Co0000
om:a^?oB/KSo00001?oC/kT00ol0003oeKFjomFe^P03o`0000;oe[Jj00?o0000omNg^OoG]kT00_oG
]kT01?l0003of;JhomRf^?l00003omRi^P;o00001?oH^KX00ol0003of;^momRk_@02omRk_@04o`00
0?oD]kcoe;Nlo`0000?odkRn00Go0000om>i`?oC^L3odkW0o`000003om:j``05o`000?o@_<Kod;c6
om2la_l000000oo?_LT01Ol0003ocKo=olfocOo=_lgo000000;obl7@0_l00003okVYb@05o`000?nf
ZLco]ZW<okJYc?l000001?nbZ<h01Ol0003o[ZSAojjXdOn^Z=7o000000?oZZOD00?o0000ojJWeonV
YmL00onVYmL00ol0003oXjOIoj>Wf@02oj>Wf@;o00001OnOZ=`2o`0002?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`00;Oooool2o`0004;ooooo00?o0025o`000?l02Y@0
0_l06J<2o`000003ociScol0003oDFgA00;oDFgA00Co0000ofAhdOmTN=7o00001?mfPM400ol0003o
QX[@ohJ:d002ohJ:d004o`000?nDT/koU9;>o`0000CoXIS<00?o0000ojbNbOn/W/T00_n/W/T01Ol0
003o]J;6okFRa_neX/Ko000000Co_:K300?o0000ol:Y`?o2ZL000_o2ZL000ol0003oaj^molN[_@03
olN[_@03o`000?o<[K_oc:fk00;o00001_o@/K/2o`0000Codk>i00?o0000omFe^_oE]KX00_oE]KX0
1Ol0003oe[JjomJf^_oF][[o000000CoekNi00?o0000omRf^?l000001?oH^KX00ol0003of;VjomRi
^P02omRi^P03o`000?oH^kgof;^m00;of;^m00Go0000omRn_ol0003oe;Nlo`000003om>h_P04o`00
0?oC^L3odkW0o`0000?od[[300Go0000om2la_o@_<Kod;c6o`000003olnmb@05o`000?o=_lgocKo=
olfocOl000000oo;`M001Ol0003ob<;Do`000?niZLWo000000?o]ZW<00?o0000ok:Xc_nbZ<h00_nb
Z<h01Ol0003o[ZSAojjXdOn^Z=7o000000?oZZOD00?o0000ojJWeonVYmL00onVYmL00ol0003oXjOI
oj>Wf@02oj>Wf@03o`000?nOZ=coWjSL00CoWjSL00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo000_ooooo`03o`000?oooooooooo043ooooo00Co
0000o`00R_l02YCo01VS0_l0;KD2o`0000?oDFgA00Go0000ofAhdOmTN=7oI7SAo`000003ogJ1d@03
o`000?n6R]3oQX[@00;oQX[@00Go0000oiBBc_nDT/koU9;>o`000003oj6Hc003o`000?n/W/Wo[9k9
00;o[9k900?o0000okFRa_neX/H00_neX/H01Ol0003o_:K3okbV`onlY/?o000000Go`ZW000?o0000
olN[_Oo7Zkd00_o7Zkd00ol0003oc:fko`000002olb`_P03o`000?o@/K_od;6k00?od;6k00?o0000
om>c^OoC/kT00ooC/kT01Ol0003oeKFjomFe^_oE]K[o000000Coe[Jj00?o0000omNg^OoG]kT00_oG
]kT2o`0000Gof;Vj00?o0000omRi^_oH^KX00_oH^KX01Ol0003of;^momRk_OoH^kgo000000?of;jo
00Go0000om>h__oC^;kodkRno`000002om>i`005o`000?oB^/?od[[3om:j`ol000000oo@_<H01Ol0
003ockg9olnmbOo?_LWo000000?ocKo=00Go0000ol_1d?o;`M3obl7@o`000002olS2e0Co000000?o
]ZW<o`000?nbZ<h00onbZ<h01Ol0003o[ZSAojjXdOn^Z=7o000000?oZZOD00?o0000ojJWeonVYmL0
0_nVYmL2o`0000CoXjOI00?o0000oinXg?nOZ=`00onOZ=`2o`0002Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`10ooooo`04o`000?l0
08[o01VSo`0IX`;o02fe00Go?V??o`000?mAKM7oDFgAo`000003ofAhd@05o`000?mfPM7oMX7AogJ1
dOl000001?n6R]001Ol0003oU9;>oiBBc_nDT/ko000000CoXIS<00Go0000ojbNbOn/W/Wo[9k9o`00
0004okFRaP05o`000?nlY/?o_:K3okbV`ol000001Oo2ZL000ol0003oaj^molN[_@02olN[_@;o0000
0oo</;h00ol0003od;6kom2a^`03om2a^`;o00000ooC/kT00ol0003oeKFjomFe^P02omFe^P05o`00
0?oF][[oe[JjomJf^_l000001?oG]kT2o`0000Gof;Vj0_l00003omRi^P05o`000?oH^kgof;^momRk
_Ol000001?oH_[l01?l0003odkRnom>h__l00003om>i`004o`000?oB^/?od[[3o`0000?od;c600?o
0000olnmbOo?_LT00_o?_LT01?l0003ocKo=olfocOl00003ol_1d004o`000?o8`]Cob<;Do`0000?o
aLCI0ol00003ok:XcP05o`000?n^Z=7o[ZSAojjXdOl000000onZYm@00ol0003oYZOGojJWe`02ojJW
e`03o`000?nSYmWoXjOI00;oXjOI0_l00004oinXg0;o0000:oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Cooooo000aooooo`;o0000@Oooool01?l0003o00ZDo`0IXol06J<2o`0]
]@;o000000?oDFgAo`000?mTN=400_mTN=400ol0003oMX7AogJ1d@02ogJ1d@05o`000?n6R]3oQX[@
ohJ:d?l000000onDT/h00ol0003oXIS<oj6Hc002oj6Hc005o`000?n/W/Wo[9k9ojbNbOl000001?ne
X/H00ol0003o_:K3okbV``02okbV``03o`000?o2ZL3o`ZW000;o`ZW000Co0000olN[_Oo7Zkgoaj^m
0_l00004olb`_P03o`000?o@/K_od;6k00;od;6k00Co0000om6c_?oA/kco00000_oC/kT00ol0003o
eKFjomFe^P02omFe^P05o`000?oF][[oe[JjomJf^_l000000_oG]kT2o`000003omRj_?l0003of;Vj
00?of;Vj00Ko0000omVl_OoI_;go0000omRi^_l00003omRk_@03o`000?oH_[oof;jo00;of;jo00Go
0000omW1`ol0003odkRno`000002om>i`005o`000?oB^/?od[[3om:j`ol000000oo@_<H01Ol0003o
ckg9olnmbOo?_LWo000000;ocKo=00Go0000ol_1d?o;`M3obl7@o`000002olS2e005o`000?o5a=Wo
aLCIolG4fOl000000oo1aMd00ol0003o/ZS>o`000003ojjXd@05o`000?nZYmCoZZODojZWe?l00000
1?nVYmL00ol0003oXjOIoj>Wf@02oj>Wf@03o`000?nOZ=coWjSL00?oWjSL00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000cooooo`03o`000?oo
oooooooo03oooooo00Go0000o`0:U?l06J?o0000o`0]]@02o`14aP03o`000?mAKM7o000000;oI7SA
00?o0000ogJ1dOmfPM400_mfPM401Ol0003oQX[@ohJ:d?n6R]3o000000?oU9;>00?o0000oj6Hc?nQ
V<`00_nQV<`01Ol0003o[9k9ojbNbOn/W/Wo000000Co]J;600?o0000okbV`onlY/<00_nlY/<00ol0
003o`ZW0ol:Y`002ol:Y`006o`000?o7Zkgo0000o`000?o8[l7o00001Oo</;h01?l0003od;6kom2a
^ol00004om6c_003o`000?oC/kWo000000?oeKFj00?o0000omJf^_oF][X00_oF][X3o`0000?of;Zl
00Go0000omRi^_oH^K[of;Vjo`000003omVl_@;o00000ooH^kd00ol0003of;joomRn_`02omRn_`05
o`000?oI`L?ofL73omW1`ol000000ooC^L001?l0003od[[3om:j`ol00003om2laP05o`000?o?_LWo
ckg9olnmbOl000000_o=_ld01Ol0003obl7@ol_1d?o;`M3o000000;ob<;D00Go0000olG4fOo5a=Wo
aLCIo`000004ol75g@Co000000?o[ZSAo`000?nZYm@00_nZYm@00ol0003oYZOGojJWe`02ojJWe`04
o`000?nSYmWoXjOIoj>Wf@;o00001?nOZ=`2o`0002oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`03ooooo`00=?ooool00ol0003oooooooooo`10ooooo`;o01VS0_l0;KD2o`14aP05
oe5]dOl0003oI7SAofAhdOl000001?mfPM401Ol0003oQX[@ohJ:d?n6R]3o000000?oU9;>00?o0000
oj6Hc?nQV<`00_nQV<`00ol0003o[9k9ojbNb@02ojbNb@05o`000?neX/Ko]J;6okFRa_l000001?nl
Y/<00ol0003o`ZW0ol:Y`002ol:Y`0;o00001?o8[l400ol0003oc;2nolb`_P02olb`_P04o`000?o@
/K_od;6ko`0000GodK>l0_l00003omFe^P04o`000?oF][[oe[JjomJf^P;o00001OoH^[`01?l0003o
f;VjomRi^_l00004omVl_@03o`000?oH^kgof;^m00;of;^m00Go0000omRn_ooH_[oof;joo`000004
omW1``;o000000GodkW0o`000?oB^/?od[[3o`000003om2laP05o`000?o?_LWockg9olnmbOl00000
0_o=_ld01Ol0003obl7@ol_1d?o;`M3o000000;ob<;D00Go0000olG4fOo5a=WoaLCIo`000004ol75
g@04o`000?nma^7o_LKQokg6h@;o00000onZYm@01?l0003oYZOGojJWeonVYmL2o`0000?oXjOI00?o
0000oinXg?nOZ=`00onOZ=`00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0@?ooool01?l06J?o0000o`0]]Ol0
;KD2o`14aP;o000000?oI7SAo`000?mfPM400omfPM401Ol0003oQX[@ohJ:d?n6R]3o000000?oU9;>
00?o0000oj6Hc?nQV<`00_nQV<`00ol0003o[9k9ojbNb@02ojbNb@05o`000?neX/Ko]J;6okFRa_l0
00001?nlY/<01?l0003o`ZW0ol:Y`?o2ZL02o`0000Gob:o100?o0000olb`__o</;h00_o</;h00ol0
003od;6ko`000006om6c_005o`000?oC]kgo0000o`000?oE]KX01?l000000ooF^Kgo0000omRj_004
omRj_003o`000?oH^K[o000000CofKbm0_l00003omRk_@05o`000?oH_[oof;joomRn_ol000001?oI
`L<01?l0003ofLG6omW5a_l00003om:j``04o`000?o@_<Kod;c6o`0000?ockg900Go0000olfocOo=
_lgocKo=o`000002ol_1d004o`000?o8`]Cob<;Do`0000?oaLCI00?o0000ol75gOo1aMd00_o1aMd0
1Ol0003o_LKQokg6hOnma^7o000000;o^<OU00?o0000ojZWe?l000000onVYmL00ol0003oXjOIoj>W
f@02oj>Wf@03o`000?nOZ=coWjSL00;oWjSL0_l0000dooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00oooool003Kooooo0_l00011ooooo`05o`0IXol0003o02feo`000?l0A<H00_lG
G=@00ol0003oI7SAo`000003ogJ1d@05o`000?n6R]3oQX[@ohJ:d?l000000onDT/h00ol0003oXIS<
oj6Hc002oj6Hc003o`000?n/W/Wo[9k900;o[9k900Go0000okFRa_neX/Ko]J;6o`000004okbV``06
o`000?o2ZL3o0000o`000?o2[LGo00001Oo8[l400ol0003oc;2nolb`_P03olb`_P03o`000?oA/kco
dK>l00CodK>l00?o0000om>g_OoC]kd00_oC]kd2o`0000Coe[Vm00?o0000omRj_?oH^[`00ooH^[`2
o`0000CofKbm00?o0000omW0`?l000000_oH^kd01Ol0003of;joomRn_ooH_[oo000000CofL7300Co
0000omW5a_oIaLKofLG60_l000000ooB^/?o0000om2laP02om2laP04o`000?o?_LWockg9o`0000?o
cKo=00Co0000ol_1d?o;`M3o00000_o8`]@00ol0003oaLCIolG4f@02o`0000?o`LGM0_l00002okg6
h@;o00000onhanD4o`000003ojJWeol0003oXjOI00;oXjOI0_l00004oinXg003o`000?oooooooooo
03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003o
ooooooooo`0nooooo`04o`0:U?l06J?o02feo`0]]@;o04C60_lGG=@00omTN=7o0000ogJ1d@02ogJ1
d@05o`000?n6R]3oQX[@ohJ:d?l000000onDT/h00ol0003oXIS<oj6Hc002oj6Hc003o`000?n/W/Wo
[9k900;o[9k900?o0000okFRa_neX/H00_neX/H01?l0003o_:K3okbV`onlY/<2o`0000Co`Zg500?o
0000olR_`Oo8[l400oo8[l400ol0003oc;2nolb`_P02olb`_P03o`000?oA/kcodK>l00CodK>l00?o
0000om>g_OoC]kd00_oC]kd00ol0003oe[VmomJi_@03omJi_@03o`000?oH^[cof;Zl00;of;Zl0_l0
0004omVl_@04o`000?oI`<3ofL30omW0`0;o00001?oH_[l01Ol0003ofL73omW1`ooI`L?o000000?o
fLG600Co0000omW:booIb/_o00000oo@_<H01Ol0003ockg9olnmbOo?_LWo000000;ocKo=00Co0000
ol_1d?o;`M3o00000_o8`]@01?l0003oaLCIolG4fOl00004ol75g@03o`000?nma^7o_LKQ00;o0000
0onhanD2o`0000?o/lOY1?l000000onSYmWo0000oinXg003oinXg0;o0000>?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo03kooooo00Co
01VSo`000?l0;KGo00000_l0A<H2oaMLe0;o00000omfPM401Ol0003oQX[@ohJ:d?n6R]3o000000;o
U9;>00?o0000oj6Hc?nQV<`00_nQV<`00ol0003o[9k9ojbNb@02ojbNb@03o`000?neX/Ko]J;600;o
]J;600?o0000okbV`onlY/<00_l00005ol:]a@03o`000?o8[l7ob:o100?ob:o100Oo0000olb`__o<
/;koc;2no`000?o>]<3o000000CodK>l00?o0000om>g_OoC]kd00_oC]kd00ol0003oe[VmomJi_@03
omJi_@04o`000?oH^[cof;ZlomRj_0;o000000?of;foo`000?oI_;d00_oI_;d00ol0003ofL30omW0
`002omW0`003o`000?oH_[oof;jo00;of;jo00Go0000omW1`ooI`L?ofL73o`000003omW5aP08o`00
0?oIb/_ofL[;o`000?oHcm3o0000om2la_l00003olnmb@04o`000?o=_lgocKo=o`0000;obl7@00Co
0000olS2e?o8`]Co00000_o5a=T01?l0003o`LGMol75gOo1aMd2o`0000;o_LKQ00?o0000okS7iOnh
anD00_nhanD01?l0003o/lOYok?7jOncanT2o`0000?o[LO]0_l00003oinXg0;o0000>oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo03ko
oooo00Go01VSo`000?l0;KGo0000o`14aP02oaMLe0;o?W?L0_l000000omfPM7o0000ohJ:d002ohJ:
d005o`000?nDT/koU9;>oiBBc_l000001?nQV<`01Ol0003o[9k9ojbNbOn/W/Wo000000Co]J;60ol0
00000onkZl[o0000ol:]a@04ol:]a@03o`000?o8[l7ob:o100?ob:o100Co0000olb`__o</;ko0000
0oo>]<001?l0003odK>lom6c_?l00005om>g_@03o`000?oF^Kgoe[Vm00?oe[Vm00Co0000omRj_?oH
^[co00000ooH_Kl01?l0003ofKbmomVl_Ol00004omW0`0;o00000ooH_[l01Ol0003ofL73omW1`ooI
`L?o000000?ofLG600Co0000omW:booIb/_o00000_oHcm02o`0000?ockg900Co0000olfocOo=_lgo
00000_o;`M001?l0003ob<;DolS2e?l00002olG4f@05o`000?o1aMgo`LGMol75gOl000000_nma^42
o`0000?o^<OU0_l00002ok?7j@;o00000on]and2o`0000;oYlO`00?o0000oinXg?l00000?_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000kooooo`;o0000?oooool00ol0
003o02feo`0]]@02o`14aP;o5ecD1?lnLm`3o`000003ohJ:d?l0003oU9;>00;oU9;>00?o0000oj6H
c?nQV<`00_nQV<`01Ol0003o[9k9ojbNbOn/W/Wo000000;o]J;60ol00004ok^[bP03o`000?o2[LGo
`Zg500?o`Zg500?o0000olR_`Oo8[l400oo8[l42o`0000Goc[C000?o0000om6c_?l000001OoC]kd0
0ol0003oe[VmomJi_@03omJi_@03o`000?oH^[co000000Cof;fo00?o0000omVl_Ol000001?oI`<00
0ol0003of/G4o`000002omRn_`05o`000?oI`L?ofL73omW1`ol000000ooIaLH01?l0003ofL[;omW:
bol00002omS?d006o`000?oGe=GoemCEo`000?o?_LWo00000_o=_ld01?l0003obl7@ol_1d?l00002
olS2e004o`000?o5a=Wo0000o`0000?o`LGM00Co0000okg6hOnma^7o00000onhanD2o`0000;o/lOY
0_l00002ojg7k@?o00001?nWao02o`0003oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`02ooooo`00?Oooool00ol0003oooooooooo`0looooo`08o`0IXol0003o02feo`000?l0A<Ko
0000oaMLe?l00003ocicg0?oH8GO1?l000000onDT/ko0000oj6Hc003oj6Hc003o`000?n/W/Wo0000
00Co00000_naZ<l00ol0003o^j_:ok^[bP02ok^[bP03o`000?o2[LGo`Zg500?o`Zg500?o0000olR_
`Oo8[l400oo8[l400ol0003oc[C0oljd`005oljd`0Co00000_oC]kd01?l0003oe[VmomJi_OoF^Kd4
o`0000Kof;fo0_l00004omW0`004o`000?oJaLCof/G4om[5a0;o00000ooI`L<01Ol0003ofLG6omW5
a_oIaLKo000000;ofL[;00Co0000omS?d?oHcm3o00000ooGe=D3o`000005olfocOl0003obl7@ol_1
d?l000000_o8`]@00ol0003oaLCIo`000003ol75g@;o000000?o_LKQo`000?l000000_nhanD2o`00
00;o/lOY0_l00002ojg7k@;o00001?nWao03o`0004;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`00?_ooool00ol0003oooooooooo`0looooo`08o`0IXol0003o02feo`00
0?l0A<Ko0000oaMLe?l00003ocicg0?oH8GO0omlTmh8o`0000;oY:?E1_naZ<l00ol0003o^j_:ok^[
bP02ok^[bP03o`000?o2[LGo`Zg500?o`Zg500Oo0000olR_`Oo8[l7ob:o1o`000?o;]LGo000000Ko
c[C000Co0000om:i`_oB^L;od[W21_l00003omFl`@03o`000?oH_Koof;fo00?of;fo0_l00004omW0
`004o`000?oJaLCof/G4om[5a0;o00000ooI`L<01Ol0003ofLG6omW5a_oIaLKo000000;ofL[;00Co
0000omS?d?oHcm3o00000ooGe=D00ol0003oeM[KomGJf`03o`000007ol_1d?l0003ob<;DolS2e?l0
003oaLCIo`000003ol75g@04o`000?nma^7o_LKQo`0000?o^<OU00?o0000ok?7jOncanT00_l00002
ojg7k@;o00000onWao03o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`00?oooool00ol0003oooooooooo`0looooo`03o`000?l0;KGo000000;o04C60_lGG=@3ocic
g004o`000?mPQMooH8GOof25g`?oO9?N1OnCW=X5ojBSe@Go/JS?00?o0000ok^[b_nkZlX00_nkZlX0
0ol0003o`Zg5ol:]a@03ol:]a@04o`000?o8[l7ob:o1o`0000?obkG500?o0000oljd`?o>]<000_o>
]<000ol0003od[W2om:i`P04om:i`P03o`000?oE_<7oeKc100?oeKc100?o0000omRm_ooH_Kl00_oH
_Kl2o`000003omS2a?l0003ofL3000;ofL3000Oo0000om[5a?oJaLCof/G4o`000?oKblWo000000;o
fL7300Go0000omW5a_oIaLKofLG6o`000002omW:b`04o`000?oHcm3of<o@o`0000?oemCE00Co0000
omGJfooEf]_o00000_oBh>83o`000004olS2e?l0003oaLCIo`0000;o`LGM0_l000000onma^7o0000
o`000002okS7i@;o000000?o/lOYo`000?l000000_n]and2o`0000;oYlO`0ol0001:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool0043ooooo0_l0000mooooo`07o`000?l0
;KGo0000o`14a_l0003o5ecDo`000003ocicg004o`000?mPQMooH8GOo`0000?oO9?N1OnCW=X4ojBS
e@03o`000?naZ<oo/JS?00;o/JS?00?o0000ok^[b_nkZlX00onkZlX00ol0003o`Zg5ol:]a@02ol:]
a@03o`000?o8[l7o000000GobkG500Co0000oljd`?o>]<3o00001_oB^L800ol0003oeKc1omFl`@04
omFl`@03o`000?oH_Koof;fo00;o00000ooH`/@01?l0003ofL30omW0`?l00003om[5a004o`000?oK
blWofl_9om_;b@;o00000ooIaLH01?l0003ofL[;omW:bol00002omS?d005o`000?oGe=GoemCEomOD
eOl000000_oEf]/01?l0003od^3Rom;Ph_l00002olgUj0;o000000KoaLCIo`000?o1aMgo`LGMo`00
0?nma^42o`0000;o^<OU0_l000000oncanWo0000o`000002ojg7k@;o00000_nWao02o`0004gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@_ooool00ol0003ooooooooo
o`0looooo`06o`0]]Ol0003o04C6o`000?lGG=Co00000_lnLm`01Ol0003oH8GOof25gomPQMoo0000
00;oO9?N00?o0000oi>Lf_nCW=X00_nCW=X00ol0003oY:?EojBSe@02ojBSe@03o`000?naZ<oo/JS?
00;o/JS?00?o0000ok^[b_nkZlX00_nkZlX00ol0003o`Zg5ol:]a@03ol:]a@03o`000?o;]LGobkG5
00GobkG500?o0000oljd`?l000001_oB^L800ol0003oeKc1omFl`@04omFl`@03o`000?oH_Koo0000
00Gof<;400?o0000omW0`?l000000ooJaL@01?l0003ofl_9om_;bOoKblT2o`0000?ofLG600Co0000
omW:booIb/_o00000_oHcm001Ol0003oemCEomODeOoGe=Go000000;oeM[K00Co0000om;Ph_l0003o
00000_o=iNP00ol0003oa^[_o`000002o`000004ol75gOl0003o_LKQo`0000?o^<OU00Go0000ok?7
jOl0003o0000ojg7k@03o`000004ojO7l?l0003o0000o`00053ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`0looooo`05o`000?l0A<Ko
0000oaMLe?l000000olnLm`01?l0003oH8GOof25gol00003ogbCgP03o`000?nCW=[oTicJ00;oTicJ
00Go0000ojBSeOnTXmGoY:?Eo`000004ok6Xc`03o`000?nkZl[o^j_:00;o^j_:00?o0000ol:]aOo2
[LD00_o2[LD00ol0003oaKK;o`000007ol^ea@?o00001OoB^L800ol0003oeKc1omFl`@03omFl`@03
o`000?oH_Koo000000Kof<;400Co0000omW0`?oJaLCof/G40_l00003om_;b@03o`000?oKd]3o0000
00;ofLG600Co0000omW:booIb/_o00000_oHcm001_l0003oemCEomODeOoGe=Go0000omGJf`;o0000
00Cod^3Ro`000?o=iNSocNGX0_l000001?o6j^oo0000okc]m?nlkO@5o`000003okS7iOl0003o0000
00;o000000Co[LO]o`000?l0003oYlO`0ol0001Dooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00Oooool004Cooooo00?o0000ooooooooool0??ooool01Ol0003o04C6o`000?lGG=Co
000000;o?W?L00Go0000of25gomPQMooH8GOo`000002ogbCgP03o`000?nCW=[oTicJ00;oTicJ00?o
0000ojBSeOnTXmD00_nTXmD00ol0003o/JS?ok6Xc`02ok6Xc`03o`000?nkZl[o^j_:00;o^j_:00Co
0000ol:]aOo2[LGo00000oo5]//00ol0003obkG5ol^ea@04ol^ea@03o`000?o?_<Oockc700?o0000
00?od[W2o`000?oE_<400_oE_<44o`0000Oof<;40_l00002om[5a003o`000?oKblWofl_900;ofl_9
00Ko0000om_Bd?oKd]3ofm;@o`000?oIaLH2omW:b`04o`000?oHcm3of<o@o`0000;oemCE0_l00000
1OoEf]_o0000om;Ph_oBh>;o000000;ocNGX00Go0000olKZkol0003o0000okc]m004o`0000;oX^ci
1?l000000on]ango0000o`000003o`0005Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`01ooooo`00AOooool2o`0003kooooo00?o04C6o`000?l000000olnLm`01?l0003oH8GOof25
gol00003ogbCgP03o`000?nCW=[oTicJ00;oTicJ00Go0000ojBSeOnTXmGoY:?Eo`000004ok6Xc`03
o`000?nkZl[o^j_:00;o^j_:00?o0000ol:]aOl000001Oo5]//00ol0003obkG5ol^ea@02ol^ea@03
o`000?o?_<Oockc700Cockc71Ol00003omC1a`03o`000?oH`/Cof<;400?of<;40_l000001?oHb<[o
0000om[5a?l00004om_;b@04o`000?oKd]3ofm;@om_Bd0;o00000ooIb//2omS?d004o`000?oGe=Go
emCEo`0000;oeM[K00Go0000om;Ph_l0003o0000olgUj004o`000004okc]m?l0003o0000o`0000;o
X^ci1?l000000on6ho[o0000o`000003o`0005_ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`01ooooo`00Aoooool00ol0003oooooooooo`0looooo`03o`000?lGG=Co000000;o?W?L
00Go0000of25gomPQMooH8GOo`000003ogbCgP05o`000?nCW=[oTicJoi>Lf_l000000onTXmD00ol0
003o/JS?ok6Xc`03ok6Xc`04o`000?nkZl[o^j_:ok^[bP;o00001oo5]//01?l0003obkG5ol^eaOl0
0008olnla`03o`000?oD`LOoe<7700Coe<7700Co0000omS2a?oH`/Cof<;40_l00003omS8bP03o`00
0?oJaLCofl_900?ofl_900Oo0000om_Bd?oKd]3ofm;@o`000?oJf]Oo000000;ofL[;0ooHcm03omOD
e@;oeM[K00?o0000om;Ph_l000000_o=iNP01?l0003oa^[_o`000?nlkO@3o`000003oj;/nOl0003o
000000So0000Goooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0018oooo
o`03o`000?oooooooooo03cooooo00?o0000oaMLe?l000000_lnLm`01?l0003oH8GOof25gol00003
ogbCgP05o`000?nCW=[oTicJoi>Lf_l000001?nTXmD00ol0003o/JS?ok6Xc`02ok6Xc`06o`000?nk
Zl[o^j_:o`000?nm]];o00002?o5]//00ol0003obkG5o`000007olnla`03o`000?oD`LOoe<7700Co
e<7700?o0000omS2a?oH`/@00_l00004omS8bP03o`000?oJaLCofl_900;ofl_90_l00003om_Bd003
o`000?oJf]Oof][G00;o00000ooHcm03omODe@;oeM[K0ol000000oo=iNSo0000o`00000=o`0006Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00BOooool00ol0003ooooo
ooooo`0looooo`05oh<00?l0003o?W?Locicg?l000000omPQMl01Ol0003oO9?NogbCg_mlTmko0000
00?oTicJ00Go0000ojBSeOnTXmGoY:?Eo`000004ok6Xc`03o`000?nkZl[o000000?o_KKB00?o0000
olFfboo5]//01_o5]//00ol0003ockc7olnla`06olnla`03o`000?oD`LOoe<7700Coe<7700?o0000
omS2a?l000001OoHb<X2o`0000Cofl_90ooKd]02o`0000;of][G00?o0000omSSgol000000_oHcm03
omODe@;oeM[K0_l00002olgUj0Go000000CoX^cio`000?l0003oQ^?j0_l0001[ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00Oooool004[ooooo0_l0000nooooo`;o000000Go?W?L
o`000?mPQMooH8GOo`000003ogbCgP05o`000?nCW=[oTicJoi>Lf_l000001?nTXmD01?l0003o/JS?
ok6XconaZ<l2o`0000Go_KKB00?o0000olFfboo5]//01Oo5]//00ol0003oc;o?o`000002o`0000?o
ckc700?o0000omC1aooD`LL00ooD`LL3o`0000Gof<S:0_l000000ooHd=7o0000om_;b@02om_;b@?o
fm;@00?o0000om[JeooJf]L00_l00002omSSg`;o00000ooGe=D2omGJf`03om;Ph_l0003ocNGX00Go
000000?oX^cio`000?n6hoX00_l0001^ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00Oooool004cooooo00?o0000ooooooooool0??ooool00ol0;:?o0000o`000003of25g`05o`00
0?mlTmkoO9?NogbCg_l000000onCW=X01_l0003oY:?EojBSeOnTXmGo0000ok6Xc`;o00000_nb]M/0
0ol0003o_KKBokffdP03okffdP03o`000?o5]/_oaKK;00?oaKK;00?o0000olbocoo<_ll00oo<_ll2
o`000003olnlaol0003o000000Co00000_oCa/h00ol0003of<S:omS8bP02omS8bP05o`000?oHd=7o
f=3AomS@dOl000000_oKblT3om_Bd004o`000?oJf]Oof][Go`0000?of>?O00?o0000om;]iol00000
0_oGe=D2omGJf`03om;Ph_l0003ocNGX00Co000000?oX^ciohKSn_l00000Loooool00ol0003ooooo
ooooo`08ooooo`7o00000Oooool1ooooo`00COooool00ol0003oooooooooo`0looooo`03o`0/Xol0
F<go000000?o00000omlTmh01Ol0003oTicJoi>Lf_nCW=[o000000;oY:?E0ol00005ok:ef`03o`00
0?nm]];o_KKB00?o_KKB00Go0000olFfboo5]/_oaKK;o`000008olboc`;o00001ooCa/h00ol0003o
f<S:omS8bP02o`0000Cof=3A00?o0000om_;bOoKd]000_oKd]001?l0003of][Gom[Jeol00002omSS
g`;o00000_oBkNL2o`0000;oeM[K00?od^3RolgUj?l000000ol000000on6ho[oooooooooo`1foooo
o`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001>ooooo`03o`000?oooooooooo03co
oooo00Co0000o`1HcOl0F<go9H7Y2ol00003oj6ci@03o`000?nb]M_o/[GK00?o/[GK00?o0000okff
d_nm]]800onm]]800ol0003oaKK;o`000009olboc`03o`000?oCa/kodlK>00GodlK>00Co0000omS8
b_oHb<[o00001OoHd=42o`0000?ofm;@00Co0000om[Jeol0003o00000_oHhml00ol0003od^gWom;]
i`02o`000005olKekOl0003o0000o`000?o=iNP00ol0001kooooo`03o`000?oooooooooo00Oooooo
0Ol00001ooooo`7ooooo001?ooooo`;o0000?Oooool00on3003o0000o`1Hc@03obF1j@?oGYgb00Go
0000ohJ/k_n6[>koQZc^o`000004oj6ci@03o`000?nb]M_o/[GK00?o/[GK00?o0000okffd_nm]]80
0onm]]800ol0003oc;o?olboc`07olboc`03o`000?oCa/kodlK>00KodlK>00?o0000omS8b_oHd=40
1?oHd=42o`000004omKIfol0003ofm;@om_Bd0;of][G00?o0000omSSgooHhml00_l00002om;]i`03
o`000?o6mNgo000000;o000000CoT>oUo`000?l0003o0000O_ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool1ooooo`00DOooool00ol0003oooooooooo`0looooo`03o`000?l0F<go000000;o
9H7Y0omNWO801Ol0003oQZc^ohJ/k_n6[>ko000000CoXK?U00?o0000ok:efonb]M/00onb]M/01Ol0
003o_KKBokffd_nm]];o000000?oaL?H1Ol00002olboc`04o`000?oCa/kodlK>om?6cPKo00001?oH
d=42o`0000?oe]WK00Go0000om_Bd?oJf]Oof][Go`000002omSSg`03o`000?oBkNOod^gW00Wo0000
POooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00D_ooool00ol0003ooooooooo
o`0looooo`03o`0/Xol0003o000000;o9H7Y00Co0000oejMl_mNWO;o00000on6[>h00ol0003oXK?U
oj6ci@02oj6ci@03o`000?nb]M_o/[GK00?o/[GK00?o0000okffd_l000002Oo5`mP6o`0000God<kH
00Go0000omS@dOoHd=7of=3Ao`000004omKIf`;o00000_oJf]L2omSSg`;o000000?od^gWo`000?l0
00001_l00025ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Cooooo`;o0000
?Oooool2o`000004o`1HcOlUPNWo9H7Yo`0000;oGYgb00Go0000ohJ/k_n6[>koQZc^o`000004oj6c
i@03o`000?nb]M_o/[GK00?o/[GK00?o0000olG3f?o5`mP02Oo5`mP00ol0003od<kHom3>f007om3>
f004o`000?oHd=7o0000o`0000?oe]WK0_l000000oo@iNKo0000om[Je`02omSSg`05o`000?oBkNOo
0000o`000?o6mNd01?l00028ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001E
ooooo`03o`000?oooooooooo03_ooooo0_l000001?l0F<go0000obF1jOl00002oejMlP05o`000?n6
[>koQZc^ohJ/k_l000001?nQ/nD01Ol0003o/[GKok:efonb]M_o000000?o^lST0ol00005olG3f003
o`000?o@c]Sod<kH00Ood<kH00?o0000omS@dOl000000ooFfM/2o`0000;od>GV0_l00002omSSg`04
o`000?oBkNOo0000olKek@?o0000S?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool005Ko
oooo00?o0000ooooooooool0??ooool01Ol0003o05S=o`000?lUPNWo000000;oGYgb00Go0000ohJ/
k_n6[>koQZc^o`000004oj6ci@03o`000?nb]M_o000000Oo^lST0ol00002olG3f003o`000?o@c]So
d<kH00;od<kH1_l00002omKIf`?o000000Wod>GVo`000?l0003o0000olC_l?l0003of>?Oom;]iol0
00000_o6mNd00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
Eoooool00ol0003oooooooooo`0looooo`?o000000Go9H7Yo`000?mNWO;oGYgbo`000003ohJ/kP03
o`000?nQ/nGoXK?U00?o00002onkb>@7o`0000GobMOT00?o0000omKIfol000000_o@iNH2o`0000?o
a>o`0_l000001?oBkNOo0000olKekOl0002Cooooo`03o`000?oooooooooo00;ooooo0Ol00001oooo
o`00F?ooool2o`0003kooooo00CoEP00o`000?l0003o00000_mNWO800ol0003oQZc^ohJ/kP03o`00
00GoZ<_b0ol00006ok_8i003o`000?o9enCobMOT00SobMOT0_l00002om3UiP;o00000_o4ko05o`00
0003olKekOl0003ooooo09Cooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03
o`000?oooooooooo03kooooo1_l00004ohK8o@;o00001OnXbo83o`0000;o^lST00?o0000olWGi?o9
en@00_o9en@7o`0000;od>GV0_l000000oo4ko3o0000o`000006o`0009Sooooo00Go0000oooooooo
ooooooooo`000001ooooo`00Foooool00ol0003oooooooooo`10ooooo`05o`000?m9/oSoBK?hodVc
n?l000001On6b?d3o`0000CoZ<_b0_l000000oo9enCo0000o`000002o`0000Ko_>3b00?o0000om3U
i_o4ko002?l0002Looooo`04o`000?ooooooooooo`00007ooooo001Looooo`03o`000?oooooooooo
04;ooooo0_l00002odVcn0?o00000on6b?d3o`000003ojS;l_l0003o_>3b00Co_>3b1ol000001?o4
ko3o0000o`000?nXlo<3o`000:7ooooo00?o0000ooooool000000Oooool005gooooo0_l00014oooo
o`Co000000CoBK?ho`000?l0003o00000on6b?d00ol0003o_>3bo`000004o`0000;oWnCl1Ol00000
0onXlo?o0000ooooo`2Uooooo`03o`000?oooooooooo007o0000001Oooooo`03o`000?oooooooooo
047ooooo00Co0000oooooooooooooooo0ol000000om9/oSo0000o`000003oioTo0?o00000omTe?<5
o`000:[ooooo0Ol00001ooooo`7o0000001Pooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool01?ooool01?l0003oI=CcofCDlomTe?<4o`000;Cooooo0_l00000067ooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000?oooool00ol0003o
ooooooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`2cooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`
ooooo`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:cooooo1?l0000Boooo
o`00JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0000Fooooo`00
J_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000Jooooo`00Jooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000Nooooo`00K?ooool2
o`0003Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool00ol0003ooooo
ooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`2>ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:
ooooo`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26oooo
o`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0000mooooo`00
Moooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l00011ooooo`00N?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015ooooo`00NOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019ooooo`00N_ooool2o`00
02Kooooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0003oooooooooo`1S
ooooo`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Ooooo
o`Co0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`Co
0000I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000
J?ooool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/ooooo`00Q_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`ooooo`00Qoooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00R?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROooool2o`0001Oooooo
00?o0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003oooooooooo`0dooooo`Co
0000Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`Co0000
Soooool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`?o0000Tooo
ool009;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00U?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2o`0000Sooooo00?o
0000ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000
]_ooool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002Oooooo`03o`000?oo
oooo000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o000000;o0000`Oooool0
0:7ooooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03003 .28261 -24 -2.73565 ]
[.03003 .28261 0 6.26435 ]
[.02107 .33874 -30 -2.78353 ]
[.02107 .33874 0 6.21647 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00213 .45746 -24 -2.88536 ]
[.00213 .45746 0 6.11464 ]
[-0.0079 .5203 -18 -2.93958 ]
[-0.0079 .5203 0 6.06042 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04225 .27781 m
.04836 .27542 L
s
[(-0.5)] .03003 .28261 1 -0.39208 Mshowa
.03334 .33406 m
.03947 .33172 L
s
[(-0.25)] .02107 .33874 1 -0.38144 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01448 .45303 m
.02066 .45081 L
s
[(0.25)] .00213 .45746 1 -0.35881 Mshowa
.00451 .516 m
.01071 .51384 L
s
[(0.5)] -0.0079 .5203 1 -0.34676 Mshowa
.125 Mabswid
.04049 .2889 m
.04416 .28747 L
s
.03872 .30007 m
.0424 .29864 L
s
.03694 .31131 m
.04062 .3099 L
s
.03515 .32265 m
.03882 .32124 L
s
.03151 .34556 m
.0352 .34416 L
s
.02968 .35715 m
.03336 .35576 L
s
.02783 .36882 m
.03152 .36744 L
s
.02597 .38058 m
.02966 .3792 L
s
.0222 .40436 m
.02589 .403 L
s
.02029 .41639 m
.02399 .41504 L
s
.01837 .42851 m
.02207 .42716 L
s
.01643 .44072 m
.02014 .43938 L
s
.01252 .46543 m
.01623 .4641 L
s
.01054 .47792 m
.01425 .47661 L
s
.00854 .49051 m
.01226 .48921 L
s
.00653 .50321 m
.01025 .50191 L
s
.04399 .26681 m
.04766 .26536 L
s
.04573 .25588 m
.04939 .25443 L
s
.00246 .52889 m
.00619 .5276 L
s
.0004 .54188 m
.00413 .5406 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51723 .65884 m .51694 .65827 L .43899 .65168 L p .155 0 0 r
F P
0 g
s
.5927 .65116 m .59527 .65394 L .51694 .65827 L p .481 .83 .997 r
F P
0 g
s
.51694 .65827 m .51723 .65884 L .5927 .65116 L p .481 .83 .997 r
F P
0 g
s
.59527 .65394 m .5927 .65116 L .66471 .63279 L p .656 .751 .92 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59527 .65394 L p .656 .751 .92 r
F P
0 g
s
.44199 .6555 m .43899 .65168 L .36521 .63435 L p .543 0 0 r
F P
0 g
s
.43899 .65168 m .44199 .6555 L .51723 .65884 L p .155 0 0 r
F P
0 g
s
.51752 .65955 m .51723 .65884 L .44199 .6555 L p .154 0 0 r
F P
0 g
s
.59011 .64842 m .5927 .65116 L .51728 .65883 L p .513 .852 .996 r
F P
0 g
s
.51728 .65883 m .51723 .65884 L p .51733 .65882 L .513 .852 .996 r
F P
0 g
s
.59011 .64842 m .51728 .65883 L .51733 .65882 L .513 .852 .996 r
F
.51723 .65884 m .51752 .65955 L .59011 .64842 L p F P
0 g
s
.58748 .64565 m .59011 .64842 L .51752 .65955 L p .554 .874 .993 r
F P
0 g
s
.51752 .65955 m .51782 .66027 L .58745 .64566 L p .554 .874 .993 r
F P
0 g
s
.58745 .64566 m .58748 .64565 L p .58742 .64566 L .554 .874 .993 r
F P
0 g
s
.58742 .64566 m .51752 .65955 L .58745 .64566 L .554 .874 .993 r
F
.5927 .65116 m .59011 .64842 L .65915 .62672 L p .677 .758 .912 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .5927 .65116 L p .677 .758 .912 r
F P
0 g
s
.36521 .63435 m .37073 .64115 L .44199 .6555 L p .543 0 0 r
F P
0 g
s
.44503 .65958 m .44199 .6555 L .37073 .64115 L p .551 0 0 r
F P
0 g
s
.44199 .6555 m .44503 .65958 L .51752 .65955 L p .154 0 0 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .72954 .6044 L p .641 .645 .839 r
F P
0 g
s
.72954 .6044 m .73799 .61332 L .67023 .63881 L p .641 .645 .839 r
F P
0 g
s
.51782 .66027 m .51752 .65955 L .44503 .65958 L p .126 0 0 r
F P
0 g
s
.59011 .64842 m .58748 .64565 L .65355 .62061 L p .699 .764 .903 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .59011 .64842 L p .699 .764 .903 r
F P
0 g
s
.37073 .64115 m .36521 .63435 L .29943 .6068 L p .682 .141 0 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72105 .59536 L p .655 .647 .83 r
F P
0 g
s
.72105 .59536 m .72954 .6044 L .66471 .63279 L p .655 .647 .83 r
F P
0 g
s
.37073 .64115 m .37633 .6483 L .44503 .65958 L p .551 0 0 r
F P
0 g
s
.44811 .66371 m .44503 .65958 L .37633 .6483 L p .542 0 0 r
F P
0 g
s
.44503 .65958 m .44811 .66371 L .51782 .66027 L p .126 0 0 r
F P
0 g
s
.58483 .64276 m .58748 .64565 L .51782 .66027 L p .602 .894 .989 r
F P
0 g
s
.58748 .64565 m .58483 .64276 L .6479 .61445 L p .72 .77 .892 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58748 .64565 L p .72 .77 .892 r
F P
0 g
s
.51812 .66084 m .51782 .66027 L .44811 .66371 L p .067 0 0 r
F P
0 g
s
.51782 .66027 m .51812 .66084 L .58483 .64276 L p .602 .894 .989 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71253 .58629 L p .669 .65 .822 r
F P
0 g
s
.71253 .58629 m .72105 .59536 L .65915 .62672 L p .669 .65 .822 r
F P
0 g
s
.29943 .6068 m .30726 .61615 L .37073 .64115 L p .682 .141 0 r
F P
0 g
s
.37633 .6483 m .37073 .64115 L .30726 .61615 L p .692 .157 0 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70397 .57727 L p .684 .654 .815 r
F P
0 g
s
.70397 .57727 m .71253 .58629 L .65355 .62061 L p .684 .654 .815 r
F P
0 g
s
.58215 .63968 m .58483 .64276 L .51812 .66084 L p .653 .91 .98 r
F P
0 g
s
.58483 .64276 m .58215 .63968 L .64221 .60824 L p .741 .775 .881 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58483 .64276 L p .741 .775 .881 r
F P
0 g
s
.37633 .6483 m .38201 .65556 L .44811 .66371 L p .542 0 0 r
F P
0 g
s
.45125 .66766 m .44811 .66371 L .38201 .65556 L p .518 0 0 r
F P
0 g
s
.44811 .66371 m .45125 .66766 L .51812 .66084 L p .067 0 0 r
F P
0 g
s
.51843 .66108 m .51812 .66084 L .45125 .66766 L p 0 0 0 r
F P
0 g
s
.51812 .66084 m .51843 .66108 L .58215 .63968 L p .653 .91 .98 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69539 .56837 L p .699 .66 .808 r
F P
0 g
s
.69539 .56837 m .70397 .57727 L .6479 .61445 L p .699 .66 .808 r
F P
0 g
s
.73799 .61332 m .72954 .6044 L .78345 .56705 L p .586 .568 .8 r
F P
0 g
s
.78345 .56705 m .79464 .57831 L .73799 .61332 L p .586 .568 .8 r
F P
0 g
s
.57943 .63631 m .58215 .63968 L .51843 .66108 L p .702 .92 .967 r
F P
0 g
s
.58215 .63968 m .57943 .63631 L .63648 .60198 L p .76 .779 .868 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58215 .63968 L p .76 .779 .868 r
F P
0 g
s
.30726 .61615 m .31519 .62594 L .37633 .6483 L p .692 .157 0 r
F P
0 g
s
.38201 .65556 m .37633 .6483 L .31519 .62594 L p .69 .157 0 r
F P
0 g
s
.72954 .6044 m .72105 .59536 L .77223 .55565 L p .596 .567 .792 r
F P
0 g
s
.77223 .55565 m .78345 .56705 L .72954 .6044 L p .596 .567 .792 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68678 .55969 L p .714 .666 .802 r
F P
0 g
s
.68678 .55969 m .69539 .56837 L .64221 .60824 L p .714 .666 .802 r
F P
0 g
s
.45125 .66766 m .45444 .67121 L .51843 .66108 L p 0 0 0 r
F P
0 g
s
.51874 .66084 m .51843 .66108 L .45444 .67121 L p .144 .687 .729 r
F P
0 g
s
.51843 .66108 m .51874 .66084 L .57943 .63631 L p .702 .92 .967 r
F P
0 g
s
.30726 .61615 m .29943 .6068 L .24558 .56996 L p .703 .171 0 r
F P
0 g
s
.72105 .59536 m .71253 .58629 L .76102 .54425 L p .608 .57 .786 r
F P
0 g
s
.76102 .54425 m .77223 .55565 L .72105 .59536 L p .608 .57 .786 r
F P
0 g
s
.38201 .65556 m .38779 .66264 L .45125 .66766 L p .518 0 0 r
F P
0 g
s
.45444 .67121 m .45125 .66766 L .38779 .66264 L p .475 0 0 r
F P
0 g
s
.71253 .58629 m .70397 .57727 L .74982 .53301 L p .621 .574 .78 r
F P
0 g
s
.74982 .53301 m .76102 .54425 L .71253 .58629 L p .621 .574 .78 r
F P
0 g
s
.57668 .63259 m .57943 .63631 L .51874 .66084 L p .746 .923 .95 r
F P
0 g
s
.57943 .63631 m .57668 .63259 L .6307 .59568 L p .778 .782 .856 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .57943 .63631 L p .778 .782 .856 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .67816 .55128 L p .73 .674 .796 r
F P
0 g
s
.67816 .55128 m .68678 .55969 L .63648 .60198 L p .73 .674 .796 r
F P
0 g
s
.70397 .57727 m .69539 .56837 L .73863 .52209 L p .635 .581 .776 r
F P
0 g
s
.73863 .52209 m .74982 .53301 L .70397 .57727 L p .635 .581 .776 r
F P
0 g
s
.31519 .62594 m .32324 .63586 L .38201 .65556 L p .69 .157 0 r
F P
0 g
s
.38779 .66264 m .38201 .65556 L .32324 .63586 L p .677 .141 0 r
F P
0 g
s
.45444 .67121 m .45768 .67411 L .51874 .66084 L p .144 .687 .729 r
F P
0 g
s
.51906 .65997 m .51874 .66084 L .45768 .67411 L p .292 .791 .809 r
F P
0 g
s
.51874 .66084 m .51906 .65997 L .57668 .63259 L p .746 .923 .95 r
F P
0 g
s
.69539 .56837 m .68678 .55969 L .72747 .51163 L p .651 .589 .773 r
F P
0 g
s
.72747 .51163 m .73863 .52209 L .69539 .56837 L p .651 .589 .773 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .57668 .63259 L p .795 .784 .843 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .6695 .54322 L p .746 .682 .79 r
F P
0 g
s
.6695 .54322 m .67816 .55128 L .6307 .59568 L p .746 .682 .79 r
F P
0 g
s
.25545 .58134 m .30726 .61615 L p .24634 .57053 L .703 .171 0 r
F P
0 g
s
.31519 .62594 m .30726 .61615 L .25545 .58134 L p .718 .189 0 r
F P
0 g
s
.25545 .58134 m .26543 .59318 L .31519 .62594 L p .718 .189 0 r
F P
0 g
s
.25545 .58134 m .21913 .5381 L p .26487 .59251 L 0 0 .457 r
F P
0 g
s
.26543 .59318 m .25545 .58134 L p .26487 .59251 L 0 0 .457 r
F P
0 g
s
.24558 .56996 m .25545 .58134 L p .24634 .57053 L .703 .171 0 r
F P
0 g
s
.5739 .62842 m .57668 .63259 L .51906 .65997 L p .783 .919 .929 r
F P
0 g
s
.57668 .63259 m .5739 .62842 L .62488 .58932 L p .795 .784 .843 r
F P
0 g
s
.38779 .66264 m .39368 .66924 L .45444 .67121 L p .475 0 0 r
F P
0 g
s
.45768 .67411 m .45444 .67121 L .39368 .66924 L p .406 0 0 r
F P
0 g
s
.68678 .55969 m .67816 .55128 L .71633 .50178 L p .668 .599 .77 r
F P
0 g
s
.71633 .50178 m .72747 .51163 L .68678 .55969 L p .668 .599 .77 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .5739 .62842 L p .81 .786 .83 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66083 .53557 L p .761 .691 .784 r
F P
0 g
s
.66083 .53557 m .6695 .54322 L .62488 .58932 L p .761 .691 .784 r
F P
0 g
s
.67816 .55128 m .6695 .54322 L .70523 .49265 L p .685 .611 .767 r
F P
0 g
s
.70523 .49265 m .71633 .50178 L .67816 .55128 L p .685 .611 .767 r
F P
0 g
s
.45768 .67411 m .461 .67615 L .51906 .65997 L p .292 .791 .809 r
F P
0 g
s
.51938 .6583 m .51906 .65997 L .461 .67615 L p .45 .882 .879 r
F P
0 g
s
.51906 .65997 m .51938 .6583 L .5739 .62842 L p .783 .919 .929 r
F P
0 g
s
.57108 .62376 m .5739 .62842 L .51938 .6583 L p .813 .911 .906 r
F P
0 g
s
.5739 .62842 m .57108 .62376 L .61901 .58292 L p .81 .786 .83 r
F P
0 g
s
.32324 .63586 m .33142 .64561 L .38779 .66264 L p .677 .141 0 r
F P
0 g
s
.39368 .66924 m .38779 .66264 L .33142 .64561 L p .652 .106 0 r
F P
0 g
s
.6695 .54322 m .66083 .53557 L .69415 .48437 L p .704 .624 .765 r
F P
0 g
s
.69415 .48437 m .70523 .49265 L .6695 .54322 L p .704 .624 .765 r
F P
0 g
s
.32324 .63586 m .31519 .62594 L .26543 .59318 L p .719 .19 0 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57108 .62376 L p .824 .786 .817 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65212 .52838 L p .777 .7 .779 r
F P
0 g
s
.65212 .52838 m .66083 .53557 L .61901 .58292 L p .777 .7 .779 r
F P
0 g
s
.39368 .66924 m .39969 .67509 L .45768 .67411 L p .406 0 0 r
F P
0 g
s
.461 .67615 m .45768 .67411 L .39969 .67509 L p .301 0 0 r
F P
0 g
s
.66083 .53557 m .65212 .52838 L .68309 .47703 L p .723 .638 .763 r
F P
0 g
s
.68309 .47703 m .69415 .48437 L .66083 .53557 L p .723 .638 .763 r
F P
0 g
s
.79464 .57831 m .78345 .56705 L .82272 .52235 L p .509 .505 .788 r
F P
0 g
s
.82272 .52235 m .83625 .53514 L .79464 .57831 L p .509 .505 .788 r
F P
0 g
s
.51938 .6583 m .51971 .65571 L .57108 .62376 L p .813 .911 .906 r
F P
0 g
s
.56822 .61852 m .57108 .62376 L .51971 .65571 L p .837 .899 .883 r
F P
0 g
s
.57108 .62376 m .56822 .61852 L .61309 .57646 L p .824 .786 .817 r
F P
0 g
s
.78345 .56705 m .77223 .55565 L .80922 .5094 L p .517 .504 .781 r
F P
0 g
s
.80922 .5094 m .82272 .52235 L .78345 .56705 L p .517 .504 .781 r
F P
0 g
s
.77223 .55565 m .76102 .54425 L .79578 .49651 L p .528 .506 .776 r
F P
0 g
s
.79578 .49651 m .80922 .5094 L .77223 .55565 L p .528 .506 .776 r
F P
0 g
s
.76102 .54425 m .74982 .53301 L .7824 .4839 L p .541 .511 .772 r
F P
0 g
s
.7824 .4839 m .79578 .49651 L .76102 .54425 L p .541 .511 .772 r
F P
0 g
s
.74982 .53301 m .73863 .52209 L .76912 .47179 L p .557 .519 .769 r
F P
0 g
s
.76912 .47179 m .7824 .4839 L .74982 .53301 L p .557 .519 .769 r
F P
0 g
s
.73863 .52209 m .72747 .51163 L .75592 .46038 L p .575 .53 .767 r
F P
0 g
s
.75592 .46038 m .76912 .47179 L .73863 .52209 L p .575 .53 .767 r
F P
0 g
s
.461 .67615 m .46437 .67709 L .51938 .6583 L p .45 .882 .879 r
F P
0 g
s
.51971 .65571 m .51938 .6583 L .46437 .67709 L p .593 .944 .921 r
F P
0 g
s
.72747 .51163 m .71633 .50178 L .74282 .44987 L p .595 .543 .766 r
F P
0 g
s
.74282 .44987 m .75592 .46038 L .72747 .51163 L p .595 .543 .766 r
F P
0 g
s
.64339 .5217 m .65212 .52838 L .61309 .57646 L p .792 .709 .773 r
F P
0 g
s
.65212 .52838 m .64339 .5217 L .67205 .47071 L p .742 .653 .761 r
F P
0 g
s
.67205 .47071 m .68309 .47703 L .65212 .52838 L p .742 .653 .761 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56822 .61852 L p .835 .787 .805 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64339 .5217 L p .792 .709 .773 r
F P
0 g
s
.71633 .50178 m .70523 .49265 L .72982 .44043 L p .617 .558 .766 r
F P
0 g
s
.72982 .44043 m .74282 .44987 L .71633 .50178 L p .617 .558 .766 r
F P
0 g
s
.70523 .49265 m .69415 .48437 L .71692 .43221 L p .64 .575 .766 r
F P
0 g
s
.71692 .43221 m .72982 .44043 L .70523 .49265 L p .64 .575 .766 r
F P
0 g
s
.33142 .64561 m .33977 .65484 L .39368 .66924 L p .652 .106 0 r
F P
0 g
s
.39969 .67509 m .39368 .66924 L .33977 .65484 L p .608 .048 0 r
F P
0 g
s
.69415 .48437 m .68309 .47703 L .70411 .42534 L p .665 .594 .765 r
F P
0 g
s
.70411 .42534 m .71692 .43221 L .69415 .48437 L p .665 .594 .765 r
F P
0 g
s
.63463 .51556 m .64339 .5217 L .60713 .56996 L p .806 .718 .768 r
F P
0 g
s
.64339 .5217 m .63463 .51556 L .66102 .46547 L p .762 .668 .758 r
F P
0 g
s
.66102 .46547 m .67205 .47071 L .64339 .5217 L p .762 .668 .758 r
F P
0 g
s
.39969 .67509 m .40583 .67988 L .461 .67615 L p .301 0 0 r
F P
0 g
s
.46437 .67709 m .461 .67615 L .40583 .67988 L p .144 0 0 r
F P
0 g
s
.26543 .59318 m .27555 .60517 L .32324 .63586 L p .719 .19 0 r
F P
0 g
s
.33142 .64561 m .32324 .63586 L .27555 .60517 L p .707 .174 0 r
F P
0 g
s
.68309 .47703 m .67205 .47071 L .69138 .41993 L p .691 .613 .765 r
F P
0 g
s
.69138 .41993 m .70411 .42534 L .68309 .47703 L p .691 .613 .765 r
F P
0 g
s
.51971 .65571 m .52004 .65207 L .56822 .61852 L p .837 .899 .883 r
F P
0 g
s
.56533 .61268 m .56822 .61852 L .52004 .65207 L p .854 .885 .86 r
F P
0 g
s
.56822 .61852 m .56533 .61268 L .60713 .56996 L p .835 .787 .805 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .56533 .61268 L p .846 .787 .794 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63463 .51556 L p .806 .718 .768 r
F P
0 g
s
.25545 .58134 m .24558 .56996 L .20758 .52532 L p 0 0 .472 r
F P
0 g
s
.67205 .47071 m .66102 .46547 L .67871 .41606 L p .716 .633 .764 r
F P
0 g
s
.67871 .41606 m .69138 .41993 L .67205 .47071 L p .716 .633 .764 r
F P
0 g
s
.46437 .67709 m .46782 .67674 L .51971 .65571 L p .593 .944 .921 r
F P
0 g
s
.52004 .65207 m .51971 .65571 L .46782 .67674 L p .706 .969 .933 r
F P
0 g
s
.62584 .50998 m .63463 .51556 L .60112 .5634 L p .82 .727 .762 r
F P
0 g
s
.63463 .51556 m .62584 .50998 L .64999 .46136 L p .781 .683 .756 r
F P
0 g
s
.64999 .46136 m .66102 .46547 L .63463 .51556 L p .781 .683 .756 r
F P
0 g
s
.66102 .46547 m .64999 .46136 L .6661 .41377 L p .742 .654 .762 r
F P
0 g
s
.6661 .41377 m .67871 .41606 L .66102 .46547 L p .742 .654 .762 r
F P
0 g
s
.56533 .61268 m .56241 .60617 L .60112 .5634 L p .846 .787 .794 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56241 .60617 L p .855 .786 .783 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62584 .50998 L p .82 .727 .762 r
F P
0 g
s
.52004 .65207 m .52038 .64727 L .56533 .61268 L p .854 .885 .86 r
F P
0 g
s
.56241 .60617 m .56533 .61268 L .52038 .64727 L p .867 .871 .838 r
F P
0 g
s
.33977 .65484 m .34829 .66323 L .39969 .67509 L p .608 .048 0 r
F P
0 g
s
.40583 .67988 m .39969 .67509 L .34829 .66323 L p .538 0 0 r
F P
0 g
s
.617 .50498 m .62584 .50998 L .59506 .55679 L p .833 .735 .757 r
F P
0 g
s
.62584 .50998 m .617 .50498 L .63895 .45838 L p .799 .697 .753 r
F P
0 g
s
.63895 .45838 m .64999 .46136 L .62584 .50998 L p .799 .697 .753 r
F P
0 g
s
.40583 .67988 m .4121 .68335 L .46437 .67709 L p .144 0 0 r
F P
0 g
s
.4121 .68335 m .41851 .68525 L .46782 .67674 L p 0 0 0 r
F P
0 g
s
.46782 .67674 m .46437 .67709 L .42919 .68131 L p 0 0 0 r
F P
0 g
s
.46782 .67674 m .42919 .68131 L .43492 .68064 L 0 0 0 r
F
.47132 .67492 m .46782 .67674 L .43714 .68203 L p .325 .811 .846 r
F P
0 g
s
.43714 .68203 m .41851 .68525 L p .44216 .68062 L .325 .811 .846 r
F P
0 g
s
.47132 .67492 m .43714 .68203 L .44216 .68062 L .325 .811 .846 r
F
.41851 .68525 m .42504 .68535 L .45746 .67804 L p F P
0 g
s
.45232 .67864 m .41851 .68525 L .45746 .67804 L .325 .811 .846 r
F
.42504 .68535 m .43171 .68346 L .45977 .67567 L p .55 .923 .932 r
F P
0 g
s
.45977 .67567 m .4749 .67148 L p .45527 .67694 L .55 .923 .932 r
F P
0 g
s
.45527 .67694 m .42504 .68535 L .45977 .67567 L .55 .923 .932 r
F
.45746 .67804 m .47132 .67492 L p .45232 .67864 L .325 .811 .846 r
F P
0 g
s
.42919 .68131 m .4121 .68335 L p .43492 .68064 L 0 0 0 r
F P
0 g
s
.64999 .46136 m .63895 .45838 L .65351 .41311 L p .767 .674 .76 r
F P
0 g
s
.65351 .41311 m .6661 .41377 L .64999 .46136 L p .767 .674 .76 r
F P
0 g
s
.20758 .52532 m .21913 .5381 L .25545 .58134 L p 0 0 .472 r
F P
0 g
s
.27555 .60517 m .28583 .61697 L .33142 .64561 L p .707 .174 0 r
F P
0 g
s
.33977 .65484 m .33142 .64561 L .28583 .61697 L p .68 .138 0 r
F P
0 g
s
.71692 .43221 m .70411 .42534 L .71373 .37635 L p .6 .565 .786 r
F P
0 g
s
.70411 .42534 m .69138 .41993 L .70007 .37236 L p .636 .591 .786 r
F P
0 g
s
.70007 .37236 m .71373 .37635 L .70411 .42534 L p .636 .591 .786 r
F P
0 g
s
.72982 .44043 m .71692 .43221 L .72754 .38213 L p .566 .54 .785 r
F P
0 g
s
.71373 .37635 m .72754 .38213 L .71692 .43221 L p .6 .565 .786 r
F P
0 g
s
.46782 .67674 m .47132 .67492 L .52004 .65207 L p .706 .969 .933 r
F P
0 g
s
.52038 .64727 m .52004 .65207 L .47132 .67492 L p .783 .966 .92 r
F P
0 g
s
.69138 .41993 m .67871 .41606 L .68654 .37025 L p .672 .617 .785 r
F P
0 g
s
.68654 .37025 m .70007 .37236 L .69138 .41993 L p .672 .617 .785 r
F P
0 g
s
.74282 .44987 m .72982 .44043 L .7415 .38958 L p .533 .517 .783 r
F P
0 g
s
.72754 .38213 m .7415 .38958 L .72982 .44043 L p .566 .54 .785 r
F P
0 g
s
.56241 .60617 m .55945 .59899 L .59506 .55679 L p .855 .786 .783 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55945 .59899 L p .863 .785 .773 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .617 .50498 L p .833 .735 .757 r
F P
0 g
s
.67871 .41606 m .6661 .41377 L .67311 .37009 L p .707 .643 .783 r
F P
0 g
s
.67311 .37009 m .68654 .37025 L .67871 .41606 L p .707 .643 .783 r
F P
0 g
s
.62788 .45653 m .63895 .45838 L .617 .50498 L p .816 .712 .749 r
F P
0 g
s
.63895 .45838 m .62788 .45653 L .64094 .41405 L p .791 .693 .756 r
F P
0 g
s
.64094 .41405 m .65351 .41311 L .63895 .45838 L p .791 .693 .756 r
F P
0 g
s
.75592 .46038 m .74282 .44987 L .75563 .39855 L p .503 .496 .782 r
F P
0 g
s
.7415 .38958 m .75563 .39855 L .74282 .44987 L p .533 .517 .783 r
F P
0 g
s
.60811 .50054 m .617 .50498 L .58896 .55013 L p .844 .743 .752 r
F P
0 g
s
.617 .50498 m .60811 .50054 L .62788 .45653 L p .816 .712 .749 r
F P
0 g
s
.52038 .64727 m .52072 .64125 L .56241 .60617 L p .867 .871 .838 r
F P
0 g
s
.55945 .59899 m .56241 .60617 L .52072 .64125 L p .877 .857 .818 r
F P
0 g
s
.6661 .41377 m .65351 .41311 L .65976 .37189 L p .74 .667 .779 r
F P
0 g
s
.65976 .37189 m .67311 .37009 L .6661 .41377 L p .74 .667 .779 r
F P
0 g
s
.76912 .47179 m .75592 .46038 L .76994 .40885 L p .476 .478 .78 r
F P
0 g
s
.75563 .39855 m .76994 .40885 L .75592 .46038 L p .503 .496 .782 r
F P
0 g
s
.65351 .41311 m .64094 .41405 L .64646 .37566 L p .77 .689 .774 r
F P
0 g
s
.64646 .37566 m .65976 .37189 L .65351 .41311 L p .77 .689 .774 r
F P
0 g
s
.7824 .4839 m .76912 .47179 L .78442 .42029 L p .453 .464 .78 r
F P
0 g
s
.76994 .40885 m .78442 .42029 L .76912 .47179 L p .476 .478 .78 r
F P
0 g
s
.61678 .45581 m .62788 .45653 L .60811 .50054 L p .832 .725 .746 r
F P
0 g
s
.62788 .45653 m .61678 .45581 L .62837 .41657 L p .812 .71 .752 r
F P
0 g
s
.62837 .41657 m .64094 .41405 L .62788 .45653 L p .812 .71 .752 r
F P
0 g
s
.55945 .59899 m .55646 .59111 L .58896 .55013 L p .863 .785 .773 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55646 .59111 L p .87 .785 .764 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60811 .50054 L p .844 .743 .752 r
F P
0 g
s
.34829 .66323 m .35699 .67047 L .40583 .67988 L p .538 0 0 r
F P
0 g
s
.4121 .68335 m .40583 .67988 L .35699 .67047 L p .423 0 0 r
F P
0 g
s
.59918 .49666 m .60811 .50054 L .5828 .54342 L p .855 .75 .747 r
F P
0 g
s
.60811 .50054 m .59918 .49666 L .61678 .45581 L p .832 .725 .746 r
F P
0 g
s
.47132 .67492 m .4749 .67148 L .52038 .64727 L p .783 .966 .92 r
F P
0 g
s
.52072 .64125 m .52038 .64727 L .4749 .67148 L p .832 .948 .896 r
F P
0 g
s
.79578 .49651 m .7824 .4839 L .79907 .43262 L p .434 .453 .781 r
F P
0 g
s
.78442 .42029 m .79907 .43262 L .7824 .4839 L p .453 .464 .78 r
F P
0 g
s
.21913 .5381 m .23079 .55132 L .26543 .59318 L p 0 0 .457 r
F P
0 g
s
.27555 .60517 m .26543 .59318 L .23079 .55132 L p 0 0 .465 r
F P
0 g
s
.64094 .41405 m .62837 .41657 L .6332 .38135 L p .798 .709 .767 r
F P
0 g
s
.6332 .38135 m .64646 .37566 L .64094 .41405 L p .798 .709 .767 r
F P
0 g
s
.52072 .64125 m .52107 .63395 L .55945 .59899 L p .877 .857 .818 r
F P
0 g
s
.55646 .59111 m .55945 .59899 L .52107 .63395 L p .883 .843 .801 r
F P
0 g
s
.28583 .61697 m .2963 .62826 L .33977 .65484 L p .68 .138 0 r
F P
0 g
s
.34829 .66323 m .33977 .65484 L .2963 .62826 L p .631 .077 0 r
F P
0 g
s
.80922 .5094 m .79578 .49651 L .81387 .44561 L p .418 .447 .783 r
F P
0 g
s
.79907 .43262 m .81387 .44561 L .79578 .49651 L p .434 .453 .781 r
F P
0 g
s
.60563 .45615 m .61678 .45581 L .59918 .49666 L p .847 .737 .742 r
F P
0 g
s
.61678 .45581 m .60563 .45615 L .61576 .42061 L p .832 .726 .748 r
F P
0 g
s
.61576 .42061 m .62837 .41657 L .61678 .45581 L p .832 .726 .748 r
F P
0 g
s
.70007 .37236 m .68654 .37025 L .68379 .33093 L p .629 .625 .827 r
F P
0 g
s
.68654 .37025 m .67311 .37009 L .67042 .33303 L p .678 .656 .821 r
F P
0 g
s
.67042 .33303 m .68379 .33093 L .68654 .37025 L p .678 .656 .821 r
F P
0 g
s
.55646 .59111 m .55344 .58254 L .5828 .54342 L p .87 .785 .764 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55344 .58254 L p .876 .784 .755 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .59918 .49666 L p .855 .75 .747 r
F P
0 g
s
.67311 .37009 m .65976 .37189 L .65716 .33731 L p .722 .683 .812 r
F P
0 g
s
.65716 .33731 m .67042 .33303 L .67311 .37009 L p .722 .683 .812 r
F P
0 g
s
.71373 .37635 m .70007 .37236 L .69731 .33099 L p .578 .591 .83 r
F P
0 g
s
.68379 .33093 m .69731 .33099 L .70007 .37236 L p .629 .625 .827 r
F P
0 g
s
.59018 .49332 m .59918 .49666 L .5766 .53665 L p .865 .757 .742 r
F P
0 g
s
.59918 .49666 m .59018 .49332 L .60563 .45615 L p .847 .737 .742 r
F P
0 g
s
.62837 .41657 m .61576 .42061 L .61993 .38889 L p .822 .727 .759 r
F P
0 g
s
.61993 .38889 m .6332 .38135 L .62837 .41657 L p .822 .727 .759 r
F P
0 g
s
.65976 .37189 m .64646 .37566 L .644 .34377 L p .761 .706 .801 r
F P
0 g
s
.644 .34377 m .65716 .33731 L .65976 .37189 L p .761 .706 .801 r
F P
0 g
s
.82272 .52235 m .80922 .5094 L .82882 .45899 L p .407 .445 .787 r
F P
0 g
s
.81387 .44561 m .82882 .45899 L .80922 .5094 L p .418 .447 .783 r
F P
0 g
s
.72754 .38213 m .71373 .37635 L .71101 .33315 L p .524 .555 .829 r
F P
0 g
s
.69731 .33099 m .71101 .33315 L .71373 .37635 L p .578 .591 .83 r
F P
0 g
s
.4749 .67148 m .47853 .66631 L .52072 .64125 L p .832 .948 .896 r
F P
0 g
s
.52107 .63395 m .52072 .64125 L .47853 .66631 L p .862 .922 .867 r
F P
0 g
s
.4749 .67148 m .47132 .67492 L .42504 .68535 L p .55 .923 .932 r
F P
0 g
s
.52107 .63395 m .52142 .62534 L .55646 .59111 L p .883 .843 .801 r
F P
0 g
s
.55344 .58254 m .55646 .59111 L .52142 .62534 L p .888 .831 .785 r
F P
0 g
s
.64646 .37566 m .6332 .38135 L .6309 .35236 L p .793 .725 .788 r
F P
0 g
s
.6309 .35236 m .644 .34377 L .64646 .37566 L p .793 .725 .788 r
F P
0 g
s
.35699 .67047 m .36588 .67623 L .4121 .68335 L p .423 0 0 r
F P
0 g
s
.37496 .68023 m .38424 .68221 L .40115 .68351 L p .023 .59 .783 r
F P
0 g
s
.41851 .68525 m .4121 .68335 L .39263 .68035 L p .24 0 0 r
F P
0 g
s
.41851 .68525 m .39263 .68035 L .39495 .68121 L .24 0 0 r
F
.36588 .67623 m .37496 .68023 L .41851 .68525 L p F P
0 g
s
.42504 .68535 m .41851 .68525 L .40407 .68358 L p .023 .59 .783 r
F P
0 g
s
.40407 .68358 m .37496 .68023 L p .40453 .68325 L .023 .59 .783 r
F P
0 g
s
.42504 .68535 m .40407 .68358 L .40453 .68325 L .023 .59 .783 r
F
.39889 .68267 m .37496 .68023 L .40115 .68351 L F
.38424 .68221 m .3937 .68197 L .40567 .68244 L p .319 .785 .937 r
F P
0 g
s
.40567 .68244 m .43171 .68346 L p .40522 .68276 L .319 .785 .937 r
F P
0 g
s
.40522 .68276 m .38424 .68221 L .40567 .68244 L .319 .785 .937 r
F
.40115 .68351 m .42504 .68535 L p .39889 .68267 L .023 .59 .783 r
F P
0 g
s
.39263 .68035 m .36588 .67623 L p .39495 .68121 L .24 0 0 r
F P
0 g
s
.59441 .45749 m .60563 .45615 L .59018 .49332 L p .86 .748 .738 r
F P
0 g
s
.60563 .45615 m .59441 .45749 L .6031 .42607 L p .849 .74 .743 r
F P
0 g
s
.6031 .42607 m .61576 .42061 L .60563 .45615 L p .849 .74 .743 r
F P
0 g
s
.83625 .53514 m .82272 .52235 L .84389 .47249 L p .4 .447 .793 r
F P
0 g
s
.82882 .45899 m .84389 .47249 L .82272 .52235 L p .407 .445 .787 r
F P
0 g
s
.7415 .38958 m .72754 .38213 L .7249 .3373 L p .471 .52 .826 r
F P
0 g
s
.71101 .33315 m .7249 .3373 L .72754 .38213 L p .524 .555 .829 r
F P
0 g
s
.61576 .42061 m .6031 .42607 L .60664 .39817 L p .843 .741 .752 r
F P
0 g
s
.60664 .39817 m .61993 .38889 L .61576 .42061 L p .843 .741 .752 r
F P
0 g
s
.55344 .58254 m .55039 .57329 L .5766 .53665 L p .876 .784 .755 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .55039 .57329 L p .881 .783 .748 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59018 .49332 L p .865 .757 .742 r
F P
0 g
s
.6332 .38135 m .61993 .38889 L .61783 .363 L p .821 .741 .776 r
F P
0 g
s
.61783 .363 m .6309 .35236 L .6332 .38135 L p .821 .741 .776 r
F P
0 g
s
.23079 .55132 m .24258 .56467 L .27555 .60517 L p 0 0 .465 r
F P
0 g
s
.28583 .61697 m .27555 .60517 L .24258 .56467 L p 0 0 .494 r
F P
0 g
s
.58112 .49047 m .59018 .49332 L .57035 .52982 L p .873 .762 .737 r
F P
0 g
s
.59018 .49332 m .58112 .49047 L .59441 .45749 L p .86 .748 .738 r
F P
0 g
s
.84389 .47249 m .85906 .48583 L .83625 .53514 L p .4 .447 .793 r
F P
0 g
s
.75563 .39855 m .7415 .38958 L .739 .34333 L p .421 .486 .821 r
F P
0 g
s
.7249 .3373 m .739 .34333 L .7415 .38958 L p .471 .52 .826 r
F P
0 g
s
.2963 .62826 m .30697 .63867 L .34829 .66323 L p .631 .077 0 r
F P
0 g
s
.35699 .67047 m .34829 .66323 L .30697 .63867 L p .549 0 0 r
F P
0 g
s
.52142 .62534 m .52178 .61542 L .55344 .58254 L p .888 .831 .785 r
F P
0 g
s
.55039 .57329 m .55344 .58254 L .52178 .61542 L p .891 .82 .771 r
F P
0 g
s
.47853 .66631 m .48223 .65932 L .52107 .63395 L p .862 .922 .867 r
F P
0 g
s
.52142 .62534 m .52107 .63395 L .48223 .65932 L p .879 .896 .84 r
F P
0 g
s
.61993 .38889 m .60664 .39817 L .60477 .37557 L p .843 .753 .763 r
F P
0 g
s
.60477 .37557 m .61783 .363 L .61993 .38889 L p .843 .753 .763 r
F P
0 g
s
.58312 .45975 m .59441 .45749 L .58112 .49047 L p .871 .757 .734 r
F P
0 g
s
.59441 .45749 m .58312 .45975 L .59037 .43284 L p .864 .752 .738 r
F P
0 g
s
.59037 .43284 m .6031 .42607 L .59441 .45749 L p .864 .752 .738 r
F P
0 g
s
.47853 .66631 m .4749 .67148 L .43171 .68346 L p .704 .959 .947 r
F P
0 g
s
.6031 .42607 m .59037 .43284 L .5933 .40906 L p .86 .753 .744 r
F P
0 g
s
.5933 .40906 m .60664 .39817 L .6031 .42607 L p .86 .753 .744 r
F P
0 g
s
.76994 .40885 m .75563 .39855 L .75333 .35105 L p .375 .455 .815 r
F P
0 g
s
.739 .34333 m .75333 .35105 L .75563 .39855 L p .421 .486 .821 r
F P
0 g
s
.55039 .57329 m .54732 .56338 L .57035 .52982 L p .881 .783 .748 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54732 .56338 L p .886 .782 .741 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58112 .49047 L p .873 .762 .737 r
F P
0 g
s
.57199 .48806 m .58112 .49047 L .56404 .52294 L p .88 .767 .733 r
F P
0 g
s
.58112 .49047 m .57199 .48806 L .58312 .45975 L p .871 .757 .734 r
F P
0 g
s
.67042 .33303 m .65716 .33731 L .64568 .31169 L p .721 .728 .856 r
F P
0 g
s
.65716 .33731 m .644 .34377 L .63355 .32052 L p .766 .746 .834 r
F P
0 g
s
.63355 .32052 m .64568 .31169 L .65716 .33731 L p .766 .746 .834 r
F P
0 g
s
.68379 .33093 m .67042 .33303 L .65793 .3051 L p .664 .702 .875 r
F P
0 g
s
.64568 .31169 m .65793 .3051 L .67042 .33303 L p .721 .728 .856 r
F P
0 g
s
.644 .34377 m .6309 .35236 L .6215 .33154 L p .802 .758 .813 r
F P
0 g
s
.6215 .33154 m .63355 .32052 L .644 .34377 L p .802 .758 .813 r
F P
0 g
s
.52178 .61542 m .52214 .60422 L .55039 .57329 L p .891 .82 .771 r
F P
0 g
s
.54732 .56338 m .55039 .57329 L .52214 .60422 L p .893 .81 .759 r
F P
0 g
s
.60664 .39817 m .5933 .40906 L .59168 .38992 L p .861 .762 .752 r
F P
0 g
s
.59168 .38992 m .60477 .37557 L .60664 .39817 L p .861 .762 .752 r
F P
0 g
s
.69731 .33099 m .68379 .33093 L .67032 .30076 L p .597 .669 .89 r
F P
0 g
s
.65793 .3051 m .67032 .30076 L .68379 .33093 L p .664 .702 .875 r
F P
0 g
s
.6309 .35236 m .61783 .363 L .60951 .34467 L p .829 .767 .793 r
F P
0 g
s
.60951 .34467 m .6215 .33154 L .6309 .35236 L p .829 .767 .793 r
F P
0 g
s
.48223 .65932 m .48597 .65049 L .52142 .62534 L p .879 .896 .84 r
F P
0 g
s
.52178 .61542 m .52142 .62534 L .48597 .65049 L p .888 .872 .815 r
F P
0 g
s
.21913 .5381 m .20758 .52532 L .18911 .47507 L p 0 .18 .714 r
F P
0 g
s
.78442 .42029 m .76994 .40885 L .7679 .36029 L p .334 .428 .809 r
F P
0 g
s
.75333 .35105 m .7679 .36029 L .76994 .40885 L p .375 .455 .815 r
F P
0 g
s
.24258 .56467 m .25453 .57784 L .28583 .61697 L p 0 0 .494 r
F P
0 g
s
.2963 .62826 m .28583 .61697 L .25453 .57784 L p 0 .01 .544 r
F P
0 g
s
.57174 .46281 m .58312 .45975 L .57199 .48806 L p .88 .764 .73 r
F P
0 g
s
.58312 .45975 m .57174 .46281 L .57756 .44078 L p .875 .761 .733 r
F P
0 g
s
.57756 .44078 m .59037 .43284 L .58312 .45975 L p .875 .761 .733 r
F P
0 g
s
.59037 .43284 m .57756 .44078 L .57988 .42137 L p .873 .762 .737 r
F P
0 g
s
.57988 .42137 m .5933 .40906 L .59037 .43284 L p .873 .762 .737 r
F P
0 g
s
.61783 .363 m .60477 .37557 L .59754 .35977 L p .85 .772 .775 r
F P
0 g
s
.59754 .35977 m .60951 .34467 L .61783 .363 L p .85 .772 .775 r
F P
0 g
s
.71101 .33315 m .69731 .33099 L .68289 .29865 L p .519 .626 .898 r
F P
0 g
s
.67032 .30076 m .68289 .29865 L .69731 .33099 L p .597 .669 .89 r
F P
0 g
s
.30697 .63867 m .31785 .64787 L .35699 .67047 L p .549 0 0 r
F P
0 g
s
.35699 .67047 m .31785 .64787 L p .35436 .66943 L .418 0 0 r
F P
0 g
s
.36148 .67338 m .35699 .67047 L p .35436 .66943 L .418 0 0 r
F P
0 g
s
.31785 .64787 m .32897 .65554 L .36588 .67623 L p .418 0 0 r
F P
0 g
s
.34031 .66138 m .37496 .68023 L p .34034 .66165 L 0 .33 .722 r
F P
0 g
s
.32897 .65554 m .33414 .65821 L p .34034 .66165 L 0 .33 .722 r
F P
0 g
s
.33414 .65821 m .34031 .66138 L p .34034 .66165 L 0 .33 .722 r
F P
0 g
s
.36588 .67623 m .36148 .67338 L p .35436 .66943 L .418 0 0 r
F P
0 g
s
.43171 .68346 m .4385 .67944 L .47853 .66631 L p .704 .959 .947 r
F P
0 g
s
.48223 .65932 m .47853 .66631 L .4385 .67944 L p .794 .948 .922 r
F P
0 g
s
.54732 .56338 m .54421 .55286 L .56404 .52294 L p .886 .782 .741 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54421 .55286 L p .889 .781 .736 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57199 .48806 L p .88 .767 .733 r
F P
0 g
s
.56279 .48605 m .57199 .48806 L .55769 .51601 L p .886 .771 .729 r
F P
0 g
s
.57199 .48806 m .56279 .48605 L .57174 .46281 L p .88 .764 .73 r
F P
0 g
s
.5933 .40906 m .57988 .42137 L .57855 .40585 L p .874 .768 .742 r
F P
0 g
s
.57855 .40585 m .59168 .38992 L .5933 .40906 L p .874 .768 .742 r
F P
0 g
s
.52214 .60422 m .5225 .59181 L .54732 .56338 L p .893 .81 .759 r
F P
0 g
s
.54421 .55286 m .54732 .56338 L .5225 .59181 L p .894 .802 .749 r
F P
0 g
s
.48597 .65049 m .48977 .63981 L .52178 .61542 L p .888 .872 .815 r
F P
0 g
s
.52214 .60422 m .52178 .61542 L .48977 .63981 L p .894 .851 .794 r
F P
0 g
s
.60477 .37557 m .59168 .38992 L .58559 .3767 L p .866 .775 .759 r
F P
0 g
s
.58559 .3767 m .59754 .35977 L .60477 .37557 L p .866 .775 .759 r
F P
0 g
s
.7249 .3373 m .71101 .33315 L .69564 .29871 L p .433 .577 .897 r
F P
0 g
s
.68289 .29865 m .69564 .29871 L .71101 .33315 L p .519 .626 .898 r
F P
0 g
s
.79907 .43262 m .78442 .42029 L .78269 .37081 L p .3 .407 .804 r
F P
0 g
s
.7679 .36029 m .78269 .37081 L .78442 .42029 L p .334 .428 .809 r
F P
0 g
s
.43171 .68346 m .42504 .68535 L .38424 .68221 L p .319 .785 .937 r
F P
0 g
s
.54421 .55286 m .54109 .54178 L .55769 .51601 L p .889 .781 .736 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54109 .54178 L p .892 .78 .731 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56279 .48605 L p .886 .771 .729 r
F P
0 g
s
.18911 .47507 m .20183 .48855 L .21913 .5381 L p 0 .18 .714 r
F P
0 g
s
.23079 .55132 m .21913 .5381 L .20183 .48855 L p 0 .175 .71 r
F P
0 g
s
.56025 .46656 m .57174 .46281 L .56279 .48605 L p .887 .77 .727 r
F P
0 g
s
.57174 .46281 m .56025 .46656 L .56464 .44972 L p .885 .769 .728 r
F P
0 g
s
.56464 .44972 m .57756 .44078 L .57174 .46281 L p .885 .769 .728 r
F P
0 g
s
.57756 .44078 m .56464 .44972 L .56637 .43492 L p .884 .769 .731 r
F P
0 g
s
.56637 .43492 m .57988 .42137 L .57756 .44078 L p .884 .769 .731 r
F P
0 g
s
.4385 .67944 m .4454 .67318 L .48223 .65932 L p .794 .948 .922 r
F P
0 g
s
.48597 .65049 m .48223 .65932 L .4454 .67318 L p .842 .921 .886 r
F P
0 g
s
.59168 .38992 m .57855 .40585 L .57361 .39524 L p .878 .777 .746 r
F P
0 g
s
.57361 .39524 m .58559 .3767 L .59168 .38992 L p .878 .777 .746 r
F P
0 g
s
.5225 .59181 m .52287 .57826 L .54421 .55286 L p .894 .802 .749 r
F P
0 g
s
.54109 .54178 m .54421 .55286 L .52287 .57826 L p .896 .795 .741 r
F P
0 g
s
.739 .34333 m .7249 .3373 L .70862 .30083 L p .345 .523 .888 r
F P
0 g
s
.69564 .29871 m .70862 .30083 L .7249 .3373 L p .433 .577 .897 r
F P
0 g
s
.25453 .57784 m .26666 .5905 L .2963 .62826 L p 0 .01 .544 r
F P
0 g
s
.30697 .63867 m .2963 .62826 L .26666 .5905 L p 0 .083 .614 r
F P
0 g
s
.5535 .48437 m .56279 .48605 L .55128 .50901 L p .891 .774 .726 r
F P
0 g
s
.56279 .48605 m .5535 .48437 L .56025 .46656 L p .887 .77 .727 r
F P
0 g
s
.57988 .42137 m .56637 .43492 L .56534 .42314 L p .884 .773 .734 r
F P
0 g
s
.56534 .42314 m .57855 .40585 L .57988 .42137 L p .884 .773 .734 r
F P
0 g
s
.48977 .63981 m .4936 .62733 L .52214 .60422 L p .894 .851 .794 r
F P
0 g
s
.5225 .59181 m .52214 .60422 L .4936 .62733 L p .896 .833 .776 r
F P
0 g
s
.63355 .32052 m .6215 .33154 L .60543 .32042 L p .823 .802 .831 r
F P
0 g
s
.6215 .33154 m .60951 .34467 L .59536 .33522 L p .847 .799 .804 r
F P
0 g
s
.59536 .33522 m .60543 .32042 L .6215 .33154 L p .847 .799 .804 r
F P
0 g
s
.64568 .31169 m .63355 .32052 L .61557 .30763 L p .79 .802 .862 r
F P
0 g
s
.60543 .32042 m .61557 .30763 L .63355 .32052 L p .823 .802 .831 r
F P
0 g
s
.81387 .44561 m .79907 .43262 L .79772 .38236 L p .274 .391 .8 r
F P
0 g
s
.78269 .37081 m .79772 .38236 L .79907 .43262 L p .3 .407 .804 r
F P
0 g
s
.37496 .68023 m .36588 .67623 L .32897 .65554 L p 0 .33 .722 r
F P
0 g
s
.60951 .34467 m .59754 .35977 L .58534 .35191 L p .864 .795 .781 r
F P
0 g
s
.58534 .35191 m .59536 .33522 L .60951 .34467 L p .864 .795 .781 r
F P
0 g
s
.65793 .3051 m .64568 .31169 L .6258 .29695 L p .744 .798 .896 r
F P
0 g
s
.61557 .30763 m .6258 .29695 L .64568 .31169 L p .79 .802 .862 r
F P
0 g
s
.4385 .67944 m .43171 .68346 L .3937 .68197 L p .557 .887 .988 r
F P
0 g
s
.59754 .35977 m .58559 .3767 L .57534 .37034 L p .876 .79 .763 r
F P
0 g
s
.57534 .37034 m .58534 .35191 L .59754 .35977 L p .876 .79 .763 r
F P
0 g
s
.67032 .30076 m .65793 .3051 L .63614 .28842 L p .679 .785 .93 r
F P
0 g
s
.6258 .29695 m .63614 .28842 L .65793 .3051 L p .744 .798 .896 r
F P
0 g
s
.54109 .54178 m .53793 .5302 L .55128 .50901 L p .892 .78 .731 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53793 .5302 L p .894 .78 .727 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .5535 .48437 L p .891 .774 .726 r
F P
0 g
s
.57855 .40585 m .56534 .42314 L .56158 .41517 L p .887 .778 .736 r
F P
0 g
s
.56158 .41517 m .57361 .39524 L .57855 .40585 L p .887 .778 .736 r
F P
0 g
s
.4454 .67318 m .4524 .66466 L .48597 .65049 L p .842 .921 .886 r
F P
0 g
s
.48977 .63981 m .48597 .65049 L .4524 .66466 L p .868 .892 .85 r
F P
0 g
s
.52287 .57826 m .52324 .56368 L .54109 .54178 L p .896 .795 .741 r
F P
0 g
s
.53793 .5302 m .54109 .54178 L .52324 .56368 L p .896 .789 .734 r
F P
0 g
s
.4936 .62733 m .49747 .61315 L .5225 .59181 L p .896 .833 .776 r
F P
0 g
s
.52287 .57826 m .5225 .59181 L .49747 .61315 L p .897 .818 .761 r
F P
0 g
s
.75333 .35105 m .739 .34333 L .72183 .30488 L p .26 .468 .872 r
F P
0 g
s
.70862 .30083 m .72183 .30488 L .739 .34333 L p .345 .523 .888 r
F P
0 g
s
.5516 .45945 m .56464 .44972 L .56025 .46656 L p .892 .774 .725 r
F P
0 g
s
.56464 .44972 m .5516 .45945 L .55275 .44945 L p .891 .774 .726 r
F P
0 g
s
.55275 .44945 m .56637 .43492 L .56464 .44972 L p .891 .774 .726 r
F P
0 g
s
.54866 .47086 m .56025 .46656 L .5535 .48437 L p .893 .775 .724 r
F P
0 g
s
.56025 .46656 m .54866 .47086 L .5516 .45945 L p .892 .774 .725 r
F P
0 g
s
.58559 .3767 m .57361 .39524 L .56534 .3903 L p .884 .787 .748 r
F P
0 g
s
.56534 .3903 m .57534 .37034 L .58559 .3767 L p .884 .787 .748 r
F P
0 g
s
.20183 .48855 m .21463 .50241 L .23079 .55132 L p 0 .175 .71 r
F P
0 g
s
.24258 .56467 m .23079 .55132 L .21463 .50241 L p 0 .186 .717 r
F P
0 g
s
.82882 .45899 m .81387 .44561 L .81298 .39467 L p .255 .382 .799 r
F P
0 g
s
.79772 .38236 m .81298 .39467 L .81387 .44561 L p .274 .391 .8 r
F P
0 g
s
.56637 .43492 m .55275 .44945 L .55204 .44153 L p .891 .776 .727 r
F P
0 g
s
.55204 .44153 m .56534 .42314 L .56637 .43492 L p .891 .776 .727 r
F P
0 g
s
.54413 .48293 m .5535 .48437 L .54482 .50197 L p .894 .777 .724 r
F P
0 g
s
.5535 .48437 m .54413 .48293 L .54866 .47086 L p .893 .775 .724 r
F P
0 g
s
.68289 .29865 m .67032 .30076 L .64662 .28205 L p .592 .758 .957 r
F P
0 g
s
.63614 .28842 m .64662 .28205 L .67032 .30076 L p .679 .785 .93 r
F P
0 g
s
.49747 .61315 m .50137 .59739 L .52287 .57826 L p .897 .818 .761 r
F P
0 g
s
.52324 .56368 m .52287 .57826 L .50137 .59739 L p .898 .805 .749 r
F P
0 g
s
.4524 .66466 m .4595 .65387 L .48977 .63981 L p .868 .892 .85 r
F P
0 g
s
.4936 .62733 m .48977 .63981 L .4595 .65387 L p .881 .865 .819 r
F P
0 g
s
.26666 .5905 m .279 .60229 L .30697 .63867 L p 0 .083 .614 r
F P
0 g
s
.31785 .64787 m .30697 .63867 L .279 .60229 L p 0 .179 .7 r
F P
0 g
s
.56534 .42314 m .55204 .44153 L .5495 .43622 L p .893 .778 .728 r
F P
0 g
s
.5495 .43622 m .56158 .41517 L .56534 .42314 L p .893 .778 .728 r
F P
0 g
s
.52324 .56368 m .52361 .54821 L .53793 .5302 L p .896 .789 .734 r
F P
0 g
s
.53476 .5182 m .53793 .5302 L .52361 .54821 L p .897 .785 .729 r
F P
0 g
s
.53793 .5302 m .53476 .5182 L .54482 .50197 L p .894 .78 .727 r
F P
0 g
s
.38424 .68221 m .37496 .68023 L .34031 .66138 L p .039 .526 .882 r
F P
0 g
s
.57361 .39524 m .56158 .41517 L .55534 .41157 L p .89 .783 .737 r
F P
0 g
s
.55534 .41157 m .56534 .3903 L .57361 .39524 L p .89 .783 .737 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53476 .5182 L p .896 .779 .724 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54413 .48293 L p .894 .777 .724 r
F P
0 g
s
.3937 .68197 m .40333 .67933 L .4385 .67944 L p .557 .887 .988 r
F P
0 g
s
.4454 .67318 m .4385 .67944 L .40333 .67933 L p .705 .91 .967 r
F P
0 g
s
.69564 .29871 m .68289 .29865 L .65727 .27783 L p .481 .712 .972 r
F P
0 g
s
.64662 .28205 m .65727 .27783 L .68289 .29865 L p .592 .758 .957 r
F P
0 g
s
.7679 .36029 m .75333 .35105 L .73529 .3107 L p .183 .417 .853 r
F P
0 g
s
.72183 .30488 m .73529 .3107 L .75333 .35105 L p .26 .468 .872 r
F P
0 g
s
.84389 .47249 m .82882 .45899 L .82843 .40745 L p .244 .379 .801 r
F P
0 g
s
.81298 .39467 m .82843 .40745 L .82882 .45899 L p .255 .382 .799 r
F P
0 g
s
.53843 .46978 m .5516 .45945 L .54866 .47086 L p .896 .777 .722 r
F P
0 g
s
.5516 .45945 m .53843 .46978 L .539 .46473 L p .896 .777 .723 r
F P
0 g
s
.539 .46473 m .55275 .44945 L .5516 .45945 L p .896 .777 .723 r
F P
0 g
s
.53695 .47555 m .54866 .47086 L .54413 .48293 L p .896 .777 .722 r
F P
0 g
s
.54866 .47086 m .53695 .47555 L .53843 .46978 L p .896 .777 .722 r
F P
0 g
s
.50137 .59739 m .5053 .5802 L .52324 .56368 L p .898 .805 .749 r
F P
0 g
s
.52361 .54821 m .52324 .56368 L .5053 .5802 L p .898 .796 .739 r
F P
0 g
s
.60543 .32042 m .59536 .33522 L .5762 .3355 L p .867 .825 .804 r
F P
0 g
s
.59536 .33522 m .58534 .35191 L .56886 .35268 L p .878 .813 .781 r
F P
0 g
s
.56886 .35268 m .5762 .3355 L .59536 .33522 L p .878 .813 .781 r
F P
0 g
s
.4595 .65387 m .46667 .64088 L .4936 .62733 L p .881 .865 .819 r
F P
0 g
s
.49747 .61315 m .4936 .62733 L .46667 .64088 L p .889 .842 .793 r
F P
0 g
s
.55275 .44945 m .539 .46473 L .53863 .46075 L p .896 .778 .723 r
F P
0 g
s
.53863 .46075 m .55204 .44153 L .55275 .44945 L p .896 .778 .723 r
F P
0 g
s
.58534 .35191 m .57534 .37034 L .56155 .37139 L p .886 .802 .762 r
F P
0 g
s
.56155 .37139 m .56886 .35268 L .58534 .35191 L p .886 .802 .762 r
F P
0 g
s
.56158 .41517 m .5495 .43622 L .5453 .43389 L p .894 .781 .729 r
F P
0 g
s
.5453 .43389 m .55534 .41157 L .56158 .41517 L p .894 .781 .729 r
F P
0 g
s
.53467 .48166 m .54413 .48293 L .5383 .49486 L p .897 .778 .722 r
F P
0 g
s
.54413 .48293 m .53467 .48166 L .53695 .47555 L p .896 .777 .722 r
F P
0 g
s
.61557 .30763 m .60543 .32042 L .58358 .31999 L p .851 .839 .833 r
F P
0 g
s
.5762 .3355 m .58358 .31999 L .60543 .32042 L p .867 .825 .804 r
F P
0 g
s
.52361 .54821 m .52398 .53199 L .53476 .5182 L p .897 .785 .729 r
F P
0 g
s
.53157 .50585 m .53476 .5182 L .52398 .53199 L p .897 .781 .725 r
F P
0 g
s
.53476 .5182 m .53157 .50585 L .5383 .49486 L p .896 .779 .724 r
F P
0 g
s
.21463 .50241 m .22754 .51638 L .24258 .56467 L p 0 .186 .717 r
F P
0 g
s
.25453 .57784 m .24258 .56467 L .22754 .51638 L p 0 .212 .732 r
F P
0 g
s
.57534 .37034 m .56534 .3903 L .55426 .39145 L p .89 .794 .747 r
F P
0 g
s
.55426 .39145 m .56155 .37139 L .57534 .37034 L p .89 .794 .747 r
F P
0 g
s
.55204 .44153 m .53863 .46075 L .53735 .45809 L p .896 .778 .723 r
F P
0 g
s
.53735 .45809 m .5495 .43622 L .55204 .44153 L p .896 .778 .723 r
F P
0 g
s
.6258 .29695 m .61557 .30763 L .59103 .30627 L p .827 .853 .867 r
F P
0 g
s
.58358 .31999 m .59103 .30627 L .61557 .30763 L p .851 .839 .833 r
F P
0 g
s
.40333 .67933 m .41311 .6742 L .4454 .67318 L p .705 .91 .967 r
F P
0 g
s
.4524 .66466 m .4454 .67318 L .41311 .6742 L p .787 .898 .921 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53157 .50585 L p .897 .779 .722 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53467 .48166 L p .897 .778 .722 r
F P
0 g
s
.5053 .5802 m .50924 .56179 L .52361 .54821 L p .898 .796 .739 r
F P
0 g
s
.52398 .53199 m .52361 .54821 L .50924 .56179 L p .898 .788 .732 r
F P
0 g
s
.56534 .3903 m .55534 .41157 L .54698 .41263 L p .894 .787 .736 r
F P
0 g
s
.54698 .41263 m .55426 .39145 L .56534 .3903 L p .894 .787 .736 r
F P
0 g
s
.70862 .30083 m .69564 .29871 L .6681 .2757 L p .349 .646 .966 r
F P
0 g
s
.65727 .27783 m .6681 .2757 L .69564 .29871 L p .481 .712 .972 r
F P
0 g
s
.46667 .64088 m .4739 .62581 L .49747 .61315 L p .889 .842 .793 r
F P
0 g
s
.50137 .59739 m .49747 .61315 L .4739 .62581 L p .893 .824 .773 r
F P
0 g
s
.34031 .66138 m .35187 .66512 L .38424 .68221 L p .039 .526 .882 r
F P
0 g
s
.3937 .68197 m .38424 .68221 L .35187 .66512 L p .304 .686 .976 r
F P
0 g
s
.85906 .48583 m .84389 .47249 L .84407 .42038 L p .242 .384 .806 r
F P
0 g
s
.82843 .40745 m .84407 .42038 L .84389 .47249 L p .244 .379 .801 r
F P
0 g
s
.279 .60229 m .29156 .6129 L .31785 .64787 L p 0 .179 .7 r
F P
0 g
s
.32897 .65554 m .31785 .64787 L .29156 .6129 L p 0 .294 .788 r
F P
0 g
s
.63614 .28842 m .6258 .29695 L .59855 .29443 L p .789 .866 .906 r
F P
0 g
s
.59103 .30627 m .59855 .29443 L .6258 .29695 L p .827 .853 .867 r
F P
0 g
s
.78269 .37081 m .7679 .36029 L .74901 .31809 L p .118 .373 .832 r
F P
0 g
s
.73529 .3107 m .74901 .31809 L .7679 .36029 L p .183 .417 .853 r
F P
0 g
s
.5495 .43622 m .53735 .45809 L .53523 .45696 L p .897 .779 .723 r
F P
0 g
s
.53523 .45696 m .5453 .43389 L .5495 .43622 L p .897 .779 .723 r
F P
0 g
s
.55534 .41157 m .5453 .43389 L .5397 .43471 L p .896 .783 .728 r
F P
0 g
s
.5397 .43471 m .54698 .41263 L .55534 .41157 L p .896 .783 .728 r
F P
0 g
s
.52398 .53199 m .52436 .51517 L .53157 .50585 L p .897 .781 .725 r
F P
0 g
s
.52835 .49324 m .53157 .50585 L .52436 .51517 L p .898 .779 .722 r
F P
0 g
s
.53157 .50585 m .52835 .49324 L .53174 .48769 L p .897 .779 .722 r
F P
0 g
s
.50924 .56179 m .5132 .54237 L .52398 .53199 L p .898 .788 .732 r
F P
0 g
s
.52436 .51517 m .52398 .53199 L .5132 .54237 L p .898 .783 .726 r
F P
0 g
s
.4739 .62581 m .48117 .60882 L .50137 .59739 L p .893 .824 .773 r
F P
0 g
s
.5053 .5802 m .50137 .59739 L .48117 .60882 L p .895 .809 .756 r
F P
0 g
s
.52511 .48046 m .53843 .46978 L .53695 .47555 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .539 .46473 L .53843 .46978 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .53695 .47555 L .53467 .48166 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .53863 .46075 L .539 .46473 L closepath p .898 .778 .721 r
F P
0 g
s
.41311 .6742 m .42304 .66652 L .4524 .66466 L p .787 .898 .921 r
F P
0 g
s
.4595 .65387 m .4524 .66466 L .42304 .66652 L p .831 .875 .876 r
F P
0 g
s
.52511 .48046 m .53467 .48166 L .53174 .48769 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .53735 .45809 L .53863 .46075 L closepath p .898 .778 .721 r
F P
0 g
s
.5453 .43389 m .53523 .45696 L .53241 .45742 L p .897 .78 .723 r
F P
0 g
s
.53241 .45742 m .5397 .43471 L .5453 .43389 L p .897 .78 .723 r
F P
0 g
s
.64662 .28205 m .63614 .28842 L .60617 .2845 L p .731 .872 .947 r
F P
0 g
s
.59855 .29443 m .60617 .2845 L .63614 .28842 L p .789 .866 .906 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .49324 L closepath p .898 .778 .721 r
F P
0 g
s
.48117 .60882 m .48848 .59012 L .5053 .5802 L p .895 .809 .756 r
F P
0 g
s
.50924 .56179 m .5053 .5802 L .48848 .59012 L p .896 .798 .744 r
F P
0 g
s
.5132 .54237 m .51717 .52218 L .52436 .51517 L p .898 .783 .726 r
F P
0 g
s
.52474 .49794 m .52436 .51517 L .51717 .52218 L p .898 .78 .723 r
F P
0 g
s
.52436 .51517 m .52474 .49794 L .52835 .49324 L p .898 .779 .722 r
F P
0 g
s
.22754 .51638 m .24058 .53015 L .25453 .57784 L p 0 .212 .732 r
F P
0 g
s
.26666 .5905 m .25453 .57784 L .24058 .53015 L p .019 .251 .754 r
F P
0 g
s
.72183 .30488 m .70862 .30083 L .67914 .27555 L p .207 .564 .937 r
F P
0 g
s
.6681 .2757 m .67914 .27555 L .70862 .30083 L p .349 .646 .966 r
F P
0 g
s
.52511 .48046 m .53523 .45696 L .53735 .45809 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .52835 .49324 L .52474 .49794 L closepath p .898 .778 .721 r
F P
0 g
s
.84407 .42038 m .85986 .43317 L .85906 .48583 L p .242 .384 .806 r
F P
0 g
s
.35187 .66512 m .36364 .66654 L .3937 .68197 L p .304 .686 .976 r
F P
0 g
s
.40333 .67933 m .3937 .68197 L .36364 .66654 L p .514 .779 .992 r
F P
0 g
s
.48848 .59012 m .49581 .56996 L .50924 .56179 L p .896 .798 .744 r
F P
0 g
s
.5132 .54237 m .50924 .56179 L .49581 .56996 L p .897 .79 .734 r
F P
0 g
s
.56155 .37139 m .55426 .39145 L .54107 .39868 L p .895 .797 .744 r
F P
0 g
s
.55426 .39145 m .54698 .41263 L .53707 .41833 L p .896 .789 .734 r
F P
0 g
s
.53707 .41833 m .54107 .39868 L .55426 .39145 L p .896 .789 .734 r
F P
0 g
s
.56886 .35268 m .56155 .37139 L .54509 .37992 L p .893 .807 .756 r
F P
0 g
s
.54107 .39868 m .54509 .37992 L .56155 .37139 L p .895 .797 .744 r
F P
0 g
s
.54698 .41263 m .5397 .43471 L .53308 .43866 L p .897 .784 .727 r
F P
0 g
s
.53308 .43866 m .53707 .41833 L .54698 .41263 L p .897 .784 .727 r
F P
0 g
s
.42304 .66652 m .43308 .65632 L .4595 .65387 L p .831 .875 .876 r
F P
0 g
s
.46667 .64088 m .4595 .65387 L .43308 .65632 L p .857 .853 .837 r
F P
0 g
s
.52511 .48046 m .53241 .45742 L .53523 .45696 L closepath p .898 .778 .721 r
F P
0 g
s
.5762 .3355 m .56886 .35268 L .54912 .36222 L p .89 .82 .772 r
F P
0 g
s
.54509 .37992 m .54912 .36222 L .56886 .35268 L p .893 .807 .756 r
F P
0 g
s
.51717 .52218 m .52114 .50146 L .52474 .49794 L p .898 .78 .723 r
F P
0 g
s
.52511 .48046 m .52474 .49794 L .52114 .50146 L closepath p .898 .778 .721 r
F P
0 g
s
.49581 .56996 m .50314 .54862 L .5132 .54237 L p .897 .79 .734 r
F P
0 g
s
.51717 .52218 m .5132 .54237 L .50314 .54862 L p .897 .784 .727 r
F P
0 g
s
.5397 .43471 m .53241 .45742 L .5291 .45945 L p .898 .78 .723 r
F P
0 g
s
.5291 .45945 m .53308 .43866 L .5397 .43471 L p .898 .78 .723 r
F P
0 g
s
.79772 .38236 m .78269 .37081 L .763 .32682 L p .067 .338 .814 r
F P
0 g
s
.74901 .31809 m .763 .32682 L .78269 .37081 L p .118 .373 .832 r
F P
0 g
s
.29156 .6129 m .30434 .62201 L .32897 .65554 L p 0 .294 .788 r
F P
0 g
s
.34031 .66138 m .32897 .65554 L .30434 .62201 L p .087 .417 .865 r
F P
0 g
s
.58358 .31999 m .5762 .3355 L .55318 .34574 L p .885 .835 .792 r
F P
0 g
s
.54912 .36222 m .55318 .34574 L .5762 .3355 L p .89 .82 .772 r
F P
0 g
s
.65727 .27783 m .64662 .28205 L .6139 .27652 L p .644 .865 .982 r
F P
0 g
s
.60617 .2845 m .6139 .27652 L .64662 .28205 L p .731 .872 .947 r
F P
0 g
s
.50314 .54862 m .51047 .52638 L .51717 .52218 L p .897 .784 .727 r
F P
0 g
s
.52114 .50146 m .51717 .52218 L .51047 .52638 L p .898 .78 .723 r
F P
0 g
s
.52511 .48046 m .5291 .45945 L .53241 .45742 L closepath p .898 .778 .721 r
F P
0 g
s
.51047 .52638 m .5178 .50356 L .52114 .50146 L p .898 .78 .723 r
F P
0 g
s
.52511 .48046 m .52114 .50146 L .5178 .50356 L closepath p .898 .778 .721 r
F P
0 g
s
.43308 .65632 m .44322 .64366 L .46667 .64088 L p .857 .853 .837 r
F P
0 g
s
.4739 .62581 m .46667 .64088 L .44322 .64366 L p .872 .834 .806 r
F P
0 g
s
.52511 .48046 m .52549 .46292 L .5291 .45945 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .52186 .4676 L .52549 .46292 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52186 .4676 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51547 .47926 L .51844 .47318 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51315 .48543 L .51547 .47926 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51166 .49127 L .51315 .48543 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51109 .49636 L .51166 .49127 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51147 .50036 L .51109 .49636 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51279 .50299 L .51147 .50036 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .51495 .50408 L .51279 .50299 L closepath p .898 .778 .721 r
F P
0 g
s
.52511 .48046 m .5178 .50356 L .51495 .50408 L closepath p .898 .778 .721 r
F P
0 g
s
.59103 .30627 m .58358 .31999 L .55727 .3306 L p .876 .854 .817 r
F P
0 g
s
.55318 .34574 m .55727 .3306 L .58358 .31999 L p .885 .835 .792 r
F P
0 g
s
.53308 .43866 m .5291 .45945 L .52549 .46292 L p .898 .78 .723 r
F P
0 g
s
.50475 .52745 m .51495 .50408 L .5178 .50356 L p .897 .78 .723 r
F P
0 g
s
.5178 .50356 m .51047 .52638 L .50475 .52745 L p .897 .78 .723 r
F P
0 g
s
.53707 .41833 m .53308 .43866 L .52588 .44549 L p .898 .783 .726 r
F P
0 g
s
.52549 .46292 m .52588 .44549 L .53308 .43866 L p .898 .78 .723 r
F P
0 g
s
.36364 .66654 m .37561 .66547 L .40333 .67933 L p .514 .779 .992 r
F P
0 g
s
.41311 .6742 m .40333 .67933 L .37561 .66547 L p .653 .817 .962 r
F P
0 g
s
.44322 .64366 m .45342 .62869 L .4739 .62581 L p .872 .834 .806 r
F P
0 g
s
.48117 .60882 m .4739 .62581 L .45342 .62869 L p .881 .818 .781 r
F P
0 g
s
.73529 .3107 m .72183 .30488 L .69039 .27727 L p .072 .475 .89 r
F P
0 g
s
.67914 .27555 m .69039 .27727 L .72183 .30488 L p .207 .564 .937 r
F P
0 g
s
.24058 .53015 m .25377 .54344 L .26666 .5905 L p .019 .251 .754 r
F P
0 g
s
.279 .60229 m .26666 .5905 L .25377 .54344 L p .093 .301 .78 r
F P
0 g
s
.49451 .55024 m .50475 .52745 L .51047 .52638 L p .896 .783 .728 r
F P
0 g
s
.51047 .52638 m .50314 .54862 L .49451 .55024 L p .896 .783 .728 r
F P
0 g
s
.54107 .39868 m .53707 .41833 L .52626 .42834 L p .897 .788 .732 r
F P
0 g
s
.52588 .44549 m .52626 .42834 L .53707 .41833 L p .898 .783 .726 r
F P
0 g
s
.52588 .44549 m .52549 .46292 L .52186 .4676 L p .898 .779 .722 r
F P
0 g
s
.45342 .62869 m .46368 .6116 L .48117 .60882 L p .881 .818 .781 r
F P
0 g
s
.48848 .59012 m .48117 .60882 L .46368 .6116 L p .887 .805 .762 r
F P
0 g
s
.50039 .52531 m .51279 .50299 L .51495 .50408 L p .897 .779 .723 r
F P
0 g
s
.51495 .50408 m .50475 .52745 L .50039 .52531 L p .897 .779 .723 r
F P
0 g
s
.59855 .29443 m .59103 .30627 L .5614 .31691 L p .862 .874 .845 r
F P
0 g
s
.55727 .3306 m .5614 .31691 L .59103 .30627 L p .876 .854 .817 r
F P
0 g
s
.48424 .57208 m .49451 .55024 L .50314 .54862 L p .894 .788 .736 r
F P
0 g
s
.50314 .54862 m .49581 .56996 L .48424 .57208 L p .894 .788 .736 r
F P
0 g
s
.46368 .6116 m .47396 .59263 L .48848 .59012 L p .887 .805 .762 r
F P
0 g
s
.49581 .56996 m .48848 .59012 L .47396 .59263 L p .891 .795 .747 r
F P
0 g
s
.47396 .59263 m .48424 .57208 L .49581 .56996 L p .891 .795 .747 r
F P
0 g
s
.54509 .37992 m .54107 .39868 L .52664 .41162 L p .897 .795 .739 r
F P
0 g
s
.52626 .42834 m .52664 .41162 L .54107 .39868 L p .897 .788 .732 r
F P
0 g
s
.6681 .2757 m .65727 .27783 L .62175 .27045 L p .521 .831 1 r
F P
0 g
s
.6139 .27652 m .62175 .27045 L .65727 .27783 L p .644 .865 .982 r
F P
0 g
s
.20183 .48855 m .18911 .47507 L .19318 .42214 L p .233 .36 .788 r
F P
0 g
s
.52186 .4676 m .51858 .45476 L .52588 .44549 L p .898 .779 .722 r
F P
0 g
s
.51858 .45476 m .52186 .4676 L .51844 .47318 L p .897 .779 .722 r
F P
0 g
s
.49772 .52008 m .51147 .50036 L .51279 .50299 L p .896 .778 .723 r
F P
0 g
s
.51279 .50299 m .50039 .52531 L .49772 .52008 L p .896 .778 .723 r
F P
0 g
s
.30434 .62201 m .31735 .62934 L .34031 .66138 L p .087 .417 .865 r
F P
0 g
s
.35187 .66512 m .34031 .66138 L .31735 .62934 L p .265 .529 .914 r
F P
0 g
s
.81298 .39467 m .79772 .38236 L .77724 .33663 L p .031 .313 .801 r
F P
0 g
s
.763 .32682 m .77724 .33663 L .79772 .38236 L p .067 .338 .814 r
F P
0 g
s
.52626 .42834 m .52588 .44549 L .51858 .45476 L p .897 .781 .725 r
F P
0 g
s
.54912 .36222 m .54509 .37992 L .52703 .39549 L p .897 .804 .749 r
F P
0 g
s
.52664 .41162 m .52703 .39549 L .54509 .37992 L p .897 .795 .739 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51858 .45476 L p .897 .779 .722 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51547 .47926 L p .897 .778 .722 r
F P
0 g
s
.37561 .66547 m .38776 .66181 L .41311 .6742 L p .653 .817 .962 r
F P
0 g
s
.42304 .66652 m .41311 .6742 L .38776 .66181 L p .74 .826 .918 r
F P
0 g
s
.48791 .54707 m .50039 .52531 L .50475 .52745 L p .894 .781 .729 r
F P
0 g
s
.50475 .52745 m .49451 .55024 L .48791 .54707 L p .894 .781 .729 r
F P
0 g
s
.49692 .5121 m .51109 .49636 L .51147 .50036 L p .896 .778 .723 r
F P
0 g
s
.51147 .50036 m .49772 .52008 L .49692 .5121 L p .896 .778 .723 r
F P
0 g
s
.51547 .47926 m .50572 .47795 L .5117 .46583 L p .897 .778 .722 r
F P
0 g
s
.50572 .47795 m .51547 .47926 L .51315 .48543 L p .896 .777 .722 r
F P
0 g
s
.60617 .2845 m .59855 .29443 L .56557 .30474 L p .84 .896 .879 r
F P
0 g
s
.5614 .31691 m .56557 .30474 L .59855 .29443 L p .862 .874 .845 r
F P
0 g
s
.49806 .50193 m .51166 .49127 L .51109 .49636 L p .896 .777 .723 r
F P
0 g
s
.51109 .49636 m .49692 .5121 L .49806 .50193 L p .896 .777 .723 r
F P
0 g
s
.51315 .48543 m .50106 .49027 L .50572 .47795 L p .896 .777 .722 r
F P
0 g
s
.50106 .49027 m .51315 .48543 L .51166 .49127 L p .896 .777 .722 r
F P
0 g
s
.51166 .49127 m .49806 .50193 L .50106 .49027 L p .896 .777 .722 r
F P
0 g
s
.55318 .34574 m .54912 .36222 L .52742 .38007 L p .895 .815 .761 r
F P
0 g
s
.52703 .39549 m .52742 .38007 L .54912 .36222 L p .897 .804 .749 r
F P
0 g
s
.52664 .41162 m .52626 .42834 L .51528 .44201 L p .897 .784 .729 r
F P
0 g
s
.51858 .45476 m .51528 .44201 L .52626 .42834 L p .897 .781 .725 r
F P
0 g
s
.51528 .44201 m .51858 .45476 L .5117 .46583 L p .896 .779 .724 r
F P
0 g
s
.47537 .56788 m .48791 .54707 L .49451 .55024 L p .891 .784 .737 r
F P
0 g
s
.49451 .55024 m .48424 .57208 L .47537 .56788 L p .891 .784 .737 r
F P
0 g
s
.48385 .53928 m .49772 .52008 L .50039 .52531 L p .893 .779 .728 r
F P
0 g
s
.50039 .52531 m .48791 .54707 L .48385 .53928 L p .893 .779 .728 r
F P
0 g
s
.25377 .54344 m .26713 .55592 L .279 .60229 L p .093 .301 .78 r
F P
0 g
s
.29156 .6129 m .279 .60229 L .26713 .55592 L p .179 .358 .805 r
F P
0 g
s
.38776 .66181 m .40006 .65552 L .42304 .66652 L p .74 .826 .918 r
F P
0 g
s
.43308 .65632 m .42304 .66652 L .40006 .65552 L p .794 .823 .875 r
F P
0 g
s
.74901 .31809 m .73529 .3107 L .70188 .2807 L p 0 .391 .837 r
F P
0 g
s
.69039 .27727 m .70188 .2807 L .73529 .3107 L p .072 .475 .89 r
F P
0 g
s
.19318 .42214 m .20636 .4356 L .20183 .48855 L p .233 .36 .788 r
F P
0 g
s
.21463 .50241 m .20183 .48855 L .20636 .4356 L p .247 .359 .782 r
F P
0 g
s
.67914 .27555 m .6681 .2757 L .62974 .26625 L p .363 .764 .985 r
F P
0 g
s
.62175 .27045 m .62974 .26625 L .6681 .2757 L p .521 .831 1 r
F P
0 g
s
.55727 .3306 m .55318 .34574 L .52781 .36549 L p .893 .828 .775 r
F P
0 g
s
.52742 .38007 m .52781 .36549 L .55318 .34574 L p .895 .815 .761 r
F P
0 g
s
.31735 .62934 m .33058 .63462 L .35187 .66512 L p .265 .529 .914 r
F P
0 g
s
.36364 .66654 m .35187 .66512 L .33058 .63462 L p .424 .618 .932 r
F P
0 g
s
.46279 .58742 m .47537 .56788 L .48424 .57208 L p .885 .788 .748 r
F P
0 g
s
.48424 .57208 m .47396 .59263 L .46279 .58742 L p .885 .788 .748 r
F P
0 g
s
.52703 .39549 m .52664 .41162 L .51196 .42944 L p .896 .789 .734 r
F P
0 g
s
.51528 .44201 m .51196 .42944 L .52664 .41162 L p .897 .784 .729 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51528 .44201 L p .896 .779 .724 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50572 .47795 L p .894 .777 .724 r
F P
0 g
s
.6139 .27652 m .60617 .2845 L .5698 .29413 L p .804 .916 .915 r
F P
0 g
s
.56557 .30474 m .5698 .29413 L .60617 .2845 L p .84 .896 .879 r
F P
0 g
s
.40006 .65552 m .41248 .6466 L .43308 .65632 L p .794 .823 .875 r
F P
0 g
s
.44322 .64366 m .43308 .65632 L .41248 .6466 L p .829 .816 .837 r
F P
0 g
s
.48261 .52738 m .49692 .5121 L .49772 .52008 L p .892 .776 .727 r
F P
0 g
s
.49772 .52008 m .48385 .53928 L .48261 .52738 L p .892 .776 .727 r
F P
0 g
s
.45018 .60533 m .46279 .58742 L .47396 .59263 L p .878 .793 .763 r
F P
0 g
s
.47396 .59263 m .46368 .6116 L .45018 .60533 L p .878 .793 .763 r
F P
0 g
s
.82843 .40745 m .81298 .39467 L .79175 .34723 L p .011 .3 .794 r
F P
0 g
s
.77724 .33663 m .79175 .34723 L .81298 .39467 L p .031 .313 .801 r
F P
0 g
s
.51196 .42944 m .51528 .44201 L .50491 .45842 L p .894 .78 .727 r
F P
0 g
s
.41248 .6466 m .425 .63516 L .44322 .64366 L p .829 .816 .837 r
F P
0 g
s
.45342 .62869 m .44322 .64366 L .425 .63516 L p .851 .807 .807 r
F P
0 g
s
.50572 .47795 m .49588 .47645 L .50491 .45842 L p .894 .777 .724 r
F P
0 g
s
.49588 .47645 m .50572 .47795 L .50106 .49027 L p .893 .775 .724 r
F P
0 g
s
.46988 .5576 m .48385 .53928 L .48791 .54707 L p .887 .779 .736 r
F P
0 g
s
.48791 .54707 m .47537 .56788 L .46988 .5576 L p .887 .779 .736 r
F P
0 g
s
.43757 .62133 m .45018 .60533 L .46368 .6116 L p .867 .8 .782 r
F P
0 g
s
.46368 .6116 m .45342 .62869 L .43757 .62133 L p .867 .8 .782 r
F P
0 g
s
.48432 .5122 m .49806 .50193 L .49692 .5121 L p .891 .774 .726 r
F P
0 g
s
.49692 .5121 m .48261 .52738 L .48432 .5122 L p .891 .774 .726 r
F P
0 g
s
.5614 .31691 m .55727 .3306 L .52821 .35183 L p .89 .844 .793 r
F P
0 g
s
.52781 .36549 m .52821 .35183 L .55727 .3306 L p .893 .828 .775 r
F P
0 g
s
.425 .63516 m .43757 .62133 L .45342 .62869 L p .851 .807 .807 r
F P
0 g
s
.52742 .38007 m .52703 .39549 L .50862 .41713 L p .895 .794 .741 r
F P
0 g
s
.51196 .42944 m .50862 .41713 L .52703 .39549 L p .896 .789 .734 r
F P
0 g
s
.50106 .49027 m .48885 .49481 L .49588 .47645 L p .893 .775 .724 r
F P
0 g
s
.48885 .49481 m .50106 .49027 L .49806 .50193 L p .892 .774 .725 r
F P
0 g
s
.49806 .50193 m .48432 .5122 L .48885 .49481 L p .892 .774 .725 r
F P
0 g
s
.20636 .4356 m .21957 .44935 L .21463 .50241 L p .247 .359 .782 r
F P
0 g
s
.22754 .51638 m .21463 .50241 L .21957 .44935 L p .269 .367 .779 r
F P
0 g
s
.26713 .55592 m .28068 .56732 L .29156 .6129 L p .179 .358 .805 r
F P
0 g
s
.30434 .62201 m .29156 .6129 L .28068 .56732 L p .271 .419 .828 r
F P
0 g
s
.33058 .63462 m .34402 .63766 L .36364 .66654 L p .424 .618 .932 r
F P
0 g
s
.37561 .66547 m .36364 .66654 L .34402 .63766 L p .552 .681 .924 r
F P
0 g
s
.62175 .27045 m .6139 .27652 L .57408 .28509 L p .747 .929 .949 r
F P
0 g
s
.5698 .29413 m .57408 .28509 L .6139 .27652 L p .804 .916 .915 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51196 .42944 L p .894 .78 .727 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .49588 .47645 L p .891 .774 .726 r
F P
0 g
s
.45583 .5747 m .46988 .5576 L .47537 .56788 L p .879 .778 .746 r
F P
0 g
s
.47537 .56788 m .46279 .58742 L .45583 .5747 L p .879 .778 .746 r
F P
0 g
s
.69039 .27727 m .67914 .27555 L .63789 .26383 L p .187 .664 .932 r
F P
0 g
s
.62974 .26625 m .63789 .26383 L .67914 .27555 L p .363 .764 .985 r
F P
0 g
s
.50862 .41713 m .51196 .42944 L .49806 .45095 L p .892 .78 .731 r
F P
0 g
s
.46819 .54188 m .48261 .52738 L .48385 .53928 L p .885 .773 .734 r
F P
0 g
s
.48385 .53928 m .46988 .5576 L .46819 .54188 L p .885 .773 .734 r
F P
0 g
s
.763 .32682 m .74901 .31809 L .71361 .28564 L p 0 .321 .786 r
F P
0 g
s
.70188 .2807 m .71361 .28564 L .74901 .31809 L p 0 .391 .837 r
F P
0 g
s
.56557 .30474 m .5614 .31691 L .52861 .33918 L p .883 .861 .813 r
F P
0 g
s
.52821 .35183 m .52861 .33918 L .5614 .31691 L p .89 .844 .793 r
F P
0 g
s
.52781 .36549 m .52742 .38007 L .50525 .40516 L p .894 .801 .75 r
F P
0 g
s
.50862 .41713 m .50525 .40516 L .52742 .38007 L p .895 .794 .741 r
F P
0 g
s
.34402 .63766 m .35764 .63829 L .37561 .66547 L p .552 .681 .924 r
F P
0 g
s
.38776 .66181 m .37561 .66547 L .35764 .63829 L p .649 .722 .902 r
F P
0 g
s
.49588 .47645 m .48595 .47465 L .49806 .45095 L p .891 .774 .726 r
F P
0 g
s
.48595 .47465 m .49588 .47645 L .48885 .49481 L p .888 .771 .727 r
F P
0 g
s
.47045 .52183 m .48432 .5122 L .48261 .52738 L p .884 .77 .731 r
F P
0 g
s
.48261 .52738 m .46819 .54188 L .47045 .52183 L p .884 .77 .731 r
F P
0 g
s
.21957 .44935 m .23285 .46314 L .22754 .51638 L p .269 .367 .779 r
F P
0 g
s
.24058 .53015 m .22754 .51638 L .23285 .46314 L p .3 .383 .78 r
F P
0 g
s
.84407 .42038 m .82843 .40745 L .80649 .35834 L p .005 .298 .793 r
F P
0 g
s
.79175 .34723 m .80649 .35834 L .82843 .40745 L p .011 .3 .794 r
F P
0 g
s
.44173 .59027 m .45583 .5747 L .46279 .58742 L p .868 .778 .759 r
F P
0 g
s
.46279 .58742 m .45018 .60533 L .44173 .59027 L p .868 .778 .759 r
F P
0 g
s
.48885 .49481 m .47651 .49886 L .48595 .47465 L p .888 .771 .727 r
F P
0 g
s
.47651 .49886 m .48885 .49481 L .48432 .5122 L p .885 .769 .728 r
F P
0 g
s
.48432 .5122 m .47045 .52183 L .47651 .49886 L p .885 .769 .728 r
F P
0 g
s
.28068 .56732 m .29441 .57736 L .30434 .62201 L p .271 .419 .828 r
F P
0 g
s
.31735 .62934 m .30434 .62201 L .29441 .57736 L p .365 .48 .843 r
F P
0 g
s
.52821 .35183 m .52781 .36549 L .50185 .39358 L p .892 .808 .759 r
F P
0 g
s
.50525 .40516 m .50185 .39358 L .52781 .36549 L p .894 .801 .75 r
F P
0 g
s
.50525 .40516 m .50862 .41713 L .49116 .44341 L p .889 .781 .736 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50862 .41713 L p .892 .78 .731 r
F P
0 g
s
.5698 .29413 m .56557 .30474 L .52901 .32759 L p .874 .88 .837 r
F P
0 g
s
.52861 .33918 m .52901 .32759 L .56557 .30474 L p .883 .861 .813 r
F P
0 g
s
.45365 .5553 m .46819 .54188 L .46988 .5576 L p .875 .769 .742 r
F P
0 g
s
.46988 .5576 m .45583 .5747 L .45365 .5553 L p .875 .769 .742 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48595 .47465 L p .886 .772 .729 r
F P
0 g
s
.35764 .63829 m .37143 .63641 L .38776 .66181 L p .649 .722 .902 r
F P
0 g
s
.40006 .65552 m .38776 .66181 L .37143 .63641 L p .719 .747 .874 r
F P
0 g
s
.4276 .60401 m .44173 .59027 L .45018 .60533 L p .854 .777 .776 r
F P
0 g
s
.45018 .60533 m .43757 .62133 L .4276 .60401 L p .854 .777 .776 r
F P
0 g
s
.62974 .26625 m .62175 .27045 L .57844 .27762 L p .663 .926 .973 r
F P
0 g
s
.57408 .28509 m .57844 .27762 L .62175 .27045 L p .747 .929 .949 r
F P
0 g
s
.37143 .63641 m .38535 .63199 L .40006 .65552 L p .719 .747 .874 r
F P
0 g
s
.41248 .6466 m .40006 .65552 L .38535 .63199 L p .77 .761 .845 r
F P
0 g
s
.41347 .61567 m .4276 .60401 L .43757 .62133 L p .834 .774 .795 r
F P
0 g
s
.43757 .62133 m .425 .63516 L .41347 .61567 L p .834 .774 .795 r
F P
0 g
s
.70188 .2807 m .69039 .27727 L .66458 .26898 L p .019 .549 .854 r
F P
0 g
s
.67085 .27087 m .70188 .2807 L .66458 .26898 L .019 .549 .854 r
F
.64621 .26307 m .6547 .26382 L .70188 .2807 L p F P
0 g
s
.71361 .28564 m .70188 .2807 L .67043 .26945 L p 0 .44 .769 r
F P
0 g
s
.67043 .26945 m .6547 .26382 L p .67772 .27235 L 0 .44 .769 r
F P
0 g
s
.67772 .27235 m .71361 .28564 L .67043 .26945 L 0 .44 .769 r
F
.6547 .26382 m .66337 .26592 L .6933 .27767 L p F P
0 g
s
.6933 .27767 m .71361 .28564 L p .68664 .27565 L 0 .44 .769 r
F P
0 g
s
.6547 .26382 m .6933 .27767 L .68664 .27565 L 0 .44 .769 r
F
.71361 .28564 m .72559 .29186 L .763 .32682 L p 0 .321 .786 r
F P
0 g
s
.72559 .29186 m .71361 .28564 L .67607 .2709 L p 0 .35 .696 r
F P
0 g
s
.67607 .2709 m .66337 .26592 L p .68383 .27445 L 0 .35 .696 r
F P
0 g
s
.68383 .27445 m .72559 .29186 L .67607 .2709 L 0 .35 .696 r
F
.66337 .26592 m .67224 .26915 L .70824 .28447 L p F P
0 g
s
.66337 .26592 m .70824 .28447 L .70053 .28141 L 0 .35 .696 r
F
.63789 .26383 m .64621 .26307 L .69039 .27727 L p .187 .664 .932 r
F P
0 g
s
.70824 .28447 m .72559 .29186 L p .70053 .28141 L 0 .35 .696 r
F P
0 g
s
.77724 .33663 m .763 .32682 L .72559 .29186 L p 0 .268 .745 r
F P
0 g
s
.72559 .29186 m .73781 .29912 L .77724 .33663 L p 0 .268 .745 r
F P
0 g
s
.73781 .29912 m .72559 .29186 L .68142 .27306 L p 0 .285 .643 r
F P
0 g
s
.68142 .27306 m .67224 .26915 L p .68873 .27669 L 0 .285 .643 r
F P
0 g
s
.68873 .27669 m .73781 .29912 L .68142 .27306 L 0 .285 .643 r
F
.67224 .26915 m .68129 .27328 L .72385 .29274 L p F P
0 g
s
.67224 .26915 m .72385 .29274 L .71569 .28901 L 0 .285 .643 r
F
.68129 .27328 m .69052 .27807 L .74022 .30224 L p .335 0 0 r
F P
0 g
s
.79175 .34723 m .77724 .33663 L .73781 .29912 L p 0 .234 .718 r
F P
0 g
s
.73781 .29912 m .75028 .30714 L .79175 .34723 L p 0 .234 .718 r
F P
0 g
s
.74022 .30224 m .75028 .30714 L p .73259 .29845 L .335 0 0 r
F P
0 g
s
.68129 .27328 m .74022 .30224 L .73259 .29845 L .335 0 0 r
F
.72385 .29274 m .73781 .29912 L p .71569 .28901 L 0 .285 .643 r
F P
0 g
s
.66458 .26898 m .64621 .26307 L p .67085 .27087 L .019 .549 .854 r
F P
0 g
s
.23285 .46314 m .2462 .47674 L .24058 .53015 L p .3 .383 .78 r
F P
0 g
s
.25377 .54344 m .24058 .53015 L .2462 .47674 L p .338 .404 .783 r
F P
0 g
s
.38535 .63199 m .39937 .62504 L .41248 .6466 L p .77 .761 .845 r
F P
0 g
s
.425 .63516 m .41248 .6466 L .39937 .62504 L p .807 .77 .819 r
F P
0 g
s
.39937 .62504 m .41347 .61567 L .425 .63516 L p .807 .77 .819 r
F P
0 g
s
.52861 .33918 m .52821 .35183 L .49842 .38245 L p .889 .817 .771 r
F P
0 g
s
.50185 .39358 m .49842 .38245 L .52821 .35183 L p .892 .808 .759 r
F P
0 g
s
.45645 .53057 m .47045 .52183 L .46819 .54188 L p .874 .764 .737 r
F P
0 g
s
.46819 .54188 m .45365 .5553 L .45645 .53057 L p .874 .764 .737 r
F P
0 g
s
.48595 .47465 m .47593 .47249 L .49116 .44341 L p .886 .772 .729 r
F P
0 g
s
.47593 .47249 m .48595 .47465 L .47651 .49886 L p .881 .765 .73 r
F P
0 g
s
.29441 .57736 m .30833 .58577 L .31735 .62934 L p .365 .48 .843 r
F P
0 g
s
.33058 .63462 m .31735 .62934 L .30833 .58577 L p .455 .537 .852 r
F P
0 g
s
.50185 .39358 m .50525 .40516 L .48419 .43581 L p .886 .782 .741 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50525 .40516 L p .889 .781 .736 r
F P
0 g
s
.43903 .56736 m .45365 .5553 L .45583 .5747 L p .862 .764 .752 r
F P
0 g
s
.45583 .5747 m .44173 .59027 L .43903 .56736 L p .862 .764 .752 r
F P
0 g
s
.57408 .28509 m .5698 .29413 L .52942 .31708 L p .858 .9 .863 r
F P
0 g
s
.52901 .32759 m .52942 .31708 L .5698 .29413 L p .874 .88 .837 r
F P
0 g
s
.46407 .50227 m .47651 .49886 L .47045 .52183 L p .876 .762 .733 r
F P
0 g
s
.47045 .52183 m .45645 .53057 L .46407 .50227 L p .876 .762 .733 r
F P
0 g
s
.47651 .49886 m .46407 .50227 L .47593 .47249 L p .881 .765 .73 r
F P
0 g
s
.85986 .43317 m .84407 .42038 L .82145 .36961 L p .013 .307 .799 r
F P
0 g
s
.80649 .35834 m .82145 .36961 L .84407 .42038 L p .005 .298 .793 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47593 .47249 L p .881 .768 .733 r
F P
0 g
s
.63789 .26383 m .62974 .26625 L .58287 .27166 L p .546 .897 .977 r
F P
0 g
s
.57844 .27762 m .58287 .27166 L .62974 .26625 L p .663 .926 .973 r
F P
0 g
s
.2462 .47674 m .25964 .48991 L .25377 .54344 L p .338 .404 .783 r
F P
0 g
s
.26713 .55592 m .25377 .54344 L .25964 .48991 L p .381 .43 .787 r
F P
0 g
s
.30833 .58577 m .32243 .59234 L .33058 .63462 L p .455 .537 .852 r
F P
0 g
s
.34402 .63766 m .33058 .63462 L .32243 .59234 L p .537 .588 .853 r
F P
0 g
s
.42435 .57779 m .43903 .56736 L .44173 .59027 L p .846 .756 .764 r
F P
0 g
s
.44173 .59027 m .4276 .60401 L .42435 .57779 L p .846 .756 .764 r
F P
0 g
s
.52901 .32759 m .52861 .33918 L .49496 .37181 L p .885 .826 .784 r
F P
0 g
s
.49842 .38245 m .49496 .37181 L .52861 .33918 L p .889 .817 .771 r
F P
0 g
s
.49842 .38245 m .50185 .39358 L .47717 .42815 L p .881 .783 .748 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50185 .39358 L p .886 .782 .741 r
F P
0 g
s
.44236 .53818 m .45645 .53057 L .45365 .5553 L p .861 .755 .744 r
F P
0 g
s
.45365 .5553 m .43903 .56736 L .44236 .53818 L p .861 .755 .744 r
F P
0 g
s
.47593 .47249 m .46582 .46988 L .48419 .43581 L p .881 .768 .733 r
F P
0 g
s
.46582 .46988 m .47593 .47249 L .46407 .50227 L p .872 .758 .734 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46582 .46988 L p .874 .763 .737 r
F P
0 g
s
.57844 .27762 m .57408 .28509 L .52984 .30769 L p .835 .92 .891 r
F P
0 g
s
.52942 .31708 m .52984 .30769 L .57408 .28509 L p .858 .9 .863 r
F P
0 g
s
.32243 .59234 m .33669 .59689 L .34402 .63766 L p .537 .588 .853 r
F P
0 g
s
.35764 .63829 m .34402 .63766 L .33669 .59689 L p .61 .631 .847 r
F P
0 g
s
.40964 .58636 m .42435 .57779 L .4276 .60401 L p .825 .747 .778 r
F P
0 g
s
.4276 .60401 m .41347 .61567 L .40964 .58636 L p .825 .747 .778 r
F P
0 g
s
.45151 .50487 m .46407 .50227 L .45645 .53057 L p .865 .753 .738 r
F P
0 g
s
.45645 .53057 m .44236 .53818 L .45151 .50487 L p .865 .753 .738 r
F P
0 g
s
.46407 .50227 m .45151 .50487 L .46582 .46988 L p .872 .758 .734 r
F P
0 g
s
.25964 .48991 m .27319 .50239 L .26713 .55592 L p .381 .43 .787 r
F P
0 g
s
.28068 .56732 m .26713 .55592 L .27319 .50239 L p .427 .46 .792 r
F P
0 g
s
.82145 .36961 m .8366 .38074 L .85986 .43317 L p .013 .307 .799 r
F P
0 g
s
.52942 .31708 m .52901 .32759 L .49146 .36168 L p .88 .837 .799 r
F P
0 g
s
.49496 .37181 m .49146 .36168 L .52901 .32759 L p .885 .826 .784 r
F P
0 g
s
.39492 .59291 m .40964 .58636 L .41347 .61567 L p .798 .733 .792 r
F P
0 g
s
.41347 .61567 m .39937 .62504 L .39492 .59291 L p .798 .733 .792 r
F P
0 g
s
.33669 .59689 m .35109 .59928 L .35764 .63829 L p .61 .631 .847 r
F P
0 g
s
.37143 .63641 m .35764 .63829 L .35109 .59928 L p .671 .666 .836 r
F P
0 g
s
.42818 .54448 m .44236 .53818 L .43903 .56736 L p .845 .744 .752 r
F P
0 g
s
.43903 .56736 m .42435 .57779 L .42818 .54448 L p .845 .744 .752 r
F P
0 g
s
.49496 .37181 m .49842 .38245 L .47008 .42042 L p .876 .784 .755 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49842 .38245 L p .881 .783 .748 r
F P
0 g
s
.38024 .59729 m .39492 .59291 L .39937 .62504 L p .764 .716 .808 r
F P
0 g
s
.39937 .62504 m .38535 .63199 L .38024 .59729 L p .764 .716 .808 r
F P
0 g
s
.35109 .59928 m .36562 .59942 L .37143 .63641 L p .671 .666 .836 r
F P
0 g
s
.38535 .63199 m .37143 .63641 L .36562 .59942 L p .723 .694 .823 r
F P
0 g
s
.64621 .26307 m .63789 .26383 L .60043 .26629 L p .401 .835 .95 r
F P
0 g
s
.60665 .26581 m .64621 .26307 L .60043 .26629 L .401 .835 .95 r
F
.58287 .27166 m .58739 .26715 L .63789 .26383 L p .546 .897 .977 r
F P
0 g
s
.58739 .26715 m .59199 .26398 L .64621 .26307 L p .401 .835 .95 r
F P
0 g
s
.6547 .26382 m .64621 .26307 L .59199 .26398 L p .246 .748 .895 r
F P
0 g
s
.59199 .26398 m .59669 .26204 L .63885 .26334 L p .246 .748 .895 r
F P
0 g
s
.63885 .26334 m .6547 .26382 L p .63174 .26388 L .246 .748 .895 r
F P
0 g
s
.59199 .26398 m .63885 .26334 L .63174 .26388 L .246 .748 .895 r
F
.60043 .26629 m .58739 .26715 L p .60665 .26581 L .401 .835 .95 r
F P
0 g
s
.36562 .59942 m .38024 .59729 L .38535 .63199 L p .723 .694 .823 r
F P
0 g
s
.46582 .46988 m .45562 .46674 L .47717 .42815 L p .874 .763 .737 r
F P
0 g
s
.45562 .46674 m .46582 .46988 L .45151 .50487 L p .861 .749 .738 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45562 .46674 L p .866 .758 .742 r
F P
0 g
s
.27319 .50239 m .28686 .51395 L .28068 .56732 L p .427 .46 .792 r
F P
0 g
s
.29441 .57736 m .28068 .56732 L .28686 .51395 L p .476 .493 .796 r
F P
0 g
s
.43887 .50651 m .45151 .50487 L .44236 .53818 L p .851 .742 .743 r
F P
0 g
s
.44236 .53818 m .42818 .54448 L .43887 .50651 L p .851 .742 .743 r
F P
0 g
s
.58287 .27166 m .57844 .27762 L .53026 .29938 L p .801 .936 .919 r
F P
0 g
s
.52984 .30769 m .53026 .29938 L .57844 .27762 L p .835 .92 .891 r
F P
0 g
s
.45151 .50487 m .43887 .50651 L .45562 .46674 L p .861 .749 .738 r
F P
0 g
s
.41394 .54926 m .42818 .54448 L .42435 .57779 L p .825 .731 .761 r
F P
0 g
s
.42435 .57779 m .40964 .58636 L .41394 .54926 L p .825 .731 .761 r
F P
0 g
s
.52984 .30769 m .52942 .31708 L .48793 .3521 L p .872 .848 .816 r
F P
0 g
s
.49146 .36168 m .48793 .3521 L .52942 .31708 L p .88 .837 .799 r
F P
0 g
s
.49146 .36168 m .49496 .37181 L .46294 .41262 L p .87 .785 .764 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49496 .37181 L p .876 .784 .755 r
F P
0 g
s
.28686 .51395 m .30065 .52437 L .29441 .57736 L p .476 .493 .796 r
F P
0 g
s
.30833 .58577 m .29441 .57736 L .30065 .52437 L p .526 .526 .799 r
F P
0 g
s
.20636 .4356 m .19318 .42214 L .22154 .37026 L p .435 .473 .8 r
F P
0 g
s
.45562 .46674 m .44535 .46302 L .47008 .42042 L p .866 .758 .742 r
F P
0 g
s
.44535 .46302 m .45562 .46674 L .43887 .50651 L p .849 .739 .742 r
F P
0 g
s
.80649 .35834 m .79175 .34723 L .75028 .30714 L p 0 .218 .706 r
F P
0 g
s
.39966 .5524 m .41394 .54926 L .40964 .58636 L p .802 .715 .769 r
F P
0 g
s
.40964 .58636 m .39492 .59291 L .39966 .5524 L p .802 .715 .769 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44535 .46302 L p .857 .752 .747 r
F P
0 g
s
.42614 .50709 m .43887 .50651 L .42818 .54448 L p .835 .729 .748 r
F P
0 g
s
.42818 .54448 m .41394 .54926 L .42614 .50709 L p .835 .729 .748 r
F P
0 g
s
.30065 .52437 m .31455 .53344 L .30833 .58577 L p .526 .526 .799 r
F P
0 g
s
.32243 .59234 m .30833 .58577 L .31455 .53344 L p .575 .56 .8 r
F P
0 g
s
.22154 .37026 m .23423 .38296 L .20636 .4356 L p .435 .473 .8 r
F P
0 g
s
.21957 .44935 m .20636 .4356 L .23423 .38296 L p .449 .473 .792 r
F P
0 g
s
.43887 .50651 m .42614 .50709 L .44535 .46302 L p .849 .739 .742 r
F P
0 g
s
.38537 .55378 m .39966 .5524 L .39492 .59291 L p .774 .697 .777 r
F P
0 g
s
.39492 .59291 m .38024 .59729 L .38537 .55378 L p .774 .697 .777 r
F P
0 g
s
.48793 .3521 m .49146 .36168 L .45573 .40475 L p .863 .785 .773 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49146 .36168 L p .87 .785 .764 r
F P
0 g
s
.58739 .26715 m .58287 .27166 L .53068 .29214 L p .753 .945 .944 r
F P
0 g
s
.53026 .29938 m .53068 .29214 L .58287 .27166 L p .801 .936 .919 r
F P
0 g
s
.53026 .29938 m .52984 .30769 L .48435 .34306 L p .863 .859 .835 r
F P
0 g
s
.48793 .3521 m .48435 .34306 L .52984 .30769 L p .872 .848 .816 r
F P
0 g
s
.31455 .53344 m .32856 .541 L .32243 .59234 L p .575 .56 .8 r
F P
0 g
s
.33669 .59689 m .32243 .59234 L .32856 .541 L p .622 .592 .799 r
F P
0 g
s
.23423 .38296 m .2469 .39582 L .21957 .44935 L p .449 .473 .792 r
F P
0 g
s
.23285 .46314 m .21957 .44935 L .2469 .39582 L p .467 .478 .786 r
F P
0 g
s
.37109 .55333 m .38537 .55378 L .38024 .59729 L p .742 .675 .785 r
F P
0 g
s
.38024 .59729 m .36562 .59942 L .37109 .55333 L p .742 .675 .785 r
F P
0 g
s
.41335 .50649 m .42614 .50709 L .41394 .54926 L p .816 .715 .754 r
F P
0 g
s
.41394 .54926 m .39966 .5524 L .41335 .50649 L p .816 .715 .754 r
F P
0 g
s
.44535 .46302 m .435 .45867 L .46294 .41262 L p .857 .752 .747 r
F P
0 g
s
.435 .45867 m .44535 .46302 L .42614 .50709 L p .835 .728 .746 r
F P
0 g
s
.32856 .541 m .34266 .5469 L .33669 .59689 L p .622 .592 .799 r
F P
0 g
s
.35109 .59928 m .33669 .59689 L .34266 .5469 L p .666 .622 .796 r
F P
0 g
s
.35684 .55103 m .37109 .55333 L .36562 .59942 L p .706 .65 .791 r
F P
0 g
s
.36562 .59942 m .35109 .59928 L .35684 .55103 L p .706 .65 .791 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .435 .45867 L p .846 .746 .752 r
F P
0 g
s
.34266 .5469 m .35684 .55103 L .35109 .59928 L p .666 .622 .796 r
F P
0 g
s
.42614 .50709 m .41335 .50649 L .435 .45867 L p .835 .728 .746 r
F P
0 g
s
.2469 .39582 m .25957 .40867 L .23285 .46314 L p .467 .478 .786 r
F P
0 g
s
.2462 .47674 m .23285 .46314 L .25957 .40867 L p .488 .487 .782 r
F P
0 g
s
.48435 .34306 m .48793 .3521 L .44846 .39682 L p .855 .786 .783 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48793 .3521 L p .863 .785 .773 r
F P
0 g
s
.40051 .50464 m .41335 .50649 L .39966 .5524 L p .794 .698 .758 r
F P
0 g
s
.39966 .5524 m .38537 .55378 L .40051 .50464 L p .794 .698 .758 r
F P
0 g
s
.82145 .36961 m .80649 .35834 L .76298 .31562 L p 0 .219 .709 r
F P
0 g
s
.75028 .30714 m .76298 .31562 L .80649 .35834 L p 0 .218 .706 r
F P
0 g
s
.25957 .40867 m .27225 .42133 L .2462 .47674 L p .488 .487 .782 r
F P
0 g
s
.25964 .48991 m .2462 .47674 L .27225 .42133 L p .512 .5 .779 r
F P
0 g
s
.53068 .29214 m .53026 .29938 L .48073 .33456 L p .85 .87 .855 r
F P
0 g
s
.48435 .34306 m .48073 .33456 L .53026 .29938 L p .863 .859 .835 r
F P
0 g
s
.435 .45867 m .42459 .45365 L .45573 .40475 L p .846 .746 .752 r
F P
0 g
s
.42459 .45365 m .435 .45867 L .41335 .50649 L p .82 .716 .75 r
F P
0 g
s
.66337 .26592 m .6547 .26382 L .59669 .26204 L p .102 .65 .826 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42459 .45365 L p .835 .739 .758 r
F P
0 g
s
.59199 .26398 m .58739 .26715 L .53112 .2859 L p .69 .943 .961 r
F P
0 g
s
.53068 .29214 m .53112 .2859 L .58739 .26715 L p .753 .945 .944 r
F P
0 g
s
.41335 .50649 m .40051 .50464 L .42459 .45365 L p .82 .716 .75 r
F P
0 g
s
.27225 .42133 m .28496 .43365 L .25964 .48991 L p .512 .5 .779 r
F P
0 g
s
.27319 .50239 m .25964 .48991 L .28496 .43365 L p .539 .515 .777 r
F P
0 g
s
.38764 .5015 m .40051 .50464 L .38537 .55378 L p .771 .68 .763 r
F P
0 g
s
.38537 .55378 m .37109 .55333 L .38764 .5015 L p .771 .68 .763 r
F P
0 g
s
.28496 .43365 m .29769 .44544 L .27319 .50239 L p .539 .515 .777 r
F P
0 g
s
.28686 .51395 m .27319 .50239 L .29769 .44544 L p .568 .533 .776 r
F P
0 g
s
.37475 .49705 m .38764 .5015 L .37109 .55333 L p .745 .66 .767 r
F P
0 g
s
.37109 .55333 m .35684 .55103 L .37475 .49705 L p .745 .66 .767 r
F P
0 g
s
.48073 .33456 m .48435 .34306 L .44112 .38881 L p .846 .787 .794 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48435 .34306 L p .855 .786 .783 r
F P
0 g
s
.42459 .45365 m .41412 .44793 L .44846 .39682 L p .835 .739 .758 r
F P
0 g
s
.41412 .44793 m .42459 .45365 L .40051 .50464 L p .803 .702 .754 r
F P
0 g
s
.29769 .44544 m .31046 .45654 L .28686 .51395 L p .568 .533 .776 r
F P
0 g
s
.30065 .52437 m .28686 .51395 L .31046 .45654 L p .597 .553 .775 r
F P
0 g
s
.40051 .50464 m .38764 .5015 L .41412 .44793 L p .803 .702 .754 r
F P
0 g
s
.36186 .4913 m .37475 .49705 L .35684 .55103 L p .717 .639 .77 r
F P
0 g
s
.35684 .55103 m .34266 .5469 L .36186 .4913 L p .717 .639 .77 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41412 .44793 L p .823 .731 .764 r
F P
0 g
s
.31046 .45654 m .32327 .46681 L .30065 .52437 L p .597 .553 .775 r
F P
0 g
s
.31455 .53344 m .30065 .52437 L .32327 .46681 L p .628 .574 .775 r
F P
0 g
s
.34897 .48429 m .36186 .4913 L .34266 .5469 L p .688 .617 .772 r
F P
0 g
s
.34266 .5469 m .32856 .541 L .34897 .48429 L p .688 .617 .772 r
F P
0 g
s
.53112 .2859 m .53068 .29214 L .47707 .32658 L p .834 .88 .876 r
F P
0 g
s
.48073 .33456 m .47707 .32658 L .53068 .29214 L p .85 .87 .855 r
F P
0 g
s
.32327 .46681 m .3361 .4761 L .31455 .53344 L p .628 .574 .775 r
F P
0 g
s
.32856 .541 m .31455 .53344 L .3361 .4761 L p .658 .596 .773 r
F P
0 g
s
.3361 .4761 m .34897 .48429 L .32856 .541 L p .658 .596 .773 r
F P
0 g
s
.75028 .30714 m .73781 .29912 L .68129 .27328 L p .335 0 0 r
F P
0 g
s
.8366 .38074 m .82145 .36961 L .7759 .32426 L p 0 .237 .725 r
F P
0 g
s
.7759 .32426 m .82145 .36961 L p .76372 .3163 L 0 .219 .709 r
F P
0 g
s
.7759 .32426 m .78901 .33274 L .8366 .38074 L p 0 .237 .725 r
F P
0 g
s
.7759 .32426 m .70952 .28853 L p .78806 .33221 L 0 .247 .644 r
F P
0 g
s
.78901 .33274 m .7759 .32426 L p .78806 .33221 L 0 .247 .644 r
F P
0 g
s
.76298 .31562 m .7759 .32426 L p .76372 .3163 L 0 .219 .709 r
F P
0 g
s
.40359 .44152 m .41412 .44793 L .38764 .5015 L p .784 .688 .758 r
F P
0 g
s
.38764 .5015 m .37475 .49705 L .40359 .44152 L p .784 .688 .758 r
F P
0 g
s
.59669 .26204 m .59199 .26398 L .53156 .28059 L p .612 .927 .968 r
F P
0 g
s
.53112 .2859 m .53156 .28059 L .59199 .26398 L p .69 .943 .961 r
F P
0 g
s
.41412 .44793 m .40359 .44152 L .44112 .38881 L p .823 .731 .764 r
F P
0 g
s
.59669 .26204 m .60148 .26116 L .66337 .26592 L p .102 .65 .826 r
F P
0 g
s
.67224 .26915 m .66337 .26592 L .60148 .26116 L p 0 .559 .759 r
F P
0 g
s
.47707 .32658 m .48073 .33456 L .43372 .38074 L p .835 .787 .805 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48073 .33456 L p .846 .787 .794 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .40359 .44152 L p .809 .723 .77 r
F P
0 g
s
.39301 .4344 m .40359 .44152 L .37475 .49705 L p .765 .674 .762 r
F P
0 g
s
.37475 .49705 m .36186 .4913 L .39301 .4344 L p .765 .674 .762 r
F P
0 g
s
.40359 .44152 m .39301 .4344 L .43372 .38074 L p .809 .723 .77 r
F P
0 g
s
.53156 .28059 m .53112 .2859 L .47335 .31909 L p .813 .888 .898 r
F P
0 g
s
.47707 .32658 m .47335 .31909 L .53112 .2859 L p .834 .88 .876 r
F P
0 g
s
.38238 .42661 m .39301 .4344 L .36186 .4913 L p .745 .659 .765 r
F P
0 g
s
.36186 .4913 m .34897 .48429 L .38238 .42661 L p .745 .659 .765 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47707 .32658 L p .835 .787 .805 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39301 .4344 L p .795 .715 .776 r
F P
0 g
s
.47335 .31909 m .47707 .32658 L .42626 .3726 L p .824 .786 .817 r
F P
0 g
s
.37172 .41818 m .38238 .42661 L .34897 .48429 L p .724 .644 .768 r
F P
0 g
s
.34897 .48429 m .3361 .4761 L .37172 .41818 L p .724 .644 .768 r
F P
0 g
s
.76298 .31562 m .75028 .30714 L .69052 .27807 L p .351 0 0 r
F P
0 g
s
.53156 .28059 m .53201 .27612 L .59669 .26204 L p .612 .927 .968 r
F P
0 g
s
.60148 .26116 m .59669 .26204 L .53201 .27612 L p .525 .898 .964 r
F P
0 g
s
.39301 .4344 m .38238 .42661 L .42626 .3726 L p .795 .715 .776 r
F P
0 g
s
.36101 .40914 m .37172 .41818 L .3361 .4761 L p .703 .629 .771 r
F P
0 g
s
.3361 .4761 m .32327 .46681 L .36101 .40914 L p .703 .629 .771 r
F P
0 g
s
.60148 .26116 m .60637 .26118 L .67224 .26915 L p 0 .559 .759 r
F P
0 g
s
.68129 .27328 m .67224 .26915 L .60637 .26118 L p 0 .486 .707 r
F P
0 g
s
.35027 .39956 m .36101 .40914 L .32327 .46681 L p .682 .615 .775 r
F P
0 g
s
.32327 .46681 m .31046 .45654 L .35027 .39956 L p .682 .615 .775 r
F P
0 g
s
.3395 .38951 m .35027 .39956 L .31046 .45654 L p .661 .602 .778 r
F P
0 g
s
.31046 .45654 m .29769 .44544 L .3395 .38951 L p .661 .602 .778 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47335 .31909 L p .824 .786 .817 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38238 .42661 L p .78 .706 .782 r
F P
0 g
s
.38238 .42661 m .37172 .41818 L .41873 .36438 L p .78 .706 .782 r
F P
0 g
s
.32869 .37906 m .3395 .38951 L .29769 .44544 L p .641 .59 .782 r
F P
0 g
s
.29769 .44544 m .28496 .43365 L .32869 .37906 L p .641 .59 .782 r
F P
0 g
s
.53201 .27612 m .53156 .28059 L .46959 .31205 L p .788 .894 .919 r
F P
0 g
s
.47335 .31909 m .46959 .31205 L .53156 .28059 L p .813 .888 .898 r
F P
0 g
s
.31785 .36828 m .32869 .37906 L .28496 .43365 L p .621 .58 .787 r
F P
0 g
s
.28496 .43365 m .27225 .42133 L .31785 .36828 L p .621 .58 .787 r
F P
0 g
s
.30696 .35728 m .31785 .36828 L .27225 .42133 L p .602 .572 .792 r
F P
0 g
s
.27225 .42133 m .25957 .40867 L .30696 .35728 L p .602 .572 .792 r
F P
0 g
s
.29602 .34613 m .30696 .35728 L .25957 .40867 L p .585 .566 .799 r
F P
0 g
s
.25957 .40867 m .2469 .39582 L .29602 .34613 L p .585 .566 .799 r
F P
0 g
s
.28504 .33492 m .29602 .34613 L .2469 .39582 L p .57 .563 .806 r
F P
0 g
s
.2469 .39582 m .23423 .38296 L .28504 .33492 L p .57 .563 .806 r
F P
0 g
s
.27399 .32374 m .28504 .33492 L .23423 .38296 L p .556 .562 .815 r
F P
0 g
s
.23423 .38296 m .22154 .37026 L .27399 .32374 L p .556 .562 .815 r
F P
0 g
s
.46959 .31205 m .47335 .31909 L .41873 .36438 L p .81 .786 .83 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37172 .41818 L p .764 .698 .789 r
F P
0 g
s
.37172 .41818 m .36101 .40914 L .41113 .35609 L p .764 .698 .789 r
F P
0 g
s
.53201 .27612 m .53247 .27237 L .60148 .26116 L p .525 .898 .964 r
F P
0 g
s
.60637 .26118 m .60148 .26116 L .53247 .27237 L p .436 .857 .951 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46959 .31205 L p .81 .786 .83 r
F P
0 g
s
.7759 .32426 m .76298 .31562 L .69994 .28325 L p .345 0 0 r
F P
0 g
s
.69052 .27807 m .69994 .28325 L .76298 .31562 L p .351 0 0 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36101 .40914 L p .748 .69 .795 r
F P
0 g
s
.36101 .40914 m .35027 .39956 L .40346 .34772 L p .748 .69 .795 r
F P
0 g
s
.60637 .26118 m .61136 .2619 L .68129 .27328 L p 0 .486 .707 r
F P
0 g
s
.69052 .27807 m .68129 .27328 L .61136 .2619 L p .16 0 0 r
F P
0 g
s
.46959 .31205 m .46577 .30541 L .53201 .27612 L p .788 .894 .919 r
F P
0 g
s
.46577 .30541 m .46959 .31205 L .41113 .35609 L p .795 .784 .843 r
F P
0 g
s
.53247 .27237 m .53201 .27612 L .46577 .30541 L p .759 .895 .938 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .35027 .39956 L p .731 .682 .802 r
F P
0 g
s
.35027 .39956 m .3395 .38951 L .39573 .33928 L p .731 .682 .802 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46577 .30541 L p .795 .784 .843 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .3395 .38951 L p .714 .674 .81 r
F P
0 g
s
.3395 .38951 m .32869 .37906 L .38792 .33076 L p .714 .674 .81 r
F P
0 g
s
.53247 .27237 m .53293 .26923 L .60637 .26118 L p .436 .857 .951 r
F P
0 g
s
.61136 .2619 m .60637 .26118 L .53293 .26923 L p .354 .813 .933 r
F P
0 g
s
.46577 .30541 m .4619 .2991 L .53247 .27237 L p .759 .895 .938 r
F P
0 g
s
.4619 .2991 m .46577 .30541 L .40346 .34772 L p .778 .782 .856 r
F P
0 g
s
.70952 .28853 m .7759 .32426 L p .70089 .28376 L .345 0 0 r
F P
0 g
s
.70952 .28853 m .71927 .29362 L .78901 .33274 L p 0 .247 .644 r
F P
0 g
s
.70952 .28853 m .6269 .26612 L p .71815 .29329 L 0 .411 .704 r
F P
0 g
s
.71927 .29362 m .70952 .28853 L p .71815 .29329 L 0 .411 .704 r
F P
0 g
s
.69994 .28325 m .70952 .28853 L p .70089 .28376 L .345 0 0 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .4619 .2991 L p .778 .782 .856 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .32869 .37906 L p .697 .667 .817 r
F P
0 g
s
.32869 .37906 m .31785 .36828 L .38005 .32217 L p .697 .667 .817 r
F P
0 g
s
.53293 .26923 m .53247 .27237 L .4619 .2991 L p .726 .893 .956 r
F P
0 g
s
.69994 .28325 m .69052 .27807 L .61645 .26312 L p .19 0 0 r
F P
0 g
s
.61136 .2619 m .61645 .26312 L .69052 .27807 L p .16 0 0 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31785 .36828 L p .68 .661 .825 r
F P
0 g
s
.31785 .36828 m .30696 .35728 L .3721 .3135 L p .68 .661 .825 r
F P
0 g
s
.45798 .29305 m .4619 .2991 L .39573 .33928 L p .76 .779 .868 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45798 .29305 L p .76 .779 .868 r
F P
0 g
s
.4619 .2991 m .45798 .29305 L .53293 .26923 L p .726 .893 .956 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30696 .35728 L p .663 .657 .834 r
F P
0 g
s
.30696 .35728 m .29602 .34613 L .36408 .30475 L p .663 .657 .834 r
F P
0 g
s
.53293 .26923 m .53341 .26654 L .61136 .2619 L p .354 .813 .933 r
F P
0 g
s
.61645 .26312 m .61136 .2619 L .53341 .26654 L p .287 .771 .917 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29602 .34613 L p .646 .653 .843 r
F P
0 g
s
.29602 .34613 m .28504 .33492 L .35599 .29592 L p .646 .653 .843 r
F P
0 g
s
.53341 .26654 m .53293 .26923 L .45798 .29305 L p .69 .886 .97 r
F P
0 g
s
.454 .28719 m .45798 .29305 L .38792 .33076 L p .741 .775 .881 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .454 .28719 L p .741 .775 .881 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28504 .33492 L p .631 .651 .852 r
F P
0 g
s
.28504 .33492 m .27399 .32374 L .34782 .287 L p .631 .651 .852 r
F P
0 g
s
.70952 .28853 m .69994 .28325 L .62163 .2646 L p .194 0 0 r
F P
0 g
s
.61645 .26312 m .62163 .2646 L .69994 .28325 L p .19 0 0 r
F P
0 g
s
.45798 .29305 m .454 .28719 L .53341 .26654 L p .69 .886 .97 r
F P
0 g
s
.44997 .28144 m .454 .28719 L .38005 .32217 L p .72 .77 .892 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .44997 .28144 L p .72 .77 .892 r
F P
0 g
s
.53341 .26654 m .53389 .26415 L .61645 .26312 L p .287 .771 .917 r
F P
0 g
s
.53389 .26415 m .53341 .26654 L .454 .28719 L p .653 .875 .981 r
F P
0 g
s
.62163 .2646 m .61645 .26312 L .53389 .26415 L p .239 .737 .908 r
F P
0 g
s
.454 .28719 m .44997 .28144 L .53389 .26415 L p .653 .875 .981 r
F P
0 g
s
.44588 .2757 m .44997 .28144 L .3721 .3135 L p .699 .764 .903 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44588 .2757 L p .699 .764 .903 r
F P
0 g
s
.53389 .26415 m .53438 .2619 L .62163 .2646 L p .239 .737 .908 r
F P
0 g
s
.6269 .26612 m .62163 .2646 L .53438 .2619 L p .211 .713 .908 r
F P
0 g
s
.6269 .26612 m .70952 .28853 L p .62272 .2649 L .194 0 0 r
F P
0 g
s
.6269 .26612 m .63227 .26744 L .71927 .29362 L p 0 .411 .704 r
F P
0 g
s
.53438 .2619 m .53488 .25962 L .6269 .26612 L p .211 .713 .908 r
F P
0 g
s
.6269 .26612 m .53488 .25962 L p .63108 .26734 L .205 .701 .917 r
F P
0 g
s
.63227 .26744 m .6269 .26612 L p .63108 .26734 L .205 .701 .917 r
F P
0 g
s
.62163 .2646 m .6269 .26612 L p .62272 .2649 L .194 0 0 r
F P
0 g
s
.44174 .26989 m .44588 .2757 L .36408 .30475 L p .677 .758 .912 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44174 .26989 L p .677 .758 .912 r
F P
0 g
s
.53438 .2619 m .53389 .26415 L .44997 .28144 L p .617 .861 .989 r
F P
0 g
s
.44997 .28144 m .44588 .2757 L .53438 .2619 L p .617 .861 .989 r
F P
0 g
s
.43754 .26392 m .44174 .26989 L .35599 .29592 L p .656 .751 .92 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43754 .26392 L p .656 .751 .92 r
F P
0 g
s
.53488 .25962 m .53438 .2619 L .44588 .2757 L p .585 .844 .994 r
F P
0 g
s
.44588 .2757 m .44174 .26989 L .53488 .25962 L p .585 .844 .994 r
F P
0 g
s
.53539 .25714 m .53488 .25962 L .44174 .26989 L p .558 .827 .996 r
F P
0 g
s
.44174 .26989 m .43754 .26392 L .53539 .25714 L p .558 .827 .996 r
F P
0 g
s
.53488 .25962 m .53539 .25714 L .63227 .26744 L p .205 .701 .917 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00004ohkCoPGo0000
1Old/nX;o`0000;ooooo2_l0000Iooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00003?n>doh7o`0000;oUMSn
00?oWMcmo`000?l000002Olm_>P8ocBcjQWo00003?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02kooooo000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nW
`>/00ol0003oS]?nohkCoP0:ohkCoP?o00001onEf?h3oigLo@Ko00003Om9aNX01Om_fo?oQ^Gfo`00
0?l0003oW>gg00Co00000_mVeO<01?l0003o=;?ZocBcj_ld/nXAo`0000Wooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06oooooo0ol00005ojO0j`?o00000on>doh00ol0003oUMSnoiGHoP09oiGHoPGoWMcm
0_l00002ojOOn`?o000000?o/>;ho`000?l000000omJd>h5ofoKl`;oQ^Gf0_l00003oic]m`03o`00
0?o0lO7o000000OoRnGj0_l00002ojW]n@04o`000?n5e?ooQMCoohGDo`;o06Vd3Ol00006ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Zooooo`Co00001OnW`>/3o`0000?o[L;Y00?o0000oiGHo_nEf?h0
1onEf?h6oigLo@;o00000onWgo/2o`0000;o/>;h0_l000000onii?Co0000o`000002ofoKl`CoQ^Gf
00?o0000oic]monLkOL00_nLkOL01?n`lOKo0000ol3alOo0lO42o`0000;oRnGj00?o0000ojW]nOnY
kOT00onYkOT00ol0003o_ngbo`000003ojCMn`;o00000on5e?l2o`1Y]0Oo000000?o:000o`000?l0
00000ol00003ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?ooool002cooooo
0ol00006ooooo`03o`000?oooooooooo06Gooooo1?l00006ojO0j`?o00001_n]`^T2o`0000;oUMSn
2?nMg?d00ol0003oYmokojOOn`03ojOOn`;o00000_n`h_P2o`0000;o^NCd1?l000000on6iOKo0000
oic]m`05oic]m`04ok3am_l0003o`?7aol3al@Co00001?nYkOT01?l0003o_ngboko]l_nokO83o`00
00SoY=gk1?l00002o`1Y]0co000000?oooooo`000?ooool0<oooool2o`0002gooooo000/ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?ooool4o`0000OoYl3[0ol00006ojg2j@?o
000000?o//?Wo`000?nMg?d01OnMg?d00ol0003oYmokojOOn`03ojOOn`;o00000on`h_P2o`0000;o
^NCd0_l000001Oo2iO3o0000o`000?o9i>_o000000CoW>gg0_n`lOH00ol0003o`?7aol3al@03o`00
0004olg_jol0003o0000ojW]n@Go_ngb0ol000000oo=j^[o0000ok_OlP03ok_OlPCo00001OnTgO/3
o`000003og^fn?l0JKCo000000?o000000?o<000o`000?l000001?l0000eooooo`03o`000?oooooo
oooo02_ooooo000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?oo
ool3o`0000SoYl3[0ol00006ojg2j@?o00001?nb`nL2o`000003oigLoOnWgo_oYmok00GoYmok00?o
0000ok3Rn?n`h_P00_n`h_P2o`0000?o^NCd0_l000000oo2iO3o0000o`000002olWTj`;o000000Co
W>ggok3am_n`lOKo00000_o0lO43o`0000;ocNo[0_l000000ooEjnCo0000oko]lP02oko]lP03o`00
0?o=j^[ocN[Z00?ocN[Z00?o0000ok_Ol_nkgo802?nkgo83o`0000CoUl;d1?mk]_P00ol0JKCo0000
o`000003o`000003oc400?l0003o000000?o0000<oooool00ol0003oooooooooo`0Zooooo`004Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`Co00002?nW`>/3o`0000Oo[L;Y
0_l00004ok;3i`?o000000?o^<GTo`000?nWgo/01?nWgo/00ol0003o/>;hok3Rn003ok3Rn003o`00
0?nii?Co^NCd00;o^NCd00Co0000ol;Ul?o2iO3o00000oo9i>/5o`0000?o`?7a0_l00003olg_j`;o
000000CoeN_To`000?l0003o_ngb1_o=j^X3o`0000[o^mob00Co0000ojg8k_n]b>ko[LS^1OnG`_@0
1ol0003oNkKhog^fn?mk]_So0000oeVUmol0JK@02_l0000aooooo`03o`000?oooooooooo02[ooooo
0009ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool3o`0000_ooooo00?o0000ooooooooool0Doooool3o`0000[oYl3[0_l00007ojg2j@?o0000
0onb`nL3o`0000Co^<GT0_l000000onWgo_o/>;hok3Rn004ok3Rn003o`000?nii?Co^NCd00;o^NCd
00Go0000ol;Ul?o2iO3o`^G`o`000003olWTj`;o000000Cod>?Uo`000?oEhN3o00000_o0lO400ol0
003ocNo[olg_j`02olg_j`03o`000?oEjnCoeN_T00;o000000?ofnKLo`000?o=j^X00_o=j^X4o`00
00;oenGQ00?o0000olWMioo9gNL00oo9gNL5o`0000Go[LS^00?o0000oiO2m?nG`_@00_nG`_@01?l0
003oNkKhog^fn?mk]_P2o`0000;oFJGg2_l0000`ooooo`03o`000?oooooooooo02Wooooo000Aoooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0D?ooool2o`0000;oXJKJ00?o0000ojO0jonW`>/01OnW`>/2
o`0000Oo[L;Y0ol00004ok;3i`;o00001OnhaN@2o`000003okg6hOl0003o/>;h00?o/>;h00?o0000
okWTm?nii?@00onii?@01Ol0003o`^G`ol;Ul?o2iO3o000000?obNC[0_l000000oo@hnGo0000omGQ
h003o`0000GocNo[00?o0000omG[i?oEjn@00_l00002om_Vg003o`000?o=j^[ocN[Z00;o00001OoG
iN400ol0003obMgWolWMi`07olWMi`03o`000?nnc>Go_/cU00Go[LS^0_l00003oiO2m003o`000?mk
]_SoNkKh00;oNkKh00Go0000oeVUmomIYOOoFJGgocB@k`09o`0002oooooo00?o0000ooooooooool0
:?ooool0017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04gooooo0_l00005oj6VfP03
o`000?nW`>_oYl3[00;oYl3[00?o0000ojg2jOn]`^T01On]`^T3o`0000Co//?W0ol00005okS5i0;o
00000onma^43o`0000Ko^NCd1?o2iO001?l0003obNC[olWTjoo9i>/2o`000007om3SiOl0003o0000
omGQh?l0003ofMkJo`000004olg_j`05o`000?oEjnCoeN_TomG[i?l000000_oKi]`3o`0000OoenGQ
0_l00002olWMi`?o00001?o9gNL00ol0003o_/cUokk<i@02okk<i@03o`000?n]b>ko[LS^00?o[LS^
00Go0000oiO2m?nG`_CoUl;do`000004og^fn008o`000?mIYOOoFJGgoeVUmol0003o=93_o`000?lB
NN<6o`0002kooooo0_l0000Yooooo`004Oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[ooooo0_l0
0007oj6VfP?o00002?n]`^T2o`0000Go//?W0_l00005okS5i0?o00000onma^42o`0000;o`/ON00Go
0000okWTm?nii?Co^NCdo`000004ol;Ul004o`000?o9i>_obNC[olWTj`;o00000_o@hnD01?l0003o
eN7Po`000?l00002omWNfP03o`000?o=kn_ocNo[00CoeN_T00Oo0000om_Vg?oKi]cofnKLo`000?oO
hMKo000000GoenGQ0ol000000ooLgmSo0000om?Jg@04om?Jg@Co00001_nnc>D00ol0003o[LS^ojg8
kP03ojg8kP05o`000?nG`_CoUl;doiO2m?l000001?mk]_P00ol0003oFJGgoeVUm`02o`000004ocB@
kol0003o4WWSoa9ih`Go0000;Oooool2o`0002Wooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`;o00004?ooool00ol0003oooooooooo`17ooooo`;o
00001onQY]X2o`0000;oYJOG00?o0000ojg2jOn]`^T01?n]`^T2o`0000Co//?W0ol00005okS5i0;o
00001?nma^42o`0000Co`/ON0_l00005ol;Ul0CobNC[00Go0000om3SiOo@hnGod>?Uo`000002omGQ
h004o`000?oIg][ofMkJomWNfP;o00001OoEjn@00ol0003ofnKLom_Vg002o`0000;ogn7F00Co0000
omOUhOoGiN7oenGQ0_l00003omcOf003o`000?oCf]godm[M00Kodm[M00Co0000ol[=g?o:cMco0000
1Onnc>D00ol0003o[LS^ojg8kP02ojg8kQ7o00000_lBNN<00ol0003o06CFo`000003o`0002gooooo
00?o0000ooooooooool09_ooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1Oooool00ol0003oooooooooo`0@ooooo`;o0000AOooool2o`0000OoXJKJ0_l00005ojFWe`05o`00
0?n]`^Wo[L;Yojg2jOl000001Onb`nL2o`0000Ko^<GT0_l00004okg6h@;o00001?o2amh2o`000003
olO8fol0003o`^G`00;o`^G`1?o9i>/00ol0003od>?Uom3Si@02om3Si@?oeN7P00Oo0000omWNf_oI
g][ofMkJo`000?oLfmGo000000?oeN_T00?o0000om_Vg?oKi]`00_l00003omoQeP04o`000?oGiN7o
enGQo`0000Gog=oH00?o0000om?JgOoCf]d01_oCf]d00ol0003ob/gLol[=g002ol[=g003o`000?nn
c>Go_/cU00?o_/cU00Go0000ojg8k_l0003o0000ojVcg`04oiR[h`GoQ:3U00CoKY?Uo`000?l0003o
KY?U0_mHQN<2o`0000;o4WWS00?o0000o`1Te_l000001?l0000[ooooo`03o`000?oooooooooo02Ko
oooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?ooool2o`0000OoXJKJ
0_l00007ojFWe`;o00001_nb`nL00ol0003o^<GTokS5i005okS5i0;o00001?nma^42o`0000Go`/ON
00Co0000olO8foo7b=_oalSK0_l00004olWTj`03o`000?o@hnGod>?U00;od>?U00Go0000omGQh?oE
hN3oeN7Po`000002omWNfP;o00000_oLfmD00ol0003oeN_To`000003om_Vg003o`000?oOhMKogn7F
00;ogn7F0_l00006omcOf0;o000000Codm[Mo`000?l0003o00001?oCf]d00ol0003ob/gLol[=g004
ol[=g003o`000?nnc>Go_/cU00?o_/cU00?o0000ojVcgonY/ml00_nY/ml4oiR[h`;oQ:3U0ol00000
1?m^TnGo0000ofjCiOm^TnD3oeR5h`;o000000?o4WWSo`000?l0I=H01_l0000Zooooo`03o`000?oo
oooooooo02Gooooo000Zooooo`;o00005Oooool00ol0003oooooooooo`0mooooo`;o00001onQY]X2
o`0000OoYJOG0_l00002ojVXe@05o`000?nb`nOo//?Wok;3iol000001onhaN@2o`0000Co_LKQ0_l0
0005ol;7gP;o00000oo7b=/00ol0003oblSGo`000003olWTj`God>?U0ooEhN001Ol0003ofMkJomWN
f_oIg][o000000?og=_E0_l00004om_Vg004o`000?oOhMKogn7FomoQeP;o000000?oh]c@o`000?oL
gmP00_oLgmP3o`000003on3JdOl0003ofMKE00?ofMKE1?l00008ol[=g006o`000?nnc>Go0000o`00
0?nh^]_o00001?nY/ml00ol0003oV:_SoiR[h`03o`0000?oQ:3U00Go0000ofjCiOl0003oKY?Uo`00
0002oeR5h`;o@WOO0ol000000ol0I=Ko0000o`1Bb@05o`0002Wooooo00?o0000ooooooooool09?oo
ool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`;o00001onQY]X2
o`0000SoYJOG00?o0000ojVXeOnYZ=D00_nYZ=D2o`0000So^<GT0_l00005okg6h@03o`000?o2amko
`/ON00?o`/ON0_l00003olO8f`;o00000_o;b=L2o`0000God>?U1?oEhN000ol0003ofMkJomWNfP02
o`0000?og=_E00?o0000omoId?l000000_oKi]`00ol0003ogn7FomoQeP02omoQeP04o`000?oRg=3o
h]c@o`0000;og=oH0_l00003on3Jd@03o`000?oIe]GofMKE00KofMKE00?o0000om;=e?l000001oo:
cM`00ol0003o^;[KokRjf`02okRjf`04o`000?nY/mooZK?OojVcg`?o00000_nHZn<00ol0003oQ:3U
ohBPi@02ohBPi@04o`000?m^TnGo0000o`0000?oF8GS1?m2Mml3o`000003o`1BbOl0A;ko000000?o
0000:?ooool2o`0002Gooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
=oooool2o`0000SoXJKJ00?o0000ojFWeonUYmL01_nUYmL2o`0000CoZJSE00Co0000ojjYdon^ZM?o
00001OnhaN@00ol0003o_LKQokg6h@04okg6h@;o00001Oo2amh00ol0003oalSKolO8f`02olO8f`05
o`000?o;b=OoblSGol_8eol000000_o?bM@01?l0003od>?Uom3SiOl00004omGQh0?ofMkJ00?o0000
omcKeOoLfmD00_oLfmD01Ol0003ogmW@omoId?l0003ofnKL00Cogn7F0_l00003on;Ld0?o00001OoP
f]400ol0003ofMKEomWFe@05omWFe@04o`000?oBcMCod/gDom;=e0;o00000oo:cM`00ol0003oa;kE
o`000004okRjf`Co000000?oZK?Oo`000?nHZn<00_nHZn<00ol0003oQ:3UohBPi@02ohBPi@03o`00
0?m^TnGoKY?U00;o00000_mHQN<01?l0003o@WOOod9ggom2Mml2obiZfP;o000000?o05;9o`000?l0
>kL01?l0000Vooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0dooooo`;o00002?nQY]X2o`0000OoYJOG0_l00004ojVXe@;o00001?n^ZM<01?l0
003o^<GTokS5i?nhaN@6okg6h@;o00001Oo2amh2o`0000CoalSK00Go0000ol_8eoo;b=OoblSGo`00
0003olo9e0;o00001?oEhN001Ol0003ofMkJomWNf_oIg][o000000?og=_E0_l00002omoId0;o0000
0ooOhMH2o`0000?oh]c@0_l00008on3Jd@03o`000?oIe]GofMKE00CofMKE00?o0000om;=e?oBcM@0
1?oBcM@00ol0003ob/gLo`000003olBne@03o`000?nh^]_o000000?o00001?nY/ml01Ol0003oV:_S
oiR[honHZn?o000000CoQ:3U00Co0000ofjCiOl0003o00000omHQN<4od9gg`?o;V[J0ol000000ol0
>kOo0000o`000002o`0002Kooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o00006Oooool00ol0
003oooooooooo`0aooooo`;o00002?nQY]X2o`0000OoYJOG0_l00005ojVXe@03o`000?n^ZM?o[ZWC
00Co[ZWC0_l00006okg6h@;o00001Oo2amh2o`0000CoalSK0_l00002ol_8e`;o00000oo?bM@00ol0
003od/WAo`000003omGQh003o`000?oIg][ofMkJ00;o00000ooLfmD01ol0003ogmW@omoId?oOfM3o
0000on7Fc?l000000_oOhMH00ol0003oh]c@on;Ld002on;Ld003o`000?oSf<_o000000Koh=[A2Ol0
0008om;=e004o`000?o4_]Goa;kEolBne@?o00000onh^]/00ol0003oZK?OojVcg`02ojVcg`05o`00
0?nHZn?oV:_SoiR[hol000001?n4X>D00ol0003oKY?UofjCi@02o`0000;oF8GS00Go0000od9ggom2
Mmoo@WOOo`000002obiZfP;o7UoD0_l000000ol0>kOo0000o`000002o`0002Kooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool0
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`?o00001onQY]X2o`00
00OoYJOG0_l00006ojVXe@03o`000?n^ZM?o[ZWC00Co[ZWC00?o0000ok:ZdOl000001Onma^400ol0
003o`/ONol;7gP04ol;7gP03o`000?o7b=_oalSK00?oalSK00Go0000ol_8eoo;b=OoblSGo`000004
olo9e006o`000?oBbM7od/WAom;9dOl0003oeN7P0ooIg]X01?l0003og=_EomcKeOoLfmD2o`0000?o
gmW@00Ko0000on7Fc?oQe/co0000omoQe_l00003on;Ld0;o00000_oSf</01?l0003oh=[Aon3JdOoP
f]43o`000003on;Eb_l0003ogM?=00GogM?=00Co0000omS<cOl0003o00000ooBcM@00ol0003ocL;@
o`000003o`0000;oa;kE00Go0000okRjfonh^]_o^;[Ko`000005ojVcg`05o`000?nHZn?oV:_SoiR[
hol000000on4X>D01Ol0003oKY?UofjCiOm^TnGo000000?oF8GS00Co0000od9ggom2Mmoo00000ol^
J]X3oaiOe004o`000?l0>kOo0000o`0g]0?o00009Oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`00:Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02cooooo00Go0000ohj?d?n>Sm3oSXo@o`000004oj6VfP;o
00002?nUYmL00ol0003oZJSEojVXe@04ojVXe@;o00001On^ZM<2o`0000?o/Z[A00Co0000okg6hOnm
a^7o00001_o2amh2o`0000CoalSK0_l00003ol_8e`03o`000?o?bMCoclWD00;oclWD00Co0000om;9
dOoBbM7od/WA0_l00003omWNfP05o`000?oLfmGog=_EomcKeOl000001?oOfM000ol0003ohMK<on7F
c002o`0000Coh]c@00Ko0000on?HbooSf<_ohmS;o`000?oPf]43o`0000?oh]G:00?o0000omgCcOoM
dld01?oMdld00ol0003of<c=omS<c@02omS<c@03o`000?oBcMCo000000Co00001?o4_]D00ol0003o
^;[KokRjf`02okRjf`03o`000?nY/mooZK?O00;oZK?O00Go0000oiR[honHZn?oV:_So`000004ohBP
i@05o`000?m^TnGoKY?UofjCiOl000000_mHQN<01Ol0003o@WOOod9ggom2Mmoo000000;o;V[J00Co
0000oaiOe?lNGmCo7UoD0ol000001?l0=kCo0000o`000?l0000Tooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01oooool0
02Wooooo0ol0000Looooo`03o`000?oooooooooo02[ooooo00?o0000ohj?d?n>Sm000on>Sm001?l0
003oXJKJoj6Vf_l00008ojFWe`;o00001_nYZ=D00ol0003o[ZWCojjYd`04ojjYd`03o`000?nbZ]7o
/Z[A00?o/Z[A0_l00007ol;7gP03o`000?o7b=_oalSK00?oalSK00Co0000ol_8eoo;b=OoblSG0_l0
0004olo9e007o`000?oBbM7od/WAom;9dOl0003oeLW>o`000002omWNfPCog=_E00Co0000omoId?oO
fM3ogmW@0_l00002on7Fc003o`000?oRdlSo000000?oh]c@00Co0000on?HbooSf<_ohmS;0ol00005
on;EbP03o`000?oMdlgogM?=00CogM?=00?o0000omS<cOoHc<d00ooHc<d3o`0000?ocL;@00?o0000
olBneOo4_]D00oo4_]D01Ol0003o^;[KokRjfonh^]_o000000?oZK?O2ol00003ofjCi@05o`000?mH
QN?oF8GSoeR5hol000000_m2Mml01?l0003o;V[JobiZf_l^J]X3oaiOe0;o4EK@0_l000001?l0=kCo
0000o`000?l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0:?ooool00ol0003oSXo@ohj?d004ohj?d0;o00002?nUYmL2o`0000KoZJSE0_l00006ojjY
d`03o`000?nbZ]7o/Z[A00?o/Z[A00Co0000okJ/conf[<oo00001?o2amh00ol0003oalSKolO8f`04
olO8f`05o`000?o;b=OoblSGol_8eol000001?o?bM@2o`0000?od/WA00Go0000omG9c_oEbLkoeLW>
o`000004omcKe@05o`000?oOfM3ogmW@omoId?l000000ooQe/`01?l0003oh]?8on;Cb?l00002on;L
d007o`000?oSf<_ohmS;on?Hbol0003oi=?6o`000006on;EbP03o`000?oMdlgogM?=00CogM?=00?o
0000omS<cOoHc<d00ol000000ooHc<go0000olg2d004olg2d003o`000?o4_]Goa;kE00;oa;kE00?o
0000okRjfonh^]/01Ol00002ojfWdPCoXIoC1?nCUm@6o`0000;oF8GS00Go0000od9ggom2Mmoo@WOO
o`000002obiZfP04o`000?lNGmCo7UoDoaiOe0;o4EK@0_l000001?l0=kCo0000o`000?l0000Roooo
o`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02Oooool0
02Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?n>Sm3oSXo@
00CoSXo@00?o0000oi6@c_l000001_nUYmL2o`0000OoZJSE00?o0000ojjYdon^ZM<01?n^ZM<2o`00
00Go/Z[A00?o0000okJ/conf[<l00_nf[<l01?l0003o`/ONol;7g_l00005olO8f`04o`000?o;b=Oo
blSGol_8e`;o00001?o?bM@00ol0003od/WAom;9d@02om;9d@03o`000?oEbLkoeLW>00;oeLW>00Co
0000omcKeOoLfmGog=_E1?oOfM001Ol0003ohMK<on7Fc?oQe/co000000?oh]?800?o0000on;Ld?oS
f</00ooSf</01?l0003oi=?6onCCa_l00004on;EbPco00000ooHc<d00ol0003oe<C;o`000005olg2
d004o`000?o4_]Goa;kEolBne@?o00000_nh[/l00ol0003o[JOBojfWdP02ojfWdP05o`000?nQWm?o
XIoCoj6Odol000001?nCUm@3ohJ>e0?o00000_mHQN<01?l0003o@WOOod9ggol00002obiZfP05o`00
0?lNGmCo7UoDoaiOe?l000000_lAE]02o`000004o`0g]?l0003o0000o`0002?ooooo00?o0000oooo
ooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?n>
Sm3oSXo@00CoSXo@00Go0000oi6@c_nAT<koTI3>o`000004ojFWe`03o`000?nYZ=GoZJSE00KoZJSE
00?o0000ojjYdon^ZM<01?n^ZM<00ol0003o/Z[Aok:Zd@04ok:Zd@03o`000?nf[<oo]Zc?00?o]Zc?
0_l00006olO8f`05o`000?o;b=OoblSGol_8eol000001Oo?bM@00ol0003od/WAom;9d@02om;9d@03
o`000?oEbLkoeLW>00;oeLW>00Co0000omS9bol0003og=_E1?oOfM001Ol0003ohMK<on7Fc?oQe/co
000000Coh]?800?o0000on?HbooSf</00_oSf</01?l0003oi=?6onCCa_l00002on;EbP?o000000?o
hm75o`000?oPd<L00ooPd<L3o`000003omg;aol0003of<c=00;of<c=00Co0000omC4booDa<_o0000
1Oo=`]001_l0003oa;kEo`000?l0003o`[C=o`0000?o^:k?00?o0000ojfWd_n]Ym800_n]Ym801Ol0
003oXIoCoj6OdonQWm?o000000CoTiOD1?n6S]@2ogR5d`?o00000_m2Mml01Ol0003o;V[JobiZf_l^
J][o000000?o7UoD0_lAE]02o`M@c@03o`000?l0=kCo000000;o00008oooool00ol0003ooooooooo
o`0Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`?o00008Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?n>Sm3oSXo@00CoSXo@00?o0000oi6@c_nAT<h00onAT<h01?l0003oYJOG
ojFWeol00007ojVXe@;o00001On^ZM<2o`0000Ko/Z[A00?o0000okJ/conf[<l00onf[<l01?l0003o
^jk=ok^^cOl00004olO8f`05o`000?o;b=OoblSGol_8eol000001Oo?bM@00ol0003od/WAom;9d@02
om;9d@03o`000?oEbLkoeLW>00;oeLW>00Co0000omS9booHbL_o00001?oOfM04on7Fc003o`000?oR
dlSoh]?800;oh]?80_l00003on?Hb`Coi=?600?o0000on;Eb_l000000ooSdLD01?l0003oh=37on3@
aooPd<L2o`000003on3@aol0003ogL_700;ogL_700?o0000omS<cOl000001?oDa</00ol0003ocL;@
olg2d002olg2d0;o00000oo2]<d01Ol0003o^:k?okR^conh[/oo000000Co[JOB00Go0000oj6OdonQ
Wm?oXIoCo`000004oi>Ge007o`000?n6S]CoQXkDohJ>e?l0003oN8GCo`000002ogR5d`;o000000Go
@WOOo`000?l^J][o;V[Jo`000003oaiOe003o`000?lAE]3o4EK@00;o1e3=00?o0000o`0g]?l00000
0_l0000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00006ohj?d003o`000?nAT<koTI3>00GoTI3>
00?o0000ojVXeOnYZ=D01_nYZ=D00ol0003o[ZWCojjYd`04ojjYd`03o`000?nbZ]7o/Z[A00Co/Z[A
0_l00005okJ/c`03o`000?nk[/go^jk=00;o^jk=00?o0000olO8foo7b=/01?o;b=L00ol0003oclWD
olo9e003olo9e003o`000?oBbM7od/WA00;od/WA00?o0000omG9c_oEbLh00_oEbLh01Ol0003of<W;
omS9booHbL_o000000?ogmW@1?oQe/`5on;Cb003o`000?oSdLGo000000;ohmS;1?oTdlH2o`0000Go
hm751?l00002on3@a`03o`000?oMblOogL_700?ogL_700?o0000omC4booDa</00ooDa</00ol0003o
cL;@olg2d002o`000003ol^ibOl0003o`[C=00;o`[C=00Go0000okR^conh[/oo^:k?o`000004ojfW
dP05o`000?nQWm?oXIoCoj6Odol000001?nCUm@01Ol0003oQXkDohJ>e?n6S]Co000000;oN8GC00Ko
0000ogR5dom[O=;oJgcBod9ggol00003obiZfP04o`000?lNGmCo7UoDo`0000;o4EK@00Go0000o`M@
cOl7D<go0000o`0g]003o`0002;ooooo00?o0000ooooooooool07Oooool000Kooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00?o0000ohj?d?n>Sm001On>Sm00
0ol0003oTI3>oi6@cP05oi6@cP03o`000?nET<co000000KoZJSE00?o0000ojjYdon^ZM<01?n^ZM<0
0ol0003o/Z[Aok:Zd@04ok:Zd@03o`000?nf[<oo]Zc?00Co]Zc?00?o0000ok^^cOnk[/d00onk[/d2
o`0000CoblSG1_o?bM@01?l0003od/WAom;9dOoBbM42o`0000CoeLW>00So0000omS9booHbL_of<W;
o`000?oJbLSo0000omoId0CohMK<1OoRdlP01Ol0003ohm75on?AaOl0003ohmS;00Coi=?600?o0000
onG@`_l000000ooSdLD3o`0000Coh=3700?o0000omg;aooMblL01?oMblL00ol0003oe<C;omC4b`03
omC4b`03o`000?o=`]3o000000?obkW900Go0000ol:dcOo2]<go`[C=o`000003okR^c`03o`000?n]
Ym;o[JOB00;o[JOB00Go0000oj6OdonQWm?oXIoCo`000004oi>Ge005o`000?n6S]CoQXkDohJ>e?l0
00000omhQM<01Ol0003oJgcBof]ld_m[O=;o000000?o;V[J00Go0000oaiOe?lNGmCo7UoDo`000002
oa5Fd0?o1e3=1Ol0000Rooooo`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02Cooooo0_l0000Looooo`03o`000?n>Sm3oSXo@00GoSXo@00?o0000oi6@c_nAT<h01OnA
T<h01Ol0003oUI3<oiF@c?nET<co000000CoZJSE1_n^ZM<2o`0000Ko/Z[A00?o0000okJ/conf[<l0
1?nf[<l00ol0003o^jk=ok^^c@03ok^^c@04o`000?no/<_o_k3;o`0000;oblSG1_o?bM@5om;9d@Go
eLW>00Go0000omS9booHbL_of<W;o`000002om[9b003o`000?oQe/cohMK<00;ohMK<1OoRdlP01Ol0
003ohm75on?AaOoSdLGo000000Coi=?600Co0000onG@`_oUd<;ohm752ol00005omg;a`03o`000?oI
aLKo000000Goe<C;00?o0000ol^ibOo;^LT00_o;^LT01Ol0003o`[C=ol:dcOo2]<go000000?o^:k?
00?o0000ojfWd_n]Ym800on]Ym801?l0003oXIoCoj6Odol00004oi>Ge005o`000?n6S]CoQXkDohJ>
e?l000001?mhQM<01?l0003oJgcBof]ld_m[O=82o`0000;o;V[J00Co0000oaiOe?lNGmCo00000_lA
E]000ol0003o1e3=o`M@c@02o`9<b`Co00008?ooool00ol0003oooooo`00000Mooooo`001_ooool0
1Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`03o`000?n>Sm3oSXo@00GoSXo@00?o
0000oi6@c_nAT<h01OnAT<h00ol0003oUI3<oiF@c003oiF@c003o`000?nYZ=GoZJSE00Ko[ZWC00?o
0000ok:ZdOnbZ]401OnbZ]400ol0003o]Zc?okJ/c`04okJ/c`03o`000?nk[/go^jk=00?o^jk=00?o
0000okn`bono/</00_no/</00ol0003oclWDolo9e004olo9e0God/WA1OoEbLh01Ol0003of<W;omS9
booHbL_o000000?of/W800Co0000on7Fc?oQe/cohMK<1OoRdlP01?l0003ohm75on?AaOoSdLD2o`00
00?oi=?600?o0000onG@`_l000001Ol000000ooTc/7o0000on;=``03on;=``03o`000?oPb/?o0000
00?ogL_700Co0000omW5a_oIaLKo00001?oDa</2o`0000CobkW900Go0000ol:dcOo2]<go`[C=o`00
0004okR^c`03o`000?n]Ym;o[JOB00;o[JOB00Go0000oj6OdonQWm?oXIoCo`000003oi>Ge005o`00
0?n6S]CoQXkDohJ>e?l000001?mhQM<01?l0003oJgcBof]ld_m[O=82oemdd003o`000?l^J][o0000
00?o7UoD00?o0000oa5Fd?lAE]000ol7D<d3o`9<b`?o00008Oooool00ol0003oooooooooo`0Koooo
o`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0F
ooooo`03o`000?n>Sm3oSXo@00GoSXo@00?o0000oi6@c_nAT<h01OnAT<h00ol0003oUI3<oiF@c005
oiF@c003o`000?n^ZM?o[ZWC00Co[ZWC00?o0000ok:ZdOnbZ]401OnbZ]400ol0003o]Zc?okJ/c`04
okJ/c`03o`000?nk[/go^jk=00?o^jk=00?o0000okn`bono/</00ono/</2o`0000CoclWD1OoBbM45
omG9cP05o`000?oHbL_of<W;omS9bol000000ooJbLP01?l0003og<S5o`000?oQe/`5on;Cb007o`00
0?oSdLGohm75on?AaOl0003oi<k2o`000002onCCaP?o000000?oiM32o`000?l000001?oTc/44on;=
``07o`000?oPb/?oh<[3on3:`ol0003ogL_7o`000004omW5aP06o`000?oDa<_oe<C;o`000?oB_LKo
00001?o;^LT00ol0003o`[C=ol:dc@02ol:dc@05o`000?nh[/oo^:k?okR^col000001?n]Ym801Ol0
003oXIoCoj6OdonQWm?o000000?oTiOD00Go0000ohJ>e?n6S]CoQXkDo`000004ogR5d`;o00000_m[
O=84oemdd005o`000?lNGmCo7UoDoaiOe?l000000_lAE]001?l0003o1e3=o`M@cOl00003o`9<b`?o
00008Oooool00ol0003oooooooooo`0Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01Cooooo00?o0000ohj?d?n>Sm001On>Sm000ol0003oTI3>oi6@cP05oi6@
cP03o`000?nET<coUI3<00KoUI3<0_l00004ojjYd`So/Z[A00?o0000okJ/conf[<l01?nf[<l00ol0
003o^jk=ok^^c@03ok^^c@03o`000?no/<_o_k3;00?o_k3;00Co0000ol>bbOo3//Wo00000_o?bM@5
om;9d@GoeLW>00Go0000omS9booHbL_of<W;o`000003om[9b004o`000?oLb<Gog<S5o`0000Goh]?8
00Ko0000on?AaOoSdLGohm75o`000?oTc/84o`0000;oiM320_l00005onC>`@03o`000?oRcL?oh/g3
00;oh/g300?o0000on3:`ooPb/<00_oPb/<00ol0003ofLG6omW5aP03omW5aP03o`000?oDa<_o0000
00;od[g600?o0000ol^ibOo;^LT00_o;^LT00ol0003o`[C=ol:dc@02ol:dc@05o`000?nh[/oo^:k?
okR^col000001?n]Ym801Ol0003oXIoCoj6OdonQWm?o000000?oTiOD00?o0000ohJ>e?n6S]@00_n6
S]@02Ol0003oN8GCogR5domhQM?o0000of]ld_l0003oJgcBo`000004oemdd0;o00000_lNGm@01?l0
003o4EK@oa5Fd?l00002o`M@c@?o0Tc;0_l1C</2o`00023ooooo00?o0000ooooooooool06_ooool0
02Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`03o`000?n>Sm3oSXo@
00GoSXo@00?o0000oi6@c_nAT<h01OnAT<h00ol0003oUI3<oiF@c006oiF@c004o`000?nJT/[oVY;:
o`0000;o[ZWC2?nbZ]400ol0003o]Zc?okJ/c`03okJ/c`;o00001Onk[/d00ol0003o_k3;okn`b`03
okn`b`03o`000?o3//Wo`k;900;o`k;900?o0000om;9dOoBbM400ooBbM45omG9cP05o`000?oHbL_o
f<W;omS9bol000000ooJbLP01Ol0003og<S5omc8aOoLb<Go000000Coh]?800Co0000on?AaOoSdLGo
hm751?l000001ooTdlKoiM32onG@`_oUd<;o0000onG=_ol000001OoTc/401Ol0003oh/g3on;=`ooR
cL?o000000Goh<[300?o0000omW5a_oIaLH01?oIaLH01Ol0003od[g6om:ma_oB_LKo000000CobkW9
00?o0000ol:dcOo2]<d00_o2]<d01Ol0003o^:k?okR^conh[/oo000000Co[JOB00Go0000oj6OdonQ
Wm?oXIoCo`000003oi>Ge003o`000?n6S]CoQXkD00;oQXkD00Wo0000ogR5domhQM?oN8GCo`000?m[
O=;o0000of]ld_l000001?mOM=02oeE]c`03o`000?lNGmCo000000;o4EK@00Co0000o`M@cOl7D<go
00000ol2C</2o`5<b`;o00008?ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo
00?o0000ooooooooool04?ooool00ol0003oSXo@ohj?d005ohj?d003o`000?nAT<koTI3>00GoTI3>
00?o0000oiF@c?nET<`01_nET<`00ol0003oVY;:oiZBbP02oiZBbP03o`000?nbZ]7o/Z[A00Ko/Z[A
1_nf[<l00ol0003o^jk=ok^^c@04ok^^c@03o`000?no/<_o_k3;00?o_k3;00?o0000ol>bbOo3//T0
0oo3//T00ol0003od/WAom;9d@02om;9d@GoeLW>00Go0000omS9booHbL_of<W;o`000003om[9b007
o`000?oLb<Gog<S5omc8aOl0003og/S3o`000003on;Cb0;ohm750ol00002onC>`P05o`000?oUd<;o
iM32onG@`_l000000_oUcKl00ol0003oi<k1onC>`@02onC>`@03o`000?oRcL?oh/g300;oh/g300?o
0000on3:`ooPb/<00_oPb/<00ol0003ogLK2o`000004omW5aP;o00000ooB_LH00ol0003obkW9ol^i
b@02ol^ib@03o`000?o2]<go`[C=00;o`[C=00Go0000okR^conh[/oo^:k?o`000004ojfWdP05o`00
0?nQWm?oXIoCoj6Odol000000onCUm@00ol0003oQXkDohJ>e002ohJ>e003o`000?mhQM?oN8GC00;o
N8GC00Co0000of]ld_l0003o00001?mOM=04oeE]c`04o`000?lAE]3o4EK@o`0000?o1e3=0ol2C</3
o`5<b`;o00008?ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00kooooo00?o0000ohj?d?n>Sm001On>Sm000ol0003oTI3>oi6@cP05oi6@
cP03o`000?nET<coUI3<00KoUI3<00?o0000oiZBb_nJT/X00onJT/X2o`0000Ko/Z[A1_nf[<l00ol0
003o^jk=ok^^c@04ok^^c@03o`000?no/<_o_k3;00?o_k3;00?o0000ol>bbOo3//T00oo3//T00ol0
003oakC8o`000002om;9d@GoeLW>00Go0000omS9booHbL_of<W;o`000003om[9b005o`000?oLb<Go
g<S5omc8aOl000000_oNb<<00ol0003oh]?8on;Cb004o`0000Coi<k200Co0000onG@`_oUd<;oiM32
0ooUcKl01?l0003oi<k1onC>`OoTc/47o`0000?oh<[300Go0000omg6`_oMa/;ogLK2o`000002omW5
aP03o`000?oG`<?o000000Cod[g600Go0000ol^ibOo;^LWobkW9o`000004ol:dc@03o`000?nh[/oo
000000Wo000000?oXIoCo`000?nCUm@00_nCUm@00ol0003oQXkDohJ>e002ohJ>e003o`000?mhQM?o
N8GC00;oN8GC00Co0000of]ld_m[O=;o00001?mOM=000ol0003oEFg?oeE]c`02oeE]c`;o000000Go
4EK@o`000?l7D<go1e3=o`000003o`9<b`?o0Dc;0_l0000Nooooo`;o00006_ooool002Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03ofmic?l0003oSXo@00CoSXo@00?o
0000oi6@c_nAT<h01OnAT<h00ol0003oUI3<oiF@c006oiF@c003o`000?nJT/[oVY;:00?oVY;:00Co
0000oijDbOnNU<Wo00001?nbZ]46okJ/c`03o`000?nk[/go^jk=00Co^jk=00?o0000okn`bono/</0
0ono/</00ol0003o`k;9ol>bb@03ol>bb@05o`000?o7]<SoakC8olNdb?l000001OoEbLh01Ol0003o
f<W;omS9booHbL_o000000?of/W800Go0000omc8aOoLb<Gog<S5o`000003omk8``?o00000_oSdLD0
0ol0003oi<k2onC>`P02onC>`P;o00000_oUd<83onG=_`03o`000?oTc/7oi<k100;o000000?oiLbn
o`000?oSbkl00_oSbkl01Ol0003oh/Voo`000?oPb/?o000000CogLK200?o0000omW5a_l000000_oG
`<<00ol0003od[g6om:maP02om:maP05o`000?o;^LWobkW9ol^ibOl000000_o2]<d4o`0000;o_J[7
00?o0000okBTb?ndY<P00_ndY<P00ol0003o[9g8ojbMb004o`000003oi>Ge?l0003oQXkD00?oQXkD
00?o0000ogR5domhQM<00_mhQM<00ol0003oJgcBof]ldP02o`0000?oGgC@00?o0000oeE]comEKLl0
0_mEKLl2odaXc@;o00000ol7D<d01?l0003o0Tc;o`9<bol00002o`5<b`;o0dk<00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00_ooooo00Co0000ofmic?m_NLco00000on>Sm000ol0003oTI3>oi6@cP05oi6@cP03
o`000?nET<coUI3<00KoUI3<00?o0000oiZBb_nJT/X00onJT/X00ol0003oWYC9oijDb@02oijDb@03
o`000?nbZ]7o/Z[A00Ko]Zc?00?o0000ok^^cOnk[/d01?nk[/d00ol0003o_k3;okn`b`03okn`b`03
o`000?o3//Wo`k;900?o`k;900?o0000olNdb?o7]<P00_o7]<P2o`0000CoeLW>0ooHbL/01Ol0003o
f/W8om[9b?oJbLSo000000?og<S500?o0000omk8`ol000000_l000001OoNb<?o0000on?AaOoSdLGo
000000Coi<k200Co0000onC=_ol0003oiM321?oUcKl00ol0003oi<k1o`000003onG<_P?ohl^o00Go
0000on;9_ooRbKooh/Voo`000006omg6`P05o`000?oG`<?oel33omO0`ol000001?oB_LH00ol0003o
bkW9ol^ib@04o`0000;oaK3600Go0000okfZaonmZ/Oo_J[7o`000004okBTb005o`000?n/WLSo[9g8
ojbMb?l000000_nRUlT3o`0000?oQXkD00?o0000ogR5domhQM<00_mhQM<01Ol0003oJgcBof]ld_m[
O=;o000000?oGgC@00?o0000oeE]comEKLl00_mEKLl3odaXc@05oa5Fd?l0003o1e3=o`M@cOl00000
0_l2C</01?l0003o0Dc;o`5<bol1C</2o`=>c003o`000?oooooooooo01gooooo00?o0000oooooooo
ool05_ooool002Oooooo0_l0000`ooooo`03o`000?oooooooooo00[ooooo00Go0000ofmic?m_NLco
KgW<o`000002ohj?d0OoTI3>00?o0000oiF@c?nET<`01_nET<`00ol0003oVY;:oiZBbP03oiZBbP03
o`000?nNU<WoWYC900CoWYC90_l00006okJ/c`Ko^jk=00?o0000okn`bono/</00ono/</00ol0003o
`k;9ol>bb@03ol>bb@03o`000?o7]<SoakC800;oakC800Co0000ol^ga_o;]lKo00000_oEbLh3omS9
b`03o`000?oJbLSof/W800;of/W800?o0000omc8aOoLb<D00ol00003omk8``04o`000?oPb<7o0000
on?Aa@Coi<k200Co0000onC=_ooTcKoo00001?oUcKl2o`0000CoiLbn00Go0000on?;_ooSbkoohl^o
o`000003on;9_`03o`000?oMa/;ogLK200?ogLK20_l00004omO0``04o`000?oB_LKod[g6om:maP?o
000000?oc;G4o`000?o5/<H00oo5/<H01Ol0003o_J[7okfZaonmZ/Oo000000?o]:C800?o0000ojbM
b?n/WLP00_n/WLP01?l0003oXYO9oj:GbOnRUlT2oiV@b@Co00001?mhQM<01?l0003oJgcBof]ld_m[
O=82o`0000;oGgC@00?o0000oeE]comEKLl00_mEKLl01Ol0003oC6S=odaXcOm<J<go000000;o1e3=
00Go0000o`9<bol2C<_o0Tc;o`000002o`5<b`?o0dk<00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Fooooo`009_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo
00?o0000ofmic?m_NL`00om_NL`00ol0003oTI3>oi6@cP05oi6@cP03o`000?nET<coUI3<00KoUI3<
00?o0000oiZBb_nJT/X00onJT/X00ol0003oWYC9oijDb@05oijDb@03o`000?nTUlSo000000Co]Zc?
1_nk[/d00ol0003o_k3;okn`b`03okn`b`03o`000?o3//Wo`k;900?o`k;900?o0000olNdb?o7]<P0
0_o7]<P00ol0003obkO6ol^gaP02ol^gaP03o`000?oHbL_of<W;00;of<W;1?oJbLP00ol0003og<S5
o`000002o`0000Cog/S300Co0000on38`OoPb<7o00001?oTc/801Ol0003oi<foonC=_ooTcKoo0000
00?oiLfo00?o0000onG;_Ol000000ooUc;h01Ol0003ohl^oon?;_ooSbkoo000000?oh/Vo00?o0000
on36__l000000ooMa/800ol0003og<?0o`000004omO0``03o`000?oB_LKod[g600;o00000oo<]L@0
0ol0003oaK36olF`aP02olF`aP04o`000?nmZ/Oo_J[7o`0000Co]:C800Go0000ojbMb?n/WLSo[9g8
o`000004oj:Gb@GoVI390_l00003ogR5d`09o`000?m[O=;oJgcBof]ld_l0003oGgC@o`000?mOM=3o
000000CoEFg?00?o0000odaXcOm<J<d00_m<J<d2o`000005o`M@cOl0003o0Tc;o`9<bol000000_l1
C</01Ol0003o0dk<o`=>c?l3C/co000001kooooo00?o0000ooooooooool05Oooool002Kooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?m_NLcoKgW<00?oKgW<00?o
LWW:o`000?nAT<h01?nAT<h00ol0003oUI3<oiF@c006oiF@c003o`000?nJT/[oVY;:00?oVY;:00?o
0000oijDbOnNU<T01OnNU<T01Ol0003oY9O8ojBGb?nTUlSo000000;o]Zc?1_nk[/d00ol0003o_k3;
okn`b`04okn`b`03o`000?o3//Wo`k;900;o`k;900?o0000olNdb?o7]<P00_o7]<P00ol0003obkO6
ol^gaP03ol^gaP;o00000_oHbL/4om[9b0?o000000?og<S5o`000?oNb<<00ooNb<<01Ol0003oh<S1
on38`OoPb<7o000000?oi<k200Co0000onC=_ooTcKooi<fo0_l00002onG=_`04o`000?oUbkgoiL^m
o`0000?oiLbn00Go0000on?;_ooSbkoohl^oo`000002on;9_`04o`000?oPa[koh<Jno`0000;ogLK2
00Co0000omc3`?oL`l3o00001?oG`<<3o`000003om:j`_l0003oc;G400;oc;G400Go0000olF`a_o5
/<KoaK36o`000003okfZa`03o`000?ndY<So]:C800;o]:C800Go0000ojbMb?n/WLSo[9g8o`000004
oj:Gb@GoVI390_n@R/P2o`000003ogR5dol0003oJgcB00;oJgcB00?o0000oemdd?mOM=000_l00004
oeE]c`03o`000?m<J<goC6S=00;oC6S=0_m6I<`2o`0000?o0Tc;00Co0000o`5<bol1C<_o00000_l3
C/`00ol0003oooooooooo`0Looooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`05ooooo`03o`000?m_NLcoKgW<00?oKgW<00Co0000og9ib_mbNL[o00000onA
T<h00ol0003oUI3<oiF@c006oiF@c003o`000?nJT/[oVY;:00CoVY;:00?o0000oijDbOnNU<T01?nN
U<T00ol0003oY9O8ojBGb003ojBGb003o`000?nk[/go^jk=00Co^jk=00?o0000okn`bono/</01?no
/</00ol0003o`k;9ol>bb@02ol>bb@03o`000?o7]<SoakC800;oakC800?o0000ol^ga_o;]lH00oo;
]lH01?l0003ockW5olniaOl00002om[9b0?o00000ooLb<D00ol0003og/S3omk8``02omk8``04o`00
0?oPb<7oh<S1on38`@;o00000_oTc/802Ol0003oi<foonC=_ooTcKoo0000onG;_Ol0003oiLfoo`00
0003onG;_@05o`000?oUc;koiLbnonG<__l000000ooSbkl01?l0003oh/Voon;9_ol00002on36_P03
o`000?oMa/;o000000?og<?000Co0000omO0`ooG`<?oel330_l00003om:j`P05o`000?o<]LCoc;G4
olbea?l000000oo5/<H01Ol0003o_J[7okfZaonmZ/Oo000000Co]:C800Go0000ojbMb?n/WLSo[9g8
o`000003oj:Gb@03o`000?nIT<WoVI3900?oVI391On@R/P2o`0000;oJgcB00Ko0000oemdd?mOM=3o
0000oemdd?l00003oeE]c`03o`000?m<J<goC6S=00;oC6S=0om6I<`01Ol7D<go0000o`9<bol2C<_o
000000;o0Dc;00Go0000o`=>c?l3C/co0dk<o`00000Nooooo`03o`000?oooooooooo01Cooooo000V
ooooo`?o0000=?ooool00ol0003oooooooooo`04ooooo`03o`000?m_NLcoKgW<00?oKgW<00Go0000
og9ib_mbNL[oLWW:o`000002oi6@cPSoUI3<00?o0000oiZBb_nJT/X01?nJT/X00ol0003oWYC9oijD
b@04oijDb@03o`000?nTUlSoY9O800CoY9O800?o0000ok^^cOnk[/d00onk[/d00ol0003o_k3;okn`
b`04okn`b`03o`000?o3//Wo`k;900;o`k;900?o0000olNdb?o7]<P00oo7]<P00ol0003obkO6ol^g
aP02ol^gaP04o`000?o?^LGockW5olnia@?o000000?of/W8o`000?oLb<D00ooLb<D01Ol0003og/S3
omk8`ooNb<?o000000?oh<S100Go0000on78_ooQb;oo0000onC>`P03onC=_`05o`000?oUbkgoiL^m
o`000?oUcKl00ooUbkd00ol0003oiLbnonG<_P07o`000003on;9_ol0003oh<Jn00?oh<Jn00?o0000
omc3`?oL`l000_oL`l001_l0003oel33o`000?l0003oekg0o`0000?od[[200Go0000olbea?o<]LCo
c;G4o`000003olF`aP05o`000?nmZ/Oo_J[7okfZaol000001?ndY<P01Ol0003o[9g8ojbMb?n/WLSo
000000?oXYO900?o0000oiV@bOnIT<T00onIT<T5oi2:b0;oR8C800?o0000of]ld_l000000omOM=02
o`0000?oEFg?00?o0000odaXcOm<J<d00_m<J<d01Ol0003oAVC<odITc?m6I<co000000?o0Tc;00Co
0000o`5<bol1C<_o00000_l3C/`00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo
000Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oKgW<ofmi
c003ofmic003o`000?mbNL[oLWW:00?oLWW:00?o0000oiF@c?nET<`01_nET<`00ol0003oVY;:oiZB
bP04oiZBbP03o`000?nNU<WoWYC900CoWYC900?o0000ojBGb?nTUlP01?nTUlP00ol0003oZI[7o`00
0004ok^^c@Ko_k3;00?o0000ol>bbOo3//T00oo3//T00ol0003oakC8olNdb002olNdb003o`000?o;
]lKobkO600;obkO600?o0000olniaOl000000_l000001?oB^l?o0000om[9b?oJbLP4omc8a@05o`00
0?oNb<?og/S3omk8`ol000000ooPb<401Ol0003ohLRoon78_ooQb;oo000000?oi<fo00Go0000onG;
_OoUbkgoiL^mo`000004onG;_@05o`000?oUc;ko0000onG9^ol000000ooTbK`00ol0003ohlRlo`00
0005on36_P03o`000?oL`l3og<?000;og<?00_l00003omNm`004o`000?oB^/;od[[2o`0000Coc;G4
00Go0000olF`a_o5/<KoaK36o`000003okfZa`05o`000?ndY<So]:C8okBTb?l000001?n/WLP01Ol0
003oXYO9oj:GbOnRUlWo000000CoVI3900?o0000oi2:b?n@R/P00on@R/P3ohR4b0;o00001?mOM=00
1Ol0003oEFg?oeE]comEKLoo000000CoC6S=00?o0000odITc?m6I<`00_m6I<`2o`000005o`9<bol0
003o0Dc;o`5<bol000000_l3C/`00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo
000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0fooooo`04o`00
0?ooooooooooo`0000KoKgW<00?o0000og9ib_mbNLX00ombNLX00ol0003oUI3<oiF@c005oiF@c003
o`000?nJT/[oVY;:00CoVY;:00?o0000oijDbOnNU<T01OnNU<T00ol0003oY9O8ojBGb003ojBGb005
o`000?nYV/OoZI[7ojVJaol000000_nk[/d6okn`b`03o`000?o3//Wo`k;900?o`k;900?o0000olNd
b?o7]<P00_o7]<P00ol0003obkO6ol^gaP02ol^gaP?o000000?ockW5o`000?oB^l<00_oB^l<2o`00
00?og<S500?o0000omk8`ooNb<<00_oNb<<01Ol0003oh<S1on38`OoPb<7o000000?ohLRo00Go0000
onC=_ooTcKooi<foo`000003onG;_@03o`000?oUbkgoiL^m00;oiL^m00Go0000onG9^ooUbK_oiLVk
o`000003onC9_0;ohlRl00?o0000on36__oPa[h00_oPa[h2o`0000Cog<?000?o0000omNm`?oG_L00
0_oG_L001?l0003od[[2om:j`_l00003olbea003o`000?o5/<KoaK3600;oaK3600Go0000okfZaonm
Z/Oo_J[7o`000003okBTb005o`000?n/WLSo[9g8ojbMb?l000001?nRUlT00ol0003oVI39oiV@b@02
oiV@b@03o`000?n@R/SoT8[800;oT8[800?o0000ohR4b?n8Q<P00_n8Q<P2o`0000?oGgC@0_l00003
oeE]c`05o`000?m<J<goC6S=odaXcOl000001?m6I<`2od5Qc0;o00000ol1C</01?l0003o0dk<o`=>
c?l0000Oooooo`03o`000?oooooooooo01;ooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`0hooooo`?o00001Om_NL`00ol0003oLWW:og9ibP03og9ibP03o`00
0?mgN/Wo000000GoUI3<00?o0000oiZBb_nJT/X01?nJT/X00ol0003oWYC9oijDb@05oijDb@03o`00
0?nTUlSoY9O800?oY9O800?o0000ojVJaonYV/L00onYV/L2o`0000Go_k3;00?o0000ol>bbOo3//T0
0oo3//T00ol0003oakC8olNdb002olNdb003o`000?o;]lKobkO600?o00001?o?^LD02Ol0003od[_3
om:k`ooB^l?o0000omFm`_l0003og<S5o`000004omk8``05o`000?oPb<7oh<S1on38`Ol000000ooQ
b;l2o`0000;oi<fo00Co0000onG;_OoUbkgoiL^m0_l00003onG;_@;o00000_oUbK/02Ol0003oi<Vl
onC9_?oTbKco0000on?8_?l0003ohlNlo`000002on36_P03o`000?oOa;go000000?og<?00_l00003
omNm`005o`000?oB^/;od[[2om:j`_l000000oo<]L@00ol0003oaK36olF`aP02olF`aP05o`000?nm
Z/Oo_J[7okfZaol000000ondY<P01Ol0003o[9g8ojbMb?n/WLSo000000CoXYO900?o0000oiV@bOnI
T<T00_nIT<T00ol0003oT8[8oi2:b002oi2:b003o`000?n8Q<SoR8C800;oR8C80_n0O/P00ol0003o
GgC@oemdd002o`0000?oEFg?00Go0000odaXcOm<J<goC6S=o`000004odITc0?o@F7<00Go0Tc;o`00
0?l1C<_o0Dc;o`000002o`=>c003o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool4
o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`0003Wooooo00?o0000ofmic?m_NL`01?m_NL`00ol0003oLWW:og9ibP03og9ibP04o`000?mgN/Wo
Mg[9o`0000?oUI3<00?o0000oiZBb_nJT/X01?nJT/X00ol0003oWYC9oijDb@05oijDb@03o`000?nT
UlSoY9O800CoY9O800?o0000ojVJaonYV/L00onYV/L00ol0003o[Yg6o`000003okn`b`03o`000?o3
//Wo`k;900?o`k;900?o0000olNdb?o7]<P00oo7]<P3o`0000;obkO600Go0000olniaOo?^LGockW5
o`000003om:k``05o`000?oE_L;oeKg2omFm`_l000001?oNb<<01Ol0003oh<S1on38`OoPb<7o0000
00?ohLRo00?o0000on;8_OoRb;d00_l00003onG;_@03o`000?oUbK_o000000;oiL^m00?o0000onG9
^ol000000_oUbK/01?l0003oi<VlonC9_?l00002on?8_005o`000?oSakco0000on36__l000000ooO
a;d01Ol0003og<?0o`000?oL`;ko000000?oekg000Go0000om:j`_oB^/;od[[2o`000003olbea003
o`000?o5/<KoaK3600;oaK3600Co0000okfZaonmZ/Oo00001?ndY<P01Ol0003o[9g8ojbMb?n/WLSo
000000?oXYO900?o0000oiV@bOnIT<T00onIT<T00ol0003oT8[8oi2:b002oi2:b003o`000?n8Q<So
R8C800;oR8C80on0O/P01Ol0003oGgC@o`000?mEKLoo000000;oEFg?00Go0000odaXcOm<J<goC6S=
o`000004odITc005o`000?m1HLco@F7<od5Qc?l000000_l1C</01Ol0003o0dk<o`=>c?l3C/co0000
01kooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0iooooo`03o`000?m_NLcoKgW<00?oKgW<00?o0000og9i
b_mbNLX00ombNLX00ol0003oMg[9ogMjb@02ogMjb@03o`000?nET<co000000OoVY;:00?o0000oijD
bOnNU<T01?nNU<T00ol0003oY9O8ojBGb004ojBGb003o`000?nYV/OoZI[700?oZI[700Go0000ojjM
a_n^WLKo[Yg6o`000002okn`b`Go`k;900Co0000olNdb?o7]<SoakC80ol00004ol^gaP05o`000?o?
^LGockW5olniaOl000000ooB^l<00ol0003oeKg2omFm`P02omFm`P05o`000?oNb<?og/S3omk8`ol0
00000ooPb<401Ol0003ohLRoon78_ooQb;oo000000?oh/Rm00Go0000onG;_OoUbkgoiL^mo`000002
onG9^`05o`000?oUbkgo0000onG9^ol000000ooUbK/00ol0003oi<Vlo`000002on?8_005o`000?oS
akcohlNlon?7_?l000001?oOa;d2o`0000;og<2n00Go0000omNm`?oG_L3oekg0o`000003om:j`P05
o`000?o<]LCoc;G4olbea?l000000oo5/<H01Ol0003o_J[7okfZaonmZ/Oo000000Co]:C800Go0000
ojbMb?n/WLSo[9g8o`000003oj:Gb@03o`000?nIT<WoVI3900?oVI3900?o0000oi2:b?n@R/P00_n@
R/P01Ol0003oR8C8ohR4b?n8Q<So000000CoP7k80_l00002oeE]c`03o`000?mEKLoo000000?oC6S=
00?o0000odITc?m6I<`00_m6I<`00ol0003o@F7<od5Qc002od5Qc004o`000?l1C<_o0Dc;o`0000;o
0dk<00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0hooooo`03
o`000?m_NLcoKgW<00CoKgW<00?o0000og9ib_mbNLX00ombNLX00ol0003oMg[9ogMjb@03ogMjb@03
o`000?nJT/[oVY;:00GoVY;:00?o0000oijDbOnNU<T01OnNU<T00ol0003oY9O8ojBGb003ojBGb003
o`000?nYV/OoZI[700?oZI[700?o0000ojjMa_n^WLH00on^WLH00ol0003o`k;9ol>bb@03ol>bb@03
o`000?o7]<So000000;o000000?oakC8o`000?o;]lH00oo;]lH01Ol0003ockW5olniaOo?^LGo0000
00Cod[_300Wo0000omFm`_oE_L;oeKg2o`000?oH_/3o0000omk8`ol000000ooPb<400ol0003ohLRo
on78_`02on78_`05o`000?oRb;goh/Rmon;8_Ol000000_oUbkd01?l0003oiLVkonG9^ooUbK/2o`00
00;oiLVk00Co0000onG9^ooUbK_o00000_oTbK`01?l0003ohlRlon?8_?l00003on?7_003o`000?oO
a;goglBm00;oglBm00Go0000omc0__oL`;kog<2no`000003omNm`004o`000?oB^/;od[[2o`0000Co
c;G400Go0000olF`a_o5/<KoaK36o`000003okfZa`05o`000?ndY<So]:C8okBTb?l000001?n/WLP0
1Ol0003oXYO9oj:GbOnRUlWo000000CoVI3900?o0000oi2:b?n@R/P00_n@R/P00ol0003oR8C8ohR4
b002ohR4b003o`000?n0O/SoP7k800?oP7k80_l00002oeE]c`;o00001?m<J<d01Ol0003oAVC<odIT
c?m6I<co000000Co@F7<00Co?V7=o`000?l1C<_o00000ol3C/`00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oooooooooo03Sooooo00?o0000ofmic?m_NL`00om_NL`00ol0003o
LWW:og9ibP03og9ibP03o`000?mgN/WoMg[900CoMg[900?oO7c8o`000?nJT/X01?nJT/X00ol0003o
WYC9oijDb@05oijDb@03o`000?nTUlSoY9O800?oY9O800?o0000ojVJaonYV/L00onYV/L00ol0003o
[Yg6ojjMaP04ojjMaP;o00000oo3//T3o`0000?oakC800?o0000ol^ga_o;]lH00_o;]lH00ol0003o
ckW5olnia@02olnia@05o`000?oB^l?od[_3om:k`ol000000ooE_L801Ol0003of;k0omRn`?oH_/3o
000000Coh<S100Go0000on78_ooQb;oohLRoo`000003on;8_@04o`000?oSakco0000o`0000CoiLVk
00Ko0000onG9^ooUbK_oiLVko`000?oUbK/6o`000004on?8_?l0003ohlNlon?7_0;o00000ooOa;d2
o`0000;og<2n00?o0000omNm`?oG_L000_oG_L001?l0003od[[2om:j`_l00002olbea0go000000?o
]:C8o`000?n/WLP00_n/WLP00ol0003oXYO9oj:Gb@02oj:Gb@03o`000?nIT<WoVI3900;oVI3900?o
0000oi2:b?n@R/P00_n@R/P00ol0003oR8C8ohR4b002ohR4b003o`000?n0O/SoP7k800?oP7k80_mi
N/L01?l0003oEFg?o`000?l00004odaXc@05o`000?m6I<coAVC<odITc?l000001?m1HL`2ociQc@03
o`000?l1C<_o000000;o0dk<00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0003So
oooo00?o0000ofmic?m_NL`01?m_NL`00ol0003oLWW:og9ibP03og9ibP03o`000?mgN/WoMg[900?o
Mg[900Co0000ogalb?mlO<So00000onJT/X00ol0003oWYC9oijDb@05oijDb@03o`000?nTUlSoY9O8
00CoY9O800?o0000ojVJaonYV/L00onYV/L00ol0003o[Yg6ojjMaP03ojjMaP03o`000?ncXLGo/j75
00?o00001Oo7]<P00ol0003obkO6ol^gaP02ol^gaP03o`000?o?^LGockW500;ockW500Go0000om:k
`ooB^l?od[_3o`000004omFm`P05o`000?oH_/3of;k0omRn`?l000000ooPb<401Ol0003ohLRoon78
_ooQb;oo000000?oh/Rm00Co0000on?7_?oSakco00001OoUbK/00ol0003oiLVkonG9^`03o`000004
onG8^_l0003oiLRjo`0000;oi<Nj00Co0000on?7_?oSakco00000_oRaK/01Ol0003oglBmo`000?oO
`kco000000;og<2n00Go0000omNm`?oG_L3oekg0o`000002om:j`PCo00000_o?]L001Ol0003ob[71
olZa`Oo:/L7o000000?oa:c200?o0000okfW`onmYl<01?l000000on/WLSo0000oj:Gb@03oj:Gb@03
o`000?nIT<WoVI3900;oVI3900?o0000oi2:b?n@R/P00_n@R/P00ol0003oR8C8ohR4b002ohR4b003
o`000?n0O/SoP7k800?oP7k80omiN/L00ol0003oEFg?o`000004odaXc@05o`000?m6I<coAVC<odIT
c?l000001?m1HL`00ol0003o?V7=ociQc@02o`0000;o0dk<00?o0000ooooooooool07oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`0gooooo`03o`000?m_NLcoKgW<00?oKgW<00?o0000og9i
b_mbNLX00ombNLX00ol0003oMg[9ogMjb@04ogMjb@07o`000?mlO<SoO7c8ogalb?l0003oVY;:o`00
0007oijDb@03o`000?nTUlSoY9O800CoY9O800?o0000ojVJaonYV/L00onYV/L00ol0003o[Yg6ojjM
aP03ojjMaPCo000000?o/j75o`000?l000001Oo7]<P00ol0003obkO6ol^gaP02ol^gaP05o`000?o?
^LGockW5olniaOl000001?oB^l<01Ol0003oeKg2omFm`_oE_L;o000000?of;k000Go0000om_0_ol0
003oh<S1o`000004on78_`05o`000?oRb;goh/Rmon;8_Ol000000_oSak`00ol0003oiLVkonG9^`02
onG9^`;o00000_oUbK/00ol0003oiLRjonG8^P03onG8^P?oi<Nj00?o0000on?7_?l000000ooRaK/2
o`0000;ogl>l00Co0000omc0__oL`;ko00000ooG_L03o`000003omBi_ol0003ockG000;ockG000Go
0000olZa`Oo:/L7ob[71o`000004olB/`P05o`000?nmYl?o_JO3okfW`ol000000_ngX/<3o`0000;o
XYO900?o0000oiV@bOnIT<T00onIT<T00ol0003oT8[8oi2:b002oi2:b005o`000?n8Q<SoR8C8ohR4
b?l000001On0O/P00ol0003oNG[7ogUja`02ogUja`?o00000om<J<d01Ol0003oAVC<odITc?m6I<co
000000Co@F7<00Go0000ociQcOlnHLgo?V7=o`000003o`=>c003o`000?oooooooooo01kooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000
ofmic?m_NL`01?m_NL`00ol0003oLWW:og9ibP03og9ibP03o`000?mgN/WoMg[900?oMg[900?o0000
ogalb?mlO<P00omlO<P2o`0000KoWYC900?o0000ojBGb?nTUlP01?nTUlP00ol0003oZI[7ojVJa`03
ojVJa`03o`000?n^WLKo[Yg600;o[Yg60ol00004ok>Qa@03o`000?niY<Co000000?oakC800?o0000
ol^ga_o;]lH00_o;]lH00ol0003ockW5olnia@02olnia@05o`000?oB^l?od[_3om:k`ol000001?oE
_L801?l0003of;k0omRn`?l00003om_0_`;o00000ooQb;l01Ol0003oh/Rmon;8_OoRb;go000000;o
hlNl0_l00003onG9^`04o`000?oUb;[o0000onG9^`;o00000_oUb;X00ol0003oiLRjo`000002onC7
^P03o`000?oTak[o000000Coh/Fk00Go0000omo3_?oO`kcogl>lo`000002omc0_P03o`000?oG_L3o
000000;o00000ooD^Kl01Ol0003ockG0olne`?o?]L3o000000?ob[7100Go0000olB/`_o4[<;oa:c2
o`000003okfW``03o`000?ngX/?o]j;300;o]j;300?o0000ok2L`ol000000_l00005oiV@b@03o`00
0?n@R/SoT8[800;oT8[800Go0000ohR4b?n8Q<SoR8C8o`000005oh1nb003o`000?miN/OoNG[700?o
NG[70ol00002odaXc@05o`000?m6I<coAVC<odITc?l000001?m1HL`00ol0003o?V7=ociQc@02ociQ
c@;o000000?o0dk<o`000?ooool07_ooool00ol0003oooooo`000005ooooo`03oeEEEOmVIVKo0000
00Oooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000ofmic?m_NL`00om_NL`00ol0003o
LWW:og9ibP03og9ibP03o`000?mgN/WoMg[900CoMg[900?o0000ogalb?mlO<P00omlO<P2oh=oa`03
o`000?nNU<WoWYC900?oWYC900?o0000ojBGb?nTUlP01?nTUlP00ol0003oZI[7ojVJa`03ojVJa`03
o`000?n^WLKo[Yg600;o000000?o[Yg6o`000?ncXLD00oncXLD01ol0003o^JC4okVTa?niY<Co0000
olNdb?l000001?o;]lH00ol0003ockW5olnia@02olnia@05o`000?oB^l?od[_3om:k`ol000001?oE
_L801Ol0003of;k0omRn`?oH_/3o000000?ofl2o00Go0000omg2_Ol0003ohLRoo`000003on;8_@04
o`000?oSakcohlNlo`0000;oi<Nk00?o0000onG9^ol000000_oUb;X2o`000003onG8^Ol0003oiLRj
00;oiLRj00Oo0000onC7^_oTak[oi<Njo`000?oTak[o000000;oh/Fk00?o0000on;4^ol000000_oO
`k`00ol0003og<2nomc0_P03o`0000;ofKfn00Co0000omBi_ooD^Koo00001?o?]L001Ol0003ob[71
olZa`Oo:/L7o000000?oa:c200Go0000okfW`onmYl?o_JO3o`000003okNR``03o`000?n`W<?o/9c3
00;o/9c30_l00003oiV@b@03o`000?n@R/SoT8[800;oT8[800?o0000ohR4b?n8Q<P00_n8Q<P00ol0
003oP7k8oh1nb003oh1nb003o`000?miN/OoNG[700?oNG[70_mcM/L01?l0003oC6S=odaXcOl00003
odITc003o`000?m1HLco@F7<00;o@F7<00?o0000ociQcOlnHLd00_lnHLd2oceRcP03o`000?l3C/co
0000027ooooo00?o0000ooooooooool03?ooool002Cooooo0_l0000hooooo`03oc]LbOl0003oKgW<
00?oKgW<00?o0000og9ib_mbNLX00ombNLX00ol0003oMg[9ogMjb@04ogMjb@03o`000?mlO<SoO7c8
00;oO7c800Go0000oh=oaon3OlOoPgo7o`000003oijDb@03o`000?nTUlSoY9O800CoY9O800?o0000
ojVJaonYV/L00onYV/L4o`0000;o[Yg600?o0000ok>QaOncXLD00_ncXLD00ol0003o^JC4okVTa003
okVTa0;o00000oo;]lH00ol0003ockW5olnia@02olnia@03o`000?oB^l?od[_300;od[_300Go0000
omFm`_oE_L;oeKg2o`000003omRn`005o`000?oK`;oofl2oom_0_ol000000ooM`[d01Ol0003oh/Rm
on;8_OoRb;go000000?ohlNl00?o0000onC7^ooTak/00_l00003onG8^P08o`000?oUb;WoiLRio`00
0?oUb;[o0000onG8^_l00002onC7^P06o`000?oTak[o0000o`000?oRaK_o00000_oRa;/02?l0003o
gl>lomo3_?l0003og<2no`000?oM`;co00000ooI_Kh01?l0003oe;VoomBi_ol00003olne`005o`00
0?o:/L7ob[71olZa`Ol000001?o4[<801Ol0003o_JO3okfW`onmYl?o000000?o]j;300?o0000ok2L
`on`W<<00_n`W<<00ol0003oZYS3o`000003o`0000CoT8[800?o0000ohR4b?n8Q<P00_n8Q<P00ol0
003oP7k8oh1nb002oh1nb003o`000?miN/OoNG[700CoNG[70omcM/L00ol0003oC6S=o`000003odIT
c003o`000?m1HLco@F7<00;o@F7<00?o0000ociQcOlnHLd00_lnHLd3oceRcP;o00008?ooool3o`00
00gooooo000Tooooo`03o`000?oooooooooo03Oooooo0_lkG<T01?l0003oKgW<ofmic?l00005og9i
bP03o`000?mgN/WoMg[900CoMg[900?o0000ogalb?mlO<P00omlO<P00ol0003oPgo7oh=oa`02oh=o
a`03o`000?nNU<Wo000000KoY9O800?o0000ojVJaonYV/L00_nYV/L3o`0000Go[Yg600?o0000ok>Q
aOncXLD00_ncXLD00ol0003o^JC4okVTa003okVTa005o`000?nnZ<?o0000ol^ga_l000001?o?^LD0
0ol0003od[_3om:k``02om:k``03o`000?oE_L;oeKg200;oeKg200Go0000omRn`?oH_/3of;k0o`00
0003om_0_`05o`000?oM`[gogL:momg2_Ol000000ooRb;d01?l0003ohlNlon?7_?l00003onC7^`03
o`000?oUb;[oiLRj00;oiLRj00?o0000onG8^Ol000000_oUb;X02?l0003oiLRjo`000?oTak[o0000
onC7^_l0003oi<Jj0_l00003on;4^`03o`000?oO`kcogl>l00;o00000_oM`;`01?l0003ofKfnomVm
__l00003omBi_`05o`000?o?]L3ockG0olne`?l000000oo:/L401Ol0003oa:c2olB/`_o4[<;o0000
00?o_JO300?o0000okNR`ongX/<00_ngX/<01Ol0003o/9c3ok2L`on`W<?o000000GoZYS30_l00003
oi2:b003o`000?n8Q<SoR8C800;oR8C800?o0000oh1nb?n0O/P00_n0O/P00ol0003oNG[7ogUja`03
ogUja`03o`000?mcM/OoLgK700;oLgK70_l00003odITc003o`000?m1HLco@F7<00;o@F7<00?o0000
ociQcOlnHLd00_lnHLd01Ol0003o?F;>oceRc_lmH/ko000001gooooo0ol00002ooooo`03o`000?oo
oooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Oooooo0olkG<T00ol0003oKgW<o`000005
og9ibP03o`000?mgN/WoMg[900CoMg[900?o0000ogalb?mlO<P00_mlO<P00ol0003oPgo7oh=oa`04
oh=oa`03o`000?nTUlSoY9O800CoY9O800?o0000ojVJaonYV/L01?l00006ojjMaP03o`000?ncXLGo
/j7500;o/j7500?o0000okVTa?niY<@00oniY<@01?l0003o_ZS3okjX`onnZ<<2o`0000CockW500?o
0000om:k`ooB^l<00_oB^l<01Ol0003oeKg2omFm`_oE_L;o000000?of;k000Go0000om_0_ooK`;oo
fl2oo`000003omg2_@05o`000?oO`kco0000on;8_Ol000000_oSak`00ol0003oi<NkonC7^`02onC7
^`04o`000?oUb;[oiLRjonG8^P;o000000?oiLRio`000?oUb;X01?l000000ooTak[o0000o`000002
onC6^P05o`000?oRa;_oh/Bkon;4^ol000000_oO`k`2o`0000;ogL2l00Go0000omVm__oI_KkofKfn
o`000003omBi_`05o`000?o?]L3ockG0olne`?l000000oo:/L401Ol0003oa:c2olB/`_o4[<;o0000
00?o_JO300Go0000okNR`ongX/?o]j;3o`000004ok2L``03o`000?nZV<?oZYS300?oZYS300?o0000
oj>Ca?l000000_n@R/P01Ol0003oR8C8ohR4b?n8Q<So000000GoP7k800?o0000ogUjaomiN/L00omi
N/L00ol0003oLgK7og=fa`03og=fa`05o`000?m6I<coAVC<odITc?l000001?m1HL`00ol0003o?V7=
ociQc@02ociQc@03o`000?lmH/ko?F;>00;o?F;>00?o0000ooooooooool05oooool3o`0000Gooooo
00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003o>ec9oc]L
b@02oc]Lb@03o`000?mbNL[oLWW:00?oLWW:00?o0000ogMjbOmgN/T01?mgN/T00ol0003oO7c8ogal
b003ogalb003o`000?n3OlOoPgo700CoPgo700?oRH?6o`000?nTUlP01?nTUlP3o`0000?oZI[700?o
0000ojjMa_n^WLH00on^WLH00ol0003o/j75ok>Qa@03ok>Qa@03o`000?niY<Co^JC400?o^JC400Ko
0000okjX`onnZ<?o_ZS3o`000?o3[<<2o`000003olniaOl0003od[_300?od[_300Go0000omFm`_oE
_L;oeKg2o`000003omRn`005o`000?oK`;oofl2oom_0_ol000001?oM`[d01?l0003ogl>lomo3_?l0
0003on?7_004o`000?oTak_oi<NkonC7^`;o00000_oUb;X01?l0003oiLNio`000?oUb;T3o`000003
onG7^Ol0003oiLNi00;o00000ooTa[X01?l0003oh/Bkon;4^ooRa;/3o`000005omo2^ol0003ogL2l
omg0_?l000000ooI_Kh01?l0003oe;VoomBi_ol00003olne`005o`000?o:/L7ob[71olZa`Ol00000
1?o4[<801Ol0003o_JO3okfW`onmYl?o000000?o]j;300?o0000ok2L`on`W<<00_n`W<<00ol0003o
ZYS3ojZH``02ojZH``04o`000?nSTlCoXi?4oj>Ca0;o00001?n8Q<P00ol0003oP7k8oh1nb002oh1n
b003o`000?miN/OoNG[700CoNG[700?o0000og=faomcM/L00omcM/L2o`0000;oAVC<00?o0000od5Q
c?m1HL`00_m1HL`00ol0003o?V7=ociQc@02ociQc@03o`000?lmH/ko?F;>00;o?F;>00?o0000oooo
ooooool04oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000gooooo`03
o`000?lkG<Wo>ec900;o>ec900?o?e_8o`000?mbNLX00ombNLX00ol0003oMg[9ogMjb@04ogMjb@03
o`000?mlO<SoO7c800?oO7c800?o0000oh=oaon3OlL00on3OlL01Ol0003oRH?6ohV3a_l0003oY9O8
00?o00001OnYV/L00ol0003o[Yg6ojjMaP03ojjMaP03o`000?ncXLGo/j7500?o/j7500?o0000okVT
a?niY<@00oniY<@01Ol0003o_ZS3okjX`onnZ<?o000000Co`jc300?o0000om:k`ooB^l<00_oB^l<0
0ol0003oeKg2omFm`P02omFm`P05o`000?oH_/3of;k0omRn`?l000000ooK`;l01Ol0003ogL:momg2
_OoM`[go000000?ogl>l0_l000000ooSakco0000onC7^`03onC7^`04o`000?oTak[o0000o`0000;o
iLNi00Go0000onG8^Ol0003oiLNio`000003onG7^@04o`000?oTa[[oi<JjonC6^P;o00000_oRa;/2
o`0000?ogl:k00Co0000omg0_?oM`;co00000_oI_Kh01Ol0003oe;VoomBi_ooD^Koo000000?ockG0
00Go0000olZa`Oo:/L7ob[71o`000003olB/`P05o`000?nmYl?o_JO3okfW`ol000001?ngX/<01Ol0
003o/9c3ok2L`on`W<?o000000GoZYS300?o0000oj>Ca?nSTl@00_nSTl@2o`0000?oR8C800?o0000
oh1nb?n0O/P00_n0O/P00ol0003oNG[7ogUja`03ogUja`03o`000?mcM/OoLgK700?oLgK700Ko0000
ofmcaol0003o0000odITc?l00004od5Qc003o`000?lnHLgo?V7=00;o?V7=00?o0000oceRc_lmH/h0
0_lmH/h00ol0003oooooooooo`0@ooooo`?o00003Oooool00ol0003oooooooooo`0:ooooo`008ooo
ool00ol0003oooooooooo`0gooooo`03o`000?lkG<Wo>ec900;o>ec90_loFlP01?l0003oLWW:og9i
b_l00006ogMjb@03o`000?mlO<SoO7c800?oO7c800?o0000oh=oaon3OlL01?n3OlL00ol0003oRH?6
o`000002o`000003ojBGb?l0003oZI[700CoZI[700?o0000ojjMa_n^WLH01?n^WLH00ol0003o/j75
ok>Qa@02ok>Qa@03o`000?niY<Co^JC400?o^JC400?o0000okjX`onnZ<<00_nnZ<<00ol0003o`jc3
ol>/``02ol>/``;o00000ooB^l<01Ol0003oeKg2omFm`_oE_L;o000000?of;k000Go0000om_0_ooK
`;oofl2oo`000004omg2_@04o`000?oO`kcogl>lo`0000;ohLBk00?o0000onC7^ooTak/00_oTak/0
1?l0003oi<NjonC7^_l00003onG7^@Co000000GoiLNio`000?oUakWoiLNio`000002onC6^P07o`00
0?oTa[Wo0000on;4^ol0003oh/Bjo`000002omo2^`04o`000?oM`;cogL2lo`0000?ofKfn00Go0000
omBi_ooD^Kooe;Voo`000003olne`005o`000?o:/L7ob[71olZa`Ol000000oo4[<801Ol0003o_JO3
okfW`onmYl?o000000?o]j;300?o0000ok2L`on`W<<00_n`W<<00ol0003oZYS3ojZH``02ojZH``03
o`000?nSTlCoXi?400?oXi?400?o0000oif>a?l000000_n8Q<P00ol0003oP7k8oh1nb002oh1nb003
o`000?miN/OoNG[700?oNG[700?o0000og=faomcM/L00omcM/L00ol0003oKg?7ofmca`03o`0000Co
@F7<00?o0000ociQcOlnHLd00_lnHLd00ol0003o?F;>oceRcP02oceRcP03o`000?oooooooooo00go
oooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo
00?o0000oc]LbOlkG<T00_lkG<T3ocmKb003o`000?mbNL[o000000KoMg[900?o0000ogalb?mlO<P0
0omlO<P00ol0003oPgo7oh=oa`03oh=oa`?o00000on9PlH2o`0000GoZI[700?o0000ojjMa_n^WLH0
0on^WLH00ol0003o/j75ok>Qa@03ok>Qa@03o`000?niY<Co^JC400?o^JC400Go0000okjX`onnZ<?o
_ZS3o`000004ol>/``06o`000?o8/<;ob;32o`000?oB^l?o00001?oE_L801Ol0003of;k0omRn`?oH
_/3o000000?ofl2o00Go0000omg2_OoM`[gogL:mo`000003omo3_003o`000?oQa;_ohLBk00;o0000
0_oTak/01Ol0003oi<NjonC7^_oTak[o000000?oiLNi00Wo0000onG7^Ol0003o0000onG7^Ol0003o
iLNio`000?oUakT00_l00002onC6^@;o00000_oRa;X01?l0003ogl:komo2^ol00002omg0_005o`00
0?oI_KkofKfnomVm__l000000ooD^Kl01?l0003ockG0olne`?l00003olZa`@03o`000?o4[<;oa:c2
00;oa:c200Co0000okfW`onmYl?o00001?ngX/<01Ol0003o/9c3ok2L`on`W<?o000000GoZYS300?o
0000oj>Ca?nSTl@00_nSTl@01?l0003oWHk4oif>a?nMS/@2o`0000GoP7k800?o0000ogUjaomiN/L0
0omiN/L00ol0003oLgK7og=fa`03og=fa`04o`000?m_LlOoKg?7ofmca`?o00000om1HL`00ol0003o
?V7=ociQc@02ociQc@03o`000?lmH/ko?F;>00;o?F;>00?o0000ooooooooool02Oooool4o`0001?o
oooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003o>ec9
oc]Lb@02oc]Lb@05o`000?loFlSo?e_8ocmKb?l000001_mgN/T00ol0003oO7c8ogalb003ogalb004
o`000?n3OlOoPgo7oh=oa`Co00001On9PlH2oi68aP05o`000?nYV/OoZI[7ojVJaol000001On^WLH0
0ol0003o/j75ok>Qa@03ok>Qa@03o`000?niY<Co^JC400?o^JC400?o0000okjX`onnZ<<00_nnZ<<0
0ol0003o`jc3ol>/``02ol>/``04o`000?o8/<;ob;32olR``P?o00000_oE_L801Ol0003of;k0omRn
`?oH_/3o000000?ofl2o00Go0000omg2_OoM`[gogL:mo`000003omo3_004o`000?oQa;_ohLBko`00
00;oh/Fj00?o0000onC7^ol000000_oTakX2o`0000;oiLNi0_l000001OoUakWo0000o`000?l0003o
iLNi00;o000000?oiLNio`000?oTa[T00_oTa[T01?l0003oh/Bjon;4^_l00003omo2^`04o`000?oM
`;cogL2lo`0000?ofKfn00Go0000omBi_ooD^Kooe;Voo`000002olne`005o`000?o:/L7ob[71olZa
`Ol000000oo4[<801Ol0003o_JO3okfW`onmYl?o000000Co]j;300Go0000ok2L`on`W<?o/9c3o`00
0005ojZH``03o`000?nSTlCoXi?400;oXi?400?o0000oif>a?nMS/@00_nMS/@00ol0003oP7k8oh1n
b002oh1nb003o`000?miN/OoNG[700?oNG[700?o0000og=faomcM/L00omcM/L00ol0003oKg?7ofmc
a`02ofmca`04o`000?m[L/SoJg;8o`0000;o@F7<00?o0000ociQcOlnHLd00_lnHLd00ol0003o?F;>
oceRcP02oceRcP03o`000?oooooooooo00Kooooo0ol0000Gooooo`03o`000?oooooooooo00[ooooo
000Sooooo`?o0000=oooool01Ol0003o>ec9oc]LbOlkG<Wo000000Co?e_800?oA5g7o`000?mgN/T0
1?mgN/T00ol0003oO7c8ogalb003ogalb0Co00000_n3OlL00ol0003oRH?6ohV3aP03ohV3aP07o`00
0?nAR<KoTHS6oi68a_l0003oZI[7o`000006ojjMaP03o`000?ncXLGo/j7500;o/j7500?o0000okVT
a?niY<@01?niY<@01Ol0003o_ZS3okjX`onnZ<?o000000Co`jc300?o0000olR``_o8/<800_o8/<80
0ol0003ocK?1olfc`@03o`0000;of;k000?o0000om_0_ooK`;l00_oK`;l01Ol0003ogL:momg2_OoM
`[go000000?ogl>l00Co0000on74^ooQa;_o00000ooRaKX01?l0003oi<NjonC7^_l00002onG7^@;o
000000CoiLNho`000?l0003oiLNi1?l000000ooUakWo0000o`000002o`000005onC6^Ol0003oh/Bj
on;4^_l000000ooO`[/01?l0003ogL2lomg0_?l00002omVm_P05o`000?oD^Kooe;VoomBi_ol00000
0oo?]L001Ol0003ob[71olZa`Oo:/L7o000000?oa:c200Go0000okfW`onmYl?o_JO3o`000003okNR
``05o`000?n`W<?o/9c3ok2L`ol000001OnZV<<00ol0003oXi?4oj>Ca002oj>Ca003o`000?nMS/Co
WHk400?oWHk40_l00003oh1nb003o`000?miN/OoNG[700?oNG[700?o0000og=faomcM/L00omcM/L0
0ol0003oKg?7ofmca`02ofmca`;o00000_m[L/P00ol0003o@F7<o`000004ociQc@03o`000?lmH/ko
?F;>00;o?F;>00?o0000ooooooooool00oooool3o`0001[ooooo00?o0000ooooooooool02_ooool0
02?ooooo00?o0000ooooooooool0=oooool01Ol0003o>ec9oc]LbOlkG<Wo000000Co?e_80_m4GLL0
0ol0003oMg[9ogMjb@02ogMjb@04o`000?mlO<SoO7c8ogalb0?o00001On3OlL00ol0003oRH?6ohV3
aP03ohV3aP03o`000?nAR<KoTHS600;oTHS600?o0000ojjMa_n^WLH01?n^WLH00ol0003o/j75ok>Q
a@03ok>Qa@03o`000?niY<Co^JC400?o^JC400?o0000okjX`onnZ<<00_nnZ<<00ol0003o`jc3ol>/
``02ol>/``05o`000?o8/<;ob;32olR``_l000001?o=/l401Ol0003odKNoo`000?oH_/3o000000?o
fl2o00Go0000omg2_OoM`[gogL:mo`000003omo3_004o`000?oQa;_ohLBko`0000Coh/Fj0_l00000
1OoTak[o0000onG7^OoUakWo000000;oiLNh0ol000001?oUakWo0000o`000?oUakT3o`0000;oi<Ji
00Go0000on;4^_oRa;[oh/Bjo`000002omo2^`05o`000?oM`;cogL2lo`000?oI_Kh03?l000000oo:
/L7o0000olB/`P03olB/`P04o`000?nmYl?o_JO3o`0000Co]j;300Go0000ok2L`on`W<?o/9c3o`00
0005ojZH``03o`000?nSTlCoXi?400;oXi?400?o0000oif>a?nMS/@00_nMS/@01?l0003oV8_4oiR;
a?l00002oh1nb003o`000?miN/OoNG[700?oNG[700?o0000og=faomcM/L00omcM/L00ol0003oKg?7
ofmca`02ofmca`03o`000?m[L/So000000;oJg;80_l00004ociQc@03o`000?lmH/ko?F;>00;o?F;>
00?o0000ooooooooool00ol0000Mooooo`03o`000?oooooooooo00[ooooo00001Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Co
oooo00?o0000ooooooooool0>?ooool01Ol0003o>ec9oc]LbOlkG<Wo000000Co?e_80om4GLL01Ol0
003oMg[9ogMjbOl0003oO7c800?o000000?oO7c8o`000?n3OlL01?n3OlL00ol0003oRH?6ohV3aP03
ohV3aP03o`000?nAR<KoTHS600?oTHS600?oV8g6o`000?n^WLH00on^WLH00ol0003o/j75ok>Qa@03
ok>Qa@03o`000?niY<Co^JC400?o^JC400?o0000okjX`onnZ<<00_nnZ<<00ol0003o`jc3ol>/``02
ol>/``03o`000?o8/<;ob;3200;ob;3200Go0000olfc`Oo=/l7ocK?1o`000003om6g_`;o00000_oK
`;l00ol0003ogL:momg2_@02omg2_@04o`000?oO`kcogl>lo`0000?ohLBk00Go0000on;5^_oRaK[o
h/Fjo`000002onC6^@05o`000?oUakWoiLNionG7^Ol000000_oUakP7o`000003onG6^Ol0003oi<Ji
00;oi<Ji00Go0000on;4^_oRa;[o0000omo2^`07o`0000;og;nl00Go0000omRl_OoH_;gof;bmo`00
0002omBi_P03o`000?o@][ood;Jo00Co000000?oa:c2o`000?nmYl<00_nmYl<00ol0003o]j;3okNR
``02okNR``05o`000?n`W<?o/9c3ok2L`ol000001?nZV<<00ol0003oXi?4oj>Ca002oj>Ca003o`00
0?nMS/CoWHk400?oWHk400Co0000oiR;a?nHRlCoV8_40_l00005ogUja`03o`000?mcM/OoLgK700?o
LgK700?o0000ofmcaom_LlL00om_LlL00ol0003oJg;8o`000003of]bb003o`000?lnHLgo?V7=00;o
?V7=00?o0000oceRc_lmH/h00_lmH/h3o`00023ooooo00?o0000ooooooooool02_ooool00005ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool01Ol0003o>ec9oc]LbOlkG<Wo
000000Co?e_81?m4GLL4o`0000?oO7c800?o0000oh=oaon3OlL01?n3OlL00ol0003oRH?6ohV3aP03
ohV3aP03o`000?nAR<KoTHS600;oTHS600Co0000oiR=a_nHSLKo00000on^WLH00ol0003o/j75ok>Q
a@02ok>Qa@03o`000?niY<Co^JC400Co^JC400?o0000okjX`onnZ<<00_nnZ<<00ol0003o`jc3ol>/
``02ol>/``05o`000?o8/<;ob;32olR``_l000001?o=/l402Ol0003odKNoom6g_ooA]koo0000omFj
__l0003ofl2oo`000003omg2_@05o`000?oO`kcogl>lomo3_?l000000_oQa;/00ol0003oh/Fjon;5
^P02on;5^P03o`000?oTa[Woi<Ji00;o000000?oiLNio`000?l000000_oUakP6o`000003onG6^Ol0
003o000000?oi<Ji00?o0000on;4^_l000000_l00002on73^P04o`000?oN`K_og/6ko`0000;og;nl
00Go0000omRl_OoH_;gof;bmo`000002omBi_P03o`000?o@][ood;Jo00;od;Jo00?o0000olbb`?o<
//001?l000000onmYl?o0000okNR``02okNR``05o`000?n`W<?o/9c3ok2L`ol000001OnZV<<00ol0
003oXi?4oj>Ca002oj>Ca003o`000?nMS/CoWHk400;oWHk400?o0000oiR;a?nHRl@00onHRl@2o`00
00CoNG[700?o0000og=faomcM/L00omcM/L00ol0003oKg?7ofmca`02ofmca`05o`000?m[L/SoJg;8
of]bb?l000000_m[L/P00omXLLWo0000ociQc@02ociQc@03o`000?lmH/ko?F;>00;o?F;>00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00?o0000
oc]LbOlkG<T00_lkG<T00ol0003o?e_8ocmKb002ocmKb003o`000?m4GLOoA5g700?o00001OmlO<P0
0ol0003oPgo7oh=oa`03oh=oa`03o`000?n9PlKoRH?600CoRH?600?o0000oi68a_nAR<H00_nAR<H0
1ol0003oV8g6oiR=a_nHSLKo0000ojjMa_l000001OncXLD00ol0003o^JC4okVTa003okVTa003o`00
0?nnZ<?o_ZS300;o_ZS300?o0000ol>/`oo3[<<00_o3[<<00ol0003ob;32olR``P02olR``P05o`00
0?o=/l7ocK?1olfc`Ol000000ooA]kl01?l0003oeKZnomFj__oE^[h3o`0000;ogL:m00Co0000omo3
_?oO`kco00000ooQa;/01Ol0003oh/Fjon;5^_oRaK[o000000;oi<Ji00Co0000onC6^OoTa[Wo0000
0_oUakP7o`000004onG6^Ol0003oiLJho`0000;oi<Ji0ol000001OoSaK[o0000on73^_oQ`k[o0000
00;og/6k00Go0000ombo_?oL_kcog;nlo`000003omRl_@04o`000?oD^Kkoe;Vno`0000?od;Jo00?o
0000olbb`?o<//000_o<//000ol0003oajk1olN^`@02o`0000?o]j;300Go0000ok2L`on`W<?o/9c3
o`000004ojZH``03o`000?nSTlCoXi?400;oXi?400?o0000oif>a?nMS/@00onMS/@00ol0003oV8_4
oiR;a003oiR;a004o`000?nCQlCo0000o`0000;oNG[700?o0000og=faomcM/L00_mcM/L00ol0003o
Kg?7ofmca`03ofmca`03o`000?m[L/SoJg;800;oJg;80_l00002ofQab@04o`000?lnHLgo?V7=o`00
00Co?F;>00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0gooooo`03o`000?lkG<Wo>ec900;o>ec900?o0000ocmKb?loFlP00_loFlP3o`00
00;oA5g700?oC6;7o`000?mlO<P00omlO<P00ol0003oPgo7oh=oa`03oh=oa`03o`000?n9PlKoRH?6
00?oRH?600?o0000oi68a_nAR<H00onAR<H00ol0003oV8g6oiR=aP02oiR=aP;o00001?ncXLD00ol0
003o^JC4okVTa004okVTa005o`000?nnZ<?o_ZS3okjX`ol000001Oo3[<<01Ol0003ob;32olR``_o8
/<;o000000CocK?100Go0000om6g_ooA]koodKNoo`000003omFj_P03o`000?oI_KgofKfm00Co0000
00Gogl>lo`000?oQa;_ohLBko`000003on;5^P05o`000?oTa[Woi<JionC6^Ol000000_oTa[T01Ol0
003oiLNhonG7^?l0003oiLNh00Ko000000?oiLJho`000?oTa[T00ol00002on?5^P05o`000?oQ`k[o
hL>jon73^_l000000_oN`K/01Ol0003og;nlombo_?oL_kco000000;of;bm00Go0000omBi__oD^Kko
e;Vno`000003om2f_`05o`000?o<//3oc;;0olbb`?l000000oo7[/401_l0003o`j_2o`000?l0003o
]j;3o`0000;o/9c300?o0000ojZH`onZV<<00onZV<<00ol0003oXi?4oj>Ca002oj>Ca003o`000?nM
S/CoWHk400;oWHk400?o0000oiR;a?nHRl@00onHRl@00ol0003oThO4oi>7a002oi>7a0;o00001Omc
M/L00ol0003oKg?7ofmca`03ofmca`03o`000?m[L/SoJg;800?oJg;800Oo0000ofQabOmXLLWoJ779
o`000?lnHLgo000000Co?F;>00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`00
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo00?o0000oc]LbOlkG<T00_lkG<T00ol0
003o?e_8o`000003o`0000CoA5g70_m<H/L01?l0003oO7c8ogalb?l00005oh=oa`03o`000?n9PlKo
RH?600CoRH?600?o0000oi68a_nAR<H00_nAR<H00ol0003oV8g6oiR=aP03oiR=aP;oX9;600Go0000
ok>QaOncXLGo/j75o`000005okVTa003o`000?nnZ<?o_ZS300;o_ZS300?o0000ol>/`oo3[<<00_o3
[<<00ol0003ob;32olR``P02olR``P05o`000?o=/l7ocK?1olfc`Ol000000ooA]kl01Ol0003oeKZn
omFj__oE^[ko000000CofKfm00?o0000ombo_?oL_k`00ol000000ooQa;_o0000on;5^P02on;5^P04
o`000?oTa[Woi<Jio`0000;oi<Ji00Ko0000onG7^?l0003oiLNho`000?oUakP5o`000004onG6^?l0
003o0000o`0000;oi<Ji00Co0000on?5^_oSaK[o00000ooQ`kX01?l0003og/6komk1^ol00002ombo
_005o`000?oH_;gof;bmomRl_Ol000000_oD^Kh01Ol0003od;Joom2f_oo@][oo000000Coc;;000Co
0000olN^`Oo7[/7o00001?o3Zl82o`0000;o/9c300?o0000ojZH`onZV<<00_nZV<<00ol0003oXi?4
oj>Ca003oj>Ca003o`000?nMS/CoWHk400;oWHk400?o0000oiR;a?nHRl@00onHRl@00ol0003oThO4
oi>7a003oi>7a003o`000?mcM/OoLgK700?oLgK700?o0000ofmcaom_LlL00_m_LlL00ol0003oJg;8
of]bb004of]bb003o`000?mXLLWoJ77900;oJ7790_l00004oceRcP03o`000?oooooooooo027ooooo
00?o0000ooooooooool02Oooool00005oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01?l0003o>ec9
oc]LbOlkG<T3o`0000?o?e_800?o0000odAMaom4GLL00_m4GLL3odaRa`03o`000?mlO<So000000Go
Pgo700?o0000ohV3a_n9PlH00on9PlH00ol0003oTHS6oi68aP03oi68aP03o`000?nHSLKoV8g600;o
V8g600Oo0000oj2Ba_nPT/KoX9;6o`000?ncXLGo000000Ko^JC400Go0000okjX`onnZ<?o_ZS3o`00
0004ol>/``03o`000?o8/<;ob;3200;ob;3200?o0000olfc`Oo=/l400_o=/l401Ol0003odKNoom6g
_ooA]koo000000?oeKZn00Go0000omVm_OoI_KgofKfmo`000003ombo_003o`000?oO`[_ogl:k00Oo
000000Goi<Jio`000?oTa[Woi<Jio`000002onG7^0Ko000000GoiLNho`000?l0003oiLJho`000002
onC6^@05o`000?oSaK[ohlFjon?5^_l000000_oQ`kX01?l0003og/6komk1^ol00003ombo_005o`00
0?oH_;gof;bmomRl_Ol000000_oD^Kh01Ol0003od;Joom2f_oo@][oo000000?oc;;000Go0000olN^
`Oo7[/7oajk1o`000004ol>[`P05o`000?nmYl;o0000ok2L`ol000001?nZV<<00ol0003oXi?4oj>C
a002oj>Ca003o`000?nMS/CoWHk400;oWHk400?o0000oiR;a?nHRl@00onHRl@00ol0003oThO4oi>7
a004oi>7a0;o00000omcM/L00ol0003oKg?7ofmca`03ofmca`03o`000?m[L/SoJg;800?oJg;800?o
0000ofQabOl000001?mXLLT2o`0000?o?F;>00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1?ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool4o`000003oc]LbOl0003o?e_800;o?e_8
00?o0000odAMaom4GLL00om4GLL4odaRa`03o`000?n3OlOoPgo700?oPgo700?o0000ohV3a_n9PlH0
1?n9PlH00ol0003oTHS6oi68aP02oi68aP03o`000?nHSLKoV8g600?oV8g600?o0000oj2Ba_nPT/H0
0_nPT/H2o`0000Go^JC400?o0000okjX`onnZ<<00_nnZ<<00ol0003o`jc3ol>/``02ol>/``05o`00
0?o8/<;ob;32olR``_l000001?o=/l400ol0003odKNoom6g_`02om6g_`04o`000?oE^[koeKZno`00
00CofKfm00Co0000ombo_?oL_kco00000ooO`[/01Ol0003ohL>jon73^_oQ`k[o000000;ohlFj1_l0
00000ooUakSo0000onG7^005o`0000?oiLJh00Co0000onC6^OoTa[Wo00000_oSaKX01Ol0003ohL>j
on73^_oQ`k[o000000;og/6k00Co0000ombo_?oL_kco00000ooH_;d01?l0003oe;VnomBi__l00003
om2f_`03o`000?o<//3oc;;000;oc;;000Co0000olN^`Oo7[/7o00001?o3Zl801?l0003o_JO2okfW
`_nmYl82o`0000CoZYS300?o0000oj>Ca?nSTl@00_nSTl@01Ol0003oWHk4oif>a?nMS/Co000000Go
V8_400?o0000oi>7a?nCQl@01?nCQl@01?l0003oSXC4ohj4a?l00002og=fa`03o`000?m_LlOoKg?7
00?oKg?700?o0000of]bb?m[L/P00om[L/P01?l0003oJ779ofQabOl00003ofQab@;oIW;;00Co0000
oceRc_lmH/ko00008oooool00ol0003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool0
=_ooool4o`0000;o>ec900?o0000ocmKb?loFlP00_loFlP00ol0003oA5g7odAMa`02odAMa`03o`00
0?m<H/OoC6;700;oC6;700?oEVO8o`000?n3OlL00on3OlL00ol0003oRH?6ohV3aP03ohV3aP03o`00
0?nAR<KoTHS600?oTHS600?o0000oiR=a_nHSLH00onHSLH00ol0003oX9;6oj2BaP02oj2BaP;oZ9S5
0_l00002okVTa003o`000?nnZ<?o_ZS300;o_ZS300?o0000ol>/`oo3[<<00_o3[<<00ol0003ob;32
olR``P02olR``P03o`000?o=/l7ocK?100;ocK?100Go0000om6g_ooA]koodKNoo`000003omFj_P05
o`000?oI_KgofKfmomVm_Ol000000ooL_k`01?l0003ogl:komo2^ol00003on73^P05o`000?oSaK[o
hlFjon?5^_l000000_oTa[T00ol0003oiLJhonG6^008o`0000;oiLJh00Go0000onC6^OoTa[Woi<Ji
o`000002on?5^P04o`000?oQ`k[ohL>jo`0000?og/6k00Co0000ombo_?oL_kco00000ooH_;d01?l0
003oe;VnomBi__l00003om2f_`05o`000?o<//3oc;;0olbb`?l000000oo7[/400ol0003o`j_2ol>[
`P02ol>[`P07o`000?nmYl;o_JO2okfW`_l0003o^J?3o`000002ojZH``03o`000?nSTlCoXi?400;o
Xi?400?o0000oif>a?nMS/@00_nMS/@00ol0003oV8_4oiR;a003oiR;a003o`000?nCQlCoThO400Co
ThO400Oo0000ohj4a?n>Q<CoSXC4o`000?mcM/Oo000000CoKg?700?o0000of]bb?m[L/P01?m[L/P0
1ol0003oJ779ofQabOmXLLWo0000ofQabOl000000omVL//00ol0003o?F;>o`00000Sooooo`03o`00
0?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo03?ooooo0ol00003ooooo`04o`0^]_l0
003o>ec9o`0000Co?e_800?o0000odAMaom4GLL00_m4GLL00ol0003oC6;7odaRa`02odaRa`;oEVO8
00Co0000oh=oaon3OlOo00001_n9PlH00ol0003oTHS6oi68aP02oi68aP03o`000?nHSLKoV8g600?o
V8g600?o0000oj2Ba_nPT/H00_nPT/H00ol0003oZ9S5ojRHa@02ojRHa@03o`000?niY<Co000000Co
_ZS300?o0000ol>/`oo3[<<00_o3[<<01Ol0003ob;32olR``_o8/<;o000000GocK?100Go0000om6g
_ooA]koodKNoo`000003omFj_P05o`000?oI_KgofKfmomVm_Ol000000_oL_k`01Ol0003ogl:komo2
^ooO`[_o000000?ohL>j00Co0000on?5^_oSaK[o00000ooTa[T00ol0003oiLJhonG6^005o`0000;o
iLNh1ol00003on?5^P04o`000?oQ`k[ohL>jo`0000;og/6k00Co0000ombo_?oL_kco00000ooH_;d0
1Ol0003oe;VnomBi__oD^Kko000000;od;Jo00?o0000olbb`?o<//000_o<//001?l0003oajk1olN^
`Ol00004ol>[`P05o`000?nmYl;o_JO2okfW`_l000000oniXl<00ol0003oZYS3o`000004oj>Ca005
o`000?nMS/CoWHk4oif>a?l000001OnHRl@00ol0003oThO4oi>7a004oi>7a003o`000?n>Q<CoSXC4
00?oSXC400?o0000ofmcaom_LlL00om_LlL00ol0003oJg;8of]bb003of]bb003o`000?mXLLWoJ779
00;oJ77900?o0000ofQabOl000001?mVL//2o`0002Cooooo00?o0000ooooooooool02?ooool0027o
oooo00?o0000ooooooooool0<?ooool3o`0000Kooooo00Co0000o`0^]_l0003o00001?loFlP00ol0
003oA5g7odAMa`02odAMa`03o`000?m<H/OoC6;700;oC6;70omFIlP00ol0003oPgo7o`000005ohV3
aP03o`000?nAR<KoTHS600?oTHS600?o0000oiR=a_nHSLH00onHSLH00ol0003oX9;6oj2BaP02oj2B
aP03o`000?nXV<GoZ9S500?oZ9S50_l00003okjX``03o`000?o3[<?o`jc300;o`jc300?o0000olR`
`_o8/<800_o8/<800ol0003ocK?1olfc`@02olfc`@05o`000?oA]koodKNoom6g_ol000000ooE^[h0
1Ol0003ofKfmomVm_OoI_Kgo000000?og;nl00Co0000omo2^ooO`[_o00001?oQ`kX01?l0003ohlFj
on?5^_l00002onC6^@03o`000?oUa[So000000Oo000000GoiLNho`000?oUakSoiLNho`000002onC6
^@Ko000000GohL>jo`000?oN`K_og/6ko`000002ombo_005o`000?oH_;gof;bmomRl_Ol000000_oD
^Kh01Ol0003od;Joom2f_oo@][oo000000?oc;;000Go0000olN^`Oo7[/7oajk1o`000003ol>[`P03
o`000?nmYl;o_JO200;o_JO200?o0000okVS`oniXl<00_niXl<2o`0000?oXi?400?o0000oif>a?nM
S/@00_nMS/@00ol0003oV8_4oiR;a003oiR;a003o`000?nCQlCoThO400?oThO400?o0000ohj4a?n>
Q<@01?n>Q<@00ol0003oKg?7ofmca`03ofmca`03o`000?m[L/SoJg;800?oJg;800?o0000ofQabOmX
LLT00omXLLT00ol0003oIW;;ofIbb`04ofIbb`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02?ooool0027ooooo0_l0000^ooooo`?o00002_ooool2o`0^]P;o00000oloFlP00ol0003oA5g7
odAMa`02odAMa`03o`000?m<H/OoC6;700;oC6;71?mFIlP2o`0000GoRH?600?o0000oi68a_nAR<H0
0onAR<H00ol0003oV8g6oiR=aP03oiR=aP03o`000?nPT/KoX9;600;oX9;600?o0000ojRHaOnXV<D0
0onXV<D01_l0003o/9g5o`000?l0003o_ZS3o`0000Co`jc300Go0000olR``_o8/<;ob;32o`000005
olfc`@05o`000?oA]koodKNoom6g_ol000000ooE^[h01Ol0003ofKfmomVm_OoI_Kgo000000;og;nl
00Go0000omo2^ooO`[_ogl:ko`000003on73^P06o`000?oSaK[ohlFjon?5^_l0003oi<Ji0ol00002
onG6^0Oo00000_oUakP01Ol0003oi<JionC6^OoTa[Wo000000;oi<Ji00?o0000on;5^_oRaKX00ol0
00001OoN`K_o0000ombo_?oL_kco000000;of;bm00Go0000omBi__oD^Kkoe;Vno`000003om2f_`05
o`000?o<//3oc;;0olbb`?l000000_o7[/400ol0003o`j_2ol>[`P02ol>[`P05o`000?nmYl;o_JO2
okfW`_l000001OniXl<01_l0003o]9o3o`000?l0003oXi?4o`0000?oWHk400?o0000oiR;a?nHRl@0
0onHRl@00ol0003oThO4oi>7a004oi>7a003o`000?n>Q<CoSXC400?oSXC400?o0000ohZ2aOl00000
0om_LlL00ol0003oJg;8of]bb004of]bb003o`000?mXLLWoJ77900?oJ7790_l00005ofIbb`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_oo
ool3o`0000gooooo00Go0000o`0^]_l0;;Go02beo`000002ocmKb003o`000?m4GLOoA5g700;oA5g7
00Go0000odaRaom<H/OoC6;7o`000004oeIWb0;oHFk900?o0000ohV3a_n9PlH00_n9PlH00ol0003o
THS6oi68aP02oi68aP03o`000?nHSLKoV8g600?oV8g600?o0000oj2Ba_nPT/H00_nPT/H00ol0003o
Z9S5ojRHa@03ojRHa@03o`000?n`WLGo/9g500;o/9g50_l00003ol>/``03o`000?o8/<;ob;3200;o
b;3200?o0000olfc`Oo=/l400_o=/l401Ol0003odKNoom6g_ooA]koo000000?oeKZn00?o0000omVm
_OoI_Kd00_oI_Kd01?l0003og;nlombo_?l00003omo2^`05o`000?oQ`k[ohL>jon73^_l000000_oS
aKX3o`000003onC6^Ol0003oiLJh00Ko000000KoiLNho`000?oUakSo0000onG7^?l00002onC6^@04
o`000?oTa[Woi<Jio`0000?oh/Fj00?o0000on74^ooQa;/01Ol00002omRl_@04o`000?oD^Kkoe;Vn
o`0000?od;Jo00Go0000olbb`?o<//3oc;;0o`000003olN^`@05o`000?o3Zl;o`j_2ol>[`_l00000
0onmYl800ol0003o^J?3okVS``03okVS``03o`000?ndWl?o]9o300;o]9o300?o0000oif>a?nMS/@0
0_nMS/@00ol0003oV8_4oiR;a003oiR;a003o`000?nCQlCoThO400?oThO400?o0000ohj4a?n>Q<@0
0on>Q<@01Ol0003oRX;5ohZ2aOn:P/Go000000;oKg?700?o0000of]bb?m[L/P00om[L/P00ol0003o
J779ofQab@04ofQab@03o`000?mVL/_o000000?oIW;;00?o0000ooooooooool08oooool00ol0003o
ooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?o00004?ooool00ol0003o02jf
o`0^]P02o`0/]@03o`000?loFlSo000000CoA5g700Go0000odaRaom<H/OoC6;7o`000004oeIWb0?o
HFk900Co0000ohV3a_n9PlKo00001OnAR<H00ol0003oV8g6oiR=aP03oiR=aP03o`000?nPT/KoX9;6
00;oX9;600?o0000ojRHaOnXV<D00onXV<D00ol0003o/9g5ok2Ma@02ok2Ma@06o`000?ngXlGo0000
o`000?o3[<?o00000oo8/<800ol0003ocK?1olfc`@03olfc`@05o`000?oA]koodKNoom6g_ol00000
0ooE^[h01Ol0003ofKfmomVm_OoI_Kgo000000?og;nl00Co0000omo2^ooO`[_o00001?oQ`kX4o`00
00?oi<Ji0_l000000ooUa[Wo0000onG7^005o`0000;oiLNh00Co0000onC6^OoTa[Wo00000ooTa[T0
1?l0003oh/Fjon;5^_l00003on74^`08o`000?oO`kcogl>lo`000?oM`Kgo0000omRl_Ol00002omBi
_P05o`000?o@][ood;Joom2f_ol000000oo<//001Ol0003oajk1olN^`Oo7[/7o000000?o`j_200Go
0000okfW`_nmYl;o_JO2o`000004okVS``03o`000?ndWl?o]9o300?o]9o30_l00002oif>a003o`00
0?nHRlCoV8_400?oV8_400?o0000oi>7a?nCQl@01?nCQl@00ol0003oSXC4ohj4a003ohj4a003o`00
0?n:P/GoRX;500;oRX;500?o0000ofmcaol000001Om[L/P00ol0003oJ779ofQab@03ofQab@04o`00
0?mVL/_oIW;;o`0000?oIW;;00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`00
8?ooool00ol0003oooooooooo`0Uooooo`?o00005?ooool00ol0003o02jfo`0/]@02o`0/]@;o0000
1?m4GLL01Ol0003oC6;7odaRaom<H/Oo000000CoEVO81?mQK/T00ol0003oRH?6o`000004oi68aP03
o`000?nHSLKoV8g600?oV8g600?o0000oj2Ba_nPT/H00onPT/H00ol0003oZ9S5ojRHa@03ojRHa@05
o`000?n`WLGo/9g5ok2MaOl000001?ngXlD3o`0000;ob;3200?o0000olfc`Oo=/l400_o=/l400ol0
003odKNoom6g_`02om6g_`04o`000?oE^[koeKZno`0000CofKfm00Co0000ombo_?oL_kco00000ooO
`[/00ol0003ohL>jo`000003o`0000;oh/Bj00?o0000onC6^OoTa[T00_l00002onG6^@Go000000Co
iLNho`000?oUakSoiLNh0_l000001OoTa[Wo0000onC6^OoTa[Wo000000?oh/Fj00Co0000on74^ooQ
a;_o00000_oO`k`01?l0003ogL6momg1_OoM`Kd3o`000005omBi__l0003od;Joom2f_ol000000oo<
//001Ol0003oajk1olN^`Oo7[/7o000000?o`j_200Go0000okfW`_nmYl;o_JO2o`000005okVS``03
o`000?ndWl?o]9o300;o]9o300Ko0000ojnLa?n_W<Co0000oif>a?l00005oiR;a003o`000?nCQlCo
ThO400?oThO400?o0000ohj4a?n>Q<@00on>Q<@00ol0003oRX;5ohZ2a@04ohZ2a@;o00001Om[L/P0
0ol0003oJ779ofQab@03ofQab@07o`000?mVL/_oIW;;ofIbbol0003oIW;;o`00000Vooooo`03o`00
0?oooooooooo00Sooooo000Pooooo`;o00008oooool3o`0001Oooooo00?o0000o`0^]_l000000ol0
;;D00ol0003oA5g7odAMa`02odAMa`05o`000?m<H/OoC6;7odaRaol000001?mFIlP5of5^b@03o`00
0?nAR<KoTHS600?oTHS600?o0000oiR=a_nHSLH00onHSLH00ol0003oX9;6oj2BaP02oj2BaP03o`00
0?nXV<GoZ9S500?oZ9S500?o0000ok2MaOn`WLD00_n`WLD00ol0003o]j?5okNSa@02okNSa@03o`00
0?nnZ<Co_ZS400Go00000_o=/l401Ol0003odKNoom6g_ooA]koo000000?oeKZn00Go0000omVm_OoI
_KgofKfmo`000003ombo_0Ko00000_oP`k/01?l0003oh/Bjon;4^_l00002onC6^@;o00000_oUa[T6
o`0000;oiLNh0_l00002onG7^@05o`000?oTa[Woi<JionC6^Ol000000_oRaKX01?l0003ohLBkon74
^ol00003omo3_005o`000?oM`KgogL6momg1_Ol000000_oJ_kl3o`000003om2f_ol0003oc;;000;o
c;;000Go0000olN^`Oo7[/7oajk1o`000002ol>[`P03o`000?nmYl;o_JO200;o_JO200?o0000okVS
`oniXl<00_niXl<00ol0003o]9o3okBO``02okBO``03o`000?n_W<Co[ic400;o[ic40_l00004oiR;
a003o`000?nCQlCoThO400?oThO400?o0000ohj4a?n>Q<@00on>Q<@00ol0003oRX;5ohZ2a@05ohZ2
a@03o`000?n7PLKo000000?oJg;800?o0000ofQabOmXLLT00omXLLT00ol0003oIW;;ofIbb`03ofIb
b`;o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Pooooo`;o
00006_ooool00ol0003o02jfo`0^]P03o`0/]@03o`000?m4GLOoA5g700;oA5g700Go0000odaRaom<
H/OoC6;7o`000003oeIWb003o`000?mQK/WoHFk900?oHFk900?oKGG:o`000?nAR<H00_nAR<H00ol0
003oV8g6oiR=aP04oiR=aP03o`000?nPT/KoX9;600;oX9;600?o0000ojRHaOnXV<D00onXV<D00ol0
003o/9g5ok2Ma@02ok2Ma@05o`000?ngXlGo]j?5okNSaOl000001?nnZ<@01?l0003oaJk3olF^`oo5
[/<4o`0000;odKNo00Go0000omFj__oE^[koeKZno`000003omVm_@Go00000_oM`;`00ol0003oh<>k
on33^`02on33^`0;o`000?oRa;[oh/Bjo`000?oTa[Wo0000onC6^Ol0003oiLJio`000?oUakT01Ol0
0002onG7^0;o00000_oUakT01?l0003oi<JionC6^Ol00002on;5^P05o`000?oQa;_ohLBkon74^ol0
00000_oO`k`01Ol0003ogL6momg1_OoM`Kgo000000?of[no00?o0000omRn`?oH_/000_l00002olbb
`005o`000?o7[/7oajk1olN^`Ol000000oo3Zl801Ol0003o_JO2okfW`_nmYl;o000000Co^J?300?o
0000okBO`ondWl<00ondWl<00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGo000000;oV8_400?o
0000oi>7a?nCQl@01?nCQl@00ol0003oSXC4ohj4a003ohj4a003o`000?n:P/GoRX;500CoRX;500Go
0000ohN1a_n7PLKoQh76o`000002of]bb003o`000?mXLLWoJ77900?oJ77900?o0000ofIbbomVL//0
1?mVL//00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oo
oooooooo01gooooo0ol0000Mooooo`03o`000?l0;[Ko000000;o02be0_l00002odAMa`03o`000?m<
H/OoC6;700;oC6;700Go0000oeIWb?mFIlSoEVO8o`000005of5^b@;oKGG:00Co0000oi68a_nAR<Ko
00001OnHSLH00ol0003oX9;6oj2BaP02oj2BaP03o`000?nXV<GoZ9S500?oZ9S500?o0000ok2MaOn`
WLD00_n`WLD00ol0003o]j?5okNSa@02okNSa@03o`000?nnZ<Co_ZS400;o_ZS400?o0000olF^`oo5
[/<00_o5[/<00ol0003obk;2ol^b`P0;o`0000;ofKfn00Go0000omg0_?oM`;cogL2lo`000003on33
^`04o`000?oRa;[oh/Bjon;4^P;o00000_oTa[T2o`000003onG7^Ol0003o000000Co00000_oUakP0
2?l0003oiLNionG7^Ol0003oi<Njo`000?oTa[Wo00000_oRaKX01?l0003ohLBkon74^ol00002omo3
_005o`000?oM`KgogL6momg1_Ol000000ooJ_kl02Ol0003of;k0omRn`?oH_/3o0000omFl`Ol0003o
c;;0o`000003olN^`@04o`000?o3Zl;o`j_2o`0000?o_JO200?o0000okVS`oniXl<00oniXl<00ol0
003o]9o3okBO``02okBO``03o`000?n_W<Co[ic400;o[ic400Oo0000oj^IaOn[VLGoZiW5o`000?nH
RlCo000000GoThO400?o0000ohj4a?n>Q<@00on>Q<@00ol0003oRX;5ohZ2a@04ohZ2a@03o`000?n7
PLKoQh7600?oQh7600?o0000of]bb?l000001?mXLLT00ol0003oIW;;ofIbb`04ofIbb`;o00009ooo
ool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o00008?ooool0
0ol0003o02jfo`000003o`0/]@04o`0_]ol0003oA5g7o`0000CoC6;700Go0000oeIWb?mFIlSoEVO8
o`000005of5^b@?oKGG:00?o0000oi68a_l000001OnHSLH00ol0003oX9;6oj2BaP02oj2BaP03o`00
0?nXV<GoZ9S500?oZ9S500?o0000ok2MaOn`WLD00_n`WLD00ol0003o]j?5okNSa@02okNSa@05o`00
0?nnZ<Co_ZS4okjXa?l000001Oo5[/<01Ol0003obk;2ol^b`_o;//;o000000?od;O100Go0000omFj
_ooE^[ooeKZoo`000003omVm_P04o`000?oM`;cogL2lo`0000Coh<>k00?o0000on;4^_oRa;X00_l0
0002onC6^@;o000000GoiLNio`000?l0003o0000onG7^@03o`000003onG7^?l0003o000000;oiLNi
00Co0000onC7^_oTak[o00000_oRaKX01Ol0003ohLBkon74^ooQa;_o000000;ogl>l00Go0000omg1
_OoM`KgogL6mo`000002omZo_`05o`000?oH_/3of;k0omRn`?l000000ooE_<42o`0000;oajk100Go
0000ol>[`_o3Zl;o`j_2o`000003okfW`P03o`000?niXl?o^J?300;o^J?300?o0000okBO`ondWl<0
0_ndWl<00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGoZiW500?oZiW500?o0000oi>7a?nCQl@0
1?nCQl@00ol0003oSXC4ohj4a002ohj4a003o`000?n:P/GoRX;500CoRX;500?o0000ohN1a_n7PLH0
1On7PLH00ol0003oJ779ofQab@03ofQab@03o`000?mVL/_oIW;;00CoIW;;00?o0000ooooool00000
9_ooool00ol0003oooooooooo`07ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`04o`000?l0
;[Ko02jfo`0000;o02be00Co0000o`0_]ol0003o00001?m<H/L01Ol0003oEVO8oeIWb?mFIlSo0000
00GoHFk91?m]MLX2o`0000GoV8g600?o0000oj2Ba_nPT/H00_nPT/H00ol0003oZ9S5ojRHa@03ojRH
a@03o`000?n`WLGo/9g500;o/9g500Go0000okNSaOngXlGo]j?5o`000004okjXa003o`000?o5[/?o
aJk300;oaJk300Go0000ol^b`_o;//;obk;2o`000004om2g`@05o`000?oE^[ooeKZoomFj_ol00000
0_oI_Kh01Ol0003ogL2lomg0_?oM`;co000000Coh<>k00Co0000on;4^_l0003o00000ooTa[T00ol0
003oiLNionG7^@05o`000007onG7^Ol0003o0000onG7^Ol0003oiLNio`000003onC7^P;o000000Go
h/Fjo`000?oQa;_ohLBko`000002omo3_005o`000?oM`KgogL6momg1_Ol000000ooJ_kl01?l0003o
f;k0omRn`?l00004omFl`@05o`000?oA^/?o0000olN^`Ol000000_o3Zl801Ol0003o_JO2okfW`_nm
Yl;o000000Co^J?300?o0000okBO`ondWl<00_ndWl<00ol0003o[ic4ojnLa003ojnLa003o`000?n[
VLGoZiW500?oZiW50_l00004oi>7a003o`000?n>Q<CoSXC400?oSXC400?o0000ohZ2aOn:P/D01?n:
P/D00ol0003oQh76ohN1aP05ohN1aP;o00001?mXLLT00ol0003oIW;;ofIbb`03ofIbb`05o`000?oo
ooooooooooooool000009Oooool00ol0003oooooooooo`07ooooo`007oooool2o`0001Kooooo0ol0
000Wooooo`03o`000?l0;[Ko000000;o02be00Co0000o`0_]ol0;kOo00001?m<H/L01Ol0003oEVO8
oeIWb?mFIlSo000000CoHFk900?o0000ofeeb_m]MLX00_m]MLX2ogUnb`05o`000?nHSLKoV8g6oiR=
a_l000001?nPT/H00ol0003oZ9S5ojRHa@03ojRHa@03o`000?n`WLGo/9g500;o/9g500?o0000okNS
aOngXlD00_ngXlD00ol0003o_ZS4okjXa002okjXa003o`000?o5[/?oaJk300;oaJk300Go0000ol^b
`_o;//;obk;2o`000003om2g`@05o`000?oE^[ooeKZoomFj_ol000000ooI_Kh01Ol0003ogL2lomg0
_?oM`;co000000Coh<>k0_l000000ooRaK_o0000onC6^@02onC6^@05o`000?oUakWo0000o`000?oU
akT00ol000000ooUakWo0000onG7^@02onG7^@;o00000_oTakX01?l0003oi<NkonC7^ol00002on74
^`05o`000?oO`kcogl>lomo3_?l000000ooM`Kd01?l0003of[noomZo_ol00003omRn`005o`000?oE
_<7oeKc1omFl`Ol000000ooA^/<01?l0003o`j_2ol>[`_l00004okfW`P05o`000?niXl?o^J?3okVS
`ol000001OndWl<00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGoZiW500?oZiW500Co0000ojJF
aOnVU/Go00000_nCQl@00ol0003oSXC4ohj4a003ohj4a003o`000?n:P/GoRX;500CoRX;500?o0000
ohN1a_n7PLH01On7PLH01?l0003oQ877ohB1aol00002ofQab@03o`000?mVL/_oIW;;00CoIW;;00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo01;ooooo0ol0000Zooooo`04o`000?l0;[Ko02jfo`0000;o
02be0_l0;kL01Ol0003oC6;7odaRaom<H/Oo000000CoEVO800?o0000of5^bOmQK/T00_mQK/T00ol0
003oKGG:ofeebP02ofeebP?oNGk;00Co0000oiR=a_nHSLKo00001?nPT/H00ol0003oZ9S5ojRHa@03
ojRHa@03o`000?n`WLGo/9g500;o/9g500?o0000okNSaOngXlD00_ngXlD01Ol0003o_ZS4okjXa?nn
Z<Co000000GoaJk300Go0000ol^b`_o;//;obk;2o`000003om2g`@05o`000?oE^[ooeKZoomFj_ol0
00000ooI_Kh01Ol0003ogL2lomg0_?oM`;co000000?oh<>k0_l00002on;5^`05o`000?oTa[Woi<Ji
o`000?oTa[X00_l000000ooUakWo0000onG7^@04o`0000?oiLNi00Go0000onC7^_oTak[oi<Njo`00
0002onC7^`;o000000GohLBko`000?oO`kcogl>lo`000003omg1_@04o`000?oJ_koof[noo`0000?o
f;k000Go0000omFl`OoE_<7oeKc1o`000004om6j``;o000000?o`j_2o`000?nmYl800_nmYl800ol0
003o^J?3okVS``02okVS``03o`000?ndWl?o]9o300;o]9o300?o0000ojnLa?n_W<@00_n_W<@00ol0
003oZiW5oj^Ia@03oj^Ia@03o`000?nVU/GoYYK500;oYYK500?o0000oi>7a?l000001On>Q<@00ol0
003oRX;5ohZ2a@03ohZ2a@03o`000?n7PLKoQh7600GoQh7600?o0000ohB1aon4PLL00_n4PLL00ol0
003oJ779o`000005ofIbb`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`07ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool3o`0002gooooo00Co0000o`0^
]_l0;[Ko00000_l0;;D01?l0003o02ngo`000?l00002odaRa`03o`000?mFIlSoEVO800;oEVO800?o
0000of5^bOmQK/T00_mQK/T00ol0003oKGG:ofeebP02ofeebPCoNGk;00?o0000oiR=a_l000001?nP
T/H00ol0003oZ9S5ojRHa@03ojRHa@03o`000?n`WLGo/9g500;o/9g500Go0000okNSaOngXlGo]j?5
o`000004okjXa003o`000?o5[/?oaJk300;oaJk300Go0000ol^b`_o;//;obk;2o`000004om2g`@05
o`000?oE^[ooeKZoomFj_ol000000_oI_Kh00ol0003ogL2lomg0_002omg0_003o`000?oP`k_oh<>k
00;o00000ooRaK/00ol0003oi<Jio`000002onC6^P;o000000?oiLNio`000?l000000_l000001?oU
b;Wo0000onG7^OoUakT2o`0000;oi<Nj00Co0000onC7^ooTak_o00000_oSak`01?l0003ogl>lomo3
_?l00003omg1_@05o`000?oJ_koof[noomZo_ol000000ooH_/001Ol0003oeKc1omFl`OoE_<7o0000
00?odK[300?o0000oljga?o>]l@00_l00002okfW`P03o`000?niXl?o^J?300;o^J?300?o0000okBO
`ondWl<00_ndWl<00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGoZiW500?oZiW500?o0000ojJF
aOnVU/D01?nVU/D00ol0003oSXC4ohj4a003ohj4a003o`000?n:P/GoRX;500?oRX;500?o0000ohN1
a_n7PLH01On7PLH00ol0003oQ877ohB1a`04ohB1a`;o00001OmVL//00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool000Cooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool3o`00
037ooooo00?o0000o`0^]_l000000_l0;;D01ol0003o02ngo`0_]ol0=[_o0000odaRaol000001?mF
IlP00ol0003oHFk9of5^b@02of5^b@03o`000?m]ML[oKGG:00;oKGG:00?o0000ogUnbomiO//00_mi
O//2o`0000?oX9;600?o0000ojRHaOnXV<D00onXV<D00ol0003o/9g5ok2Ma@02ok2Ma@03o`000?ng
XlGo]j?500;o]j?500?o0000okjXa?nnZ<@00_nnZ<@00ol0003oaJk3olF^``02olF^``05o`000?o;
//;obk;2ol^b`_l000000oo@]l400ol0003oeKZoomFj_`02omFj_`04o`000?oI_KkofKfno`0000?o
gL2l00Ko0000on33^ol0003o0000omo3_?l00003on;5^`;o00000_oTa[X3o`00000=onG7^Ol0003o
0000onG8^_l0003oiLRio`000?oUakWo0000onG8^_l0003oi<Njo`000002onC7^`04o`000?oSakco
hlNlon?7_0;o000000?ogl>lo`000?oM`Kd00_oM`Kd01?l0003of[noomZo_ol00003omRn`005o`00
0?oE_<7oeKc1omFl`Ol000000ooA^/<02Ol0003oc[O4oljga?o>]lCo0000olZeaOl0003o_JO2o`00
0003okVS``03o`000?ndWl?o]9o300?o]9o300?o0000ojnLa?n_W<@00_n_W<@00ol0003oZiW5oj^I
a@02oj^Ia@03o`000?nVU/GoYYK500CoYYK50_l00004ohj4a003o`000?n:P/GoRX;500CoRX;500?o
0000ohN1a_n7PLH01?n7PLH00ol0003oQ877ohB1a`05ohB1a`03o`000?n2PLWo000000CoIW;;00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo0004
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`;o00002_oo
ool3o`0003Cooooo00Co001ho`000?l0;[Ko00000_l0;;D01?l0003o02ngo`000?l0=[/2o`0000Co
EVO800?o0000of5^bOmQK/T00_mQK/T01Ol0003oKGG:ofeeb_m]ML[o000000GoNGk;0_n6Q/`01?l0
003oX9;6oj2Ba_l00005ojRHa@03o`000?n`WLGo/9g500;o/9g500?o0000okNSaOngXlD00_ngXlD0
1Ol0003o_ZS4okjXa?nnZ<Co000000GoaJk300Go0000ol^b`_o;//;obk;2o`000003om2g`@05o`00
0?oE^[ooeKZoomFj_ol000000ooI_Kh01?l0003ogL2lomg0_?oM`;`2o`0000?ogl>l00?o0000on;5
^ooRaK/00_l00002onC6^P0:o`000?oTak[o0000onC7^_l0003oiLRjo`000?oUb;[o0000onG8^@;o
00000ooUb;X2o`0000;oi<Nk00Co0000on?7_?oSakco00000_oRb;d01Ol0003ogL6momg1_OoM`Kgo
000000?of[no00Co0000omRn`?oH_/3o00000ooE_<400ol0003odK[3om6j``02om6j``04o`000?o>
]lCoc[O4o`0000?ob[G50_l00003okVS``03o`000?ndWl?o]9o300;o]9o300?o0000ojnLa?n_W<@0
0_n_W<@00ol0003oZiW5oj^Ia@03oj^Ia@03o`000?nVU/GoYYK500?oYYK500Co0000oj:Da_nRU<Ko
00000on>Q<@00ol0003oRX;5ohZ2a@03ohZ2a@03o`000?n7PLKoQh7600GoQh7600?o0000ohB1aon4
PLL01?n4PLL01Ol0003oPX79oh:1bOn2PLWo000000;oIW;;00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3
o`0003Sooooo00?o001ho`000?l000000_l0;;D00ol0003o02ngo`000002o`0f^`05o`000?mFIlSo
EVO8oeIWb?l000001OmQK/T01Ol0003oKGG:ofeeb_m]ML[o000000GoNGk;0on6Q/`00ol0003oX9;6
o`000004ojRHa@03o`000?n`WLGo/9g500?o/9g500Go0000okNSaOngXlGo]j?5o`000004okjXa003
o`000?o5[/?oaJk300;oaJk300Go0000ol^b`_o;//;obk;2o`000004om2g`@05o`000?oE^[ooeKZo
omFj_ol000000ooI_Kh00ol0003ogL2lomg0_002o`0000Cogl>l00Wo0000on;5^ol0003oh/Fko`00
0?oTa[[o0000onC7^_l000000_oTakX2o`0000;oiLRj00?o0000onG8^Ol000001?oUb;X01?l0003o
i<NkonC7^ol00002on?7_005o`000?oRb;goh/Rmon;8_Ol000000ooM`Kd01?l0003of[noomZo_ol0
0003omRn`005o`000?oE_<7oeKc1omFl`Ol000000ooA^/<01?l0003oc[O4oljga?l00004olZea@05
o`000?o6/lOo0000okVS`ol000001?ndWl<00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGoZiW5
00?oZiW500?o0000ojJFaOnVU/D00onVU/D00ol0003oXYC6oj:DaP02oj:DaP03o`000?n>Q<Co0000
00GoRX;500?o0000ohN1a_n7PLH01On7PLH00ol0003oQ877ohB1a`04ohB1a`03o`000?n2PLWoPX79
00?oPX7900?o0000ofIbbol000002Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo0ol0000looooo`05o`00N?l0003o02beo`0/]Ol000000_l0;kL2
o`0f^`05o`A0`Ol0003oEVO8oeIWb?l000001OmQK/T01Ol0003oKGG:ofeeb_m]ML[o000000GoNGk;
1?n6Q/`2o`0000CoZ9S500?o0000ok2MaOn`WLD00_n`WLD00ol0003o]j?5okNSa@02okNSa@03o`00
0?nnZ<Co_ZS400;o_ZS400?o0000olF^`oo5[/<00_o5[/<01Ol0003obk;2ol^b`_o;//;o000000Co
d;O100Go0000omFj_ooE^[ooeKZoo`000002omVm_PCo000000?og<6no`000?oO`k`00_oO`k`00ol0
003oh/Fko`000002on;5^`0;o`000?oTa[[o0000onC7^_l0003oi<Njo`000?oUb;[o0000onG8^_l0
00000_oUb;T00ol0003oiLRjonG8^P02onG8^P04o`000?oTak_oi<Nko`0000;ohlNl00So0000on;8
_OoRb;go0000on78_ol0003ogL6mo`0000;of[no00Go0000omRn`?oH_/3of;k0o`000003omFl`@05
o`000?oA^/?odK[3om6j`ol000000_o>]l@00ol0003ob[G5olZea@02olZea@05o`000?o6/lOoa[?7
olJcaol000001?ndWl<00ol0003o[ic4ojnLa003ojnLa003o`000?n[VLGoZiW500;oZiW500?o0000
ojJFaOnVU/D00onVU/D00ol0003oXYC6oj:DaP03oj:DaP?o00001On:P/D00ol0003oQh76ohN1aP04
ohN1aP03o`000?n4PLOoQ87700CoQ87700?o0000oh:1bOn2PLT01On2PLT00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0ol0
0010ooooo`04o`00N?l0003o02beo`0000;o02ng00Oo0000o`0f^ol0=[_o1431o`000?mFIlSo0000
00GoHFk900Go0000ofeeb_m]ML[oKGG:o`000005ogUnb`CoQXK<0_nCSl`3o`000003ojRHaOl0003o
/9g500?o/9g500?o0000okNSaOngXlD00_ngXlD00ol0003o_ZS4okjXa002okjXa003o`000?o5[/?o
aJk300;oaJk300Go0000ol^b`_o;//;obk;2o`000003om2g`@03o`000?oE^[ooeKZo00;oeKZo00Co
0000omVm__l0003o00001?oL`Kh01?l0003ogl>lomo3_?oO`k`2o`0000?oh/Fk0_l000002_oTak[o
0000onC7^_oTak[o0000onG8^_l0003oiLRjo`000?oUb;T2o`0000?oiLRj00Co0000onG9^ol0003o
00000_oSak`01?l0003oh/Rmon;8_Ol00003on78_`05o`000?oJ_koof[noomZo_ol000000ooH_/00
1?l0003oeKc1omFl`Ol00004om6j``04o`000?o>]lCoc[O4o`0000?ob[G500?o0000olJcaoo6/lL0
0_o6/lL2o`0000?o]9o300?o0000ojnLa?n_W<@00_n_W<@00ol0003oZiW5oj^Ia@02oj^Ia@03o`00
0?nVU/GoYYK500?oYYK500?o0000oj:Da_nRU<H00onRU<H01Ol0003oWY;7oijBaonNT/Oo000000?o
RX;500?o0000ohN1a_n7PLH01?n7PLH00ol0003oQ877ohB1a`04ohB1a`03o`000?n2PLWoPX7900Go
PX7900?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Ko
oooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014ooooo`06
o`000?l0;;Go02beo`000?l0;kOo00000_l0=[/2o`A0`@;o00001OmQK/T01Ol0003oKGG:ofeeb_m]
ML[o000000CoNGk;00?o0000ohJ6c?n6Q/`00_n6Q/`5oi>?c0;o00001?n`WLD01Ol0003o]j?5okNS
aOngXlGo000000Co_ZS400?o0000olF^`oo5[/<00_o5[/<01Ol0003obk;2ol^b`_o;//;o000000Co
d;O100Co0000omFj_ooE^[ooeKZo0ol000000ooH_/3o0000omc1_P03omc1_P05o`000?oO`kcogl>l
omo3_?l000001?oRaK/00ol0003oi<Njo`000002onC7^P03o`000?oUb;[o000000;oiLRj0_l00000
1OoUbK_o0000onG8^_oUb;[o000000;oiLVk00Go0000on?7_?oSakcohlNlo`000002on;8_@04o`00
0?oQb;oohLRoon78_`;o000000?of[noo`000?oH_/000_oH_/001Ol0003oeKc1omFl`OoE_<7o0000
00?odK[300Co0000oljga?o>]lCo00000oo:]LD00ol0003oa[?7olJca`02olJca`06o`000?o2/<So
`[38o`000?ndWl?o00001?n_W<@00ol0003oZiW5oj^Ia@02oj^Ia@03o`000?nVU/GoYYK500?oYYK5
00?o0000oj:Da_nRU<H00onRU<H00ol0003oWY;7oijBa`03oijBa`03o`000?n:P/Go000000KoQh76
00?o0000ohB1aon4PLL01?n4PLL00ol0003oPX79oh:1b@05oh:1b@03o`000?oooooooooo00gooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`007_ooool2o`0004Oooooo00?o
0000o`0/]Ol000000_l0;kL00ol0003o03Jko`000002o`A0`@;o00000omQK/T00ol0003oKGG:ofee
bP02ofeebP03o`000?miO/_oNGk;00;oNGk;00?o0000ohJ6c?n6Q/`00_n6Q/`5oi>?c0;oWiO<1?l0
0004okNSa@03o`000?nnZ<Co_ZS400;o_ZS400?o0000olF^`oo5[/<00_o5[/<01Ol0003obk;2ol^b
`_o;//;o000000Cod;O100?o0000omFj_ooE^[l00_l00003omRn`003o`000?oL`Kkog<6n00;og<6n
00?o0000omo3_?oO`k`00_l00004on;5^`05o`000?oTak[o0000onC7^_l000000_oUb;X01?l0003o
iLRjo`000?l00002onG9^`03o`000?oUb;[o000000?oiLVk00Co0000on?7_?oSakco00000_oRb;d0
1Ol0003ohLRoon78_ooQb;oo000000;oh<S10_l00002omRn`005o`000?oE_<7oeKc1omFl`Ol00000
0ooA^/<01?l0003oc[O4oljga?l00003olZea@03o`000?o6/lOoa[?700;oa[?700?o0000ol:`b?o2
/<P00_o2/<P00ol0003o[ic4ojnLa002ojnLa003o`000?n[VLGoZiW500;oZiW500?o0000ojJFaOnV
U/D00onVU/D00ol0003oXYC6oj:DaP03oj:DaP03o`000?nNT/OoWY;700CoWY;70_l00007ohN1aP03
o`000?n4PLOoQ87700?oQ87700?o0000oh:1bOn2PLT01On2PLT00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0
AOooool2o`0000;o02ng00?o0000o`0f^ol0=[/00_l4@<42oaM=a`04o`000?mQK/WoHFk9o`0000Co
KGG:00?o0000ogUnbomiO//00_miO//00ol0003oQXK<ohJ6c002ohJ6c003o`000?nCSlcoTho<00;o
Tho<1OnOUl`3o`0000;o]j?500?o0000okjXa?nnZ<@00_nnZ<@00ol0003oaJk3olF^``02olF^``05
o`000?o;//;obk;2ol^b`_l000000oo@]l44o`000003om>k`_l0003of;k000;of;k000Go0000omc1
__oL`Kkog<6no`000002omo3_003o`000?oOa;go000000?oh/Fk00Ko0000on?7_?l0003o0000onC7
^_l00002onG8^P;o000000CoiLZko`000?oUbK_oiLVk0_l00003onG9^`;o000000GohlNlo`000?oR
b;goh/Rmo`000003on78_`09o`000?oPb<7oh<S1on38`Ol0003og/S3o`000?oH_/3o000000;oeKc1
00Go0000om6j`ooA^/?odK[3o`000002oljga003o`000?o:]LGob[G500;ob[G500Go0000olJcaoo6
/lOoa[?7o`000004ol:`b003o`000?nn[/[o000000?o[ic400?o0000oj^IaOn[VLD00_n[VLD00ol0
003oYYK5ojJFa@02ojJFa@03o`000?nRU<KoXYC600?oXYC600?o0000oijBaonNT/L01?nNT/L01?l0
003oVi79oi^AbOl00005ohN1aP03o`000?n4PLOoQ87700?oQ87700?o0000oh:1bOn2PLT01On2PLT0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0
027ooooo00?o0000ooooooooool0AOooool01?l0;;Go0000o`0_]ol00002o`0f^`03o`000?l4@<7o
143100;o5dg700?o0000of5^bOl000001?m]MLX00ol0003oNGk;ogUnb`02ogUnb`05o`000?n6Q/co
QXK<ohJ6c?l000001OnCSl`5oinGc0?oZYo;1Ol000000onnZ<Co0000olF^``03olF^``05o`000?o;
//;obk;2ol^b`_l000000_o@]l43o`0000Codk_200Go0000omRn`?oH_/3of;k0o`000003omc1_P03
o`000?oO`kco000000;oglBm00Co0000on;5^ooRaK_o00000_oSak`00ol0003oi<Rlo`000003o`00
00?oiLZk0_oUbK/2o`0000?oiLVk00?o0000onG;_OoUbkd00_l00002on;8_@05o`000?oQb;oohLRo
on78_ol000000_oPb<401Ol0003og/S3omk8`ooNb<?o000000?oeKc100Go0000om6j`ooA^/?odK[3
o`000002oljga005o`000?o:]LGob[G5olZeaOl000000oo6/lL00ol0003o`[38ol:`b002ol:`b007
o`000?nn[/[o_Zk:okj^b_l0003o[ic4o`000004oj^Ia@03o`000?nVU/GoYYK500;oYYK500?o0000
oj:Da_nRU<H00onRU<H00ol0003oWY;7oijBa`04oijBa`03o`000?nKTLWoVi7900;oVi7900Go0000
ohN1a_n7PLKoQh76o`000006ohB1a`03o`000?n2PLWoPX7900CoPX7900?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000Rooooo`03o`000?oooooo
oooo04Cooooo0_l00002o`0_]`03o`000?l0=[_o000000;o14310olGCLL2o`0000CoKGG:00?o0000
ogUnbomiO//00_miO//01Ol0003oQXK<ohJ6c?n6Q/co000000GoTho<00?o0000oinGc?nOUl`00_nO
Ul`4ojZOb`04o`000?ndY/[o]:K:okBVbPgo00000_o=]l@00ol0003odk_2om>k`P02om>k`P05o`00
0?oH_/3of;k0omRn`?l000000ooL`Kh2o`0000?oglBm00?o0000on;5^ol000000_oSak`01?l0003o
i<RlonC8_?l00002onC9_008o`000?oUb[_oiLZko`000?oUbK_o0000onG;_Ol00002onG9^`05o`00
0?oUbkgoiL^monG;_Ol000000_oRb;d01Ol0003ohLRoon78_ooQb;oo000000;oh<S100?o0000omk8
`ooNb<<00_oNb<<2o`000003omFl`Ol0003odK[300;odK[300Co0000oljga?o>]lCo00000oo:]LD0
1Ol0003oa[?7olJcaoo6/lOo000000Co`[3800?o0000okj^b_nn[/X00_nn[/X3o`0000?oZiW500?o
0000ojJFaOnVU/D00_nVU/D00ol0003oXYC6oj:DaP03oj:DaP03o`000?nNT/OoWY;700CoWY;700?o
0000oi^AbOnKTLT01?nKTLT00ol0003oQh76o`000006ohB1a`03o`000?n2PLWoPX7900CoPX7900?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000S
ooooo`;o0000AOooool01?l007Oo0000o`0_]ol00002o`0f^`03o`000?l4@<7o000000?o5dg700Go
0000ofeeb_m]ML[oKGG:o`000005ogUnb`05o`000?n6Q/coQXK<ohJ6c?l000001?nCSl`00ol0003o
WiO<oinGc003oinGc0CoZYo;00?o0000okBVb_ndY/X00_ndY/X00ol0003o_Jc8okf/b002okf/b005
o`000?o6//Koa[;6olJba_l000001?o=]l@01Ol0003odk_2om>k`_oC^l;o000000?of;k000Co0000
omc1__oL`Kkog<6n0_l00004omo4_@;o00000ooSak`00ol0003oi<Rlo`000003onC9_003o`000?oU
b[_oiLZk00;o00000_oUbkd01?l0003oiLVkonG9^ol00003onG;_@04o`000?oRb;goh/Rmo`0000;o
hLRo00Go0000on38`OoPb<7oh<S1o`000003omk8``04o`000?oLb<Gog<S5o`0000?odK[300Co0000
oljga?o>]lCo00000oo:]LD01Ol0003oa[?7olJcaoo6/lOo000000Co`[3800?o0000okj^b_nn[/X0
0_nn[/X01ol0003o^Zc;okZ/bonj[<_o0000oj^IaOl000001?nVU/D00ol0003oXYC6oj:DaP03oj:D
aP03o`000?nNT/OoWY;700CoWY;700?o0000oi^AbOnKTLT01OnKTLT2o`0000KoQ87700?o0000oh:1
bOn2PLT01?n2PLT00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01Oooool002Gooooo00?o0000ooooooooool0@oooool00ol007Oo0000o`000002o`0f^`03
o`000?l4@<7o143100?o5dg700Go;E_>o`000?m]ML[oKGG:o`000005ogUnb`05o`000?n6Q/coQXK<
ohJ6c?l000001?nCSl`00ol0003oWiO<oinGc003oinGc0CoZYo;00?o0000okBVb_ndY/X00_ndY/X0
0ol0003o_Jc8okf/b002okf/b005o`000?o6//Koa[;6olJba_l000001?o=]l@01Ol0003odk_2om>k
`_oC^l;o000000?of;k000Ko0000omc1__oL`Kko0000omc3`?l00004omo4_@05o`000?oSakcohlNl
on?7_?l000000_oTb;`01?l0003oi<VlonC9_?l00002onG:^`;o00000ooUbkd00ol0003oiLVko`00
0003onG;_@04o`000?oTcKoo0000o`0000?ohLRo00Co0000on38`OoPb<7o00000ooNb<<01Ol0003o
g<S5omc8aOoLb<Go000000?odK[300?o0000oljga?l000000oo:]LD01Ol0003oa[?7olJcaoo6/lOo
000000Co`[3800?o0000okj^b_nn[/X00_nn[/X00ol0003o^Zc;okZ/b`02okZ/b`;o00001?nVU/D0
0ol0003oXYC6oj:DaP03oj:DaP03o`000?nNT/OoWY;700CoWY;700?o0000oi^AbOnKTLT01OnKTLT0
0ol0003oV97:o`000005ohB1a`03o`000?n2PLWoPX7900CoPX7900?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo000Vooooo`03o`000?oooooooooo
04?ooooo00Go001go`0_]ol0003o03Jko`000002o`A0`@08o`000?lGCLOo5dg7o`000?l]Flko0000
ofeeb_l00005ogUnb`05o`000?n6Q/coQXK<ohJ6c?l000001?nCSl`00ol0003oWiO<oinGc002oinG
c003o`000?nZWl_oZYo;00;oZYo;00?o0000okBVb_ndY/X00_ndY/X00ol0003o_Jc8okf/b002okf/
b005o`000?o6//Koa[;6olJba_l000001?o=]l@01Ol0003odk_2om>k`_oC^l;o000000?of;k000?o
0000omc1__l000000_oL`l000ol0003oglBmomo4_@02omo4_@04o`000?oSakcohlNlo`0000;oi<Rl
00Ko0000onC9_?oTbKcoi<Vlo`000?oUb[/2o`0000CoiL^m0_l00003onG;_@04o`000?oTcKooi<fo
o`0000?ohLRo00Co0000on38`OoPb<7o00000ooNb<<02Ol0003og<S5omc8aOoLb<Go0000om[9b?l0
003odK[3o`000002oljga004o`000?o:]LGob[G5o`0000Coa[?700Go0000ol:`b?o2/<So`[38o`00
0004okj^bP03o`000?nj[<_o^Zc;00;o^Zc;00?o0000okJZcOl000000onVU/D00ol0003oXYC6oj:D
aP03oj:DaP03o`000?nNT/OoWY;700CoWY;700?o0000oi^AbOnKTLT01OnKTLT01Ol0003oV97:oiRA
b_nHTL[o000000?oQ87700?o0000oh:1bOn2PLT01?n2PLT00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0@ooo
ool01ol007Oo0000o`0f^ol0=[_o0000o`A0`Ol000000olGCLL2obeKcP;o00001OmiO//01Ol0003o
QXK<ohJ6c?n6Q/co000000CoTho<00?o0000oinGc?nOUl`00_nOUl`01Ol0003oZYo;ojZObonZWl_o
000000Go]:K:00?o0000okf/b?nm[<P00_nm[<P01Ol0003oa[;6olJba_o6//Ko000000CocKO400Go
0000om>k`_oC^l;odk_2o`000003omRn`0;o00000ooL`l002Ol0003oglBmomo4_OoOa;go0000on77
__l0003ohlNlo`000002onC8_004o`000?oTbKcoi<VlonC9_0;o000000?oiLbno`000?oUbkd00_oU
bkd2o`0000?oiL^m00Go0000onC=_ooTcKooi<foo`000002on78_`04o`000?oPb<7oh<S1o`0000?o
g/S300Go0000omc8aOoLb<Gog<S5o`000003om[9b004o`000?o>]lCoc[O4o`0000?ob[G500Go0000
olJcaoo6/lOoa[?7o`000003ol:`b003o`000?nn[/[o_Zk:00;o_Zk:00?o0000okZ/bonj[</00_nj
[</01ol0003o]Z[=okJZcOnfZ/go0000ojJFaOl000001OnRU<H00ol0003oWY;7oijBa`03oijBa`;o
00001_nKTLT2o`0000GoV97:00?o0000ohB1aol000001_n2PLT00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Sooooo0_l00014ooooo`04o`00
O_l0003o03Jko`0000;o143100?o0000oaM=aolGCLL00ol]Flh2o`0000?oNGk;00?o0000ohJ6c?n6
Q/`00_n6Q/`00ol0003oTho<oi>?c002oi>?c003o`000?nOUlcoWiO<00;oWiO<00Go0000ojZObonZ
Wl_oZYo;o`000004okBVbP03o`000?nm[<So_Jc800;o_Jc800?o0000olJba_o6//H00_o6//H00ol0
003ocKO4olfga002olfga005o`000?oC^l;odk_2om>k`_l000000_oH_/02o`0000Gog<?000?o0000
omo4_Ol000000ooQakh3o`000006onC8_?l0003oi<VlonC9_?l0003oiLZk0_oUc;h01_l0003oiL^m
onG;_Ol0003oiLjoo`0000;oiL^m00Co0000onC=_ooTcKooi<fo0_l00002on78_`04o`000?oPb<7o
h<S1o`0000?og/S300Co0000omc8aOoLb<Go00001?oJbLP00ol0003oc[O4o`000003olZea@05o`00
0?o6/lOoa[?7olJcaol000000oo2/<P00ol0003o_Zk:okj^bP02okj^bP03o`000?nj[<_o^Zc;00;o
^Zc;00?o0000okJZcOnfZ/d00_nfZ/d2o`0000GoXYC600?o0000oijBaonNT/L00onNT/L00ol0003o
Vi79oi^Ab@05oi^Ab@03o`000?nHTL[oV97:00GoV97:0ol00005oh:1b@03o`000?oooooooooo01co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00:_ooool00ol0003ooooo
ooooo`12ooooo`03o`00O_l0003o000000;o143100Co0000oaM=aolGCLOo00000_l]Flh2odE[d`;o
000000?oNGk;o`000?n6Q/`00on6Q/`00ol0003oTho<oi>?c002oi>?c003o`000?nOUlcoWiO<00;o
WiO<00Go0000ojZObonZWl_oZYo;o`000004okBVbP03o`000?nm[<So_Jc800;o_Jc800?o0000olJb
a_o6//H00_o6//H01Ol0003ocKO4olfga?o=]lCo000000?odk_200Ko0000omRn`?l0003o0000omS1
`ol00005omc3`0;o00001?oQakh00ol0003oh/Voon;9_`05o`0000?oiLbn00?o0000onG;_Ol00000
0_oUc[l00ol0003oiL^mo`000003onC=_`03o`000?oTcl;oi<o200;o00000_oPb<401Ol0003og/S3
omk8`ooNb<?o000000;og<S500?o0000om[9b?oJbLP00_oJbLP00ol0003of<W;o`000003olZea@05
o`000?o6/lOoa[?7olJcaol000000oo2/<P00ol0003o_Zk:okj^bP02okj^bP03o`000?nj[<_o^Zc;
00;o^Zc;00?o0000okJZcOnfZ/d00_nfZ/d01?l0003o/ZS>ok:Xc_l00003oj:DaP03o`000?nNT/Oo
WY;700?oWY;700?o0000oi^AbOnKTLT01OnKTLT00ol0003oV97:oiRAbP05oiRAbP05o`000?nFTLco
UY7<oiJAc?l000000on2PLT00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@_ooool01Ol007ko03Jko`000?l4
@<7o000000;o5dg700Co0000obeKc_l]Flko00000om5Jm<2o`0000CoQXK<00?o0000oi>?c?nCSl`0
0_nCSl`00ol0003oWiO<oinGc002oinGc005o`000?nZWl_oZYo;ojZObol000001?ndY/X00ol0003o
_Jc8okf/b002okf/b005o`000?o6//Koa[;6olJba_l000001?o=]l@01?l0003odk_2om>k`_oC^l82
o`0000?of<7300?o0000omc3`?oL`l000ooL`l000ol0003ohLNnon77_P02on77_P05o`000?oRbKoo
h/Voon;9_ol000000ooTbkl01_l0003oiLbnonG<__l0003oiL^mo`0000?oiLjo0_l00003onC=_`05
o`000?oTcl;oi<o2onC?`_l000000_oPb<401Ol0003og/S3omk8`ooNb<?o000000;og<S500?o0000
om[9b?oJbLP00_oJbLP00ol0003of<W;omS9b`02o`000003olZeaOl0003oa[?700;oa[?700Go0000
ol:`b?o2/<So`[38o`000003okj^bP;o00000onj[</2o`0000Co]Z[=00?o0000ok:Xc_nbZ<h00_nb
Z<h00ol0003oXYC6o`000005oijBa`03o`000?nKTLWoVi7900CoVi790_l00006oiRAbP;o00001OnF
TL`00ol0003oPX79o`00000Rooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?oo
ool002cooooo00?o0000ooooooooool0@Oooool00ol0003o001no`000002o`A0`@04o`000?lGCLOo
5dg7o`0000;o;E_>1?m5Jm<2o`0000;oQXK<00?o0000oi>?c?nCSl`00onCSl`00ol0003oWiO<oinG
c002oinGc005o`000?nZWl_oZYo;ojZObol000001?ndY/X00ol0003o_Jc8okf/b002okf/b005o`00
0?o6//Koa[;6olJba_l000001?o=]l@00ol0003odk_2om>k`P02o`0000Cof<7300?o0000omc3`?oL
`l000_oL`l02o`0000?ohLNn00Go0000on;9_ooRbKooh/Voo`000003onC;_`04o`000?oUc;koiLbn
onG<_P;o00001?oUc[l01Ol0003oi<foonC=_ooTcKoo000000Coi<o200Co0000on38`OoPb<7o0000
0_oNb<<01?l0003og<S5omc8aOl00004om[9b004o`000?oHbL_of<W;o`0000;oeLW>00Go0000olJc
aoo6/lOoa[?7o`000003ol:`b005o`000?nn[/[o_Zk:okj^b_l000001?nj[</00ol0003o]Z[=okJZ
c@02okJZc@;o00001OnbZ<h2o`0000GoWY;700?o0000oi^AbOnKTLT01?nKTLT00ol0003oV97:oiRA
bP05oiRAbP03o`000?nFTLcoUY7<00GoUY7<0_l0000Sooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool01?ooool002gooooo0_l00012ooooo`05o`000?l00X_o0000o`A0`Ol000000_lG
CLL01?l0003o;E_>obeKc_l00003odE[d`;oGG[G00?o0000ohJ6c?l000001OnCSl`00ol0003oWiO<
oinGc002oinGc005o`000?nZWl_oZYo;ojZObol000001?ndY/X00ol0003o_Jc8okf/b002okf/b005
o`000?o6//Koa[;6olJba_l000001?o=]l@01Ol0003odk_2o`000?oC_lOo000000Gof<7300Co0000
omc3`?oL`l3o00000_oNal801?l0003ohLNnon77__l00003on;9_`05o`000?oTbkooi<^oonC;_ol0
00000_oUc;h2o`0000CoiLjo0_l00003onC=_`06o`000?oTcl;oi<o2onC?`_l0003oi=750_l00003
omk8``04o`000?oLb<Gog<S5o`0000?of/W800Co0000omS9booHbL_o00000_oEbLh01Ol0003od/WA
o`000?o6/lOo000000?o`[3800Go0000okj^b_nn[/[o_Zk:o`000004okZ/b`03o`000?nfZ/go]Z[=
00;o]Z[=00?o0000ok:Xc_nbZ<h01?nbZ<h01?l0003o[jO@ojnWd?l00003oijBa`03o`000?nKTLWo
Vi7900CoVi7900?o0000oiRAb_nHTLX01OnHTLX00ol0003oUY7<oiJAc005oiJAc003o`000?oooooo
oooo02Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`00;oooool00ol0
003oooooooooo`10ooooo`04o`00Mol00X_o0000o`0000;o5dg700Co0000obeKc_l]Flko00000om5
Jm<00ol0003oGG[Goeeje`02o`0000CoTho<00?o0000oinGc?nOUl`00onOUl`01Ol0003oZYo;ojZO
bonZWl_o000000Co]:K:00?o0000okf/b?nm[<P00_nm[<P01Ol0003oa[;6olJba_o6//Ko000000Co
cKO40_l00002om>oa`03o`000?oH`L?of<7300?of<7300?o0000omc3`?l000000ooNal800ol0003o
hLNno`000003on;9_`03o`000?oTbkooi<^o00;oi<^o0ol000000ooUcl7o0000onG>_`02onG>_`03
o`000?oUdL;o000000;oi<fo00Go0000onC?`_oTcl;oi<o2o`000002onCAa@05o`000?oNb<?og/S3
omk8`ol000000_oLb<D01Ol0003of/W8om[9b?oJbLSo000000;of<W;00Co0000omG9c_oEbLko0000
0_oBbM42o`0000?o`[3800Go0000okj^b_nn[/[o_Zk:o`000004okZ/b`03o`000?nfZ/go]Z[=00;o
]Z[=00?o0000ok:Xc_nbZ<h00onbZ<h2o`0000Co[jO@00?o0000oijBaol000001_nKTLT00ol0003o
V97:oiRAbP04oiRAbP;o00001_nFTL`2o`0002Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`04ooooo`00<?ooool00ol0003oooooooooo`10ooooo`04o`00O_l00X_o1431o`0000;o
5dg700?o0000obeKc_l000001?m5Jm<3oeeje`;o00000onCSl`00ol0003oWiO<oinGc003oinGc005
o`000?nZWl_oZYo;ojZObol000001?ndY/X00ol0003o_Jc8okf/b002okf/b005o`000?o6//Koa[;6
olJba_l000000oo=]l@2o`0000Codko700?o0000omS1`ooH`L<00_oH`L<2o`0000Gog/O20_l00003
on;9_`06o`000?oTbkooi<^oonC;_ol0003oiLbn0ooUcl401?l0003oiLjoonG>_ol00002onGA`P03
o`000?oTcKoo000000?oi<o200?o0000onCAaOoTdLD00_l00002omk8``04o`000?oLb<Gog<S5o`00
00?of/W800Co0000omS9booHbL_o00000_oEbLh01?l0003od/WAom;9dOl00002olo9e003o`000?o2
/<So000000?o_Zk:00Co0000okZ/bonj[<_o^Zc;0_l00003okJZc@;o00001OnbZ<h00ol0003o[jO@
ojnWd004ojnWd0;o00001OnKTLT2o`0000KoV97:00?o0000oiJAc?nFTL`01?nFTL`2o`0002_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`00047ooooo00?o
001no`02Rol000000_lGCLL01?l0003o;E_>obeKc_l00003odE[d`?oGG[G0_mdRMX4o`0000CoWiO<
00Go0000ojZObonZWl_oZYo;o`000004okBVbP03o`000?nm[<So_Jc800;o_Jc800?o0000olJba_o6
//H00_o6//H4o`000003olbkb_l0003odko700?odko700?o0000omS1`ooH`L<00_oH`L<00ol0003o
g/O2omk7`P04omk7`P07o`000?oPbl?o0000o`000?oRbKoo0000onC;_`03o`0000CoiLo100?o0000
onG>_ol000000ooUdL82o`0000?oi<o200Co0000onCAaOoTdLGo00000_oSe<P2o`0000;og<S500Go
0000om[9b?oJbLSof/W8o`000002omS9b`04o`000?oEbLkoeLW>o`0000;od/WA00Co0000olo9e?o?
bMCoclWD0_l00003okj^bP05o`000?nj[<_o^Zc;okZ/bol000001?nfZ/d00ol0003o/ZS>ok:XcP03
ok:XcP;o00001On_Ym02o`0000;oZjKB00Go0000oi^AbOnKTLWoVi79o`000006oiRAbP;o00001_nF
TL`00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00ooo
ool003?ooooo00?o0000ooooooooool0?oooool01Ol00X_o01FMo`000?lGCLOo000000;o;E_>00Go
0000odE[dom5Jm?oAF_Co`000002oeeje`03o`000?mdRM[oM8WJ00;oM8WJ0_l00003oinGc005o`00
0?nZWl_oZYo;ojZObol000001?ndY/X00ol0003o_Jc8okf/b002okf/b004o`000?o6//Koa[;6olJb
aP;o00001?o<^lX00ol0003odko7om>oa`02om>oa`03o`000?oH`L?of<7300;of<7300?o0000omk7
`_oNal800ooNal800ol0003oh<_3on3;``02on3;``?o00000_oSc/<01ol0003oiLo1onG?`OoUcl7o
0000onG>_ol000000ooUdL82o`0000?oi<o200Co0000onCAaOoTdLGo00000_oSe<P2o`0000;og<S5
00Go0000om[9b?oJbLSof/W8o`000002omS9b`04o`000?oEbLkoeLW>o`0000;od/WA00Go0000olo9
e?o?bMCoclWDo`000002ol_8e`03o`000?nn[/[o000000?o^Zc;00?o0000okJZcOnfZ/d00_nfZ/d0
0ol0003o/ZS>ok:XcP03ok:XcP03o`000?n_Ym3o[jO@00Co[jO@00?o0000oj^Vd_n[Y]800on[Y]80
0ol0003oVi79o`000006oiRAbP03o`000?nFTLcoUY7<00CoUY7<0_l0000_ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000ooooooooool0?oooool01?l0
0X_o01FMo`000?l00002obeKcP05o`000?m5Jm?oAF_CodE[dol000000omMN]L4ogB9fP;oRIKJ1?l0
0003ojZOb`03o`000?ndY/[o]:K:00;o]:K:00?o0000okf/b?nm[<P00_nm[<P4o`000003ol>gc_l0
003oc;_:00?oc;_:00?o0000om>oaooC_lL00_oC_lL01ol0003of<73omS1`ooH`L?o0000om[6a_l0
00000ooNal800ol0003oh<_3on3;``03on3;``05o`000?oSc/?ohlk3on?>`ol000001?oUcl400ol0
003oiLjoonGA`P02onGA`P03o`000?oUeLKo000000;oi<o200Co0000onCAaOoTdLGo00000_oSe<P0
0ol0003oh]O=o`000002omc8a@?of/W800Co0000omS9booHbL_o00000_oEbLh01?l0003od/WAom;9
dOl00003olo9e004o`000?o;b=OoblSGol_8e`;o00000onj[</00ol0003o]Z[=okJZc@02okJZc@03
o`000?nbZ<ko/ZS>00;o/ZS>0_l00005ojnWd0;o00001_n[Y]82o`0000KoV97:00?o0000oiJAc?nF
TL`01?nFTL`00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool003Gooooo00?o0000ooooooooool0?oooool01?l00X_o01FMoaM=aol00002obeKcP04
o`000?m5Jm?oAF_Co`0000?oGG[G00Go0000ogB9f_mdRM[oM8WJo`000004ohVFfPoo00001?o3]lh0
0ol0003oc;_:olbkbP02olbkbP03o`000?oC_lOodko700;odko700Co0000omS1`ooH`L?o00000ooJ
a/H01?l0003og/O2omk7`_l00004on3;``03o`000?oSc/?ohlk300;ohlk300Co0000onG?`OoUcl7o
iLo10_l00003onGA`P06o`000?oUeLKoiMG6o`000?oTcl;o00000_oTdLD01?l0003ohmC8on?Db?l0
0002on;Gc@;o00000ooJbLP01?l0003of<W;omS9bol00002omG9cP04o`000?oBbM7od/WAo`0000?o
clWD00Go0000ol_8eoo;b=OoblSGo`000002olO8f`03o`000?nj[<_o000000?o]Z[=0_l00004ok:X
cP03o`000?n_Ym3o[jO@00?o[jO@0_l00006oj^VdP;o00000_nWYM@01?l0003oV97:oiRAb_nHTLX2
o`0000GoUY7<0_l0000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool0
03Kooooo0_l0000oooooo`04o`00O_l0003o01FMo`0000;o;E_>00Go0000odE[dom5Jm?oAF_Co`00
0002oeeje`03o`000?mdRM[oM8WJ00;oM8WJ1?n9U]X4oibQf0GoZj[F1Oni/M800ol0003o`kO>ol>g
cP02ol>gcP03o`000?o<^l[oc;_:00;oc;_:00?o0000om>oaooC_lL00ooC_lL2o`0000Cof/K600?o
0000omk7`_l000001?oPbl<00ol0003ohlk3on?>``02on?>``03o`000?oUcl7o000000;o000000?o
i=;5o`000?oUdL800_l00003onGEaP;o00000_oTdLD01?l0003ohmC8on?Db?l00002on;Gc@03o`00
0?oPfm7o000000;of/W800Co0000omS9booHbL_o00000_oEbLh01?l0003od/WAo`000?l00002olo9
e0;o00000_o;b=L2o`0000?oalSK0_l00003okJZc@03o`000?nbZ<ko/ZS>00;o/ZS>0_l00004ojnW
d0;o00001_n[Y]82o`0000GoYjGD00?o0000oiRAb_l000001_nFTL`00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool003Sooooo00?o0000oooooooo
ool0?Oooool01_l007ko0000o`0]/ol0003o;E_>o`0000?oAF_C00Co0000oeejeomMN]Oo00001?md
RMX01Ol0003oRIKJohVFf_n9U][o000000?oW:7H00?o0000oj^Ze_n[Z]H00_n[Z]H00ol0003o^K7B
okVadP02okVadP03o`000?o3]lko`kO>00;o`kO>00?o0000olbkb_o<^lX00oo<^lX01?l0003odko7
om>oaooC_lL2o`0000Kof/K60_l00004on3;``03o`000?oSc/?ohlk300;ohlk30_l00003onCBa@03
o`000?oUdL;o000000CoiMG60_l00002onCAa@04o`000?oSe<SohmC8o`0000;oh]O=00Ko0000on3K
dOoPfm7oh=_Ao`000?oJbLP2omS9b`06o`000?oEbLkoeLW>o`000?oBbM7o00000oo?bM@01Ol0003o
blSGol_8eoo;b=Oo000000?oalSK0_l00002ol;7gP03o`000?nfZ/go000000Co/ZS>00?o0000ojnW
d?n_Ym000on_Ym000ol0003oZjKBoj^VdP04oj^VdP;o00001onWYM@2o`0000GoUY7<0_l0000hoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool003Wooooo00?o0000oooooooo
ool0?Oooool00ol00X_o01FMo`0]/`02o`0000?oAF_C00Co0000oeejeomMN]Oo00001?mdRMX01Ol0
003oRIKJohVFf_n9U][o000000CoW:7H1?n[Z]H00ol0003o^K7BokVadP02okVadP03o`000?o3]lko
`kO>00;o`kO>00?o0000olbkb_o<^lX00oo<^lX01_l0003odko7om>oaol0003oeLK;o`0000Kof/K6
00Oo0000omg<b?l0003o0000on3;`ol0003ohlk300Co00001OoTd/D00ol0003oiM72onGEaP03onGE
aP05o`000?oTfL_o0000onCAaOl000000_oSe<P01?l0003oh]O=on;GcOl00003on3Kd@;o00000ooH
bL/2omG9cP03o`000?oBbM7od/WA00?oclWD00?o0000ol_8eoo;b=L00_l00003olO8f`03o`000?o2
amko`/ON00;o`/ON0_l00003ok:XcP;o00001?n_Ym02o`0000GoZjKB0_l00006ojNUe0?o000000?o
Y:GFo`000?nFTL`00_nFTL`2o`0003_ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`00>_ooool00ol0003oooooooooo`0mooooo`05o`02Rol05Igo02fcobeKc_l000000_m5
Jm<01Ol0003oGG[GoeejeomMN]Oo000000?oM8WJ00?o0000ohVFf_n9U]X00_n9U]X01Ol0003oW:7H
oibQf?nLXMSo000000CoZj[F00?o0000okVad_ni/M800_ni/M800ol0003o`kO>ol>gcP02ol>gcP03
o`000?o<^l[oc;_:00;oc;_:00?o0000om>oaol000000ooEa//00ol0003of/K6om[6aP02om[6aP03
o`000?oMc<SogLc800;ogLc80ol00003on7Aa`03o`000?oTd/Goi=;500?oi=;500Co0000onGEa_oU
eLKoiMG60_l00002onCIb`;o00000_oSe<P01?l0003oh]O=on;GcOl00003on3Kd@03o`000?oMg]Ko
000000;of<W;0_oEbLh00ol0003od/WAom;9d@03olo9e004o`000?o;b=OoblSGo`0000?oalSK0_l0
0003ol;7gP;o00000_nma^400ol0003o/ZS>o`000004ojnWd0;o00001On[Y]82o`0000KoYjGD0_l0
0005ojBUeP03o`000?nFTLco000003kooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`02ooooo`00>oooool2o`0003kooooo00?o0000o`0EWOl0;K<00_l000000om5Jm?o0000oeeje`02
oeeje`05o`000?mdRM[oM8WJogB9f_l000001?n9U]X01Ol0003oW:7HoibQf?nLXMSo000000CoZj[F
00?o0000okVad_ni/M800_ni/M800ol0003o`kO>ol>gcP02ol>gcP03o`000?o<^l[oc;_:00;oc;_:
0_l00004omG6b`05o`000?oJa/Kof/K6om[6a_l000001OoMc<P00ol0003ohM77on7Aa`02on7Aa`03
o`000?oTd/Goi=;500;oi=;50_l00003onGEaP06o`000?oTfL_oi=W;onCIbol0003oi=750_oSe<P0
1?l0003oh]O=on;GcOl00003on3Kd@03o`000?oMg]KogMkF00;o00000ooEbLh2om;9d@?oclWD00Co
0000ol_8eol0003o00000_o7b=/2o`0000?o`/ON0_l00004okg6h@;o00001?n_Ym000ol0003oZjKB
oj^VdP03oj^VdP;o00001OnWYM@3o`0000OoY:GF0_l0000oooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00_ooool003gooooo00?o0000ooooooooool0??ooool2o`0000;o04_900?o
0000odE[dol000000_mMN]L00ol0003oM8WJogB9fP02ogB9fP05o`000?n9U][oRIKJohVFf_l00000
0onLXMP00ol0003oZj[Foj^ZeP02oj^ZeP03o`000?ni/M;o^K7B00;o^K7B00?o0000ol>gc_o3]lh0
0_o3]lh01?l0003oc;_:olbkb_o<^lX2o`0000KoeLK;00Co0000om[6a_oJa/Ko00001?oMc<P00ol0
003ohM77on7Aa`03on7Aa`03o`000?oTd/Goi=;500;o000000GohmO;o`000?oUeLKoiMG6o`000003
onCIb`;o00000ooSe<P2on;Gc@05o`000?oPfm7oh=_Aon3KdOl000000_oMg]H00ol0003of^;Lo`00
0002omG9cP;od/WA0oo?bM@00ol0003oblSGo`000002olO8f`;o00001?o2amh00ol0003o_LKQokg6
h@02okg6h@;o00000_nhaN@01?l0003o[jO@o`000?l00004oj^VdP;o00001OnWYM@2o`0000OoY:GF
0ol00012ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003kooooo00?o
0000ooooooooool0>oooool00ol00X_o0000o`0]/`02o`1;b@05odE[dol0003oGG[Goeejeol00000
1?mdRMX01Ol0003oRIKJohVFf_n9U][o000000CoW:7H00Go0000oj^Ze_n[Z]KoZj[Fo`000004okVa
dP03o`000?o3]lko`kO>00;o`kO>00Ko0000olbkb_l0003o0000olk5dOl00006omG6b`03o`000?oJ
a/Ko000000GogLc800?o0000on7AaooQdLL00ooQdLL00ol0003oi=;5o`000003on?Gb`03o`000?oU
eLKo000000?oi=W;00?o0000on?Od?l000000_oSe<P3on;Gc@;oh=_A0_l00002omgNeP03o`000?oJ
h]cof^;L00;o00000_oBbM43olo9e003ol_8eol0003o000000;oalSK00?o0000ol;7g_o2amh00_o2
amh2o`0000?o_LKQ0_l00004okS5i0;o00001?n[Y]82o`0000GoYjGD0_l00006ojBUeP?o0000A_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooo
oooo03_ooooo00?o0000o`0EWOl0;K<00_l0BlT2o`000003oeejeol0003oM8WJ00?oM8WJ00Go0000
ohVFf_n9U][oRIKJo`000004oibQf005o`000?n[Z]KoZj[Foj^Ze_l000001?ni/M800ol0003o`kO>
ol>gcP02ol>gcP;o00001?o>aM400ol0003oeLK;omG6b`04omG6b`;o00001?oMc<P00ol0003ohM77
on7Aa`03on7Aa`03o`000?oTd/Go000000?ohmO;00?o0000onGEa_oTfL/00ooTfL/01Ol0003ohmo@
on?Od?l0003ohmC800?oh]O=0_oPfm400ol0003ogMkFomgNeP02o`0000;of^;L00Co0000omKVh_l0
003o00000oo?bM@01?o;b=Oo0000olO8foo7b=/2o`0000?o`/ON0_l00003okg6h@;o00000onhaN@3
o`0000;o//?W00Co0000oj^Vd_l0003o00001?nWYM@3o`0000GoY:GF0ol0001:ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool0043ooooo0_l0000looooo`04o`000?l05Igo
02fco`1;b@;o5V[M00?o0000oeejeol000000omdRMX01Ol0003oRIKJohVFf_n9U][o000000CoW:7H
00Go0000oj^Ze_n[Z]KoZj[Fo`000005okVadP03o`000?o3]lko`kO>00;o00001_o>aM400ol0003o
eLK;omG6b`02omG6b`03o`000?oIc/kofLk>00?o000000CogLc8o`000?oQdLOohM771?l00004on?G
b`;o00001?oTfL/00ol0003ohmo@on?Od002o`0000?oh]O=0_oPfm401?l0003ogMkFomgNe_l00002
om[Rg0;o000000Coe^KRo`000?o@jNOo00000_o?bM@00oo;b=Oo0000olO8f`02o`0000?o`/ON0_l0
0003okg6h@;o00000onhaN@2o`0000Co//?W0ol00004ojNUe0;o00001_nTYMH2o`0004gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@_ooool00ol0003oooooooooo`0j
ooooo`?o000000Co04_9oaIZgOlFJ]go5V[M0_l00002ogB9fP05o`000?n9U][oRIKJohVFf_l00000
1?nLXMP00ol0003oZj[Foj^ZeP02oj^ZeP03o`000?ni/M;o^K7B00;o^K7B0ol000000oo5`]So0000
olk5d@05olk5d@05o`000?oEa/_oeLK;omG6bol000001_oIc/h4o`0000?ogmG>00?o0000on?GbooS
el/00_l000000ooQgM7o0000onCIb`02onCIb`06o`000?oSgm3ohmo@o`000?oQiMOo00000_oReld2
on3Kd@04o`000?oMg]Ko0000o`0000;of^;L00Co0000omKVh_l0003o00000_o@jNL2o`000004ol_8
eoo7b=_oalSKo`0000?o`/ON0_l00002okg6h@?o00000_nhaN@3o`0000?o//?W0ol00002ojg2j@03
o`000?nWYMCo000000;o00001OnTYMH3o`00053ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`00@oooool00ol0003oooooooooo`0kooooo`;o000000Go04_9oaIZgOlFJ]go
0000od>7j@02o`000003ogB9f_l0003oRIKJ00;oRIKJ00Go0000oibQf?nLXMSoW:7Ho`000004oj^Z
eP03o`000?ni/M;o^K7B00?o00001?o5`]P00ol0003oc/GAolk5d@04olk5d@03o`000?oEa/_o0000
00OofLk>00?o0000omoEc_oOeLh00ooOeLh01?l0003ohmO;o`000?l00003on7Md@03o`000?oTfL_o
i=W;00?ohmo@00Go0000on7UeooQiMOo0000on;Gc@02on3Kd@;ogMkF00?o0000om[Rg?oJh]`00_l0
00001?oFi^;o0000om3Yioo@jNL4o`000003olO8fol0003o000000?o`/ON00?o0000okg6hOnma^40
0_l00003okS5i0;o00000onb`nL3o`0000Co[L;Y0ol00005ojBUeP?o0000E?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo03_ooooo00?o
02fco`000?l0BlT00_lFJ]d01?l0003o@hOYod>7jOm3QnT3o`000003ohVFf_l0003oW:7H00?oW:7H
00?o0000oj^Ze_l000001?l00002okRog`03o`000?o5`]SoaL;H00?oaL;H00?o0000olk5dOo>aM40
1?o>aM400ol0003ofLk>omW>cP05omW>cP03o`000?oOeLkogmG>00?ogmG>00?o0000on?Gbol00000
1?oQgM400ol0003oi=W;onCIb`02on?Od0;o00000_oQiML2o`0000;oh=_A0_oMg]H01Ol0003of^;L
om[Rg?l0003oe^KR00;o000000?od>WWo`000?l000000_l000000onnk??o0000o`000003ol;7gP;o
000000?o_LKQo`000?l000000onhaN@2o`000003ok;3iol0003o000000;o00000on]`^T4o`0000?o
Yl3[00?o0000ojBUe_l000000_l0001Hooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00Oooool004Gooooo0_l0000looooo`03o`000?l0BlWo000000;o5V[M00Co0000od>7jOm3QnWo
00000_m/W^h8o`0000;oY[SV00?o0000okRogonh_ml00onh_ml00ol0003oaL;HolG2f003olG2f003
o`000?o>aM7oc/GA00;oc/GA00?o0000omC@e_oDd=H00_l00003omW>cP03o`000?oOeLkogmG>00Co
gmG>0_l00005on7Md@05o`000?oTfL_ohmo@on?Od?l000000ooQiML01?l0003og>cMo`000?oPfm42
omgNeP06o`000?oJh]cof^;Lo`000?oFi^;o00000_o@jNL3o`000006okk/lol0003o0000ok?[mol0
003o`/ON0_l000000onma^7o0000o`000002okS5i0Ko00000on]`^T4o`0000KoYl3[0ol0001Koooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Oooooo00?o0000oooooooo
ool0>_ooool00ol0003o04_9o`000002oaIZg@04o`000?m3QnWo@hOYo`0000;oK9k^00?o0000ohf^
k?n=[^`00_n=[^`00ol0003oY[SVojJhiP02ojJhiP03o`000?nh_moo^;oO00;o^;oO00?o0000olG2
f?o5`]P00oo5`]P01Ol0003oc/GAolk5dOo>aM7o000000Goe=3F0_l000001?oIc/ko0000omoEc_oO
eLh4o`0000KohMgA0_l00002on?Od003o`000?oQiMOohNGG00;o000000?og>cMo`000?l000000_oM
g]H2om[Rg0?o00000_o@jNL6o`0000?o/n_g0_l000000onma^7o0000o`000002okS5i0Go00000on]
`^T3o`0000GoYl3[1Ol0001Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Ooo
ool004Sooooo00?o0000ooooooooool0>_ooool01Ol0003o04_9o`000?lFJ]go000000?o@hOY00Co
0000ofbNk_m/W^ko00001?n=[^`01Ol0003oY[SVojJhi_nV^>Ko000000Go^;oO00?o0000olG2f?o5
`]P00oo5`]P00ol0003oc/GAo`000008omC@ePCo00000ooKf]H01?l0003ohMgAon7MdOoQgM43o`00
0003omkTfOl0003ohmo@00;ohNGG0_l000001_oLk=go0000o`000?oDl^Go0000omgNeP;of^;L00Co
0000omKVh_l0003od>WW1Ol00003ok?[m`Ko000000?o^<GTo`000?l000000ol00002ojg2j@Co0000
0onW`>/5o`0006Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00BOoo
ool00ol0003oooooooooo`0jooooo`;o00000_lFJ]d01?l0003o@hOYod>7jOl00003ofbNkP05o`00
0?n=[^coSJk/ohf^k?l000001?nV^>H00ol0003o^;oOokRog`02okRog`03o`000?o5`]SoaL;H00?o
aL;H0_l00008omC@eP03o`000?oKf]Kofm[F00Cofm[F00?o0000on7MdOoQgM400_l00003omkTf@05
o`000?oSgm3ohNGGon7Ueol000000_oLk=d00ol0003oe?;UomCbi@02o`0000;of^;L00?o0000omKV
h_o@jNL01Ol00002ok?[m`co000000?o[L;Yo`000?l000000_l00002ojO0j`Go0000Joooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000??ooool01?l0003o
5V[MoaIZgOl00002od>7j@05o`000?m/W^koK9k^ofbNk_l000000on=[^`00ol0003oY[SVojJhiP02
ojJhiP03o`000?nh_moo^;oO00;o^;oO00?o0000olG2f?o5`]P00_l00003ol_Bg`;o00001?oDd=H0
0ol0003ofm[Fom_JeP05om_JeP?o00001?oNi=T2o`000004on7Ueol0003o0000omc/g@;o000000Wo
e?;Uo`000?l0003ob?O[o`000?oJh]coe^KRo`000?o@jNL00_l000000onnk??o0000ok?[m`0@o`00
0003ojO0jol0003o000000?o0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo001<ooooo`03o`000?oooooooooo03[ooooo00?o0000oaIZgOl000000om3QnT01Ol0003o
K9k^ofbNk_m/W^ko000000?oSJk/00Go0000ojJhi_nV^>KoY[SVo`000004okRog`03o`000?o5`]So
000000Oobm;O0_l000000ooDd=Ko0000om_JeP02om_JePGo00001OoNi=T2o`000004omO[h_l0003o
0000omc/g@;o000000?oe?;Uo`000?l000000_o8mn/2o`000005omKVh_o@jNOod>WWo`000?nnk?<0
5Ol0001fooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001=ooooo`03o`000?oo
oooooooo03[ooooo0ol00003od>7j@04o`000?m/W^koK9k^o`0000?oSJk/00?o0000ojJhi_nV^>H0
0_nV^>H01?l0003o^;oOokRogonh_ml2o`0000[obm;O1Ol00004omCOh003o`000?oNi=Wog^CI00?o
00000_oGjn801Ol0003og>cMomc/gOl0003oe?;U00;o00000_o8mn/4o`000003om3Yiol0003o_^cc
00oo0000Ooooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00C_ooool00ol0003o
ooooooooo`0kooooo`;o00000_m3QnT01Ol0003oK9k^ofbNk_m/W^ko000000?oSJk/00Ko0000ojJh
i_nV^>KoY[SVo`000?nh_ml2o`0000?o_M?[0ol00005ol_Bg`03o`000?oDgn3oe=oP00Koe=oP00Co
0000omkTfOoNi=Wo00000ooGjn82o`000006omc/gOl0003oe?;UomCbiOl0003ob?O[1ol000000onn
k??o0000o`000002o`0008cooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004oo
oooo0_l0000mooooo`Co00000om/W^h01?l0003oSJk/ohf^k?l00002ojJhiP?o00002?nmdn/3o`00
0003ol_Bgol0003oe=oP00Soe=oP0_l00002omO[hP?o000000Cobo;/o`000?l0003oe?;U1?l00000
0ondn>ko0000o`000004o`0009;ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0
057ooooo00?o0000ooooooooool0>oooool00ol0003o2HKQo`000009o`0000CoYm7f0_l00008okgC
j`03o`000?oDgn3o000000So00000_oGjn82o`0000;obo;/0_l00002omCbi@?o000000?o]?S^o`00
0?l000000_l0002Gooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001Booooo`03
o`000?oooooooooo03cooooo00?o0000o`V6hOl9Q^401?m=[oT3oh?7o@03o`000?nWdOKoYm7f00?o
Ym7f0ol00004okgCj`03o`000?o9iN_obNG[00OobNG[00Go0000omO[h_l0003o0000ol_bk003o`00
0003okCel_l0003o000000Go0000W?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1oooo
o`00Doooool2o`0003kooooo00Co0000o`V6hOl9Q^7o00000om=[oT00ol0003oPlOmoh?7o@02o`00
00GoYm7f0_l000000onmdn_o0000olWUj`08olWUj`04o`000?oGjn;o0000ol_bk0;o000000Ko]?Gb
o`000?l0003o0000olSgjondn>h2o`0009oooooo00?o0000ooooooooool01?ooool1o`00007ooooo
0Oooool005Gooooo00?o0000ooooooooool0??ooool2o`000003o`V6hOl0003o000000?oCJoi00?o
0000oh?7oOn3aod00_l00005ojOAmP03o`000?o9iN_o000000So00000_o;l^`00ol0003o]?Gbo`00
0004o`000003okChk_l0003ooooo0:;ooooo00?o0000ooooooooool01?ooool1o`00007ooooo001F
ooooo`03o`000?oooooooooo03gooooo0_l000000ol9Q^7o0000o`000002odf_n@;o00000_n3aod2
o`000003ojOAm_l0003o]>Sg00Wo]>Sg00?o0000ol_bk?l000001ol0002Wooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`00Eoooool00ol0003oooooooooo`0oooooo`03o`000?l9Q^7o0000
00;oCJoi1_l00002okCXm`Wo000000?o]?Gbo`000?l000000ol0002/ooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00F?ooool2o`0004;ooooo5?l0002aooooo`03o`000?oooooooooo00;o
oooo0Ol00001ooooo`00F_ooool00ol0003oooooooooo`16ooooo`Wo0000]_ooool01Ol0003ooooo
oooooooooooo0000007ooooo001Kooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
_Oooool01?l0003oooooooooool00001ooooo`00G?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo0;kooooo00?o0000ooooool000000Oooool005gooooo0_l00014ooooo`03o`000?oo
oooooooo0;kooooo00?o0000ooooooooool00Ol0000005oooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`2oooooo`7o00000Oooool1o`000000H?ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo0<3ooooo0_l00000067ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`2oooooo`?o0000001Rooooo`;o0000?oooool00ol0003oooooooooo`2kooooo`Co0000
0oooool006Cooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`Co00001ooo
ool006Gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2cooooo`Co00002oooool0
06Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2`ooooo`?o00003oooool006Oo
oooo0_l0000jooooo`03o`000?oooooooooo0:cooooo1?l0000Booooo`00JOooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0000Fooooo`00J_ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000Jooooo`00Joooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo0:7ooooo1?l0000Nooooo`00K?ooool2o`0003Cooooo00?o0000oooo
ooooool0WOooool4o`0002;ooooo001^ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0VOooool4o`0002Kooooo001_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool00ol0003oooooooooo`2Aooooo`Co0000;_oo
ool007;ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2>ooooo`?o0000<_ooool0
07?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2:ooooo`Co0000=Oooool007Co
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000>Oooool007Gooooo
0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0000mooooo`00Moooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo07kooooo1?l00011ooooo`00N?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo07[ooooo1?l00015ooooo`00NOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo07Kooooo1?l00019ooooo`00N_ooool2o`0002Kooooo00?o0000oooooooo
ool0L_ooool4o`0004gooooo001looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
Koooool3o`00057ooooo001mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Jooo
ool4o`0005Cooooo001nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4
o`0005Sooooo001oooooo`;o00008Oooool00ol0003oooooooooo`1Sooooo`Co0000G?ooool0087o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Oooooo`Co0000H?ooool008;ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Kooooo`Co0000I?ooool008?ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1Gooooo`Co0000J?ooool008Cooooo0_l0000L
ooooo`03o`000?oooooooooo05?ooooo1?l0001/ooooo`00Q_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo04oooooo1?l0001`ooooo`00Qoooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04cooooo0ol0001dooooo`00R?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Sooooo1?l0001gooooo`00ROooool2o`0001Oooooo00?o0000ooooooooool0A?oo
ool4o`0007_ooooo002;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4
o`0007oooooo002<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool4o`00
08?ooooo002=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool4o`0008Oo
oooo002>ooooo`;o00004_ooool00ol0003oooooooooo`0dooooo`Co0000Roooool0093ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0aooooo`Co0000Soooool0097ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`?o0000Toooool009;ooooo0_l0000=oooo
o`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00U?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01kooooo1?l0002Rooooo`00Uoooool2o`0000Sooooo00?o0000ooooooooool06_ooool4
o`000:Kooooo002Iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`00
0:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:ko
oooo002Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;;ooooo
002Looooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000]_ooool009kooooo00Co0000
oooooooooooo00002Oooool4o`000;Wooooo002Oooooo`03o`000?oooooo000000Gooooo1?l0002m
ooooo`00X?ooool2o`000003ooooool0003o000000;o0000`Oooool00:7ooooo0_l00035ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886655, -0.0135833, \
0.0036241, 0.0036241}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51724 .6546 m .51694 .65827 L .43899 .65168 L p .508 .797 .998 r
F P
0 g
s
.51694 .65827 m .51724 .6546 L .59261 .64665 L p .667 .732 .898 r
F P
0 g
s
.59261 .64665 m .59527 .65394 L .51694 .65827 L p .667 .732 .898 r
F P
0 g
s
.59527 .65394 m .59261 .64665 L .66453 .62829 L p .664 .641 .818 r
F P
0 g
s
.66453 .62829 m .67023 .63881 L .59527 .65394 L p .664 .641 .818 r
F P
0 g
s
.44208 .65182 m .51724 .6546 L p .43994 .65172 L .508 .797 .998 r
F P
0 g
s
.43899 .65168 m .44208 .65182 L p .43994 .65172 L .508 .797 .998 r
F P
0 g
s
.44208 .65182 m .43899 .65168 L .36521 .63435 L p 0 .514 .781 r
F P
0 g
s
.51754 .65096 m .51724 .6546 L .44208 .65182 L p .529 .82 .999 r
F P
0 g
s
.36521 .63435 m .37086 .63827 L .44208 .65182 L p 0 .514 .781 r
F P
0 g
s
.44208 .65182 m .44521 .6521 L .51754 .65096 L p .529 .82 .999 r
F P
0 g
s
.44208 .65182 m .37086 .63827 L p .44429 .65193 L 0 .506 .746 r
F P
0 g
s
.44521 .6521 m .44208 .65182 L p .44429 .65193 L 0 .506 .746 r
F P
0 g
s
.51724 .6546 m .51754 .65096 L .58993 .63928 L p .686 .742 .894 r
F P
0 g
s
.58993 .63928 m .59261 .64665 L .51724 .6546 L p .686 .742 .894 r
F P
0 g
s
.59261 .64665 m .58993 .63928 L .65879 .61763 L p .676 .645 .812 r
F P
0 g
s
.65879 .61763 m .66453 .62829 L .59261 .64665 L p .676 .645 .812 r
F P
0 g
s
.51785 .64727 m .51754 .65096 L .44521 .6521 L p .558 .843 .998 r
F P
0 g
s
.51754 .65096 m .51785 .64727 L .58723 .63185 L p .705 .753 .889 r
F P
0 g
s
.58723 .63185 m .58993 .63928 L .51754 .65096 L p .705 .753 .889 r
F P
0 g
s
.58993 .63928 m .58723 .63185 L .65303 .60692 L p .69 .651 .807 r
F P
0 g
s
.65303 .60692 m .65879 .61763 L .58993 .63928 L p .69 .651 .807 r
F P
0 g
s
.67023 .63881 m .66453 .62829 L .72929 .60021 L p .622 .572 .777 r
F P
0 g
s
.72929 .60021 m .73799 .61332 L .67023 .63881 L p .622 .572 .777 r
F P
0 g
s
.58451 .62439 m .58723 .63185 L .51785 .64727 L p .726 .765 .884 r
F P
0 g
s
.58723 .63185 m .58451 .62439 L .64724 .59626 L p .704 .659 .803 r
F P
0 g
s
.64724 .59626 m .65303 .60692 L .58723 .63185 L p .704 .659 .803 r
F P
0 g
s
.66453 .62829 m .65879 .61763 L .72056 .58692 L p .631 .574 .772 r
F P
0 g
s
.72056 .58692 m .72929 .60021 L .66453 .62829 L p .631 .574 .772 r
F P
0 g
s
.37086 .63827 m .36521 .63435 L .29943 .6068 L p .475 0 0 r
F P
0 g
s
.44521 .6521 m .44837 .65237 L .51785 .64727 L p .558 .843 .998 r
F P
0 g
s
.51816 .64348 m .51785 .64727 L .44837 .65237 L p .593 .867 .994 r
F P
0 g
s
.51785 .64727 m .51816 .64348 L .58451 .62439 L p .726 .765 .884 r
F P
0 g
s
.37086 .63827 m .37658 .64245 L .44521 .6521 L p 0 .506 .746 r
F P
0 g
s
.44837 .65237 m .44521 .6521 L .37658 .64245 L p 0 .517 .728 r
F P
0 g
s
.65879 .61763 m .65303 .60692 L .71182 .57361 L p .642 .577 .767 r
F P
0 g
s
.71182 .57361 m .72056 .58692 L .65879 .61763 L p .642 .577 .767 r
F P
0 g
s
.58177 .61689 m .58451 .62439 L .51816 .64348 L p .746 .776 .878 r
F P
0 g
s
.58451 .62439 m .58177 .61689 L .64143 .58574 L p .718 .668 .799 r
F P
0 g
s
.64143 .58574 m .64724 .59626 L .58451 .62439 L p .718 .668 .799 r
F P
0 g
s
.65303 .60692 m .64724 .59626 L .70307 .56046 L p .653 .583 .764 r
F P
0 g
s
.70307 .56046 m .71182 .57361 L .65303 .60692 L p .653 .583 .764 r
F P
0 g
s
.44837 .65237 m .45157 .65249 L .51816 .64348 L p .593 .867 .994 r
F P
0 g
s
.51847 .63951 m .51816 .64348 L .45157 .65249 L p .632 .889 .987 r
F P
0 g
s
.51816 .64348 m .51847 .63951 L .58177 .61689 L p .746 .776 .878 r
F P
0 g
s
.29943 .6068 m .30738 .61428 L .37086 .63827 L p .475 0 0 r
F P
0 g
s
.37658 .64245 m .37086 .63827 L .30738 .61428 L p .502 0 0 r
F P
0 g
s
.64724 .59626 m .64143 .58574 L .69433 .54763 L p .666 .592 .763 r
F P
0 g
s
.69433 .54763 m .70307 .56046 L .64724 .59626 L p .666 .592 .763 r
F P
0 g
s
.37658 .64245 m .38238 .64667 L .44837 .65237 L p 0 .517 .728 r
F P
0 g
s
.45157 .65249 m .44837 .65237 L .38606 .64699 L p 0 .548 .729 r
F P
0 g
s
.45157 .65249 m .38606 .64699 L .3894 .64726 L 0 .548 .729 r
F
.45157 .65249 m .45482 .65233 L .51847 .63951 L p .632 .889 .987 r
F P
0 g
s
.38606 .64699 m .38238 .64667 L p .3894 .64726 L 0 .548 .729 r
F P
0 g
s
.38238 .64667 m .38827 .65073 L .45157 .65249 L p 0 .548 .729 r
F P
0 g
s
.45482 .65233 m .45157 .65249 L .39343 .65087 L p .028 .599 .747 r
F P
0 g
s
.39343 .65087 m .38827 .65073 L p .39777 .65095 L .028 .599 .747 r
F P
0 g
s
.45482 .65233 m .39343 .65087 L .39777 .65095 L .028 .599 .747 r
F
.38827 .65073 m .39425 .65439 L .45236 .65241 L p F P
0 g
s
.45236 .65241 m .45482 .65233 L p .44987 .65221 L .028 .599 .747 r
F P
0 g
s
.44987 .65221 m .38827 .65073 L .45236 .65241 L .028 .599 .747 r
F
.51879 .6353 m .51847 .63951 L .45482 .65233 L p .674 .909 .976 r
F P
0 g
s
.45482 .65233 m .45812 .65171 L .51879 .6353 L p .674 .909 .976 r
F P
0 g
s
.45812 .65171 m .45482 .65233 L .40074 .65417 L p .115 .667 .781 r
F P
0 g
s
.40074 .65417 m .39425 .65439 L p .4058 .65391 L .115 .667 .781 r
F P
0 g
s
.45812 .65171 m .40074 .65417 L .4058 .65391 L .115 .667 .781 r
F
.39425 .65439 m .40033 .65745 L .45466 .65206 L p F P
0 g
s
.45466 .65206 m .45812 .65171 L p .45142 .65199 L .115 .667 .781 r
F P
0 g
s
.45142 .65199 m .39425 .65439 L .45466 .65206 L .115 .667 .781 r
F
.46147 .65052 m .45812 .65171 L .40802 .65669 L p .225 .746 .823 r
F P
0 g
s
.40802 .65669 m .40033 .65745 L p .41358 .65595 L .225 .746 .823 r
F P
0 g
s
.46147 .65052 m .40802 .65669 L .41358 .65595 L .225 .746 .823 r
F
.40033 .65745 m .40653 .65968 L .45712 .65124 L p F P
0 g
s
.45334 .65144 m .40033 .65745 L .45712 .65124 L .225 .746 .823 r
F
.45712 .65124 m .46147 .65052 L p .45334 .65144 L F P
0 g
s
.46487 .6486 m .46147 .65052 L .41529 .65821 L p .35 .826 .865 r
F P
0 g
s
.41529 .65821 m .40653 .65968 L p .42117 .6569 L .35 .826 .865 r
F P
0 g
s
.46487 .6486 m .41529 .65821 L .42117 .6569 L .35 .826 .865 r
F
.40653 .65968 m .41284 .66087 L .45973 .64981 L p F P
0 g
s
.45557 .65036 m .40653 .65968 L .45973 .64981 L .35 .826 .865 r
F
.45973 .64981 m .46487 .6486 L p .45557 .65036 L F P
0 g
s
.46833 .64583 m .46487 .6486 L .42258 .65857 L p .478 .895 .898 r
F P
0 g
s
.42258 .65857 m .41284 .66087 L p .4286 .6566 L .478 .895 .898 r
F P
0 g
s
.46833 .64583 m .42258 .65857 L .4286 .6566 L .478 .895 .898 r
F
.41284 .66087 m .41926 .66084 L .46246 .64763 L p F P
0 g
s
.45806 .64861 m .41284 .66087 L .46246 .64763 L .478 .895 .898 r
F
.46246 .64763 m .46833 .64583 L p .45806 .64861 L F P
0 g
s
.47184 .64211 m .46833 .64583 L .42988 .65759 L p .596 .946 .914 r
F P
0 g
s
.42988 .65759 m .41926 .66084 L p .43592 .65491 L .596 .946 .914 r
F P
0 g
s
.47184 .64211 m .42988 .65759 L .43592 .65491 L .596 .946 .914 r
F
.41926 .66084 m .42579 .65942 L .46532 .64456 L p F P
0 g
s
.46079 .64605 m .41926 .66084 L .46532 .64456 L .596 .946 .914 r
F
.46532 .64456 m .47184 .64211 L p .46079 .64605 L F P
0 g
s
.4754 .63735 m .47184 .64211 L .43721 .65513 L p .694 .975 .915 r
F P
0 g
s
.43721 .65513 m .42579 .65942 L p .44314 .65171 L .694 .975 .915 r
F P
0 g
s
.4754 .63735 m .43721 .65513 L .44314 .65171 L .694 .975 .915 r
F
.42579 .65942 m .43244 .65648 L .46829 .64051 L p F P
0 g
s
.46374 .64254 m .42579 .65942 L .46829 .64051 L .694 .975 .915 r
F
.43244 .65648 m .43919 .65189 L .47137 .63539 L p .769 .985 .902 r
F P
0 g
s
.47137 .63539 m .479 .63147 L p .46689 .63798 L .769 .985 .902 r
F P
0 g
s
.46689 .63798 m .43244 .65648 L .47137 .63539 L .769 .985 .902 r
F
.46829 .64051 m .4754 .63735 L p .46374 .64254 L .694 .975 .915 r
F P
0 g
s
.579 .60939 m .58177 .61689 L .51847 .63951 L p .766 .788 .871 r
F P
0 g
s
.58177 .61689 m .579 .60939 L .6356 .57546 L p .734 .679 .797 r
F P
0 g
s
.6356 .57546 m .64143 .58574 L .58177 .61689 L p .734 .679 .797 r
F P
0 g
s
.64143 .58574 m .6356 .57546 L .6856 .53529 L p .68 .602 .762 r
F P
0 g
s
.6856 .53529 m .69433 .54763 L .64143 .58574 L p .68 .602 .762 r
F P
0 g
s
.51847 .63951 m .51879 .6353 L .579 .60939 L p .766 .788 .871 r
F P
0 g
s
.57621 .60189 m .579 .60939 L .51879 .6353 L p .786 .8 .864 r
F P
0 g
s
.579 .60939 m .57621 .60189 L .62975 .5655 L p .75 .691 .795 r
F P
0 g
s
.62975 .5655 m .6356 .57546 L .579 .60939 L p .75 .691 .795 r
F P
0 g
s
.6356 .57546 m .62975 .5655 L .67688 .52357 L p .695 .615 .762 r
F P
0 g
s
.67688 .52357 m .6856 .53529 L .6356 .57546 L p .695 .615 .762 r
F P
0 g
s
.73799 .61332 m .72929 .60021 L .78317 .56346 L p .563 .517 .762 r
F P
0 g
s
.78317 .56346 m .79464 .57831 L .73799 .61332 L p .563 .517 .762 r
F P
0 g
s
.30738 .61428 m .31543 .62213 L .37658 .64245 L p .502 0 0 r
F P
0 g
s
.38238 .64667 m .37658 .64245 L .31543 .62213 L p .507 0 0 r
F P
0 g
s
.72929 .60021 m .72056 .58692 L .7717 .54841 L p .57 .517 .756 r
F P
0 g
s
.7717 .54841 m .78317 .56346 L .72929 .60021 L p .57 .517 .756 r
F P
0 g
s
.72056 .58692 m .71182 .57361 L .76025 .53341 L p .578 .519 .753 r
F P
0 g
s
.76025 .53341 m .7717 .54841 L .72056 .58692 L p .578 .519 .753 r
F P
0 g
s
.62388 .55594 m .62975 .5655 L .57621 .60189 L p .767 .704 .793 r
F P
0 g
s
.62975 .5655 m .62388 .55594 L .66817 .51263 L p .712 .629 .763 r
F P
0 g
s
.66817 .51263 m .67688 .52357 L .62975 .5655 L p .712 .629 .763 r
F P
0 g
s
.71182 .57361 m .70307 .56046 L .74884 .51867 L p .589 .525 .751 r
F P
0 g
s
.74884 .51867 m .76025 .53341 L .71182 .57361 L p .589 .525 .751 r
F P
0 g
s
.51879 .6353 m .51911 .63079 L .57621 .60189 L p .786 .8 .864 r
F P
0 g
s
.57341 .5944 m .57621 .60189 L .51911 .63079 L p .805 .811 .855 r
F P
0 g
s
.57621 .60189 m .57341 .5944 L .62388 .55594 L p .767 .704 .793 r
F P
0 g
s
.51911 .63079 m .51879 .6353 L .45812 .65171 L p .715 .924 .962 r
F P
0 g
s
.70307 .56046 m .69433 .54763 L .73748 .50444 L p .601 .533 .75 r
F P
0 g
s
.73748 .50444 m .74884 .51867 L .70307 .56046 L p .601 .533 .75 r
F P
0 g
s
.30738 .61428 m .29943 .6068 L .24558 .56996 L p .588 .036 0 r
F P
0 g
s
.69433 .54763 m .6856 .53529 L .72619 .49091 L p .616 .544 .751 r
F P
0 g
s
.72619 .49091 m .73748 .50444 L .69433 .54763 L p .616 .544 .751 r
F P
0 g
s
.618 .54686 m .62388 .55594 L .57341 .5944 L p .784 .719 .791 r
F P
0 g
s
.62388 .55594 m .618 .54686 L .65947 .50259 L p .73 .646 .765 r
F P
0 g
s
.65947 .50259 m .66817 .51263 L .62388 .55594 L p .73 .646 .765 r
F P
0 g
s
.6856 .53529 m .67688 .52357 L .71496 .4783 L p .632 .558 .752 r
F P
0 g
s
.71496 .4783 m .72619 .49091 L .6856 .53529 L p .632 .558 .752 r
F P
0 g
s
.67688 .52357 m .66817 .51263 L .7038 .46678 L p .651 .574 .755 r
F P
0 g
s
.7038 .46678 m .71496 .4783 L .67688 .52357 L p .651 .574 .755 r
F P
0 g
s
.51911 .63079 m .51943 .62591 L .57341 .5944 L p .805 .811 .855 r
F P
0 g
s
.57058 .58695 m .57341 .5944 L .51943 .62591 L p .823 .821 .847 r
F P
0 g
s
.57341 .5944 m .57058 .58695 L .618 .54686 L p .784 .719 .791 r
F P
0 g
s
.31543 .62213 m .32358 .63007 L .38238 .64667 L p .507 0 0 r
F P
0 g
s
.38827 .65073 m .38238 .64667 L .32358 .63007 L p .491 0 0 r
F P
0 g
s
.61209 .53832 m .618 .54686 L .57058 .58695 L p .801 .734 .79 r
F P
0 g
s
.618 .54686 m .61209 .53832 L .65078 .49354 L p .75 .664 .767 r
F P
0 g
s
.65078 .49354 m .65947 .50259 L .618 .54686 L p .75 .664 .767 r
F P
0 g
s
.45812 .65171 m .46147 .65052 L .51911 .63079 L p .715 .924 .962 r
F P
0 g
s
.51943 .62591 m .51911 .63079 L .46147 .65052 L p .754 .935 .945 r
F P
0 g
s
.66817 .51263 m .65947 .50259 L .6927 .45652 L p .671 .593 .759 r
F P
0 g
s
.6927 .45652 m .7038 .46678 L .66817 .51263 L p .671 .593 .759 r
F P
0 g
s
.65947 .50259 m .65078 .49354 L .68166 .44765 L p .694 .614 .763 r
F P
0 g
s
.68166 .44765 m .6927 .45652 L .65947 .50259 L p .694 .614 .763 r
F P
0 g
s
.51943 .62591 m .51976 .62061 L .57058 .58695 L p .823 .821 .847 r
F P
0 g
s
.56772 .57953 m .57058 .58695 L .51976 .62061 L p .841 .831 .838 r
F P
0 g
s
.57058 .58695 m .56772 .57953 L .61209 .53832 L p .801 .734 .79 r
F P
0 g
s
.25551 .58062 m .30738 .61428 L p .24634 .5705 L .588 .036 0 r
F P
0 g
s
.31543 .62213 m .30738 .61428 L .25551 .58062 L p .617 .064 0 r
F P
0 g
s
.25551 .58062 m .26555 .59172 L .31543 .62213 L p .617 .064 0 r
F P
0 g
s
.24558 .56996 m .25551 .58062 L p .24634 .5705 L .588 .036 0 r
F P
0 g
s
.25551 .58062 m .24558 .56996 L .20758 .52532 L p 0 0 .521 r
F P
0 g
s
.24244 .56628 m .25435 .58 L .2623 .58852 L p 0 0 .496 r
F P
0 g
s
.25551 .58062 m .22093 .54073 L .2285 .54948 L 0 0 .521 r
F
.21936 .53894 m .25551 .58062 L p .2186 .53805 L F P
0 g
s
.25551 .58062 m .22884 .54987 L p .26498 .59108 L 0 0 .493 r
F P
0 g
s
.22884 .54987 m .21936 .53894 L p .23447 .55621 L 0 0 .493 r
F P
0 g
s
.26498 .59108 m .22884 .54987 L .23447 .55621 L 0 0 .493 r
F
.20758 .52532 m .2186 .53805 L p .2285 .54948 L 0 0 .521 r
F P
0 g
s
.22093 .54073 m .20758 .52532 L .2285 .54948 L 0 0 .521 r
F
.26498 .59108 m .21936 .53894 L .21978 .53941 L 0 0 .493 r
F
.26555 .59172 m .25551 .58062 L p .26498 .59108 L F P
0 g
s
.32358 .63007 m .31543 .62213 L .26555 .59172 L p .626 .072 0 r
F P
0 g
s
.26555 .59172 m .27571 .60295 L .32358 .63007 L p .626 .072 0 r
F P
0 g
s
.21936 .53894 m .21909 .53862 L p .21978 .53941 L 0 0 .493 r
F P
0 g
s
.21909 .53862 m .23069 .55237 L .26555 .59172 L p 0 0 .493 r
F P
0 g
s
.27571 .60295 m .26555 .59172 L .25232 .57679 L p 0 0 .484 r
F P
0 g
s
.27571 .60295 m .25232 .57679 L .25693 .58187 L 0 0 .484 r
F
.27571 .60295 m .2376 .56017 L .24354 .56681 L F
.25232 .57679 m .2376 .56017 L p .25693 .58187 L F P
0 g
s
.25577 .58097 m .27546 .60267 L p .24354 .56681 L 0 0 .484 r
F P
0 g
s
.24354 .56681 m .24209 .56518 L .24348 .56678 L 0 0 .484 r
F
.24354 .56681 m .24348 .56678 L .25577 .58097 L F
.27504 .60219 m .24209 .56518 L .27546 .60267 L F
.2376 .56017 m .23069 .55237 L p .24354 .56681 L F P
0 g
s
.24209 .56518 m .23069 .55237 L .25577 .58097 L 0 0 .484 r
F
.33187 .63784 m .32358 .63007 L .27571 .60295 L p .619 .059 0 r
F P
0 g
s
.27571 .60295 m .28604 .614 L .33187 .63784 L p .619 .059 0 r
F P
0 g
s
.27546 .60267 m .27571 .60295 L p .27504 .60219 L 0 0 .484 r
F P
0 g
s
.23069 .55237 m .24244 .56628 L .25577 .58097 L p 0 0 .484 r
F P
0 g
s
.28604 .614 m .27571 .60295 L .27413 .60121 L p 0 0 .496 r
F P
0 g
s
.27413 .60121 m .24244 .56628 L p .27578 .60277 L 0 0 .496 r
F P
0 g
s
.28604 .614 m .27413 .60121 L .27578 .60277 L 0 0 .496 r
F
.2623 .58852 m .27971 .60721 L p .25393 .57886 L F P
0 g
s
.27756 .6048 m .25393 .57886 L .27971 .60721 L 0 0 .496 r
F
.27807 .60528 m .25393 .57886 L .28133 .60894 L F
.25393 .57886 m .24244 .56628 L .2623 .58852 L F
.27971 .60721 m .28133 .60894 L p .27756 .6048 L F P
0 g
s
.28133 .60894 m .28604 .614 L p .27807 .60528 L 0 0 .496 r
F P
0 g
s
.34029 .64515 m .33187 .63784 L .28604 .614 L p .593 .026 0 r
F P
0 g
s
.28604 .614 m .29655 .62455 L .34029 .64515 L p .593 .026 0 r
F P
0 g
s
.29655 .62455 m .28604 .614 L .25435 .58 L p 0 .016 .527 r
F P
0 g
s
.25435 .58 m .26645 .59318 L .28029 .60761 L p 0 .016 .527 r
F P
0 g
s
.27552 .60235 m .25435 .58 L .28029 .60761 L 0 .016 .527 r
F
.26645 .59318 m .27877 .60548 L .2808 .60754 L p 0 .075 .58 r
F P
0 g
s
.34888 .65172 m .34029 .64515 L .29655 .62455 L p .547 0 0 r
F P
0 g
s
.29655 .62455 m .30725 .63426 L .34888 .65172 L p .547 0 0 r
F P
0 g
s
.2808 .60754 m .30725 .63426 L p .27922 .60604 L 0 .075 .58 r
F P
0 g
s
.27922 .60604 m .26645 .59318 L .2808 .60754 L 0 .075 .58 r
F
.28029 .60761 m .29655 .62455 L p .27552 .60235 L 0 .016 .527 r
F P
0 g
s
.2186 .53805 m .21909 .53862 L .21936 .53894 L p 0 0 .521 r
F P
0 g
s
.60616 .53037 m .61209 .53832 L .56772 .57953 L p .819 .75 .788 r
F P
0 g
s
.61209 .53832 m .60616 .53037 L .6421 .48558 L p .77 .684 .768 r
F P
0 g
s
.6421 .48558 m .65078 .49354 L .61209 .53832 L p .77 .684 .768 r
F P
0 g
s
.65078 .49354 m .6421 .48558 L .67067 .44028 L p .718 .638 .767 r
F P
0 g
s
.67067 .44028 m .68166 .44765 L .65078 .49354 L p .718 .638 .767 r
F P
0 g
s
.46147 .65052 m .46487 .6486 L .51943 .62591 L p .754 .935 .945 r
F P
0 g
s
.51976 .62061 m .51943 .62591 L .46487 .6486 L p .789 .941 .926 r
F P
0 g
s
.32358 .63007 m .33187 .63784 L .38827 .65073 L p .491 0 0 r
F P
0 g
s
.39425 .65439 m .38827 .65073 L .33187 .63784 L p .455 0 0 r
F P
0 g
s
.63341 .47877 m .6421 .48558 L .60616 .53037 L p .791 .706 .77 r
F P
0 g
s
.6421 .48558 m .63341 .47877 L .65972 .43451 L p .744 .663 .771 r
F P
0 g
s
.65972 .43451 m .67067 .44028 L .6421 .48558 L p .744 .663 .771 r
F P
0 g
s
.56772 .57953 m .56485 .57217 L .60616 .53037 L p .819 .75 .788 r
F P
0 g
s
.6002 .52305 m .60616 .53037 L .56485 .57217 L p .836 .767 .786 r
F P
0 g
s
.60616 .53037 m .6002 .52305 L .63341 .47877 L p .791 .706 .77 r
F P
0 g
s
.51976 .62061 m .52009 .61485 L .56772 .57953 L p .841 .831 .838 r
F P
0 g
s
.56485 .57217 m .56772 .57953 L .52009 .61485 L p .856 .84 .828 r
F P
0 g
s
.72619 .49091 m .71496 .4783 L .74162 .43211 L p .557 .512 .761 r
F P
0 g
s
.71496 .4783 m .7038 .46678 L .72858 .42089 L p .579 .531 .765 r
F P
0 g
s
.72858 .42089 m .74162 .43211 L .71496 .4783 L p .579 .531 .765 r
F P
0 g
s
.7038 .46678 m .6927 .45652 L .71567 .4112 L p .605 .554 .771 r
F P
0 g
s
.71567 .4112 m .72858 .42089 L .7038 .46678 L p .605 .554 .771 r
F P
0 g
s
.73748 .50444 m .72619 .49091 L .7548 .44468 L p .537 .496 .757 r
F P
0 g
s
.74162 .43211 m .7548 .44468 L .72619 .49091 L p .557 .512 .761 r
F P
0 g
s
.6927 .45652 m .68166 .44765 L .70287 .40321 L p .633 .58 .776 r
F P
0 g
s
.70287 .40321 m .71567 .4112 L .6927 .45652 L p .633 .58 .776 r
F P
0 g
s
.74884 .51867 m .73748 .50444 L .76811 .45838 L p .521 .483 .755 r
F P
0 g
s
.7548 .44468 m .76811 .45838 L .73748 .50444 L p .537 .496 .757 r
F P
0 g
s
.68166 .44765 m .67067 .44028 L .69019 .39703 L p .665 .609 .782 r
F P
0 g
s
.69019 .39703 m .70287 .40321 L .68166 .44765 L p .665 .609 .782 r
F P
0 g
s
.6247 .47315 m .63341 .47877 L .6002 .52305 L p .812 .728 .771 r
F P
0 g
s
.63341 .47877 m .6247 .47315 L .64879 .43037 L p .771 .691 .774 r
F P
0 g
s
.64879 .43037 m .65972 .43451 L .63341 .47877 L p .771 .691 .774 r
F P
0 g
s
.76025 .53341 m .74884 .51867 L .78154 .47298 L p .508 .474 .754 r
F P
0 g
s
.76811 .45838 m .78154 .47298 L .74884 .51867 L p .521 .483 .755 r
F P
0 g
s
.46487 .6486 m .46833 .64583 L .51976 .62061 L p .789 .941 .926 r
F P
0 g
s
.52009 .61485 m .51976 .62061 L .46833 .64583 L p .82 .943 .906 r
F P
0 g
s
.56485 .57217 m .56195 .56486 L .6002 .52305 L p .836 .767 .786 r
F P
0 g
s
.59421 .51638 m .6002 .52305 L .56195 .56486 L p .853 .783 .783 r
F P
0 g
s
.6002 .52305 m .59421 .51638 L .6247 .47315 L p .812 .728 .771 r
F P
0 g
s
.67067 .44028 m .65972 .43451 L .67759 .39277 L p .698 .64 .788 r
F P
0 g
s
.67759 .39277 m .69019 .39703 L .67067 .44028 L p .698 .64 .788 r
F P
0 g
s
.7717 .54841 m .76025 .53341 L .79509 .48824 L p .497 .468 .755 r
F P
0 g
s
.78154 .47298 m .79509 .48824 L .76025 .53341 L p .508 .474 .754 r
F P
0 g
s
.52009 .61485 m .52043 .60858 L .56485 .57217 L p .856 .84 .828 r
F P
0 g
s
.56195 .56486 m .56485 .57217 L .52043 .60858 L p .871 .848 .818 r
F P
0 g
s
.78317 .56346 m .7717 .54841 L .80874 .50386 L p .489 .466 .758 r
F P
0 g
s
.79509 .48824 m .80874 .50386 L .7717 .54841 L p .497 .468 .755 r
F P
0 g
s
.33187 .63784 m .34029 .64515 L .39425 .65439 L p .455 0 0 r
F P
0 g
s
.40033 .65745 m .39425 .65439 L .34029 .64515 L p .394 0 0 r
F P
0 g
s
.65972 .43451 m .64879 .43037 L .66507 .39049 L p .732 .673 .792 r
F P
0 g
s
.66507 .39049 m .67759 .39277 L .65972 .43451 L p .732 .673 .792 r
F P
0 g
s
.61598 .46875 m .6247 .47315 L .59421 .51638 L p .834 .751 .772 r
F P
0 g
s
.6247 .47315 m .61598 .46875 L .63788 .42791 L p .799 .719 .776 r
F P
0 g
s
.63788 .42791 m .64879 .43037 L .6247 .47315 L p .799 .719 .776 r
F P
0 g
s
.79464 .57831 m .78317 .56346 L .82247 .51959 L p .484 .467 .763 r
F P
0 g
s
.80874 .50386 m .82247 .51959 L .78317 .56346 L p .489 .466 .758 r
F P
0 g
s
.82247 .51959 m .83625 .53514 L .79464 .57831 L p .484 .467 .763 r
F P
0 g
s
.56195 .56486 m .55903 .5576 L .59421 .51638 L p .853 .783 .783 r
F P
0 g
s
.58819 .51039 m .59421 .51638 L .55903 .5576 L p .869 .799 .78 r
F P
0 g
s
.59421 .51638 m .58819 .51039 L .61598 .46875 L p .834 .751 .772 r
F P
0 g
s
.64879 .43037 m .63788 .42791 L .65259 .39022 L p .767 .706 .795 r
F P
0 g
s
.65259 .39022 m .66507 .39049 L .64879 .43037 L p .767 .706 .795 r
F P
0 g
s
.46833 .64583 m .47184 .64211 L .52009 .61485 L p .82 .943 .906 r
F P
0 g
s
.52043 .60858 m .52009 .61485 L .47184 .64211 L p .846 .941 .885 r
F P
0 g
s
.52043 .60858 m .52077 .60176 L .56195 .56486 L p .871 .848 .818 r
F P
0 g
s
.55903 .5576 m .56195 .56486 L .52077 .60176 L p .884 .855 .808 r
F P
0 g
s
.60723 .46558 m .61598 .46875 L .58819 .51039 L p .854 .773 .771 r
F P
0 g
s
.61598 .46875 m .60723 .46558 L .62695 .42712 L p .825 .747 .777 r
F P
0 g
s
.62695 .42712 m .63788 .42791 L .61598 .46875 L p .825 .747 .777 r
F P
0 g
s
.63788 .42791 m .62695 .42712 L .64014 .39195 L p .801 .739 .795 r
F P
0 g
s
.64014 .39195 m .65259 .39022 L .63788 .42791 L p .801 .739 .795 r
F P
0 g
s
.55903 .5576 m .55608 .55041 L .58819 .51039 L p .869 .799 .78 r
F P
0 g
s
.58214 .50507 m .58819 .51039 L .55608 .55041 L p .883 .814 .776 r
F P
0 g
s
.58819 .51039 m .58214 .50507 L .60723 .46558 L p .854 .773 .771 r
F P
0 g
s
.34029 .64515 m .34888 .65172 L .40033 .65745 L p .394 0 0 r
F P
0 g
s
.40653 .65968 m .40033 .65745 L .34888 .65172 L p .302 0 0 r
F P
0 g
s
.71567 .4112 m .70287 .40321 L .71292 .36282 L p .563 .563 .811 r
F P
0 g
s
.70287 .40321 m .69019 .39703 L .69929 .35837 L p .606 .6 .819 r
F P
0 g
s
.69929 .35837 m .71292 .36282 L .70287 .40321 L p .606 .6 .819 r
F P
0 g
s
.69019 .39703 m .67759 .39277 L .68581 .35604 L p .652 .639 .825 r
F P
0 g
s
.68581 .35604 m .69929 .35837 L .69019 .39703 L p .652 .639 .825 r
F P
0 g
s
.72858 .42089 m .71567 .4112 L .72671 .36928 L p .524 .529 .802 r
F P
0 g
s
.71292 .36282 m .72671 .36928 L .71567 .4112 L p .563 .563 .811 r
F P
0 g
s
.67759 .39277 m .66507 .39049 L .67244 .35588 L p .698 .679 .828 r
F P
0 g
s
.67244 .35588 m .68581 .35604 L .67759 .39277 L p .698 .679 .828 r
F P
0 g
s
.47184 .64211 m .4754 .63735 L .52043 .60858 L p .846 .941 .885 r
F P
0 g
s
.52077 .60176 m .52043 .60858 L .4754 .63735 L p .868 .938 .864 r
F P
0 g
s
.52077 .60176 m .52111 .59439 L .55903 .5576 L p .884 .855 .808 r
F P
0 g
s
.55608 .55041 m .55903 .5576 L .52111 .59439 L p .896 .861 .798 r
F P
0 g
s
.74162 .43211 m .72858 .42089 L .74068 .37761 L p .489 .499 .794 r
F P
0 g
s
.72671 .36928 m .74068 .37761 L .72858 .42089 L p .524 .529 .802 r
F P
0 g
s
.59843 .46359 m .60723 .46558 L .58214 .50507 L p .873 .795 .77 r
F P
0 g
s
.60723 .46558 m .59843 .46359 L .61599 .42797 L p .851 .774 .776 r
F P
0 g
s
.61599 .42797 m .62695 .42712 L .60723 .46558 L p .851 .774 .776 r
F P
0 g
s
.66507 .39049 m .65259 .39022 L .65916 .35793 L p .743 .718 .828 r
F P
0 g
s
.65916 .35793 m .67244 .35588 L .66507 .39049 L p .743 .718 .828 r
F P
0 g
s
.62695 .42712 m .61599 .42797 L .62769 .39565 L p .833 .77 .792 r
F P
0 g
s
.62769 .39565 m .64014 .39195 L .62695 .42712 L p .833 .77 .792 r
F P
0 g
s
.7548 .44468 m .74162 .43211 L .75484 .38765 L p .459 .473 .786 r
F P
0 g
s
.74068 .37761 m .75484 .38765 L .74162 .43211 L p .489 .499 .794 r
F P
0 g
s
.65259 .39022 m .64014 .39195 L .64594 .36218 L p .785 .754 .825 r
F P
0 g
s
.64594 .36218 m .65916 .35793 L .65259 .39022 L p .785 .754 .825 r
F P
0 g
s
.55608 .55041 m .55311 .54328 L .58214 .50507 L p .883 .814 .776 r
F P
0 g
s
.57604 .5004 m .58214 .50507 L .55311 .54328 L p .897 .828 .771 r
F P
0 g
s
.58214 .50507 m .57604 .5004 L .59843 .46359 L p .873 .795 .77 r
F P
0 g
s
.76811 .45838 m .7548 .44468 L .76919 .3992 L p .433 .452 .78 r
F P
0 g
s
.75484 .38765 m .76919 .3992 L .7548 .44468 L p .459 .473 .786 r
F P
0 g
s
.52111 .59439 m .52146 .58644 L .55608 .55041 L p .896 .861 .798 r
F P
0 g
s
.55311 .54328 m .55608 .55041 L .52146 .58644 L p .906 .866 .789 r
F P
0 g
s
.4754 .63735 m .479 .63147 L .52077 .60176 L p .868 .938 .864 r
F P
0 g
s
.52111 .59439 m .52077 .60176 L .479 .63147 L p .885 .932 .845 r
F P
0 g
s
.58957 .46275 m .59843 .46359 L .57604 .5004 L p .891 .815 .766 r
F P
0 g
s
.59843 .46359 m .58957 .46275 L .60499 .4304 L p .874 .799 .773 r
F P
0 g
s
.60499 .4304 m .61599 .42797 L .59843 .46359 L p .874 .799 .773 r
F P
0 g
s
.34888 .65172 m .35763 .65727 L .40653 .65968 L p .302 0 0 r
F P
0 g
s
.37566 .66427 m .38493 .66525 L .40545 .66233 L p .202 .73 .808 r
F P
0 g
s
.41284 .66087 m .40653 .65968 L .38415 .65857 L p .172 0 0 r
F P
0 g
s
.41284 .66087 m .38415 .65857 L .38798 .65925 L .172 0 0 r
F
.35763 .65727 m .36656 .66153 L .41284 .66087 L p F P
0 g
s
.41926 .66084 m .41284 .66087 L .38034 .66133 L p 0 0 0 r
F P
0 g
s
.38034 .66133 m .36656 .66153 L p .38699 .66126 L 0 0 0 r
F P
0 g
s
.41926 .66084 m .38034 .66133 L .38699 .66126 L 0 0 0 r
F
.36656 .66153 m .37566 .66427 L .41926 .66084 L p F P
0 g
s
.42579 .65942 m .41926 .66084 L .39066 .66309 L p .202 .73 .808 r
F P
0 g
s
.39066 .66309 m .37566 .66427 L p .39698 .66221 L .202 .73 .808 r
F P
0 g
s
.42579 .65942 m .39066 .66309 L .39698 .66221 L .202 .73 .808 r
F
.40545 .66233 m .41497 .66097 L p .40201 .66172 L F P
0 g
s
.41497 .66097 m .42579 .65942 L p .40917 .66103 L .202 .73 .808 r
F P
0 g
s
.40917 .66103 m .40201 .66172 L .41497 .66097 L .202 .73 .808 r
F
.40201 .66172 m .37566 .66427 L .40545 .66233 L F
.43244 .65648 m .42579 .65942 L .40103 .66296 L p .407 .858 .888 r
F P
0 g
s
.40103 .66296 m .38493 .66525 L p .40686 .6612 L .407 .858 .888 r
F P
0 g
s
.43244 .65648 m .40103 .66296 L .40686 .6612 L .407 .858 .888 r
F
.38493 .66525 m .39437 .66432 L .42065 .65891 L p F P
0 g
s
.41513 .65968 m .38493 .66525 L .42065 .65891 L .407 .858 .888 r
F
.39437 .66432 m .40396 .66132 L .42654 .65528 L p .582 .938 .924 r
F P
0 g
s
.42654 .65528 m .43919 .65189 L p .42142 .65682 L .582 .938 .924 r
F P
0 g
s
.42142 .65682 m .39437 .66432 L .42654 .65528 L .582 .938 .924 r
F
.42065 .65891 m .43244 .65648 L p .41513 .65968 L .407 .858 .888 r
F P
0 g
s
.38415 .65857 m .35763 .65727 L p .38798 .65925 L .172 0 0 r
F P
0 g
s
.61599 .42797 m .60499 .4304 L .61521 .40125 L p .861 .798 .787 r
F P
0 g
s
.61521 .40125 m .62769 .39565 L .61599 .42797 L p .861 .798 .787 r
F P
0 g
s
.64014 .39195 m .62769 .39565 L .63276 .36859 L p .824 .786 .817 r
F P
0 g
s
.63276 .36859 m .64594 .36218 L .64014 .39195 L p .824 .786 .817 r
F P
0 g
s
.78154 .47298 m .76811 .45838 L .78375 .41204 L p .413 .436 .775 r
F P
0 g
s
.76919 .3992 m .78375 .41204 L .76811 .45838 L p .433 .452 .78 r
F P
0 g
s
.55311 .54328 m .55011 .53621 L .57604 .5004 L p .897 .828 .771 r
F P
0 g
s
.56989 .49635 m .57604 .5004 L .55011 .53621 L p .909 .841 .766 r
F P
0 g
s
.57604 .5004 m .56989 .49635 L .58957 .46275 L p .891 .815 .766 r
F P
0 g
s
.79509 .48824 m .78154 .47298 L .79849 .42589 L p .397 .425 .773 r
F P
0 g
s
.78375 .41204 m .79849 .42589 L .78154 .47298 L p .413 .436 .775 r
F P
0 g
s
.62769 .39565 m .61521 .40125 L .61958 .37708 L p .856 .814 .807 r
F P
0 g
s
.61958 .37708 m .63276 .36859 L .62769 .39565 L p .856 .814 .807 r
F P
0 g
s
.52146 .58644 m .52181 .57793 L .55311 .54328 L p .906 .866 .789 r
F P
0 g
s
.55011 .53621 m .55311 .54328 L .52181 .57793 L p .915 .87 .78 r
F P
0 g
s
.479 .63147 m .48266 .62442 L .52111 .59439 L p .885 .932 .845 r
F P
0 g
s
.52146 .58644 m .52111 .59439 L .48266 .62442 L p .9 .926 .826 r
F P
0 g
s
.59392 .43432 m .60499 .4304 L .58957 .46275 L p .894 .822 .769 r
F P
0 g
s
.60499 .4304 m .59392 .43432 L .60268 .40864 L p .886 .822 .78 r
F P
0 g
s
.60268 .40864 m .61521 .40125 L .60499 .4304 L p .886 .822 .78 r
F P
0 g
s
.58065 .46299 m .58957 .46275 L .56989 .49635 L p .906 .833 .762 r
F P
0 g
s
.58957 .46275 m .58065 .46299 L .59392 .43432 L p .894 .822 .769 r
F P
0 g
s
.69929 .35837 m .68581 .35604 L .68357 .32666 L p .608 .673 .886 r
F P
0 g
s
.68581 .35604 m .67244 .35588 L .67022 .32876 L p .672 .72 .885 r
F P
0 g
s
.67022 .32876 m .68357 .32666 L .68581 .35604 L p .672 .72 .885 r
F P
0 g
s
.67244 .35588 m .65916 .35793 L .65698 .33312 L p .731 .762 .877 r
F P
0 g
s
.65698 .33312 m .67022 .32876 L .67244 .35588 L p .731 .762 .877 r
F P
0 g
s
.71292 .36282 m .69929 .35837 L .69708 .32679 L p .543 .623 .881 r
F P
0 g
s
.68357 .32666 m .69708 .32679 L .69929 .35837 L p .608 .673 .886 r
F P
0 g
s
.65916 .35793 m .64594 .36218 L .64384 .33973 L p .782 .797 .864 r
F P
0 g
s
.64384 .33973 m .65698 .33312 L .65916 .35793 L p .782 .797 .864 r
F P
0 g
s
.80874 .50386 m .79509 .48824 L .81341 .4405 L p .386 .418 .772 r
F P
0 g
s
.79849 .42589 m .81341 .4405 L .79509 .48824 L p .397 .425 .773 r
F P
0 g
s
.72671 .36928 m .71292 .36282 L .71077 .32908 L p .479 .572 .871 r
F P
0 g
s
.69708 .32679 m .71077 .32908 L .71292 .36282 L p .543 .623 .881 r
F P
0 g
s
.479 .63147 m .4754 .63735 L .43244 .65648 L p .769 .985 .902 r
F P
0 g
s
.61521 .40125 m .60268 .40864 L .60637 .38753 L p .883 .836 .794 r
F P
0 g
s
.60637 .38753 m .61958 .37708 L .61521 .40125 L p .883 .836 .794 r
F P
0 g
s
.55011 .53621 m .54709 .52919 L .56989 .49635 L p .909 .841 .766 r
F P
0 g
s
.56369 .49289 m .56989 .49635 L .54709 .52919 L p .919 .852 .761 r
F P
0 g
s
.56989 .49635 m .56369 .49289 L .58065 .46299 L p .906 .833 .762 r
F P
0 g
s
.64594 .36218 m .63276 .36859 L .63077 .34853 L p .826 .824 .847 r
F P
0 g
s
.63077 .34853 m .64384 .33973 L .64594 .36218 L p .826 .824 .847 r
F P
0 g
s
.48266 .62442 m .48636 .61619 L .52146 .58644 L p .9 .926 .826 r
F P
0 g
s
.52181 .57793 m .52146 .58644 L .48636 .61619 L p .911 .919 .81 r
F P
0 g
s
.52181 .57793 m .52217 .56885 L .55011 .53621 L p .915 .87 .78 r
F P
0 g
s
.54709 .52919 m .55011 .53621 L .52217 .56885 L p .923 .874 .771 r
F P
0 g
s
.74068 .37761 m .72671 .36928 L .72465 .33343 L p .419 .524 .858 r
F P
0 g
s
.71077 .32908 m .72465 .33343 L .72671 .36928 L p .479 .572 .871 r
F P
0 g
s
.82247 .51959 m .80874 .50386 L .8285 .45557 L p .379 .417 .774 r
F P
0 g
s
.81341 .4405 m .8285 .45557 L .80874 .50386 L p .386 .418 .772 r
F P
0 g
s
.58276 .4396 m .59392 .43432 L .58065 .46299 L p .911 .841 .763 r
F P
0 g
s
.59392 .43432 m .58276 .4396 L .59007 .41767 L p .906 .842 .771 r
F P
0 g
s
.59007 .41767 m .60268 .40864 L .59392 .43432 L p .906 .842 .771 r
F P
0 g
s
.63276 .36859 m .61958 .37708 L .61773 .35946 L p .86 .845 .827 r
F P
0 g
s
.61773 .35946 m .63077 .34853 L .63276 .36859 L p .86 .845 .827 r
F P
0 g
s
.57165 .46421 m .58065 .46299 L .56369 .49289 L p .919 .848 .757 r
F P
0 g
s
.58065 .46299 m .57165 .46421 L .58276 .4396 L p .911 .841 .763 r
F P
0 g
s
.75484 .38765 m .74068 .37761 L .73876 .33972 L p .366 .481 .844 r
F P
0 g
s
.72465 .33343 m .73876 .33972 L .74068 .37761 L p .419 .524 .858 r
F P
0 g
s
.48266 .62442 m .479 .63147 L .43919 .65189 L p .824 .983 .883 r
F P
0 g
s
.35763 .65727 m .34888 .65172 L .30725 .63426 L p .472 0 0 r
F P
0 g
s
.60268 .40864 m .59007 .41767 L .5931 .39979 L p .905 .852 .781 r
F P
0 g
s
.5931 .39979 m .60637 .38753 L .60268 .40864 L p .905 .852 .781 r
F P
0 g
s
.83625 .53514 m .82247 .51959 L .84372 .47078 L p .378 .42 .778 r
F P
0 g
s
.8285 .45557 m .84372 .47078 L .82247 .51959 L p .379 .417 .774 r
F P
0 g
s
.54709 .52919 m .54404 .52221 L .56369 .49289 L p .919 .852 .761 r
F P
0 g
s
.55743 .48996 m .56369 .49289 L .54404 .52221 L p .928 .862 .755 r
F P
0 g
s
.56369 .49289 m .55743 .48996 L .57165 .46421 L p .919 .848 .757 r
F P
0 g
s
.48636 .61619 m .49011 .60677 L .52181 .57793 L p .911 .919 .81 r
F P
0 g
s
.52217 .56885 m .52181 .57793 L .49011 .60677 L p .92 .913 .795 r
F P
0 g
s
.61958 .37708 m .60637 .38753 L .60469 .37238 L p .888 .86 .807 r
F P
0 g
s
.60469 .37238 m .61773 .35946 L .61958 .37708 L p .888 .86 .807 r
F P
0 g
s
.52217 .56885 m .52253 .55922 L .54709 .52919 L p .923 .874 .771 r
F P
0 g
s
.54404 .52221 m .54709 .52919 L .52253 .55922 L p .929 .877 .763 r
F P
0 g
s
.76919 .3992 m .75484 .38765 L .75309 .34776 L p .321 .443 .829 r
F P
0 g
s
.73876 .33972 m .75309 .34776 L .75484 .38765 L p .366 .481 .844 r
F P
0 g
s
.84372 .47078 m .85906 .48583 L .83625 .53514 L p .378 .42 .778 r
F P
0 g
s
.5715 .44611 m .58276 .4396 L .57165 .46421 L p .924 .857 .756 r
F P
0 g
s
.58276 .4396 m .5715 .44611 L .57735 .42819 L p .921 .858 .762 r
F P
0 g
s
.57735 .42819 m .59007 .41767 L .58276 .4396 L p .921 .858 .762 r
F P
0 g
s
.56256 .4663 m .57165 .46421 L .55743 .48996 L p .929 .861 .752 r
F P
0 g
s
.57165 .46421 m .56256 .4663 L .5715 .44611 L p .924 .857 .756 r
F P
0 g
s
.43919 .65189 m .44604 .6456 L .48266 .62442 L p .824 .983 .883 r
F P
0 g
s
.48636 .61619 m .48266 .62442 L .44604 .6456 L p .863 .972 .86 r
F P
0 g
s
.60637 .38753 m .5931 .39979 L .59163 .38714 L p .908 .869 .789 r
F P
0 g
s
.59163 .38714 m .60469 .37238 L .60637 .38753 L p .908 .869 .789 r
F P
0 g
s
.59007 .41767 m .57735 .42819 L .57975 .41368 L p .921 .865 .767 r
F P
0 g
s
.57975 .41368 m .5931 .39979 L .59007 .41767 L p .921 .865 .767 r
F P
0 g
s
.49011 .60677 m .49389 .59619 L .52217 .56885 L p .92 .913 .795 r
F P
0 g
s
.52253 .55922 m .52217 .56885 L .49389 .59619 L p .927 .906 .782 r
F P
0 g
s
.67022 .32876 m .65698 .33312 L .64591 .31758 L p .737 .838 .927 r
F P
0 g
s
.65698 .33312 m .64384 .33973 L .63375 .3262 L p .795 .862 .899 r
F P
0 g
s
.63375 .3262 m .64591 .31758 L .65698 .33312 L p .795 .862 .899 r
F P
0 g
s
.68357 .32666 m .67022 .32876 L .65819 .3111 L p .664 .801 .948 r
F P
0 g
s
.64591 .31758 m .65819 .3111 L .67022 .32876 L p .737 .838 .927 r
F P
0 g
s
.64384 .33973 m .63077 .34853 L .62167 .33692 L p .839 .877 .87 r
F P
0 g
s
.62167 .33692 m .63375 .3262 L .64384 .33973 L p .839 .877 .87 r
F P
0 g
s
.78375 .41204 m .76919 .3992 L .76767 .35737 L p .284 .413 .817 r
F P
0 g
s
.75309 .34776 m .76767 .35737 L .76919 .3992 L p .321 .443 .829 r
F P
0 g
s
.52253 .55922 m .52289 .5491 L .54404 .52221 L p .929 .877 .763 r
F P
0 g
s
.54096 .51526 m .54404 .52221 L .52289 .5491 L p .934 .879 .756 r
F P
0 g
s
.54404 .52221 m .54096 .51526 L .55743 .48996 L p .928 .862 .755 r
F P
0 g
s
.30725 .63426 m .31816 .64282 L .35763 .65727 L p .472 0 0 r
F P
0 g
s
.32929 .64992 m .34063 .65527 L .36081 .66045 L p 0 .391 .686 r
F P
0 g
s
.36656 .66153 m .35763 .65727 L .33528 .64909 L p .359 0 0 r
F P
0 g
s
.36656 .66153 m .33528 .64909 L .3413 .65177 L .359 0 0 r
F
.31816 .64282 m .32929 .64992 L .36656 .66153 L p F P
0 g
s
.37566 .66427 m .36656 .66153 L .34822 .65582 L p 0 .391 .686 r
F P
0 g
s
.34822 .65582 m .32929 .64992 L p .35342 .65738 L 0 .391 .686 r
F P
0 g
s
.37566 .66427 m .34822 .65582 L .35342 .65738 L 0 .391 .686 r
F
.36081 .66045 m .37566 .66427 L p .35506 .65789 L F P
0 g
s
.35506 .65789 m .32929 .64992 L .36081 .66045 L 0 .391 .686 r
F
.38493 .66525 m .37566 .66427 L .36118 .66055 L p .013 .568 .819 r
F P
0 g
s
.36118 .66055 m .34063 .65527 L p .3654 .66085 L .013 .568 .819 r
F P
0 g
s
.38493 .66525 m .36118 .66055 L .3654 .66085 L .013 .568 .819 r
F
.34063 .65527 m .3522 .65863 L .36848 .66192 L p F P
0 g
s
.36351 .66043 m .34063 .65527 L .36848 .66192 L .013 .568 .819 r
F
.3522 .65863 m .36396 .65978 L .37649 .66165 L p .249 .735 .925 r
F P
0 g
s
.37649 .66165 m .39437 .66432 L p .37245 .66136 L .249 .735 .925 r
F P
0 g
s
.37245 .66136 m .3522 .65863 L .37649 .66165 L .249 .735 .925 r
F
.36848 .66192 m .38493 .66525 L p .36351 .66043 L .013 .568 .819 r
F P
0 g
s
.33528 .64909 m .31816 .64282 L p .3413 .65177 L .359 0 0 r
F P
0 g
s
.55111 .48748 m .55743 .48996 L .54096 .51526 L p .935 .87 .75 r
F P
0 g
s
.55743 .48996 m .55111 .48748 L .56256 .4663 L p .929 .861 .752 r
F P
0 g
s
.69708 .32679 m .68357 .32666 L .67061 .30677 L p .578 .752 .96 r
F P
0 g
s
.65819 .3111 m .67061 .30677 L .68357 .32666 L p .664 .801 .948 r
F P
0 g
s
.63077 .34853 m .61773 .35946 L .60964 .34964 L p .872 .884 .841 r
F P
0 g
s
.60964 .34964 m .62167 .33692 L .63077 .34853 L p .872 .884 .841 r
F P
0 g
s
.44604 .6456 m .45298 .63756 L .48636 .61619 L p .863 .972 .86 r
F P
0 g
s
.49011 .60677 m .48636 .61619 L .45298 .63756 L p .89 .959 .837 r
F P
0 g
s
.71077 .32908 m .69708 .32679 L .68319 .30457 L p .482 .692 .96 r
F P
0 g
s
.67061 .30677 m .68319 .30457 L .69708 .32679 L p .578 .752 .96 r
F P
0 g
s
.5931 .39979 m .57975 .41368 L .57851 .40354 L p .923 .876 .772 r
F P
0 g
s
.57851 .40354 m .59163 .38714 L .5931 .39979 L p .923 .876 .772 r
F P
0 g
s
.61773 .35946 m .60469 .37238 L .59765 .36425 L p .897 .888 .814 r
F P
0 g
s
.59765 .36425 m .60964 .34964 L .61773 .35946 L p .897 .888 .814 r
F P
0 g
s
.21909 .53862 m .20758 .52532 L .18911 .47507 L p 0 .154 .696 r
F P
0 g
s
.56011 .45366 m .5715 .44611 L .56256 .4663 L p .934 .868 .749 r
F P
0 g
s
.5715 .44611 m .56011 .45366 L .56452 .43997 L p .933 .869 .753 r
F P
0 g
s
.56452 .43997 m .57735 .42819 L .5715 .44611 L p .933 .869 .753 r
F P
0 g
s
.49389 .59619 m .49771 .58451 L .52253 .55922 L p .927 .906 .782 r
F P
0 g
s
.52289 .5491 m .52253 .55922 L .49771 .58451 L p .933 .901 .771 r
F P
0 g
s
.55337 .46913 m .56256 .4663 L .55111 .48748 L p .937 .871 .747 r
F P
0 g
s
.56256 .4663 m .55337 .46913 L .56011 .45366 L p .934 .868 .749 r
F P
0 g
s
.79849 .42589 m .78375 .41204 L .78249 .36831 L p .256 .39 .807 r
F P
0 g
s
.76767 .35737 m .78249 .36831 L .78375 .41204 L p .284 .413 .817 r
F P
0 g
s
.43919 .65189 m .43244 .65648 L .39437 .66432 L p .582 .938 .924 r
F P
0 g
s
.57735 .42819 m .56452 .43997 L .5663 .42896 L p .933 .874 .756 r
F P
0 g
s
.5663 .42896 m .57975 .41368 L .57735 .42819 L p .933 .874 .756 r
F P
0 g
s
.52289 .5491 m .52325 .5385 L .54096 .51526 L p .934 .879 .756 r
F P
0 g
s
.53785 .50833 m .54096 .51526 L .52325 .5385 L p .939 .881 .75 r
F P
0 g
s
.54096 .51526 m .53785 .50833 L .55111 .48748 L p .935 .87 .75 r
F P
0 g
s
.72465 .33343 m .71077 .32908 L .69596 .30444 L p .383 .623 .947 r
F P
0 g
s
.68319 .30457 m .69596 .30444 L .71077 .32908 L p .482 .692 .96 r
F P
0 g
s
.60469 .37238 m .59163 .38714 L .58566 .38059 L p .915 .889 .792 r
F P
0 g
s
.58566 .38059 m .59765 .36425 L .60469 .37238 L p .915 .889 .792 r
F P
0 g
s
.54472 .48539 m .55111 .48748 L .53785 .50833 L p .94 .876 .745 r
F P
0 g
s
.55111 .48748 m .54472 .48539 L .55337 .46913 L p .937 .871 .747 r
F P
0 g
s
.45298 .63756 m .46 .62779 L .49011 .60677 L p .89 .959 .837 r
F P
0 g
s
.49389 .59619 m .49011 .60677 L .46 .62779 L p .908 .945 .816 r
F P
0 g
s
.49771 .58451 m .50156 .57179 L .52289 .5491 L p .933 .901 .771 r
F P
0 g
s
.52325 .5385 m .52289 .5491 L .50156 .57179 L p .937 .896 .761 r
F P
0 g
s
.57975 .41368 m .5663 .42896 L .56532 .42135 L p .934 .88 .758 r
F P
0 g
s
.56532 .42135 m .57851 .40354 L .57975 .41368 L p .934 .88 .758 r
F P
0 g
s
.81341 .4405 m .79849 .42589 L .79755 .38032 L p .237 .375 .8 r
F P
0 g
s
.78249 .36831 m .79755 .38032 L .79849 .42589 L p .256 .39 .807 r
F P
0 g
s
.59163 .38714 m .57851 .40354 L .57366 .39848 L p .927 .888 .773 r
F P
0 g
s
.57366 .39848 m .58566 .38059 L .59163 .38714 L p .927 .888 .773 r
F P
0 g
s
.73876 .33972 m .72465 .33343 L .70894 .30628 L p .289 .553 .925 r
F P
0 g
s
.69596 .30444 m .70894 .30628 L .72465 .33343 L p .383 .623 .947 r
F P
0 g
s
.18911 .47507 m .20166 .49029 L .21909 .53862 L p 0 .154 .696 r
F P
0 g
s
.23069 .55237 m .21909 .53862 L .20166 .49029 L p 0 .141 .687 r
F P
0 g
s
.30725 .63426 m .29655 .62455 L .26645 .59318 L p 0 .075 .58 r
F P
0 g
s
.44604 .6456 m .43919 .65189 L .40396 .66132 L p .709 .974 .923 r
F P
0 g
s
.5486 .46205 m .56011 .45366 L .55337 .46913 L p .941 .877 .743 r
F P
0 g
s
.56011 .45366 m .5486 .46205 L .55154 .45279 L p .941 .877 .745 r
F P
0 g
s
.55154 .45279 m .56452 .43997 L .56011 .45366 L p .941 .877 .745 r
F P
0 g
s
.52325 .5385 m .52362 .52748 L .53785 .50833 L p .939 .881 .75 r
F P
0 g
s
.53471 .5014 m .53785 .50833 L .52362 .52748 L p .942 .882 .745 r
F P
0 g
s
.53785 .50833 m .53471 .5014 L .54472 .48539 L p .94 .876 .745 r
F P
0 g
s
.46 .62779 m .46709 .61632 L .49389 .59619 L p .908 .945 .816 r
F P
0 g
s
.49771 .58451 m .49389 .59619 L .46709 .61632 L p .921 .931 .798 r
F P
0 g
s
.54407 .47254 m .55337 .46913 L .54472 .48539 L p .943 .878 .742 r
F P
0 g
s
.55337 .46913 m .54407 .47254 L .5486 .46205 L p .941 .877 .743 r
F P
0 g
s
.56452 .43997 m .55154 .45279 L .55272 .44538 L p .941 .879 .746 r
F P
0 g
s
.55272 .44538 m .5663 .42896 L .56452 .43997 L p .941 .879 .746 r
F P
0 g
s
.50156 .57179 m .50543 .55814 L .52325 .5385 L p .937 .896 .761 r
F P
0 g
s
.52362 .52748 m .52325 .5385 L .50543 .55814 L p .941 .892 .753 r
F P
0 g
s
.53826 .48359 m .54472 .48539 L .53471 .5014 L p .944 .88 .741 r
F P
0 g
s
.54472 .48539 m .53826 .48359 L .54407 .47254 L p .943 .878 .742 r
F P
0 g
s
.57851 .40354 m .56532 .42135 L .56161 .41767 L p .936 .887 .758 r
F P
0 g
s
.56161 .41767 m .57366 .39848 L .57851 .40354 L p .936 .887 .758 r
F P
0 g
s
.63375 .3262 m .62167 .33692 L .6058 .33477 L p .86 .923 .869 r
F P
0 g
s
.62167 .33692 m .60964 .34964 L .59566 .34849 L p .888 .918 .838 r
F P
0 g
s
.59566 .34849 m .6058 .33477 L .62167 .33692 L p .888 .918 .838 r
F P
0 g
s
.64591 .31758 m .63375 .3262 L .61601 .32281 L p .82 .924 .905 r
F P
0 g
s
.6058 .33477 m .61601 .32281 L .63375 .3262 L p .86 .923 .869 r
F P
0 g
s
.75309 .34776 m .73876 .33972 L .72215 .30996 L p .205 .488 .898 r
F P
0 g
s
.70894 .30628 m .72215 .30996 L .73876 .33972 L p .289 .553 .925 r
F P
0 g
s
.5663 .42896 m .55272 .44538 L .55203 .44031 L p .941 .882 .747 r
F P
0 g
s
.55203 .44031 m .56532 .42135 L .5663 .42896 L p .941 .882 .747 r
F P
0 g
s
.60964 .34964 m .59765 .36425 L .58557 .36385 L p .908 .911 .811 r
F P
0 g
s
.58557 .36385 m .59566 .34849 L .60964 .34964 L p .908 .911 .811 r
F P
0 g
s
.8285 .45557 m .81341 .4405 L .81284 .39312 L p .227 .367 .797 r
F P
0 g
s
.79755 .38032 m .81284 .39312 L .81341 .4405 L p .237 .375 .8 r
F P
0 g
s
.40396 .66132 m .4137 .65617 L .44604 .6456 L p .709 .974 .923 r
F P
0 g
s
.45298 .63756 m .44604 .6456 L .4137 .65617 L p .795 .98 .902 r
F P
0 g
s
.65819 .3111 m .64591 .31758 L .62631 .31269 L p .763 .917 .94 r
F P
0 g
s
.61601 .32281 m .62631 .31269 L .64591 .31758 L p .82 .924 .905 r
F P
0 g
s
.46709 .61632 m .47424 .60325 L .49771 .58451 L p .921 .931 .798 r
F P
0 g
s
.50156 .57179 m .49771 .58451 L .47424 .60325 L p .93 .919 .782 r
F P
0 g
s
.59765 .36425 m .58566 .38059 L .57551 .38072 L p .922 .904 .788 r
F P
0 g
s
.57551 .38072 m .58557 .36385 L .59765 .36425 L p .922 .904 .788 r
F P
0 g
s
.67061 .30677 m .65819 .3111 L .63672 .30446 L p .687 .897 .973 r
F P
0 g
s
.62631 .31269 m .63672 .30446 L .65819 .3111 L p .763 .917 .94 r
F P
0 g
s
.20166 .49029 m .2143 .50597 L .23069 .55237 L p 0 .141 .687 r
F P
0 g
s
.24244 .56628 m .23069 .55237 L .2143 .50597 L p 0 .144 .689 r
F P
0 g
s
.52362 .52748 m .52399 .5161 L .53471 .5014 L p .942 .882 .745 r
F P
0 g
s
.53154 .49446 m .53471 .5014 L .52399 .5161 L p .945 .883 .741 r
F P
0 g
s
.53471 .5014 m .53154 .49446 L .53826 .48359 L p .944 .88 .741 r
F P
0 g
s
.50543 .55814 m .50933 .54367 L .52362 .52748 L p .941 .892 .753 r
F P
0 g
s
.52399 .5161 m .52362 .52748 L .50933 .54367 L p .944 .888 .747 r
F P
0 g
s
.31816 .64282 m .30725 .63426 L .27877 .60548 L p 0 .159 .653 r
F P
0 g
s
.58566 .38059 m .57366 .39848 L .56545 .39891 L p .932 .897 .77 r
F P
0 g
s
.56545 .39891 m .57551 .38072 L .58566 .38059 L p .932 .897 .77 r
F P
0 g
s
.56532 .42135 m .55203 .44031 L .54952 .43793 L p .942 .885 .747 r
F P
0 g
s
.54952 .43793 m .56161 .41767 L .56532 .42135 L p .942 .885 .747 r
F P
0 g
s
.53693 .47107 m .5486 .46205 L .54407 .47254 L p .946 .882 .739 r
F P
0 g
s
.5486 .46205 m .53693 .47107 L .53841 .46638 L p .946 .882 .739 r
F P
0 g
s
.53841 .46638 m .55154 .45279 L .5486 .46205 L p .946 .882 .739 r
F P
0 g
s
.47424 .60325 m .48143 .5887 L .50156 .57179 L p .93 .919 .782 r
F P
0 g
s
.50543 .55814 m .50156 .57179 L .48143 .5887 L p .936 .908 .769 r
F P
0 g
s
.53465 .47638 m .54407 .47254 L .53826 .48359 L p .946 .882 .738 r
F P
0 g
s
.54407 .47254 m .53465 .47638 L .53693 .47107 L p .946 .882 .739 r
F P
0 g
s
.4137 .65617 m .42356 .64882 L .45298 .63756 L p .795 .98 .902 r
F P
0 g
s
.46 .62779 m .45298 .63756 L .42356 .64882 L p .849 .971 .874 r
F P
0 g
s
.55154 .45279 m .53841 .46638 L .53899 .46265 L p .946 .883 .74 r
F P
0 g
s
.53899 .46265 m .55272 .44538 L .55154 .45279 L p .946 .883 .74 r
F P
0 g
s
.76767 .35737 m .75309 .34776 L .73561 .31533 L p .135 .43 .87 r
F P
0 g
s
.72215 .30996 m .73561 .31533 L .75309 .34776 L p .205 .488 .898 r
F P
0 g
s
.68319 .30457 m .67061 .30677 L .64726 .29812 L p .587 .86 .995 r
F P
0 g
s
.63672 .30446 m .64726 .29812 L .67061 .30677 L p .687 .897 .973 r
F P
0 g
s
.39437 .66432 m .38493 .66525 L .3522 .65863 L p .249 .735 .925 r
F P
0 g
s
.84372 .47078 m .8285 .45557 L .82833 .40641 L p .224 .366 .797 r
F P
0 g
s
.81284 .39312 m .82833 .40641 L .8285 .45557 L p .227 .367 .797 r
F P
0 g
s
.53173 .48198 m .53826 .48359 L .53154 .49446 L p .946 .883 .738 r
F P
0 g
s
.53826 .48359 m .53173 .48198 L .53465 .47638 L p .946 .882 .738 r
F P
0 g
s
.57366 .39848 m .56161 .41767 L .5554 .41823 L p .939 .892 .756 r
F P
0 g
s
.5554 .41823 m .56545 .39891 L .57366 .39848 L p .939 .892 .756 r
F P
0 g
s
.55272 .44538 m .53899 .46265 L .53863 .46012 L p .946 .883 .74 r
F P
0 g
s
.53863 .46012 m .55203 .44031 L .55272 .44538 L p .946 .883 .74 r
F P
0 g
s
.50933 .54367 m .51325 .52852 L .52399 .5161 L p .944 .888 .747 r
F P
0 g
s
.52436 .50443 m .52399 .5161 L .51325 .52852 L p .946 .886 .742 r
F P
0 g
s
.52399 .5161 m .52436 .50443 L .53154 .49446 L p .945 .883 .741 r
F P
0 g
s
.48143 .5887 m .48867 .57281 L .50543 .55814 L p .936 .908 .769 r
F P
0 g
s
.50933 .54367 m .50543 .55814 L .48867 .57281 L p .94 .9 .758 r
F P
0 g
s
.42356 .64882 m .43354 .63929 L .46 .62779 L p .849 .971 .874 r
F P
0 g
s
.46709 .61632 m .46 .62779 L .43354 .63929 L p .884 .956 .845 r
F P
0 g
s
.52834 .48749 m .53154 .49446 L .52436 .50443 L p .947 .884 .738 r
F P
0 g
s
.53154 .49446 m .52834 .48749 L .53173 .48198 L p .946 .883 .738 r
F P
0 g
s
.69596 .30444 m .68319 .30457 L .65796 .29366 L p .467 .8 .999 r
F P
0 g
s
.64726 .29812 m .65796 .29366 L .68319 .30457 L p .587 .86 .995 r
F P
0 g
s
.56161 .41767 m .54952 .43793 L .54533 .43843 L p .944 .888 .746 r
F P
0 g
s
.54533 .43843 m .5554 .41823 L .56161 .41767 L p .944 .888 .746 r
F P
0 g
s
.55203 .44031 m .53863 .46012 L .53735 .45897 L p .946 .884 .74 r
F P
0 g
s
.53735 .45897 m .54952 .43793 L .55203 .44031 L p .946 .884 .74 r
F P
0 g
s
.2143 .50597 m .22705 .52178 L .24244 .56628 L p 0 .144 .689 r
F P
0 g
s
.25435 .58 m .24244 .56628 L .22705 .52178 L p 0 .163 .702 r
F P
0 g
s
.27877 .60548 m .29131 .61656 L .31816 .64282 L p 0 .159 .653 r
F P
0 g
s
.32929 .64992 m .31816 .64282 L .29131 .61656 L p 0 .27 .742 r
F P
0 g
s
.48867 .57281 m .49593 .55577 L .50933 .54367 L p .94 .9 .758 r
F P
0 g
s
.51325 .52852 m .50933 .54367 L .49593 .55577 L p .943 .893 .749 r
F P
0 g
s
.40396 .66132 m .39437 .66432 L .36396 .65978 L p .465 .856 .976 r
F P
0 g
s
.78249 .36831 m .76767 .35737 L .74931 .3222 L p .082 .384 .845 r
F P
0 g
s
.73561 .31533 m .74931 .3222 L .76767 .35737 L p .135 .43 .87 r
F P
0 g
s
.85906 .48583 m .84372 .47078 L .84402 .41986 L p .229 .372 .801 r
F P
0 g
s
.82833 .40641 m .84402 .41986 L .84372 .47078 L p .224 .366 .797 r
F P
0 g
s
.43354 .63929 m .4436 .62765 L .46709 .61632 L p .884 .956 .845 r
F P
0 g
s
.47424 .60325 m .46709 .61632 L .4436 .62765 L p .907 .94 .819 r
F P
0 g
s
.51325 .52852 m .51719 .51283 L .52436 .50443 L p .946 .886 .742 r
F P
0 g
s
.52474 .49253 m .52436 .50443 L .51719 .51283 L p .947 .885 .738 r
F P
0 g
s
.52436 .50443 m .52474 .49253 L .52834 .48749 L p .947 .884 .738 r
F P
0 g
s
.52511 .48046 m .53693 .47107 L .53465 .47638 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .53841 .46638 L .53693 .47107 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .53465 .47638 L .53173 .48198 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .53899 .46265 L .53841 .46638 L closepath p .948 .884 .736 r
F P
0 g
s
.54952 .43793 m .53735 .45897 L .53524 .45927 L p .946 .885 .74 r
F P
0 g
s
.53524 .45927 m .54533 .43843 L .54952 .43793 L p .946 .885 .74 r
F P
0 g
s
.59566 .34849 m .58557 .36385 L .56912 .37142 L p .92 .92 .798 r
F P
0 g
s
.58557 .36385 m .57551 .38072 L .56174 .38766 L p .93 .91 .779 r
F P
0 g
s
.56174 .38766 m .56912 .37142 L .58557 .36385 L p .93 .91 .779 r
F P
0 g
s
.49593 .55577 m .50321 .53779 L .51325 .52852 L p .943 .893 .749 r
F P
0 g
s
.51719 .51283 m .51325 .52852 L .50321 .53779 L p .945 .888 .743 r
F P
0 g
s
.70894 .30628 m .69596 .30444 L .66882 .29103 L p .336 .722 .984 r
F P
0 g
s
.65796 .29366 m .66882 .29103 L .69596 .30444 L p .467 .8 .999 r
F P
0 g
s
.52511 .48046 m .53173 .48198 L .52834 .48749 L closepath p .948 .884 .736 r
F P
0 g
s
.57551 .38072 m .56545 .39891 L .55439 .40492 L p .937 .901 .765 r
F P
0 g
s
.55439 .40492 m .56174 .38766 L .57551 .38072 L p .937 .901 .765 r
F P
0 g
s
.6058 .33477 m .59566 .34849 L .57654 .35635 L p .905 .932 .82 r
F P
0 g
s
.56912 .37142 m .57654 .35635 L .59566 .34849 L p .92 .92 .798 r
F P
0 g
s
.52511 .48046 m .53863 .46012 L .53899 .46265 L closepath p .948 .884 .736 r
F P
0 g
s
.4436 .62765 m .45373 .614 L .47424 .60325 L p .907 .94 .819 r
F P
0 g
s
.48143 .5887 m .47424 .60325 L .45373 .614 L p .921 .925 .797 r
F P
0 g
s
.56545 .39891 m .5554 .41823 L .54706 .42303 L p .941 .894 .753 r
F P
0 g
s
.54706 .42303 m .55439 .40492 L .56545 .39891 L p .941 .894 .753 r
F P
0 g
s
.61601 .32281 m .6058 .33477 L .58401 .34257 L p .884 .944 .847 r
F P
0 g
s
.57654 .35635 m .58401 .34257 L .6058 .33477 L p .905 .932 .82 r
F P
0 g
s
.52511 .48046 m .52834 .48749 L .52474 .49253 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .53735 .45897 L .53863 .46012 L closepath p .948 .884 .736 r
F P
0 g
s
.5554 .41823 m .54533 .43843 L .53974 .4418 L p .945 .889 .745 r
F P
0 g
s
.53974 .4418 m .54706 .42303 L .5554 .41823 L p .945 .889 .745 r
F P
0 g
s
.36396 .65978 m .37591 .65858 L .40396 .66132 L p .465 .856 .976 r
F P
0 g
s
.4137 .65617 m .40396 .66132 L .37591 .65858 L p .63 .922 .976 r
F P
0 g
s
.50321 .53779 m .51051 .51909 L .51719 .51283 L p .945 .888 .743 r
F P
0 g
s
.52114 .49676 m .51719 .51283 L .51051 .51909 L p .947 .885 .739 r
F P
0 g
s
.51719 .51283 m .52114 .49676 L .52474 .49253 L p .947 .885 .738 r
F P
0 g
s
.45373 .614 m .46392 .59851 L .48143 .5887 L p .921 .925 .797 r
F P
0 g
s
.48867 .57281 m .48143 .5887 L .46392 .59851 L p .931 .913 .779 r
F P
0 g
s
.62631 .31269 m .61601 .32281 L .59154 .33018 L p .854 .954 .876 r
F P
0 g
s
.58401 .34257 m .59154 .33018 L .61601 .32281 L p .884 .944 .847 r
F P
0 g
s
.52511 .48046 m .52474 .49253 L .52114 .49676 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .53524 .45927 L .53735 .45897 L closepath p .948 .884 .736 r
F P
0 g
s
.29131 .61656 m .30408 .62608 L .32929 .64992 L p 0 .27 .742 r
F P
0 g
s
.34063 .65527 m .32929 .64992 L .30408 .62608 L p 0 .403 .838 r
F P
0 g
s
.84402 .41986 m .85986 .43317 L .85906 .48583 L p .229 .372 .801 r
F P
0 g
s
.22705 .52178 m .23995 .53739 L .25435 .58 L p 0 .163 .702 r
F P
0 g
s
.26645 .59318 m .25435 .58 L .23995 .53739 L p 0 .197 .725 r
F P
0 g
s
.54533 .43843 m .53524 .45927 L .53242 .46102 L p .947 .885 .739 r
F P
0 g
s
.53242 .46102 m .53974 .4418 L .54533 .43843 L p .947 .885 .739 r
F P
0 g
s
.79755 .38032 m .78249 .36831 L .76327 .33034 L p .045 .35 .826 r
F P
0 g
s
.74931 .3222 m .76327 .33034 L .78249 .36831 L p .082 .384 .845 r
F P
0 g
s
.46392 .59851 m .47413 .58139 L .48867 .57281 L p .931 .913 .779 r
F P
0 g
s
.49593 .55577 m .48867 .57281 L .47413 .58139 L p .937 .903 .764 r
F P
0 g
s
.51051 .51909 m .51781 .4999 L .52114 .49676 L p .947 .885 .739 r
F P
0 g
s
.52511 .48046 m .52114 .49676 L .51781 .4999 L closepath p .948 .884 .736 r
F P
0 g
s
.72215 .30996 m .70894 .30628 L .67987 .29014 L p .205 .633 .95 r
F P
0 g
s
.66882 .29103 m .67987 .29014 L .70894 .30628 L p .336 .722 .984 r
F P
0 g
s
.63672 .30446 m .62631 .31269 L .59915 .31924 L p .811 .96 .908 r
F P
0 g
s
.59154 .33018 m .59915 .31924 L .62631 .31269 L p .854 .954 .876 r
F P
0 g
s
.47413 .58139 m .48435 .56287 L .49593 .55577 L p .937 .903 .764 r
F P
0 g
s
.50321 .53779 m .49593 .55577 L .48435 .56287 L p .942 .895 .753 r
F P
0 g
s
.52511 .48046 m .53242 .46102 L .53524 .45927 L closepath p .948 .884 .736 r
F P
0 g
s
.48435 .56287 m .49457 .54323 L .50321 .53779 L p .942 .895 .753 r
F P
0 g
s
.51051 .51909 m .50321 .53779 L .49457 .54323 L p .945 .889 .745 r
F P
0 g
s
.37591 .65858 m .38804 .65492 L .4137 .65617 L p .63 .922 .976 r
F P
0 g
s
.42356 .64882 m .4137 .65617 L .38804 .65492 L p .742 .946 .947 r
F P
0 g
s
.49457 .54323 m .50478 .52275 L .51051 .51909 L p .945 .889 .745 r
F P
0 g
s
.51781 .4999 m .51051 .51909 L .50478 .52275 L p .947 .885 .739 r
F P
0 g
s
.50478 .52275 m .51496 .50172 L .51781 .4999 L p .947 .885 .739 r
F P
0 g
s
.52511 .48046 m .51781 .4999 L .51496 .50172 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .5291 .4641 L .53242 .46102 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .52549 .46832 L .5291 .4641 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .52185 .47337 L .52549 .46832 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51842 .47893 L .52185 .47337 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51545 .4846 L .51842 .47893 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51314 .48999 L .51545 .4846 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51164 .49473 L .51314 .48999 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51108 .49848 L .51164 .49473 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51147 .501 L .51108 .49848 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .5128 .5021 L .51147 .501 L closepath p .948 .884 .736 r
F P
0 g
s
.52511 .48046 m .51496 .50172 L .5128 .5021 L closepath p .948 .884 .736 r
F P
0 g
s
.53974 .4418 m .53242 .46102 L .5291 .4641 L p .947 .885 .739 r
F P
0 g
s
.54706 .42303 m .53974 .4418 L .5331 .44784 L p .945 .888 .743 r
F P
0 g
s
.5291 .4641 m .5331 .44784 L .53974 .4418 L p .947 .885 .739 r
F P
0 g
s
.64726 .29812 m .63672 .30446 L .60684 .30979 L p .752 .958 .938 r
F P
0 g
s
.59915 .31924 m .60684 .30979 L .63672 .30446 L p .811 .96 .908 r
F P
0 g
s
.55439 .40492 m .54706 .42303 L .53712 .43182 L p .943 .893 .75 r
F P
0 g
s
.5331 .44784 m .53712 .43182 L .54706 .42303 L p .945 .888 .743 r
F P
0 g
s
.50041 .52353 m .5128 .5021 L .51496 .50172 L p .946 .885 .74 r
F P
0 g
s
.51496 .50172 m .50478 .52275 L .50041 .52353 L p .946 .885 .74 r
F P
0 g
s
.56174 .38766 m .55439 .40492 L .54116 .4162 L p .94 .899 .758 r
F P
0 g
s
.53712 .43182 m .54116 .4162 L .55439 .40492 L p .943 .893 .75 r
F P
0 g
s
.38804 .65492 m .40031 .64875 L .42356 .64882 L p .742 .946 .947 r
F P
0 g
s
.43354 .63929 m .42356 .64882 L .40031 .64875 L p .815 .948 .909 r
F P
0 g
s
.30408 .62608 m .31708 .63375 L .34063 .65527 L p 0 .403 .838 r
F P
0 g
s
.3522 .65863 m .34063 .65527 L .31708 .63375 L p .135 .543 .922 r
F P
0 g
s
.5331 .44784 m .5291 .4641 L .52549 .46832 L p .947 .885 .738 r
F P
0 g
s
.56912 .37142 m .56174 .38766 L .54522 .40111 L p .935 .906 .769 r
F P
0 g
s
.54116 .4162 m .54522 .40111 L .56174 .38766 L p .94 .899 .758 r
F P
0 g
s
.23995 .53739 m .25303 .55245 L .26645 .59318 L p 0 .197 .725 r
F P
0 g
s
.27877 .60548 m .26645 .59318 L .25303 .55245 L p 0 .245 .757 r
F P
0 g
s
.48794 .54441 m .50041 .52353 L .50478 .52275 L p .944 .888 .746 r
F P
0 g
s
.50478 .52275 m .49457 .54323 L .48794 .54441 L p .944 .888 .746 r
F P
0 g
s
.81284 .39312 m .79755 .38032 L .77748 .3395 L p .024 .329 .813 r
F P
0 g
s
.76327 .33034 m .77748 .3395 L .79755 .38032 L p .045 .35 .826 r
F P
0 g
s
.20166 .49029 m .18911 .47507 L .19318 .42214 L p .181 .308 .759 r
F P
0 g
s
.73561 .31533 m .72215 .30996 L .69113 .29088 L p .089 .545 .907 r
F P
0 g
s
.67987 .29014 m .69113 .29088 L .72215 .30996 L p .205 .633 .95 r
F P
0 g
s
.49771 .52136 m .51147 .501 L .5128 .5021 L p .946 .884 .74 r
F P
0 g
s
.5128 .5021 m .50041 .52353 L .49771 .52136 L p .946 .884 .74 r
F P
0 g
s
.52549 .46832 m .52588 .45616 L .5331 .44784 L p .947 .885 .738 r
F P
0 g
s
.52588 .45616 m .52549 .46832 L .52185 .47337 L p .947 .884 .738 r
F P
0 g
s
.40031 .64875 m .4127 .6401 L .43354 .63929 L p .815 .948 .909 r
F P
0 g
s
.4436 .62765 m .43354 .63929 L .4127 .6401 L p .861 .94 .871 r
F P
0 g
s
.57654 .35635 m .56912 .37142 L .54931 .38667 L p .929 .916 .783 r
F P
0 g
s
.54522 .40111 m .54931 .38667 L .56912 .37142 L p .935 .906 .769 r
F P
0 g
s
.53712 .43182 m .5331 .44784 L .52588 .45616 L p .946 .886 .742 r
F P
0 g
s
.65796 .29366 m .64726 .29812 L .61463 .30186 L p .671 .943 .962 r
F P
0 g
s
.60684 .30979 m .61463 .30186 L .64726 .29812 L p .752 .958 .938 r
F P
0 g
s
.47543 .56439 m .48794 .54441 L .49457 .54323 L p .939 .893 .756 r
F P
0 g
s
.49457 .54323 m .48435 .56287 L .47543 .56439 L p .939 .893 .756 r
F P
0 g
s
.49688 .51635 m .51108 .49848 L .51147 .501 L p .946 .884 .74 r
F P
0 g
s
.51147 .501 m .49771 .52136 L .49688 .51635 L p .946 .884 .74 r
F P
0 g
s
.52185 .47337 m .51856 .46619 L .52588 .45616 L p .947 .884 .738 r
F P
0 g
s
.51856 .46619 m .52185 .47337 L .51842 .47893 L p .946 .883 .738 r
F P
0 g
s
.4127 .6401 m .42518 .62905 L .4436 .62765 L p .861 .94 .871 r
F P
0 g
s
.45373 .614 m .4436 .62765 L .42518 .62905 L p .891 .929 .838 r
F P
0 g
s
.46287 .58314 m .47543 .56439 L .48435 .56287 L p .933 .899 .77 r
F P
0 g
s
.48435 .56287 m .47413 .58139 L .46287 .58314 L p .933 .899 .77 r
F P
0 g
s
.58401 .34257 m .57654 .35635 L .55343 .37299 L p .919 .926 .799 r
F P
0 g
s
.54931 .38667 m .55343 .37299 L .57654 .35635 L p .929 .916 .783 r
F P
0 g
s
.498 .50885 m .51164 .49473 L .51108 .49848 L p .946 .883 .74 r
F P
0 g
s
.51108 .49848 m .49688 .51635 L .498 .50885 L p .946 .883 .74 r
F P
0 g
s
.42518 .62905 m .43772 .61573 L .45373 .614 L p .891 .929 .838 r
F P
0 g
s
.46392 .59851 m .45373 .614 L .43772 .61573 L p .91 .917 .81 r
F P
0 g
s
.45029 .60035 m .46287 .58314 L .47413 .58139 L p .924 .907 .787 r
F P
0 g
s
.47413 .58139 m .46392 .59851 L .45029 .60035 L p .924 .907 .787 r
F P
0 g
s
.51842 .47893 m .51166 .47727 L .51856 .46619 L p .946 .883 .738 r
F P
0 g
s
.51166 .47727 m .51842 .47893 L .51545 .4846 L p .946 .882 .738 r
F P
0 g
s
.31708 .63375 m .33031 .63931 L .3522 .65863 L p .135 .543 .922 r
F P
0 g
s
.36396 .65978 m .3522 .65863 L .33031 .63931 L p .324 .671 .976 r
F P
0 g
s
.54116 .4162 m .53712 .43182 L .52626 .44405 L p .943 .888 .747 r
F P
0 g
s
.52588 .45616 m .52626 .44405 L .53712 .43182 L p .946 .886 .742 r
F P
0 g
s
.43772 .61573 m .45029 .60035 L .46392 .59851 L p .91 .917 .81 r
F P
0 g
s
.48382 .54118 m .49771 .52136 L .50041 .52353 L p .942 .886 .747 r
F P
0 g
s
.50041 .52353 m .48794 .54441 L .48382 .54118 L p .942 .886 .747 r
F P
0 g
s
.501 .49938 m .51314 .48999 L .51164 .49473 L p .946 .882 .739 r
F P
0 g
s
.51164 .49473 m .498 .50885 L .501 .49938 L p .946 .882 .739 r
F P
0 g
s
.51545 .4846 m .50566 .48859 L .51166 .47727 L p .946 .882 .738 r
F P
0 g
s
.50566 .48859 m .51545 .4846 L .51314 .48999 L p .946 .882 .739 r
F P
0 g
s
.51314 .48999 m .501 .49938 L .50566 .48859 L p .946 .882 .739 r
F P
0 g
s
.52626 .44405 m .52588 .45616 L .51856 .46619 L p .945 .883 .741 r
F P
0 g
s
.59154 .33018 m .58401 .34257 L .55758 .36015 L p .907 .937 .818 r
F P
0 g
s
.55343 .37299 m .55758 .36015 L .58401 .34257 L p .919 .926 .799 r
F P
0 g
s
.19318 .42214 m .20607 .43848 L .20166 .49029 L p .181 .308 .759 r
F P
0 g
s
.2143 .50597 m .20166 .49029 L .20607 .43848 L p .184 .305 .754 r
F P
0 g
s
.25303 .55245 m .2663 .56663 L .27877 .60548 L p 0 .245 .757 r
F P
0 g
s
.29131 .61656 m .27877 .60548 L .2663 .56663 L p .052 .307 .794 r
F P
0 g
s
.66882 .29103 m .65796 .29366 L .62254 .29542 L p .569 .908 .975 r
F P
0 g
s
.61463 .30186 m .62254 .29542 L .65796 .29366 L p .671 .943 .962 r
F P
0 g
s
.54522 .40111 m .54116 .4162 L .52665 .43207 L p .941 .891 .753 r
F P
0 g
s
.52626 .44405 m .52665 .43207 L .54116 .4162 L p .943 .888 .747 r
F P
0 g
s
.74931 .3222 m .73561 .31533 L .7026 .2931 L p 0 .466 .863 r
F P
0 g
s
.69113 .29088 m .7026 .2931 L .73561 .31533 L p .089 .545 .907 r
F P
0 g
s
.82833 .40641 m .81284 .39312 L .79193 .34942 L p .018 .319 .806 r
F P
0 g
s
.77748 .3395 m .79193 .34942 L .81284 .39312 L p .024 .329 .813 r
F P
0 g
s
.48253 .53372 m .49688 .51635 L .49771 .52136 L p .941 .883 .747 r
F P
0 g
s
.49771 .52136 m .48382 .54118 L .48253 .53372 L p .941 .883 .747 r
F P
0 g
s
.46984 .5601 m .48382 .54118 L .48794 .54441 L p .937 .888 .758 r
F P
0 g
s
.48794 .54441 m .47543 .56439 L .46984 .5601 L p .937 .888 .758 r
F P
0 g
s
.33031 .63931 m .34376 .64253 L .36396 .65978 L p .324 .671 .976 r
F P
0 g
s
.37591 .65858 m .36396 .65978 L .34376 .64253 L p .493 .769 .993 r
F P
0 g
s
.51856 .46619 m .51523 .45891 L .52626 .44405 L p .945 .883 .741 r
F P
0 g
s
.51523 .45891 m .51856 .46619 L .51166 .47727 L p .944 .88 .741 r
F P
0 g
s
.59915 .31924 m .59154 .33018 L .56176 .34823 L p .89 .948 .84 r
F P
0 g
s
.55758 .36015 m .56176 .34823 L .59154 .33018 L p .907 .937 .818 r
F P
0 g
s
.54931 .38667 m .54522 .40111 L .52705 .42029 L p .937 .895 .761 r
F P
0 g
s
.52665 .43207 m .52705 .42029 L .54522 .40111 L p .941 .891 .753 r
F P
0 g
s
.52665 .43207 m .52626 .44405 L .51523 .45891 L p .942 .882 .745 r
F P
0 g
s
.48419 .52252 m .498 .50885 L .49688 .51635 L p .941 .88 .746 r
F P
0 g
s
.49688 .51635 m .48253 .53372 L .48419 .52252 L p .941 .88 .746 r
F P
0 g
s
.45577 .57777 m .46984 .5601 L .47543 .56439 L p .928 .89 .772 r
F P
0 g
s
.47543 .56439 m .46287 .58314 L .45577 .57777 L p .928 .89 .772 r
F P
0 g
s
.51166 .47727 m .50481 .47536 L .51523 .45891 L p .944 .88 .741 r
F P
0 g
s
.50481 .47536 m .51166 .47727 L .50566 .48859 L p .943 .878 .742 r
F P
0 g
s
.20607 .43848 m .21902 .45521 L .2143 .50597 L p .184 .305 .754 r
F P
0 g
s
.22705 .52178 m .2143 .50597 L .21902 .45521 L p .198 .311 .754 r
F P
0 g
s
.67987 .29014 m .66882 .29103 L .63058 .29044 L p .45 .853 .97 r
F P
0 g
s
.62254 .29542 m .63058 .29044 L .66882 .29103 L p .569 .908 .975 r
F P
0 g
s
.34376 .64253 m .35739 .64326 L .37591 .65858 L p .493 .769 .993 r
F P
0 g
s
.38804 .65492 m .37591 .65858 L .35739 .64326 L p .627 .833 .98 r
F P
0 g
s
.2663 .56663 m .27978 .57958 L .29131 .61656 L p .052 .307 .794 r
F P
0 g
s
.30408 .62608 m .29131 .61656 L .27978 .57958 L p .145 .381 .833 r
F P
0 g
s
.4887 .50836 m .501 .49938 L .498 .50885 L p .941 .878 .745 r
F P
0 g
s
.498 .50885 m .48419 .52252 L .4887 .50836 L p .941 .878 .745 r
F P
0 g
s
.60684 .30979 m .59915 .31924 L .566 .33727 L p .866 .958 .864 r
F P
0 g
s
.56176 .34823 m .566 .33727 L .59915 .31924 L p .89 .948 .84 r
F P
0 g
s
.50566 .48859 m .49574 .49225 L .50481 .47536 L p .943 .878 .742 r
F P
0 g
s
.49574 .49225 m .50566 .48859 L .501 .49938 L p .942 .877 .743 r
F P
0 g
s
.55343 .37299 m .54931 .38667 L .52744 .40874 L p .932 .899 .771 r
F P
0 g
s
.52705 .42029 m .52744 .40874 L .54931 .38667 L p .937 .895 .761 r
F P
0 g
s
.501 .49938 m .4887 .50836 L .49574 .49225 L p .942 .877 .743 r
F P
0 g
s
.46804 .55023 m .48253 .53372 L .48382 .54118 L p .934 .881 .758 r
F P
0 g
s
.48382 .54118 m .46984 .5601 L .46804 .55023 L p .934 .881 .758 r
F P
0 g
s
.44164 .59385 m .45577 .57777 L .46287 .58314 L p .917 .893 .791 r
F P
0 g
s
.46287 .58314 m .45029 .60035 L .44164 .59385 L p .917 .893 .791 r
F P
0 g
s
.76327 .33034 m .74931 .3222 L .71429 .29664 L p 0 .403 .826 r
F P
0 g
s
.7026 .2931 m .71429 .29664 L .74931 .3222 L p 0 .466 .863 r
F P
0 g
s
.52705 .42029 m .52665 .43207 L .51187 .45149 L p .939 .881 .75 r
F P
0 g
s
.51523 .45891 m .51187 .45149 L .52665 .43207 L p .942 .882 .745 r
F P
0 g
s
.51187 .45149 m .51523 .45891 L .50481 .47536 L p .94 .876 .745 r
F P
0 g
s
.84402 .41986 m .82833 .40641 L .80662 .35981 L p .025 .32 .807 r
F P
0 g
s
.79193 .34942 m .80662 .35981 L .82833 .40641 L p .018 .319 .806 r
F P
0 g
s
.35739 .64326 m .3712 .64138 L .38804 .65492 L p .627 .833 .98 r
F P
0 g
s
.40031 .64875 m .38804 .65492 L .3712 .64138 L p .725 .87 .949 r
F P
0 g
s
.42748 .60803 m .44164 .59385 L .45029 .60035 L p .9 .895 .815 r
F P
0 g
s
.45029 .60035 m .43772 .61573 L .42748 .60803 L p .9 .895 .815 r
F P
0 g
s
.55758 .36015 m .55343 .37299 L .52784 .3975 L p .926 .904 .782 r
F P
0 g
s
.52744 .40874 m .52784 .3975 L .55343 .37299 L p .932 .899 .771 r
F P
0 g
s
.3712 .64138 m .38515 .63686 L .40031 .64875 L p .725 .87 .949 r
F P
0 g
s
.4127 .6401 m .40031 .64875 L .38515 .63686 L p .795 .888 .912 r
F P
0 g
s
.61463 .30186 m .60684 .30979 L .57028 .3273 L p .835 .966 .889 r
F P
0 g
s
.566 .33727 m .57028 .3273 L .60684 .30979 L p .866 .958 .864 r
F P
0 g
s
.21902 .45521 m .23204 .47203 L .22705 .52178 L p .198 .311 .754 r
F P
0 g
s
.23995 .53739 m .22705 .52178 L .23204 .47203 L p .222 .325 .759 r
F P
0 g
s
.41332 .62006 m .42748 .60803 L .43772 .61573 L p .876 .897 .843 r
F P
0 g
s
.43772 .61573 m .42518 .62905 L .41332 .62006 L p .876 .897 .843 r
F P
0 g
s
.47022 .5354 m .48419 .52252 L .48253 .53372 L p .933 .875 .755 r
F P
0 g
s
.48253 .53372 m .46804 .55023 L .47022 .5354 L p .933 .875 .755 r
F P
0 g
s
.27978 .57958 m .29347 .59099 L .30408 .62608 L p .145 .381 .833 r
F P
0 g
s
.31708 .63375 m .30408 .62608 L .29347 .59099 L p .25 .461 .87 r
F P
0 g
s
.38515 .63686 m .3992 .62972 L .4127 .6401 L p .795 .888 .912 r
F P
0 g
s
.42518 .62905 m .4127 .6401 L .3992 .62972 L p .843 .895 .876 r
F P
0 g
s
.3992 .62972 m .41332 .62006 L .42518 .62905 L p .843 .895 .876 r
F P
0 g
s
.45343 .56552 m .46804 .55023 L .46984 .5601 L p .924 .878 .771 r
F P
0 g
s
.46984 .5601 m .45577 .57777 L .45343 .56552 L p .924 .878 .771 r
F P
0 g
s
.64707 .28452 m .65554 .28337 L .69097 .2907 L p .201 .699 .914 r
F P
0 g
s
.69113 .29088 m .67987 .29014 L .6482 .28759 L p .323 .78 .948 r
F P
0 g
s
.65461 .28806 m .69113 .29088 L .6482 .28759 L .323 .78 .948 r
F
.63875 .28683 m .64707 .28452 L .69113 .29088 L p F P
0 g
s
.7026 .2931 m .69113 .29088 L .65546 .28573 L p .201 .699 .914 r
F P
0 g
s
.65546 .28573 m .64707 .28452 L p .66184 .2868 L .201 .699 .914 r
F P
0 g
s
.66184 .2868 m .7026 .2931 L .65546 .28573 L .201 .699 .914 r
F
.69097 .2907 m .7026 .2931 L p .68357 .29016 L F P
0 g
s
.64707 .28452 m .69097 .2907 L .68357 .29016 L .201 .699 .914 r
F
.71429 .29664 m .7026 .2931 L .66272 .28485 L p .096 .621 .877 r
F P
0 g
s
.66272 .28485 m .65554 .28337 L p .66885 .28637 L .096 .621 .877 r
F P
0 g
s
.66885 .28637 m .71429 .29664 L .66272 .28485 L .096 .621 .877 r
F
.65554 .28337 m .66416 .28324 L .70398 .29388 L p F P
0 g
s
.70398 .29388 m .71429 .29664 L p .6966 .29264 L .096 .621 .877 r
F P
0 g
s
.65554 .28337 m .70398 .29388 L .6966 .29264 L .096 .621 .877 r
F
.71429 .29664 m .7262 .30128 L .76327 .33034 L p 0 .403 .826 r
F P
0 g
s
.7262 .30128 m .71429 .29664 L .66996 .28479 L p .014 .553 .843 r
F P
0 g
s
.66996 .28479 m .66416 .28324 L p .6755 .28654 L .014 .553 .843 r
F P
0 g
s
.6755 .28654 m .7262 .30128 L .66996 .28479 L .014 .553 .843 r
F
.66416 .28324 m .67295 .28397 L .71739 .29841 L p F P
0 g
s
.71739 .29841 m .7262 .30128 L p .71032 .29666 L .014 .553 .843 r
F P
0 g
s
.66416 .28324 m .71739 .29841 L .71032 .29666 L .014 .553 .843 r
F
.77748 .3395 m .76327 .33034 L .7262 .30128 L p 0 .357 .799 r
F P
0 g
s
.7262 .30128 m .73835 .30681 L .77748 .3395 L p 0 .357 .799 r
F P
0 g
s
.73835 .30681 m .7262 .30128 L .67714 .28534 L p 0 .501 .819 r
F P
0 g
s
.67714 .28534 m .67295 .28397 L p .68165 .28701 L 0 .501 .819 r
F P
0 g
s
.68165 .28701 m .73835 .30681 L .67714 .28534 L 0 .501 .819 r
F
.67295 .28397 m .68191 .28538 L .73124 .30411 L p F P
0 g
s
.73124 .30411 m .73835 .30681 L p .72486 .3021 L 0 .501 .819 r
F P
0 g
s
.67295 .28397 m .73124 .30411 L .72486 .3021 L 0 .501 .819 r
F
.79193 .34942 m .77748 .3395 L .73835 .30681 L p 0 .329 .784 r
F P
0 g
s
.73835 .30681 m .75071 .31299 L .79193 .34942 L p 0 .329 .784 r
F P
0 g
s
.75071 .31299 m .73835 .30681 L .68422 .28626 L p 0 .466 .808 r
F P
0 g
s
.68422 .28626 m .68191 .28538 L p .68704 .28744 L 0 .466 .808 r
F P
0 g
s
.68704 .28744 m .75071 .31299 L .68422 .28626 L 0 .466 .808 r
F
.68191 .28538 m .69102 .28727 L .74558 .31078 L p F P
0 g
s
.74558 .31078 m .75071 .31299 L p .74041 .30886 L 0 .466 .808 r
F P
0 g
s
.68191 .28538 m .74558 .31078 L .74041 .30886 L 0 .466 .808 r
F
.80662 .35981 m .79193 .34942 L .75071 .31299 L p 0 .318 .781 r
F P
0 g
s
.75071 .31299 m .76329 .31955 L .80662 .35981 L p 0 .318 .781 r
F P
0 g
s
.76329 .31955 m .75071 .31299 L .74526 .31064 L p 0 .448 .809 r
F P
0 g
s
.74526 .31064 m .69112 .28731 L p .75974 .31797 L 0 .448 .809 r
F P
0 g
s
.69125 .28737 m .75974 .31797 L .69112 .28731 L 0 .448 .809 r
F
.75974 .31797 m .76329 .31955 L .74526 .31064 L F
.69112 .28731 m .69102 .28727 L p .69125 .28737 L F P
0 g
s
.69102 .28727 m .70029 .28942 L .76046 .3182 L p 0 .448 .809 r
F P
0 g
s
.76046 .3182 m .76329 .31955 L p .75724 .31685 L 0 .448 .809 r
F P
0 g
s
.69102 .28727 m .76046 .3182 L .75724 .31685 L 0 .448 .809 r
F
.82152 .37035 m .80662 .35981 L .76329 .31955 L p 0 .321 .789 r
F P
0 g
s
.76329 .31955 m .77606 .32623 L .82152 .37035 L p 0 .321 .789 r
F P
0 g
s
.77606 .32623 m .76329 .31955 L .70029 .28942 L p 0 .446 .822 r
F P
0 g
s
.70029 .28942 m .70971 .29161 L .77595 .32617 L p 0 .446 .822 r
F P
0 g
s
.77595 .32617 m .77606 .32623 L p .7758 .3261 L 0 .446 .822 r
F P
0 g
s
.70029 .28942 m .77595 .32617 L .7758 .3261 L 0 .446 .822 r
F
.78901 .33274 m .7766 .3265 L p .70971 .29161 L 0 .459 .844 r
F P
0 g
s
.7766 .3265 m .77606 .32623 L .77595 .32617 L p 0 .459 .844 r
F P
0 g
s
.77595 .32617 m .70971 .29161 L p .7766 .3265 L 0 .459 .844 r
F P
0 g
s
.6482 .28759 m .63875 .28683 L p .65461 .28806 L .323 .78 .948 r
F P
0 g
s
.63058 .29044 m .63875 .28683 L .67987 .29014 L p .45 .853 .97 r
F P
0 g
s
.50481 .47536 m .49788 .47311 L .51187 .45149 L p .94 .876 .745 r
F P
0 g
s
.49788 .47311 m .50481 .47536 L .49574 .49225 L p .937 .871 .746 r
F P
0 g
s
.52744 .40874 m .52705 .42029 L .50848 .44393 L p .935 .879 .756 r
F P
0 g
s
.51187 .45149 m .50848 .44393 L .52705 .42029 L p .939 .881 .75 r
F P
0 g
s
.47625 .51666 m .4887 .50836 L .48419 .52252 L p .933 .87 .752 r
F P
0 g
s
.48419 .52252 m .47022 .5354 L .47625 .51666 L p .933 .87 .752 r
F P
0 g
s
.49574 .49225 m .4857 .49538 L .49788 .47311 L p .937 .871 .746 r
F P
0 g
s
.4857 .49538 m .49574 .49225 L .4887 .50836 L p .935 .869 .749 r
F P
0 g
s
.56176 .34823 m .55758 .36015 L .52824 .38659 L p .919 .909 .795 r
F P
0 g
s
.52784 .3975 m .52824 .38659 L .55758 .36015 L p .926 .904 .782 r
F P
0 g
s
.50848 .44393 m .51187 .45149 L .49788 .47311 L p .935 .87 .75 r
F P
0 g
s
.4887 .50836 m .47625 .51666 L .4857 .49538 L p .935 .869 .749 r
F P
0 g
s
.62254 .29542 m .61463 .30186 L .57462 .31835 L p .794 .969 .913 r
F P
0 g
s
.57028 .3273 m .57462 .31835 L .61463 .30186 L p .835 .966 .889 r
F P
0 g
s
.85986 .43317 m .84402 .41986 L .82152 .37035 L p .045 .332 .813 r
F P
0 g
s
.80662 .35981 m .82152 .37035 L .84402 .41986 L p .025 .32 .807 r
F P
0 g
s
.29347 .59099 m .30737 .60055 L .31708 .63375 L p .25 .461 .87 r
F P
0 g
s
.33031 .63931 m .31708 .63375 L .30737 .60055 L p .36 .542 .898 r
F P
0 g
s
.43872 .57928 m .45343 .56552 L .45577 .57777 L p .91 .874 .788 r
F P
0 g
s
.45577 .57777 m .44164 .59385 L .43872 .57928 L p .91 .874 .788 r
F P
0 g
s
.23204 .47203 m .24518 .48863 L .23995 .53739 L p .222 .325 .759 r
F P
0 g
s
.25303 .55245 m .23995 .53739 L .24518 .48863 L p .254 .348 .767 r
F P
0 g
s
.45611 .54717 m .47022 .5354 L .46804 .55023 L p .922 .867 .767 r
F P
0 g
s
.46804 .55023 m .45343 .56552 L .45611 .54717 L p .922 .867 .767 r
F P
0 g
s
.52784 .3975 m .52744 .40874 L .50505 .43621 L p .929 .877 .763 r
F P
0 g
s
.50848 .44393 m .50505 .43621 L .52744 .40874 L p .935 .879 .756 r
F P
0 g
s
.566 .33727 m .56176 .34823 L .52865 .37606 L p .91 .915 .81 r
F P
0 g
s
.52824 .38659 m .52865 .37606 L .56176 .34823 L p .919 .909 .795 r
F P
0 g
s
.49788 .47311 m .49087 .47041 L .50848 .44393 L p .935 .87 .75 r
F P
0 g
s
.49087 .47041 m .49788 .47311 L .4857 .49538 L p .93 .862 .752 r
F P
0 g
s
.42395 .59119 m .43872 .57928 L .44164 .59385 L p .891 .867 .808 r
F P
0 g
s
.44164 .59385 m .42748 .60803 L .42395 .59119 L p .891 .867 .808 r
F P
0 g
s
.30737 .60055 m .32148 .60802 L .33031 .63931 L p .36 .542 .898 r
F P
0 g
s
.34376 .64253 m .33031 .63931 L .32148 .60802 L p .469 .62 .916 r
F P
0 g
s
.50505 .43621 m .50848 .44393 L .49087 .47041 L p .928 .863 .755 r
F P
0 g
s
.46366 .52403 m .47625 .51666 L .47022 .5354 L p .922 .86 .761 r
F P
0 g
s
.47022 .5354 m .45611 .54717 L .46366 .52403 L p .922 .86 .761 r
F P
0 g
s
.63058 .29044 m .62254 .29542 L .57901 .31038 L p .742 .965 .936 r
F P
0 g
s
.57462 .31835 m .57901 .31038 L .62254 .29542 L p .794 .969 .913 r
F P
0 g
s
.24518 .48863 m .25844 .5047 L .25303 .55245 L p .254 .348 .767 r
F P
0 g
s
.2663 .56663 m .25303 .55245 L .25844 .5047 L p .295 .378 .779 r
F P
0 g
s
.4857 .49538 m .47555 .49778 L .49087 .47041 L p .93 .862 .752 r
F P
0 g
s
.47555 .49778 m .4857 .49538 L .47625 .51666 L p .925 .858 .756 r
F P
0 g
s
.52824 .38659 m .52784 .3975 L .50159 .42831 L p .923 .874 .771 r
F P
0 g
s
.50505 .43621 m .50159 .42831 L .52784 .3975 L p .929 .877 .763 r
F P
0 g
s
.47625 .51666 m .46366 .52403 L .47555 .49778 L p .925 .858 .756 r
F P
0 g
s
.82152 .37035 m .8366 .38074 L .85986 .43317 L p .045 .332 .813 r
F P
0 g
s
.40913 .60101 m .42395 .59119 L .42748 .60803 L p .865 .856 .831 r
F P
0 g
s
.42748 .60803 m .41332 .62006 L .40913 .60101 L p .865 .856 .831 r
F P
0 g
s
.44187 .55755 m .45611 .54717 L .45343 .56552 L p .907 .856 .781 r
F P
0 g
s
.45343 .56552 m .43872 .57928 L .44187 .55755 L p .907 .856 .781 r
F P
0 g
s
.32148 .60802 m .33577 .61318 L .34376 .64253 L p .469 .62 .916 r
F P
0 g
s
.35739 .64326 m .34376 .64253 L .33577 .61318 L p .569 .687 .921 r
F P
0 g
s
.57028 .3273 m .566 .33727 L .52906 .36593 L p .898 .919 .827 r
F P
0 g
s
.52865 .37606 m .52906 .36593 L .566 .33727 L p .91 .915 .81 r
F P
0 g
s
.39432 .60851 m .40913 .60101 L .41332 .62006 L p .831 .841 .854 r
F P
0 g
s
.41332 .62006 m .3992 .62972 L .39432 .60851 L p .831 .841 .854 r
F P
0 g
s
.33577 .61318 m .35023 .61588 L .35739 .64326 L p .569 .687 .921 r
F P
0 g
s
.3712 .64138 m .35739 .64326 L .35023 .61588 L p .656 .743 .914 r
F P
0 g
s
.49087 .47041 m .48379 .46715 L .50505 .43621 L p .928 .863 .755 r
F P
0 g
s
.48379 .46715 m .49087 .47041 L .47555 .49778 L p .92 .85 .757 r
F P
0 g
s
.50159 .42831 m .50505 .43621 L .48379 .46715 L p .92 .854 .76 r
F P
0 g
s
.25844 .5047 m .27184 .51993 L .2663 .56663 L p .295 .378 .779 r
F P
0 g
s
.27978 .57958 m .2663 .56663 L .27184 .51993 L p .342 .415 .792 r
F P
0 g
s
.37954 .61354 m .39432 .60851 L .3992 .62972 L p .786 .818 .878 r
F P
0 g
s
.3992 .62972 m .38515 .63686 L .37954 .61354 L p .786 .818 .878 r
F P
0 g
s
.35023 .61588 m .36483 .61601 L .3712 .64138 L p .656 .743 .914 r
F P
0 g
s
.38515 .63686 m .3712 .64138 L .36483 .61601 L p .728 .786 .898 r
F P
0 g
s
.36483 .61601 m .37954 .61354 L .38515 .63686 L p .728 .786 .898 r
F P
0 g
s
.63875 .28683 m .63058 .29044 L .58348 .30339 L p .679 .951 .954 r
F P
0 g
s
.57901 .31038 m .58348 .30339 L .63058 .29044 L p .742 .965 .936 r
F P
0 g
s
.52865 .37606 m .52824 .38659 L .4981 .42022 L p .915 .871 .78 r
F P
0 g
s
.50159 .42831 m .4981 .42022 L .52824 .38659 L p .923 .874 .771 r
F P
0 g
s
.45094 .53021 m .46366 .52403 L .45611 .54717 L p .908 .846 .771 r
F P
0 g
s
.45611 .54717 m .44187 .55755 L .45094 .53021 L p .908 .846 .771 r
F P
0 g
s
.42754 .56625 m .44187 .55755 L .43872 .57928 L p .887 .842 .795 r
F P
0 g
s
.43872 .57928 m .42395 .59119 L .42754 .56625 L p .887 .842 .795 r
F P
0 g
s
.57462 .31835 m .57028 .3273 L .52948 .35621 L p .884 .924 .844 r
F P
0 g
s
.52906 .36593 m .52948 .35621 L .57028 .3273 L p .898 .919 .827 r
F P
0 g
s
.47555 .49778 m .46528 .4993 L .48379 .46715 L p .92 .85 .757 r
F P
0 g
s
.46528 .4993 m .47555 .49778 L .46366 .52403 L p .913 .844 .763 r
F P
0 g
s
.46366 .52403 m .45094 .53021 L .46528 .4993 L p .913 .844 .763 r
F P
0 g
s
.20607 .43848 m .19318 .42214 L .22154 .37026 L p .388 .415 .767 r
F P
0 g
s
.27184 .51993 m .28541 .534 L .27978 .57958 L p .342 .415 .792 r
F P
0 g
s
.29347 .59099 m .27978 .57958 L .28541 .534 L p .396 .457 .806 r
F P
0 g
s
.4981 .42022 m .50159 .42831 L .47664 .46327 L p .911 .844 .766 r
F P
0 g
s
.48379 .46715 m .47664 .46327 L .50159 .42831 L p .92 .854 .76 r
F P
0 g
s
.41314 .57305 m .42754 .56625 L .42395 .59119 L p .861 .823 .809 r
F P
0 g
s
.42395 .59119 m .40913 .60101 L .41314 .57305 L p .861 .823 .809 r
F P
0 g
s
.52906 .36593 m .52865 .37606 L .49457 .41194 L p .906 .867 .789 r
F P
0 g
s
.4981 .42022 m .49457 .41194 L .52865 .37606 L p .915 .871 .78 r
F P
0 g
s
.47664 .46327 m .48379 .46715 L .46528 .4993 L p .908 .836 .762 r
F P
0 g
s
.22154 .37026 m .23387 .3868 L .20607 .43848 L p .388 .415 .767 r
F P
0 g
s
.21902 .45521 m .20607 .43848 L .23387 .3868 L p .397 .414 .761 r
F P
0 g
s
.43812 .53499 m .45094 .53021 L .44187 .55755 L p .889 .828 .78 r
F P
0 g
s
.44187 .55755 m .42754 .56625 L .43812 .53499 L p .889 .828 .78 r
F P
0 g
s
.59261 .29208 m .59729 .28761 L .64648 .28403 L p .53 .895 .971 r
F P
0 g
s
.64707 .28452 m .63875 .28683 L .59424 .29602 L p .607 .928 .966 r
F P
0 g
s
.59911 .2949 m .64707 .28452 L .59424 .29602 L .607 .928 .966 r
F
.58801 .29731 m .59261 .29208 L .64707 .28452 L p F P
0 g
s
.65554 .28337 m .64707 .28452 L .59815 .29131 L p .53 .895 .971 r
F P
0 g
s
.59815 .29131 m .59261 .29208 L p .6028 .29067 L .53 .895 .971 r
F P
0 g
s
.6028 .29067 m .65554 .28337 L .59815 .29131 L .53 .895 .971 r
F
.59729 .28761 m .60205 .2838 L .65612 .28331 L p .454 .855 .97 r
F P
0 g
s
.64648 .28403 m .65554 .28337 L p .63997 .28552 L .53 .895 .971 r
F P
0 g
s
.59261 .29208 m .64648 .28403 L .63997 .28552 L .53 .895 .971 r
F
.66416 .28324 m .65554 .28337 L .60204 .28726 L p .454 .855 .97 r
F P
0 g
s
.60204 .28726 m .59729 .28761 L p .60632 .28702 L .454 .855 .97 r
F P
0 g
s
.60632 .28702 m .66416 .28324 L .60204 .28726 L .454 .855 .97 r
F
.65612 .28331 m .66416 .28324 L p .64987 .28417 L F P
0 g
s
.59729 .28761 m .65612 .28331 L .64987 .28417 L .454 .855 .97 r
F
.67295 .28397 m .66416 .28324 L .60588 .28376 L p .383 .813 .965 r
F P
0 g
s
.60588 .28376 m .60205 .2838 L p .60959 .28382 L .383 .813 .965 r
F P
0 g
s
.60959 .28382 m .67295 .28397 L .60588 .28376 L .383 .813 .965 r
F
.60205 .2838 m .60689 .28053 L .66606 .28361 L p F P
0 g
s
.66606 .28361 m .67295 .28397 L p .6603 .28394 L .383 .813 .965 r
F P
0 g
s
.60205 .2838 m .66606 .28361 L .6603 .28394 L .383 .813 .965 r
F
.68191 .28538 m .67295 .28397 L .60966 .28067 L p .325 .773 .959 r
F P
0 g
s
.60966 .28067 m .60689 .28053 L p .61255 .2809 L .325 .773 .959 r
F P
0 g
s
.61255 .2809 m .68191 .28538 L .60966 .28067 L .325 .773 .959 r
F
.60689 .28053 m .61181 .27767 L .67634 .28477 L p F P
0 g
s
.67634 .28477 m .68191 .28538 L p .67133 .2847 L .325 .773 .959 r
F P
0 g
s
.60689 .28053 m .67634 .28477 L .67133 .2847 L .325 .773 .959 r
F
.69102 .28727 m .68191 .28538 L .61181 .27767 L p .282 .738 .955 r
F P
0 g
s
.61181 .27767 m .61681 .27508 L .68699 .28661 L p .282 .738 .955 r
F P
0 g
s
.68699 .28661 m .69102 .28727 L p .68309 .28631 L .282 .738 .955 r
F P
0 g
s
.61181 .27767 m .68699 .28661 L .68309 .28631 L .282 .738 .955 r
F
.59424 .29602 m .58801 .29731 L p .59911 .2949 L .607 .928 .966 r
F P
0 g
s
.58348 .30339 m .58801 .29731 L .63875 .28683 L p .679 .951 .954 r
F P
0 g
s
.57901 .31038 m .57462 .31835 L .5299 .34691 L p .867 .927 .863 r
F P
0 g
s
.52948 .35621 m .5299 .34691 L .57462 .31835 L p .884 .924 .844 r
F P
0 g
s
.28541 .534 m .29913 .54663 L .29347 .59099 L p .396 .457 .806 r
F P
0 g
s
.30737 .60055 m .29347 .59099 L .29913 .54663 L p .454 .504 .82 r
F P
0 g
s
.46528 .4993 m .45492 .49976 L .47664 .46327 L p .908 .836 .762 r
F P
0 g
s
.45492 .49976 m .46528 .4993 L .45094 .53021 L p .897 .826 .769 r
F P
0 g
s
.3987 .57774 m .41314 .57305 L .40913 .60101 L p .829 .799 .823 r
F P
0 g
s
.40913 .60101 m .39432 .60851 L .3987 .57774 L p .829 .799 .823 r
F P
0 g
s
.45094 .53021 m .43812 .53499 L .45492 .49976 L p .897 .826 .769 r
F P
0 g
s
.23387 .3868 m .24622 .40361 L .21902 .45521 L p .397 .414 .761 r
F P
0 g
s
.23204 .47203 m .21902 .45521 L .24622 .40361 L p .411 .419 .758 r
F P
0 g
s
.29913 .54663 m .31301 .55756 L .30737 .60055 L p .454 .504 .82 r
F P
0 g
s
.32148 .60802 m .30737 .60055 L .31301 .55756 L p .515 .552 .832 r
F P
0 g
s
.49457 .41194 m .4981 .42022 L .46942 .45867 L p .899 .832 .771 r
F P
0 g
s
.47664 .46327 m .46942 .45867 L .4981 .42022 L p .911 .844 .766 r
F P
0 g
s
.52948 .35621 m .52906 .36593 L .49101 .40344 L p .896 .862 .799 r
F P
0 g
s
.49457 .41194 m .49101 .40344 L .52906 .36593 L p .906 .867 .789 r
F P
0 g
s
.38426 .58018 m .3987 .57774 L .39432 .60851 L p .791 .77 .834 r
F P
0 g
s
.39432 .60851 m .37954 .61354 L .38426 .58018 L p .791 .77 .834 r
F P
0 g
s
.46942 .45867 m .47664 .46327 L .45492 .49976 L p .894 .819 .767 r
F P
0 g
s
.4252 .53817 m .43812 .53499 L .42754 .56625 L p .866 .806 .789 r
F P
0 g
s
.42754 .56625 m .41314 .57305 L .4252 .53817 L p .866 .806 .789 r
F P
0 g
s
.58348 .30339 m .57901 .31038 L .53032 .33803 L p .846 .928 .883 r
F P
0 g
s
.5299 .34691 m .53032 .33803 L .57901 .31038 L p .867 .927 .863 r
F P
0 g
s
.31301 .55756 m .32704 .56655 L .32148 .60802 L p .515 .552 .832 r
F P
0 g
s
.33577 .61318 m .32148 .60802 L .32704 .56655 L p .577 .601 .841 r
F P
0 g
s
.24622 .40361 m .25859 .42046 L .23204 .47203 L p .411 .419 .758 r
F P
0 g
s
.24518 .48863 m .23204 .47203 L .25859 .42046 L p .429 .43 .758 r
F P
0 g
s
.36984 .58029 m .38426 .58018 L .37954 .61354 L p .745 .734 .842 r
F P
0 g
s
.37954 .61354 m .36483 .61601 L .36984 .58029 L p .745 .734 .842 r
F P
0 g
s
.32704 .56655 m .3412 .57342 L .33577 .61318 L p .577 .601 .841 r
F P
0 g
s
.35023 .61588 m .33577 .61318 L .3412 .57342 L p .637 .649 .845 r
F P
0 g
s
.35547 .57803 m .36984 .58029 L .36483 .61601 L p .694 .694 .846 r
F P
0 g
s
.36483 .61601 m .35023 .61588 L .35547 .57803 L p .694 .694 .846 r
F P
0 g
s
.3412 .57342 m .35547 .57803 L .35023 .61588 L p .637 .649 .845 r
F P
0 g
s
.45492 .49976 m .44446 .49903 L .46942 .45867 L p .894 .819 .767 r
F P
0 g
s
.44446 .49903 m .45492 .49976 L .43812 .53499 L p .878 .805 .774 r
F P
0 g
s
.43812 .53499 m .4252 .53817 L .44446 .49903 L p .878 .805 .774 r
F P
0 g
s
.5299 .34691 m .52948 .35621 L .48742 .39473 L p .885 .856 .809 r
F P
0 g
s
.49101 .40344 m .48742 .39473 L .52948 .35621 L p .896 .862 .799 r
F P
0 g
s
.49101 .40344 m .49457 .41194 L .46214 .4533 L p .887 .819 .776 r
F P
0 g
s
.46942 .45867 m .46214 .4533 L .49457 .41194 L p .899 .832 .771 r
F P
0 g
s
.41222 .5396 m .4252 .53817 L .41314 .57305 L p .839 .78 .796 r
F P
0 g
s
.41314 .57305 m .3987 .57774 L .41222 .5396 L p .839 .78 .796 r
F P
0 g
s
.25859 .42046 m .27101 .43707 L .24518 .48863 L p .429 .43 .758 r
F P
0 g
s
.25844 .5047 m .24518 .48863 L .27101 .43707 L p .452 .445 .76 r
F P
0 g
s
.46214 .4533 m .46942 .45867 L .44446 .49903 L p .878 .801 .77 r
F P
0 g
s
.58801 .29731 m .58348 .30339 L .53075 .32954 L p .823 .927 .903 r
F P
0 g
s
.53032 .33803 m .53075 .32954 L .58348 .30339 L p .846 .928 .883 r
F P
0 g
s
.27101 .43707 m .28349 .45319 L .25844 .5047 L p .452 .445 .76 r
F P
0 g
s
.27184 .51993 m .25844 .5047 L .28349 .45319 L p .479 .465 .764 r
F P
0 g
s
.3992 .53915 m .41222 .5396 L .3987 .57774 L p .807 .751 .8 r
F P
0 g
s
.3987 .57774 m .38426 .58018 L .3992 .53915 L p .807 .751 .8 r
F P
0 g
s
.8366 .38074 m .82152 .37035 L .77606 .32623 L p 0 .339 .806 r
F P
0 g
s
.43394 .497 m .44446 .49903 L .4252 .53817 L p .856 .782 .778 r
F P
0 g
s
.4252 .53817 m .41222 .5396 L .43394 .497 L p .856 .782 .778 r
F P
0 g
s
.44446 .49903 m .43394 .497 L .46214 .4533 L p .878 .801 .77 r
F P
0 g
s
.53032 .33803 m .5299 .34691 L .48379 .3858 L p .872 .85 .819 r
F P
0 g
s
.48742 .39473 m .48379 .3858 L .5299 .34691 L p .885 .856 .809 r
F P
0 g
s
.48742 .39473 m .49101 .40344 L .4548 .44711 L p .872 .805 .781 r
F P
0 g
s
.46214 .4533 m .4548 .44711 L .49101 .40344 L p .887 .819 .776 r
F P
0 g
s
.28349 .45319 m .29606 .46856 L .27184 .51993 L p .479 .465 .764 r
F P
0 g
s
.28541 .534 m .27184 .51993 L .29606 .46856 L p .509 .488 .769 r
F P
0 g
s
.4548 .44711 m .46214 .4533 L .43394 .497 L p .859 .78 .773 r
F P
0 g
s
.38616 .53674 m .3992 .53915 L .38426 .58018 L p .772 .718 .802 r
F P
0 g
s
.38426 .58018 m .36984 .58029 L .38616 .53674 L p .772 .718 .802 r
F P
0 g
s
.29606 .46856 m .30871 .48293 L .28541 .534 L p .509 .488 .769 r
F P
0 g
s
.29913 .54663 m .28541 .534 L .30871 .48293 L p .542 .516 .776 r
F P
0 g
s
.59261 .29208 m .58801 .29731 L .53119 .32142 L p .795 .922 .922 r
F P
0 g
s
.53075 .32954 m .53119 .32142 L .58801 .29731 L p .823 .927 .903 r
F P
0 g
s
.42335 .49358 m .43394 .497 L .41222 .5396 L p .831 .756 .78 r
F P
0 g
s
.41222 .5396 m .3992 .53915 L .42335 .49358 L p .831 .756 .78 r
F P
0 g
s
.37312 .53236 m .38616 .53674 L .36984 .58029 L p .735 .684 .802 r
F P
0 g
s
.36984 .58029 m .35547 .57803 L .37312 .53236 L p .735 .684 .802 r
F P
0 g
s
.43394 .497 m .42335 .49358 L .4548 .44711 L p .859 .78 .773 r
F P
0 g
s
.30871 .48293 m .32144 .49606 L .29913 .54663 L p .542 .516 .776 r
F P
0 g
s
.31301 .55756 m .29913 .54663 L .32144 .49606 L p .578 .546 .782 r
F P
0 g
s
.48379 .3858 m .48742 .39473 L .44741 .44007 L p .857 .79 .785 r
F P
0 g
s
.4548 .44711 m .44741 .44007 L .48742 .39473 L p .872 .805 .781 r
F P
0 g
s
.53075 .32954 m .53032 .33803 L .48013 .37665 L p .858 .842 .829 r
F P
0 g
s
.48379 .3858 m .48013 .37665 L .53032 .33803 L p .872 .85 .819 r
F P
0 g
s
.36012 .52601 m .37312 .53236 L .35547 .57803 L p .695 .649 .799 r
F P
0 g
s
.35547 .57803 m .3412 .57342 L .36012 .52601 L p .695 .649 .799 r
F P
0 g
s
.32144 .49606 m .33426 .50773 L .31301 .55756 L p .578 .546 .782 r
F P
0 g
s
.32704 .56655 m .31301 .55756 L .33426 .50773 L p .616 .579 .789 r
F P
0 g
s
.34716 .51777 m .36012 .52601 L .3412 .57342 L p .656 .613 .795 r
F P
0 g
s
.3412 .57342 m .32704 .56655 L .34716 .51777 L p .656 .613 .795 r
F P
0 g
s
.33426 .50773 m .34716 .51777 L .32704 .56655 L p .616 .579 .789 r
F P
0 g
s
.77606 .32623 m .78901 .33274 L .8366 .38074 L p 0 .339 .806 r
F P
0 g
s
.44741 .44007 m .4548 .44711 L .42335 .49358 L p .839 .759 .774 r
F P
0 g
s
.41271 .48872 m .42335 .49358 L .3992 .53915 L p .805 .729 .781 r
F P
0 g
s
.3992 .53915 m .38616 .53674 L .41271 .48872 L p .805 .729 .781 r
F P
0 g
s
.42335 .49358 m .41271 .48872 L .44741 .44007 L p .839 .759 .774 r
F P
0 g
s
.59729 .28761 m .59261 .29208 L .53163 .31365 L p .765 .915 .939 r
F P
0 g
s
.53119 .32142 m .53163 .31365 L .59261 .29208 L p .795 .922 .922 r
F P
0 g
s
.48013 .37665 m .48379 .3858 L .43997 .43218 L p .841 .775 .788 r
F P
0 g
s
.44741 .44007 m .43997 .43218 L .48379 .3858 L p .857 .79 .785 r
F P
0 g
s
.53119 .32142 m .53075 .32954 L .47644 .36729 L p .842 .834 .839 r
F P
0 g
s
.48013 .37665 m .47644 .36729 L .53075 .32954 L p .858 .842 .829 r
F P
0 g
s
.40204 .48239 m .41271 .48872 L .38616 .53674 L p .777 .701 .78 r
F P
0 g
s
.38616 .53674 m .37312 .53236 L .40204 .48239 L p .777 .701 .78 r
F P
0 g
s
.43997 .43218 m .44741 .44007 L .41271 .48872 L p .818 .737 .775 r
F P
0 g
s
.23387 .3868 m .22154 .37026 L .27399 .32374 L p .517 .496 .771 r
F P
0 g
s
.27399 .32374 m .28469 .33946 L .23387 .3868 L p .517 .496 .771 r
F P
0 g
s
.24622 .40361 m .23387 .3868 L .28469 .33946 L p .527 .496 .765 r
F P
0 g
s
.41271 .48872 m .40204 .48239 L .43997 .43218 L p .818 .737 .775 r
F P
0 g
s
.39135 .47462 m .40204 .48239 L .37312 .53236 L p .748 .673 .777 r
F P
0 g
s
.37312 .53236 m .36012 .52601 L .39135 .47462 L p .748 .673 .777 r
F P
0 g
s
.28469 .33946 m .29535 .35532 L .24622 .40361 L p .527 .496 .765 r
F P
0 g
s
.25859 .42046 m .24622 .40361 L .29535 .35532 L p .54 .501 .761 r
F P
0 g
s
.47644 .36729 m .48013 .37665 L .43248 .42343 L p .824 .76 .791 r
F P
0 g
s
.43997 .43218 m .43248 .42343 L .48013 .37665 L p .841 .775 .788 r
F P
0 g
s
.29535 .35532 m .30599 .37115 L .25859 .42046 L p .54 .501 .761 r
F P
0 g
s
.27101 .43707 m .25859 .42046 L .30599 .37115 L p .555 .509 .758 r
F P
0 g
s
.38065 .46543 m .39135 .47462 L .36012 .52601 L p .72 .645 .774 r
F P
0 g
s
.36012 .52601 m .34716 .51777 L .38065 .46543 L p .72 .645 .774 r
F P
0 g
s
.43248 .42343 m .43997 .43218 L .40204 .48239 L p .797 .716 .775 r
F P
0 g
s
.60205 .2838 m .59729 .28761 L .53208 .30616 L p .732 .904 .955 r
F P
0 g
s
.53163 .31365 m .53208 .30616 L .59729 .28761 L p .765 .915 .939 r
F P
0 g
s
.53163 .31365 m .53119 .32142 L .47271 .35772 L p .825 .825 .848 r
F P
0 g
s
.47644 .36729 m .47271 .35772 L .53119 .32142 L p .842 .834 .839 r
F P
0 g
s
.30599 .37115 m .31663 .38675 L .27101 .43707 L p .555 .509 .758 r
F P
0 g
s
.28349 .45319 m .27101 .43707 L .31663 .38675 L p .573 .52 .758 r
F P
0 g
s
.40204 .48239 m .39135 .47462 L .43248 .42343 L p .797 .716 .775 r
F P
0 g
s
.36995 .45492 m .38065 .46543 L .34716 .51777 L p .692 .619 .771 r
F P
0 g
s
.34716 .51777 m .33426 .50773 L .36995 .45492 L p .692 .619 .771 r
F P
0 g
s
.31663 .38675 m .32726 .40193 L .28349 .45319 L p .573 .52 .758 r
F P
0 g
s
.29606 .46856 m .28349 .45319 L .32726 .40193 L p .593 .535 .759 r
F P
0 g
s
.35926 .44317 m .36995 .45492 L .33426 .50773 L p .665 .595 .767 r
F P
0 g
s
.33426 .50773 m .32144 .49606 L .35926 .44317 L p .665 .595 .767 r
F P
0 g
s
.32726 .40193 m .33791 .41652 L .29606 .46856 L p .593 .535 .759 r
F P
0 g
s
.30871 .48293 m .29606 .46856 L .33791 .41652 L p .615 .552 .761 r
F P
0 g
s
.34858 .43032 m .35926 .44317 L .32144 .49606 L p .639 .572 .764 r
F P
0 g
s
.32144 .49606 m .30871 .48293 L .34858 .43032 L p .639 .572 .764 r
F P
0 g
s
.33791 .41652 m .34858 .43032 L .30871 .48293 L p .615 .552 .761 r
F P
0 g
s
.47271 .35772 m .47644 .36729 L .42496 .41384 L p .807 .744 .794 r
F P
0 g
s
.43248 .42343 m .42496 .41384 L .47644 .36729 L p .824 .76 .791 r
F P
0 g
s
.42496 .41384 m .43248 .42343 L .39135 .47462 L p .775 .694 .774 r
F P
0 g
s
.39135 .47462 m .38065 .46543 L .42496 .41384 L p .775 .694 .774 r
F P
0 g
s
.53208 .30616 m .53163 .31365 L .46894 .34794 L p .806 .815 .857 r
F P
0 g
s
.47271 .35772 m .46894 .34794 L .53163 .31365 L p .825 .825 .848 r
F P
0 g
s
.60689 .28053 m .60205 .2838 L .53253 .29893 L p .698 .889 .967 r
F P
0 g
s
.53208 .30616 m .53253 .29893 L .60205 .2838 L p .732 .904 .955 r
F P
0 g
s
.4174 .40347 m .42496 .41384 L .38065 .46543 L p .754 .673 .773 r
F P
0 g
s
.38065 .46543 m .36995 .45492 L .4174 .40347 L p .754 .673 .773 r
F P
0 g
s
.42496 .41384 m .4174 .40347 L .47271 .35772 L p .807 .744 .794 r
F P
0 g
s
.46894 .34794 m .47271 .35772 L .4174 .40347 L p .789 .729 .797 r
F P
0 g
s
.40981 .39235 m .4174 .40347 L .36995 .45492 L p .733 .654 .772 r
F P
0 g
s
.36995 .45492 m .35926 .44317 L .40981 .39235 L p .733 .654 .772 r
F P
0 g
s
.40218 .38056 m .40981 .39235 L .35926 .44317 L p .712 .636 .771 r
F P
0 g
s
.35926 .44317 m .34858 .43032 L .40218 .38056 L p .712 .636 .771 r
F P
0 g
s
.53253 .29893 m .53208 .30616 L .46515 .33797 L p .787 .804 .866 r
F P
0 g
s
.46894 .34794 m .46515 .33797 L .53208 .30616 L p .806 .815 .857 r
F P
0 g
s
.4174 .40347 m .40981 .39235 L .46894 .34794 L p .789 .729 .797 r
F P
0 g
s
.70029 .28942 m .69102 .28727 L .61681 .27508 L p .255 .711 .954 r
F P
0 g
s
.46515 .33797 m .46894 .34794 L .40981 .39235 L p .771 .715 .8 r
F P
0 g
s
.39452 .36819 m .40218 .38056 L .34858 .43032 L p .693 .62 .77 r
F P
0 g
s
.34858 .43032 m .33791 .41652 L .39452 .36819 L p .693 .62 .77 r
F P
0 g
s
.61181 .27767 m .60689 .28053 L .53299 .29188 L p .664 .871 .977 r
F P
0 g
s
.53253 .29893 m .53299 .29188 L .60689 .28053 L p .698 .889 .967 r
F P
0 g
s
.38684 .35531 m .39452 .36819 L .33791 .41652 L p .675 .606 .771 r
F P
0 g
s
.33791 .41652 m .32726 .40193 L .38684 .35531 L p .675 .606 .771 r
F P
0 g
s
.40981 .39235 m .40218 .38056 L .46515 .33797 L p .771 .715 .8 r
F P
0 g
s
.37912 .34203 m .38684 .35531 L .32726 .40193 L p .657 .594 .772 r
F P
0 g
s
.32726 .40193 m .31663 .38675 L .37912 .34203 L p .657 .594 .772 r
F P
0 g
s
.70971 .29161 m .71927 .29362 L .78901 .33274 L p 0 .459 .844 r
F P
0 g
s
.37136 .32846 m .37912 .34203 L .31663 .38675 L p .642 .584 .774 r
F P
0 g
s
.31663 .38675 m .30599 .37115 L .37136 .32846 L p .642 .584 .774 r
F P
0 g
s
.53299 .29188 m .53253 .29893 L .46131 .32782 L p .767 .792 .874 r
F P
0 g
s
.46515 .33797 m .46131 .32782 L .53253 .29893 L p .787 .804 .866 r
F P
0 g
s
.46131 .32782 m .46515 .33797 L .40218 .38056 L p .753 .701 .803 r
F P
0 g
s
.36356 .31469 m .37136 .32846 L .30599 .37115 L p .627 .576 .778 r
F P
0 g
s
.30599 .37115 m .29535 .35532 L .36356 .31469 L p .627 .576 .778 r
F P
0 g
s
.40218 .38056 m .39452 .36819 L .46131 .32782 L p .753 .701 .803 r
F P
0 g
s
.35571 .30084 m .36356 .31469 L .29535 .35532 L p .614 .572 .783 r
F P
0 g
s
.29535 .35532 m .28469 .33946 L .35571 .30084 L p .614 .572 .783 r
F P
0 g
s
.34782 .287 m .35571 .30084 L .28469 .33946 L p .603 .57 .79 r
F P
0 g
s
.28469 .33946 m .27399 .32374 L .34782 .287 L p .603 .57 .79 r
F P
0 g
s
.61681 .27508 m .61181 .27767 L .53346 .28496 L p .632 .852 .983 r
F P
0 g
s
.53299 .29188 m .53346 .28496 L .61181 .27767 L p .664 .871 .977 r
F P
0 g
s
.61681 .27508 m .62188 .27262 L .70029 .28942 L p .255 .711 .954 r
F P
0 g
s
.70971 .29161 m .70029 .28942 L .62188 .27262 L p .246 .692 .957 r
F P
0 g
s
.45744 .3175 m .46131 .32782 L .39452 .36819 L p .736 .689 .806 r
F P
0 g
s
.39452 .36819 m .38684 .35531 L .45744 .3175 L p .736 .689 .806 r
F P
0 g
s
.46131 .32782 m .45744 .3175 L .53299 .29188 L p .767 .792 .874 r
F P
0 g
s
.53346 .28496 m .53299 .29188 L .45744 .3175 L p .746 .781 .881 r
F P
0 g
s
.45354 .30703 m .45744 .3175 L .38684 .35531 L p .719 .678 .809 r
F P
0 g
s
.38684 .35531 m .37912 .34203 L .45354 .30703 L p .719 .678 .809 r
F P
0 g
s
.45744 .3175 m .45354 .30703 L .53346 .28496 L p .746 .781 .881 r
F P
0 g
s
.62188 .27262 m .61681 .27508 L .53393 .2781 L p .603 .831 .987 r
F P
0 g
s
.53346 .28496 m .53393 .2781 L .61681 .27508 L p .632 .852 .983 r
F P
0 g
s
.4496 .29642 m .45354 .30703 L .37912 .34203 L p .702 .668 .813 r
F P
0 g
s
.37912 .34203 m .37136 .32846 L .4496 .29642 L p .702 .668 .813 r
F P
0 g
s
.71927 .29362 m .70971 .29161 L .62704 .27012 L p .252 .681 .963 r
F P
0 g
s
.62188 .27262 m .62704 .27012 L .70971 .29161 L p .246 .692 .957 r
F P
0 g
s
.53393 .2781 m .53346 .28496 L .45354 .30703 L p .725 .769 .888 r
F P
0 g
s
.44562 .28569 m .4496 .29642 L .37136 .32846 L p .686 .66 .818 r
F P
0 g
s
.37136 .32846 m .36356 .31469 L .44562 .28569 L p .686 .66 .818 r
F P
0 g
s
.45354 .30703 m .4496 .29642 L .53393 .2781 L p .725 .769 .888 r
F P
0 g
s
.4416 .27485 m .44562 .28569 L .36356 .31469 L p .671 .653 .824 r
F P
0 g
s
.36356 .31469 m .35571 .30084 L .4416 .27485 L p .671 .653 .824 r
F P
0 g
s
.62704 .27012 m .62188 .27262 L .53441 .27122 L p .578 .81 .987 r
F P
0 g
s
.53393 .2781 m .53441 .27122 L .62188 .27262 L p .603 .831 .987 r
F P
0 g
s
.53441 .27122 m .53393 .2781 L .4496 .29642 L p .704 .757 .893 r
F P
0 g
s
.62704 .27012 m .63227 .26744 L .71927 .29362 L p .252 .681 .963 r
F P
0 g
s
.43754 .26392 m .4416 .27485 L .35571 .30084 L p .656 .649 .831 r
F P
0 g
s
.35571 .30084 m .34782 .287 L .43754 .26392 L p .656 .649 .831 r
F P
0 g
s
.4496 .29642 m .44562 .28569 L .53441 .27122 L p .704 .757 .893 r
F P
0 g
s
.53489 .26426 m .53441 .27122 L .44562 .28569 L p .684 .746 .898 r
F P
0 g
s
.44562 .28569 m .4416 .27485 L .53489 .26426 L p .684 .746 .898 r
F P
0 g
s
.53441 .27122 m .53489 .26426 L .62704 .27012 L p .578 .81 .987 r
F P
0 g
s
.63227 .26744 m .62704 .27012 L .53489 .26426 L p .557 .789 .986 r
F P
0 g
s
.53539 .25714 m .53489 .26426 L .4416 .27485 L p .664 .735 .903 r
F P
0 g
s
.4416 .27485 m .43754 .26392 L .53539 .25714 L p .664 .735 .903 r
F P
0 g
s
.53489 .26426 m .53539 .25714 L .63227 .26744 L p .557 .789 .986 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojVli`03o`00
0?n>bOcoS/Wl00?oS/Wl2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00005?nY_>L5o`00013oS/Wl
2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool002cooooo0ol0
0003ooooo`03o`000?oooooooooo07?ooooo1?l00002ojNVe003o`000?nY_>OoZKcW017oZKcW2?l0
0004ojnni@03o`000?nCcocoTlol00KoTlol2?l0000;ohk9o0Oo00004oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo02kooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0Koooool3o`0000KoYjKD00?o0000ojVlionY_>L02onY_>L6o`0000co[kkU00?o0000
oi??o?nCco`05OnCco`7o`0000Co@:kf0ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0;Oooool002cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zoooo
o`Co00002_nWY]@00ol0003oZKcWojVli`05ojVli`Co00003on__^D5o`0000koTlol3_l00004ocja
m0Go@:kf0ol0000=ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?ooool002co
oooo0ol00006ooooo`03o`000?oooooooooo06Gooooo1?l0000<ojNVe0?o00000_nY_>L00ol0003o
[kkUojnni@0>ojnni@Oo00001?nd`N@00ol0003oV]Cloi[Do00Boi[Do0Oo00000om1]_@6ocjam0Co
@:kf0ol0000:ooooo`03o`000?oooooooooo03;ooooo0_l0000]ooooo`00;?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo063ooooo1?l0000=ojNVe0?o00000_n[Ym800ol0003o[kkU
ojnni@09ojnni@So00002?nd`N@3o`0000KoV]Cl1ol00009oj7Jn`Co00001Om8_?@5od6fm0Co?[7d
1?m0[_H3o`0000Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`004Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05cooooo0ol0000=ojNVe0Co
00001_n[Ym800ol0003o[kkUojnni@03ojnni@Go00002ond`N@5o`0000;o^LCS00?o0000oj7JnonQ
f_/02onQf_/6o`0000?oZMkj0_l00006oe?5m@KoB;cd1?m1]_@01?l0003o?[7docjam?ln/O@3od2^
mP?o00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000Aooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo1?l0000=ojNVe0?o00002On[Ym82o`00
0003ojnniOl0003o000000ko]<7T1?l00005okW4h`?o00001?nQf_/2o`0000WoZMkj1?l00002ok;S
m`;o00002omRd?L01?l0003oDlGeoe?5mOmCaOD4odRlm0;o@KKd0_l00002ocjam0;o@:kf0ol00002
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002oooool0
0ol0003oooooooooo`1Cooooo`?o00003OnWY]@4o`0000WoZjOB0ol000000on_Z=7o0000okC1i00<
okC1i0Co00001Onia><4o`0000;o_/OQ00?o0000ojWNn_nYg_X01onYg_X2o`0000Ko/^?g2_l00000
0omdf_So0000ogCJn00<o`0000?o69kP0_m8_?@2od6fm0;o000000?o?[7dod2^m_l000000_l0000f
ooooo`03o`000?oooooooooo02Wooooo000Aooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool2
o`000003oiZAb_l0003oYjKD00[oYjKD0ol0000:oj^WdP?o00001On_Z=400ol0003o]<7TokC1i007
okC1i0;o00001onia><3o`0000Go_/OQ0_l00002ojWNnP03o`000?nbhoOo/^?g00So/^?g0_l00002
ok_Wm003o`000?o3j_3o000000_o000000?o[O?do`000?mcf_P02?mcf_P6o`000005oaRNh?l3SMOo
083Ao`20dOm1]_@01ol0000cooooo`03o`000?oooooooooo02Sooooo000Aooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1=ooooo`;o00001?nJTLX00ol0003oYjKDojNVe005ojNVe0?o0000
2on[Ym82o`0000So[jSA00?o0000okC1i?nd`N@00ond`N@2o`0000Oo^LCS1?l00005okk7h@?o0000
00?oa<[Oo`000?nbhoL02?nbhoL00ol0003o^nOdok_Wm002ok_Wm003o`000?o3j_3o000000;o0000
00?oVnggo`000?l000000ol00004ojgcm003okggkonAj?WoTNSi00GoTNSi1Ol00004ogO<o`?oE[Sk
0oldX_<01?lHW^3o083Ao`20dOl00003o`1bdP?o0000<Oooool2o`0002Wooooo000Aooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0B_ooool2o`0000OoVY7:00Co0000ojNVe?nWY]CoYjKD0_l0000<oj^W
dP?o00002_n_Z=42o`000003okC1i?nia>?o^LCS00Oo^LCS0ol00006okk7h@?o00001?o4b]l00ol0
003o/^?gok;Sm`03ok;Sm`03o`000?nkioCo^nOd00;o^nOd00?o0000ol?Zl?o3j_000_l000000oo;
k>co0000o`000002o`0000Go[O?d0_nmmnl2o`0000WoZo7f00Go0000oiKLo_nFg?koU]cno`000005
ogO<o`04o`000?mF^?_oE[Sko`0000?o=:;c00?o0000o`20dOl0Mlh00ol0L]800ol0MMSo0000o`00
000_ooooo`;o0000:Oooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo0_l0000@ooooo`03o`000?oooooooooo04Oooooo0_l00009oiZAbP?o00003?n[
Ym83o`0000[o[jSA0ol000000oncZm3o0000okW4h`06okW4h`;o00001onnan43o`0000Koa<[O0_l0
00000onbhoOo^nOdok_Wm004ok_Wm005o`000?o3j_3o`n[`ol?Zl?l000000_o;k>`2o`000003om;]
iol0003o[O?d00;o[O?d00Co0000okggkonmmnoo00000_o;n>T00ol0003oZo7foj_amP03oj_amP03
o`000?o0mO3o000000?o[nGi0_l00004oiKLoP?o00000omgc?l01?l0003oE[Sko`000?ldX_<2o`00
0003oaJ;j?l0003o083A00?o07;B00?o07GHo`000?ooool0;oooool00ol0003oooooooooo`0Voooo
o`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
013ooooo0_l00015ooooo`;o00002OnJTLX2o`000003oifBb?l0003oZjOB00WoZjOB0ol0000:ojnX
d@?o00001OncZm001?l0003o^LCSokW4honia><2o`0000Oo_/OQ0ol00006olC:g`?o000000?obLgM
o`000?nkio@00onkio@4ol?Zl004o`000?o;k>cobnc/ol_/k0;o000000Cod^gWo`000?l0003o[O?d
0onmmnl01?l0003oboSYol_hjOo;n>T2o`000003oj_am_l0003o`?G`00;o`?G`0_l00008ojoUn@;o
00001?nFg?h4o`000004ogO<ool0003o0000o`0000;o=:;c00Co0000oaJ;j?l0Mmco07OL0_l0L]83
o`0002kooooo00?o0000ooooooooool09_ooool002[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`10ooooo`;o00002_nJTLX00ol0003oWI;8oifBb002oifBb003o`000?n[Ym;oZjOB
00GoZjOB0_l0000;ojnXd@;o00001oncZm03o`0000Wo_/OQ0_l00007olC:g`;o00000oo9cMd2o`00
0003ok_Wm?o3j_3o`n[`00?o`n[`1?o;k>`00ol0003od^gWom;]i`03o`0000;o_OO_00Co0000ol_h
jOo;n>WoboSY0ol00003ol3el0?o000000CocoGXo`000?o3j_3o`n[`0ol00006ojoUn@;o00000_nC
`?D00ol0003oNk7eog^am@03o`000003of:Ol_l0003o000000;o000000Go=:;coaJ;j?lFRnSo07OL
o`000002o`1bdP03o`1ef?l0003o000002gooooo00?o0000ooooooooool09Oooool002[ooooo0_l0
000Eooooo`03o`000?oooooooooo03gooooo0_l0000:oiZAbP;o00001OnMT/P00ol0003oZjOBoj^W
dP03oj^WdP;o00002_n_Z=43o`0000Oo/j_@0_l000000onh[Loo0000okk7h@07okk7h@;o00001_o4
b]l3o`0000?obLgM0_l000000oo>d=_o0000ol?Zl002ol?Zl0Gobnc/00?o0000om;]iooBkNL00_l0
00000ooHkN;o0000o`000004ol_hj@;o000000CoeOOSo`000?o0mO3o00001Oo?mNP00ol0003o`n[`
ol?Zl004ol?Zl0;o000000Go[nGio`000?l0003oZLgbo`000003oi?0m@?o00000omk/OD2of:OlP04
o`000?m9SNcoBHg/odV=k0;o000000Co5X_Xo`000?l0Mmco06OC0_l0L]800ol0MMSo0000o`00000/
ooooo`03o`000?oooooooooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0>_ooool2o`0000[oVY7:0_l00007oifBb005o`000?n[Ym;oZjOBoj^Wd_l000002on_Z=42
o`0000So/j_@0_l00003okR]c`03o`000?nnan7o_/OQ00Co_/OQ00?o0000olC:goo4b]l01?o4b]l3
o`0000?obLgM0ol00002olk@f`;o00001_o;k>`00ol0003od^gWom;]i`02o`000004omS]h_l0003o
gNgLo`0000?oboSY00Ko0000omGghooEmn?o0000omgegOl00004oloej0?o00002Oo3j_000ol0003o
ZLgbojW=lP02ojW=lP?o00000_nC`?D01Ol0003oNk7eog^amOmk/OGo000000;oHYob00Co0000odV=
k?m9SNcoBHg/0_ldO>D02?l0003o5X_Xo`1gg?l0003o06OCo`1Kc?l0L];o07GH0_l0000Zooooo`;o
00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0gooooo`;o0000
2_nJTLX2o`0000WoWI;80_l0000;ojnXd@?o00002?ncZm02o`0000Ko^:g?00Co0000okk7hOnnan7o
00001oo4b]l2o`0000CobLgM0_l00003olk@f`;o000000?odm?Io`000?o;k>`00oo;k>`00ol0003o
d^gWom;]i`02o`000005omS]h_l0003ogNgLomg]g?l000000_o;n>T01?l0003oeOOSomGghol00002
omgeg@03o`000?o?mNSocoGX00?o000000?of_CPom7/iooAk>L00_oAk>L3o`000006ol?Zl?l0003o
0000okcFkOl0003oZLgb0ol000000onYcO;o0000oi?0m@02oi?0m@03o`000?mk/OGoNk7e00;oNk7e
00Co0000of:Ol_mRWo;o00000om9SN`4ocAli@07o`000?l0Mmco06OCo`000?l0Flco07;Bo`1ef002
o`0002Sooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@07ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo03Cooooo0_l0000:oiZAbP;o00002OnMT/P2o`000003oj2Caol0003o[jSA00Oo[jSA0ol0
0009ok>[d0;o00001onh[Ll2o`0000Soa<[O0_l00004olW=g@;o00001?o>d=/01Ol0003odm?Iom?C
fOoCdmWo000000;obnc/1?oBkNL01?l0003of>gRomS]h_l00002omg]g0;o00001?oEmn<2omgeg@?o
00001?oJm>000ol0003odNcWom7/i`06om7/i`03o`000?nle^go_=K]00?o00001OnYcO801Ol0003o
Tl3eoi?0mOnC`?Go000000CoNk7e00Co0000of:Ol_l0003o00000om9SN`3ocAli@;o8VkN00Ko0000
o`1Wdol0Im?o05_<o`1Db?l0L]83o`0002Oooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o0000
6Oooool00ol0003oooooooooo`0aooooo`;o00002onJTLX00ol0003oWI;8oifBb008oifBb003o`00
0?nPTlOoX9?700;oX9?700?o0000ojnXdOn_Z=400on_Z=42o`0000[o/j_@0_l00007okR]c`;o0000
00?o_;3>o`000?o4b]l01Oo4b]l00ol0003obLgMolW=g@03olW=g@;o00001?o>d=/2o`0000?odm?I
0_l00004om;]i`04o`000?oHkN;of>gRo`0000;ogNgL0_l000001?oRk=So0000omGghooEmn<2omge
g@;o000000?oho;Go`000?oJm>000_oJm>02o`0000OodNcW00?o0000ol_Li_l000000_l00003okcF
k@03o`000?nYcO;oZLgb00;oZLgb00Go0000oi?0mOnC`?GoTl3eo`000004og^am@03o`000?mRWo;o
HYob00;o00000_m9SN`01?l0003o=7cUocAliOldO>D3ob9^gP03o`000?l0Im?o05_<00;o05C80ol0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Gooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;_oo
ool2o`0000_oVY7:0_l00009oifBb0;o00001_nPTlL01Ol0003o[jSAojnXdOn_Z=7o000000[o/j_@
0_l00007okR]c`;o00001?nl/<h01Ol0003oa<[OolC:goo4b]oo000000GobLgM0_l00004olk@f`;o
00000ooCdmT2o`000005omOEe_l0003od^gWom;]iol000000_oHkN801Ol0003ogNgLomg]g?oMkMco
000000;oh^cH00Co0000omGghooMmMgogOGM0_l00002on?be`03o`000?oJm>3of_CP00;o000000Co
h_7Ho`000?oLk=kog>cN0ol000001_oAk>Oo0000o`000?l0003obmcVo`0000Go_=K]00?o0000ojW=
l_nYcO800_nYcO801Ol0003oTl3eoi?0mOnC`?Go000000CoNk7e00Co0000of:Ol_mRWo;o00000om9
SN`3ocAli@03o`000?lRK]ko8VkN00;o56;H00Go06OCo`1Kc?l0003o05C8o`1Aa`03o`0002Kooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0/ooooo`03o`00
0?n4O/Go000000WoVY7:0_l00009oifBb0;o00002?nPTlL2o`0000_o/j_@0_l00007okR]c`;o0000
1_nl/<h2o`0000KobLgM0_l00004olk@f`;o00001?oCdmT01?l0003oemGFomOEe_l00002om;]i`?o
f>gR0ooMkM`2o`000003on;/f?l0003o000000?ogOGM00Oo0000on?beooSl]Ooho;Go`000?oJm>3o
000000?oh_7H00?o0000omc/g_oLk=h00_oLk=h3o`0000GobmcV00?o0000okcFkOnle^d00_nle^d?
o`0000?oHYob00Co0000odV=k?m9SNco00000oldO>D00ol0003o8VkNob9^gP03oaARf007o`1Kc?l0
003o05C8o`1Aaol0003o07GHo`00000Uooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01oooool002Wooooo0ol0000Loooo
o`03o`000?oooooooooo02[ooooo00Go0000ohAnaOn4O/GoQ7k5o`000006oiZAbP;o00002_nMT/P0
0ol0003oX9?7oj2Ca`07oj2Ca`03o`000?nTULKo000000Wo/j_@0_l00007okR]c`;o00001_nl/<h2
o`000003ol2ccOl0003obLgM00CobLgM1_o>d=/00ol0003odm?Iom?Cf@02om?Cf@;o00000_oGeMH2
o`0000?of>gR0ooMkM`2o`0000;oh^cH00?o0000onG[dol000000_oMmMd00ol0003oho;Gon?be`02
o`0000Goh_7H00?o0000omc/g_oLk=h01?l00002omKPgP03o`000?o;g>KobmcV00?obmcV00Ko0000
okcFkOl0003o0000ok_3h?l00004ojbhhPCoVjcR1?n;Wn45o`0000?oBHg/00Co0000ocAliOldO>Go
00000_lRK]h01?l0003o56;HoaARf?lDH]P2o`000004o`1Db?l0DLOo0000o`1Bb@;o00009?ooool0
0ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000
ohAnaOn4O/D00on4O/D00ol0003oVY7:oiZAbP02oiZAbP03o`000?nMT/SoWI;800SoWI;80_l00008
oj2Ca`;o00000onTULH00ol0003o/j_@ok>[d004ok>[d0;o00001onh[Ll2o`0000Oo_;3>00?o0000
ol2ccOo0/ld00_o0/ld00ol0003obLgMolW=g@06olk@f`;o00000ooCdmT2o`0000?oemGF00Go0000
om_Ge?l0003of>gRo`000003omg]g003o`000?oRk=Soh^cH00;o000000CoiN_Co`000?oMmMgo0000
0ooSl]L00ol0003oj>oAo`000003on;af0Go00000_oLk=h00ol0003oe^3NomKPgP02omKPgP03o`00
0?o;g>KobmcV00?obmcV00Go0000ok_3h?nk`n3o^l?Po`000004ojbhhP05o`000?nK[>;oVjcRoi^/
h_l000001?n;Wn43ogZBgP?o00000_m9SN`01?l0003o=7cUocAliOl00002ob9^gP03o`000?lDH]So
56;H00;o2eWC00Oo0000o`1Db?l0DLOo0000o`1BbOl0E/ko000002;ooooo0ol00004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ohAnaOn4O/D01On4O/D01?l0003oVY7:
oiZAb_l00009oifBb0;o00002OnPTlL00ol0003oY9G6ojBEaP04ojBEaP03o`000?ncZm3o/j_@00;o
/j_@00?o0000okR]conh[Ll01_nh[Ll00ol0003o_;3>okb`cP05okb`cP;o00001?o0/ld2o`0000Oo
c]3K00?o0000om?CfOoCdmT00_oCdmT01?l0003oemGFomOEe_oGeMH2o`000003om_Ge?l0003o0000
00CogNgL00Co0000on;/f?oRk=So00000_oUjm<2o`0000?oho;G0_l000001?oXkm7o0000on;af?oR
lMP4o`0000?ohn_F0_l00006omKPgP06o`000?o;g>Ko0000o`000?o8c=go00000onk`n000ol0003o
[;SRojbhhP02ojbhhP05o`000?nK[>;oVjcRoi^/h_l000001?n;Wn401Ol0003oNY;NogZBg_mjT]ko
JhKK00Co00000_ldO>D01?l0003o8VkNob9^g_l00003oaARf0;o2eWC00Oo0000o`1Db?l0DLOo0000
o`1BbOl0E/ko000002?ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00cooooo1?l00008ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Tooooo`03o`000?n4O/GoQ7k500KoQ7k50_l0000:oifBb003o`000?nPTlOo
X9?700OoX9?70_l00007ojBEaP04o`000?ncZm3o/j_@o`0000So^:g?0_l00006okb`cP;o00001Oo0
/ld00ol0003oaKO<o`000005olk@f`03o`000?oCdmWodm?I00;odm?I0_l00003omOEeP06o`000?oK
emCofmODo`000?oOfM7o00000_oMkM`01Ol0003oh^cHon;/f?oRk=So000000;oiN_C00?o0000onSZ
col000000_oSl]L01?l0003oj>oAonS_dOoXkm44o`000003onO^dOl0003ohn_F00?ohn_F0_l00007
omKPgP05o`000?o8c=gob<cMolS<gOl000000onk`n000ol0003o[;SRojbhhP02ojbhhP05o`000?nK
[>;oVjcRoi^/h_l000001?n;Wn401ol0003oNY;NogZBg_mjT]ko0000of^6fol000000_m[Q]/00ol0
003o=7cUo`000003ob9^gP04o`000?lDH]So56;Ho`0000;o2eWC1?l000000ol0D/Wo05K>o`00000S
ooooo`03o`000?oooooooooo01kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0
000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ohAnaOn4O/D01_n4O/D00ol0003oQWk3o`00
0008oifBb0;o00002OnPTlL00ol0003oY9G6ojBEaP07ojBEaP;o00002?nh[Ll2o`0000Oo_;3>00?o
0000ol2ccOo0/ld00oo0/ld2o`0000;oaKO<00?o0000olk@foo>d=/00_o>d=/4om?Cf@;o00001?oG
eMH01?l0003ofmODom_Ge?l00002omoId@03o`000?oMkMcoh^cH00?oh^cH0ooUjm<01_l0003oj>[?
onSZcol0003oho;Go`0000;oj>oA0ol00003onO^d@03o`000?oSjmKohn_F00;ohn_F00Co0000omoR
eooOh]Oo00000ooFh=h2o`000003om?Bf?l0003ob<cM00;ob<cM00?o0000ok_3h?nk`n000_nk`n00
1Ol0003o[;SRojbhh_n/^>;o000000?oVjcR00?o0000oh^OhOn;Wn400_n;Wn401ol0003oNY;NogZB
g_mjT]ko0000of^6fol000000_m[Q]/2oeekf005ocAliOl0003o8VkNob9^g_l000000olDH]P2o`]I
d`;o1UC@0ol000000ol0D/Wo05K>o`00000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00008ohAn
a@05o`000?n6O/?oQWk3ohIn`ol000001OnMT/P2o`0000WoX9?70_l00009ojBEaP03o`000?nXV<Go
000000Ko^:g?0_l00007okb`cP;o00001Oo0/ld00ol0003oaKO<olFgc003olFgc003o`000?o>d=_o
000000Codm?I00?o0000omOEe_oGeMH00_oGeMH2o`0000;ofmOD00?o0000omoIdOoOfM400_l00003
on;/f005o`000?oUjm?oiN_ConG[dol000000_oXj/l01?l0003oho;GonS_dOoXkm44o`0000CoinkA
00Go0000on?[e_oSjmKohn_Fo`000004omoRe`03o`000?oFh=ko000000?odm;H00Go0000olS<gOo8
c=gob<cMo`000004ok_3h005o`000?n/^>;o[;SRojbhh_l000001?nK[>801Ol0003oRioQoh^OhOn;
Wn7o000000?oNY;N00Go0000of^6fom[Q]_o0000of^6f`03oeekf005o`000?lRK]ko8VkNob9^g_l0
00000_lDH]P00ol0003o2eWCo`]Id`03o`IDd0;o000000?o05;9o`1Fc_l000008_ooool00ol0003o
ooooooooo`0Mooooo`001_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool07Oooool00ol0003oQ7k5ohAna@07ohAna@03o`000?n6O/?oQWk300?oQWk300Go0000oifBb?nM
T/SoWI;8o`00000:oj2Ca`03o`000?nTULKoY9G600OoY9G60_l00003ojRHa@04o`000?nh[Loo^:g?
okR]c`;o00001onl/<h2o`0000Go`;?=0_l00005olFgc0;o00001OoCdmT00ol0003oemGFomOEeP02
omOEeP03o`000?oKemCofmOD00;o00000_oOfM400ol0003oh]_?o`000002on;/f005o`000?oUjm?o
iN_ConG[dol000000_oXj/l6o`000003on_]c?l0003oinkA00;oinkA1_l00006omoRe`03o`000?oC
d]Sodm;H00;odm;H00?o0000olS<gOo8c=d00_o8c=d01Ol0003o^l?Pok_3h?nk`n3o000000?o[;SR
00?o0000oi^/h_nK[>800_nK[>801Ol0003oRioQoh^OhOn;Wn7o000000?oNY;N00Co0000of^6fom[
Q]_oJhKK0_l00003oeekf0;o000000?o8VkNo`000?lDH]P00_lDH]P00ol0003o2eWCo`000003o`ID
d0;o000000?o05;9o`1Fc_l000008_ooool2o`0001gooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oQ7k5ohAna@07ohAna@03o`000?n6O/?o
QWk300CoQWk300Co0000oifBb?nMT/So00002OnPTlL2o`0000WoY9G600?o0000ojRHaOnXV<D00onX
V<D01?l0003o^:g?okR]col00008okb`cP03o`000?o0/lgo`;?=00Co`;?=00?o0000olFgc?o5]l`0
1?o5]l`00ol0003obK[<o`000003om?Cf@03o`000?oGeMKoemGF00?oemGF00Co0000om_Ge?oKemCo
00000ooOfM401Ol0003oh]_?on;Kcol0003oh^cH00CoiN_C00?o0000onSZcooXj/l00ol000001_oX
km7o0000on_]c?o[kLco0000onO^d@?o000000?ojn_<o`000?oXjLl00_oXjLl00ol0003ogn;GomoR
e`03omoRe`;o00001?oCd]P00ol0003ob<cMolS<g@02olS<g@05o`000?nk`n3o^l?Pok_3h?l00000
0on/^>800ol0003oVjcRoi^/hP02oi^/hP05o`000?n;Wn7oRioQoh^OhOl000000omjT]h00ol0003o
JhKKof^6f`02of^6f`04o`000?mMNmSoGG_Hoeekf0;oDW7D00?o0000ob9^g_l000000_lDH]P00ol0
003o2eWCo`]Id`03o`IDd0;o157>00Co0000o`1BbOl0E/ko00008?ooool00ol0003oooooo`00000M
ooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`03o`000?n4O/Go
Q7k500OoQ7k500?o0000ohIn`on6O/<01_n6O/<00ol0003oX9?7oj2Ca`08oj2Ca`03o`000?nTULKo
Y9G600OoY9G60_l00006ojRHa@;o00002?nl/<h2o`0000Go`;?=0_l00006olFgc006o`000?o9^/co
bK[<olVjc?l0003odm?I1OoGeMH01Ol0003ofmODom_Ge?oKemCo000000?ogmWA00?o0000on;KcooR
fll00_l00004onG[d`04onSZcol0003o0000o`0000;ojnS;00?oj>oAo`000?o[kL`00_o[kL`2o`00
00?ojn_<00Oo0000onSYcooXjLooj>W?o`000?oUhm3o000000?ogn;G00?o0000omcHdol000001?oC
d]P00ol0003ob<cMolS<g@02olS<g@03o`000?nk`n3o000000Wo000000?oVjcRo`000?n;Wn400_n;
Wn400ol0003oNY;NogZBgP02ogZBgP05o`000?m[Q]_oJhKKof^6fol000000omMNmP01Ol0003oDW7D
oe9ae?mBLMCo000000?o56;H00?o0000o`]Idol000000ol6E=02o`AAcP04o`000?l0D/Wo05K>o`00
027ooooo00?o0000ooooooooool06oooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool05_ooool00ol0003oQ7k5ohAna@07ohAna@03o`000?n6O/?o
QWk300KoQWk30_l00008oj2Ca`;o00002OnTULH00ol0003oZ9S5ojRHa@05ojRHa@03o`000?n/VlGo
000000Ko_;3>0_l00006ol2cc@03o`000?o5]lcoaKO<00CoaKO<0_l00003olVjc0;o00001OoGeMH0
1Ol0003ofmODom_Ge?oKemCo000000?ogmWA00Ko0000on;KcooRfloo0000onGLc?l00002onG[d`?o
000000Goj>[?o`000?o[j<_ojnS;o`000003on_]c0;o00001?o[jl`01Ol0003oj>W?onSYcooXjLoo
000000?oiN?@00?o0000omoReol000000_oLf=<00ol0003odm;Hom?Bf002om?Bf003o`000?o8c=go
b<cM00Co00000_nn]m<01Ol0003o/ZgCok:]donb[M?o000000?oYZ?C0ol00002oh^Oh@03o`000?mj
T]koNY;N00;oNY;N00Co0000of^6fom[Q]_oJhKK0_l00002oeekf003o`000?mBLMCoDW7D00;oDW7D
0_l000001OlDH]So0000o`]Idol;FM?o000000;o1UC@00Go0000o`AAc_l4DLko0000o`1Bb@02o`00
027ooooo00?o0000ooooooooool06_ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Gooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?n4O/GoQ7k500OoQ7k500?o0000ohIn`on6O/<01_n6O/<0
1?l0003oRX32ohZ0`_l00006oj2Ca`03o`000?nTULKoY9G600OoY9G60_l00007ojRHa@05o`000?n/
VlGo[9_5ojbKaOl000001?nl/<h00ol0003o`;?=ol2cc@04ol2cc@;o00001_o5]l`00ol0003obK[<
olVjc002olVjc003o`000?o>_/_o000000CoemGF00Go0000om_Ge?oKemCofmODo`000003omoId@04
o`000?oRflooh]_?o`0000;oiMc<0ol00003onSZc`04o`000?o[j<_ojnS;o`0000?ojng<00?o0000
ongZb?l000000oo[jl`01Ol0003oj>W?onSYcooXjLoo000000GoiN?@00?o0000omcHdooLf=<00_oL
f=<00ol0003odm;Hom?Bf004o`0000;ob<7C00Go0000okjgdonn]m?o_[OCo`000003ok:]d`03o`00
0?nVXm?oYZ?C00;oYZ?C00Go0000oi^IdOl0003oRioQo`000004ogZBgP09o`000?m[Q]_oJhKKof^6
fol0003oGG_Ho`000?mMNmSo000000CoDW7D0_m8JM400ol0003o56;Ho`000002o`]Id`?o1UC@0ol4
DLh4o`00023ooooo00?o0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Booooo`03o`000?n4O/GoQ7k500OoQ7k500?o0000ohIn`on6O/<01_n6O/<0
0ol0003oRX32ohZ0`P02ohZ0`P03o`000?nPTlOoX9?700;oX9?700?o0000ojBEa_nTULH01onTULH0
0ol0003oZ9S5ojRHa@06ojRHa@03o`000?n/VlGo[9_500?o[9_500Co0000okb`c_nl/<ko00001_o0
/ld00ol0003oaKO<olFgc005olFgc003o`000?o9^/cobK[<00;obK[<00Go0000oljnboo>_/_oc[k;
o`000002omOEePCofmOD00Go0000omoIdOoOfM7ogmWAo`000002on;Kc`Go000000CoiN_ConSZcooX
j/ooj>[?0oo[j</01oo]ilSo0000on_]c?o[kLco0000ongZb?l000000_o[jl`6o`0000GoiN?@0_l0
0004omcHd`05o`000?oCd]So0000om;9dOl000001?o8`M<01Ol0003o_[OCokjgdonn]m?o000000?o
/ZgC00?o0000ojJSdonVXm<00_nVXm<01?l0003oViWAoi^IdOnKVM42o`0000?oNY;N00Wo0000of^6
fom[Q]_oJhKKo`000?mMNmSo0000oeekf?l000001?mBLM@4odQYd@04o`000?l;FM?o2eWCo`0000;o
1UC@00?o0000o`AAc_l4DLh00_l6DLh3o`00023ooooo00?o0000ooooooooool06Oooool002Oooooo
0_l0000/ooooo`03o`000?oooooooooo013ooooo00?o0000ohAnaOn4O/D01on4O/D00ol0003oQWk3
ohIn``06ohIn``03o`000?n:P<;oRX3200CoRX3200?o0000oj2CaonPTlL02OnTULH2o`0000OoZ9S5
0_l00006ojbKa@;o00001_o0/ld2o`0000KoaKO<0_l00004olVjc003o`000?o>_/_oc[k;00;oc[k;
0_l00004om_Ge0CogmWA0_oRfll3o`0000;oiMc<0_l00003onSZc`?ojnS;0_o]ilP00ol0003ojng<
ongZb002ongZb0?o000000?ok^S7o`000?o/ilT00_o/ilT2o`0000?oiN?@00?o0000on?Lc_l00000
1?oLf=<2o`0000;od/WA00Go0000olS1doo8`M?ob<7Co`000003okjgd`05o`000?nb[M?o/ZgCok:]
dol000001?nVXm<00ol0003oViWAoi^Id@02oi^Id@;oT93?0_l000000omjT]ko0000of^6f`02of^6
f`03o`000?mMNmSoGG_H00;o00001?mBLM@00ol0003oB6WAodQYd@02odQYd@;o000000Co2eWCo`00
0?l6E=3o1UC@0ol4DLh3o`IAcP;o00008?ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00?o0000ohAnaOn4O/D01on4O/D00ol0
003oQWk3ohIn``06ohIn``03o`000?n:P<;oRX3200KoRX3200?o0000ojBEa_nTULH01onTULH00ol0
003oZ9S5ojRHa@06ojRHa@03o`000?n/VlGo[9_500Go[9_500?o0000ok6NaOl000001Oo0/ld00ol0
003oaKO<olFgc005olFgc003o`000?o9^/cobK[<00?obK[<00?o0000oljnboo>_//00_o>_//00ol0
003od/;:o`000003om_Ge0CogmWA1?l00003onGLc003o`000?oWgLWo000000;oj>[?0oo[j</2ongW
b004o`000?o[kLcokN[8ongZb0;o00001?o^j<L3oncWb@06o`000?oZhl[oj^?:o`000?oUhm3o0000
0ooSg<h00ol0003og=SComcHd`02o`0000;od/WA00?o0000olS1doo8`M<00_o8`M<01Ol0003o_[OC
okjgdonn]m?o000000?o/ZgC00?o0000ojJSdonVXm<00_nVXm<00ol0003oViWAoi^Id@02oi^Id@Go
T93?0_l00002of^6f`04o`000?mMNmSoGG_Hoeekf0;o00000omBLM@00ol0003oB6WAodQYd@02odQY
d@;o@F?>0_l00002o`IDd004o`000?l4DLko157>o`0000?o1U7>0_l0000Nooooo`;o00006_ooool0
02Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03o`000?n4O/GoQ7k5
00KoQ7k500?o0000ohIn`on6O/<01_n6O/<00ol0003oRX32ohZ0`P07ohZ0`P03o`000?nTULKoY9G6
00GoY9G60_l00008ojRHa@03o`000?n/VlGo[9_500Go[9_500Go0000ok6NaOnaW/Go/Ik5o`000003
ol2cc@03o`000?o5]lcoaKO<00CoaKO<0_l00004olVjc0;o00001?o>_//01_l0003od/;:om;2b_oB
`/[o0000om_Ge0;ogmWA0ol00002on;Kc`05o`000?oUg<coiMc<onGLc?l000000_oWgLT00ol0003o
j>[?on_Xb`02on_Xb`;okNO80_l00002ongZb003o`000?o_ilCo000000?ok^S700Co0000oncWbOo/
ilWo00001?oZhlX00ol0003ohmc>on?LcP02on?LcP?o000000Gofm3>o`000?oBbM7od/WAo`000004
olS1d`05o`000?nn]m?o_[OCokjgdol000000onb[M<00ol0003oYZ?CojJSd`02ojJSd`05o`000?nK
VM7oViWAoi^IdOl000001On@T<l2ohJ7c@03o`000?m[Q]_o000000CoGG_H00Go0000oe9ae?mBLMCo
DW7Do`000004odQYd@?o@F?>00Go2eWCo`000?l6E=3o1UC@o`000002o`AAcP?o1U7>0_l;E=000ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02oooool00ol0003oHf[4o`000006ohAna@03o`000?n6O/?oQWk300Ko
QWk300?o0000ohZ0`_n:P<801on:P<800ol0003oSX;2o`000005ojBEaP03o`000?nXV<GoZ9S500Ko
Z9S50_l00007ojbKa@03o`000?naW/Go/Ik500;o/Ik500?o0000ol2ccOo0/ld01oo5]l`00ol0003o
bK[<olVjc003olVjc003o`000?o>_/_oc[k;00?oc[k;00?o0000om;2b_oB`/X00_oB`/X4o`000003
omoIdOoRflooh]_?00;oh]_?0ooUg<`01Ol0003oimg9onOMbOoWgLWo000000?ojnS;0_o]ilP01Ol0
003ok^K5o`000?o]j/So000000;oknO40oo^j<L01?l0003ok>O9oncWbOl00004on[SbP;o00001?oS
g<h01Ol0003ofm3>om_@c_oKd<ko000000;od/WA00Go0000olS1doo8`M?ob<7Co`000004okjgd`05
o`000?nb[M?o/ZgCok:]dol000001?nVXm<01Ol0003oViWAoi^IdOnKVM7o000000GoT93?1?n6Qld2
o`0000?oGG_H00Go0000oe9ae?mBLMCoDW7Do`000004odQYd@05o`000?m1Hlko@F?>od5Sc_l00000
0_l6E=001?l0003o157>o`AAc_l00003o`IAcP;o2eC@00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Fooooo`009oooool2o`00033ooooo00?o0000ooooooooool02_ooool01?l0003oHf[4
of=Za?l00004ohAna@03o`000?n6O/?oQWk300KoQWk300?o0000ohZ0`_n:P<801on:P<801Ol0003o
SX;2ohj2`_n>P/;o000000?oY9G600?o0000ojRHaOnXV<D01_nXV<D00ol0003o[9_5ojbKa@06ojbK
a@03o`000?naW/Go/Ik500Co/Ik500?o0000olFgc?o5]l`01Oo5]l`00ol0003obK[<olVjc003olVj
c003o`000?o>_/_oc[k;00?oc[k;00Co0000om;2b_oB`/[od/;:0ol00003omoId@Coh]_?0ooUg<`0
0ol0003oimg9onOMb@02onOMb@03o`000?o[j<_ojnS;00;okNO800Co0000onkVaOo^i/GokN[80oo_
il@01?l0003ok^S7onkXaoo^j<L3o`0000Coj^?:00?o0000onSNbOl000000_oSg<h00ol0003oh]K;
o`000002om_@cP05o`000?oBbM7od/WAom;9dOl000000oo8`M<00ol0003o_[OCokjgd`02okjgd`05
o`000?nb[M?o/ZgCok:]dol000000onVXm<00ol0003oViWAoi^Id@02oi^Id@03o`000?n@T<ooT93?
00;oT93?00?o0000ohJ7cOn6Qld00_n6Qld2ogeob`03o`000?mMNmSoGG_H00;o00000_mBLM@00ol0
003oB6WAodQYd@02odQYd@03o`000?m1Hlko@F?>00;o@F?>00?o0000o`IDd?l000000ol4DLh3o`IA
cP?o2eC@00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`009_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00Go0000of=Za?mSJ/CoHf[4o`000003ohAn
a@03o`000?n6O/?oQWk300KoQWk300?o0000ohZ0`_n:P<801on:P<800ol0003oSX;2ohj2`P02ohj2
`P03o`000?nTULKoY9G600WoZ9S500?o0000ojbKaOn/VlD01On/VlD2o`0000Ko/Ik50_l00006olFg
c003o`000?o9^/cobK[<00?obK[<00?o0000oljnboo>_//00oo>_//00ol0003od/;:om;2bP03o`00
00;oelK900?o0000omoIdOoRfll00ooRfll3onGLc003o`000?oWgLWoimg900;oimg90_l000001?o[
j<_okNO8ongWb?l00002onkVa@03o`000?o_ilCoknO400;oknO400?o0000onkXaol000000_l00000
0oo^iLGo0000on[SbP02on[SbP06o`000?oXg/Woj=k9o`000?oSg<ko00000_oRe//01?l0003ofm3>
om_@c_l00003om;9d@05o`000?o8`M?ob<7ColS1dol000001?nn]m<01Ol0003o/ZgCok:]donb[M?o
000000?oYZ?C00?o0000oi^IdOnKVM400_nKVM400ol0003oT93?oi2@c`02oi2@c`03o`000?n6Qlgo
QXO=00;oQXO=0ommOl/01Ol0003oGG_Ho`000?mBLMCo000000;oDW7D00Go0000odQYdOm8JM7oB6WA
o`000004od5ScP04ocaOc?l0003o1UC@o`0000;o157>00Co0000o`IAc_l6DLko1U7>0ol;E=000ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo000Vooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00ol0003oHf[4of=Za002of=Za003o`000?n4O/Go000000So
QWk300?o0000ohZ0`_n:P<801on:P<800ol0003oSX;2ohj2`P04ohj2`P03o`000?nXV<GoZ9S500Oo
Z9S500?o0000ojbKaOn/VlD01On/VlD00ol0003o/Ik5ok6Na@05ok6Na@04o`000?nfX/Go]Z;5o`00
00CoaKO<1_o9^/`00ol0003oc[k;oljnb`03oljnb`Co000000?od/;:o`000?oGa/T00_oGa/T00ol0
003oh]_?on;Kc`02on;Kc`?oiMc<00?o0000onOMbOoWgLT00_oWgLT00ol0003oj]k7o`000003ongW
b0;ok^K500?o0000onoWa?o_il@00_o_il@3o`000008onoV`ol0003ok^G5o`000?o]hlGo0000on[S
b_l00003onSNb@;o00000_oRe//01Ol0003ofm3>om_@c_oKd<ko000000;od/WA00?o0000olS1doo8
`M<00_o8`M<01Ol0003o_[OCokjgdonn]m?o000000?o/ZgC00?o0000ojJSdonVXm<00_nVXm<01Ol0
003oViWAoi^IdOnKVM7o000000GoT93?00Go0000ohJ7cOn6QlgoQXO=o`000004ogeob`;o00000_mB
LM@00ol0003oDW7Do`000003odQYd@03o`000?m1Hlko@F?>00;o@F?>0_llGl`2o`0000?o157>00Co
0000o`IAc_l6DLko00000_l;E=000ol0003oooooooooo`0Looooo`;o00005_ooool002Kooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`000?mSJ/CoHf[400CoHf[400?o
0000ohIn`on6O/<01_n6O/<00ol0003oRX32ohZ0`P07ohZ0`P03o`000?n>P/;oSX;200GoSX;200?o
0000ojRHaOnXV<D01_nXV<D00ol0003o[9_5ojbKa@05ojbKa@03o`000?naW/Go/Ik500Go/Ik500?o
0000okJRaOnfX/D00_nfX/D00ol0003oaKO<olFgc006olVjc003o`000?o>_/_oc[k;00;oc[k;0ol0
0003om;2bP03o`000?oGa/WoelK900;oelK900Co0000on;KcooRflooh]_?0ooUg<`00ol0003oimg9
onOMb@02onOMb@04o`000?oZg/Ooj]k7o`0000;okNO80oo^i/D01?l0003oknO4onoWa?o_il@2o`00
00;oknK300?o0000onkUaOl000000oo]hlD00ol0003oj=k9onSNb@02onSNb@05o`000?oRe/_oh]K;
on;Fbol000000ooKd<h01?l0003od/WAom;9dOl00003olS1d`03o`000?nn]m?o_[OC00;o_[OC00Go
0000ok:]donb[M?o/ZgCo`000004ojJSd`05o`000?nKVM7oViWAoi^IdOl000001?n@T<l00ol0003o
QXO=ohJ7c@02ohJ7c@03o`000?mmOl_oOGo;00?oOGo;0_l000001?mBLMCo0000oe9ae?l00003odQY
d@03o`000?m1Hlko@F?>00;o@F?>00Go0000ocaOc?llGlco1UC@o`000002o`AAcP04o`000?l6DLko
1U7>o`0000?o2eC@00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`009_ooool3
o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003oHf[4of=Za004of=Za003o`000?n6O/?o
QWk300GoQWk300?o0000ohZ0`_n:P<801on:P<800ol0003oSX;2ohj2`P05ohj2`P03o`000?nBQL;o
000000KoZ9S52?n/VlD00ol0003o/Ik5ok6Na@05ok6Na@03o`000?nfX/Go]Z;500Co]Z;500?o0000
olVjc?o9^/`01?o9^/`3oljnb`?o00001OoB`/X00ol0003oelK9omO6b@02omO6b@04o`000?oKb/So
0000on;Kc`?oiMc<00?o0000onOMbOoWgLT00_oWgLT00ol0003oj]k7on[Na`02o`000004ongWb?o^
i/Gok^K5onkVa@;o00000_o_il@01Ol0003ol>K2o`000?o_i/?o000000;ok^G500Go0000ongSaOo]
hlGokN?5o`000003onSNb@;o00000ooRe//01Ol0003ofm3>om_@c_l0003od/WA017o00000onVXm<0
1Ol0003oViWAoi^IdOnKVM7o000000CoT93?00?o0000ohJ7cOn6Qld00_n6Qld00ol0003oOGo;ogeo
b`03ogeob`;oMGW900Co0000oe9ae?l0003o00000om8JM400ol0003o@F?>od5ScP02od5ScP05o`00
0?llGlco?5o<ocaOc?l000000_l4DLh01Ol0003o1U7>o`IAc_l6DLko000000;o2eC@00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo00;ooooo00?o0000of=Za?mSJ/@01?mSJ/@00ol0003oIFW2o`000005ohIn``03
o`000?n:P<;oRX3200OoRX3200?o0000ohj2`_n>P/801On>P/801Ol0003oTXG2oi:5`_nBQL;o0000
00CoZ9S52?n/VlD00ol0003o/Ik5ok6Na@05ok6Na@03o`000?nfX/Go]Z;500Co]Z;50_l00005olVj
c006oljnbol0003o0000o`000?o>_/_o00001OoB`/X00ol0003oelK9omO6b@02omO6b@04o`000?oK
b/Sofl[8o`0000CoiMc<1?oWgLT00ol0003oj]k7on[Na`02o`000004ongWb?o^i/Gok^K5onkVa@;o
00000_o_il@00ol0003ol>K2oo3V`P02onoV``03o`000?o^iLGo000000?okN?50_l00002onSNb@03
o`000?oWf/Oo000000?oh]K;00?o0000om_@c_l000000_l00002omG5bP05o`000?o=_L_ocKg;olfm
bol000001?o4]</01_l0003o^jc:ok^/b_nk[<[o0000ok:Sb@?o00001?nKVM400ol0003oT93?oi2@
c`02oi2@c`03o`000?n6QlgoQXO=00;oQXO=00?o0000ogeobommOl/00ommOl/3ogEib@03o`000?mB
LMCo000000?oB6WA00?o0000od5Sc_m1Hlh00_m1Hlh00ol0003o?5o<ocaOc002ocaOc0;o000000Go
157>o`000?l6DLko1U7>o`000002o`]Dd003o`000?oooooooooo01kooooo00?o0000ooooooooool0
4_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo
00Co0000oooooooooooo00001omSJ/@01?l0003oIFW2ofEY`_l00003ohIn``03o`000?n:P<;oRX32
00OoRX3200?o0000ohj2`_n>P/801On>P/800ol0003oTXG2oi:5`P03oi:5`P03o`000?nXV<GoZ9S5
00So[9_500?o0000ok6NaOnaW/D01OnaW/D00ol0003o]Z;5okJRa@04okJRa@04o`000?nkYlGo^jO5
o`0000;obK[<0ol00003oljnb`03o`000?oB`/[od/;:00?od/;:00?o0000omO6bOoGa/T00_oGa/T0
1Ol0003ofl[8om_:b?oKb/So000000?oiMc<1?oWgLT01_l0003oj]k7on[Naol0003ok=o5o`0000?o
k^K500Co0000onoU`_l0003oknO40oo`i/800oo_i/?o0000o`000002o`0000?okN?500?o0000oncP
aOo/h<D00_l00002onOJa`03o`000?oRe/_oh]K;00?o000000Gog<c9o`000?oEaL[oeLG:o`000003
olfmb`03o`000?o4]<_oa;C;00;oa;C;00Go0000ok^/b_nk[<[o^jc:o`000004ok:Sb@;o00000onK
VM400ol0003oT93?oi2@c`02oi2@c`05o`000?n6QlgoQXO=ohJ7cOl000001OmmOl/00ol0003oMGW9
ogEib@02ogEib@03oe9ae?l0003o000000;oB6WA00?o0000od5Sc_m1Hlh00_m1Hlh00ol0003o?5o<
ocaOc002ocaOc0;o>Ug<0_l00003o`IAcP04o`000?l;E=3o2eC@o`0001oooooo00?o0000oooooooo
ool04_ooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03So
oooo0ol00006of=Za003o`000?mUJL;oIFW200;oIFW200?o0000ohIn`ol000002On:P<800ol0003o
SX;2ohj2`P05ohj2`P03o`000?nBQL;oTXG200GoTXG200?o0000ojbKaOn/VlD01On/VlD2o`0000Oo
/Ik500?o0000okJRaOnfX/D01?nfX/D01?l0003o^jO5ok^WaOnkYlD3o`0000Koc[k;1OoB`/X00ol0
003oelK9omO6b@02omO6b@08o`000?oKb/Sofl[8om_:b?l0003oglk7o`000?oUg<`4onOMb@04o`00
0?oZg/Ooj]k7o`0000;ok=o500Co0000onkVaOo^i/Go00000_o_iL801?l0003ol>K2oo3V`_o`i/82
o`000003oo3T`?l0003ol>C100;o000000?okN?5o`000?o/h<D00_o/h<D01?l0003oim[7onOJaol0
0002on;Fb`;o00000_oLc<T01Ol0003oeLG:omG5b_oEaL[o000000?ocKg;00?o0000olBdboo4]</0
0_o4]</01Ol0003o^jc:ok^/b_nk[<[o000000Co/Z?900?o0000ojZKb?l000000_l00004oi2@c`03
o`000?n6QlgoQXO=00;oQXO=00?o0000ogeobommOl/00ommOl/00ol0003oMGW9ogEib@03ogEib@;o
00000_m8JM400ol0003o@F?>od5ScP02od5ScP03o`000?llGlco?5o<00;o?5o<0oljGL`01Ol4DLko
0000o`IAc_l6DLko000000;o2eC@00?o0000ooooooooool07_ooool00ol0003oooooooooo`07oooo
o`Co000000?o410@ooooooooool00oooool001_ooooo00Go410@oooooooooooooooooa0@4005oooo
o`?o0000>Oooool00ol0003oHf[4of=Za004of=Za003o`000?mUJL;oIFW200CoIFW200?o0000ohZ0
`_n:P<801on:P<800ol0003oSX;2ohj2`P05ohj2`P03o`000?nBQL;oTXG200KoTXG200?o0000ojbK
aOn/VlD01?n/VlD00ol0003o/Ik5ok6Na@06ok6Na@03o`000?nfX/Go]Z;500Co]Z;500?o0000ok^W
aOl000000_l000000onkYlGo0000oljnb`05oljnb`God/;:00?o0000omO6bOoGa/T00_oGa/T01Ol0
003ofl[8om_:b?oKb/So000000;oglk700?o0000onOMbOoWgLT00_oWgLT01?l0003oj]k7on[Naol0
0002oncOa@;o00000_o^i/D3onoU`P04o`000?o`i/;ol>K2o`0000?ol>C00_o`i<42onoS`P06o`00
0?o/h<Gok>35o`000?o[gLCo00000_oWf/L01Ol0003oh]K;o`000?oRd/Oo000000;og<c900Go0000
omG5b_oEaL[oeLG:o`000003olfmb`05o`000?o4]<_oa;C;olBdbol000000onk[<X00ol0003o/Z?9
ok:Sb@02ok:Sb@03o`000?nZVlSoZY_800;oZY_80_l00003oi2@c`03o`000?n6QlgoQXO=00;oQXO=
00?o0000ogeobommOl/00ommOl/00ol0003oMGW9ogEib@03ogEib@05oficaol0003o0000odQYdOl0
00001?m1Hlh00ol0003o?5o<ocaOc002ocaOc005o`000?ljGLco>Ug<ocYMc?l000000ol6DLh01?l0
003o2eC@o`]Dd?l0000Nooooo`?o00002_ooool00ol0003oooooooooo`05ooooo`006oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>Oooool00ol0003oHf[4of=Za004
of=Za003o`000?mUJL;oIFW200CoIFW200?o0000ohZ0`_n:P<801_n:P<800ol0003oSX;2ohj2`P05
ohj2`P03o`000?nBQL;oTXG200KoTXG200?o0000oiN8`_l000001On/VlD8ok6Na@03o`000?nfX/Go
]Z;500Co]Z;50ol00004ok^Wa@;o00001?o>_//5om;2bP03o`000?oGa/WoelK900;oelK900Go0000
om_:b?oKb/Sofl[8o`000003omo>a`03o`000?oWgLWoimg900;oimg90_oZg/L01ol0003ok=o5oncO
aOl0003okN33o`000?o^i/D00oo_iL82o`000003oo3V`_l0003o000000;ol>C000?o0000oo3T`Ol0
00000_o_hl800ol0003ok>35o`000002on_Ma003o`000?oWf/Ooim[700;o00000_oRd/L01?l0003o
g<c9omc<bOl00002omG5bP05o`000?o=_L_ocKg;olfmbol000001?o4]</01Ol0003o^jc:ok^/b_nk
[<[o000000Co/Z?900?o0000ojZKb?nZVlP00_nZVlP00ol0003oXYC6o`000002oi2@c`05o`000?n6
QlgoQXO=ohJ7cOl000001OmmOl/00ol0003oMGW9ogEib@03ogEib@03o`000?m^LlOoKW?700?o0000
1?m1Hlh00ol0003o?5o<ocaOc002ocaOc003o`000?ljGLco>Ug<00;o>Ug<0_l000001Ol6DLko0000
o`]Dd?l;E=3o0000023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`00
6oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>?ooool00ol0003o
Hf[4of=Za004of=Za003o`000?mUJL;oIFW200CoIFW200?o0000ofU[`_l000001_n:P<800ol0003o
SX;2ohj2`P05ohj2`P03o`000?nBQL;oTXG200KoTXG200Go0000oiN8`_nGR<;oUhS2o`000003ojbK
a@So/Ik500?o0000okJRaOnfX/D00_nfX/D3o`0000Ko^jO500Co0000ol6/aOo1[<Go00000_o>_//5
om;2bP03o`000?oGa/WoelK900;oelK900Go0000om_:b?oKb/Sofl[8o`000003omo>a`03o`000?oS
dLKo000000;oimg90_oZg/L01?l0003ok=o5oncOaOl00002ongP``04o`000?o_iL;oknG2onoU`P;o
00000_o`i/801_oai;ool>C0oo3T`?l0003ol>C1o`0000;okn?20ol00003on_Ma004o`000?oWf/Oo
0000o`0000;oh];700Co0000omc<bOoLc<Wo00000ooEaLX01Ol0003ocKg;olfmboo=_L_o000000?o
a;C;00?o0000ok^/b_nk[<X00_nk[<X01Ol0003o/Z?9ok:SbOnbXlWo000000CoZY_800Co0000oj:D
a_nRU<KoXYC60_l00004ohJ7c@03o`000?mmOl_oOGo;00?oOGo;00?o0000ogEibOmeNLT00omeNLT0
1?l0003oKW?7oficaom^LlL2o`0000Co@F?>00?o0000ocaOc?llGl`00_llGl`00ol0003o>Ug<ocYM
c002ocYMc0;o>Eg<0_l00003o`]Dd003o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0>?ooool00ol0003oHf[4of=Za004of=Za003o`000?mUJL;oIFW200CoIFW200Co
0000ofU[`_mYJl;o00001?n:P<800ol0003oSX;2ohj2`P05ohj2`P03o`000?nBQL;oTXG200KoTXG2
00?o0000oiN8`_nGR<800_nGR<800ol0003o[9_5ojbKa@08ok6Na@03o`000?nfX/Go]Z;500?o0000
00?o]Z;5o`000?nkYlD01OnkYlD00ol0003o`Jc5ol6/a@02ol6/a@03o`000?oB`/[od/;:00?od/;:
00?o0000omO6bOoGa/T00_oGa/T01Ol0003ofl[8om_:b?oKb/So000000?oglk700Go0000on?Aa_oS
dLKohm76o`000002on[Na`04o`000?o/glGok=o5o`0000?okN3300_o0000onoU`_o_iL;o0000oo3T
`?l0003ol>K2oo7T_ol0003ol>C0o`000002oo3T`@05o`000?o_hl;o0000onoQ`_l000000oo[gL@0
1Ol0003oim[7o`000?oWelGo000000;oh];700Co0000omc<bOoLc<Wo00000ooEaLX01Ol0003ocKg;
olfmboo=_L_o000000?oa;C;00Go0000ok^/b_nk[<[o^jc:o`000004ok:Sb@03o`000?nZVlSoZY_8
00;oZY_800?o0000oj:Da_nRU<H00_nRU<H2o`0000?oQXO=00?o0000ogeobommOl/00ommOl/00ol0
003oMGW9ogEib@03ogEib@03o`000?m^LlOoKW?700;oKW?70_l00003od5ScP03o`000?llGlco?5o<
00;o?5o<00?o0000ocYMc?ljGL`00_ljGL`3ocUMc005o`IAc_l0003o2eC@o`]Dd?l000008?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2o`0003Sooooo00?o0000of=Za?mSJ/@01?mSJ/@00ol0003oIFW2ofEY`P04
ofEY`P05o`000?mYJl;oJF_2ofU[`_l000000on:P<800ol0003oSX;2ohj2`P06ohj2`P03o`000?nB
QL;oTXG200GoTXG200?o0000oiN8`_nGR<801?nGR<800ol0003o/Ik5ok6Na@06ok6Na@Co00000onf
X/D00ol0003o^jO5ok^Wa@04ok^Wa@03o`000?o1[<Go`Jc500?o`Jc500?o0000om;2b_oB`/X00ooB
`/X4omO6b@05o`000?oKb/Sofl[8om_:b?l000000ooOc/L00ol0003ohm76on?AaP02on?AaP03o`00
0?oZg/Ooj]k700?ok=o500?o0000ongP`oo]h<<00_l000001Oo_iL;o0000oo3T`?o`i<3o000000;o
lNBo00?o0000oo3T`?l000000_o`i<401Ol0003okn?2o`000?o_hL;o000000?ojmg40_l000000ooW
elGo0000on;Ba`02on;Ba`04o`000?oLc<Wog<c9o`0000;oeLG:00Go0000olfmboo=_L_ocKg;o`00
0004olBdb`05o`000?nk[<[o^jc:ok^/b_l000000onbXlT00ol0003oZY_8ojZKb002ojZKb003o`00
0?nRU<KoXYC600?oXYC600?o0000oiZ=aOl000000_n6Qld00ol0003oOGo;ogeob`03ogeob`03o`00
0?meNLWoMGW900;oMGW900?o0000oficaom^LlL00om^LlL00omYKlKo0000o`000002od5ScP03o`00
0?llGlco?5o<00;o?5o<00?o0000ocYMc?ljGL`00_ljGL`01Ol0003o>Eg<ocUMc?liGLco000000;o
2eC@00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0gooooo`03
o`000?mSJ/CoHf[400CoHf[400?o0000ofEY`_mUJL801?mUJL800ol0003oJF_2ofU[`P02ofU[`P03
o`000?n:P<;o000000SoSX;200?o0000oi:5`_nBQL801OnBQL800ol0003oUhS2oiN8`P05oiN8`P03
o`000?naW/Go/Ik500Co/Ik50ol00005okJRa@03o`000?nkYlGo^jO500Co^jO500?o0000ol6/aOo1
[<D00oo1[<D00ol0003oa[76o`000003om;2bPCoelK900Go0000om_:b?oKb/Sofl[8o`000003omo>
a`03o`000?oSdLKohm7600;ohm7600?o0000onKDaOl000000oo/glD01Ol0003okN33ongP`ol0003o
kn7100;o00000_o`i<02o`000003oo7T_ol0003o000000Co000000?okn?2o`000?o_hL800_l00002
on_Ma0;o00000_oWelD01?l0003oh];7on;Baol00002omc<b@05o`000?oEaL[oeLG:omG5b_l00000
0oo=_L/01Ol0003oa;C;olBdboo4]<_o000000?o^jc:00?o0000ok:SbOnbXlT00_nbXlT00ol0003o
ZY_8ojZKb002ojZKb003o`000?nRU<KoXYC600;oXYC600Co0000oiZ=aOnJSLGoVXg50_l00005ogeo
b`03o`000?meNLWoMGW900?oMGW900?o0000oficaom^LlL00_m^LlL00ol0003oJFo6ofU_aP02o`00
0003od5Sc_l0003o?5o<00?o?5o<00?o0000ocYMc?ljGL`00_ljGL`00ol0003o>Eg<ocUMc002ocUM
c004o`000?l;E=3o2eC@o`00023ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Toooo
o`03o`000?oooooooooo03Oooooo00?o0000of=Za?mSJ/@01?mSJ/@00ol0003oIFW2ofEY`P04ofEY
`P03o`000?mYJl;oJF_200CoJF_200?o0000ohj2`_n>P/801_n>P/800ol0003oTXG2oi:5`P05oi:5
`P03o`000?nGR<;oUhS200GoUhS200?o0000oif=`_l000000_naW/D4o`0000Ko]Z;500?o0000ok^W
aOnkYlD01?nkYlD00ol0003o`Jc5ol6/a@03ol6/a@04o`000?o6/LKoa[76o`0000;od/;:1?oGa/T0
0ol0003ofl[8om_:b002om_:b004o`000?oOc/Ooglk7o`0000Cohm7600Co0000onKDaOoVe<Go0000
0_o/glD01?l0003okN33ongP`ol00002onoQ`@06o`000?o`i<3ol>C0o`000?oahkoolNBo0_l00000
1?oahkko0000oo7S__oahkh2o`000008onoQ`_l0003ok]o1o`000?o[gLCo0000on_K`ol00002onOG
a@04o`000?oRd/Ooh];7o`0000;og<c900Go0000omG5b_oEaL[oeLG:o`000003olfmb`05o`000?o4
]<_oa;C;olBdbol000000onk[<X01Ol0003o/Z?9ok:SbOnbXlWo000000CoZY_800?o0000oj:Da_nR
U<H00onRU<H00ol0003oVXg5oiZ=a@02oiZ=a@;o00001?mmOl/00ol0003oMGW9ogEib@03ogEib@03
o`000?m^LlOoKW?700;oKW?700Co0000ofU_a_mYKlKoJFo60ol00004ocaOc003o`000?ljGLco>Ug<
00;o>Ug<00?o0000ocUMc?liGL`00_liGL`01?ljGlgo0000o`]Dd?l0000Oooooo`03o`000?oooooo
000000Gooooo00?oEEEEofIVI_l000001oooool002Cooooo00?o0000ooooooooool0=oooool00ol0
003oHf[4of=Za004of=Za003o`000?mUJL;oIFW200CoIFW200?o0000ofU[`_mYJl801?mYJl800ol0
003oSX;2ohj2`P05ohj2`P03o`000?nBQL;oTXG200GoTXG200?o0000oiN8`_nGR<801OnGR<801?l0
003oWHg2oif=`_nMSL82o`0000;o/Ik500?o0000okJRaOnfX/D01?nfX/D00ol0003o^jO5ok^Wa@04
ok^Wa@03o`000?o1[<Go`Jc500?o`Jc500?o0000olJaa_o6/LH00_o6/LH2o`0000CoelK91?oKb/P0
1?l0003oglk7omo>aol00004on?AaP07o`000?oVe<Goi]C5o`000?oYf<Co0000oncOa@02ongP``08
o`000?o_hL7okn71onoQ`Ol0003ol>C0o`000?oahkl2o`000003oo7S__l0003olN>n00;olN>n00Co
0000oo7R_ol0003o00000_o^gl42o`000005on_K`ol0003oimO5onOGaOl000000ooRd/L01?l0003o
g<c9omc<bOl00002omG5bP05o`000?o=_L_ocKg;olfmbol000000oo4]</01Ol0003o^jc:ok^/b_nk
[<[o000000Co/Z?900?o0000ojZKb?nZVlP00_nZVlP00ol0003oXYC6oj:DaP02oj:DaP03o`000?nJ
SLGoVXg500?oVXg500Co0000oiB7`ol0003o00000_mmOl/00ol0003oMGW9ogEib@02ogEib@03o`00
0?m^LlOoKW?700?oKW?700Oo0000ofU_a_mYKlKoJFo6o`000?mYKlKo000000Co?5o<00?o0000ocYM
c?ljGL`00_ljGL`00ol0003o>Eg<ocUMc002ocUMc0;o>Uo=00?o0000o`]Dd?l000008Oooool00ol0
003oooooooooo`0<ooooo`009?ooool2o`0003Sooooo00?o;Tk2o`000?mSJ/@00omSJ/@00ol0003o
IFW2ofEY`P04ofEY`P03o`000?mYJl;oJF_200CoJF_200?o0000ofe^`_l000001On>P/800ol0003o
TXG2oi:5`P05oi:5`P03o`000?nGR<;oUhS200GoUhS200?o0000oif=`_l000000_l000001?nMSL;o
0000ok6NaOnaW/D6okJRa@03o`000?nkYlGo^jO500Co^jO500?o0000ol6/aOo1[<D00oo1[<D00ol0
003oa[76olJaaP03olJaaP03o`000?o<]lKo000000;oelK91?oKb/P01Ol0003oglk7omo>aooOc/Oo
000000?ohm7600Co0000onKDaOoVe<Go00000_oYf<@01Ol0003okN33ongP`oo]h<?o000000;okn71
0ol00002oo7S_`08o`000?oahkkolN>noo7S__l0003olN>no`000?oah[l2o`0000?ok]o100Co0000
on_K`oo[fl?o00000_oWelD01Ol0003oh];7on;Baol0003og<c900co000000?oa;C;o`000?nk[<X0
0_nk[<X01Ol0003o/Z?9ok:SbOnbXlWo000000CoZY_800?o0000oj:Da_nRU<H00onRU<H00ol0003o
VXg5oiZ=a@02oiZ=a@03o`000?nDQl?oU8O300;oU8O30_l00005ogEib@03o`000?m^LlOoKW?700;o
KW?700?o0000ofU_a_mYKlH00omYKlH00ol0003oIFc5o`000003ocaOc003o`000?ljGLco>Ug<00;o
>Ug<00?o0000ocUMc?liGL`00_liGL`00ol0003o>Uo=ocYOc@02o`00023ooooo0ol0000=ooooo`00
9?ooool00ol0003oooooooooo`0gooooo`;o;Tk200Co0000of=Za?mSJ/Co00001_mUJL800ol0003o
JF_2ofU[`P05ofU[`P04o`000?m]K/;oKFk2o`0000?oSX;200?o0000oi:5`_nBQL801_nBQL800ol0
003oUhS2oiN8`P04oiN8`P?o00001OnMSL800ol0003o]Z;5okJRa@04okJRa@03o`000?nkYlGo^jO5
00Co^jO500?o0000ol6/aOo1[<D00oo1[<D00ol0003oa[76olJaaP03olJaaP05o`000?o<]lKoc;O6
olbga_l000001?oKb/P01Ol0003oglk7omo>aooOc/Oo000000?ohm7600Co0000onKDaOoVe<Go0000
0ooYf<@01?l0003okN33ongP`ol00002onoQ`@03o`000?o`hKoo000000;olN>o00?o0000oo7S__oa
hkh00_l00002oo7S_P;o000000Sol>6oo`000?o^gl7o0000onkN`?l0003ojm_3o`0000?oimO51Ol0
00000ooOc<Go0000omW6aP02omW6aP05o`000?oC_lKodko6om>oa_l000000_o<^<H3o`0000;o^jc:
00Go0000ok:SbOnbXlWo/Z?9o`000004ojZKb003o`000?nRU<KoXYC600;oXYC600?o0000oiZ=aOnJ
SLD00onJSLD00ol0003oU8O3oiB7``03oiB7``03o`000?meNLWoMGW900?oMGW900?o0000oficaom^
LlL00_m^LlL00ol0003oJFo6ofU_aP04ofU_aP03o`000?mUK<Go000000;o?5o<00?o0000ocYMc?lj
GL`00_ljGL`00ol0003o>Eg<ocUMc002ocUMc005o`000?ljGlgo>Uo=ocYOcOl000007Oooool3o`00
00;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=oooool3obi>`P03
o`000?mSJ/Co000000KoIFW200?o0000ofU[`_mYJl801?mYJl800ol0003oKFk2ofe^`P02ofe^`P03
o`000?n>P/;o000000SoTXG200?o0000oiN8`_nGR<800_nGR<83o`0000SoWHg200?o0000okJRaOnf
X/D00onfX/D00ol0003o^jO5ok^Wa@05ok^Wa@03o`000?o1[<Go`Jc500;o`Jc500?o0000olJaa_o6
/LH00oo6/LH00ol0003oc;O6olbgaP02olbgaP05o`000?oKb/Sofl[8om_:b?l000000ooOc/L01Ol0
003ohm76on?Aa_oSdLKo000000?oi]C500Go0000onWHa?oYf<Co0000on_J`P02o`0000;okn7100Co
0000oo3Q_oo`hKoo00000_oahkl01_l0003olN>noo7S__oahkko0000oo7S_P;o000000Kol>6oo`00
0?l0003o0000onkN`?l00002on_K``03o`000?oWelGo000000;o00000_oTd/@00ol0003oglc5o`00
0003omW6aP05o`000?oC_lKodko6om>oa_l000000oo<^<H00ol0003oaK36olF`aP03o`0000;o/Z?9
00?o0000ojZKb?nZVlP00_nZVlP00ol0003oXYC6oj:DaP03oj:DaP03o`000?nJSLGoVXg500;oVXg5
00?o0000oiB7`onDQl<01?nDQl<00ol0003oMGW9ogEib@02ogEib@03o`000?m^LlOoKW?700?oKW?7
00?o0000ofU_a_mYKlH00omYKlH01ol0003oIFc5o`000?mUK<Go0000ocaOc?l000001?ljGL`00ol0
003o>Eg<ocUMc002ocUMc003o`000?ljGlgo>Uo=00;o>Uo=00?o0000ooooooooool05oooool3o`00
00Gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003o
;Tk2obi>`P02obi>`P03o`000?mUJL;oIFW200CoIFW200?o0000ofU[`_mYJl801?mYJl800ol0003o
KFk2ofe^`P04ofe^`P03o`000?nBQL;oTXG200KoTXG200?o0000oiN8`_nGR<800ol00002oiN8`P03
o`000?nMSL;oWHg200GoWHg200?o0000oj>B`ol000000onfX/D00ol0003o^jO5ok^Wa@05ok^Wa@03
o`000?o1[<Go`Jc500;o`Jc500?o0000olJaa_o6/LH00oo6/LH00ol0003oc;O6olbgaP02olbgaP03
o`000?oA_<Ko000000;ofl[80ooOc/L00ol0003ohm76on?AaP02on?AaP04o`000?oVe<Goi]C5o`00
00;ojMS400Co0000on_J`_o[f/;o00000_o_hL400ol0003ol>6ooo3Q_`02o`000004oo7S_ol0003o
0000oo7S_PGo000000Col>6oo`000?l0003o00000_o^g/000ol0003ojm_3on_K``02o`000005onWG
`ol0003oi=;4onCBa?l000000_oOc<D01Ol0003ofLK6omW6a_oIa/Ko000000;odko600Go0000olbh
a_o<^<Koc;S6o`000004olF`aP05o`000?nnZLGo0000ok:SbOl000001?nZVlP00ol0003oXYC6oj:D
aP02oj:DaP03o`000?nJSLGoVXg500?oVXg500?o0000oiB7`onDQl<00onDQl<00ol0003oSX?2o`00
0003ogEib@03o`000?m^LlOoKW?700;oKW?700?o0000ofU_a_mYKlH01?mYKlH00ol0003oIFc5o`00
0002ofE/a@;o00001?ljGL`00ol0003o>Eg<ocUMc002ocUMc003o`000?ljGlgo>Uo=00;o>Uo=00?o
0000ooooooooool04oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000g
ooooo`03o`000?l^C/;o;Tk200;o;Tk200?o0000ofEY`_mUJL801?mUJL800ol0003oJF_2ofU[`P04
ofU[`P03o`000?m]K/;oKFk200CoKFk200?o0000oi:5`_nBQL801OnBQL84o`0000CoUhS200?o0000
oif=`_nMSL801OnMSL801Ol0003oXi;3oj>B`onST/?o000000;o]Z;51onkYlD00ol0003o`Jc5ol6/
a@02ol6/a@03o`000?o6/LKoa[7600?oa[7600?o0000olbga_o<]lH00_o<]lH01Ol0003odKc6om6l
a_oA_<Ko000000?oglk700?o0000on?Aa_oSdLH00_oSdLH01?l0003oi]C5onKDaOl00003onWHa006
o`000?o[f/;ojm[2o`000?o_hL7o00000_o`hKl01ol0003olN6no`000?l0003ol^:mo`000?oahkh0
0_l000001?obh[go0000oo3Q_oo`hKl2o`0000?ok]k00ol00002onWG``05o`000?oTd/Coi=;4onCB
a?l000000_oOc<D01?l0003ofLK6omW6a_l00003om>oaP05o`000?o<^<Koc;S6olbha_l000000oo5
/<H01?l0003o_ZW5okjYaOnnZLD2o`0000?oZY_800?o0000oj:Da_nRU<H00onRU<H00ol0003oVXg5
oiZ=a@02oiZ=a@03o`000?nDQl?oU8O300CoU8O300Co0000ohj3`_n>Pl;o00000_meNLT00ol0003o
KW?7ofica`02ofica`03o`000?mYKlKoJFo600CoJFo600Co0000ofE/aOmUK<Go00000_mUK<D00ol0
003o>Ug<ocYMc002ocYMc003o`000?liGLco>Eg<00;o>Eg<00?o0000ocYOcOljGld00_ljGld00ol0
003oooooooooo`0@ooooo`?o00003Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`0gooooo`03o`000?l^C/;o;Tk200;o;Tk200?o;dk1o`000?mUJL800omUJL800ol0003o
JF_2ofU[`P04ofU[`P03o`000?m]K/;oKFk200CoKFk200?o0000og=a`_l000001?nBQL83o`0000Ko
UhS200?o0000oif=`_nMSL801OnMSL800ol0003oXi;3oj>B``03oj>B``03o`000?nkYlGo^jO500Go
^jO500?o0000ol6/aOo1[<D00oo1[<D00ol0003oa[76olJaaP03olJaaP05o`000?o<]lKoc;O6olbg
a_l000001?oA_<H2o`0000;oglk71?oSdLH01?l0003oi]C5onKDaOl00003onWHa006o`000?o[f/;o
jm[2o`000?o]g<7o00000_o`hKl02?l0003olN6noo7Q__l0003ol^:mo`000?oahkko00000oobh[d0
0ol0003ol>6oo`000002o`0000;ok]k00_l000001Oo/fl7o0000onWG`ooYel?o000000;oi=;400Co
0000omo<aOoOc<Go00000ooIa/H01?l0003odko6om>oa_l00003olbhaP05o`000?o5/<KoaK36olF`
a_l000001?nnZLD01_l0003o]j?4o`000?l0003oZY_8o`0000CoXYC600?o0000oiZ=aOnJSLD00onJ
SLD00ol0003oU8O3oiB7``03oiB7``03o`000?n>Pl;oSX?200;oSX?20_l00005ofica`03o`000?mY
KlKoJFo600?oJFo600?o0000ofE/aOmUK<D00_mUK<D01?l0003oIFc5of9[aOl00003ocYMc003o`00
0?liGLco>Eg<00;o>Eg<00?o0000ocYOcOljGld00_ljGld00ol0003oooooooooo`0=ooooo`?o0000
4?ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`000?l^
C/;o;Tk200;o;Tk20_l_C/401Ol0003oIFW2ofEY`_mUJL;o000000KoJF_200?o0000ofe^`_m]K/80
1?m]K/800ol0003oLg72og=a`P05o`0000OoUhS200?o0000oif=`_nMSL801OnMSL800ol0003oXi;3
oj>B``04oj>B``;o00001OnkYlD00ol0003o`Jc5ol6/a@03ol6/a@03o`000?o6/LKoa[7600?oa[76
00?o0000olbga_o<]lH00_o<]lH01Ol0003odKc6om6la_oA_<Ko000000;oe/;60_l00003on?AaP04
o`000?oVe<Goi]C5o`0000?ojMS400Co0000on_J`_o[f/;o00000_o]g<401?l0003ol>6ooo3Q_ol0
0002oo7Q_P03o`000?obh[go000000?o000000?ol^:mo`000?obh[d00_l000000oo`h;ko0000onkN
`002o`000003oncK`Ol0003ojMO300;ojMO300Co0000onCBa?oTd/Co00000_oOc<D01?l0003ofLK6
omW6a_l00003om>oaP04o`000?o<^<Koc;S6o`0000CoaK3600Go0000okjYaOnnZLGo_ZW5o`000004
okNSa0;o00001?nRU<H00ol0003oVXg5oiZ=a@02oiZ=a@03o`000?nDQl?oU8O300?oU8O300?o0000
ohj3`_n>Pl801?n>Pl800ol0003oKW?7ofica`02ofica`03o`000?mYKlKoJFo600CoJFo600?o0000
ofE/aOmUK<D00omUK<D01?l0003oHV_5of9[aOl00002ocYMc003o`000?liGLco>Eg<00;o>Eg<00?o
0000ocYOcOljGld00_ljGld00ol0003oooooooooo`09ooooo`Co00004oooool00ol0003ooooooooo
o`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`000?l^C/;o;Tk200;o;Tk20_l_C/40
1?l0003oIFW2ofEY`_l00006ofU[`P03o`000?m]K/;oKFk200CoKFk200?o0000og=a`_l000000ol0
00000onBQL;o0000oiN8`P06oiN8`P03o`000?nMSL;oWHg200GoWHg200?o0000oj>B`onST/<01?nS
T/<01?l0003oZYS4ojZHa?l00003ok^Wa@03o`000?o1[<Go`Jc500?o`Jc500?o0000olJaa_o6/LH0
0oo6/LH00ol0003oc;O6olbgaP02olbgaP05o`000?oA_<KodKc6om6la_l000000ooF`/H01Ol0003o
flO5o`000?oSdLKo000000?oi]C500Go0000onWHa?oYf<CojMS4o`000002on_J`P04o`000?o]g<7o
0000onoN_`;o00000_oahKh2o`000003oo;R_Ol0003ol^:m00;ol^:m0_l000000oobh[go0000oo3P
_P03o`000004onoN_ol0003ok=_1o`0000;ojMO300Co0000onCBa?oTd/Co00000_oOc<D01Ol0003o
fLK6omW6a_oIa/Ko000000;odko600Go0000olbha_o<^<Koc;S6o`000003olF`aP05o`000?nnZLGo
_ZW5okjYaOl000001OngXl@00ol0003o/Ig3o`000002oj:DaP03o`000?nJSLGoVXg500;oVXg500?o
0000oiB7`onDQl<01?nDQl<00ol0003oSX?2ohj3`P04ohj3`P03ohUn`Ol0003oKW?700;oKW?700?o
0000ofU_a_mYKlH01?mYKlH00ol0003oIFc5ofE/a@03ofE/a@07o`000?mRJlGoHV_5of9[aOl0003o
>Ug<o`000004ocUMc003o`000?ljGlgo>Uo=00;o>Uo=00?o0000ooooooooool01_ooool3o`0001Oo
oooo00?o0000ooooooooool02_ooool002?ooooo0ol0000gooooo`05o`000?l^C/;o;Tk2obi>`_l0
00000ol_C/400ol0003oIFW2o`000006ofU[`P03o`000?m]K/;oKFk200?oKFk20ol00004og=a`P03
o`000?nGR<;oUhS200KoUhS200?o0000oif=`_nMSL801OnMSL800ol0003oXi;3oj>B``03oj>B``03
o`000?nZV<CoZYS400;oZYS400?o0000ok^WaOnkYlD01Oo1[<D00ol0003oa[76olJaaP03olJaaP03
o`000?o<]lKoc;O600;oc;O600?o0000om6la_oA_<H00_oA_<H01?l0003oe/;6omK2a_l00003om_7
a@05o`000?oVe<Goi]C5onKDaOl000000ooYf<@01_l0003ojm[2on_J`_l0003okMc1o`0000;okmjo
00Go0000oo7Q__oahKko0000oo7R_@07o`000005oo;R_Ol0003ol>2noo3P__l000000_o_g[l01?l0
003ok=_1oncK`Ol00002onWG``04o`000?oTd/Coi=;4o`0000;oglc500Co0000omW6a_oIa/Ko0000
0_oC_lH01Ol0003oc;S6olbha_o<^<Ko000000CoaK3600Go0000okjYaOnnZLGo_ZW5o`000004okNS
a007o`000?naWL?o/Ig3ok6M`ol0003oXYC6o`000004oiZ=a@03o`000?nDQl?oU8O300?oU8O300?o
0000ohj3`_n>Pl801?n>Pl801?l0003oRGk1ohUn`Ol00002ofica`03o`000?mYKlKoJFo600?oJFo6
00?o0000ofE/aOmUK<D01?mUK<D2o`0000?oHV_50_l00004ocUMc003o`000?ljGlgo>Uo=00;o>Uo=
00?o0000ooooooooool00oooool3o`0001[ooooo00?o0000ooooooooool02_ooool002?ooooo00?o
0000ooooooooool0=oooool01Ol0003o;Tk2obi>`_l^C/;o000000Co;dk100?o0000ofU[`_mYJl80
1?mYJl801?l0003oKFk2ofe^`_m]K/84o`0000KoLg7200?o0000oiN8`_nGR<801OnGR<800ol0003o
WHg2oif=`P05oif=`P03o`000?nST/?oXi;300CoXi;300?o0000ojZHa?nZV<@00onZV<@00ol0003o
`Jc5ol6/a@03ol6/a@03o`000?o6/LKoa[7600?oa[7600?o0000olbga_o<]lH00_o<]lH00ol0003o
dKc6om6laP02om6laP04o`000?oF`/Koe/;6o`0000CoflO50_l000000ooVe<Go0000onWHa002onWH
a004o`000?o[f/;ojm[2o`0000;okMc100Ko0000onoN_oo_g[oo0000oo7Q__l00002oo7R_@03o`00
0?obh[co000000?o00000_obh[d2o`000007oo3P__l0003okmjoonoN_ol0003ok=_1o`000002onWG
``04o`000?oTd/Coi=;4o`0000;oglc500Go0000omW6a_oIa/KofLK6o`000002om>oaP05o`000?o<
^<Koc;S6olbha_l000000oo5/<H01Ol0003o_ZW5okjYaOnnZLGo000000Co]j?400?o0000ok6M`ona
WL<00onaWL<00ol0003oVXg5oiZ=a@02oiZ=a@03o`000?nDQl?oU8O300CoU8O300?o0000ohj3`_n>
Pl800on>Pl800ol0003oRGk1ohUn`@02ohUn`@;o00001_mYKlH00ol0003oIFc5ofE/a@03ofE/a@04
o`000?mRJlGoHV_5o`0000?oHV_500?o0000ocUMc?liGL`00_liGL`00ol0003o>Uo=ocYOc@02ocYO
c@03o`000?oooooooooo00?o00007Oooool00ol0003oooooooooo`0:ooooo`0000Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04
ooooo`03o`000?oooooooooo03Sooooo00Go0000obi>`_l^C/;o;Tk2o`000004obm>`@03o`000?mY
Jl;oJF_200CoJF_21?l00003ofe^`P03o`000?mcLL;oLg7200?oLg7200?o0000ogYg`ol000001OnG
R<800ol0003oWHg2oif=`P05oif=`P03o`000?nST/?oXi;300CoXi;300?o0000ojZHa?nZV<@01?nZ
V<@2o`0000?o`Jc500?o0000olJaa_o6/LH00oo6/LH00ol0003oc;O6olbgaP02olbgaP03o`000?oA
_<KodKc600;odKc600Go0000omK2a_oF`/Koe/;6o`000003om_7a@03o`000?oPcLGoh<g500;o0000
0ooYf<@00ol0003ojm[2o`000002ongL`@06o`000?o_g[ookmjoo`000?o`h;ko00000ooah[d6o`00
0005oo;R_Ol0003o0000oo3P__l000000_o_g[l01?l0003ok=_1oncK`Ol00002onWG``04o`000?oT
d/Coi=;4o`0000;oglc500Co0000omW6a_oIa/Ko00000_oC_lH01Ol0003oc;S6olbha_o<^<Ko0000
00?oaK3600?o0000okjYaOnnZLD00_nnZLD00ol0003o]j?4okNSa002okNSa003o`000?naWL?o/Ig3
00?o/Ig300?o0000oiZ=aOnJSLD00_nJSLD00ol0003oU8O3oiB7``03oiB7``03o`000?n>Pl;oSX?2
00CoSX?200?o0000ohUn`On9O/400on9O/400ol0003oJFo6ofU_aP04ofU_aP03o`000?mUK<GoIFc5
00?oIFc500Co0000of9[aOmRJlGo00000omRJlD00omQJ/Ko0000ocUMc002ocUMc003o`000?ljGlgo
>Uo=00;o>Uo=0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo03Sooooo00Go0000obi>`_l^C/;o;Tk2o`000004obm>`@03oc9?
`Ol0003oJF_200;oJF_20ol00005ofe^`P03o`000?mcLL;oLg7200CoLg7200Co0000ogYg`omjMl?o
00000onGR<800ol0003oWHg2oif=`P05oif=`P03o`000?nST/?oXi;300CoXi;300?o0000ojZHa?nZ
V<@01?nZV<@01_l0003o/Ik5ok6NaOl0003o`Jc5o`0000Koa[7600?o0000olbga_o<]lH00_o<]lH0
0ol0003odKc6om6laP02om6laP04o`000?oF`/Koe/;6o`0000?oflO500Wo0000on3=aOoPcLGoh<g5
o`000?oTdLCo0000onWHa?l000000_o[f/800ol0003okMc1o`000003onoN_`03o`000?o`h;ko0000
00;olN:m1_l000000oobh[go0000o`000002oo3P_P04o`000?o_g[ookmjoo`0000;ok=_100?o0000
onWG`ooYel<01Ol000001OoOc<Go0000omW6a_oIa/Ko000000;odko600Go0000olbha_o<^<Koc;S6
o`000003olF`aP05o`000?nnZLGo_ZW5okjYaOl000001?ngXl@00ol0003o/Ig3ok6M``03ok6M``03
o`000?n[Ul;o000000;oVXg500?o0000oiB7`onDQl<01?nDQl<00ol0003oSX?2ohj3`P03ohj3`P03
o`000?n9O/7oRGk100CoRGk100?oQG_1o`000?mYKlH00omYKlH00ol0003oIFc5ofE/a@04ofE/a@07
o`000?mRJlGoHV_5of9[aOl0003oHV_5o`000002of5ZaP04o`000?liGLco>Eg<o`0000Co>Uo=00?o
0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00?o
0000obi>`_l^C/800_l^C/800ol0003o;dk1obm>`@02obm>`@;o<To11?l00007ofe^`P03o`000?mc
LL;oLg7200?oLg7200?o0000ogYg`omjMl<00_mjMl<00ol0003oUhS2o`000007oif=`P03o`000?nS
T/?oXi;300CoXi;300?o0000ojZHa?nZV<@01?nZV<@00ol0003o/Ik5ok6Na@02ok6Na@;o00001Oo6
/LH00ol0003oc;O6olbgaP02olbgaP03o`000?oA_<KodKc600;odKc600Go0000omK2a_oF`/Koe/;6
o`000003om_7a@04o`000?oPcLGoh<g5o`0000?oi=740_l000001Oo[f/;o0000ongL`Oo]g<7o0000
00;okmjo00Co0000oo3P__l0003olN6m0_l000000oobh[co0000o`000004o`000005oo;Q_Ol0003o
l>2noo3P__l000000_o_g[l7o`000004onOE`ol0003oi=34onC@a0Go000000?odko6o`000?o<^<H0
0_o<^<H01Ol0003oaK36olF`a_o5/<Ko000000?o_ZW500?o0000okNSa?ngXl@00ongXl@00ol0003o
/Ig3ok6M``02ok6M``07o`000?n[Ul;oZiO2oj^G`_l0003oVXg5o`000005oiB7``03o`000?n>Pl;o
SX?200CoSX?200?o0000ohUn`On9O/400on9O/401?l0003oQG_1ohEk`Ol00003ofU_aP03o`000?mU
K<GoIFc500?oIFc500?o0000of9[aOmRJlD00omRJlD2o`0000?oHF[600?o0000ocUMc?l000001?lj
Gld00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo03Oooooo00?o0000obi>`_l^C/800_l^C/800ol0003o;dk1obm>`@02obm>`@Co000000?o
JF_2o`000?m]K/801_m]K/800ol0003oLg72og=a`P03og=a`P03o`000?mjMl?oNWO300?oNWO300?o
0000oif=`_nMSL801_nMSL800ol0003oXi;3oj>B``04oj>B``03o`000?nZV<CoZYS400CoZYS400?o
0000ok6NaOnaW/D00_naW/D00ol0003o^:G6o`000003olJaaP03o`000?o<]lKoc;O600;oc;O600?o
0000om6la_oA_<H00_oA_<H01Ol0003oe/;6omK2a_oF`/Ko000000?oflO500Co0000on3=aOoPcLGo
00001?oTdL@01_l0003oj=K3o`000?l0003okMc1o`0000;okmjo00Ko0000oo3P__o`h;ko0000oo7Q
_Ol00002oo;R_0Go00000_obhKd01?l0003ol>2no`000?o_g[l3o`000007ongL`?l0003ojmW1on_I
`Ol0003oimG3o`000003onC@a005o`000?oOblGogl_5o`000?oJaLD00_l00002olbhaP03o`000?o5
/<KoaK3600;oaK3600Go0000okjYaOnnZLGo_ZW5o`000004okNSa003o`000?naWL?o/Ig300?o/Ig3
00?o0000oj^G`_n[Ul800_n[Ul800ol0003oU8O3oiB7``04oiB7``03o`000?n>Pl;oSX?200?oSX?2
00?o0000ohUn`On9O/400on9O/400ol0003oQG_1ohEk`@02ohEk`@04o`000?mYKlKoJFo6o`0000Go
IFc500?o0000of9[aOmRJlD01?mRJlD00ol0003oHF[6of5ZaP02of5ZaP;o00001?ljGld00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0=oooool00ol0003o;Tk2obi>`P02obi>`P03o`000?l_C/7o000000;o00001?lbCl400ol0
003oKFk2ofe^`P05ofe^`P03o`000?mcLL;oLg7200?oLg7200?o0000ogYg`omjMl<01?mjMl<00ol0
003oWHg2oif=`P05oif=`P03o`000?nST/?oXi;300CoXi;300?o0000ojZHa?nZV<@01?nZV<@00ol0
003o/Ik5ok6Na@02ok6Na@07o`000?nhYLKo^:G6okRUa_l0003oa[76o`000004olbgaP03o`000?oA
_<KodKc600;odKc600Go0000omK2a_oF`/Koe/;6o`000004om_7a@04o`000?oPcLGoh<g5o`0000?o
i=7400Go0000onSF`ooXe/?o0000on_I`@03o`000004onoN_ol0003ol>2no`0000;olN6m00?o0000
oo;R_?l000001?l00002oo;Q_@03o`000?o`h;ko000000;o000000Cokmjoo`000?o]g<3o00000_o[
fL400ol0003oimG3o`000003onC@a004o`000?oOblGogl_5o`0000;of/G500Go0000omG0aOl0003o
c;S6o`000003olF`aP05o`000?nnZLGo_ZW5okjYaOl000001?ngXl@00ol0003o/Ig3ok6M``03ok6M
``03o`000?n[Ul;oZiO200?oZiO20_l00004oiB7``03o`000?n>Pl;oSX?200?oSX?200?o0000ohUn
`On9O/401?n9O/400ol0003oQG_1ohEk`@03ohEk`@;o00001OmUK<D00ol0003oHV_5of9[a@04of9[
a@;o00001OmQJ/H00ol0003o>Uo=ocYOc@02ocYOc@03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02Oooool00005oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=oooool01?l0003o;Tk2obi>`_l^C/83
o`0000;o;dk100?o0000oc9?`OlbCl400_lbCl400ol0003oKFk2ofe^`P05ofe^`P03o`000?mcLL;o
Lg7200?oLg7200?o0000ogYg`omjMl<00omjMl<00ol0003oPWc4o`000005oif=`P03o`000?nST/?o
Xi;300CoXi;300?o0000ojZHa?nZV<@01?nZV<@00ol0003o/Ik5ok6Na@02ok6Na@03o`000?nhYLKo
^:G600?o^:G600?o0000olbga_o<]lH00oo<]lH00ol0003odKc6om6laP02om6laP05o`000?oF`/Ko
e/;6omK2a_l000000ooKalD01?l0003oh<g5on3=aOl00003onCAa004o`000?oXe/?oj=K3o`0000;o
jmW100?o0000onkL`?o^g<000_l000001oo`h;ko0000oo7Q_Ol0003ol^:lo`000?obh[`01?l00000
2_obhKgo0000o`000?l0003olN2mo`000?o_g[oo0000ongL`?l00002on_I`@04o`000?oWeL?oimG3
o`0000;oi=3400Co0000omo;aOoOblGo00000_oJaLD01?l0003oeL35omG0aOoE`<D2o`0000;oaK36
00?o0000okjYaOnnZLD00_nnZLD00ol0003o]j?4okNSa002okNSa003o`000?naWL?o/Ig300;o/Ig3
00?o0000oj^G`_n[Ul800on[Ul801?l0003oYY;1ojJB`Ol00002oiB7``03o`000?n>Pl;oSX?200Co
SX?200?o0000ohUn`On9O/400on9O/400ol0003oQG_1ohEk`@05ohEk`@03o`000?mUK<GoIFc500?o
IFc500?o0000of9[aOmRJlD01?mRJlD00ol0003oHF[6o`000004of5ZaP03of1[aol0003o>Uo=00;o
>Uo=00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06oooo
o`;o0000>?ooool4o`000003obi>`_l0003o;dk100;o;dk100?o0000oc9?`OlbCl400_lbCl400olh
Dl;o0000ofe^`P04ofe^`P03o`000?mcLL;oLg7200?oLg7200?o0000ogYg`omjMl<01?mjMl<01?l0
003oPWc4oh9la?l00003oif=`P03o`000?nST/?oXi;300GoXi;300?o0000ojZHa?nZV<@00onZV<@0
0ol0003o/Ik5ok6Na@03ok6Na@03o`000?nhYLKo^:G600?o^:G60_l00003olbgaP03o`000?oA_<Ko
dKc600;odKc600Go0000omK2a_oF`/Koe/;6o`000003om_7a@05o`000?oPcLGoh<g5on3=aOl00000
0ooTdL@00ol0003oj=K3o`000002on_I`@06o`000?o^g<3ok]c0onkL`?l0003okmjn1?l000000oob
h[co0000o`000005o`000004oo;Q_?l0003olN2mo`0000;okmjo00?o0000ongL`?l000000_o[fL40
0ol0003oimG3o`000003onC@a006o`000?oOblGogl_5o`000?oJaLGo00001?oE`<D01Ol0003ock[5
o`000?o5/<Ko000000?o_ZW500?o0000okNSa?ngXl@00_ngXl@00ol0003o/Ig3ok6M``03ok6M``03
o`000?n[Ul;oZiO200;oZiO200?o0000ojJB`OnVT/400_nVT/400ol0003oU8O3o`000005ohj3`P03
o`000?n9O/7oRGk100?oRGk100?o0000ohEk`On5Nl401_n5Nl400ol0003oIFc5ofE/a@03ofE/a@03
o`000?mRJlGoHV_500CoHV_500Co0000of5Za_mQJ/Ko00000_mQJ/H01?l0003oH6_7of1[aol00002
ocYOc@03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`03o`000?oo
oooooooo03Kooooo1?l00002obi>`P03o`000?l_C/7o;dk100;o;dk100?o0000oc9?`OlbCl400_lb
Cl42ocQC`P03o`000?m]K/;oKFk200;oKFk200?o0000og=a`_mcLL800omcLL800ol0003oNWO3ogYg
``03ogYg``03o`000?n2O<CoPWc400;oPWc400?o0000oif=`_l000001onST/<00ol0003oZYS4ojZH
a004ojZHa003o`000?naW/Go/Ik500;o/Ik500?o0000okRUa_nhYLH00onhYLH01_l0003o_jc6okn/
a_l0003oc;O6o`0000CodKc600Go0000omK2a_oF`/Koe/;6o`000004om_7a@04o`000?oPcLGoh<g5
o`0000?oi=7400Co0000onSF`ooXe/?o00000_o[fL401?l0003ok]c0onkL`?l00002onoN_P04o`00
0?oah;go0000oo;Q_0Go000000Kol^:lo`000?obhKco0000oo7P_Ol00002onoN_`03o`000?o]g<3o
000000;ojmW100?o0000onOE`ol000000ooTd<@01?l0003ogl_5omo;aOl00002om[5a@05o`000?oE
`<GoeL35omG0aOl000000oo?^/D2o`0000;o_ZW500?o0000okNSa?ngXl@00_ngXl@00ol0003o/Ig3
ok6M``03ok6M``03o`000?n[Ul;oZiO200;oZiO200?o0000ojJB`OnVT/401?nVT/400ol0003oSX?2
ohj3`P04ohj3`P03o`000?n9O/7oRGk100?oRGk100?o0000ohEk`On5Nl401On5Nl400ol0003oPWW1
o`000003ofE/a@03o`000?mRJlGoHV_500CoHV_500?o0000of5Za_mQJ/H00_mQJ/H00ol0003oHF[6
o`000003of1[a`03o`000?ljGlgo000002?ooooo00?o0000ooooooooool02Oooool0027ooooo00?o
0000ooooooooool0<oooool3o`0000?ooooo00Co02Nbo`000?l^C/;o00001?l_C/400ol0003o<To1
oc9?`@02oc9?`@?o>5?200Co0000ofe^`_m]K/;o00001_mcLL800ol0003oNWO3ogYg``03ogYg``03
o`000?n2O<CoPWc400?oPWc40_l00006oj>B``03o`000?nZV<CoZYS400CoZYS400?o0000ok6NaOna
W/D00onaW/D00ol0003o^:G6okRUaP02okRUaP03o`000?no[<Ko_jc600;o_jc60_l00004om6laP05
o`000?oF`/Koe/;6omK2a_l000000ooKalD01?l0003oh<g5on3=aOl00003onCAa004o`000?oXe/?o
j=K3o`0000;ojmW100Wo0000onkL`?o^g<3ok]c0o`000?o_g[ko0000oo7P_Ol000000_obhK`4o`00
0003oo;R_?l0003o000000;o000000ColN2mo`000?o_g[oo00000_o]g<000ol0003ojmW1o`000002
onOE``04o`000?oTd<Coi=34o`0000;ogl_500Co0000om[5aOoJaLGo00000ooE`<D00ol0003ock[5
olnja@02olnja@05o`000?o:]<Go0000okjYaOl000001?ngXl@00ol0003o/Ig3ok6M``02ok6M``03
o`000?n[Ul;oZiO200?oZiO200?o0000ojJB`OnVT/401?nVT/42o`0000CoSX?200?o0000ohUn`On9
O/400on9O/400ol0003oQG_1ohEk`@05ohEk`@05o`000?n2NL7oPWW1oh9i`Ol000000_mUK<D00ol0
003oHV_5of9[a@04of9[a@03o`000?mQJ/KoHF[600;oHF[60_l00005of1[a`;o00009?ooool00ol0
003oooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0`ooooo`?o00001_ooool01?l0003o
02Nbo`000?l00004obm>`@03o`000?lbCl7o<To100;o<To100Oo0000ocQC`_lhDl;o>5?2o`000?m]
K/;o000000GoLg7200?o0000ogYg`omjMl<00omjMl<00ol0003oPWc4oh9la004oh9la0;oRXC600?o
0000oj>B`onST/<00_nST/<00ol0003oZYS4ojZHa004ojZHa003o`000?naW/Go/Ik500?o/Ik500?o
0000okRUa_nhYLH00onhYLH00ol0003o_jc6okn/aP02okn/aP06o`000?o6/lOo0000o`000?oA_<Ko
00000ooF`/H00ol0003oflO5om_7a@02om_7a@04o`000?oPcLGoh<g5o`0000?oi=7400Ko0000onSF
`ooXe/?o0000on_I`Ol00003onkL`003o`000?o_g[ko000000;olN2m2Ol000000oobh[co0000oo7Q
_@02o`000004onoN_ol0003okMc0o`0000;ojmW100?o0000onOE`ol000000ooTd<@00ol0003ogl_5
o`000002om[5a@05o`000?oE`<GoeL35omG0aOl000001?o?^/D01Ol0003ob[C5olZdaOo:]<Go0000
00Co]j?400?o0000ok6M`onaWL<00_naWL<00ol0003oZiO2oj^G`P03oj^G`P03o`000?nVT/7oYY;1
00CoYY;100Co0000oj6>`?nQS/3o00000_n>Pl800ol0003oRGk1ohUn`@03ohUn`@03o`000?n5Nl7o
QG_100GoQG_100?o0000oh9i`On2NL400on2NL400ol0003oIFc5o`000005of9[a@03o`000?mQJ/Ko
HF[600CoHF[600?o0000of1[aomPJlL01?mPJlL00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Sooooo000Qooooo`;o0000;_ooool3o`0000[ooooo0_l09k800ol0003o;dk1obm>`@02obm>
`@03o`000?lbCl7o<To100;o<To100?o0000ocQC`_lhDl800_lhDl800ol0003oLg72og=a`P04og=a
`P03o`000?mjMl?oNWO300?oNWO300?o0000oh9la?n2O<@00on2O<@01Ol0003oRXC6ohZ4a_n:Q<Ko
000000?oXi;300?o0000ojZHa?nZV<@01?nZV<@00ol0003o/Ik5ok6Na@02ok6Na@03o`000?nhYLKo
^:G600?o^:G600?o0000okn/a_no[<H00_no[<H00ol0003oa[?7olJca`02olJca`;o00000ooF`/H0
1Ol0003oflO5om_7aOoKalGo000000;oh<g500Go0000onCAa?oTdLCoi=74o`000002onSF``04o`00
0?o[fL7ojmW1o`0000;ok]c000?o0000onoN__o_g[h02ol000001_obh[co0000oo7Q_OoahKgo0000
oo3P_PCo000000GojmW1o`000?oWeL?oimG3o`000002onC@a004o`000?oOblGogl_5o`0000;of/G5
00Go0000omG0aOoE`<GoeL35o`000003olnja@03o`000?o:]<Gob[C500;ob[C50_l00003okNSa003
o`000?naWL?o/Ig300;o/Ig300?o0000oj^G`_n[Ul800_n[Ul800ol0003oYY;1ojJB`@04ojJB`@03
o`000?nQS/3oXHk000;oXHk000?o0000ohj3`_l000001On9O/400ol0003oQG_1ohEk`@05ohEk`@03
o`000?n2NL7oPWW100CoPWW100?o0000of9[aOmRJlD01?mRJlD00ol0003oHF[6of5ZaP04of5ZaP;o
00001OmPJlL00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`00
0?oooooooooo02[ooooo0ol0000=ooooo`03o`000?l09k;o000000Co;dk100?o0000oc9?`OlbCl40
0_lbCl400ol0003o>5?2ocQC`P02ocQC`P03o`000?mcLL;oLg7200?oLg7200?o0000ogYg`omjMl<0
0omjMl<00ol0003oPWc4oh9la004oh9la003o`000?n:Q<KoRXC600;oRXC600?o0000oj>B`ol00000
1_nZV<@00ol0003o/Ik5ok6Na@03ok6Na@03o`000?nhYLKo^:G600;o^:G600?o0000okn/a_no[<H0
0ono[<H00ol0003oa[?7olJca`02olJca`05o`000?o>^/Oo0000omK2a_l000000ooKalD01Ol0003o
h<g5on3=aOoPcLGo000000;oi=7400Co0000onSF`ooXe/?o00000_o[fL401?l0003ok]c0onkL`?o^
g<04o`000004oo7P__l0003o0000oo;Q_@Co000000Kol^:lo`000?obh[co0000oo7Q_Ol00002oo3P
_P04o`000?o_g[oo0000ongL`@;o000000GoimG3o`000?oTd<Coi=34o`000002omo;a@04o`000?oJ
aLGof/G5o`0000?oeL3500Go0000olnjaOo?^/Gock[5o`000004olZda@06o`000?o5[lCoaJo4o`00
0?ngXlCo00001?naWL<00ol0003oZiO2oj^G`P02oj^G`P03o`000?nVT/7oYY;100CoYY;100?o0000
oj6>`?nQS/001?nQS/000ol0003oRGk1ohUn`@03ohUn`@03o`000?n5Nl7oQG_100GoQG_100?o0000
oh9i`On2NL401On2NL400omoMl7o0000of9[a@04of9[a@03o`000?mQJ/KoHF[600?oHF[600Co0000
of1[aomPJlOo00000omPJlL00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Q
ooooo`03o`000?oooooooooo02Oooooo0ol0000@ooooo`04o`000?l09k;o02Nbo`0000?o;dk100?o
0000oc9?`OlbCl400_lbCl400ol0003o>5?2ocQC`P02ocQC`P03od5Ia?l0003oLg7200?oLg7200?o
0000ogYg`omjMl<00omjMl<00ol0003oPWc4oh9la004oh9la003o`000?n:Q<KoRXC600?oRXC600?o
0000ojZHa?nZV<@01?nZV<@00ol0003o/Ik5ok6Na@03ok6Na@03o`000?nhYLKo^:G600?o^:G600?o
0000okn/a_no[<H00_no[<H00ol0003oa[?7olJca`02olJca`04o`000?o>^/Ooc[[7oljja`?o0000
0_oKalD01?l0003oh<g5on3=aOl00003onCAa004o`000?oXe/?oj=K3o`0000;ojmW11Ol000000oo_
g[oo0000oo7P_P02o`000003oo;Q_Ol0003o000000?o00000_obh[`00ol0003olN6mo`000002oo3P
_P03o`000?o_g[oo000000;okMc100?o0000on_J`_l000000ooTd<@00ol0003ogl_5o`000003om[5
a@04o`000?oE`<GoeL35o`0000?ock[500?o0000olZdaOo:]<D00_o:]<D00ol0003oaJo4olF_a002
olF_a003o`000?naWL?o/Ig300;o/Ig300?o0000oj^G`_n[Ul800on[Ul800ol0003oYY;1ojJB`@03
ojJB`@03o`000?nQS/3oXHk000CoXHk00_l00004ohUn`@03o`000?n5Nl7oQG_100GoQG_100?o0000
oh9i`On2NL401On2NL401?l0003oOgO1ogmg`Ol00003of9[a@03o`000?mQJ/KoHF[600CoHF[600Co
0000of1[aomPJlOo00000omPJlL00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo
000Pooooo`03o`000?oooooooooo02Gooooo0ol0000Dooooo`06o`000?l09k;o02B_o`000?l_C/7o
00001?lbCl400ol0003o>5?2ocQC`P03ocQC`P;o@EW400Co0000og=a`_mcLL;o00001_mjMl<00ol0
003oPWc4oh9la003oh9la003o`000?n:Q<KoRXC600CoRXC600?oTh_8o`000?nZV<@00onZV<@00ol0
003o/Ik5ok6Na@04ok6Na@03o`000?nhYLKo^:G600;o^:G600?o0000okn/a_no[<H00_no[<H00ol0
003oa[?7olJca`03olJca`05o`000?o>^/Ooc[[7oljjaol000000_oD`LL7o`000003onCAa?l0003o
000000Ko00000_o/fl401?l0003okmjoo`000?oah;h2o`0000;ol^6m1Ol000001oobh[co0000o`00
0?oahKgo0000oo3P__l000000_o_g[l00ol0003okMc1o`000002on_J`P;o000000Goi=34o`000?oO
blGogl_5o`000002om[5a@05o`000?oE`<GoeL35omG0aOl000000oo?^/D01Ol0003ob[C5olZdaOo:
]<Go000000GoaJo40_l00003ok6M``03o`000?n[Ul;oZiO200;oZiO200?o0000ojJB`OnVT/400onV
T/400ol0003oXHk0oj6>`004oj6>`004o`000?nMRl3oWH_0o`0000?oRGk100?o0000ohEk`On5Nl40
1?n5Nl400ol0003oPWW1oh9i`@05oh9i`@03o`000?moMl7oOgO100;oOgO100Co0000of9[aOmRJlGo
00001OmQJ/H00ol0003oH6_7of1[a`02of1[a`03o`000?mPJlOo000002Kooooo00?o0000oooooooo
ool02?ooool0023ooooo0_l0000Sooooo`?o00005oooool01_l0003o02Nbo`000?l0003o;dk1o`00
00Co<To100?o0000ocQC`_lhDl800olhDl83od5Ia003o`000?mcLL;o000000GoNWO300?o0000oh9l
a?n2O<@01?n2O<@00ol0003oRXC6ohZ4aP03ohZ4aP04o`000?nCRlSoTh_8o`0000?oZYS400?o0000
ok6NaOnaW/D00onaW/D00ol0003o^:G6okRUaP02okRUaP03o`000?no[<Ko_jc600?o_jc600?o0000
olJcaoo6/lL00_o6/lL01Ol0003oc[[7oljjaoo>^/Oo000000Coe<7700Co0000om_8aooKb<Oo0000
0_oPc/H2o`0000;oiM?400Co0000onWH`ooYf<?o00000_o/fl400ol0003okmjoonoN_`02o`000003
oo3P__l0003ol^6m00Oo00000_oah[d02?l0003ol>2noo3P__l0003okmjoo`000?o]g<7o00000_o[
f/800ol0003oj=O4onSGa002o`000005omo;aOl0003of/G5om[5aOl000000ooE`<D01Ol0003ock[5
olnjaOo?^/Go000000?ob[C500?o0000olF_a?o5[l@00oo5[l@01_l0003o_jW4oknYa?l0003o/Ig3
o`0000CoZiO200?o0000ojJB`OnVT/400onVT/400ol0003oXHk0oj6>`004oj6>`003o`000?nMRl3o
WH_000;oWH_000?o0000ohUn`Ol000001on5Nl400ol0003oPWW1oh9i`@04oh9i`@03o`000?moMl7o
OgO100CoOgO100?o0000of9[aOl000001OmQJ/H00ol0003oH6_7of1[a`03of1[a`;o00009_ooool0
0ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool01?l0
003o02Nbo`0W/_l09:l2o`0000Co<To100?o0000ocQC`_lhDl800_lhDl800ol0003o@EW4od5Ia002
od5Ia003o`000?mjMl?oNWO300CoNWO300?o0000oh9la?n2O<@00on2O<@00ol0003oRXC6ohZ4aP04
ohZ4aP07o`000?nCRlSoTh_8oi>;b?l0003oZYS4o`000005ok6Na@03o`000?nhYLKo^:G600?o^:G6
00?o0000okn/a_no[<H00_no[<H00ol0003oa[?7olJca`02olJca`03o`000?o>^/Ooc[[700;oc[[7
00Go0000omC1aooD`LOoe<77o`000002om_8a`05o`000?oPc/Koh<k6on3>a_l000000_oUdl@01?l0
003ojMS3onWH`ol00003oncK`@04o`000?o_g[ookmjoo`0000;ol>2n2?l00003oo7R_@05o`000?o`
h;ko0000onoN_ol000000_o]g<400ol0003ojm[2o`000003onSGa003o`000?oUdlGo000000?of/G5
00Co0000omG0aOoE`<Go00000oo?^/D00ol0003ob[C5olZda@02olZda@03o`000?o5[lCoaJo400;o
aJo400?o0000oknYa?noZL@00_noZL@00ol0003oZiO2oj^G`P03oj^G`P03o`000?nVT/7oYY;100;o
YY;100?o0000oj6>`?nQS/001?nQS/000ol0003oWH_0oif;`004oif;`003o`000?n5Nl7oQG_100Go
QG_100?o0000oh9i`On2NL401On2NL400ol0003oOgO1ogmg`@05ogmg`@03o`000?mQJ/KoHF[600?o
HF[600?o0000of1[aomPJlL01OmPJlL00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oo
oooo000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`05o`000?l09k;o0000o`0T[ol0
00001?lbCl400ol0003o>5?2ocQC`P02ocQC`P03o`000?m1FLCo@EW400;o@EW400?o0000ogYg`omj
Ml<00omjMl<00ol0003oPWc4oh9la004oh9la003o`000?n:Q<KoRXC600?oRXC600?o0000oi>;b?nC
RlP00onCRlP00ol0003o/Ik5ok6Na@04ok6Na@03o`000?nhYLKo^:G600;o^:G600?o0000okn/a_no
[<H00ono[<H00ol0003oa[?7olJca`02olJca`05o`000?o>^/Ooc[[7oljjaol000001?oD`LL01?l0
003oflS7om_8aol00002on3>aP05o`000?oUdlCoiM?4onGCa?l000000_oYf<<01Ol0003ok=_1oncK
`Ol0003okmjo00;o00000_o`h;h5o`000004oo;R_Ol0003ol^:lo`0000;olN:m00?o0000oo7Q__l0
00000_o_g[l00ol0003okMc1o`000002on_J`P04o`000?oXelCoj=O4o`0000;oiM?50_l000001OoJ
aLGo0000omG0aOoE`<Go000000?ock[500?o0000olZdaOo:]<D00_o:]<D00ol0003oaJo4olF_a002
olF_a003o`000?noZLCo_jW400;o_jW400?o0000okZU`ol000000on[Ul800ol0003oYY;1ojJB`@02
ojJB`@03o`000?nQS/3oXHk000CoXHk000?o0000oif;`?nMRl001?nMRl02o`0000KoQG_100?o0000
oh9i`On2NL401On2NL400ol0003oOgO1ogmg`@06ogmg`@03o`000?mQJ/KoHF[600?oHF[600?o0000
of1[aomPJlL01?mPJlL2o`0002Oooooo00?o0000ooooooooool01oooool0023ooooo00?o0000oooo
ooooool06_ooool3o`00023ooooo00Ko0000o`0W/_l0003o02B_o`0T/?l00003oc9?`@03o`000?lh
Dl;o>5?200;o>5?200?o0000od5Ia?m1FL@00_m1FL@00om;H<Oo0000ogYg``03ogYg``03o`000?n2
O<CoPWc400?oPWc400?o0000ohZ4a_n:Q<H01?n:Q<H00ol0003oTh_8oi>;b003oi>;b003oifDbOl0
003o/Ik500?o/Ik500?o0000okRUa_nhYLH00onhYLH00ol0003o_jc6okn/aP02okn/aP03o`000?o6
/lOoa[?700;oa[?700?o0000oljjaoo>^/L00_o>^/L01Ol0003oe<77omC1aooD`LOo000000;oflS7
00Go0000on3>a_oPc/Koh<k6o`000002onGCa004o`000?oYf<?ojMS3o`0000;ok=_10ol000000oo^
g/3o0000oo3P_P03o`000003oo;R_Ol0003o000000Co000000OolN:mo`000?oahKkolN6no`000?o_
g[oo000000;okMc100?o0000on_J`_l000000_oXel@01?l0003oiM?5onGCaOl00002on;@aP05o`00
0?oE`<GoeL35omG0aOl000000oo?^/D01Ol0003ob[C5olZdaOo:]<Go000000CoaJo400?o0000oknY
a?noZL@00_noZL@01ol0003o^ZG3okZU`onjYL?o0000oj^G`_l000001?nVT/400ol0003oXHk0oj6>
`004oj6>`003o`000?nMRl3oWH_000CoWH_000Co0000oiV8_onIR;oo00001On5Nl400ol0003oPWW1
oh9i`@04oh9i`@03o`000?moMl7oOgO100KoOgO100?o0000ogeg`_l000001?mQJ/H00ol0003oH6_7
of1[a`04of1[a`03o`000?oooooo000002Kooooo00?o0000ooooooooool01oooool0023ooooo0ol0
000Gooooo`?o00008oooool01ol0003o02Nbo`0W/_l0003o02B_o`0T/?l000000_lbCl400ol0003o
>5?2ocQC`P02ocQC`P03o`000?m1FLCo@EW400;o@EW40_m;H<L01?l0003oNWO3ogYg`ol00006oh9l
a003o`000?n:Q<KoRXC600?oRXC600?o0000oi>;b?nCRlP00onCRlP01?l0003oWIC9oifDbOl00003
ok6Na@03o`000?nhYLKo^:G600;o^:G600?o0000okn/a_no[<H00ono[<H00ol0003oa[?7olJca`02
olJca`05o`000?o>^/Ooc[[7oljjaol000000ooD`LL01Ol0003oflS7om_8aooKb<Oo000000;oh<k6
00Go0000onGCa?oUdlCoiM?4o`000002onWH``04o`000?o/fl7ok=_1o`0000;ok]k000Ko0000oo3P
__l0003ol>6no`000?obh[d2o`000004oo;R_Ol0003o0000oo;R_@;o00000_oahKh02?l0003ol>6o
o`000?l0003okMc1o`000?o[f/;o00000ooXel@00ol0003oiM?5o`000003on;@aP;o000000?oeL35
o`000?o?^/D00_o?^/D01Ol0003ob[C5olZdaOo:]<Go000000CoaJo400?o0000oknYa?noZL@00_no
ZL@00ol0003o^ZG3okZU``02okZU``;o00001?nVT/400ol0003oXHk0oj6>`004oj6>`003o`000?nM
Rl3oWH_000CoWH_000?o0000oiV8_onIR;l00_nIR;l01Ol0003oQG_1ohEk`On5Nl7o000000KoPWW1
00?o0000ogmg`OmoMl401_moMl401Ol0003oOGO2ogeg`_mmMl;o000000;oHF[600?o0000of1[aomP
JlL01?mPJlL01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool01oooool001oo
oooo0_l0000Fooooo`?o00009oooool01?l0003o02Nbo`000?l09:l2o`0T/003o`000?lbCl7o0000
00Co>5?200?o0000od5Ia?m1FL@00_m1FL@01_l0003oBf37od]Paol0003oNWO3o`0000KoPWc400?o
0000ohZ4a_n:Q<H00on:Q<H00ol0003oTh_8oi>;b003oi>;b007o`000?nMU<WoWIC9oifDbOl0003o
/Ik5o`000004okRUaP03o`000?no[<Ko_jc600?o_jc600?o0000olJcaoo6/lL00_o6/lL00ol0003o
c[[7oljja`02oljja`05o`000?oD`LOoe<77omC1aol000000_oKb<L01Ol0003oh<k6on3>a_oPc/Ko
000000;oiM?400Co0000onWH`ooYf<?ojMS30ol00003onkN`0;o000000Gol>6no`000?obh[go0000
oo;R_@04o`000005oo;R_Ol0003olN6noo7Q__l000000_o`hKl00ol0003okMc1o`000002on_J`P04
o`000?oXelCoj=O4o`0000;oiM?500Co0000on;@a_oRd<Ko00000_oNc<L01Ol0003ock[5olnjaOo?
^/Go000000?ob[C500?o0000olF_a?o5[l@00_o5[l@00ol0003o_jW4oknYa002oknYa003o`000?nj
YL?o^ZG300;o^ZG300?o0000okJQ`ol000000onVT/400ol0003oXHk0oj6>`004oj6>`003o`000?nM
Rl3oWH_000CoWH_000?o0000oiV8_onIR;l01?nIR;l00ol0003oQG_1o`000007oh9i`@03o`000?mo
Ml7oOgO100GoOgO100?o0000ogeg`_mmMl800ommMl800ol0003oHF[6o`000006of1[a`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Booooo`?o0000:_ooool00ol0003o02Nbo`0W/P02o`0000;o02B`
0_l00004ocQC`P05o`000?m1FLCo@EW4od5Ia?l000001?m;H<L00ol0003oPWc4oh9la004oh9la003
o`000?n:Q<KoRXC600?oRXC600?o0000oi>;b?nCRlP01?nCRlP00ol0003oWIC9oifDb@02oifDb@;o
00001?nhYLH00ol0003o_jc6okn/aP03okn/aP03o`000?o6/lOoa[?700;oa[?700Go0000oljjaoo>
^/Ooc[[7o`000003omC1a`05o`000?oKb<OoflS7om_8aol000000_oPc/H01Ol0003oiM?4onGCa?oU
dlCo000000;ojMS30_l000000oo/g<;o0000onkN`002onkN`007o`000?o`hKkol>6no`000?obh[go
0000oo;R_@02o`000006oo7S__l0003ol^:mo`000?oahKko00000oo`hKl01Ol0003okMc1o`000?o[
f/;o000000;oj=O400Co0000onGCaOoUdlGo00000_oRd<H01?l0003og/c7omk<aooNc<L2o`000003
olnjaOl0003ob[C500?ob[C500Go0000olF_a?o5[lCoaJo4o`000004oknYa003o`000?njYL?o^ZG3
00;o^ZG300Oo0000okJQ`onfXL?o]Z73o`000?nVT/7o000000KoXHk000?o0000oif;`?nMRl001?nM
Rl000ol0003oVHRooiV8_`05oiV8_`;o00001on2NL400ol0003oOgO1ogmg`@05ogmg`@03o`000?mm
Ml;oOGO200GoOGO200?o0000of1[aomPJlL01?mPJlL00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0ol0
000]ooooo`05o`000?l09k;o02Nbo`000?l09:l00ol09;000ol0003o>5?2ocQC`P02ocQC`P05o`00
0?m1FLCo@EW4od5Ia?l000001?m;H<L00omGJ/[o0000oh9la004oh9la003o`000?n:Q<KoRXC600?o
RXC600?o0000oi>;b?nCRlP00onCRlP00ol0003oWIC9oifDb@03oifDb@06o`000?nWW<_o0000o`00
0?nhYLKo00001Ono[<H00ol0003oa[?7olJca`02olJca`05o`000?o>^/Ooc[[7oljjaol000001?oD
`LL01Ol0003oflS7om_8aooKb<Oo000000;oh<k600Go0000onGCa?oUdlCoiM?4o`000002onWH``04
o`000?o/g<;ok=c2o`0000;ok]k000Go0000oo3Q__o`hKko0000oo3R_`03o`000004oo7S__l0003o
0000oo;R_@;o000000OolN6no`000?o`hKool>6oo`000?o_hL7o000000;ojm[200Ko0000onSGa?oX
elCo0000onGCaOl00002on;@aP05o`000?oNc<Oog/c7omk<aol000000_oJb<P00ol0003ob[C5olZd
a@02olZda@05o`000?o5[lCoaJo4olF_a?l000001?noZL@00ol0003o^ZG3okZU``02okZU``03o`00
0?nfXL?o]Z7300;o]Z730_l00006oj6>`003o`000?nMRl3oWH_000CoWH_000?o0000oiV8_onIR;l0
1OnIR;l00ol0003oUXK0o`000006oh9i`@03o`000?moMl7oOgO100KoOgO100?o0000ogeg`_mmMl80
1OmmMl800omkMl?o0000of1[a`04of1[a`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Oooool01Ol0003o02Nb
o`000?l09:oo000000;o02B`00?o0000ocQC`_lhDl800_lhDl801Ol0003o@EW4od5Ia?m1FLCo0000
00CoBf370_mGJ/X01Ol0003oPWc4oh9la?n2O<Co000000KoRXC600?o0000oi>;b?nCRlP00onCRlP0
0ol0003oWIC9oifDb@02oifDb@03o`000?nWW<_oYic;00;oYic;0_l00004okn/aP03o`000?o6/lOo
a[?700?oa[?700Go0000oljjaoo>^/Ooc[[7o`000003omC1a`05o`000?oKb<OoflS7om_8aol00000
0ooPc/H01Ol0003oiM?4onGCa?l0003ojMS300;o00000oo/g<801_l0003ok]k0o`000?l0003ol>6n
o`0000;ol>:o00?o0000oo7S__l000000_oahkh2o`000003oo7S_ol0003o000000;ol>6o00Ko0000
onoQ`Oo_hL7o0000on_J`_l00002onSGa003o`000?oUdlGo000000?oh]3600Co0000omk<aooNc<Oo
00000ooJb<P01Ol0003ob[C5olZdaOo:]<Go000000?oaJo400?o0000oknYa?noZL@00_noZL@00ol0
003o^ZG3okZU``02okZU``03o`000?nfXL?o]Z7300;o]Z7300?o0000ok6M`ol000001OnQS/000ol0
003oWH_0oif;`004oif;`003o`000?nIR;ooVHRo00GoVHRo00Go0000oiJ6`?nFQ/3oUXK0o`000005
oh9i`@03o`000?moMl7oOgO100GoOgO100?o0000ogeg`_mmMl801OmmMl801?l0003oNgO3og]g`ol0
0004of1[a`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`06ooooo`001?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool2o`0000[ooooo0ol0000dooooo`05o`00QOl0003o02Nbo`000?l09:l00ol09;001?l0003o>5?2
ocQC`_l00004od5Ia003o`000?m;H<OoBf3700;oBf370omGJ/X01?l0003oPWc4oh9la?l00005ohZ4
aP03o`000?nCRlSoTh_800?oTh_800?o0000oifDbOnMU<T00onMU<T00ol0003oYic;ojNLb`02ojNL
b`03o`000?naY/co000000;o000000?o_jc6o`000?o6/lL00oo6/lL01Ol0003oc[[7oljjaoo>^/Oo
000000Coe<7700Go0000om_8aooKb<OoflS7o`000002on3>aP04o`000?oUdlCoiM?4onGCa0;o0000
013oj=S5o`000?o/g<;ok=c2o`000?o^g/3o0000onkO`Ol0003ol>6no`000?o`h[oo0000oo7S__l0
003olN>n0ol00002oo7S_`04o`000?o`hKool>6oo`0000;okn7100?o0000ongP`ol000000_oXel@0
1?l0003oiM?5onGCaOl00002on;@aP04o`000?oNc<Oog/c7o`0000?of/S800Go0000omK4bOl0003o
b[C5o`000003olF_a003o`000?noZLCo_jW400;o_jW400?o0000okZU`onjYL<00_njYL<00ol0003o
]Z73okJQ``02okJQ``05o`000?naWL?o/Ig3ok6M`ol000000onQS/000ol0003oWH_0oif;`004oif;
`003o`000?nIR;ooVHRo00GoVHRo00?o0000oiJ6`?nFQ/000onFQ/001Ol0003oPWW1oh9i`On2NL7o
000000OoOgO100?o0000ogeg`_mmMl801OmmMl800ol0003oNgO3og]g``02og]g``04o`000?mPJlOo
H6_7o`0000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`001?ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo00Kooooo0ol0000hooooo`05o`00QOl0003o0000o`0T[ol000000_l09;001?l0:K?o
0000ocQC`_l00004od5Ia003o`000?m;H<OoBf3700;oBf3700Oo0000oeMZb_mGJ/[oEf[:o`000?n2
O<Co000000GoRXC600?o0000oi>;b?nCRlP00onCRlP00ol0003oWIC9oifDb@02oifDb@03o`000?nW
W<_oYic;00;oYic;00?o0000ok6Vc?naY/`00onaY/`2o`0000?oa[?700?o0000oljjaoo>^/L00_o>
^/L01Ol0003oe<77omC1aooD`LOo000000?oflS700Co0000on3>a_oPc/Koh<k61?l00003onSHa@03
o`000?o/g<;ok=c200;o00000_o^gl42o`000004oo3R_ol0003o0000oo7S_P?o000000?olNBoo`00
0?oahkl00_l000001Oo`hKoo0000onoQ`Oo_hL7o000000;okN3300Ko0000onSGa?oXelCo0000onGC
aOl00002on;@aP04o`000?oNc<Oog/c7o`0000?of/S800Go0000omK4bOoFa<Woe/C9o`000003olF_
a003o`000?noZLCo_jW400;o_jW400?o0000okZU`onjYL<00_njYL<00ol0003o]Z73okJQ``02okJQ
``03o`000?naWL?o/Ig300?o/Ig300?o0000oj6>`?l000001_nMRl000ol0003oVHRooiV8_`05oiV8
_`03o`000?nFQ/3oUXK000GoUXK000?o0000oh9i`Ol000001omoMl400ol0003oOGO2ogeg`P05ogeg
`P03o`000?mkMl?oNgO300CoNgO300?o0000of1[aol000002Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000looooo`04o`00QOl0003o02B_
o`0000;o02B`00Co0000o`0Y/ol0003o00001?m1FL@00ol0003oBf37od]Pa`02od]Pa`03o`000?mG
J/[oEf[:00;oEf[:00?o0000ohZ4a_n:Q<H00on:Q<H00ol0003oTh_8oi>;b003oi>;b003o`000?nM
U<WoWIC900?oWIC900?o0000ojNLbonWW</00_nWW</00ol0003o/JK<ok6Vc003ok6Vc006o`000?nl
[lgo0000o`000?o6/lOo00000oo>^/L01Ol0003oe<77omC1aooD`LOo000000CoflS71Ol00002on?C
a`04o`000?oXf<Goj=S5o`0000;ok=c20_l00003onkO`@08o`000?o`h[oo0000o`000?oahkko0000
oo7S__l00002oo7T_`03oo7S_ol0003ol>C000;o00000_o_hL401Ol0003okN33ongP`ol0003ok=o5
00;o000000GoiM?5o`000?oRd<Koh]36o`000003omk<a`04o`000?oJb<Sof/S8o`0000?oe/C900Go
0000om6obOl0003oaJo4o`000004oknYa003o`000?njYL?o^ZG300;o^ZG300?o0000okJQ`onfXL<0
0_nfXL<00ol0003o/Ig3ok6M``04ok6M``;o00001_nMRl000ol0003oVHRooiV8_`05oiV8_`03o`00
0?nFQ/3oUXK000KoUXK00_l00007ogmg`@03o`000?mmMl;oOGO200GoOGO200?o0000og]g`omkMl<0
1_mkMl<00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1_ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooooooo0ol00010ooooo`04o`00QOl0003o02B_o`0000;o02B`0_l0:K<00ol0
003o@EW4od5Ia002od5Ia003o`000?m;H<OoBf3700;oBf3700?o0000oeMZb_mGJ/X00_mGJ/X00omU
M<ko0000ohZ4aP03ohZ4aP03o`000?nCRlSoTh_800?oTh_800?o0000oifDbOnMU<T00onMU<T00ol0
003oYic;ojNLb`02ojNLb`03o`000?naY/co/JK<00;o/JK<00?o0000okb_cOnl[ld00_nl[ld3o`00
00;oc[[700Ko0000omC1aooD`LOoe<77o`000?oKb<L4o`0000;ogLk900Co0000on?CaooSdlOo0000
0ooXf<D01Ol0003ok=c2o`000?o/gLCo000000;ok]o11?l00002oo7S_P;o00000_oai;l2o`0000;o
l>C000Co0000onoQ`Oo_hL7o00000_o]h<<01?l0003ok=o5oncOaOl00002onGCa@03o`000?oRd<Ko
000000?og/c700Co0000om[8b?oJb<So00000ooFa<T01Ol0003odKo9om6obOoA_lWo000000Co_jW4
00?o0000okZU`onjYL<00_njYL<00ol0003o]Z73okJQ``02okJQ``03o`000?naWL?o/Ig300Co/Ig3
00?o0000ojjJ`ol000001OnMRl000ol0003oVHRooiV8_`05oiV8_`03o`000?nFQ/3oUXK000KoUXK0
00?o0000oi>4`?l000001omoMl400ol0003oOGO2ogeg`P04ogeg`P03o`000?mkMl?oNgO300KoNgO3
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014ooooo`03o`00
0?l09:oo000000;o02B`00?o0000o`0Y/ol000001?m1FL@00ol0003oBf37od]Pa`02od]Pa`03o`00
0?mGJ/[oEf[:00;oEf[:0_mUM<h01?l0003oRXC6ohZ4a_l00006oi>;b003o`000?nMU<WoWIC900;o
WIC900?o0000ojNLbonWW</00_nWW</00ol0003o/JK<ok6Vc003ok6Vc003o`000?nl[lgo_:o=00;o
_:o=00?o0000olFgcOo5]ld02?l00002omK7b`04o`000?oMc/WogLk9o`0000?ohm?700Co0000onSH
aOoXf<Goj=S50_l00002oncMa007o`000?o^gl7o0000onoQ`_l0003olN:oo`000002oo7S_P;o0000
0_oai;l01Ol0003ol>C0oo3T`?o`i<3o000000;okn7100?o0000ongP`ol000000oo/glD00ol0003o
iM?5o`000002on;@aP04o`000?oNc<Oog/c7o`0000;of/S800Go0000omK4bOoFa<Woe/C9o`000003
om6ob@;o00000onoZL@00ol0003o^ZG3okZU``02okZU``03o`000?nfXL?o]Z7300;o]Z7300?o0000
ok6M`onaWL<01?naWL<01Ol0003o[Y[3ojjJ`on^V/?o000000?oWH_000?o0000oiV8_onIR;l01OnI
R;l00ol0003oUXK0oiJ6`006oiJ6`005o`000?nCQ<3oThC0oi>4`?l000001OmoMl400ol0003oOGO2
ogeg`P04ogeg`P03o`000?mkMl?oNgO300KoNgO300?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Nooooo`;o0000A_ooool01_l007ko0000o`0T
[ol0003o02B`o`0000;o02Vc00Co0000od5Ia?m1FLCo00001Om;H<L00ol0003oEf[:oeMZbP02oeMZ
bP?oIGC>00?o0000ohZ4a_l000001OnCRlP00ol0003oWIC9oifDb@03oifDb@03o`000?nWW<_oYic;
00;oYic;00?o0000ok6Vc?naY/`00onaY/`01Ol0003o_:o=okb_cOnl[lgo000000CoaKO=00Go0000
olk0c?o>`<coc/3<o`000003omK7b`05o`000?oMc/WogLk9omg>bOl000000ooSdlL00ol0003oj=S5
onSHa@02o`0000;ok=g400?o0000onkO`Ol000000_o_hL85o`000004oo7U`?oai;oolNBoo`0000?o
l>C00_l000001?o_hL7o0000ongP`ol00003oncOa@03o`000?oZg/Oo000000;oh]3600Co0000omk<
aooNc<Oo00000_oJb<P01Ol0003oe/C9omK4bOoFa<Wo000000?odKo900Ko0000olfkb_o=^l[o0000
oknYa?l00004okZU``03o`000?nfXL?o]Z7300;o]Z7300?o0000ok6M`onaWL<01?naWL<00ol0003o
[Y[3ojjJ``03ojjJ``03o`000?nMRl3o000000OoVHRo00?o0000oiJ6`?nFQ/001_nFQ/000ol0003o
ThC0oi>4`003oi>4`005o`000?moMl7oOgO1ogmg`Ol000001_mmMl800ol0003oNgO3og]g``06og]g
``03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`008?ooool00ol0003oooooooooo`14ooooo`03o`00O_l0003o000000;o02B`00Ko0000o`0Y/ol0
<[Wo0000od5Ia?l00004od]Pa`03o`000?mGJ/[oEf[:00?oEf[:1?mUM<h2o`0000GoTh_800?o0000
oifDbOnMU<T00_nMU<T00ol0003oYic;ojNLb`03ojNLb`03o`000?naY/co/JK<00;o/JK<00?o0000
okb_cOnl[ld00_nl[ld01Ol0003oaKO=olFgcOo5]lgo000000?oc/3<00?o0000omK7booFal/00_oF
al/01Ol0003ogLk9omg>bOoMc/Wo000000;ohm?700?o0000onSHaOoXf<D00_l00003oncMa0;o0000
0_o_hL800ol0003okn?2o`000002oo3T`@;o000000?olNBoo`000?l000000_o`i<001?l0003oknG2
o`000?l00002ongP``05o`000?o/glGok=o5o`000?oZg/L00_l000000ooRd<Ko0000omk<a`02omk<
a`04o`000?oJb<Sof/S8o`0000;oe/C900Go0000om6obOoA_lWodKo9o`000003olfkbP;o00001?nj
YL<00ol0003o]Z73okJQ``02okJQ``03o`000?naWL?o/Ig300?o/Ig30_l00006ojjJ``;o00001onI
R;l00ol0003oUXK0oiJ6`005oiJ6`0;o00001onCQ<000ol0003oOgO1o`000007ogeg`P03o`000?mk
Ml?oNgO300GoNgO300?o0000ooooooooool04?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Cooooo00So001no`000?l09;3o02B`o`00
0?l0:K?o0000o`0b^@;o00001?m;H<L00ol0003oEf[:oeMZbP02oeMZbP03o`000?mUM<koIGC>00;o
IGC>0_mdPM401Ol0003oTh_8oi>;b?nCRlSo000000GoWIC900?o0000ojNLbonWW</00_nWW</00ol0
003o/JK<ok6Vc003ok6Vc003o`000?nl[lgo_:o=00;o_:o=00Go0000olFgcOo5]lgoaKO=o`000003
olk0c003o`000?oFal_oe/O;00;oe/O;00Co0000omg>bOoMc/Wo00000ooSdlL01Ol0003oj=S5o`00
0?oXflOo000000?ok=g400Ko0000onoQ`_o_hL;o0000onoS`_l00002oo3T`@08o`000?oaiL3o0000
o`000?o`i/;o0000oo3T`?l00002onoU`P04o`000?o]h<?okN33o`0000;ok=o500?o0000on[Naol0
00000_oWgLT01Ol0003og/c7omk<aooNc<Oo000000;of/S800Co0000omK4bOoFa<Wo00000ooA_lT0
1ol0003ocK_:olfkb_o=^l[o0000olRhb_l000000onjYL<00ol0003o]Z73okJQ``02okJQ``03o`00
0?naWL?o/Ig300?o/Ig300?o0000ojjJ`on^V/<01On^V/<00ol0003oZYO3o`000006oiV8_`03o`00
0?nFQ/3oUXK000GoUXK000?o0000oi>4`?nCQ<001onCQ<02o`0000OoOGO200?o0000og]g`omkMl<0
1OmkMl<00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
1Oooool002;ooooo00?o0000ooooooooool0A?ooool01?l007ko0000o`0T/?l00002o`0Y/`;o03:i
00?o0000od]Paom;H<L00_m;H<L00ol0003oEf[:oeMZbP02oeMZbP03o`000?mUM<koIGC>00;oIGC>
0omdPM401?l0003oTh_8oi>;b?l00004oifDb@03o`000?nWW<_oYic;00?oYic;00?o0000ok6Vc?na
Y/`00_naY/`00ol0003o_:o=okb_c@02okb_c@03o`000?o5]lgoaKO=00;oaKO=00Go0000olk0c?o>
`<coc/3<o`000003omK7b`05o`000?oMc/WogLk9omg>bOl000000ooSdlL2o`0000;oj=_700?o0000
oncMa?o/gL@00_l000003_o_hL;o0000onoS`_o_hl;o0000oo3T`Ol0003olNG0o`000?oai;ool>K2
o`000?o`i<3o00000_o_iL82o`000007ongP`ol0003ok=o5oncOaOl0003oj]k7o`000002onOMb@;o
00000_oNc<L01?l0003of/S8om[8b?l00002omK4b@05o`000?oA_lWodKo9om6obOl000000oo=^lX0
1ol0003ob;S:olRhb_o8^<[o0000okZU`ol000001?nfXL<00ol0003o/Ig3ok6M``03ok6M``03o`00
0?n^V/?o[Y[300Go[Y[300Go0000ojZG`onZUl?oZYO3o`000004oiV8_`03o`000?nFQ/3oUXK000Go
UXK000?o0000oi>4`?nCQ<001onCQ<000ol0003oTHC1o`000006ogeg`P03o`000?mkMl?oNgO300Go
NgO300?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo000Sooooo`;o0000AOooool02Ol007_o0000o`0T/?l0003o02Vco`000?l0<[Wo03k1o`000003
od]Pa`03o`000?mGJ/[oEf[:00;oEf[:00?o0000ofEdc_mUM<h00_mUM<h4ogB1d@03o`000?nCRlSo
000000CoWIC900?o0000ojNLbonWW</00_nWW</00ol0003o/JK<ok6Vc003ok6Vc003o`000?nl[lgo
_:o=00;o_:o=00Go0000olFgcOo5]lgoaKO=o`000003olk0c003o`000?oFal_oe/O;00;oe/O;00Co
0000omg>bOoMc/Wo00000ooSdlL2o`0000?oj=_700Co0000oncMa?l0003ok>350_l00002onoS`P03
o`000?o`i<7ol>C100?o00000_o`i/82o`0000;oknG200Co0000onkVaOl0003o00000_o/glD00ol0
003oj]k7o`000002onOMb@03o`000?oUg<coiMc<00;o00000_oJb<P01?l0003oe/C9omK4bOl00003
om6ob@05o`000?o=^l[ocK_:olfkb_l000001?o8^<X2o`0000Co]Z7300?o0000ok6M`onaWL<00ona
WL<00ol0003o[Y[3ojjJ``04ojjJ``;o00001OnZUl<01?l0003oVHRooiV8_ol00007oiJ6`003o`00
0?nCQ<3oThC000KoThC00_l00003oi64`@03o`000?mmMl;oOGO200;oOGO200?o0000og]g`omkMl<0
1OmkMl<00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1Oooool002Gooooo00?o0000ooooooooool0@oooool01Ol007_o0000o`000?l0:K?o000000;o03:i
00Go03k1o`000?m;H<OoBf37o`000004oeMZbP03o`000?mUM<koIGC>00;oIGC>00?o0000ogB1dOmd
PM400_mdPM42o`0000CoWIC900?o0000ojNLbonWW</00_nWW</00ol0003o/JK<ok6Vc003ok6Vc003
o`000?nl[lgo_:o=00;o_:o=00Go0000olFgcOo5]lgoaKO=o`000003olk0c003o`000?oFal_oe/O;
00;oe/O;00Co0000omg>bOoMc/Wo00000_oSdlL2o`0000?oj=_700?o0000oncMa?l000000_o/h<D0
1?l0003okn?2onoS`_l00002oo3T`@;o000000GoknO3o`000?o`i/;ol>K2o`000002onoU`P04o`00
0?o^i/Gok^K5o`0000;ok=o500?o0000on[Naol000000_oWgLT00ol0003oiMc<onGLc002o`0000;o
f/S800Co0000omK4bOoFa<Wo00000ooA_lT00ol0003ocK_:olfkbP02o`0000Cob;S:00?o0000olBd
bol000000onfXL<00ol0003o/Ig3ok6M``03ok6M``03o`000?n^V/?o[Y[300Co[Y[300?o0000ojZG
`onZUl<01OnZUl<00ol0003oVHRoo`000007oiJ6`003o`000?nCQ<3oThC000KoThC000?o0000oi64
`OnAQ<401?nAQ<401?l0003oOGO2ogeg`_l00007og]g``03o`000?oooooooooo01Oooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`05ooooo`009_ooool00ol0003oooooooooo`13oooo
o`06o`00Nol0003o02Vco`0Y/ol0003o03:i0_l0?/400ol0003oBf37o`000004oeMZbP05o`000?mU
M<koIGC>ofEdc_l000001OmdPM42oh>=e004o`000?nMU<WoWIC9o`0000GoYic;00?o0000ok6Vc?na
Y/`00_naY/`00ol0003o_:o=okb_c@02okb_c@05o`000?o5]lgoaKO=olFgcOl000001?o>`<`01Ol0
003oe/O;omK7booFal_o000000?ogLk90ol000000ooSel_o0000onSKa`02onSKa`;o00000oo/h<D2
o`000004onoS`_l0003o0000o`0000?oknO30_o`i/82o`000004onoU`_l0003ok^K5onkVa@;o0000
00Cok=o5o`000?oZg/Oo00000_oWgLT01_l0003oiMc<onGLc?l0003oh][>o`0000;of/S80_oFa<T0
1Ol0003odKo9om6obOoA_lWo000000;ocK_:00?o0000olRhb_o8^<X00oo8^<X01ol0003oa;C;olBd
boo4]<_o0000okJQ`ol000001?naWL<2o`0000Ko[Y[300?o0000ojZG`onZUl<01_nZUl<2o`0000Ko
UXK00_l00008oi>4`003o`000?nAQ<7oTHC100GoTHC100?o0000ogeg`_l000001omkMl<00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Oooooo
00?o0000ooooooooool0@oooool01_l007_o0000o`0Y/ol0003o03:io`0000;o03k10_l00004oeMZ
bP05o`000?mUM<koIGC>ofEdc_l000001OmdPM43oh>=e003o`000?nMU<Wo000000CoYic;00?o0000
ok6Vc?naY/`00onaY/`00ol0003o_:o=okb_c@02okb_c@05o`000?o5]lgoaKO=olFgcOl000000oo>
`<`00ol0003oe/O;omK7b`02omK7b`04o`000?oMc/Wo0000o`0000CohmO;00Go0000onSKaooXflOo
j=_7o`000003oncPa@03o`000?o]hlGokN?500;o000000Sok^K5o`000?o_il?oknO3o`000?o`i/;o
0000onoXa0;o00000_o^i/D01_l0003okNO8o`000?o/glGoj]k7o`0000;oimg900Co0000onGLc?oU
g<co00000_oRf/h2o`0000;oe/C900Go0000om6obOoA_lWodKo9o`000002olfkbP03o`000?o8^<[o
b;S:00;ob;S:0_l00004olBdb`;o00001?naWL<00ol0003o[Y[3ojjJ``04ojjJ``;o00002?nZUl<0
0ol0003oYiG3o`000005oiJ6`003o`000?nCQ<3oThC000KoThC00_l00008oi64`@;o00001omkMl<0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool0
02Sooooo0_l00014ooooo`03o`000?l0:K?o000000;o03:i0ol0?/400ol0003oEf[:oeMZbP02oeMZ
bP05o`000?mUM<koIGC>ofEdc_l000001OmdPM44oh>=e0;o00001?nWW</00ol0003o/JK<ok6Vc002
ok6Vc003o`000?nl[lgo_:o=00?o_:o=00Go0000olFgcOo5]lgoaKO=o`000003olk0c003o`000?oF
al_oe/O;00;oe/O;0_l000000ooLd/oo0000on?Gb`03on?Gb`03o`000?oXflOoj=_700;o00000_o/
h<D01ol0003okN?5ongSaOo]hlGo0000onkVaOl000000oo_il<2o`000003onoXa?l0003oknG200;o
k^K500Ko0000ongWb?l0003o0000on[Naol00002onOMb@04o`000?oUg<coiMc<o`0000;oh][>00?o
0000omkIdOl000000_oFa<T3om6ob@04o`000?o=^l[ocK_:o`0000Cob;S:00?o0000olBdboo4]</0
0oo4]</00ol0003o_k3;o`000003ok6M``03o`000?n^V/?o[Y[300Co[Y[300?o0000ojZG`onZUl<0
1_nZUl<2o`0000?oYiG300Go0000oiJ6`?nFQ/3oUXK0o`000008oi>4`003o`000?nAQ<7oTHC100Oo
THC100Co0000oi24`on@Q<?o00001OmkMl<00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0@Oooool01_l007ko
0000o`0Y/ol0003o03:io`0000;o03k100Go3Dk;o`000?mGJ/[oEf[:o`000004ofEdcP03o`000?md
PM7oM87A00;oM87A00?o0000oh>=e?n3SM@00_n3SM@2oi>Ie`?o000000?oYic;o`000?naY/`00ona
Y/`00ol0003o_:o=okb_c@02okb_c@05o`000?o5]lgoaKO=olFgcOl000001?o>`<`01?l0003oe/O;
omK7booFal/2o`0000;og=;?00Go0000on?GbooSel_ohmO;o`000002onSKa`03o`000?oXglWo0000
00;ok>3500Co0000ongSaOo]hlGo00000_o^i/D00ol0003oknO3onoW``02o`000003onoXa?l0003o
000000;ok^K500Ko0000ongWb?l0003ojnW;o`000?oZg/L2onOMb@04o`000?oUg<coiMc<o`0000;o
h][>00?o0000omkIdOoNfM400_l00003om6ob@04o`000?o=^l[ocK_:o`0000Cob;S:00?o0000olBd
boo4]</00_o4]</2o`0000?o_k3;00?o0000ok6M`ol000001_n^V/<00ol0003oZYO3ojZG``05ojZG
``;o00001_nWUL<00ol0003oUXK0o`000007oi>4`0;o00002?nAQ<42o`0000CoT8C300Go0000og]g
`omkMl?oNgO3o`00000Pooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool0
02_ooooo00?o0000ooooooooool0@Oooool00ol007_o0000o`000002o`0b^@?o03k100Co3Dk;o`00
0?mGJ/[o00001?mUM<h00ol0003oM87AogB1d@02ogB1d@03o`000?n3SMCoPhgD00;oPhgD1OnCVML4
o`0000;o/JK<00?o0000okb_cOnl[ld00_nl[ld01Ol0003oaKO=olFgcOo5]lgo000000?oc/3<00?o
0000omK7booFal/00ol00003omcBc`07o`000?oSel_ohmO;on?Gbol0003oj=_7o`000003onSOb@;o
00000_o]hlD01?l0003ok^K5onkVaOl00002onoW``;o000000SoknS4o`000?o^jlSo0000onkVaOl0
003okNO8o`0000;ojnW;00Coj]k7onOMbOoWgLWo00000_oUg<`01?l0003oh][>on;Jc_l00002omkI
d@03o`000?oKem?o000000?odKo90_o=^lX01?l0003ob;S:olRhb_o8^<X2o`0000Coa;C;00?o0000
okn`bono/</00ono/</2o`0000Ko[Y[300?o0000ojZG`onZUl<01OnZUl<00ol0003oYiG3ojNE``06
ojNE``;o00001onCQ<000ol0003oTHC1oi64`@07oi64`@03o`000?n@Q<?oT8C300GoT8C300?o0000
og]g`ol000008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000/oooo
o`03o`000?oooooooooo047ooooo00Go001no`000?l0<[Wo03:io`000002o`0n`@;o3Dk;0_l00004
ofEdcP03o`000?mdPM7oM87A00;oM87A00?o0000oh>=e?n3SM@00_n3SM@00ol0003oTiWGoi>Ie`02
oi>Ie`CoXjKH1Ol00002okb_c@06o`000?o5]lgoaKO=olFgcOl0003oc/3<1Ol00002omC<dP05o`00
0?oLd/oog=;?omcBcol000000ooSel/2o`0000Coj=o900Go0000ongSaOo]hlGokN?5o`000002onkV
a@?o000000?ok^W7o`000?l000000_o^jlP01?l0003ok^K5ongWb?l00002on_Yb`04o`000?oWgLWo
img9onOMb@;oiMc<00Co0000on;Jc_oRf/ko00000_oNfM401_l0003ofmOCom_GdooKem?o0000om6o
b@;ocK_:1?o8^<X00ol0003oa;C;olBdb`02olBdb`;o00001Ono/</00ol0003o^jg<o`000004ojjJ
``;o00001_nZUl<2o`0000OoYiG30_l000000onTTlCo0000oi>4`005oi>4`003o`000?nAQ<7oTHC1
00OoTHC100?o0000oi24`on@Q<<01_n@Q<<2o`0002?ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`04ooooo`00;Oooool2o`0004;ooooo00Co001ko`000?l0<[Wo00000_l0?/401?l0
003o3Dk;o`e>bol00004ofEdcP03o`000?mdPM7oM87A00;oM87A00?o0000oh>=e?n3SM@00_n3SM@0
0ol0003oTiWGoi>Ie`02oi>Ie`GoXjKH00Co0000ok6af?na/MSo/K7H2?l00002ol[5e@03o`000?oD
c=;oe<cB00;oe<cB00Co0000omcBcooLd/oo00000ooSel/2o`0000Goj=o90_l000000oo]hlGo0000
o`000002o`0000?ok^W700So0000onoXa?o^jlSok^_8o`000?o^i/GokNO8o`0000;ojnW;0_l00002
onOMb@;oiMc<00Co0000on;Jc_oRf/ko00000_oNfM401?l0003ofmOCom_GdooKem<2o`0000;ocK_:
1?o8^<X00ol0003oa;C;olBdb`02olBdb`03o`000?no/<_o_k3;00?o_k3;0_l00003ok^]c004o`00
0?n^V/?o[Y[3o`0000KoZYO30_l00008ojNE``03o`000?nTTlCoY9?400;oY9?400Co0000oi>4`?nC
Q<3oThC00_l00008oi64`@;o00002?n@Q<<00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01?ooool002oooooo00?o0000ooooooooool0@?ooool01?l018Ko
0000o`0b^Ol00002o`0n`@;o3Dk;00Go9F7Eo`000?mUM<koIGC>o`000005ogB1d@03o`000?n3SMCo
PhgD00;oPhgD00?o0000oi>IeonCVML00_nCVML00ol0003oXjKHoj>Vf002oj>Vf003o`000?na/MSo
/K7H00;o/K7H00Go0000okjkeonn^mOo_[_Go`000004ol[5e@05o`000?oDc=;oe<cBomC<d_l00000
0ooLd/l01_l0003ohmO;on?Gbol0003oi=g>o`0000Coj=o900?o0000on[Tb_oZi<X00_l00002oncX
b@05o`000?o^jLOok^W7o`000?o_j<@00_o^jlP2o`0000;okNO80_o[jL/01?l0003ojN_?o`000?oW
gLT2onGLc005o`000?oRf/koh][>o`000?oNfM400_l00003om_Gd`04o`000?oGe=Ko0000olfkbPCo
b;S:00Co0000olBdboo4]<_oa;C;0_l00004okn`b`;o00001Onk[L`00ol0003o[Y[3o`000006ojZG
``03o`000?nWUL?oYiG300KoYiG30_l00006ojBCa003o`000?nCQ<3o000000WoTHC100?o0000oi24
`on@Q<<01_n@Q<<2o`0002Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04oooo
o`00<?ooool00ol0003oooooooooo`10ooooo`03o`04Q_l0003o000000;o03k100Oo0000o`e>bol=
C/_o9F7Eo`000?mUM<ko000000GoM87A00?o0000oh>=e?n3SM@00_n3SM@01Ol0003oTiWGoi>IeonC
VMOo000000GoXjKH00?o0000ok6af?na/MP00_na/MP01Ol0003o_[_Gokjkeonn^mOo000000Cob/GE
00Go0000omC<d_oDc=;oe<cBo`000003omcBc`03o`000?oSel_o000000;oi=g>00Go0000onSObOoX
glWoj=o9o`000003on[TbP04o`000?o/j<Wok>S9o`0000?ok^W700Oo0000onk[b?o^jlSo0000on_^
c?l0003okNO800;ojnW;00Co0000onW[col0003o00000ooUg<`2on;JcP;og]WA00Co0000om_GdooK
em?ofmOC0_l000000ooGe=Ko0000o`000004olRhbP05o`000?o4]<_oa;C;olBdbol000001Ono/</0
0ol0003o^jg<ok^]c005ok^]c0;o00001OnZUl<2o`0000OoYiG30_l00008ojBCa0;o00002?nAQ<42
o`0000OoT8C30_l0000[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0
037ooooo0_l00011ooooo`05o`04Q_l0003o03k1o`0n`Ol000000_l=C//2obEQe@;o00001OmdPM40
1Ol0003oPhgDoh>=e?n3SMCo000000CoTiWG00?o0000oj>Vf?nSY]P00_nSY]P00ol0003o/K7Hok6a
f003ok6af005o`000?nn^mOo_[_Gokjkeol000001?o:aMD01Ol0003oe<cBomC<d_oDc=;o000000?o
g=;?0_l00004onCMcP03o`000?oXglWo000000?oj^C:00Co0000oncXbOo/j<Wo00000_o^jLL2o`00
00;ok^_800Co0000on_^c?l0003okNO80_o[jL/01Ol0003ojN_?o`000?oVkM?o000000;oiMc<0_oR
f/h2omkId@05o`000?oKem?ofmOCom_Gdol000000_oGe=H00ol0003od];Ho`000003olRhbP?oa;C;
0_l00004okn`b`;o00001_nk[L`2o`000003okN[c?l0003oZYO300;oZYO30_l00007ojNE``;o0000
2?nTTl@2o`000003oj6BaOl0003oTHC100KoTHC100?o0000oi24`on@Q<<01_n@Q<<00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool003?ooooo00?o
0000ooooooooool0?oooool01ol018Ko0000o`0n`Ol0?/7o0000o`e>bol000000_lUHMD2o`0000?o
M87A00?o0000oh>=e?n3SM@00_n3SM@00ol0003oTiWGoi>Ie`02oi>Ie`03o`000?nSY]SoXjKH00;o
XjKH00?o0000ok6af?na/MP00_na/MP00ol0003o_[_Gokjke`02okjke`03o`000?o:aMGob/GE00;o
b/GE00Go0000omC<d_oDc=;oe<cBo`000002omcBc`;o00001OoTgLh2o`0000?oj^C:00Co0000oncX
bOo/j<Wok>S90ol000001?o[k<co0000onk[b?l00002on_^c006o`000?o[jL_ojnW;o`000?oYjloo
00000_oVkM<01?l0003oiMc<on;Jc_oRf/h2omkId@03o`000?oKem?ofmOC00;o000000?oemCFo`00
0?l000000ooBd]P00ol0003ob;S:olBdb`02olBdb`03o`000?no/<_o_k3;00?o_k3;00?o0000ok^]
c?nk[L`01?nk[L`2o`0000Co]j_<00?o0000ojZG`ol000002?nWUL<00ol0003oY9?4ojBCa006ojBC
a0;o00001?nQT/D00ol0003oTHC1oi64`@03oi64`@03o`000?n@Q<?oT8C300GoT8C30_l0000_oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000oooooooo
ool0?oooool2o`000004o`0n`Ol0003o3Dk;o`e>b`;o9F7E0_loM]h2o`000003ogB1dOl0003oPhgD
00?oPhgD00?o0000oi>IeonCVML00_nCVML00ol0003oXjKHoj>Vf002oj>Vf003o`000?na/MSo/K7H
00;o/K7H00?o0000okjkeonn^mL00_nn^mL01Ol0003ob/GEol[5eOo:aMGo000000Coe<cB0ol00000
0ooMfmCo0000onCMcP03onCMcP?o00000ooZi<X00ol0003ok>S9oncXb@02o`0000;ojnc<00Co0000
onk[b?o^jlSojnk<0_l00003on_Yb`04onW[col0003oi^gConK]d`;o00000_oRf/h2omkId@04o`00
0?oKem?ofmOCo`0000;oemCF00?o0000om;Bf?oBd]P00_oBd]P2o`0000?oa;C;00?o0000okn`bono
/</00_no/</2o`0000Go^jg<0_l00006okN[c0;o00001onWUL<2o`0000OoY9?40_l00007oj6Ba@03
o`000?nAQ<7oTHC100;o00001on@Q<<00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0?oooool3o`0000;o3Dk;
00?o0000obEQeOlUHMD00oloM]h2o`0000CoPhgD00?o0000oi>IeonCVML00_nCVML00ol0003oXjKH
oj>Vf002oj>Vf003o`000?na/MSo/K7H00;o/K7H00Go0000okjkeonn^mOo_[_Go`000004ol[5e@04
o`000?oDc=;oe<cBomC<dP;o00000ooMfm@01Ol0003oi=g>onCMc_oTgLko000000?oi^G@00?o0000
on[Tb_l000000ol00004on_/c006o`000?o^jlSojnk<o`000?oXlM3o00000_o[jL/02?oYjloo0000
onK]dooVkM?o0000on;^f?l0003oh][>0_oNfM43om_Gd`04o`000?oGe=Ko0000o`0000?od];H0_l0
00001?o>cm[o0000olBdboo4]</5okn`b`03o`000?nk[Lco^jg<00?o^jg<0_l00006okN[c0;o0000
00?o]:S=o`000?nWUL<01?nWUL<2o`0000OoY9?40_l00009oj6Ba@03o`000?nAQ<7o000000OoT8C3
0_l0000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool003Kooooo0_l0
0010ooooo`05o`000?l0?/7o0000o`e>bol000000_lUHMD4ocmfgP;o00000on3SM@00ol0003oTiWG
oi>Ie`02oi>Ie`03o`000?nSY]SoXjKH00;oXjKH00?o0000ok6af?na/MP00_na/MP01Ol0003o_[_G
okjkeonn^mOo000000Cob/GE00?o0000omC<d_oDc=800_l00005omgKe003o`000?oTgLko000000Go
i^G@0_l00002onSZc`03o`000?o[k<cojnc<00;ojnc<00?o0000on_^c?l000000_oXlM001?l0003o
jnW;onW[col00002onK]d`04o`000?oRk]So0000o`0000;og]WA0_oKem<2o`000003omODe_l0003o
d];H00?od];H00Co0000olk?f_o>cm[oc/oJ0_l00004okn`b`;o00001?nk[L`2o`0000Ko]j_<0_l0
0004okBXc@05o`000?nWUL?oYiG3ojNE`ol000001_nTTl@3o`0000_oXI;50_l00007oi24``03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00>?oo
ool00ol0003oooooooooo`0nooooo`;o00000_l=C//00ol0003o9F7Eo`000003ocmfgP;oG8[U1?l0
0004oi>Ie`03o`000?nSY]SoXjKH00;oXjKH00?o0000ok6af?na/MP00_na/MP01Ol0003o_[_Gokjk
eonn^mOo000000Cob/GE0ol000000ooDem[o0000omgKe004omgKe0;o00001_oViM001?l0003oj>[?
onSZcol00003on_/c0;o000000Kojnk<o`000?oXlM3oj?7@o`000?o[jL/2onW[c`;oi^gC00Ko0000
on;^f?l0003og_3Mo`000?oNfM42om_Gd`04o`000?oGe=KoemCFo`0000?od];H0_l00002olk?fP;o
000000CobLcMo`000?no/<_o_k3;0_l00004ok^]c0;o00001_ngZl`2o`0000Ko]:S=00Co0000ojNE
`ol0003o00001OnTTl@2o`0000_oXI;50ol000000onOT/Ko0000oi24``04oi24``;o0000>?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo
03gooooo00Go00B6o`000?l0003o3Dk;o`000002obEQe@04o`000?loM]ko?gKNo`0000CoG8[U0_l0
0002oi>Ie`03o`000?nSY]SoXjKH00?oXjKH00?o0000ok6af?na/MP00_na/MP01Ol0003o_[_Gokjk
eonn^mOo000000?ob/GE0_l00004omCGfP03o`000?oMfmCogM_D00;ogM_D0_l00005onKUd005o`00
0?oXj/ooj>[?o`000?o[k<`00ol000000ooXl=7o0000onSad002onSad0;o00000_oYjll2onK]d`?o
000000?og_3Mo`000?l000000_oKem<01?l0003oemCFomODe_l00002om;Bf0;o00000_o>cmX2o`00
00CobLcM0_l00004ok^]c0;o00001_ngZl`2o`0000So]:S=0_l00005ojBCa0;o00002onQT/D2o`00
00GoWi;600?o0000oi24`on@Q<<00_l0000kooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool003[ooooo00?o0000ooooooooool0?Oooool4o`0000;o9F7E00Go0000ocmfg_lo
M]ko?gKNo`000003oeb:i@;oN9kZ0ol00004oj>Vf003o`000?na/MSo/K7H00;o/K7H00?o0000okjk
eonn^mL00_nn^mL4o`000003olWAh?l0003oe=OJ00?oe=OJ00Go0000omgKe?oMfmCogM_Do`000002
on3Ue`05o`000?oViM3oi^G@onKUd?l000000ooXj/l2o`0000?oj?3A00So0000onSad?oXlM3oj?7@
o`000?oSmMKo0000onW[c`;oi^gC0_l00002omk`g@04o`000?oHl>;o0000om_Gd`;oemCF00Go0000
om;Bf?oBd]Sod];Ho`000003olk?fP03o`000?o9c=gobLcM00?obLcM0_l00003ok^]c0;o00001Ong
Zl`3o`0000Oo]:S=0ol000000on`Y/ko0000ojBCa002ojBCa0;o00002_nQT/D3o`0000OoWi;600?o
0000oi24`ol00000?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000k
ooooo`;o0000?_ooool2o`000004o`e>bol0003o9F7Eo`0000?o?gKN00Go0000oeb:iOmLR^GoG8[U
o`000003ogRNjPCo000000?oXjKHo`000?na/MP00ona/MP00ol0003o_[_Gokjke`03o`0000CobM7P
00?o0000omCGf_oDemX00_oDemX01?l0003ogM_DomgKe?l00004on3Ue`04o`000?oViM3o0000onSZ
c`?o00001?oXl=400ol0003oj?7@onSad002o`000003on?ee_l0003ojN_?00;oi^gC00?oh^kHo`00
0?oNl=d00_l000000ooHl>;o0000o`000002omODeP03o`000?oBd]Sod];H00;o00000_o>cmX2o`00
00?obLcM0ol000000oo4bMko0000ok^]c002o`0000Go]j_<0_l00007okBXc@?o00001On`Y/h3o`00
00[oXI;50_l0000:oinBaP;o0000?oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo000mooooo`03o`000?oooooooooo03cooooo1?l000001OlUHMGo0000ocmfg_loM]ko0000
00CoG8[U00?o0000ogRNj_mhW^X01?nA[n/9o`0000;o^/WU00?o0000olWAh?o9dN000_o9dN000ol0
003oe=OJomCGfP03omCGfP;o00001_oPiML3o`0000;oi>gF00?o0000onS`dOoXl=400_l00002onSa
d003o`000?oSmMKohoGF00;o00000_oVkM<2o`000003omk`gOl0003of?3R00;o000000?odO7Wo`00
0?oGe=H00_oBd]P2o`0000;oc/oJ0_l00003olW<g@;o00001?o4bMh2o`0000Go]j_<0_l00006okBX
c@?o00001_n`Y/h3o`0000[oXI;50_l00009oinBaP?o0000@_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo000nooooo`03o`000?oooooooooo03cooooo1Ol00003ocmfgP05
o`000?mLR^GoG8[Uoeb:iOl000000omhW^X4oi6_j`GoYkkY00?o0000ok[9iOnjbND00_njbND00ol0
003obM7PolWAh003olWAh004o`000?oDem[oe=OJomCGfP?o00001OoPiML00ol0003oi>gFonC]eP02
onC]eP08o`000?oXl=7o0000o`000?oRm=So0000onSad?l00002on?eeP06o`000?oLn=co0000onK]
dol0003og_3M0_l000001?oHl>;o0000om7aiooAlNL2o`0000;od];H00?o0000olk?f_o>cmX00_l0
0002olW<g@?o00000oo4bMh3o`000003okk6h?l0003o]j_<00;o]j_<0_l00006okBXc@;o00001_n`
Y/h3o`0000;o[JG?00?o0000oj6BaOnQT/D01OnQT/D3o`0000SoWi;60ol00016ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool003oooooo00?o0000ooooooooool0??ooool4
o`0000?o?gKN00Go0000oeb:iOmLR^GoG8[Uo`000003ogRNjP05o`000?nA[n_oTJo[oi6_jol00000
1?nW_^T00ol0003o^/WUok[9i@03ok[9i@03o`000?o9dN3obM7P00;obM7P00Co0000omCGf_l0003o
00000ooGiN001Ol0003oh>GGon3UeooPiMOo000000Coi>gF00?o0000onS`dOl000000_oRm=P01?l0
003oj?7@o`000?oSmMH2o`000007omchg?l0003oi^gCo`000?oNl=go0000omS`hP02o`000007om7a
iol0003o0000olW`kOl0003od];Ho`000002olk?fP03o`000?o9c=gobLcM00;o00000oo4bMh3o`00
00Go_/KP0ol00005okBXc@?o00001On`Y/h3o`0000Ko[JG?00?o0000oj6BaOnQT/D00_nQT/D2o`00
00SoWi;60ol0001:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0043o
oooo0_l0000mooooo`Go000000?o?gKNo`000?mLR^D00omLR^D01?l0003oN9kZogRNj_l00004oi6_
j`03o`000?nW_^WoYkkY00;oYkkY00?o0000ok[9iOnjbND00_njbND00ol0003obM7PolWAh002olWA
h0;o00001_oGiN000ol0003oh>GGo`000005onC]eP;o00000ooRm=P01?l0003ohoGFo`000?l00002
omchg0;o00000_oNl=d3o`000003om7aiol0003o000000;obO3]0_l00003olk?fP04olW<gOl0003o
0000o`0000;oa<WN0ol00006okk6h0?o00001?ndZ<d3o`0000Go/:K>0ol00009ojfUc`03o`000?nQ
T/Go000000;o00002?nOT/H2o`0004gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`00@_ooool00ol0003oooooooooo`0looooo`Go00001?mLR^D01Ol0003oN9kZogRNj_mh
W^[o000000?oTJo[00?o0000ojNnjOnW_^T00_nW_^T00ol0003o^/WUok[9i@02ok[9i@04o`000?o9
dN3obM7PolWAh0;o00002?oGiN07o`0000?oh_CH0_l000001?oSmMKo0000omchg?oLn=`3o`000005
omk`gOl0003of?3Ro`000?oAlNL00_l000001oo9l>go0000o`000?l0003o`Noao`000?o>cmX00ol0
0002olC9gP?o00001Onna^04o`0000;o^L?R00?o0000okBXcOl000000_l00005ok2VcP?o00002on]
YLl3o`0000SoWi;60ol0001@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_oo
ool004?ooooo00?o0000ooooooooool0??ooool3o`000003ocmfg_l0003oG8[U00;oG8[U00Go0000
ogRNj_mhW^[oN9kZo`000003oi6_j`03o`000?nW_^WoYkkY00;oYkkY00?o0000ok[9iOnjbND00_nj
bND01?l0003obM7PolWAh?l00003ol_Sj@03o`000?oGiN3oenGP00?oenGP00?o0000omc`g_oLl=h0
0ooLl=h2on;df0?o000000CofOSOo`000?l0003og?SL1?l000001?oNl=go0000o`000?oAlNL2o`00
0003olW`kOl0003o000000;o`Noa0ol000001?o9c=go0000olC9g_o4bMh2o`0000Go_/KP0ol00005
okW3hP?o00001On`Y/h3o`0000[o[JG?1?l00002ojVTd@03o`000?nOT/KoWi;600?oWi;60ol0001D
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000oooo
ooooool0??ooool7o`000005oeb:iOl0003oN9kZogRNj_l000000onA[n/00ol0003oYkkYojNnj@02
ojNnj@03o`000?njbNGo^/WU00?o^/WU0_l00005ol_Sj@05o`000?oGiN3oenGPomOUh?l000001?oL
l=h4o`0000?ofOSO00Wo0000omchg?l0003o0000om;kh_l0003oa?cVo`000?oHl>800_oAlNL4o`00
0006ol7_lOl0003o0000o`000?ngk?Ko00000_o4bMh2o`0000Co_/KP1?l00003okW3hPGo00000_nd
`><00ol0003o/:K>ok2VcP03o`0000Wo[JG?1?l00007ojVTd@03o`000?nOT/Ko000000;o0000F?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000?_ooool2
o`000003o`1We_lRRnco8X_/00Co000000GoN9kZo`000?nA[n_oTJo[o`000005ojNnj@03o`000?nj
bNGo^/WU00?o00001oo;hnT00ol0003oenGPo`000002omc`gPCo00001?oIn=l2o`000005omchg?l0
003od__Ro`000?o4o>H00ol000001OoAlNOo0000o`000?l0003o`Noa00?o000000?o]ncfo`000?l0
00000ol00004okk6h0?o00000_ni`n85o`0000Go]<3S1Ol00009ojfUc`?o00002_nYY=43o`0005_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00Aoooool00ol0003ooooo
ooooo`0looooo`;o000000Ko06OFob:;k?lRRnco8X_/o`000?mBZoT4o`000004oi6_jol0003oYkkY
ojNnj@Go00001?nig_800ol0003obn?Yol_Sj@04ol_Sj@?o00000oo@l^P00ol0003ofOSOomWhg`05
o`000003om;kh_l0003o000000?o00000_oAlNL00ol0003o`Noao`000002o`000003okO/m_l0003o
000000;o00000_nQho`00ol0003o_/KPokk6h002o`0000?o^L?R0ol00004okC0h`Ko00000on__N@0
0ol0003o[JG?ojfUc`04ojfUc`Co00002?nYY=45o`0005oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00B?ooool00ol0003oooooooooo`0looooo`;o000000Go06OFo`00
0?lRRnco8X_/o`000003oe:[n@03ogk4o_l0003o000000;o00001?nPeOX00ol0003o^MkbokWNlP03
okWNlP05o`000?o;hnWobn?Yol_SjOl000001_o@l^P01Ol0003ofOSOo`000?l0003obo[V00;o0000
0_oBnn82o`000003ok7ij_l0003o000000;o000000Co`Noao`000?l0003o]ncf0ol00002oj7So0Ko
00000oni`n82o`0000;o]<3S1_l0000:ojnmi003o`000?n]YLoo000000?o00001onYY=45o`0006Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00BOooool00ol0003ooooo
ooooo`0mooooo`03o`000?l0ImKo000000;o8X_/00Go0000oe:[nOmBZoWoDZ_io`000002ogk4oPKo
X=Gj00?o0000okWNl_nig_800onig_800ol0003obn?Yo`000006om3bj004o`000?oIn=oo0000ol_j
iP?o000000?od__Ro`000?l000001Ol000000oo1ko7o0000okO/mP0=o`000003okW3h_nd`>?o0000
00Go00002_n__N@8o`0000KoZJCA1Ol0001[ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00Oooool004[ooooo0_l0000nooooo`?o00000_lRRn`01Ol0003oDZ_ioe:[nOmBZoWo0000
00;oO/Cn0_l00004oj3EnP03o`000?nig_;o^Mkb00?o^Mkb2?l000000oo;n^Ko0000o`000002okGi
k0Co000000?oV?;Yo`000?l000000_l000000ongk?Ko0000o`00000@o`0000?o[kgT3Ol00006ojZk
i@03o`000?nYY=7oZJCA00Go0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo001<ooooo`03o`000?oooooooooo03gooooo0_l00002ob:;k005o`000?mBZoWoDZ_ioe:[
nOl000000omna?h00ol0003oX=Gjoj3EnP02oj3EnP04o`000?nig_;o0000o`0000Ko_O;b00?o0000
ol_ji_l000000_nenN`3o`000003ok7ij_l0003o000001co00003_nZ^nD8o`0007Kooooo00?o0000
ooooooooool02?ooool1o`00007ooooo0Oooool004gooooo00?o0000ooooooooool0?_ooool4o`00
00?oDZ_i00Go0000ogk4o_mna?koO/Cno`000002oj3EnP?o00000_nml_86o`0000;o]OW/1_l0000=
ooooo`Wo00000on2c?l00ol0003oZ[_UojZki@04ojZki@go0000Ooooool00ol0003oooooooooo`07
ooooo`7o00000Oooool1ooooo`00C_ooool00ol0003oooooooooo`10ooooo`_o00002?nQk?T00ol0
003o]OW/o`000005o`0001Wooooo2_l0002<ooooo`03o`000?oooooooooo00Oooooo0Ol00001oooo
o`7ooooo001?ooooo`;o0000A?ooool00ol3TM7o0000o`000006o`0000;oMm_i2Ol0002cooooo`03
o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo04Gooooo
00?o0000o`>AdOl000001_l000000ooooooo0000ooooo`2hooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`7ooooo001Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0^?oo
ool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000
ooooooooool0^?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00EOooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool01?ooool1o`00
007ooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool005Oooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F?ooool2o`0004Wooooo00?o
0000ooooooooool0^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005[ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`2looooo`05o`000?ooooooooooooooool000000Ooo
ool005_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2mooooo`04o`000?oooooo
ooooo`00007ooooo001Looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0__ooool0
0ol0003oooooo`000001ooooo`00GOooool2o`0004Cooooo00?o0000ooooooooool0__ooool00ol0
003oooooooooo`01o`000000Goooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;oo
oooo0Ol00001ooooo`7o0000001Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
`?ooool2o`000000HOooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;oooooo0ol0
000006;ooooo0_l0000oooooo`03o`000?oooooooooo0;_ooooo1?l00003ooooo`00I?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo0;Oooooo1?l00007ooooo`00IOooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;?ooooo1?l0000;ooooo`00I_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo0;3ooooo0ol0000?ooooo`00Ioooool2o`0003[ooooo00?o
0000ooooooooool0[?ooool4o`0001;ooooo001Yooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0Z?ooool4o`0001Kooooo001Zooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0Y?ooool4o`0001[ooooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0XOooool4o`0001kooooo001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Mooooo`Co0000
8_ooool006kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Iooooo`Co00009_oo
ool006oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Eooooo`Co0000:_ooool0
073ooooo0_l0000`ooooo`03o`000?oooooooooo097ooooo1?l0000^ooooo`00L_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo08kooooo0ol0000booooo`00Loooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo08[ooooo1?l0000eooooo`00M?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000iooooo`00MOooool2o`0002_ooooo00?o0000
ooooooooool0P_ooool4o`0003gooooo001gooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0O_ooool4o`00047ooooo001hooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0N_ooool4o`0004Gooooo001iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
M_ooool4o`0004Wooooo001jooooo`;o00009_ooool00ol0003oooooooooo`1booooo`Co0000COoo
ool007cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1_ooooo`?o0000DOooool0
07gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000E?ooool007ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000F?ooool007oooooo
0_l0000Qooooo`03o`000?oooooooooo06?ooooo1?l0001Looooo`00POooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo05oooooo1?l0001Pooooo`00P_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo05_ooooo1?l0001Tooooo`00Poooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo05Oooooo1?l0001Xooooo`00Q?ooool2o`0001cooooo00?o0000oooooooo
ool0Doooool4o`0006cooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
Coooool4o`00073ooooo0027ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?oo
ool3o`0007Cooooo0028ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4
o`0007Oooooo0029ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000Noooool008_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Ooooool008cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`Co0000Poooool008gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`Co0000Qoooool008kooooo0_l0000B
ooooo`03o`000?oooooooooo03Cooooo1?l0002;ooooo`00T?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo037ooooo1?l0002?ooooo`00TOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02kooooo0ol0002Cooooo`00T_ooool2o`0000gooooo00?o0000ooooooooool0
:_ooool4o`0009Kooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_oo
ool4o`0009[ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4
o`0009kooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`00
0:;ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Y_ooool009Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003oooo
o`03o`000?oooooooooo00_ooooo0ol0002fooooo`00W_ooool01?l0003oooooooooool00009oooo
o`Co0000^Oooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o0000
00?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51725 .65007 m .51694 .65827 L .43899 .65168 L p .684 .722 .878 r
F P
0 g
s
.51694 .65827 m .51725 .65007 L .59252 .6422 L p .69 .646 .801 r
F P
0 g
s
.59252 .6422 m .59527 .65394 L .51694 .65827 L p .69 .646 .801 r
F P
0 g
s
.59527 .65394 m .59252 .6422 L .66436 .62421 L p .658 .584 .761 r
F P
0 g
s
.66436 .62421 m .67023 .63881 L .59527 .65394 L p .658 .584 .761 r
F P
0 g
s
.43899 .65168 m .44219 .6475 L .51725 .65007 L p .684 .722 .878 r
F P
0 g
s
.51756 .64178 m .51725 .65007 L .44219 .6475 L p .701 .735 .877 r
F P
0 g
s
.51725 .65007 m .51756 .64178 L .58976 .63029 L p .701 .652 .798 r
F P
0 g
s
.58976 .63029 m .59252 .6422 L .51725 .65007 L p .701 .652 .798 r
F P
0 g
s
.44219 .6475 m .43899 .65168 L .36521 .63435 L p .547 .77 .98 r
F P
0 g
s
.59252 .6422 m .58976 .63029 L .65847 .6094 L p .666 .586 .756 r
F P
0 g
s
.65847 .6094 m .66436 .62421 L .59252 .6422 L p .666 .586 .756 r
F P
0 g
s
.44219 .6475 m .44541 .64333 L .51756 .64178 L p .701 .735 .877 r
F P
0 g
s
.51788 .63342 m .51756 .64178 L .44541 .64333 L p .718 .749 .877 r
F P
0 g
s
.51756 .64178 m .51788 .63342 L .58698 .61832 L p .713 .66 .795 r
F P
0 g
s
.58698 .61832 m .58976 .63029 L .51756 .64178 L p .713 .66 .795 r
F P
0 g
s
.58976 .63029 m .58698 .61832 L .65256 .59457 L p .675 .591 .754 r
F P
0 g
s
.65256 .59457 m .65847 .6094 L .58976 .63029 L p .675 .591 .754 r
F P
0 g
s
.36521 .63435 m .37104 .63445 L .44219 .6475 L p .547 .77 .98 r
F P
0 g
s
.44541 .64333 m .44219 .6475 L .37104 .63445 L p .56 .793 .986 r
F P
0 g
s
.58419 .6064 m .58698 .61832 L .51788 .63342 L p .726 .67 .794 r
F P
0 g
s
.58698 .61832 m .58419 .6064 L .64665 .57988 L p .685 .598 .753 r
F P
0 g
s
.64665 .57988 m .65256 .59457 L .58698 .61832 L p .685 .598 .753 r
F P
0 g
s
.44541 .64333 m .44867 .63911 L .51788 .63342 L p .718 .749 .877 r
F P
0 g
s
.51819 .62503 m .51788 .63342 L .44867 .63911 L p .736 .765 .876 r
F P
0 g
s
.51788 .63342 m .51819 .62503 L .58419 .6064 L p .726 .67 .794 r
F P
0 g
s
.67023 .63881 m .66436 .62421 L .72908 .59677 L p .61 .533 .743 r
F P
0 g
s
.72908 .59677 m .73799 .61332 L .67023 .63881 L p .61 .533 .743 r
F P
0 g
s
.58139 .59464 m .58419 .6064 L .51819 .62503 L p .74 .681 .794 r
F P
0 g
s
.58419 .6064 m .58139 .59464 L .64073 .56553 L p .696 .607 .753 r
F P
0 g
s
.64073 .56553 m .64665 .57988 L .58419 .6064 L p .696 .607 .753 r
F P
0 g
s
.66436 .62421 m .65847 .6094 L .72016 .57999 L p .616 .534 .739 r
F P
0 g
s
.72016 .57999 m .72908 .59677 L .66436 .62421 L p .616 .534 .739 r
F P
0 g
s
.37104 .63445 m .37692 .63467 L .44541 .64333 L p .56 .793 .986 r
F P
0 g
s
.44867 .63911 m .44541 .64333 L .37692 .63467 L p .577 .818 .99 r
F P
0 g
s
.65847 .6094 m .65256 .59457 L .71124 .56323 L p .623 .537 .736 r
F P
0 g
s
.71124 .56323 m .72016 .57999 L .65847 .6094 L p .623 .537 .736 r
F P
0 g
s
.37104 .63445 m .36521 .63435 L .29943 .6068 L p .115 .585 .916 r
F P
0 g
s
.44867 .63911 m .45195 .6348 L .51819 .62503 L p .736 .765 .876 r
F P
0 g
s
.51851 .61665 m .51819 .62503 L .45195 .6348 L p .755 .783 .876 r
F P
0 g
s
.51819 .62503 m .51851 .61665 L .58139 .59464 L p .74 .681 .794 r
F P
0 g
s
.57858 .58316 m .58139 .59464 L .51851 .61665 L p .755 .696 .795 r
F P
0 g
s
.58139 .59464 m .57858 .58316 L .63482 .55168 L p .709 .619 .755 r
F P
0 g
s
.63482 .55168 m .64073 .56553 L .58139 .59464 L p .709 .619 .755 r
F P
0 g
s
.65256 .59457 m .64665 .57988 L .70234 .54674 L p .631 .542 .736 r
F P
0 g
s
.70234 .54674 m .71124 .56323 L .65256 .59457 L p .631 .542 .736 r
F P
0 g
s
.64665 .57988 m .64073 .56553 L .69347 .53074 L p .642 .551 .737 r
F P
0 g
s
.69347 .53074 m .70234 .54674 L .64665 .57988 L p .642 .551 .737 r
F P
0 g
s
.37692 .63467 m .38287 .6349 L .44867 .63911 L p .577 .818 .99 r
F P
0 g
s
.45195 .6348 m .38479 .63502 L .38673 .63489 L .599 .844 .991 r
F
.38287 .6349 m .3889 .63498 L .45195 .6348 L p F P
0 g
s
.45528 .63035 m .45195 .6348 L .39159 .63498 L p .625 .871 .988 r
F P
0 g
s
.39159 .63498 m .3889 .63498 L p .39422 .63461 L .625 .871 .988 r
F P
0 g
s
.45528 .63035 m .39159 .63498 L .39422 .63461 L .625 .871 .988 r
F
.3889 .63498 m .395 .63481 L .45455 .63041 L p F P
0 g
s
.45373 .63046 m .3889 .63498 L .45455 .63041 L .625 .871 .988 r
F
.45455 .63041 m .45528 .63035 L p .45373 .63046 L F P
0 g
s
.45863 .62571 m .45528 .63035 L .39838 .63456 L p .653 .897 .982 r
F P
0 g
s
.39838 .63456 m .395 .63481 L p .40159 .63386 L .653 .897 .982 r
F P
0 g
s
.45863 .62571 m .39838 .63456 L .40159 .63386 L .653 .897 .982 r
F
.395 .63481 m .40118 .63423 L .45761 .62586 L p F P
0 g
s
.4565 .62601 m .395 .63481 L .45761 .62586 L .653 .897 .982 r
F
.45761 .62586 m .45863 .62571 L p .4565 .62601 L F P
0 g
s
.46203 .62082 m .45863 .62571 L .40518 .63364 L p .683 .921 .972 r
F P
0 g
s
.40518 .63364 m .40118 .63423 L p .40888 .63253 L .683 .921 .972 r
F P
0 g
s
.46203 .62082 m .40518 .63364 L .40888 .63253 L .683 .921 .972 r
F
.40118 .63423 m .40745 .63312 L .46075 .62111 L p F P
0 g
s
.45939 .6214 m .40118 .63423 L .46075 .62111 L .683 .921 .972 r
F
.46075 .62111 m .46203 .62082 L p .45939 .6214 L F P
0 g
s
.46546 .61565 m .46203 .62082 L .41201 .6321 L p .713 .942 .958 r
F P
0 g
s
.41201 .6321 m .40745 .63312 L p .4161 .63052 L .713 .942 .958 r
F P
0 g
s
.46546 .61565 m .41201 .6321 L .4161 .63052 L .713 .942 .958 r
F
.40745 .63312 m .4138 .63137 L .46394 .61611 L p F P
0 g
s
.46237 .61657 m .40745 .63312 L .46394 .61611 L .713 .942 .958 r
F
.4138 .63137 m .42025 .62886 L .4672 .61081 L p .743 .96 .94 r
F P
0 g
s
.4672 .61081 m .46892 .61014 L p .46546 .61148 L .743 .96 .94 r
F P
0 g
s
.46546 .61148 m .4138 .63137 L .4672 .61081 L .743 .96 .94 r
F
.46394 .61611 m .46546 .61565 L p .46237 .61657 L .713 .942 .958 r
F P
0 g
s
.45195 .6348 m .44867 .63911 L .38479 .63502 L p .599 .844 .991 r
F P
0 g
s
.38479 .63502 m .38287 .6349 L p .38673 .63489 L .599 .844 .991 r
F P
0 g
s
.64073 .56553 m .63482 .55168 L .68464 .51545 L p .653 .562 .739 r
F P
0 g
s
.68464 .51545 m .69347 .53074 L .64073 .56553 L p .653 .562 .739 r
F P
0 g
s
.51851 .61665 m .51884 .6083 L .57858 .58316 L p .755 .696 .795 r
F P
0 g
s
.57576 .57205 m .57858 .58316 L .51884 .6083 L p .771 .712 .797 r
F P
0 g
s
.57858 .58316 m .57576 .57205 L .62891 .5385 L p .723 .634 .758 r
F P
0 g
s
.62891 .5385 m .63482 .55168 L .57858 .58316 L p .723 .634 .758 r
F P
0 g
s
.45195 .6348 m .45528 .63035 L .51851 .61665 L p .755 .783 .876 r
F P
0 g
s
.51884 .6083 m .51851 .61665 L .45528 .63035 L p .774 .801 .875 r
F P
0 g
s
.63482 .55168 m .62891 .5385 L .67584 .5011 L p .667 .575 .743 r
F P
0 g
s
.67584 .5011 m .68464 .51545 L .63482 .55168 L p .667 .575 .743 r
F P
0 g
s
.31581 .61589 m .32414 .62061 L .32732 .62138 L p .063 .584 .874 r
F P
0 g
s
.29943 .6068 m .30723 .61103 L p .30954 .61188 L .115 .585 .916 r
F P
0 g
s
.37104 .63445 m .30215 .60784 L .30954 .61188 L .115 .585 .916 r
F
.30215 .60784 m .29943 .6068 L .30954 .61188 L F
.32414 .62061 m .33258 .62517 L .33449 .6255 L p .066 .601 .86 r
F P
0 g
s
.30764 .61125 m .37104 .63445 L p .30723 .61103 L .115 .585 .916 r
F P
0 g
s
.37692 .63467 m .37104 .63445 L .30986 .61206 L p .08 .58 .893 r
F P
0 g
s
.30986 .61206 m .30764 .61125 L p .31118 .61244 L .08 .58 .893 r
F P
0 g
s
.37692 .63467 m .30986 .61206 L .31118 .61244 L .08 .58 .893 r
F
.37692 .63467 m .30764 .61125 L .30772 .61127 L F
.30764 .61125 m .30758 .61122 L p .30772 .61127 L F P
0 g
s
.30758 .61122 m .31581 .61589 L .37692 .63467 L p .08 .58 .893 r
F P
0 g
s
.38287 .6349 m .37692 .63467 L .32095 .61747 L p .063 .584 .874 r
F P
0 g
s
.38287 .6349 m .32095 .61747 L .32293 .61795 L .063 .584 .874 r
F
.38287 .6349 m .31744 .61639 L .31922 .61686 L F
.32095 .61747 m .31744 .61639 L p .32293 .61795 L F P
0 g
s
.32732 .62138 m .38283 .63489 L p .31922 .61686 L .063 .584 .874 r
F P
0 g
s
.31922 .61686 m .3177 .61643 L .32064 .61794 L .063 .584 .874 r
F
.31922 .61686 m .32064 .61794 L .32732 .62138 L F
.38278 .63487 m .3177 .61643 L .38283 .63489 L F
.31744 .61639 m .31581 .61589 L p .31922 .61686 L F P
0 g
s
.3177 .61643 m .31581 .61589 L .32732 .62138 L .063 .584 .874 r
F
.38283 .63489 m .38287 .6349 L p .38278 .63487 L F P
0 g
s
.3889 .63498 m .38287 .6349 L .33179 .62247 L p .066 .601 .86 r
F P
0 g
s
.33179 .62247 m .32414 .62061 L p .33557 .62315 L .066 .601 .86 r
F P
0 g
s
.3889 .63498 m .33179 .62247 L .33557 .62315 L .066 .601 .86 r
F
.33449 .6255 m .38787 .63481 L p .32648 .62113 L F P
0 g
s
.38754 .63472 m .32648 .62113 L .38787 .63481 L .066 .601 .86 r
F
.3876 .6347 m .32648 .62113 L .38813 .63485 L F
.32648 .62113 m .32414 .62061 L .33449 .6255 L F
.38787 .63481 m .38813 .63485 L p .38754 .63472 L F P
0 g
s
.38813 .63485 m .3889 .63498 L p .3876 .6347 L .066 .601 .86 r
F P
0 g
s
.395 .63481 m .3889 .63498 L .34245 .62689 L p .09 .63 .853 r
F P
0 g
s
.34245 .62689 m .33258 .62517 L p .34693 .62739 L .09 .63 .853 r
F P
0 g
s
.395 .63481 m .34245 .62689 L .34693 .62739 L .09 .63 .853 r
F
.33258 .62517 m .34115 .62937 L .34642 .6299 L p F P
0 g
s
.34642 .6299 m .39236 .63454 L p .34692 .62742 L .09 .63 .853 r
F P
0 g
s
.34692 .62742 m .33258 .62517 L .34642 .6299 L .09 .63 .853 r
F
.3907 .63414 m .33258 .62517 L .39236 .63454 L F
.39236 .63454 m .395 .63481 L p .3907 .63414 L F P
0 g
s
.40118 .63423 m .395 .63481 L .35299 .63056 L p .134 .67 .852 r
F P
0 g
s
.35299 .63056 m .34115 .62937 L p .35793 .63072 L .134 .67 .852 r
F P
0 g
s
.40118 .63423 m .35299 .63056 L .35793 .63072 L .134 .67 .852 r
F
.34115 .62937 m .34985 .63298 L .35608 .63313 L p F P
0 g
s
.35608 .63313 m .39689 .63412 L p .35788 .63079 L .134 .67 .852 r
F P
0 g
s
.35788 .63079 m .34115 .62937 L .35608 .63313 L .134 .67 .852 r
F
.39689 .63412 m .40118 .63423 L p .39441 .63368 L F P
0 g
s
.39441 .63368 m .34115 .62937 L .39689 .63412 L .134 .67 .852 r
F
.40745 .63312 m .40118 .63423 L .36345 .63331 L p .196 .72 .856 r
F P
0 g
s
.36345 .63331 m .34985 .63298 L p .36867 .63303 L .196 .72 .856 r
F P
0 g
s
.40745 .63312 m .36345 .63331 L .36867 .63303 L .196 .72 .856 r
F
.34985 .63298 m .35868 .63582 L .36578 .63542 L p F P
0 g
s
.36578 .63542 m .40169 .63344 L p .36852 .63315 L .196 .72 .856 r
F P
0 g
s
.36852 .63315 m .34985 .63298 L .36578 .63542 L .196 .72 .856 r
F
.40169 .63344 m .40745 .63312 L p .39862 .6331 L F P
0 g
s
.39862 .6331 m .34985 .63298 L .40169 .63344 L .196 .72 .856 r
F
.4138 .63137 m .40745 .63312 L .37387 .63498 L p .273 .775 .863 r
F P
0 g
s
.37387 .63498 m .35868 .63582 L p .37921 .63416 L .273 .775 .863 r
F P
0 g
s
.4138 .63137 m .37387 .63498 L .37921 .63416 L .273 .775 .863 r
F
.35868 .63582 m .36766 .63767 L .37554 .6366 L p F P
0 g
s
.37554 .6366 m .40673 .63234 L p .37892 .63435 L .273 .775 .863 r
F P
0 g
s
.37892 .63435 m .35868 .63582 L .37554 .6366 L .273 .775 .863 r
F
.40673 .63234 m .4138 .63137 L p .40325 .63222 L F P
0 g
s
.40325 .63222 m .35868 .63582 L .40673 .63234 L .273 .775 .863 r
F
.42025 .62886 m .4138 .63137 L .38427 .6354 L p .359 .831 .868 r
F P
0 g
s
.38427 .6354 m .36766 .63767 L p .38959 .634 L .359 .831 .868 r
F P
0 g
s
.42025 .62886 m .38427 .6354 L .38959 .634 L .359 .831 .868 r
F
.36766 .63767 m .37678 .63838 L .38537 .6365 L p F P
0 g
s
.38537 .6365 m .41199 .63067 L p .38911 .63428 L .359 .831 .868 r
F P
0 g
s
.38911 .63428 m .36766 .63767 L .38537 .6365 L .359 .831 .868 r
F
.41199 .63067 m .42025 .62886 L p .40823 .63087 L F P
0 g
s
.40823 .63087 m .36766 .63767 L .41199 .63067 L .359 .831 .868 r
F
.42678 .62549 m .42025 .62886 L .39466 .63446 L p .448 .882 .87 r
F P
0 g
s
.39466 .63446 m .37678 .63838 L p .39985 .63243 L .448 .882 .87 r
F P
0 g
s
.42678 .62549 m .39466 .63446 L .39985 .63243 L .448 .882 .87 r
F
.37678 .63838 m .38605 .63778 L .39526 .635 L p F P
0 g
s
.39526 .635 m .41745 .6283 L p .39911 .63285 L .448 .882 .87 r
F P
0 g
s
.39911 .63285 m .37678 .63838 L .39526 .635 L .448 .882 .87 r
F
.41354 .6289 m .37678 .63838 L .41745 .6283 L F
.41745 .6283 m .42678 .62549 L p .41354 .6289 L F P
0 g
s
.43339 .62118 m .42678 .62549 L .40505 .63204 L p .535 .925 .866 r
F P
0 g
s
.40505 .63204 m .38605 .63778 L p .41001 .62938 L .535 .925 .866 r
F P
0 g
s
.43339 .62118 m .40505 .63204 L .41001 .62938 L .535 .925 .866 r
F
.38605 .63778 m .39546 .63573 L .40523 .63199 L p F P
0 g
s
.40523 .63199 m .4231 .62513 L p .40893 .62997 L .535 .925 .866 r
F P
0 g
s
.40893 .62997 m .38605 .63778 L .40523 .63199 L .535 .925 .866 r
F
.41913 .62618 m .38605 .63778 L .4231 .62513 L F
.4231 .62513 m .43339 .62118 L p .41913 .62618 L F P
0 g
s
.44009 .61588 m .43339 .62118 L .39546 .63573 L p .613 .957 .856 r
F P
0 g
s
.39546 .63573 m .40499 .63215 L .42892 .62106 L p .613 .957 .856 r
F P
0 g
s
.42499 .62259 m .39546 .63573 L .42892 .62106 L .613 .957 .856 r
F
.42892 .62106 m .44009 .61588 L p .42499 .62259 L F P
0 g
s
.44687 .60953 m .44009 .61588 L .41525 .62739 L p .681 .978 .842 r
F P
0 g
s
.41525 .62739 m .40499 .63215 L p .42152 .62322 L .681 .978 .842 r
F P
0 g
s
.44687 .60953 m .41525 .62739 L .42152 .62322 L .681 .978 .842 r
F
.40499 .63215 m .41465 .62697 L .43491 .616 L p F P
0 g
s
.4311 .61805 m .40499 .63215 L .43491 .616 L .681 .978 .842 r
F
.41465 .62697 m .42442 .62015 L .44725 .6061 L p .737 .991 .825 r
F P
0 g
s
.44725 .6061 m .45373 .60212 L p .4427 .60913 L .737 .991 .825 r
F P
0 g
s
.4427 .60913 m .41465 .62697 L .44725 .6061 L .737 .991 .825 r
F
.43491 .616 m .44687 .60953 L p .4311 .61805 L .681 .978 .842 r
F P
0 g
s
.30723 .61103 m .30758 .61122 L .30764 .61125 L p .115 .585 .916 r
F P
0 g
s
.51884 .6083 m .51916 .60001 L .57576 .57205 L p .771 .712 .797 r
F P
0 g
s
.57293 .5614 m .57576 .57205 L .51916 .60001 L p .788 .73 .799 r
F P
0 g
s
.57576 .57205 m .57293 .5614 L .623 .52614 L p .739 .651 .762 r
F P
0 g
s
.623 .52614 m .62891 .5385 L .57576 .57205 L p .739 .651 .762 r
F P
0 g
s
.62891 .5385 m .623 .52614 L .66709 .48786 L p .683 .592 .748 r
F P
0 g
s
.66709 .48786 m .67584 .5011 L .62891 .5385 L p .683 .592 .748 r
F P
0 g
s
.45528 .63035 m .45863 .62571 L .51884 .6083 L p .774 .801 .875 r
F P
0 g
s
.51916 .60001 m .51884 .6083 L .45863 .62571 L p .794 .821 .873 r
F P
0 g
s
.6171 .51472 m .623 .52614 L .57293 .5614 L p .756 .671 .768 r
F P
0 g
s
.623 .52614 m .6171 .51472 L .65838 .47591 L p .701 .613 .755 r
F P
0 g
s
.65838 .47591 m .66709 .48786 L .623 .52614 L p .701 .613 .755 r
F P
0 g
s
.51916 .60001 m .51949 .59181 L .57293 .5614 L p .788 .73 .799 r
F P
0 g
s
.57009 .5513 m .57293 .5614 L .51949 .59181 L p .805 .751 .802 r
F P
0 g
s
.57293 .5614 m .57009 .5513 L .6171 .51472 L p .756 .671 .768 r
F P
0 g
s
.6112 .50436 m .6171 .51472 L .57009 .5513 L p .775 .694 .774 r
F P
0 g
s
.6171 .51472 m .6112 .50436 L .6497 .46539 L p .721 .637 .763 r
F P
0 g
s
.6497 .46539 m .65838 .47591 L .6171 .51472 L p .721 .637 .763 r
F P
0 g
s
.45863 .62571 m .46203 .62082 L .51916 .60001 L p .794 .821 .873 r
F P
0 g
s
.51949 .59181 m .51916 .60001 L .46203 .62082 L p .813 .841 .871 r
F P
0 g
s
.70234 .54674 m .69347 .53074 L .73667 .49194 L p .576 .504 .736 r
F P
0 g
s
.69347 .53074 m .68464 .51545 L .72529 .47627 L p .588 .515 .74 r
F P
0 g
s
.72529 .47627 m .73667 .49194 L .69347 .53074 L p .588 .515 .74 r
F P
0 g
s
.71124 .56323 m .70234 .54674 L .74815 .50851 L p .567 .496 .735 r
F P
0 g
s
.73667 .49194 m .74815 .50851 L .70234 .54674 L p .576 .504 .736 r
F P
0 g
s
.68464 .51545 m .67584 .5011 L .71399 .46174 L p .602 .529 .745 r
F P
0 g
s
.71399 .46174 m .72529 .47627 L .68464 .51545 L p .602 .529 .745 r
F P
0 g
s
.72016 .57999 m .71124 .56323 L .7597 .5257 L p .559 .491 .735 r
F P
0 g
s
.74815 .50851 m .7597 .5257 L .71124 .56323 L p .567 .496 .735 r
F P
0 g
s
.72908 .59677 m .72016 .57999 L .77131 .54326 L p .553 .488 .737 r
F P
0 g
s
.7597 .5257 m .77131 .54326 L .72016 .57999 L p .559 .491 .735 r
F P
0 g
s
.67584 .5011 m .66709 .48786 L .70279 .44856 L p .62 .548 .752 r
F P
0 g
s
.70279 .44856 m .71399 .46174 L .67584 .5011 L p .62 .548 .752 r
F P
0 g
s
.73799 .61332 m .72908 .59677 L .78297 .56089 L p .549 .489 .741 r
F P
0 g
s
.77131 .54326 m .78297 .56089 L .72908 .59677 L p .553 .488 .737 r
F P
0 g
s
.51949 .59181 m .51982 .58373 L .57009 .5513 L p .805 .751 .802 r
F P
0 g
s
.56724 .54183 m .57009 .5513 L .51982 .58373 L p .824 .774 .805 r
F P
0 g
s
.57009 .5513 m .56724 .54183 L .6112 .50436 L p .775 .694 .774 r
F P
0 g
s
.78297 .56089 m .79464 .57831 L .73799 .61332 L p .549 .489 .741 r
F P
0 g
s
.66709 .48786 m .65838 .47591 L .69168 .43692 L p .64 .57 .76 r
F P
0 g
s
.69168 .43692 m .70279 .44856 L .66709 .48786 L p .64 .57 .76 r
F P
0 g
s
.60529 .49515 m .6112 .50436 L .56724 .54183 L p .796 .72 .78 r
F P
0 g
s
.6112 .50436 m .60529 .49515 L .64105 .45641 L p .744 .664 .772 r
F P
0 g
s
.64105 .45641 m .6497 .46539 L .6112 .50436 L p .744 .664 .772 r
F P
0 g
s
.65838 .47591 m .6497 .46539 L .68065 .42699 L p .663 .596 .77 r
F P
0 g
s
.68065 .42699 m .69168 .43692 L .65838 .47591 L p .663 .596 .77 r
F P
0 g
s
.46203 .62082 m .46546 .61565 L .51949 .59181 L p .813 .841 .871 r
F P
0 g
s
.51982 .58373 m .51949 .59181 L .46546 .61565 L p .832 .861 .867 r
F P
0 g
s
.6497 .46539 m .64105 .45641 L .6697 .4189 L p .69 .628 .782 r
F P
0 g
s
.6697 .4189 m .68065 .42699 L .6497 .46539 L p .69 .628 .782 r
F P
0 g
s
.51982 .58373 m .52015 .57578 L .56724 .54183 L p .824 .774 .805 r
F P
0 g
s
.56438 .53303 m .56724 .54183 L .52015 .57578 L p .842 .798 .808 r
F P
0 g
s
.56724 .54183 m .56438 .53303 L .60529 .49515 L p .796 .72 .78 r
F P
0 g
s
.59938 .48717 m .60529 .49515 L .56438 .53303 L p .818 .749 .787 r
F P
0 g
s
.60529 .49515 m .59938 .48717 L .63242 .44907 L p .769 .696 .782 r
F P
0 g
s
.63242 .44907 m .64105 .45641 L .60529 .49515 L p .769 .696 .782 r
F P
0 g
s
.30758 .61122 m .29943 .6068 L .24558 .56996 L p 0 .269 .702 r
F P
0 g
s
.64105 .45641 m .63242 .44907 L .65881 .41274 L p .72 .664 .794 r
F P
0 g
s
.65881 .41274 m .6697 .4189 L .64105 .45641 L p .72 .664 .794 r
F P
0 g
s
.46546 .61565 m .46892 .61014 L .51982 .58373 L p .832 .861 .867 r
F P
0 g
s
.52015 .57578 m .51982 .58373 L .46892 .61014 L p .849 .88 .862 r
F P
0 g
s
.52015 .57578 m .52049 .56799 L .56438 .53303 L p .842 .798 .808 r
F P
0 g
s
.56151 .52496 m .56438 .53303 L .52049 .56799 L p .861 .823 .81 r
F P
0 g
s
.56438 .53303 m .56151 .52496 L .59938 .48717 L p .818 .749 .787 r
F P
0 g
s
.59346 .48046 m .59938 .48717 L .56151 .52496 L p .841 .78 .794 r
F P
0 g
s
.59938 .48717 m .59346 .48046 L .62379 .44343 L p .797 .732 .792 r
F P
0 g
s
.62379 .44343 m .63242 .44907 L .59938 .48717 L p .797 .732 .792 r
F P
0 g
s
.63242 .44907 m .62379 .44343 L .64795 .4086 L p .753 .705 .806 r
F P
0 g
s
.64795 .4086 m .65881 .41274 L .63242 .44907 L p .753 .705 .806 r
F P
0 g
s
.26587 .58748 m .27619 .59651 L .28033 .59859 L p 0 .219 .617 r
F P
0 g
s
.24558 .56996 m .25525 .57818 L p .30758 .61122 L 0 .269 .702 r
F P
0 g
s
.25576 .5786 m .30758 .61122 L p .25525 .57818 L 0 .269 .702 r
F P
0 g
s
.31581 .61589 m .30758 .61122 L .25576 .5786 L p 0 .235 .653 r
F P
0 g
s
.25576 .5786 m .25568 .57854 L p .25587 .57866 L 0 .235 .653 r
F P
0 g
s
.31581 .61589 m .25576 .5786 L .25587 .57866 L 0 .235 .653 r
F
.25568 .57854 m .26587 .58748 L .31581 .61589 L p F P
0 g
s
.32414 .62061 m .31581 .61589 L .26587 .58748 L p 0 .219 .617 r
F P
0 g
s
.28033 .59859 m .32408 .62058 L p .26854 .589 L 0 .219 .617 r
F P
0 g
s
.32408 .62058 m .32414 .62061 L p .32399 .62052 L 0 .219 .617 r
F P
0 g
s
.32399 .62052 m .26854 .589 L .32408 .62058 L 0 .219 .617 r
F
.26854 .589 m .26587 .58748 L .28033 .59859 L F
.25525 .57818 m .25568 .57854 L .25576 .5786 L p 0 .269 .702 r
F P
0 g
s
.70279 .44856 m .69168 .43692 L .71499 .39987 L p .568 .541 .784 r
F P
0 g
s
.69168 .43692 m .68065 .42699 L .7022 .39128 L p .597 .573 .797 r
F P
0 g
s
.7022 .39128 m .71499 .39987 L .69168 .43692 L p .597 .573 .797 r
F P
0 g
s
.71399 .46174 m .70279 .44856 L .72791 .41034 L p .544 .514 .772 r
F P
0 g
s
.71499 .39987 m .72791 .41034 L .70279 .44856 L p .568 .541 .784 r
F P
0 g
s
.68065 .42699 m .6697 .4189 L .68954 .38469 L p .631 .611 .811 r
F P
0 g
s
.68954 .38469 m .7022 .39128 L .68065 .42699 L p .631 .611 .811 r
F P
0 g
s
.72529 .47627 m .71399 .46174 L .74097 .42251 L p .524 .492 .763 r
F P
0 g
s
.72791 .41034 m .74097 .42251 L .71399 .46174 L p .544 .514 .772 r
F P
0 g
s
.46892 .61014 m .47243 .60428 L .52015 .57578 L p .849 .88 .862 r
F P
0 g
s
.52049 .56799 m .52015 .57578 L .47243 .60428 L p .866 .899 .855 r
F P
0 g
s
.56151 .52496 m .55862 .51765 L .59346 .48046 L p .841 .78 .794 r
F P
0 g
s
.58751 .47504 m .59346 .48046 L .55862 .51765 L p .864 .814 .799 r
F P
0 g
s
.59346 .48046 m .58751 .47504 L .61516 .43952 L p .826 .771 .8 r
F P
0 g
s
.61516 .43952 m .62379 .44343 L .59346 .48046 L p .826 .771 .8 r
F P
0 g
s
.62379 .44343 m .61516 .43952 L .63712 .4065 L p .789 .749 .817 r
F P
0 g
s
.63712 .4065 m .64795 .4086 L .62379 .44343 L p .789 .749 .817 r
F P
0 g
s
.52049 .56799 m .52082 .56037 L .56151 .52496 L p .861 .823 .81 r
F P
0 g
s
.55862 .51765 m .56151 .52496 L .52082 .56037 L p .879 .849 .81 r
F P
0 g
s
.73667 .49194 m .72529 .47627 L .75419 .43618 L p .507 .475 .756 r
F P
0 g
s
.74097 .42251 m .75419 .43618 L .72529 .47627 L p .524 .492 .763 r
F P
0 g
s
.6697 .4189 m .65881 .41274 L .67699 .38023 L p .669 .654 .826 r
F P
0 g
s
.67699 .38023 m .68954 .38469 L .6697 .4189 L p .669 .654 .826 r
F P
0 g
s
.74815 .50851 m .73667 .49194 L .76756 .45112 L p .494 .462 .751 r
F P
0 g
s
.75419 .43618 m .76756 .45112 L .73667 .49194 L p .507 .475 .756 r
F P
0 g
s
.65881 .41274 m .64795 .4086 L .66451 .37794 L p .711 .703 .84 r
F P
0 g
s
.66451 .37794 m .67699 .38023 L .65881 .41274 L p .711 .703 .84 r
F P
0 g
s
.46892 .61014 m .46546 .61565 L .4138 .63137 L p .743 .96 .94 r
F P
0 g
s
.7597 .5257 m .74815 .50851 L .78107 .46707 L p .485 .454 .748 r
F P
0 g
s
.76756 .45112 m .78107 .46707 L .74815 .50851 L p .494 .462 .751 r
F P
0 g
s
.60651 .43733 m .61516 .43952 L .58751 .47504 L p .854 .811 .807 r
F P
0 g
s
.61516 .43952 m .60651 .43733 L .62629 .40644 L p .824 .796 .825 r
F P
0 g
s
.62629 .40644 m .63712 .4065 L .61516 .43952 L p .824 .796 .825 r
F P
0 g
s
.47243 .60428 m .47597 .59802 L .52049 .56799 L p .866 .899 .855 r
F P
0 g
s
.52082 .56037 m .52049 .56799 L .47597 .59802 L p .88 .916 .846 r
F P
0 g
s
.55862 .51765 m .55572 .51111 L .58751 .47504 L p .864 .814 .799 r
F P
0 g
s
.58154 .47093 m .58751 .47504 L .55572 .51111 L p .885 .848 .801 r
F P
0 g
s
.58751 .47504 m .58154 .47093 L .60651 .43733 L p .854 .811 .807 r
F P
0 g
s
.52082 .56037 m .52116 .55293 L .55862 .51765 L p .879 .849 .81 r
F P
0 g
s
.55572 .51111 m .55862 .51765 L .52116 .55293 L p .895 .875 .809 r
F P
0 g
s
.64795 .4086 m .63712 .4065 L .65209 .37788 L p .756 .755 .852 r
F P
0 g
s
.65209 .37788 m .66451 .37794 L .64795 .4086 L p .756 .755 .852 r
F P
0 g
s
.77131 .54326 m .7597 .5257 L .79472 .48374 L p .478 .449 .747 r
F P
0 g
s
.78107 .46707 m .79472 .48374 L .7597 .5257 L p .485 .454 .748 r
F P
0 g
s
.78297 .56089 m .77131 .54326 L .80848 .50086 L p .474 .447 .748 r
F P
0 g
s
.79472 .48374 m .80848 .50086 L .77131 .54326 L p .478 .449 .747 r
F P
0 g
s
.63712 .4065 m .62629 .40644 L .63971 .38004 L p .8 .807 .858 r
F P
0 g
s
.63971 .38004 m .65209 .37788 L .63712 .4065 L p .8 .807 .858 r
F P
0 g
s
.47243 .60428 m .46892 .61014 L .42025 .62886 L p .77 .973 .92 r
F P
0 g
s
.59782 .43685 m .60651 .43733 L .58154 .47093 L p .881 .852 .81 r
F P
0 g
s
.60651 .43733 m .59782 .43685 L .61543 .40838 L p .858 .842 .828 r
F P
0 g
s
.61543 .40838 m .62629 .40644 L .60651 .43733 L p .858 .842 .828 r
F P
0 g
s
.79464 .57831 m .78297 .56089 L .82234 .51809 L p .473 .45 .752 r
F P
0 g
s
.80848 .50086 m .82234 .51809 L .78297 .56089 L p .474 .447 .748 r
F P
0 g
s
.47597 .59802 m .47955 .59134 L .52082 .56037 L p .88 .916 .846 r
F P
0 g
s
.52116 .55293 m .52082 .56037 L .47955 .59134 L p .893 .932 .836 r
F P
0 g
s
.52116 .55293 m .52151 .54567 L .55572 .51111 L p .895 .875 .809 r
F P
0 g
s
.55279 .50534 m .55572 .51111 L .52151 .54567 L p .909 .9 .804 r
F P
0 g
s
.55572 .51111 m .55279 .50534 L .58154 .47093 L p .885 .848 .801 r
F P
0 g
s
.57553 .46809 m .58154 .47093 L .55279 .50534 L p .904 .88 .8 r
F P
0 g
s
.58154 .47093 m .57553 .46809 L .59782 .43685 L p .881 .852 .81 r
F P
0 g
s
.82234 .51809 m .83625 .53514 L .79464 .57831 L p .473 .45 .752 r
F P
0 g
s
.33258 .62517 m .32414 .62061 L .27619 .59651 L p .355 0 0 r
F P
0 g
s
.62629 .40644 m .61543 .40838 L .62732 .38437 L p .84 .857 .857 r
F P
0 g
s
.62732 .38437 m .63971 .38004 L .62629 .40644 L p .84 .857 .857 r
F P
0 g
s
.7022 .39128 m .68954 .38469 L .69915 .35586 L p .564 .621 .867 r
F P
0 g
s
.68954 .38469 m .67699 .38023 L .68567 .35348 L p .616 .676 .885 r
F P
0 g
s
.68567 .35348 m .69915 .35586 L .68954 .38469 L p .616 .676 .885 r
F P
0 g
s
.71499 .39987 m .7022 .39128 L .71278 .36039 L p .518 .571 .849 r
F P
0 g
s
.69915 .35586 m .71278 .36039 L .7022 .39128 L p .564 .621 .867 r
F P
0 g
s
.67699 .38023 m .66451 .37794 L .67232 .35333 L p .671 .735 .898 r
F P
0 g
s
.67232 .35333 m .68567 .35348 L .67699 .38023 L p .671 .735 .898 r
F P
0 g
s
.72791 .41034 m .71499 .39987 L .72656 .36697 L p .479 .529 .831 r
F P
0 g
s
.71278 .36039 m .72656 .36697 L .71499 .39987 L p .518 .571 .849 r
F P
0 g
s
.42025 .62886 m .42678 .62549 L .47243 .60428 L p .77 .973 .92 r
F P
0 g
s
.47597 .59802 m .47243 .60428 L .42678 .62549 L p .795 .983 .898 r
F P
0 g
s
.58908 .438 m .59782 .43685 L .57553 .46809 L p .904 .889 .807 r
F P
0 g
s
.59782 .43685 m .58908 .438 L .60453 .41226 L p .887 .885 .824 r
F P
0 g
s
.60453 .41226 m .61543 .40838 L .59782 .43685 L p .887 .885 .824 r
F P
0 g
s
.47955 .59134 m .48316 .58423 L .52116 .55293 L p .893 .932 .836 r
F P
0 g
s
.52151 .54567 m .52116 .55293 L .48316 .58423 L p .903 .945 .823 r
F P
0 g
s
.66451 .37794 m .65209 .37788 L .65905 .35542 L p .727 .795 .906 r
F P
0 g
s
.65905 .35542 m .67232 .35333 L .66451 .37794 L p .727 .795 .906 r
F P
0 g
s
.74097 .42251 m .72791 .41034 L .74053 .37546 L p .446 .493 .814 r
F P
0 g
s
.72656 .36697 m .74053 .37546 L .72791 .41034 L p .479 .529 .831 r
F P
0 g
s
.52151 .54567 m .52185 .53858 L .55279 .50534 L p .909 .9 .804 r
F P
0 g
s
.54984 .50033 m .55279 .50534 L .52185 .53858 L p .92 .922 .797 r
F P
0 g
s
.55279 .50534 m .54984 .50033 L .57553 .46809 L p .904 .88 .8 r
F P
0 g
s
.56948 .46648 m .57553 .46809 L .54984 .50033 L p .919 .91 .795 r
F P
0 g
s
.57553 .46809 m .56948 .46648 L .58908 .438 L p .904 .889 .807 r
F P
0 g
s
.25568 .57854 m .24558 .56996 L .20758 .52532 L p 0 .152 .667 r
F P
0 g
s
.75419 .43618 m .74097 .42251 L .7547 .38569 L p .42 .465 .8 r
F P
0 g
s
.74053 .37546 m .7547 .38569 L .74097 .42251 L p .446 .493 .814 r
F P
0 g
s
.65209 .37788 m .63971 .38004 L .64585 .35976 L p .78 .85 .904 r
F P
0 g
s
.64585 .35976 m .65905 .35542 L .65209 .37788 L p .78 .85 .904 r
F P
0 g
s
.61543 .40838 m .60453 .41226 L .61491 .3908 L p .874 .9 .847 r
F P
0 g
s
.61491 .3908 m .62732 .38437 L .61543 .40838 L p .874 .9 .847 r
F P
0 g
s
.27619 .59651 m .28665 .60537 L .33258 .62517 L p .355 0 0 r
F P
0 g
s
.34115 .62937 m .33258 .62517 L .28665 .60537 L p .34 0 0 r
F P
0 g
s
.42678 .62549 m .43339 .62118 L .47597 .59802 L p .795 .983 .898 r
F P
0 g
s
.47955 .59134 m .47597 .59802 L .43339 .62118 L p .818 .989 .875 r
F P
0 g
s
.76756 .45112 m .75419 .43618 L .76906 .39747 L p .4 .443 .789 r
F P
0 g
s
.7547 .38569 m .76906 .39747 L .75419 .43618 L p .42 .465 .8 r
F P
0 g
s
.48316 .58423 m .48682 .57667 L .52151 .54567 L p .903 .945 .823 r
F P
0 g
s
.52185 .53858 m .52151 .54567 L .48682 .57667 L p .911 .956 .809 r
F P
0 g
s
.63971 .38004 m .62732 .38437 L .63268 .3663 L p .826 .898 .891 r
F P
0 g
s
.63268 .3663 m .64585 .35976 L .63971 .38004 L p .826 .898 .891 r
F P
0 g
s
.58027 .4407 m .58908 .438 L .56948 .46648 L p .92 .922 .798 r
F P
0 g
s
.58908 .438 m .58027 .4407 L .59356 .41797 L p .909 .921 .813 r
F P
0 g
s
.59356 .41797 m .60453 .41226 L .58908 .438 L p .909 .921 .813 r
F P
0 g
s
.52185 .53858 m .5222 .53168 L .54984 .50033 L p .92 .922 .797 r
F P
0 g
s
.54687 .49604 m .54984 .50033 L .5222 .53168 L p .927 .94 .787 r
F P
0 g
s
.54984 .50033 m .54687 .49604 L .56948 .46648 L p .919 .91 .795 r
F P
0 g
s
.56337 .46602 m .56948 .46648 L .54687 .49604 L p .929 .935 .785 r
F P
0 g
s
.56948 .46648 m .56337 .46602 L .58027 .4407 L p .92 .922 .798 r
F P
0 g
s
.78107 .46707 m .76756 .45112 L .78362 .41055 L p .385 .427 .781 r
F P
0 g
s
.76906 .39747 m .78362 .41055 L .76756 .45112 L p .4 .443 .789 r
F P
0 g
s
.60453 .41226 m .59356 .41797 L .60245 .39921 L p .898 .934 .829 r
F P
0 g
s
.60245 .39921 m .61491 .3908 L .60453 .41226 L p .898 .934 .829 r
F P
0 g
s
.20758 .52532 m .21917 .53769 L .25568 .57854 L p 0 .152 .667 r
F P
0 g
s
.26587 .58748 m .25568 .57854 L .22897 .54865 L p 0 .118 .631 r
F P
0 g
s
.26587 .58748 m .22897 .54865 L .23255 .5521 L 0 .118 .631 r
F
.26587 .58748 m .22268 .54161 L .22537 .5443 L F
.26587 .58748 m .21927 .5378 L .21942 .53796 L F
.22897 .54865 m .22268 .54161 L p .23255 .5521 L F P
0 g
s
.22268 .54161 m .21927 .5378 L p .22537 .5443 L 0 .118 .631 r
F P
0 g
s
.21927 .5378 m .21917 .53769 L p .21942 .53796 L 0 .118 .631 r
F P
0 g
s
.21917 .53769 m .23086 .55048 L .26587 .58748 L p 0 .118 .631 r
F P
0 g
s
.27619 .59651 m .26587 .58748 L .2387 .55876 L p 0 .103 .609 r
F P
0 g
s
.2387 .55876 m .23335 .5531 L p .24239 .56226 L 0 .103 .609 r
F P
0 g
s
.27619 .59651 m .2387 .55876 L .24239 .56226 L 0 .103 .609 r
F
.24362 .56343 m .23335 .5531 L .23653 .55623 L F
.27619 .59651 m .24239 .56226 L .24362 .56343 L F
.24239 .56226 m .23335 .5531 L .24362 .56343 L F
.28665 .60537 m .29727 .61378 L .34115 .62937 L p .34 0 0 r
F P
0 g
s
.24268 .5634 m .27611 .59643 L p .23653 .55623 L 0 .103 .609 r
F P
0 g
s
.23335 .5531 m .23086 .55048 L p .23653 .55623 L 0 .103 .609 r
F P
0 g
s
.23086 .55048 m .24268 .5634 L p .23653 .55623 L 0 .103 .609 r
F P
0 g
s
.27597 .59628 m .23086 .55048 L .27611 .59643 L 0 .103 .609 r
F
.27611 .59643 m .27619 .59651 L p .27597 .59628 L F P
0 g
s
.28665 .60537 m .27619 .59651 L .25426 .57483 L p 0 .106 .602 r
F P
0 g
s
.25426 .57483 m .24268 .5634 L p .26013 .58005 L 0 .106 .602 r
F P
0 g
s
.28665 .60537 m .25426 .57483 L .26013 .58005 L 0 .106 .602 r
F
.28458 .60348 m .28511 .60396 L p .28377 .60268 L F P
0 g
s
.28377 .60268 m .24268 .5634 L .28458 .60348 L 0 .106 .602 r
F
.28511 .60396 m .28665 .60537 L p .28369 .60254 L F P
0 g
s
.28369 .60254 m .24268 .5634 L .28511 .60396 L 0 .106 .602 r
F
.29727 .61378 m .28665 .60537 L .26949 .58968 L p 0 .128 .61 r
F P
0 g
s
.26949 .58968 m .25466 .57613 L p .27559 .59463 L 0 .128 .61 r
F P
0 g
s
.29727 .61378 m .26949 .58968 L .27559 .59463 L 0 .128 .61 r
F
.29039 .6077 m .28809 .60567 L .29304 .61025 L F
.28809 .60567 m .25466 .57613 L .29104 .60847 L F
.28809 .60567 m .29104 .60847 L .29304 .61025 L F
.25466 .57613 m .26683 .58836 L .29198 .60937 L p F P
0 g
s
.29198 .60937 m .29304 .61025 L p .29104 .60847 L 0 .128 .61 r
F P
0 g
s
.29104 .60847 m .25466 .57613 L .29198 .60937 L 0 .128 .61 r
F
.29304 .61025 m .29727 .61378 L p .29039 .6077 L F P
0 g
s
.34985 .63298 m .34115 .62937 L .29727 .61378 L p .303 0 0 r
F P
0 g
s
.29727 .61378 m .30807 .62147 L .34985 .63298 L p .303 0 0 r
F P
0 g
s
.30807 .62147 m .29727 .61378 L .28449 .60311 L p 0 .171 .635 r
F P
0 g
s
.28449 .60311 m .26683 .58836 L p .29039 .60727 L 0 .171 .635 r
F P
0 g
s
.30807 .62147 m .28449 .60311 L .29039 .60727 L 0 .171 .635 r
F
.26683 .58836 m .27919 .59975 L .28848 .60674 L p F P
0 g
s
.28848 .60674 m .29949 .61502 L p .2898 .60711 L 0 .171 .635 r
F P
0 g
s
.2898 .60711 m .26683 .58836 L .28848 .60674 L 0 .171 .635 r
F
.29949 .61502 m .30807 .62147 L p .29439 .61049 L F P
0 g
s
.29439 .61049 m .26683 .58836 L .29949 .61502 L 0 .171 .635 r
F
.35868 .63582 m .34985 .63298 L .30807 .62147 L p .24 0 0 r
F P
0 g
s
.30807 .62147 m .31905 .62817 L .35868 .63582 L p .24 0 0 r
F P
0 g
s
.31905 .62817 m .30807 .62147 L .29934 .61491 L p 0 .236 .676 r
F P
0 g
s
.29934 .61491 m .27919 .59975 L p .30474 .61797 L 0 .236 .676 r
F P
0 g
s
.31905 .62817 m .29934 .61491 L .30474 .61797 L 0 .236 .676 r
F
.27919 .59975 m .29176 .60999 L .30227 .61699 L p F P
0 g
s
.30227 .61699 m .30756 .62052 L p .3033 .6174 L 0 .236 .676 r
F P
0 g
s
.3033 .6174 m .27919 .59975 L .30227 .61699 L 0 .236 .676 r
F
.30756 .62052 m .31905 .62817 L p .30202 .61603 L F P
0 g
s
.30202 .61603 m .27919 .59975 L .30756 .62052 L 0 .236 .676 r
F
.36766 .63767 m .35868 .63582 L .32824 .62994 L p .151 0 0 r
F P
0 g
s
.32824 .62994 m .31905 .62817 L p .33501 .63129 L .151 0 0 r
F P
0 g
s
.36766 .63767 m .32824 .62994 L .33501 .63129 L .151 0 0 r
F
.33022 .63361 m .34159 .63757 L .36983 .63822 L p 0 .545 .732 r
F P
0 g
s
.31905 .62817 m .33022 .63361 L .36766 .63767 L p .151 0 0 r
F P
0 g
s
.37678 .63838 m .36766 .63767 L .35162 .63593 L p 0 .545 .732 r
F P
0 g
s
.37678 .63838 m .35162 .63593 L .35537 .63622 L 0 .545 .732 r
F
.37678 .63838 m .3404 .63472 L .34729 .63536 L F
.36983 .63822 m .37678 .63838 L p .36411 .63708 L F P
0 g
s
.35162 .63593 m .3404 .63472 L p .35537 .63622 L 0 .545 .732 r
F P
0 g
s
.3404 .63472 m .33022 .63361 L p .34729 .63536 L 0 .545 .732 r
F P
0 g
s
.36411 .63708 m .33022 .63361 L .36983 .63822 L 0 .545 .732 r
F
.38605 .63778 m .37678 .63838 L .36455 .6381 L p .1 .655 .784 r
F P
0 g
s
.38605 .63778 m .36455 .6381 L .36803 .6378 L .1 .655 .784 r
F
.38605 .63778 m .35265 .63783 L .35953 .63766 L F
.37834 .63826 m .38605 .63778 L p .3725 .63771 L F P
0 g
s
.36455 .6381 m .35265 .63783 L p .36803 .6378 L .1 .655 .784 r
F P
0 g
s
.35265 .63783 m .34159 .63757 L p .35953 .63766 L .1 .655 .784 r
F P
0 g
s
.35314 .63984 m .37087 .63812 L p .34159 .63757 L .1 .655 .784 r
F P
0 g
s
.3725 .63771 m .34159 .63757 L .37834 .63826 L .1 .655 .784 r
F
.39546 .63573 m .38605 .63778 L .37747 .63831 L p .248 .762 .827 r
F P
0 g
s
.39546 .63573 m .37747 .63831 L .38157 .63708 L .248 .762 .827 r
F
.37948 .63809 m .38708 .63697 L p .38066 .63737 L F P
0 g
s
.37747 .63831 m .35314 .63984 L p .38157 .63708 L .248 .762 .827 r
F P
0 g
s
.38066 .63737 m .37487 .63773 L .37859 .63802 L .248 .762 .827 r
F
.38066 .63737 m .37859 .63802 L .37948 .63809 L F
.38708 .63697 m .39546 .63573 L p .38123 .63711 L F P
0 g
s
.38123 .63711 m .37487 .63773 L .38708 .63697 L .248 .762 .827 r
F
.35314 .63984 m .36488 .64024 L .37948 .63809 L p F P
0 g
s
.37487 .63773 m .35314 .63984 L .37948 .63809 L .248 .762 .827 r
F
.40499 .63215 m .39546 .63573 L .36488 .64024 L p .393 .852 .853 r
F P
0 g
s
.36488 .64024 m .37678 .63865 L .3877 .63613 L p .393 .852 .853 r
F P
0 g
s
.3877 .63613 m .40499 .63215 L p .38347 .63649 L .393 .852 .853 r
F P
0 g
s
.38347 .63649 m .36488 .64024 L .3877 .63613 L .393 .852 .853 r
F
.41465 .62697 m .40499 .63215 L .38988 .63563 L p .523 .919 .862 r
F P
0 g
s
.38988 .63563 m .37678 .63865 L p .39609 .63269 L .523 .919 .862 r
F P
0 g
s
.41465 .62697 m .38988 .63563 L .39609 .63269 L .523 .919 .862 r
F
.37678 .63865 m .38884 .63497 L .39618 .6327 L p F P
0 g
s
.39244 .63382 m .37678 .63865 L .39618 .6327 L .523 .919 .862 r
F
.38884 .63497 m .40102 .62918 L .41448 .62398 L p .629 .962 .854 r
F P
0 g
s
.41448 .62398 m .42442 .62015 L p .40914 .62651 L .629 .962 .854 r
F P
0 g
s
.40914 .62651 m .38884 .63497 L .41448 .62398 L .629 .962 .854 r
F
.39618 .6327 m .41465 .62697 L p .39244 .63382 L .523 .919 .862 r
F P
0 g
s
.33022 .63361 m .31905 .62817 L .29176 .60999 L p 0 .324 .731 r
F P
0 g
s
.29176 .60999 m .30455 .61877 L .31615 .62548 L p 0 .324 .731 r
F P
0 g
s
.31615 .62548 m .33022 .63361 L p .31065 .62159 L 0 .324 .731 r
F P
0 g
s
.31065 .62159 m .29176 .60999 L .31615 .62548 L 0 .324 .731 r
F
.34159 .63757 m .33022 .63361 L .31614 .62547 L p 0 .434 .797 r
F P
0 g
s
.31614 .62547 m .30455 .61877 L p .32274 .62801 L 0 .434 .797 r
F P
0 g
s
.34159 .63757 m .31614 .62547 L .32274 .62801 L 0 .434 .797 r
F
.30455 .61877 m .31757 .62582 L .32523 .62957 L p F P
0 g
s
.32523 .62957 m .34159 .63757 L p .32009 .62666 L 0 .434 .797 r
F P
0 g
s
.32009 .62666 m .30455 .61877 L .32523 .62957 L 0 .434 .797 r
F
.31757 .62582 m .33079 .63089 L .3434 .63594 L p .034 .559 .863 r
F P
0 g
s
.3434 .63594 m .35314 .63984 L p .33721 .63356 L .034 .559 .863 r
F P
0 g
s
.33721 .63356 m .31757 .62582 L .3434 .63594 L .034 .559 .863 r
F
.25466 .57613 m .27211 .59154 L p .24268 .5634 L 0 .106 .602 r
F P
0 g
s
.43339 .62118 m .44009 .61588 L .47955 .59134 L p .818 .989 .875 r
F P
0 g
s
.48316 .58423 m .47955 .59134 L .44009 .61588 L p .837 .993 .852 r
F P
0 g
s
.62732 .38437 m .61491 .3908 L .61951 .37495 L p .862 .934 .869 r
F P
0 g
s
.61951 .37495 m .63268 .3663 L .62732 .38437 L p .862 .934 .869 r
F P
0 g
s
.48682 .57667 m .4905 .56867 L .52185 .53858 L p .911 .956 .809 r
F P
0 g
s
.5222 .53168 m .52185 .53858 L .4905 .56867 L p .916 .964 .794 r
F P
0 g
s
.79472 .48374 m .78107 .46707 L .79839 .42468 L p .376 .416 .775 r
F P
0 g
s
.78362 .41055 m .79839 .42468 L .78107 .46707 L p .385 .427 .781 r
F P
0 g
s
.5222 .53168 m .52255 .52494 L .54687 .49604 L p .927 .94 .787 r
F P
0 g
s
.54387 .49243 m .54687 .49604 L .52255 .52494 L p .931 .955 .774 r
F P
0 g
s
.54687 .49604 m .54387 .49243 L .56337 .46602 L p .929 .935 .785 r
F P
0 g
s
.57137 .44481 m .58027 .4407 L .56337 .46602 L p .929 .946 .783 r
F P
0 g
s
.58027 .4407 m .57137 .44481 L .5825 .42537 L p .922 .947 .795 r
F P
0 g
s
.5825 .42537 m .59356 .41797 L .58027 .4407 L p .922 .947 .795 r
F P
0 g
s
.44009 .61588 m .44687 .60953 L .48316 .58423 L p .837 .993 .852 r
F P
0 g
s
.48682 .57667 m .48316 .58423 L .44687 .60953 L p .854 .994 .829 r
F P
0 g
s
.61491 .3908 m .60245 .39921 L .60632 .38562 L p .888 .958 .84 r
F P
0 g
s
.60632 .38562 m .61951 .37495 L .61491 .3908 L p .888 .958 .84 r
F P
0 g
s
.69915 .35586 m .68567 .35348 L .68397 .33435 L p .558 .742 .962 r
F P
0 g
s
.68567 .35348 m .67232 .35333 L .67058 .33645 L p .632 .81 .968 r
F P
0 g
s
.67058 .33645 m .68397 .33435 L .68567 .35348 L p .632 .81 .968 r
F P
0 g
s
.5572 .46661 m .56337 .46602 L .54387 .49243 L p .933 .953 .771 r
F P
0 g
s
.56337 .46602 m .5572 .46661 L .57137 .44481 L p .929 .946 .783 r
F P
0 g
s
.67232 .35333 m .65905 .35542 L .6573 .34067 L p .702 .87 .961 r
F P
0 g
s
.6573 .34067 m .67058 .33645 L .67232 .35333 L p .702 .87 .961 r
F P
0 g
s
.59356 .41797 m .5825 .42537 L .5899 .40947 L p .913 .957 .805 r
F P
0 g
s
.5899 .40947 m .60245 .39921 L .59356 .41797 L p .913 .957 .805 r
F P
0 g
s
.71278 .36039 m .69915 .35586 L .6975 .33436 L p .485 .672 .946 r
F P
0 g
s
.68397 .33435 m .6975 .33436 L .69915 .35586 L p .558 .742 .962 r
F P
0 g
s
.80848 .50086 m .79472 .48374 L .81333 .43958 L p .371 .411 .773 r
F P
0 g
s
.79839 .42468 m .81333 .43958 L .79472 .48374 L p .376 .416 .775 r
F P
0 g
s
.65905 .35542 m .64585 .35976 L .64412 .34701 L p .763 .917 .941 r
F P
0 g
s
.64412 .34701 m .6573 .34067 L .65905 .35542 L p .763 .917 .941 r
F P
0 g
s
.4905 .56867 m .49422 .56024 L .5222 .53168 L p .916 .964 .794 r
F P
0 g
s
.52255 .52494 m .5222 .53168 L .49422 .56024 L p .919 .97 .779 r
F P
0 g
s
.72656 .36697 m .71278 .36039 L .71121 .33641 L p .419 .606 .924 r
F P
0 g
s
.6975 .33436 m .71121 .33641 L .71278 .36039 L p .485 .672 .946 r
F P
0 g
s
.64585 .35976 m .63268 .3663 L .631 .35543 L p .812 .951 .91 r
F P
0 g
s
.631 .35543 m .64412 .34701 L .64585 .35976 L p .812 .951 .91 r
F P
0 g
s
.74053 .37546 m .72656 .36697 L .7251 .3404 L p .363 .546 .9 r
F P
0 g
s
.71121 .33641 m .7251 .3404 L .72656 .36697 L p .419 .606 .924 r
F P
0 g
s
.82234 .51809 m .80848 .50086 L .82844 .45495 L p .37 .411 .773 r
F P
0 g
s
.81333 .43958 m .82844 .45495 L .80848 .50086 L p .371 .411 .773 r
F P
0 g
s
.44687 .60953 m .45373 .60212 L .48682 .57667 L p .854 .994 .829 r
F P
0 g
s
.4905 .56867 m .48682 .57667 L .45373 .60212 L p .868 .994 .808 r
F P
0 g
s
.52255 .52494 m .52291 .51834 L .54387 .49243 L p .931 .955 .774 r
F P
0 g
s
.54083 .48943 m .54387 .49243 L .52291 .51834 L p .931 .965 .76 r
F P
0 g
s
.54387 .49243 m .54083 .48943 L .5572 .46661 L p .933 .953 .771 r
F P
0 g
s
.60245 .39921 m .5899 .40947 L .59306 .39813 L p .903 .972 .808 r
F P
0 g
s
.59306 .39813 m .60632 .38562 L .60245 .39921 L p .903 .972 .808 r
F P
0 g
s
.63268 .3663 m .61951 .37495 L .61792 .36584 L p .849 .972 .874 r
F P
0 g
s
.61792 .36584 m .631 .35543 L .63268 .3663 L p .849 .972 .874 r
F P
0 g
s
.56237 .4502 m .57137 .44481 L .5572 .46661 L p .931 .963 .764 r
F P
0 g
s
.57137 .44481 m .56237 .4502 L .57132 .43428 L p .927 .964 .772 r
F P
0 g
s
.57132 .43428 m .5825 .42537 L .57137 .44481 L p .927 .964 .772 r
F P
0 g
s
.49422 .56024 m .49798 .55139 L .52255 .52494 L p .919 .97 .779 r
F P
0 g
s
.52291 .51834 m .52255 .52494 L .49798 .55139 L p .92 .974 .764 r
F P
0 g
s
.7547 .38569 m .74053 .37546 L .7392 .34621 L p .317 .496 .876 r
F P
0 g
s
.7251 .3404 m .7392 .34621 L .74053 .37546 L p .363 .546 .9 r
F P
0 g
s
.5825 .42537 m .57132 .43428 L .57724 .42136 L p .92 .97 .777 r
F P
0 g
s
.57724 .42136 m .5899 .40947 L .5825 .42537 L p .92 .97 .777 r
F P
0 g
s
.55095 .46813 m .5572 .46661 L .54083 .48943 L p .932 .966 .754 r
F P
0 g
s
.5572 .46661 m .55095 .46813 L .56237 .4502 L p .931 .963 .764 r
F P
0 g
s
.83625 .53514 m .82234 .51809 L .84369 .47047 L p .374 .415 .776 r
F P
0 g
s
.82844 .45495 m .84369 .47047 L .82234 .51809 L p .37 .411 .773 r
F P
0 g
s
.61951 .37495 m .60632 .38562 L .60484 .37812 L p .874 .983 .835 r
F P
0 g
s
.60484 .37812 m .61792 .36584 L .61951 .37495 L p .874 .983 .835 r
F P
0 g
s
.45373 .60212 m .46065 .59365 L .4905 .56867 L p .868 .994 .808 r
F P
0 g
s
.49422 .56024 m .4905 .56867 L .46065 .59365 L p .879 .993 .789 r
F P
0 g
s
.76906 .39747 m .7547 .38569 L .75353 .35368 L p .281 .455 .855 r
F P
0 g
s
.7392 .34621 m .75353 .35368 L .7547 .38569 L p .317 .496 .876 r
F P
0 g
s
.5899 .40947 m .57724 .42136 L .57973 .41229 L p .911 .979 .776 r
F P
0 g
s
.57973 .41229 m .59306 .39813 L .5899 .40947 L p .911 .979 .776 r
F P
0 g
s
.52291 .51834 m .52327 .51188 L .54083 .48943 L p .931 .965 .76 r
F P
0 g
s
.53777 .48696 m .54083 .48943 L .52327 .51188 L p .928 .972 .744 r
F P
0 g
s
.54083 .48943 m .53777 .48696 L .55095 .46813 L p .932 .966 .754 r
F P
0 g
s
.84369 .47047 m .85906 .48583 L .83625 .53514 L p .374 .415 .776 r
F P
0 g
s
.49798 .55139 m .50176 .54214 L .52291 .51834 L p .92 .974 .764 r
F P
0 g
s
.52327 .51188 m .52291 .51834 L .50176 .54214 L p .92 .977 .749 r
F P
0 g
s
.60632 .38562 m .59306 .39813 L .59173 .39214 L p .891 .986 .799 r
F P
0 g
s
.59173 .39214 m .60484 .37812 L .60632 .38562 L p .891 .986 .799 r
F P
0 g
s
.55326 .45668 m .56237 .4502 L .55095 .46813 L p .928 .972 .744 r
F P
0 g
s
.56237 .4502 m .55326 .45668 L .56001 .4445 L p .925 .973 .748 r
F P
0 g
s
.56001 .4445 m .57132 .43428 L .56237 .4502 L p .925 .973 .748 r
F P
0 g
s
.46065 .59365 m .46764 .58415 L .49422 .56024 L p .879 .993 .789 r
F P
0 g
s
.49798 .55139 m .49422 .56024 L .46764 .58415 L p .889 .99 .771 r
F P
0 g
s
.78362 .41055 m .76906 .39747 L .76808 .36262 L p .256 .425 .838 r
F P
0 g
s
.75353 .35368 m .76808 .36262 L .76906 .39747 L p .281 .455 .855 r
F P
0 g
s
.57132 .43428 m .56001 .4445 L .56445 .43468 L p .921 .976 .75 r
F P
0 g
s
.56445 .43468 m .57724 .42136 L .57132 .43428 L p .921 .976 .75 r
F P
0 g
s
.54463 .47045 m .55095 .46813 L .53777 .48696 L p .928 .973 .737 r
F P
0 g
s
.55095 .46813 m .54463 .47045 L .55326 .45668 L p .928 .972 .744 r
F P
0 g
s
.45373 .60212 m .44687 .60953 L .41465 .62697 L p .737 .991 .825 r
F P
0 g
s
.67058 .33645 m .6573 .34067 L .64659 .33489 L p .68 .943 .962 r
F P
0 g
s
.6573 .34067 m .64412 .34701 L .63433 .34289 L p .745 .973 .927 r
F P
0 g
s
.63433 .34289 m .64659 .33489 L .6573 .34067 L p .745 .973 .927 r
F P
0 g
s
.59306 .39813 m .57973 .41229 L .57858 .40769 L p .902 .985 .768 r
F P
0 g
s
.57858 .40769 m .59173 .39214 L .59306 .39813 L p .902 .985 .768 r
F P
0 g
s
.64412 .34701 m .631 .35543 L .62216 .3527 L p .795 .989 .887 r
F P
0 g
s
.62216 .3527 m .63433 .34289 L .64412 .34701 L p .795 .989 .887 r
F P
0 g
s
.57724 .42136 m .56445 .43468 L .56628 .42788 L p .915 .98 .748 r
F P
0 g
s
.56628 .42788 m .57973 .41229 L .57724 .42136 L p .915 .98 .748 r
F P
0 g
s
.68397 .33435 m .67058 .33645 L .65895 .32872 L p .6 .897 .987 r
F P
0 g
s
.64659 .33489 m .65895 .32872 L .67058 .33645 L p .68 .943 .962 r
F P
0 g
s
.50176 .54214 m .50558 .53253 L .52327 .51188 L p .92 .977 .749 r
F P
0 g
s
.52363 .50551 m .52327 .51188 L .50558 .53253 L p .919 .978 .735 r
F P
0 g
s
.52327 .51188 m .52363 .50551 L .53777 .48696 L p .928 .972 .744 r
F P
0 g
s
.21917 .53769 m .20758 .52532 L .18911 .47507 L p 0 .2 .728 r
F P
0 g
s
.46764 .58415 m .47468 .57366 L .49798 .55139 L p .889 .99 .771 r
F P
0 g
s
.50176 .54214 m .49798 .55139 L .47468 .57366 L p .896 .988 .755 r
F P
0 g
s
.53466 .48494 m .53777 .48696 L .52363 .50551 L p .924 .975 .73 r
F P
0 g
s
.53777 .48696 m .53466 .48494 L .54463 .47045 L p .928 .973 .737 r
F P
0 g
s
.631 .35543 m .61792 .36584 L .61004 .36423 L p .833 .995 .848 r
F P
0 g
s
.61004 .36423 m .62216 .3527 L .631 .35543 L p .833 .995 .848 r
F P
0 g
s
.6975 .33436 m .68397 .33435 L .67144 .32442 L p .51 .836 .999 r
F P
0 g
s
.65895 .32872 m .67144 .32442 L .68397 .33435 L p .6 .897 .987 r
F P
0 g
s
.79839 .42468 m .78362 .41055 L .78286 .3728 L p .24 .403 .825 r
F P
0 g
s
.76808 .36262 m .78286 .3728 L .78362 .41055 L p .256 .425 .838 r
F P
0 g
s
.61792 .36584 m .60484 .37812 L .59795 .37738 L p .86 .996 .812 r
F P
0 g
s
.59795 .37738 m .61004 .36423 L .61792 .36584 L p .86 .996 .812 r
F P
0 g
s
.71121 .33641 m .6975 .33436 L .68408 .32195 L p .417 .762 .995 r
F P
0 g
s
.67144 .32442 m .68408 .32195 L .6975 .33436 L p .51 .836 .999 r
F P
0 g
s
.46065 .59365 m .45373 .60212 L .42442 .62015 L p .783 .997 .807 r
F P
0 g
s
.54402 .46404 m .55326 .45668 L .54463 .47045 L p .923 .976 .725 r
F P
0 g
s
.55326 .45668 m .54402 .46404 L .54855 .45578 L p .921 .977 .727 r
F P
0 g
s
.54855 .45578 m .56001 .4445 L .55326 .45668 L p .921 .977 .727 r
F P
0 g
s
.56001 .4445 m .54855 .45578 L .55151 .44917 L p .919 .978 .728 r
F P
0 g
s
.55151 .44917 m .56445 .43468 L .56001 .4445 L p .919 .978 .728 r
F P
0 g
s
.47468 .57366 m .48178 .56225 L .50176 .54214 L p .896 .988 .755 r
F P
0 g
s
.50558 .53253 m .50176 .54214 L .48178 .56225 L p .902 .985 .741 r
F P
0 g
s
.53822 .4734 m .54463 .47045 L .53466 .48494 L p .922 .976 .722 r
F P
0 g
s
.54463 .47045 m .53822 .4734 L .54402 .46404 L p .923 .976 .725 r
F P
0 g
s
.57973 .41229 m .56628 .42788 L .56536 .42457 L p .908 .983 .742 r
F P
0 g
s
.56536 .42457 m .57858 .40769 L .57973 .41229 L p .908 .983 .742 r
F P
0 g
s
.60484 .37812 m .59173 .39214 L .58588 .39201 L p .88 .993 .78 r
F P
0 g
s
.58588 .39201 m .59795 .37738 L .60484 .37812 L p .88 .993 .78 r
F P
0 g
s
.7251 .3404 m .71121 .33641 L .6969 .32126 L p .327 .685 .979 r
F P
0 g
s
.68408 .32195 m .6969 .32126 L .71121 .33641 L p .417 .762 .995 r
F P
0 g
s
.81333 .43958 m .79839 .42468 L .79786 .38399 L p .232 .389 .815 r
F P
0 g
s
.78286 .3728 m .79786 .38399 L .79839 .42468 L p .24 .403 .825 r
F P
0 g
s
.50558 .53253 m .50943 .52259 L .52363 .50551 L p .919 .978 .735 r
F P
0 g
s
.52399 .49922 m .52363 .50551 L .50943 .52259 L p .918 .978 .724 r
F P
0 g
s
.52363 .50551 m .52399 .49922 L .53466 .48494 L p .924 .975 .73 r
F P
0 g
s
.18911 .47507 m .20163 .49061 L .21917 .53769 L p 0 .2 .728 r
F P
0 g
s
.23086 .55048 m .21917 .53769 L .20163 .49061 L p 0 .18 .714 r
F P
0 g
s
.56445 .43468 m .55151 .44917 L .55271 .44464 L p .916 .979 .726 r
F P
0 g
s
.55271 .44464 m .56628 .42788 L .56445 .43468 L p .916 .979 .726 r
F P
0 g
s
.42442 .62015 m .43428 .6117 L .46065 .59365 L p .783 .997 .807 r
F P
0 g
s
.46764 .58415 m .46065 .59365 L .43428 .6117 L p .818 .999 .788 r
F P
0 g
s
.53152 .48326 m .53466 .48494 L .52399 .49922 L p .92 .976 .718 r
F P
0 g
s
.53466 .48494 m .53152 .48326 L .53822 .4734 L p .922 .976 .722 r
F P
0 g
s
.59173 .39214 m .57858 .40769 L .5738 .40795 L p .894 .989 .754 r
F P
0 g
s
.5738 .40795 m .58588 .39201 L .59173 .39214 L p .894 .989 .754 r
F P
0 g
s
.7392 .34621 m .7251 .3404 L .7099 .32228 L p .249 .61 .955 r
F P
0 g
s
.6969 .32126 m .7099 .32228 L .7251 .3404 L p .327 .685 .979 r
F P
0 g
s
.48178 .56225 m .48892 .55002 L .50558 .53253 L p .902 .985 .741 r
F P
0 g
s
.50943 .52259 m .50558 .53253 L .48892 .55002 L p .907 .983 .73 r
F P
0 g
s
.43428 .6117 m .44422 .60168 L .46764 .58415 L p .818 .999 .788 r
F P
0 g
s
.47468 .57366 m .46764 .58415 L .44422 .60168 L p .846 .997 .771 r
F P
0 g
s
.56628 .42788 m .55271 .44464 L .55205 .44251 L p .912 .98 .723 r
F P
0 g
s
.55205 .44251 m .56536 .42457 L .56628 .42788 L p .912 .98 .723 r
F P
0 g
s
.82844 .45495 m .81333 .43958 L .81309 .39591 L p .231 .384 .81 r
F P
0 g
s
.79786 .38399 m .81309 .39591 L .81333 .43958 L p .232 .389 .815 r
F P
0 g
s
.57858 .40769 m .56536 .42457 L .5617 .425 L p .903 .984 .734 r
F P
0 g
s
.5617 .425 m .5738 .40795 L .57858 .40769 L p .903 .984 .734 r
F P
0 g
s
.50943 .52259 m .51331 .51236 L .52399 .49922 L p .918 .978 .724 r
F P
0 g
s
.52436 .49297 m .52399 .49922 L .51331 .51236 L p .917 .977 .714 r
F P
0 g
s
.52399 .49922 m .52436 .49297 L .53152 .48326 L p .92 .976 .718 r
F P
0 g
s
.53464 .47205 m .54402 .46404 L .53822 .4734 L p .918 .977 .711 r
F P
0 g
s
.54402 .46404 m .53464 .47205 L .53692 .46787 L p .917 .977 .712 r
F P
0 g
s
.53692 .46787 m .54855 .45578 L .54402 .46404 L p .917 .977 .712 r
F P
0 g
s
.54855 .45578 m .53692 .46787 L .5384 .46454 L p .916 .977 .712 r
F P
0 g
s
.5384 .46454 m .55151 .44917 L .54855 .45578 L p .916 .977 .712 r
F P
0 g
s
.20163 .49061 m .21423 .50661 L .23086 .55048 L p 0 .18 .714 r
F P
0 g
s
.24268 .5634 m .23086 .55048 L .21423 .50661 L p 0 .173 .71 r
F P
0 g
s
.53171 .4768 m .53822 .4734 L .53152 .48326 L p .917 .977 .71 r
F P
0 g
s
.53822 .4734 m .53171 .4768 L .53464 .47205 L p .918 .977 .711 r
F P
0 g
s
.75353 .35368 m .7392 .34621 L .72311 .32488 L p .185 .543 .928 r
F P
0 g
s
.7099 .32228 m .72311 .32488 L .7392 .34621 L p .249 .61 .955 r
F P
0 g
s
.48892 .55002 m .4961 .53705 L .50943 .52259 L p .907 .983 .73 r
F P
0 g
s
.51331 .51236 m .50943 .52259 L .4961 .53705 L p .911 .98 .72 r
F P
0 g
s
.44422 .60168 m .45424 .59015 L .47468 .57366 L p .846 .997 .771 r
F P
0 g
s
.48178 .56225 m .47468 .57366 L .45424 .59015 L p .867 .994 .755 r
F P
0 g
s
.55151 .44917 m .5384 .46454 L .53899 .46228 L p .915 .978 .711 r
F P
0 g
s
.53899 .46228 m .55271 .44464 L .55151 .44917 L p .915 .978 .711 r
F P
0 g
s
.52834 .48181 m .53152 .48326 L .52436 .49297 L p .917 .977 .709 r
F P
0 g
s
.53152 .48326 m .52834 .48181 L .53171 .4768 L p .917 .977 .71 r
F P
0 g
s
.56536 .42457 m .55205 .44251 L .54955 .44294 L p .91 .98 .719 r
F P
0 g
s
.54955 .44294 m .5617 .425 L .56536 .42457 L p .91 .98 .719 r
F P
0 g
s
.84369 .47047 m .82844 .45495 L .82851 .40828 L p .238 .385 .809 r
F P
0 g
s
.81309 .39591 m .82851 .40828 L .82844 .45495 L p .231 .384 .81 r
F P
0 g
s
.63433 .34289 m .62216 .3527 L .60642 .35862 L p .795 .999 .837 r
F P
0 g
s
.62216 .3527 m .61004 .36423 L .59616 .37052 L p .83 1 .807 r
F P
0 g
s
.59616 .37052 m .60642 .35862 L .62216 .3527 L p .83 1 .807 r
F P
0 g
s
.61004 .36423 m .59795 .37738 L .58595 .38365 L p .857 .997 .781 r
F P
0 g
s
.58595 .38365 m .59616 .37052 L .61004 .36423 L p .857 .997 .781 r
F P
0 g
s
.45424 .59015 m .4643 .57724 L .48178 .56225 L p .867 .994 .755 r
F P
0 g
s
.48892 .55002 m .48178 .56225 L .4643 .57724 L p .883 .99 .741 r
F P
0 g
s
.64659 .33489 m .63433 .34289 L .61676 .34806 L p .749 .993 .868 r
F P
0 g
s
.60642 .35862 m .61676 .34806 L .63433 .34289 L p .795 .999 .837 r
F P
0 g
s
.55271 .44464 m .53899 .46228 L .53864 .46124 L p .914 .978 .71 r
F P
0 g
s
.53864 .46124 m .55205 .44251 L .55271 .44464 L p .914 .978 .71 r
F P
0 g
s
.59795 .37738 m .58588 .39201 L .57578 .39791 L p .877 .993 .759 r
F P
0 g
s
.57578 .39791 m .58595 .38365 L .59795 .37738 L p .877 .993 .759 r
F P
0 g
s
.4961 .53705 m .50331 .52348 L .51331 .51236 L p .911 .98 .72 r
F P
0 g
s
.51721 .5019 m .51331 .51236 L .50331 .52348 L p .913 .979 .712 r
F P
0 g
s
.51331 .51236 m .51721 .5019 L .52436 .49297 L p .917 .977 .714 r
F P
0 g
s
.76808 .36262 m .75353 .35368 L .73653 .32892 L p .137 .488 .902 r
F P
0 g
s
.72311 .32488 m .73653 .32892 L .75353 .35368 L p .185 .543 .928 r
F P
0 g
s
.65895 .32872 m .64659 .33489 L .62717 .33889 L p .691 .978 .899 r
F P
0 g
s
.61676 .34806 m .62717 .33889 L .64659 .33489 L p .749 .993 .868 r
F P
0 g
s
.52474 .48673 m .52436 .49297 L .51721 .5019 L p .916 .977 .708 r
F P
0 g
s
.52436 .49297 m .52474 .48673 L .52834 .48181 L p .917 .977 .709 r
F P
0 g
s
.58588 .39201 m .5738 .40795 L .56563 .41315 L p .891 .988 .74 r
F P
0 g
s
.56563 .41315 m .57578 .39791 L .58588 .39201 L p .891 .988 .74 r
F P
0 g
s
.21423 .50661 m .22696 .52276 L .24268 .5634 L p 0 .173 .71 r
F P
0 g
s
.25466 .57613 m .24268 .5634 L .22696 .52276 L p 0 .181 .716 r
F P
0 g
s
.42442 .62015 m .41465 .62697 L .38884 .63497 L p .629 .962 .854 r
F P
0 g
s
.4643 .57724 m .47441 .56309 L .48892 .55002 L p .883 .99 .741 r
F P
0 g
s
.4961 .53705 m .48892 .55002 L .47441 .56309 L p .895 .986 .73 r
F P
0 g
s
.67144 .32442 m .65895 .32872 L .63769 .33116 L p .62 .952 .927 r
F P
0 g
s
.62717 .33889 m .63769 .33116 L .65895 .32872 L p .691 .978 .899 r
F P
0 g
s
.5738 .40795 m .5617 .425 L .5555 .42922 L p .902 .984 .726 r
F P
0 g
s
.5555 .42922 m .56563 .41315 L .5738 .40795 L p .902 .984 .726 r
F P
0 g
s
.55205 .44251 m .53864 .46124 L .53736 .46151 L p .913 .978 .709 r
F P
0 g
s
.53736 .46151 m .54955 .44294 L .55205 .44251 L p .913 .978 .709 r
F P
0 g
s
.52511 .48046 m .53464 .47205 L .53171 .4768 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .53692 .46787 L .53464 .47205 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .5384 .46454 L .53692 .46787 L closepath p .915 .977 .704 r
F P
0 g
s
.85906 .48583 m .84369 .47047 L .84411 .4208 L p .251 .393 .811 r
F P
0 g
s
.82851 .40828 m .84411 .4208 L .84369 .47047 L p .238 .385 .809 r
F P
0 g
s
.52511 .48046 m .53171 .4768 L .52834 .48181 L closepath p .915 .977 .704 r
F P
0 g
s
.50331 .52348 m .51055 .50943 L .51721 .5019 L p .913 .979 .712 r
F P
0 g
s
.52115 .49125 m .51721 .5019 L .51055 .50943 L p .914 .977 .707 r
F P
0 g
s
.51721 .5019 m .52115 .49125 L .52474 .48673 L p .916 .977 .708 r
F P
0 g
s
.47441 .56309 m .48453 .54788 L .4961 .53705 L p .895 .986 .73 r
F P
0 g
s
.50331 .52348 m .4961 .53705 L .48453 .54788 L p .904 .982 .72 r
F P
0 g
s
.52511 .48046 m .53899 .46228 L .5384 .46454 L closepath p .915 .977 .704 r
F P
0 g
s
.68408 .32195 m .67144 .32442 L .64833 .32487 L p .538 .912 .948 r
F P
0 g
s
.63769 .33116 m .64833 .32487 L .67144 .32442 L p .62 .952 .927 r
F P
0 g
s
.5617 .425 m .54955 .44294 L .54538 .44592 L p .909 .98 .715 r
F P
0 g
s
.54538 .44592 m .5555 .42922 L .5617 .425 L p .909 .98 .715 r
F P
0 g
s
.43428 .6117 m .42442 .62015 L .40102 .62918 L p .711 .986 .837 r
F P
0 g
s
.52511 .48046 m .52834 .48181 L .52474 .48673 L closepath p .915 .977 .704 r
F P
0 g
s
.78286 .3728 m .76808 .36262 L .75018 .33425 L p .106 .446 .881 r
F P
0 g
s
.73653 .32892 m .75018 .33425 L .76808 .36262 L p .137 .488 .902 r
F P
0 g
s
.52511 .48046 m .53864 .46124 L .53899 .46228 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .52474 .48673 L .52115 .49125 L closepath p .915 .977 .704 r
F P
0 g
s
.48453 .54788 m .49468 .53179 L .50331 .52348 L p .904 .982 .72 r
F P
0 g
s
.51055 .50943 m .50331 .52348 L .49468 .53179 L p .91 .979 .712 r
F P
0 g
s
.54955 .44294 m .53736 .46151 L .53525 .46308 L p .913 .978 .708 r
F P
0 g
s
.53525 .46308 m .54538 .44592 L .54955 .44294 L p .913 .978 .708 r
F P
0 g
s
.40102 .62918 m .41332 .62129 L .43428 .6117 L p .711 .986 .837 r
F P
0 g
s
.44422 .60168 m .43428 .6117 L .41332 .62129 L p .772 .997 .816 r
F P
0 g
s
.52511 .48046 m .53736 .46151 L .53864 .46124 L closepath p .915 .977 .704 r
F P
0 g
s
.22696 .52276 m .23984 .5387 L .25466 .57613 L p 0 .181 .716 r
F P
0 g
s
.26683 .58836 m .25466 .57613 L .23984 .5387 L p 0 .204 .732 r
F P
0 g
s
.6969 .32126 m .68408 .32195 L .6591 .32001 L p .448 .859 .959 r
F P
0 g
s
.64833 .32487 m .6591 .32001 L .68408 .32195 L p .538 .912 .948 r
F P
0 g
s
.51055 .50943 m .51782 .49505 L .52115 .49125 L p .914 .977 .707 r
F P
0 g
s
.52511 .48046 m .52115 .49125 L .51782 .49505 L closepath p .915 .977 .704 r
F P
0 g
s
.49468 .53179 m .50483 .51505 L .51055 .50943 L p .91 .979 .712 r
F P
0 g
s
.51782 .49505 m .51055 .50943 L .50483 .51505 L p .914 .978 .707 r
F P
0 g
s
.35314 .63984 m .34159 .63757 L .31757 .62582 L p .034 .559 .863 r
F P
0 g
s
.84411 .4208 m .85986 .43317 L .85906 .48583 L p .251 .393 .811 r
F P
0 g
s
.41332 .62129 m .4257 .61136 L .44422 .60168 L p .772 .997 .816 r
F P
0 g
s
.45424 .59015 m .44422 .60168 L .4257 .61136 L p .817 .999 .793 r
F P
0 g
s
.52511 .48046 m .53525 .46308 L .53736 .46151 L closepath p .915 .977 .704 r
F P
0 g
s
.50483 .51505 m .51497 .49786 L .51782 .49505 L p .914 .978 .707 r
F P
0 g
s
.52511 .48046 m .51782 .49505 L .51497 .49786 L closepath p .915 .977 .704 r
F P
0 g
s
.4257 .61136 m .43814 .59951 L .45424 .59015 L p .817 .999 .793 r
F P
0 g
s
.4643 .57724 m .45424 .59015 L .43814 .59951 L p .849 .997 .772 r
F P
0 g
s
.79786 .38399 m .78286 .3728 L .76406 .34065 L p .089 .416 .865 r
F P
0 g
s
.75018 .33425 m .76406 .34065 L .78286 .3728 L p .106 .446 .881 r
F P
0 g
s
.56563 .41315 m .5555 .42922 L .54715 .43699 L p .905 .982 .721 r
F P
0 g
s
.5555 .42922 m .54538 .44592 L .53978 .4513 L p .91 .979 .713 r
F P
0 g
s
.53978 .4513 m .54715 .43699 L .5555 .42922 L p .91 .979 .713 r
F P
0 g
s
.57578 .39791 m .56563 .41315 L .55456 .42305 L p .897 .986 .732 r
F P
0 g
s
.54715 .43699 m .55456 .42305 L .56563 .41315 L p .905 .982 .721 r
F P
0 g
s
.54538 .44592 m .53525 .46308 L .53243 .46583 L p .914 .978 .707 r
F P
0 g
s
.53243 .46583 m .53978 .4513 L .54538 .44592 L p .914 .978 .707 r
F P
0 g
s
.7099 .32228 m .6969 .32126 L .67002 .31654 L p .356 .797 .96 r
F P
0 g
s
.6591 .32001 m .67002 .31654 L .6969 .32126 L p .448 .859 .959 r
F P
0 g
s
.58595 .38365 m .57578 .39791 L .562 .4096 L p .886 .99 .745 r
F P
0 g
s
.55456 .42305 m .562 .4096 L .57578 .39791 L p .897 .986 .732 r
F P
0 g
s
.52511 .48046 m .53243 .46583 L .53525 .46308 L closepath p .915 .977 .704 r
F P
0 g
s
.43814 .59951 m .45061 .5859 L .4643 .57724 L p .849 .997 .772 r
F P
0 g
s
.47441 .56309 m .4643 .57724 L .45061 .5859 L p .873 .993 .753 r
F P
0 g
s
.52511 .48046 m .52911 .4696 L .53243 .46583 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .5255 .47413 L .52911 .4696 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .52185 .4791 L .5255 .47413 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51841 .48418 L .52185 .4791 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51544 .48901 L .51841 .48418 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51312 .49325 L .51544 .48901 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51164 .49662 L .51312 .49325 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51108 .49887 L .51164 .49662 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51148 .49985 L .51108 .49887 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51281 .4995 L .51148 .49985 L closepath p .915 .977 .704 r
F P
0 g
s
.52511 .48046 m .51497 .49786 L .51281 .4995 L closepath p .915 .977 .704 r
F P
0 g
s
.59616 .37052 m .58595 .38365 L .56948 .39674 L p .872 .994 .761 r
F P
0 g
s
.562 .4096 m .56948 .39674 L .58595 .38365 L p .886 .99 .745 r
F P
0 g
s
.50044 .51834 m .51281 .4995 L .51497 .49786 L p .913 .978 .708 r
F P
0 g
s
.51497 .49786 m .50483 .51505 L .50044 .51834 L p .913 .978 .708 r
F P
0 g
s
.45061 .5859 m .4631 .57074 L .47441 .56309 L p .873 .993 .753 r
F P
0 g
s
.48453 .54788 m .47441 .56309 L .4631 .57074 L p .889 .988 .737 r
F P
0 g
s
.36488 .64024 m .35314 .63984 L .33079 .63089 L p .191 .686 .918 r
F P
0 g
s
.48803 .53669 m .50044 .51834 L .50483 .51505 L p .909 .98 .715 r
F P
0 g
s
.50483 .51505 m .49468 .53179 L .48803 .53669 L p .909 .98 .715 r
F P
0 g
s
.4631 .57074 m .47558 .55425 L .48453 .54788 L p .889 .988 .737 r
F P
0 g
s
.49468 .53179 m .48453 .54788 L .47558 .55425 L p .901 .984 .725 r
F P
0 g
s
.47558 .55425 m .48803 .53669 L .49468 .53179 L p .901 .984 .725 r
F P
0 g
s
.23984 .5387 m .2529 .55409 L .26683 .58836 L p 0 .204 .732 r
F P
0 g
s
.27919 .59975 m .26683 .58836 L .2529 .55409 L p 0 .243 .758 r
F P
0 g
s
.60642 .35862 m .59616 .37052 L .577 .38457 L p .853 .997 .78 r
F P
0 g
s
.56948 .39674 m .577 .38457 L .59616 .37052 L p .872 .994 .761 r
F P
0 g
s
.53978 .4513 m .53243 .46583 L .52911 .4696 L p .914 .977 .707 r
F P
0 g
s
.49772 .51906 m .51148 .49985 L .51281 .4995 L p .913 .978 .709 r
F P
0 g
s
.51281 .4995 m .50044 .51834 L .49772 .51906 L p .913 .978 .709 r
F P
0 g
s
.61676 .34806 m .60642 .35862 L .58459 .37317 L p .83 1 .801 r
F P
0 g
s
.577 .38457 m .58459 .37317 L .60642 .35862 L p .853 .997 .78 r
F P
0 g
s
.20163 .49061 m .18911 .47507 L .19318 .42214 L p .171 .299 .754 r
F P
0 g
s
.72311 .32488 m .7099 .32228 L .6811 .3144 L p .271 .73 .952 r
F P
0 g
s
.67002 .31654 m .6811 .3144 L .7099 .32228 L p .356 .797 .96 r
F P
0 g
s
.54715 .43699 m .53978 .4513 L .53313 .45871 L p .913 .979 .713 r
F P
0 g
s
.52911 .4696 m .53313 .45871 L .53978 .4513 L p .914 .977 .707 r
F P
0 g
s
.53313 .45871 m .52911 .4696 L .5255 .47413 L p .916 .977 .708 r
F P
0 g
s
.33079 .63089 m .34422 .63378 L .36488 .64024 L p .191 .686 .918 r
F P
0 g
s
.37678 .63865 m .36488 .64024 L .34422 .63378 L p .351 .8 .951 r
F P
0 g
s
.81309 .39591 m .79786 .38399 L .77816 .34792 L p .085 .399 .854 r
F P
0 g
s
.76406 .34065 m .77816 .34792 L .79786 .38399 L p .089 .416 .865 r
F P
0 g
s
.49687 .51712 m .51108 .49887 L .51148 .49985 L p .914 .978 .71 r
F P
0 g
s
.51148 .49985 m .49772 .51906 L .49687 .51712 L p .914 .978 .71 r
F P
0 g
s
.62717 .33889 m .61676 .34806 L .59224 .36261 L p .802 1 .825 r
F P
0 g
s
.58459 .37317 m .59224 .36261 L .61676 .34806 L p .83 1 .801 r
F P
0 g
s
.48387 .53776 m .49772 .51906 L .50044 .51834 L p .909 .98 .718 r
F P
0 g
s
.50044 .51834 m .48803 .53669 L .48387 .53776 L p .909 .98 .718 r
F P
0 g
s
.55456 .42305 m .54715 .43699 L .53718 .44786 L p .911 .98 .72 r
F P
0 g
s
.53313 .45871 m .53718 .44786 L .54715 .43699 L p .913 .979 .713 r
F P
0 g
s
.5255 .47413 m .52588 .46769 L .53313 .45871 L p .916 .977 .708 r
F P
0 g
s
.52588 .46769 m .5255 .47413 L .52185 .4791 L p .917 .977 .709 r
F P
0 g
s
.49797 .51264 m .51164 .49662 L .51108 .49887 L p .915 .978 .711 r
F P
0 g
s
.51108 .49887 m .49687 .51712 L .49797 .51264 L p .915 .978 .711 r
F P
0 g
s
.2529 .55409 m .26615 .56857 L .27919 .59975 L p 0 .243 .758 r
F P
0 g
s
.29176 .60999 m .27919 .59975 L .26615 .56857 L p 0 .298 .794 r
F P
0 g
s
.52185 .4791 m .51854 .47759 L .52588 .46769 L p .917 .977 .709 r
F P
0 g
s
.51854 .47759 m .52185 .4791 L .51841 .48418 L p .917 .977 .71 r
F P
0 g
s
.63769 .33116 m .62717 .33889 L .59995 .35292 L p .767 .996 .851 r
F P
0 g
s
.59224 .36261 m .59995 .35292 L .62717 .33889 L p .802 1 .825 r
F P
0 g
s
.46991 .5556 m .48387 .53776 L .48803 .53669 L p .902 .984 .732 r
F P
0 g
s
.48803 .53669 m .47558 .55425 L .46991 .5556 L p .902 .984 .732 r
F P
0 g
s
.34422 .63378 m .35783 .63433 L .37678 .63865 L p .351 .8 .951 r
F P
0 g
s
.38884 .63497 m .37678 .63865 L .35783 .63433 L p .497 .888 .956 r
F P
0 g
s
.50095 .50591 m .51312 .49325 L .51164 .49662 L p .916 .977 .712 r
F P
0 g
s
.51164 .49662 m .49797 .51264 L .50095 .50591 L p .916 .977 .712 r
F P
0 g
s
.562 .4096 m .55456 .42305 L .54127 .43708 L p .907 .982 .73 r
F P
0 g
s
.53718 .44786 m .54127 .43708 L .55456 .42305 L p .911 .98 .72 r
F P
0 g
s
.53718 .44786 m .53313 .45871 L .52588 .46769 L p .917 .977 .714 r
F P
0 g
s
.51841 .48418 m .51161 .48774 L .51854 .47759 L p .917 .977 .71 r
F P
0 g
s
.51161 .48774 m .51841 .48418 L .51544 .48901 L p .918 .977 .711 r
F P
0 g
s
.19318 .42214 m .20592 .44005 L .20163 .49061 L p .171 .299 .754 r
F P
0 g
s
.21423 .50661 m .20163 .49061 L .20592 .44005 L p .163 .291 .749 r
F P
0 g
s
.50561 .49741 m .51544 .48901 L .51312 .49325 L p .917 .977 .712 r
F P
0 g
s
.51312 .49325 m .50095 .50591 L .50561 .49741 L p .917 .977 .712 r
F P
0 g
s
.51544 .48901 m .50561 .49741 L .51161 .48774 L p .918 .977 .711 r
F P
0 g
s
.73653 .32892 m .72311 .32488 L .69235 .31348 L p .197 .666 .939 r
F P
0 g
s
.6811 .3144 m .69235 .31348 L .72311 .32488 L p .271 .73 .952 r
F P
0 g
s
.48252 .53487 m .49687 .51712 L .49772 .51906 L p .912 .98 .722 r
F P
0 g
s
.49772 .51906 m .48387 .53776 L .48252 .53487 L p .912 .98 .722 r
F P
0 g
s
.45588 .57226 m .46991 .5556 L .47558 .55425 L p .892 .989 .751 r
F P
0 g
s
.47558 .55425 m .4631 .57074 L .45588 .57226 L p .892 .989 .751 r
F P
0 g
s
.35783 .63433 m .3716 .63245 L .38884 .63497 L p .497 .888 .956 r
F P
0 g
s
.40102 .62918 m .38884 .63497 L .3716 .63245 L p .616 .946 .939 r
F P
0 g
s
.56948 .39674 m .562 .4096 L .54538 .42643 L p .903 .985 .742 r
F P
0 g
s
.54127 .43708 m .54538 .42643 L .562 .4096 L p .907 .982 .73 r
F P
0 g
s
.64833 .32487 m .63769 .33116 L .60775 .34414 L p .726 .988 .877 r
F P
0 g
s
.59995 .35292 m .60775 .34414 L .63769 .33116 L p .767 .996 .851 r
F P
0 g
s
.82851 .40828 m .81309 .39591 L .79248 .35582 L p .093 .392 .849 r
F P
0 g
s
.77816 .34792 m .79248 .35582 L .81309 .39591 L p .085 .399 .854 r
F P
0 g
s
.4418 .58742 m .45588 .57226 L .4631 .57074 L p .876 .994 .774 r
F P
0 g
s
.4631 .57074 m .45061 .5859 L .4418 .58742 L p .876 .994 .774 r
F P
0 g
s
.52588 .46769 m .52627 .4611 L .53718 .44786 L p .917 .977 .714 r
F P
0 g
s
.52627 .4611 m .52588 .46769 L .51854 .47759 L p .92 .977 .717 r
F P
0 g
s
.3716 .63245 m .38551 .62811 L .40102 .62918 L p .616 .946 .939 r
F P
0 g
s
.41332 .62129 m .40102 .62918 L .38551 .62811 L p .707 .979 .908 r
F P
0 g
s
.26615 .56857 m .27962 .58181 L .29176 .60999 L p 0 .298 .794 r
F P
0 g
s
.30455 .61877 m .29176 .60999 L .27962 .58181 L p .035 .369 .838 r
F P
0 g
s
.54127 .43708 m .53718 .44786 L .52627 .4611 L p .918 .978 .724 r
F P
0 g
s
.42769 .6008 m .4418 .58742 L .45061 .5859 L p .853 .998 .803 r
F P
0 g
s
.45061 .5859 m .43814 .59951 L .42769 .6008 L p .853 .998 .803 r
F P
0 g
s
.48412 .52817 m .49797 .51264 L .49687 .51712 L p .915 .979 .726 r
F P
0 g
s
.49687 .51712 m .48252 .53487 L .48412 .52817 L p .915 .979 .726 r
F P
0 g
s
.38551 .62811 m .39951 .62132 L .41332 .62129 L p .707 .979 .908 r
F P
0 g
s
.4257 .61136 m .41332 .62129 L .39951 .62132 L p .773 .994 .872 r
F P
0 g
s
.577 .38457 m .56948 .39674 L .54953 .41596 L p .897 .987 .757 r
F P
0 g
s
.54538 .42643 m .54953 .41596 L .56948 .39674 L p .903 .985 .742 r
F P
0 g
s
.41358 .61217 m .42769 .6008 L .43814 .59951 L p .82 .999 .835 r
F P
0 g
s
.43814 .59951 m .4257 .61136 L .41358 .61217 L p .82 .999 .835 r
F P
0 g
s
.39951 .62132 m .41358 .61217 L .4257 .61136 L p .773 .994 .872 r
F P
0 g
s
.20592 .44005 m .21871 .45842 L .21423 .50661 L p .163 .291 .749 r
F P
0 g
s
.22696 .52276 m .21423 .50661 L .21871 .45842 L p .165 .292 .749 r
F P
0 g
s
.46802 .55174 m .48252 .53487 L .48387 .53776 L p .907 .983 .741 r
F P
0 g
s
.48387 .53776 m .46991 .5556 L .46802 .55174 L p .907 .983 .741 r
F P
0 g
s
.6591 .32001 m .64833 .32487 L .61564 .33629 L p .678 .974 .902 r
F P
0 g
s
.60775 .34414 m .61564 .33629 L .64833 .32487 L p .726 .988 .877 r
F P
0 g
s
.75018 .33425 m .73653 .32892 L .70379 .31369 L p .14 .608 .924 r
F P
0 g
s
.69235 .31348 m .70379 .31369 L .73653 .32892 L p .197 .666 .939 r
F P
0 g
s
.51854 .47759 m .51518 .47581 L .52627 .4611 L p .92 .977 .717 r
F P
0 g
s
.51518 .47581 m .51854 .47759 L .51161 .48774 L p .922 .976 .721 r
F P
0 g
s
.48859 .5181 m .50095 .50591 L .49797 .51264 L p .919 .978 .727 r
F P
0 g
s
.49797 .51264 m .48412 .52817 L .48859 .5181 L p .919 .978 .727 r
F P
0 g
s
.58459 .37317 m .577 .38457 L .55372 .4057 L p .89 .99 .773 r
F P
0 g
s
.54953 .41596 m .55372 .4057 L .577 .38457 L p .897 .987 .757 r
F P
0 g
s
.54538 .42643 m .54127 .43708 L .52666 .45433 L p .919 .978 .735 r
F P
0 g
s
.52627 .4611 m .52666 .45433 L .54127 .43708 L p .918 .978 .724 r
F P
0 g
s
.27962 .58181 m .2933 .59346 L .30455 .61877 L p .035 .369 .838 r
F P
0 g
s
.31757 .62582 m .30455 .61877 L .2933 .59346 L p .124 .456 .886 r
F P
0 g
s
.51161 .48774 m .50471 .49093 L .51518 .47581 L p .922 .976 .721 r
F P
0 g
s
.50471 .49093 m .51161 .48774 L .50561 .49741 L p .922 .976 .724 r
F P
0 g
s
.84411 .4208 m .82851 .40828 L .80701 .3641 L p .111 .395 .849 r
F P
0 g
s
.79248 .35582 m .80701 .3641 L .82851 .40828 L p .093 .392 .849 r
F P
0 g
s
.49562 .50538 m .50561 .49741 L .50095 .50591 L p .921 .977 .727 r
F P
0 g
s
.50095 .50591 m .48859 .5181 L .49562 .50538 L p .921 .977 .727 r
F P
0 g
s
.50561 .49741 m .49562 .50538 L .50471 .49093 L p .922 .976 .724 r
F P
0 g
s
.52666 .45433 m .52627 .4611 L .51518 .47581 L p .924 .975 .729 r
F P
0 g
s
.45339 .56737 m .46802 .55174 L .46991 .5556 L p .9 .986 .765 r
F P
0 g
s
.46991 .5556 m .45588 .57226 L .45339 .56737 L p .9 .986 .765 r
F P
0 g
s
.67002 .31654 m .6591 .32001 L .62362 .32933 L p .624 .953 .925 r
F P
0 g
s
.61564 .33629 m .62362 .32933 L .6591 .32001 L p .678 .974 .902 r
F P
0 g
s
.21871 .45842 m .2316 .47689 L .22696 .52276 L p .165 .292 .749 r
F P
0 g
s
.23984 .5387 m .22696 .52276 L .2316 .47689 L p .176 .302 .755 r
F P
0 g
s
.4701 .54284 m .48412 .52817 L .48252 .53487 L p .914 .981 .747 r
F P
0 g
s
.48252 .53487 m .46802 .55174 L .4701 .54284 L p .914 .981 .747 r
F P
0 g
s
.59224 .36261 m .58459 .37317 L .55794 .39568 L p .882 .992 .792 r
F P
0 g
s
.55372 .4057 m .55794 .39568 L .58459 .37317 L p .89 .99 .773 r
F P
0 g
s
.76406 .34065 m .75018 .33425 L .71541 .31487 L p .1 .561 .911 r
F P
0 g
s
.70379 .31369 m .71541 .31487 L .75018 .33425 L p .14 .608 .924 r
F P
0 g
s
.54953 .41596 m .54538 .42643 L .52706 .44735 L p .92 .977 .748 r
F P
0 g
s
.52666 .45433 m .52706 .44735 L .54538 .42643 L p .919 .978 .735 r
F P
0 g
s
.2933 .59346 m .3072 .60324 L .31757 .62582 L p .124 .456 .886 r
F P
0 g
s
.33079 .63089 m .31757 .62582 L .3072 .60324 L p .23 .554 .932 r
F P
0 g
s
.43867 .58144 m .45339 .56737 L .45588 .57226 L p .888 .989 .795 r
F P
0 g
s
.45588 .57226 m .4418 .58742 L .43867 .58144 L p .888 .989 .795 r
F P
0 g
s
.51518 .47581 m .51178 .47361 L .52666 .45433 L p .924 .975 .729 r
F P
0 g
s
.51178 .47361 m .51518 .47581 L .50471 .49093 L p .927 .973 .736 r
F P
0 g
s
.59995 .35292 m .59224 .36261 L .56221 .38593 L p .871 .992 .812 r
F P
0 g
s
.55794 .39568 m .56221 .38593 L .59224 .36261 L p .882 .992 .792 r
F P
0 g
s
.63991 .31803 m .64823 .31356 L .68507 .3135 L p .509 .892 .96 r
F P
0 g
s
.6811 .3144 m .67002 .31654 L .63655 .32241 L p .567 .926 .945 r
F P
0 g
s
.64115 .32157 m .6811 .3144 L .63655 .32241 L .567 .926 .945 r
F
.63171 .32326 m .63991 .31803 L .6811 .3144 L p F P
0 g
s
.69235 .31348 m .6811 .3144 L .64431 .31764 L p .509 .892 .96 r
F P
0 g
s
.64431 .31764 m .63991 .31803 L p .64871 .31726 L .509 .892 .96 r
F P
0 g
s
.64871 .31726 m .69235 .31348 L .64431 .31764 L .509 .892 .96 r
F
.64823 .31356 m .65666 .30979 L .69716 .31314 L p .454 .855 .971 r
F P
0 g
s
.68507 .3135 m .69235 .31348 L p .6787 .31467 L .509 .892 .96 r
F P
0 g
s
.63991 .31803 m .68507 .3135 L .6787 .31467 L .509 .892 .96 r
F
.70379 .31369 m .69235 .31348 L .65213 .31356 L p .454 .855 .971 r
F P
0 g
s
.65213 .31356 m .64823 .31356 L p .65623 .31358 L .454 .855 .971 r
F P
0 g
s
.65623 .31358 m .70379 .31369 L .65213 .31356 L .454 .855 .971 r
F
.65666 .30979 m .66523 .30662 L .70953 .3139 L p .405 .816 .977 r
F P
0 g
s
.69716 .31314 m .70379 .31369 L p .69106 .31366 L .454 .855 .971 r
F P
0 g
s
.64823 .31356 m .69716 .31314 L .69106 .31366 L .454 .855 .971 r
F
.71541 .31487 m .70379 .31369 L .66 .31007 L p .405 .816 .977 r
F P
0 g
s
.66 .31007 m .65666 .30979 L p .6637 .3104 L .405 .816 .977 r
F P
0 g
s
.6637 .3104 m .71541 .31487 L .66 .31007 L .405 .816 .977 r
F
.66523 .30662 m .67392 .30395 L .72219 .31566 L p .365 .778 .98 r
F P
0 g
s
.71541 .31487 m .72723 .31688 L .76406 .34065 L p .1 .561 .911 r
F P
0 g
s
.70953 .3139 m .71541 .31487 L p .70383 .31387 L .405 .816 .977 r
F P
0 g
s
.65666 .30979 m .70953 .3139 L .70383 .31387 L .405 .816 .977 r
F
.72723 .31688 m .71541 .31487 L .66523 .30662 L p .365 .778 .98 r
F P
0 g
s
.72219 .31566 m .72723 .31688 L p .71705 .31519 L .365 .778 .98 r
F P
0 g
s
.66523 .30662 m .72219 .31566 L .71705 .31519 L .365 .778 .98 r
F
.63655 .32241 m .63171 .32326 L p .64115 .32157 L .567 .926 .945 r
F P
0 g
s
.62362 .32933 m .63171 .32326 L .67002 .31654 L p .624 .953 .925 r
F P
0 g
s
.47606 .52949 m .48859 .5181 L .48412 .52817 L p .92 .977 .749 r
F P
0 g
s
.48412 .52817 m .4701 .54284 L .47606 .52949 L p .92 .977 .749 r
F P
0 g
s
.85986 .43317 m .84411 .4208 L .82172 .37249 L p .139 .406 .853 r
F P
0 g
s
.80701 .3641 m .82172 .37249 L .84411 .4208 L p .111 .395 .849 r
F P
0 g
s
.52706 .44735 m .52666 .45433 L .51178 .47361 L p .928 .972 .743 r
F P
0 g
s
.2316 .47689 m .24462 .49515 L .23984 .5387 L p .176 .302 .755 r
F P
0 g
s
.2529 .55409 m .23984 .5387 L .24462 .49515 L p .196 .321 .765 r
F P
0 g
s
.3072 .60324 m .32131 .61087 L .33079 .63089 L p .23 .554 .932 r
F P
0 g
s
.34422 .63378 m .33079 .63089 L .32131 .61087 L p .347 .656 .97 r
F P
0 g
s
.42387 .59363 m .43867 .58144 L .4418 .58742 L p .869 .988 .829 r
F P
0 g
s
.4418 .58742 m .42769 .6008 L .42387 .59363 L p .869 .988 .829 r
F P
0 g
s
.45592 .5563 m .4701 .54284 L .46802 .55174 L p .91 .98 .773 r
F P
0 g
s
.46802 .55174 m .45339 .56737 L .45592 .5563 L p .91 .98 .773 r
F P
0 g
s
.50471 .49093 m .49771 .49354 L .51178 .47361 L p .927 .973 .736 r
F P
0 g
s
.49771 .49354 m .50471 .49093 L .49562 .50538 L p .927 .972 .743 r
F P
0 g
s
.55372 .4057 m .54953 .41596 L .52746 .44012 L p .92 .975 .763 r
F P
0 g
s
.52706 .44735 m .52746 .44012 L .54953 .41596 L p .92 .977 .748 r
F P
0 g
s
.48549 .51264 m .49562 .50538 L .48859 .5181 L p .925 .974 .747 r
F P
0 g
s
.48859 .5181 m .47606 .52949 L .48549 .51264 L p .925 .974 .747 r
F P
0 g
s
.49562 .50538 m .48549 .51264 L .49771 .49354 L p .927 .972 .743 r
F P
0 g
s
.60775 .34414 m .59995 .35292 L .56651 .37646 L p .858 .992 .834 r
F P
0 g
s
.56221 .38593 m .56651 .37646 L .59995 .35292 L p .871 .992 .812 r
F P
0 g
s
.77816 .34792 m .76406 .34065 L .72723 .31688 L p .078 .526 .902 r
F P
0 g
s
.32131 .61087 m .33561 .61614 L .34422 .63378 L p .347 .656 .97 r
F P
0 g
s
.35783 .63433 m .34422 .63378 L .33561 .61614 L p .465 .753 .992 r
F P
0 g
s
.40904 .60367 m .42387 .59363 L .42769 .6008 L p .842 .983 .868 r
F P
0 g
s
.42769 .6008 m .41358 .61217 L .40904 .60367 L p .842 .983 .868 r
F P
0 g
s
.24462 .49515 m .25778 .51282 L .2529 .55409 L p .196 .321 .765 r
F P
0 g
s
.26615 .56857 m .2529 .55409 L .25778 .51282 L p .225 .35 .781 r
F P
0 g
s
.33561 .61614 m .35008 .61889 L .35783 .63433 L p .465 .753 .992 r
F P
0 g
s
.3716 .63245 m .35783 .63433 L .35008 .61889 L p .576 .836 .994 r
F P
0 g
s
.39421 .61134 m .40904 .60367 L .41358 .61217 L p .802 .969 .909 r
F P
0 g
s
.41358 .61217 m .39951 .62132 L .39421 .61134 L p .802 .969 .909 r
F P
0 g
s
.51178 .47361 m .50834 .4709 L .52706 .44735 L p .928 .972 .743 r
F P
0 g
s
.50834 .4709 m .51178 .47361 L .49771 .49354 L p .931 .967 .753 r
F P
0 g
s
.55794 .39568 m .55372 .4057 L .52787 .43261 L p .919 .971 .778 r
F P
0 g
s
.52746 .44012 m .52787 .43261 L .55372 .4057 L p .92 .975 .763 r
F P
0 g
s
.82172 .37249 m .8366 .38074 L .85986 .43317 L p .139 .406 .853 r
F P
0 g
s
.52746 .44012 m .52706 .44735 L .50834 .4709 L p .93 .966 .758 r
F P
0 g
s
.35008 .61889 m .36469 .61902 L .3716 .63245 L p .576 .836 .994 r
F P
0 g
s
.38551 .62811 m .3716 .63245 L .36469 .61902 L p .671 .899 .978 r
F P
0 g
s
.46337 .53975 m .47606 .52949 L .4701 .54284 L p .919 .972 .775 r
F P
0 g
s
.4701 .54284 m .45592 .5563 L .46337 .53975 L p .919 .972 .775 r
F P
0 g
s
.37941 .61649 m .39421 .61134 L .39951 .62132 L p .746 .943 .947 r
F P
0 g
s
.39951 .62132 m .38551 .62811 L .37941 .61649 L p .746 .943 .947 r
F P
0 g
s
.44161 .5682 m .45592 .5563 L .45339 .56737 L p .902 .976 .804 r
F P
0 g
s
.45339 .56737 m .43867 .58144 L .44161 .5682 L p .902 .976 .804 r
F P
0 g
s
.36469 .61902 m .37941 .61649 L .38551 .62811 L p .671 .899 .978 r
F P
0 g
s
.61564 .33629 m .60775 .34414 L .57086 .3673 L p .843 .989 .857 r
F P
0 g
s
.56651 .37646 m .57086 .3673 L .60775 .34414 L p .858 .992 .834 r
F P
0 g
s
.49771 .49354 m .49061 .49537 L .50834 .4709 L p .931 .967 .753 r
F P
0 g
s
.49061 .49537 m .49771 .49354 L .48549 .51264 L p .931 .964 .762 r
F P
0 g
s
.79248 .35582 m .77816 .34792 L .73923 .31953 L p .072 .503 .898 r
F P
0 g
s
.72723 .31688 m .73923 .31953 L .77816 .34792 L p .078 .526 .902 r
F P
0 g
s
.47522 .51891 m .48549 .51264 L .47606 .52949 L p .926 .966 .77 r
F P
0 g
s
.47606 .52949 m .46337 .53975 L .47522 .51891 L p .926 .966 .77 r
F P
0 g
s
.25778 .51282 m .2711 .52957 L .26615 .56857 L p .225 .35 .781 r
F P
0 g
s
.27962 .58181 m .26615 .56857 L .2711 .52957 L p .264 .387 .801 r
F P
0 g
s
.56221 .38593 m .55794 .39568 L .52828 .42479 L p .916 .966 .793 r
F P
0 g
s
.52787 .43261 m .52828 .42479 L .55794 .39568 L p .919 .971 .778 r
F P
0 g
s
.48549 .51264 m .47522 .51891 L .49061 .49537 L p .931 .964 .762 r
F P
0 g
s
.42719 .57825 m .44161 .5682 L .43867 .58144 L p .887 .966 .837 r
F P
0 g
s
.43867 .58144 m .42387 .59363 L .42719 .57825 L p .887 .966 .837 r
F P
0 g
s
.62362 .32933 m .61564 .33629 L .57526 .35844 L p .825 .984 .88 r
F P
0 g
s
.57086 .3673 m .57526 .35844 L .61564 .33629 L p .843 .989 .857 r
F P
0 g
s
.52787 .43261 m .52746 .44012 L .50486 .46754 L p .931 .957 .772 r
F P
0 g
s
.50834 .4709 m .50486 .46754 L .52746 .44012 L p .93 .966 .758 r
F P
0 g
s
.20592 .44005 m .19318 .42214 L .22154 .37026 L p .365 .386 .749 r
F P
0 g
s
.50486 .46754 m .50834 .4709 L .49061 .49537 L p .933 .956 .769 r
F P
0 g
s
.45053 .54856 m .46337 .53975 L .45592 .5563 L p .913 .962 .802 r
F P
0 g
s
.45592 .5563 m .44161 .5682 L .45053 .54856 L p .913 .962 .802 r
F P
0 g
s
.2711 .52957 m .28461 .54503 L .27962 .58181 L p .264 .387 .801 r
F P
0 g
s
.2933 .59346 m .27962 .58181 L .28461 .54503 L p .312 .434 .825 r
F P
0 g
s
.56651 .37646 m .56221 .38593 L .5287 .41665 L p .911 .958 .808 r
F P
0 g
s
.52828 .42479 m .5287 .41665 L .56221 .38593 L p .916 .966 .793 r
F P
0 g
s
.4127 .58616 m .42719 .57825 L .42387 .59363 L p .862 .948 .869 r
F P
0 g
s
.42387 .59363 m .40904 .60367 L .4127 .58616 L p .862 .948 .869 r
F P
0 g
s
.22154 .37026 m .23362 .38955 L .20592 .44005 L p .365 .386 .749 r
F P
0 g
s
.21871 .45842 m .20592 .44005 L .23362 .38955 L p .367 .383 .745 r
F P
0 g
s
.63171 .32326 m .62362 .32933 L .57971 .34988 L p .804 .976 .902 r
F P
0 g
s
.57526 .35844 m .57971 .34988 L .62362 .32933 L p .825 .984 .88 r
F P
0 g
s
.80701 .3641 m .79248 .35582 L .75142 .32265 L p .082 .492 .897 r
F P
0 g
s
.73923 .31953 m .75142 .32265 L .79248 .35582 L p .072 .503 .898 r
F P
0 g
s
.49061 .49537 m .48342 .49621 L .50486 .46754 L p .933 .956 .769 r
F P
0 g
s
.48342 .49621 m .49061 .49537 L .47522 .51891 L p .929 .95 .781 r
F P
0 g
s
.46483 .52393 m .47522 .51891 L .46337 .53975 L p .922 .951 .793 r
F P
0 g
s
.46337 .53975 m .45053 .54856 L .46483 .52393 L p .922 .951 .793 r
F P
0 g
s
.28461 .54503 m .29829 .55889 L .2933 .59346 L p .312 .434 .825 r
F P
0 g
s
.3072 .60324 m .2933 .59346 L .29829 .55889 L p .369 .49 .851 r
F P
0 g
s
.52828 .42479 m .52787 .43261 L .50133 .46344 L p .928 .944 .785 r
F P
0 g
s
.50486 .46754 m .50133 .46344 L .52787 .43261 L p .931 .957 .772 r
F P
0 g
s
.47522 .51891 m .46483 .52393 L .48342 .49621 L p .929 .95 .781 r
F P
0 g
s
.39817 .59172 m .4127 .58616 L .40904 .60367 L p .827 .919 .898 r
F P
0 g
s
.40904 .60367 m .39421 .61134 L .39817 .59172 L p .827 .919 .898 r
F P
0 g
s
.43757 .55564 m .45053 .54856 L .44161 .5682 L p .9 .943 .828 r
F P
0 g
s
.44161 .5682 m .42719 .57825 L .43757 .55564 L p .9 .943 .828 r
F P
0 g
s
.50133 .46344 m .50486 .46754 L .48342 .49621 L p .93 .939 .783 r
F P
0 g
s
.57086 .3673 m .56651 .37646 L .52911 .40817 L p .903 .948 .822 r
F P
0 g
s
.5287 .41665 m .52911 .40817 L .56651 .37646 L p .911 .958 .808 r
F P
0 g
s
.23362 .38955 m .24572 .4092 L .21871 .45842 L p .367 .383 .745 r
F P
0 g
s
.2316 .47689 m .21871 .45842 L .24572 .4092 L p .375 .386 .744 r
F P
0 g
s
.29829 .55889 m .31216 .57085 L .3072 .60324 L p .369 .49 .851 r
F P
0 g
s
.32131 .61087 m .3072 .60324 L .31216 .57085 L p .434 .553 .877 r
F P
0 g
s
.63991 .31803 m .63171 .32326 L .5842 .34161 L p .781 .964 .923 r
F P
0 g
s
.57971 .34988 m .5842 .34161 L .63171 .32326 L p .804 .976 .902 r
F P
0 g
s
.38364 .59476 m .39817 .59172 L .39421 .61134 L p .779 .878 .919 r
F P
0 g
s
.39421 .61134 m .37941 .61649 L .38364 .59476 L p .779 .878 .919 r
F P
0 g
s
.31216 .57085 m .3262 .58064 L .32131 .61087 L p .434 .553 .877 r
F P
0 g
s
.33561 .61614 m .32131 .61087 L .3262 .58064 L p .505 .621 .9 r
F P
0 g
s
.5287 .41665 m .52828 .42479 L .49778 .4585 L p .922 .927 .796 r
F P
0 g
s
.50133 .46344 m .49778 .4585 L .52828 .42479 L p .928 .944 .785 r
F P
0 g
s
.82172 .37249 m .80701 .3641 L .76379 .32603 L p .105 .49 .901 r
F P
0 g
s
.75142 .32265 m .76379 .32603 L .80701 .3641 L p .082 .492 .897 r
F P
0 g
s
.36915 .59517 m .38364 .59476 L .37941 .61649 L p .72 .824 .93 r
F P
0 g
s
.37941 .61649 m .36469 .61902 L .36915 .59517 L p .72 .824 .93 r
F P
0 g
s
.24572 .4092 m .25788 .42893 L .2316 .47689 L p .375 .386 .744 r
F P
0 g
s
.24462 .49515 m .2316 .47689 L .25788 .42893 L p .387 .395 .746 r
F P
0 g
s
.3262 .58064 m .3404 .58805 L .33561 .61614 L p .505 .621 .9 r
F P
0 g
s
.35008 .61889 m .33561 .61614 L .3404 .58805 L p .579 .692 .919 r
F P
0 g
s
.45432 .52746 m .46483 .52393 L .45053 .54856 L p .911 .928 .812 r
F P
0 g
s
.45053 .54856 m .43757 .55564 L .45432 .52746 L p .911 .928 .812 r
F P
0 g
s
.35472 .59293 m .36915 .59517 L .36469 .61902 L p .652 .761 .93 r
F P
0 g
s
.36469 .61902 m .35008 .61889 L .35472 .59293 L p .652 .761 .93 r
F P
0 g
s
.48342 .49621 m .47615 .4959 L .50133 .46344 L p .93 .939 .783 r
F P
0 g
s
.47615 .4959 m .48342 .49621 L .46483 .52393 L p .922 .928 .796 r
F P
0 g
s
.3404 .58805 m .35472 .59293 L .35008 .61889 L p .579 .692 .919 r
F P
0 g
s
.42452 .56074 m .43757 .55564 L .42719 .57825 L p .877 .914 .849 r
F P
0 g
s
.42719 .57825 m .4127 .58616 L .42452 .56074 L p .877 .914 .849 r
F P
0 g
s
.57526 .35844 m .57086 .3673 L .52954 .39934 L p .894 .936 .835 r
F P
0 g
s
.52911 .40817 m .52954 .39934 L .57086 .3673 L p .903 .948 .822 r
F P
0 g
s
.46483 .52393 m .45432 .52746 L .47615 .4959 L p .922 .928 .796 r
F P
0 g
s
.49778 .4585 m .50133 .46344 L .47615 .4959 L p .922 .917 .794 r
F P
0 g
s
.64823 .31356 m .63991 .31803 L .58875 .3336 L p .756 .949 .941 r
F P
0 g
s
.5842 .34161 m .58875 .3336 L .63991 .31803 L p .781 .964 .923 r
F P
0 g
s
.25788 .42893 m .27011 .4484 L .24462 .49515 L p .387 .395 .746 r
F P
0 g
s
.25778 .51282 m .24462 .49515 L .27011 .4484 L p .404 .41 .752 r
F P
0 g
s
.52911 .40817 m .5287 .41665 L .49418 .45266 L p .912 .908 .804 r
F P
0 g
s
.49778 .4585 m .49418 .45266 L .5287 .41665 L p .922 .927 .796 r
F P
0 g
s
.73923 .31953 m .72723 .31688 L .67392 .30395 L p .336 .744 .98 r
F P
0 g
s
.4114 .56366 m .42452 .56074 L .4127 .58616 L p .845 .876 .864 r
F P
0 g
s
.4127 .58616 m .39817 .59172 L .4114 .56366 L p .845 .876 .864 r
F P
0 g
s
.57971 .34988 m .57526 .35844 L .52996 .39016 L p .882 .922 .847 r
F P
0 g
s
.52954 .39934 m .52996 .39016 L .57526 .35844 L p .894 .936 .835 r
F P
0 g
s
.8366 .38074 m .82172 .37249 L .77632 .32946 L p .139 .498 .907 r
F P
0 g
s
.76379 .32603 m .77632 .32946 L .82172 .37249 L p .105 .49 .901 r
F P
0 g
s
.44372 .5293 m .45432 .52746 L .43757 .55564 L p .891 .896 .825 r
F P
0 g
s
.43757 .55564 m .42452 .56074 L .44372 .5293 L p .891 .896 .825 r
F P
0 g
s
.27011 .4484 m .28243 .4673 L .25778 .51282 L p .404 .41 .752 r
F P
0 g
s
.2711 .52957 m .25778 .51282 L .28243 .4673 L p .426 .43 .76 r
F P
0 g
s
.47615 .4959 m .46881 .49428 L .49778 .4585 L p .922 .917 .794 r
F P
0 g
s
.46881 .49428 m .47615 .4959 L .45432 .52746 L p .907 .898 .807 r
F P
0 g
s
.49418 .45266 m .49778 .4585 L .46881 .49428 L p .909 .89 .8 r
F P
0 g
s
.65666 .30979 m .64823 .31356 L .59335 .32584 L p .729 .93 .956 r
F P
0 g
s
.58875 .3336 m .59335 .32584 L .64823 .31356 L p .756 .949 .941 r
F P
0 g
s
.45432 .52746 m .44372 .5293 L .46881 .49428 L p .907 .898 .807 r
F P
0 g
s
.39824 .56424 m .4114 .56366 L .39817 .59172 L p .805 .829 .87 r
F P
0 g
s
.39817 .59172 m .38364 .59476 L .39824 .56424 L p .805 .829 .87 r
F P
0 g
s
.52954 .39934 m .52911 .40817 L .49056 .44586 L p .9 .885 .809 r
F P
0 g
s
.49418 .45266 m .49056 .44586 L .52911 .40817 L p .912 .908 .804 r
F P
0 g
s
.28243 .4673 m .29487 .48529 L .2711 .52957 L p .426 .43 .76 r
F P
0 g
s
.28461 .54503 m .2711 .52957 L .29487 .48529 L p .454 .456 .771 r
F P
0 g
s
.5842 .34161 m .57971 .34988 L .53039 .38062 L p .867 .905 .856 r
F P
0 g
s
.52996 .39016 m .53039 .38062 L .57971 .34988 L p .882 .922 .847 r
F P
0 g
s
.75142 .32265 m .73923 .31953 L .68274 .30165 L p .319 .716 .98 r
F P
0 g
s
.67392 .30395 m .68274 .30165 L .73923 .31953 L p .336 .744 .98 r
F P
0 g
s
.43303 .52926 m .44372 .5293 L .42452 .56074 L p .865 .857 .832 r
F P
0 g
s
.42452 .56074 m .4114 .56366 L .43303 .52926 L p .865 .857 .832 r
F P
0 g
s
.38508 .56239 m .39824 .56424 L .38364 .59476 L p .758 .777 .868 r
F P
0 g
s
.38364 .59476 m .36915 .59517 L .38508 .56239 L p .758 .777 .868 r
F P
0 g
s
.29487 .48529 m .30743 .50205 L .28461 .54503 L p .454 .456 .771 r
F P
0 g
s
.29829 .55889 m .28461 .54503 L .30743 .50205 L p .486 .487 .784 r
F P
0 g
s
.77632 .32946 m .78901 .33274 L .8366 .38074 L p .139 .498 .907 r
F P
0 g
s
.46881 .49428 m .4614 .49123 L .49418 .45266 L p .909 .89 .8 r
F P
0 g
s
.4614 .49123 m .46881 .49428 L .44372 .5293 L p .887 .864 .811 r
F P
0 g
s
.49056 .44586 m .49418 .45266 L .4614 .49123 L p .891 .859 .803 r
F P
0 g
s
.66523 .30662 m .65666 .30979 L .59801 .31828 L p .702 .908 .968 r
F P
0 g
s
.59335 .32584 m .59801 .31828 L .65666 .30979 L p .729 .93 .956 r
F P
0 g
s
.30743 .50205 m .32012 .51728 L .29829 .55889 L p .486 .487 .784 r
F P
0 g
s
.31216 .57085 m .29829 .55889 L .32012 .51728 L p .522 .525 .799 r
F P
0 g
s
.37194 .55805 m .38508 .56239 L .36915 .59517 L p .709 .722 .86 r
F P
0 g
s
.36915 .59517 m .35472 .59293 L .37194 .55805 L p .709 .722 .86 r
F P
0 g
s
.52996 .39016 m .52954 .39934 L .4869 .43806 L p .885 .862 .812 r
F P
0 g
s
.49056 .44586 m .4869 .43806 L .52954 .39934 L p .9 .885 .809 r
F P
0 g
s
.44372 .5293 m .43303 .52926 L .4614 .49123 L p .887 .864 .811 r
F P
0 g
s
.58875 .3336 m .5842 .34161 L .53083 .37072 L p .851 .888 .864 r
F P
0 g
s
.53039 .38062 m .53083 .37072 L .5842 .34161 L p .867 .905 .856 r
F P
0 g
s
.32012 .51728 m .33292 .53071 L .31216 .57085 L p .522 .525 .799 r
F P
0 g
s
.3262 .58064 m .31216 .57085 L .33292 .53071 L p .564 .568 .816 r
F P
0 g
s
.35885 .55126 m .37194 .55805 L .35472 .59293 L p .658 .668 .848 r
F P
0 g
s
.35472 .59293 m .3404 .58805 L .35885 .55126 L p .658 .668 .848 r
F P
0 g
s
.33292 .53071 m .34584 .5421 L .3262 .58064 L p .564 .568 .816 r
F P
0 g
s
.3404 .58805 m .3262 .58064 L .34584 .5421 L p .609 .616 .832 r
F P
0 g
s
.34584 .5421 m .35885 .55126 L .3404 .58805 L p .609 .616 .832 r
F P
0 g
s
.4223 .52722 m .43303 .52926 L .4114 .56366 L p .832 .813 .832 r
F P
0 g
s
.4114 .56366 m .39824 .56424 L .4223 .52722 L p .832 .813 .832 r
F P
0 g
s
.76379 .32603 m .75142 .32265 L .69169 .29961 L p .313 .693 .979 r
F P
0 g
s
.68274 .30165 m .69169 .29961 L .75142 .32265 L p .319 .716 .98 r
F P
0 g
s
.23362 .38955 m .22154 .37026 L .27399 .32374 L p .494 .456 .744 r
F P
0 g
s
.4614 .49123 m .45394 .48665 L .49056 .44586 L p .891 .859 .803 r
F P
0 g
s
.45394 .48665 m .4614 .49123 L .43303 .52926 L p .862 .826 .811 r
F P
0 g
s
.4869 .43806 m .49056 .44586 L .45394 .48665 L p .871 .827 .802 r
F P
0 g
s
.53039 .38062 m .52996 .39016 L .48322 .42925 L p .868 .837 .813 r
F P
0 g
s
.4869 .43806 m .48322 .42925 L .52996 .39016 L p .885 .862 .812 r
F P
0 g
s
.27399 .32374 m .2844 .34321 L .23362 .38955 L p .494 .456 .744 r
F P
0 g
s
.24572 .4092 m .23362 .38955 L .2844 .34321 L p .5 .456 .739 r
F P
0 g
s
.67392 .30395 m .66523 .30662 L .60273 .3109 L p .675 .884 .975 r
F P
0 g
s
.59801 .31828 m .60273 .3109 L .66523 .30662 L p .702 .908 .968 r
F P
0 g
s
.43303 .52926 m .4223 .52722 L .45394 .48665 L p .862 .826 .811 r
F P
0 g
s
.59335 .32584 m .58875 .3336 L .53127 .36049 L p .834 .869 .87 r
F P
0 g
s
.53083 .37072 m .53127 .36049 L .58875 .3336 L p .851 .888 .864 r
F P
0 g
s
.41152 .5231 m .4223 .52722 L .39824 .56424 L p .796 .767 .827 r
F P
0 g
s
.39824 .56424 m .38508 .56239 L .41152 .5231 L p .796 .767 .827 r
F P
0 g
s
.2844 .34321 m .29479 .36293 L .24572 .4092 L p .5 .456 .739 r
F P
0 g
s
.25788 .42893 m .24572 .4092 L .29479 .36293 L p .509 .46 .737 r
F P
0 g
s
.29479 .36293 m .30519 .38266 L .25788 .42893 L p .509 .46 .737 r
F P
0 g
s
.27011 .4484 m .25788 .42893 L .30519 .38266 L p .52 .467 .738 r
F P
0 g
s
.40074 .51685 m .41152 .5231 L .38508 .56239 L p .758 .721 .818 r
F P
0 g
s
.38508 .56239 m .37194 .55805 L .40074 .51685 L p .758 .721 .818 r
F P
0 g
s
.77632 .32946 m .76379 .32603 L .70077 .29768 L p .318 .676 .977 r
F P
0 g
s
.69169 .29961 m .70077 .29768 L .76379 .32603 L p .313 .693 .979 r
F P
0 g
s
.48322 .42925 m .4869 .43806 L .44643 .48047 L p .849 .795 .798 r
F P
0 g
s
.45394 .48665 m .44643 .48047 L .4869 .43806 L p .871 .827 .802 r
F P
0 g
s
.44643 .48047 m .45394 .48665 L .4223 .52722 L p .834 .786 .806 r
F P
0 g
s
.53083 .37072 m .53039 .38062 L .47952 .41943 L p .85 .813 .813 r
F P
0 g
s
.48322 .42925 m .47952 .41943 L .53039 .38062 L p .868 .837 .813 r
F P
0 g
s
.4223 .52722 m .41152 .5231 L .44643 .48047 L p .834 .786 .806 r
F P
0 g
s
.30519 .38266 m .31561 .40212 L .27011 .4484 L p .52 .467 .738 r
F P
0 g
s
.28243 .4673 m .27011 .4484 L .31561 .40212 L p .535 .479 .74 r
F P
0 g
s
.68274 .30165 m .67392 .30395 L .60751 .30364 L p .649 .858 .979 r
F P
0 g
s
.60273 .3109 m .60751 .30364 L .67392 .30395 L p .675 .884 .975 r
F P
0 g
s
.59801 .31828 m .59335 .32584 L .53171 .34994 L p .815 .849 .875 r
F P
0 g
s
.53127 .36049 m .53171 .34994 L .59335 .32584 L p .834 .869 .87 r
F P
0 g
s
.38995 .50851 m .40074 .51685 L .37194 .55805 L p .721 .677 .807 r
F P
0 g
s
.37194 .55805 m .35885 .55126 L .38995 .50851 L p .721 .677 .807 r
F P
0 g
s
.31561 .40212 m .32607 .42103 L .28243 .4673 L p .535 .479 .74 r
F P
0 g
s
.29487 .48529 m .28243 .4673 L .32607 .42103 L p .552 .495 .745 r
F P
0 g
s
.37919 .49813 m .38995 .50851 L .35885 .55126 L p .686 .636 .794 r
F P
0 g
s
.35885 .55126 m .34584 .5421 L .37919 .49813 L p .686 .636 .794 r
F P
0 g
s
.32607 .42103 m .33659 .43911 L .29487 .48529 L p .552 .495 .745 r
F P
0 g
s
.30743 .50205 m .29487 .48529 L .33659 .43911 L p .573 .515 .752 r
F P
0 g
s
.47952 .41943 m .48322 .42925 L .43889 .47269 L p .827 .764 .793 r
F P
0 g
s
.44643 .48047 m .43889 .47269 L .48322 .42925 L p .849 .795 .798 r
F P
0 g
s
.43889 .47269 m .44643 .48047 L .41152 .5231 L p .805 .747 .799 r
F P
0 g
s
.41152 .5231 m .40074 .51685 L .43889 .47269 L p .805 .747 .799 r
F P
0 g
s
.53127 .36049 m .53083 .37072 L .47579 .40863 L p .832 .789 .811 r
F P
0 g
s
.47952 .41943 m .47579 .40863 L .53083 .37072 L p .85 .813 .813 r
F P
0 g
s
.33659 .43911 m .34715 .4561 L .30743 .50205 L p .573 .515 .752 r
F P
0 g
s
.32012 .51728 m .30743 .50205 L .34715 .4561 L p .596 .539 .76 r
F P
0 g
s
.36846 .48582 m .37919 .49813 L .34584 .5421 L p .653 .599 .782 r
F P
0 g
s
.34584 .5421 m .33292 .53071 L .36846 .48582 L p .653 .599 .782 r
F P
0 g
s
.34715 .4561 m .35778 .47175 L .32012 .51728 L p .596 .539 .76 r
F P
0 g
s
.33292 .53071 m .32012 .51728 L .35778 .47175 L p .623 .567 .771 r
F P
0 g
s
.35778 .47175 m .36846 .48582 L .33292 .53071 L p .623 .567 .771 r
F P
0 g
s
.78901 .33274 m .77632 .32946 L .70996 .29573 L p .332 .665 .974 r
F P
0 g
s
.70077 .29768 m .70996 .29573 L .77632 .32946 L p .318 .676 .977 r
F P
0 g
s
.60273 .3109 m .59801 .31828 L .53215 .33909 L p .795 .83 .878 r
F P
0 g
s
.53171 .34994 m .53215 .33909 L .59801 .31828 L p .815 .849 .875 r
F P
0 g
s
.69169 .29961 m .68274 .30165 L .61234 .29645 L p .625 .832 .98 r
F P
0 g
s
.60751 .30364 m .61234 .29645 L .68274 .30165 L p .649 .858 .979 r
F P
0 g
s
.43133 .46329 m .43889 .47269 L .40074 .51685 L p .776 .711 .79 r
F P
0 g
s
.40074 .51685 m .38995 .50851 L .43133 .46329 L p .776 .711 .79 r
F P
0 g
s
.43889 .47269 m .43133 .46329 L .47952 .41943 L p .827 .764 .793 r
F P
0 g
s
.47579 .40863 m .47952 .41943 L .43133 .46329 L p .804 .735 .787 r
F P
0 g
s
.53171 .34994 m .53127 .36049 L .47205 .39689 L p .813 .767 .81 r
F P
0 g
s
.47579 .40863 m .47205 .39689 L .53127 .36049 L p .832 .789 .811 r
F P
0 g
s
.42375 .45233 m .43133 .46329 L .38995 .50851 L p .749 .676 .781 r
F P
0 g
s
.38995 .50851 m .37919 .49813 L .42375 .45233 L p .749 .676 .781 r
F P
0 g
s
.60751 .30364 m .60273 .3109 L .5326 .32796 L p .775 .81 .881 r
F P
0 g
s
.53215 .33909 m .5326 .32796 L .60273 .3109 L p .795 .83 .878 r
F P
0 g
s
.70996 .29573 m .71927 .29362 L .78901 .33274 L p .332 .665 .974 r
F P
0 g
s
.43133 .46329 m .42375 .45233 L .47579 .40863 L p .804 .735 .787 r
F P
0 g
s
.47205 .39689 m .47579 .40863 L .42375 .45233 L p .782 .708 .781 r
F P
0 g
s
.70077 .29768 m .69169 .29961 L .61723 .2893 L p .605 .807 .977 r
F P
0 g
s
.61234 .29645 m .61723 .2893 L .69169 .29961 L p .625 .832 .98 r
F P
0 g
s
.41616 .43989 m .42375 .45233 L .37919 .49813 L p .723 .646 .772 r
F P
0 g
s
.37919 .49813 m .36846 .48582 L .41616 .43989 L p .723 .646 .772 r
F P
0 g
s
.53215 .33909 m .53171 .34994 L .46829 .38428 L p .795 .746 .808 r
F P
0 g
s
.47205 .39689 m .46829 .38428 L .53171 .34994 L p .813 .767 .81 r
F P
0 g
s
.40858 .42609 m .41616 .43989 L .36846 .48582 L p .699 .619 .763 r
F P
0 g
s
.36846 .48582 m .35778 .47175 L .40858 .42609 L p .699 .619 .763 r
F P
0 g
s
.42375 .45233 m .41616 .43989 L .47205 .39689 L p .782 .708 .781 r
F P
0 g
s
.40099 .41106 m .40858 .42609 L .35778 .47175 L p .677 .595 .756 r
F P
0 g
s
.35778 .47175 m .34715 .4561 L .40099 .41106 L p .677 .595 .756 r
F P
0 g
s
.2844 .34321 m .27399 .32374 L .34782 .287 L p .583 .52 .75 r
F P
0 g
s
.46829 .38428 m .47205 .39689 L .41616 .43989 L p .762 .683 .775 r
F P
0 g
s
.61234 .29645 m .60751 .30364 L .53306 .31659 L p .756 .792 .882 r
F P
0 g
s
.5326 .32796 m .53306 .31659 L .60751 .30364 L p .775 .81 .881 r
F P
0 g
s
.34782 .287 m .35547 .30533 L .2844 .34321 L p .583 .52 .75 r
F P
0 g
s
.29479 .36293 m .2844 .34321 L .35547 .30533 L p .591 .521 .745 r
F P
0 g
s
.39341 .39496 m .40099 .41106 L .34715 .4561 L p .658 .575 .75 r
F P
0 g
s
.34715 .4561 m .33659 .43911 L .39341 .39496 L p .658 .575 .75 r
F P
0 g
s
.35547 .30533 m .36308 .32379 L .29479 .36293 L p .591 .521 .745 r
F P
0 g
s
.30519 .38266 m .29479 .36293 L .36308 .32379 L p .601 .525 .742 r
F P
0 g
s
.36308 .32379 m .37068 .3422 L .30519 .38266 L p .601 .525 .742 r
F P
0 g
s
.31561 .40212 m .30519 .38266 L .37068 .3422 L p .612 .533 .741 r
F P
0 g
s
.38583 .37799 m .39341 .39496 L .33659 .43911 L p .641 .558 .745 r
F P
0 g
s
.33659 .43911 m .32607 .42103 L .38583 .37799 L p .641 .558 .745 r
F P
0 g
s
.37068 .3422 m .37826 .36033 L .31561 .40212 L p .612 .533 .741 r
F P
0 g
s
.32607 .42103 m .31561 .40212 L .37826 .36033 L p .625 .544 .742 r
F P
0 g
s
.37826 .36033 m .38583 .37799 L .32607 .42103 L p .625 .544 .742 r
F P
0 g
s
.5326 .32796 m .53215 .33909 L .46451 .37088 L p .777 .727 .806 r
F P
0 g
s
.46829 .38428 m .46451 .37088 L .53215 .33909 L p .795 .746 .808 r
F P
0 g
s
.41616 .43989 m .40858 .42609 L .46829 .38428 L p .762 .683 .775 r
F P
0 g
s
.70996 .29573 m .70077 .29768 L .62219 .28211 L p .588 .783 .973 r
F P
0 g
s
.61723 .2893 m .62219 .28211 L .70077 .29768 L p .605 .807 .977 r
F P
0 g
s
.46451 .37088 m .46829 .38428 L .40858 .42609 L p .743 .662 .77 r
F P
0 g
s
.40858 .42609 m .40099 .41106 L .46451 .37088 L p .743 .662 .77 r
F P
0 g
s
.61723 .2893 m .61234 .29645 L .53351 .30499 L p .736 .774 .883 r
F P
0 g
s
.53306 .31659 m .53351 .30499 L .61234 .29645 L p .756 .792 .882 r
F P
0 g
s
.53306 .31659 m .5326 .32796 L .46072 .35678 L p .76 .71 .805 r
F P
0 g
s
.46451 .37088 m .46072 .35678 L .5326 .32796 L p .777 .727 .806 r
F P
0 g
s
.46072 .35678 m .46451 .37088 L .40099 .41106 L p .725 .643 .766 r
F P
0 g
s
.40099 .41106 m .39341 .39496 L .46072 .35678 L p .725 .643 .766 r
F P
0 g
s
.71927 .29362 m .70996 .29573 L .6272 .27484 L p .575 .762 .967 r
F P
0 g
s
.62219 .28211 m .6272 .27484 L .70996 .29573 L p .588 .783 .973 r
F P
0 g
s
.45691 .34208 m .46072 .35678 L .39341 .39496 L p .709 .626 .763 r
F P
0 g
s
.39341 .39496 m .38583 .37799 L .45691 .34208 L p .709 .626 .763 r
F P
0 g
s
.53351 .30499 m .53306 .31659 L .45691 .34208 L p .744 .695 .805 r
F P
0 g
s
.46072 .35678 m .45691 .34208 L .53306 .31659 L p .76 .71 .805 r
F P
0 g
s
.45308 .32691 m .45691 .34208 L .38583 .37799 L p .694 .613 .761 r
F P
0 g
s
.38583 .37799 m .37826 .36033 L .45308 .32691 L p .694 .613 .761 r
F P
0 g
s
.62219 .28211 m .61723 .2893 L .53397 .29322 L p .717 .757 .884 r
F P
0 g
s
.53351 .30499 m .53397 .29322 L .61723 .2893 L p .736 .774 .883 r
F P
0 g
s
.44923 .31139 m .45308 .32691 L .37826 .36033 L p .68 .602 .761 r
F P
0 g
s
.37826 .36033 m .37068 .3422 L .44923 .31139 L p .68 .602 .761 r
F P
0 g
s
.44536 .29563 m .44923 .31139 L .37068 .3422 L p .668 .593 .763 r
F P
0 g
s
.37068 .3422 m .36308 .32379 L .44536 .29563 L p .668 .593 .763 r
F P
0 g
s
.45691 .34208 m .45308 .32691 L .53351 .30499 L p .744 .695 .805 r
F P
0 g
s
.53397 .29322 m .53351 .30499 L .45308 .32691 L p .728 .682 .805 r
F P
0 g
s
.6272 .27484 m .63227 .26744 L .71927 .29362 L p .575 .762 .967 r
F P
0 g
s
.44147 .27977 m .44536 .29563 L .36308 .32379 L p .657 .588 .766 r
F P
0 g
s
.36308 .32379 m .35547 .30533 L .44147 .27977 L p .657 .588 .766 r
F P
0 g
s
.6272 .27484 m .62219 .28211 L .53444 .28129 L p .699 .742 .885 r
F P
0 g
s
.53397 .29322 m .53444 .28129 L .62219 .28211 L p .717 .757 .884 r
F P
0 g
s
.43754 .26392 m .44147 .27977 L .35547 .30533 L p .647 .584 .771 r
F P
0 g
s
.35547 .30533 m .34782 .287 L .43754 .26392 L p .647 .584 .771 r
F P
0 g
s
.45308 .32691 m .44923 .31139 L .53397 .29322 L p .728 .682 .805 r
F P
0 g
s
.53444 .28129 m .53397 .29322 L .44923 .31139 L p .713 .671 .807 r
F P
0 g
s
.44923 .31139 m .44536 .29563 L .53444 .28129 L p .713 .671 .807 r
F P
0 g
s
.63227 .26744 m .6272 .27484 L .53491 .26926 L p .682 .728 .886 r
F P
0 g
s
.53444 .28129 m .53491 .26926 L .6272 .27484 L p .699 .742 .885 r
F P
0 g
s
.53491 .26926 m .53444 .28129 L .44536 .29563 L p .699 .662 .81 r
F P
0 g
s
.44536 .29563 m .44147 .27977 L .53491 .26926 L p .699 .662 .81 r
F P
0 g
s
.53539 .25714 m .53491 .26926 L .44147 .27977 L p .686 .655 .814 r
F P
0 g
s
.44147 .27977 m .43754 .26392 L .53539 .25714 L p .686 .655 .814 r
F P
0 g
s
.53491 .26926 m .53539 .25714 L .63227 .26744 L p .682 .728 .886 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojnWd003o`00
0?n^^^;o[[[R00?o[[[R2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo0_l00002ooooo`03o`000?oooooooooo07Sooooo2_l0000HojnWd003o`000?n^
^^;o[[[R00ko[[[R2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_oo
ool002cooooo0_l00004ooooo`03o`000?oooooooooo07?ooooo1?l00002ojFEa@03o`000?n_Ym3o
[jO@01go[jO@00?o0000ojjjh_n^^^806On^^^87o`0001?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06oooooo0ol00006ojFEa@03o`000?n_Ym3o[jO@01So[jO@1_l0000OojjjhP03o`000?nC`oOoTl?g
00?o00004?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02gooooo000/ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0J_ooool4o`0000[oYIG500?o0000ojnWd?n_
Ym003?n_Ym0;o`0000Go/ZW?00?o0000ok:mh_nb_N801_nb_N8?o`0000Oo[[[R00?o0000oi?3monC
`oL01?nC`oL3o`0000gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00
;?ooool3o`0000Kooooo00?o0000ooooooooool0IOooool4o`0000koYIG500?o0000ojnWd?n_Ym00
1?n_Ym08o`00013o/ZW?00?o0000ok:mh_nb_N805Onb_N87o`0000[oTl?g0ol0000:ooooo`03o`00
0?oooooooooo03;ooooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo063ooooo1?l0000@ojFEa@?o000000Co[jO@o`000?l0003o00006_nbZLl00ol0003o/[gR
ok:mhP0Jok:mhP05o`000?nFb?WoU/SioiK8nOl000002_nC`oL3o`0000Oooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0[ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05cooooo0ol0000AojFEa@?o00000_nXU/@00ol0003o/ZW?ok:Yc`0Iok:Y
c`Co00001onb_N8Eo`0000SoU/Si0_l00008oi?3m`?o00001Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02[ooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05Oooooo1?l0000AojFEa@?o00001OnXU/@00ol0003o/ZW?ok:Yc`0Cok:Yc`Ko00000onfZlh00ol0
003o]l7RokO1hP0IokO1hP04o`000?nJc_[oV/kjoi[>nPWoU/Si0ol00006oi?3m`?o00000_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo0009ooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000
ooooooooool0Doooool3o`0001;oYIG50ol00008ojRFa003o`000?nbZLoo/ZW?00go/ZW?1_l00009
okJ[cP03o`000?ng`N;o]l7R017o]l7R2?l00009oi[>nP03o`000?nFb?WoU/Si00GoU/Si0ol00005
oi?3m`?o0000=_ooool00ol0003oooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo053ooooo0_l000000onEQKoo0000ojFEa@0?ojFEa@?o00003?nXU/@00ol0003o/ZW?ok:Yc`06
ok:Yc`Ko00003_nfZlh00ol0003o]l7RokO1hP08okO1hP[o00001onla^801?l0003oWmCjoioDn_nO
e?X2o`0000WoV/kj0_l00004oiK8n@Co00000onC`oL4o`0003Cooooo00?o0000ooooooooool0:?oo
ool0017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04gooooo0_l00004oiF5_`03o`00
0?nUULGoYIG500[oYIG50ol0000?ojRFa003o`000?nbZLoo/ZW?00;o/ZW?1?l0000BokJ[cP?o0000
0ong`N83o`0001Co_<KR00?o0000oioDn_nOe?X02?nOe?X5o`0000GoV/kj0_l00003oiK8n@Co0000
0onC`oL3o`00037ooooo0_l0000Yooooo`004Oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000ooooooooool0B_ooool2o`0000KoUHFo
00?o0000ojFEaOnUULD01onUULD3o`00017oZ9K40_l000000onbZLoo0000okJ[cP0BokJ[cPGo0000
0_nj[/h00ol0003o_<KRokc6hP0Cokc6hPGo00004OnOe?X6o`0000?oV/kj1ol00003oeBZn@;o0000
;oooool2o`0002Wooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool2o`0000WoUHFo
00?o0000ojFEaOnUULD00onUULD3o`00017oZ9K40ol000000on[Ul?o0000okJ[cP0@okJ[cPCo0000
1onj[/h00ol0003o_<KRokc6hP0:okc6hPWo00001?o1b^400ol0003oY]_jojKKnP04ojKKnPOo0000
2_nOe?X4o`0000;oD;7j00Co0000oe6]n_mA[O[oDJgj1OmDZ_T00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02Kooooo000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool04?ooool2o`0004Gooooo0_l0000;oiF5_`04o`000?nUULGoYIG5ojFE
a@;o00004OnXU/@3o`0000GoZiO300?o0000okJ[c_nfZlh02OnfZlh5o`0000_o^Zk>00?o0000okc6
h_nla^801?nla^86o`0000Wo`L[Q1?l0000BojKKnPOo00000omA]oX00om@/O[o0000o`000002oe2a
nP?oDJgj1?mDZ_T2o`0002kooooo00?o0000ooooooooool09_ooool002[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`10ooooo`;o00003OnEQKl3o`00017oZ9K40ol00008oj^G``03
o`000?nfZlko]Z_>00Go]Z_>1?l0000>okZ^cP?o000000?o_<KRo`000?l000003?o1b^46o`0000?o
a/oQ00?o0000ojcRnOn/h_T03_n/h_T6o`000004oeg7n_mF__[oE[kjoeJnnP?o000000?oDKOjo`00
0?m@/OX00om@/OX00ol0003oDJgjoe6]nP04oeBZn@;o0000;Oooool00ol0003oooooooooo`0Uoooo
o`00:_ooool2o`0001Gooooo00?o0000ooooooooool0?Oooool2o`0000goUHFo0_l000000onGQKko
0000ojRFa00>ojRFa0?o00002on[Ul<00ol0003o]Z_>okJ[cP02okJ[cP?o00003_nj[/h4o`0000;o
_[7>00?o0000ol7:hOo1b^402?o1b^45o`0000Soa/oQ00?o0000ojcRnOn/h_T01on/h_T5o`0000;o
/nSg3Ol00002oeJnnP04oe6gn_l0003oDKOjoe6gnP?oD;7j00Co0000oe6]n_mA[O[o00000omDZ_T2
o`0002cooooo00?o0000ooooooooool09?ooool002[ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0jooooo`;o00003OnEQKl2o`0000CoUhFn00?o0000ojRFa?nXU/@02OnXU/@3o`00
00koZiO30ol0000@okZ^cP?o00001_nn/Lh00ol0003o`L[Qol7:h@03ol7:h@?o00003?o6cn43o`00
00?o[>;i00?o0000ok?Xmoncj?L01Oncj?L3o`000003ok[^m?l0003o000000So000000?oIm3jo`00
0?l000001ol000000omF__[oDKOjoe6gnP03oe2anP04o`000?mA[O[oDJgjo`0000?oE:[i0_l0000Z
ooooo`;o00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0goooo
o`;o00003OnEQKl2o`0000KoUhFn00?o0000ojRFa?nXU/@01_nXU/@3o`0000koZiO30ol000000on^
V/;o0000okZ^cP0<okZ^cPCo00002?nn/Lh2o`000003ol7:hOl0003oa/oQ00coa/oQ1Ol000000oo;
e>3o0000ok?Xm`06ok?Xm`03o`000?njk_Co^^kd00;o^^kd00?o0000ol7bl?n2i?D01?n2i?D4o`00
00CoP^Ce00?o0000odFjlom5^_<01OmWd?X4o`000003oeJnn_mA]o[oDKOj00?oD;7j00?o0000oe6]
n_l000000omDZ_T00ol0003oooooooooo`0Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00003OnEQKl2o`0000SoUhFn00?o0000
ojRFa?nXU/@00onXU/@3o`0000koZiO30ol00004ojjJ`P03o`000?nj[/ko^Zk>00Oo^Zk>1?l00009
okjacP?o000000?o`[G>o`000?o6cn402Oo6cn45o`0000CobmCP0_l00002ok?Xm`Ko^^kd00Co0000
ol7bl?o1l_3o`O;`2Ol000000onOlncoTNgaoi7]l@02og;Km@04o`000?mKc?GoFlceoe_<m@GoAK[c
00?o0000oc:Zl?l000000_lSVn`00olISnWo0000o`000002o`000006oe6gn_m@/O[oD;7jo`000?mA
[O[o00000_mDZ_T2o`0002Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o00006Oooool00ol0
003oooooooooo`0aooooo`;o00003OnEQKl2o`0000_oUhFn00?o0000ojRFa?nXU/@00_l0000?oj^G
``;o00002?n^V/800ol0003o^Zk>okZ^cP03okZ^cP?o00002_nn/Lh3o`0000Co`[G>00?o0000olK?
hOo6cn401Oo6cn43o`0000KobmCP0ol000000oo@fMoo0000ok[^m003ok[^m003o`000?o1l_3o`O;`
00;o`O;`0_l000000oo7m^co0000o`000004o`000003oiock?l0003o000000[oL]_e0ol000001_mK
c?GoAK[codFjlom5^_?o0000oc:Zl0;o8i_/0_lISnT4oa>6iP;oD;7j00?o0000oe6]n_l000000_mD
Z_T2o`0002Oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool01Oooool002Wooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0^ooooo`;o00003OnEQKl2o`0000coUhFn0ol0000?oj^G``?o00002_n^V/801?l0003o^Zk>okZ^
c_nj[/h2o`0000[o_[7>0ol00007ol:ecP03o`000?o6cn7oa/oQ00;oa/oQ0_l00007ol_Dh0?o0000
0_o@fMl2o`000003ok[^m?o1l_3o`O;`00Co`O;`0_l00002olOfk0Go000000CoWo?/o`000?l0003o
[OWV0on9jO84o`0000?oP]Ko00Go0000of[3o_mZ`okoJ/?no`000002oe>_nP08o`000?loW?Co?icd
o`000?m5^_?o0000oc:Zl?lSVn`2oaV?j@?o4hKV0_lBP>D01?m@/O[o0000oe6]n_l00002oeBZn@;o
00009_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`06ooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02co
oooo00?o0000ogid__l000002onEQKl2o`0000coUhFn0_l000000onIQ[go0000oj^G``0=oj^G``;o
00003?n^V/83o`0000_o_[7>0ol00009ol:ecP;o000000?oa/oQol_Dh?o;e>001oo;e>03o`0000;o
d=WO0ol000000ooEg]ko0000ol7bl003ol7bl004o`000?o7m^coaoK/olOfk0Go000000CoWo?/o`00
0?n]nNKo[OWV1OnNlnd00ol0003oVNGloiWUo002oiWUo0CoP]Ko00Go0000of[3o_mZ`okoJ/?no`00
0002oe>_nP03o`000?loW?Co?icd00;o00000_l_Rnd2o`000005oaV?jOlCQ^Ko4hKVoa>6i_l00000
0_lBP>D00olDONGo0000o`000002o`000003oeBZnOl0003ooooo02Cooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007oooo
o`00:Oooool3o`0001cooooo00?o0000ooooooooool0:_ooool01Ol0003oOWBnogid__mnM;ko0000
00SoUHFo0_l0000=oiN5_P03o`000?nIQ[goVHJm00;oVHJm00?o0000oj^G`on[Ul<02?n[Ul<3o`00
00co[Y[20_l000000onaW<;o0000okjacP09okjacP;o00002Oo2]Lh3o`000003olJjc_l0003obmCP
00OobmCP0_l00003om3Ig`;o00000ooEg]h01?l0003o`O;`ol7bl?l00004olOfk0Co000000GoWo?/
ojgii_n]nNKo[OWVo`000002oikck@;o/?[V0on^lOH00ol0003oVNGloiWUo003oiWUo005o`000?n2
e_ooP]Kooh;Fool000000omZ`oh02?l0003oDjojoe>_n_l0003o?icdo`000?loW?Co00000_l_Rnd2
ob=liP03o`000?lISnWo4hKV00;o4hKV0_lBP>D2oaAmi@03oaYmi_l0003o000000?o00009?ooool0
0ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000
ogid__mnM;h00_mnM;h00ol0003oUHFooiF5_`04oiF5_`;o00003OnGQKh2o`0000GoVHJm00?o0000
oj^G`on[Ul<01On[Ul<3o`0000co[Y[20ol00003ok6L`P03o`000?nn/Lko_[7>00Go_[7>0ol00009
ol:ecP;o00001?o6^/h00ol0003obmCPol_Dh003ol_Dh0;o00001?o@fMl2o`0000?oeMkN0ol00005
olOfk0Co00000on]nNH00onio>3o0000ok3jiP02ok3jiP03o`000?n^lOKo[_7f00Co[_7f00Ko0000
oiWUo?nIiOcoVNGlo`000?nIiO`7o`000009of[3o_l0003oDjojoe>_n_l0003o?icdo`000?loW?Co
000000;o;h_]0olSO>H01?l0003o6HoYoa>6i_lCQ^H2oa:0i@03o`000?lDONGo6WgV00;o6WgV00?o
8goXo`000?l000008_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`00
0?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09_oo
ool00ol0003oOWBnogid_P04ogid_P04o`000?nEQKooUHFooiF5_`;o00003OnGQKh2o`0000SoVHJm
00?o0000oj^G`on[Ul<00_n[Ul<2o`0000go[Y[20_l00007ok6L`P03o`000?nn/Lko_[7>00;o_[7>
0_l0000:ol:ecP;o00001_o6^/h01Ol0003obmCPol_Dh?o;e>3o000000Cod=WO0_l00004omGNgP;o
000000?ofN?Mo`000?o7m^`00_o7m^`4o`000007om?khOl0003o[OWVokWlh?l0003oa?kIo`000002
ok3jiP04o`000?nnnNgo__W]okkik@;o00001?n^lOH3o`0000;oXLog1?n>_OH4ogb/lPGo000000Co
?icdo`000?loW?Co00000_l_Rnd2ob=liP;o6g;Q00Oo0000oa>6i_lCQ^Ko0000oa:0iOl0003o57gU
00?o6WgV0_lSOnP00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00002?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003oOWBnogid_P05ogid_P04o`000?nE
QKoo0000o`0000koUhFn00?o0000oiV6_OnIQ[d02?nIQ[d00ol0003oZiO3oj^G``02o`0000go[Y[2
0_l00009ok6L`P04o`000?nn/Lko_[7>o`0000[o`[G>0ol00007olJjcP?o00001Oo@fMl2o`0000Co
eMkN0_l00002omWSg@03o`000?o7m^co000000;o000000SocOWVo`000?oCnn7odo_Qo`000?nio>3o
0000olCnf@?o000000?o_okNo`000?nnnNd01OnnnNd2o`0000;o/mkf00?o0000oj7?monQcoL00_nQ
coL01Ol0003oS[gfohjmm_n>_OKo000000CoO:cb0om[Vn`5o`0000;o;h_]00?o0000ob=li_lSO>H0
1?lKL^401OlCQ^Ko0000oa:0iOlBP>Go57gU00?o6WgV0_lSOnP00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Qoooo
o`03o`000?oooooooooo02;ooooo00?o0000ogid__mnM;h01_mnM;h2o`0000koUhFn0_l0000;oiV6
_@;o00003On^V/83o`0000[o/Ic20_l0000;ol:ecP;o00002?o6^/h2o`000003ol^nc_l0003od=WO
00?od=WO00?o0000omGNg_oEg]h00ooEg]h2o`0000?ofN?M0ol00002olgiiP?odo_Q00CoeogKo`00
0?o4o]Woa?kI0ol000000onoo]ko0000o`000002o`0000;o__W]0_l000000oo3j_3o0000ok?NmP02
ok?NmP03o`000?nQcoOoXLog00;oXLog00Go0000ohjmm_n>_OKoS[gfo`000004ogb/lP04o`000?m[
VncoJi_/of^Kk0;oG8_V0ol00002obn;k@03o`000?lSO>Ko8gcV00?o6g;Q0_lFJ]d01OlCQ^Ko0000
oa:0iOlDONGo000000;o6WgV0_lSOnP00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01go
oooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oo
oooo0_l00008ogid_P03o`000?moM;go000000coUhFn0_l0000;oiV6_@;o000000?oW8Rmo`000?n^
V/802_n^V/82o`0000_o/Ic20_l000000oneX<?o0000ol:ecP07ol:ecP?o00001oo6^/h3o`0000?o
bkk>00Co0000om3Igoo@fMoo00001OoEg]h2o`0000?ofN?M0ol000000oo=nNKo0000om?kh@02om?k
h@03omOmfol0003o000000;oa?kI00Go0000olgodol0003o_okNo`000004ol_mh`;o00000oo3j_00
1Ol0003o/mkfok?Nm_ncg_Ko000000CoXLog00?o0000ohjmm_n>_OH00_n>_OH01Ol0003oO:cbogb/
l_ml[?;o000000?oJi_/00Go0000oeb;i_mLRnKo0000oeb;iP02o`000004obn;kOl0003o8gcVo`00
00?o6g;Q0_lFJ]d00olCQ^Ko0000oa:0i@02o`0000;o6WgV0_lSOnP00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Mooooo`03o`000?mnM;koOWBn00OoOWBn00Go0000ogmd_OmoM;goOgBmo`00000:
oiN5_P03o`000?nIQ[goVHJm00[oVHJm00?o0000oib8_OnLR;d00_nLR;d00ol0003o[Y[2ojjJ`P06
ojjJ`P;o00002onaW<82o`0000?o]J3300?o0000ol:ec_o2]Lh01?o2]Lh2o`0000Soa[[>0_l00005
ol^ncP;o00001_oEg]h2o`0000;ofN?M0ol000000ooMim_o0000om?kh@03om?kh@;oeogK0_l00000
1oo4o]WocOoColgodoo=om?o0000ol_oe_l000001?o;oN<00ol0003oco?Xo`000004ol?Zl005o`00
0?ncg_Ko/mkfok?Nm_l000000onQcoL00ol0003oS[gfohjmmP02ohjmmP05o`000?ml[?;oO:cbogb/
l_l000000om[Vn`01Ol0003oG8_Voeb;i_mLRnKo000000;oDGkP0_l00002ob=liP04o`000?lKL^7o
6g;Qo`0000?o5V[M00Co0000oa:0iOl0003o57gU0_lJONH2ob=oj003o`000?oooooooooo023ooooo
0_l0000Mooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool09?ooool2o`0001co
oooo00?o0000ogid__mnM;h01omnM;h00ol0003oOgBmogmd_@02ogmd_@03o`000?nGQKkoUhFn00Ko
UhFn0_l0000;oiV6_@;o00001OnLR;d00ol0003o[Y[2ojjJ`P04ojjJ`P;o00002onaW<82o`0000Ko
]J3300Co0000ol:ec_o2]Lko`[G>0_l00008olJjcP;o00001Oo;_/h2o`000003om34col0003oeMkN
00CoeMkN00?o0000omWSgOl000000ol000001?oMim_o0000on7/f?l00002om?kh@05o`000?oGoM_o
eogKom_meOl000000oo=om<00ol0003obooFo`000003o`000003ol_mhol0003oco?X00;oco?X00?o
0000ol?Zl?o3j_000_o3j_001Ol0003o/mkfok?Nm_ncg_Ko000000?oXLog00?o0000ohjmm_n>_OH0
0_n>_OH01Ol0003oO:cbogb/l_ml[?;o000000?oJi_/00?o0000oeb;i_mLRnH00_mLRnH01ol0003o
DGkPoe5nh?mAO^3o0000ob=li_l000000olKL^400ol0003o5V[MoaIZg@02oaEVfP;o000000Ko57gU
o`000?lJONKo0000ob=oj?l0000Pooooo`03o`000?oooooo000001gooooo0006ooooo`05oa0@4?oo
ooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
0_l0000Wooooo`03o`000?oooooooooo01Sooooo00?o0000ogid__mnM;h01omnM;h00ol0003oOgBm
ogmd_@04ogmd_@03o`000?nGQKkoUhFn00?oUhFn0_l0000;oiV6_@;o00001onLR;d00ol0003o[Y[2
ojjJ`P02ojjJ`P;o00002onaW<82o`0000So]J3300Co0000ol:ec_o2]Lko00002?o6^/h2o`0000Ko
bkk>00Go0000om34coo@a<ood<C?o`000003omGNgPKo00000_oMim/00ol0003ohNcHo`000002om?k
h@;oeogK00Co0000om_meOoNoLoo00000_o=om<01?l0003obooFo`000?l00003omGnf@03o`000?o?
lnSoco?X00;oco?X00Co0000ol?Zl?o3j_3o`n[`4?l00002ogb/lP03o`000?m[VncoJi_/00;oJi_/
00Go0000oeb;i_mLRnKoG8_Vo`000004oe5nh003o`000?lSO>Ko000000;o6g;Q00Co0000oaIZgOlF
J]go5V[M0olEI]X3o`000004oaYmi_l0003o8goXo`00027ooooo00?o0000ooooooooool06oooool0
00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05_oo
ool00ol0003oOWBnogid_P07ogid_P03o`000?moM;goOgBm00KoOgBm00Go0000oiN5__nGQKkoUhFn
o`00000<oiV6_@03o`000?nLR;goW8Rm00SoW8Rm00?o0000ojjJ`_l000003?naW<82o`0000Wo]J33
0_l00009olJjcP;o00001_o;_/h2o`0000Cod<C?00?o0000omGNg_l000000_l000000ooIhmgo0000
o`000002omgWf`03o`000?oQk=SohNcH00;o00000ooGoM/01ooKoMGo0000omkmcol0003ocOoCo`00
0?oDold00_oDolh01?l0003oeOkIomGnfOoEo]T2o`0000Coco?X1?l000000oo7fNOo0000ok[;i`02
ok[;i`05o`000?n[_>GoZkcUoj^liOl000001?nM[N82oi2Ng@03o`000?ml[?;o000000CoJi_/00Co
0000oeb;i_mLRnKoG8_V0_l00003oe5nh0;oAgCJ00Go8gcVo`000?lKL^7o6g;Qo`000002oaIZg@03
o`000?lEI][o5FKJ00;o5fCI0_l000001?lJONKo0000ob=oj?l0000Qooooo`03o`000?oooooooooo
01[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool0
0ol0003oOWBnogid_P07ogid_P03o`000?moM;goOgBm00OoOgBm00Co0000oiN5__l0003o00002onI
Q[d2o`0000[oW8Rm0_l0000=ok6L`P03o`000?neX<?o]J3300Oo]J330_l000000oniY<Co0000olJj
cP05olJjcP?o00001_o;_/h2o`0000God<C?0ol00003omWSg@04o`000?oMim_ogNOKomgWf`?ohNcH
00Oo0000onC_eOl0003oeogKo`000?oKoMGo000000;og_g?00Ko0000omCocOoJolOo0000omCoc_l0
0003omGnf@03o`000?oIn=oo000000?oco?X0_l00003olOIi`05o`000?njbnOo^/_Wok[;iol00000
0on[_>D00ol0003oWJgRoif]hP03oif]hPCoT9kM0_l00003of^Kk007o`000?mLRnKoG8_Voeb;i_l0
003oDGkPo`000002oe5nh004o`000?m7M=[oAgCJo`0000?o6g;Q00Co0000oaIZgOlFJ]go00000_lE
I]X3oaMTf@05o`000?lJONKo0000ob=oj?l000008?ooool00ol0003oooooooooo`0Jooooo`009ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ogid__mnM;h01omn
M;h00ol0003oOgBmogmd_@08ogmd_@;o00002onIQ[d2o`0000_oW8Rm00?o0000oin;_Ol000002ona
W<82o`0000So]J330_l00004okVTa003o`000?o6^/koa[[>00;oa[[>00?o0000ol^nc_o;_/h01Oo;
_/h2o`0000Cod<C?0ol000001OoDbLoo0000omWSgOoIhmgo000000?ogNOK00So0000on7/f?oQk=So
hNcHo`000?oTkmGo0000omOmf`;ofogE0_oNoLl2o`000003omCocOoJolOo000000Co000000?oeOkI
o`000?oIn=l00_oIn=l3o`000003om?Ui?l0003oamWW00;oamWW00Go0000ok[;ionjbnOo^/_Wo`00
0003oj^li@03o`000?nM[N;oWJgR00;oWJgR00?o0000oi2NgOn@W]d00_n@W]d2ohBBf@;o000000?o
Ji_/o`000?mLRnH00_mLRnH00ol0003oDGkPo`000002oe5nh004o`000?m7M=[oAgCJodMdfP;o0000
00Go6g;Qo`000?lFJ]go5V[Mo`000002oaEVfP04o`000?lGI=Wo5fCIoaMTf@?o000000?o8goXo`00
0?ooool07oooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000oooooooo
ool04?ooool00ol0003oOWBnogid_P07ogid_P03o`000?moM;goOgBm00SoOgBm00?o0000oh9e_?l0
00002_nIQ[d00ol0003oW8Rmoib8_@09oib8_@;o00000onORkd00ol0003o/Ic2ok6L`P06ok6L`P;o
00002OneX<<00ol0003o^JC4okVTa004okVTa004o`000?o6^/koa[[>o`0000Sobkk>00Co0000om34
coo@a<ood<C?1?l00002omC9c`03o`000?oIhmgo000000CogNOK0ooQk=P2o`000005onC_eOl0003o
0000om_meOl000000_oNoLl2o`0000;of_o70ol00003omcnc`03o`000?oIn=oofOSO00;ofOSO00Co
0000om?Ui?oCiNCo00001?o7fNL01Ol0003o^/_Wok[;ionjbnOo000000?oZkcU00?o0000oif]h_nM
[N800_nM[N800ol0003oT9kMoi2Ng@02oi2Ng@GoQ9;I0_l00002oeb;iP06o`000?mAO^3oDGkPo`00
0?mAO^3o00000om7M=X2od5/eP03o`000?lKL^7o000000;o5V[M00?o0000oaEVf_lEI]X00olGI=T2
oaaUf@;o000000?o8goXo`000?ooool07oooool00ol0003oooooooooo`0Hooooo`009oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00?o0000ogid__mnM;h01omnM;h00ol0
003oOgBmogmd_@08ogmd_@05o`000?n2MKcoPWFloh9e_?l000001onIQ[d2o`0000_oW8Rm00?o0000
oin;_OnORkd00onORkd00ol0003o/Ic2ok6L`P04ok6L`P;o00002OneX<<2o`0000Oo^JC40_l00008
ol^ncP;o000000God<C?o`000?l0003o0000om34c`02o`0000;oe<W?0_l00004omgWf`05o`000?oQ
k=SohNcHon7/f?l000000_oTkmD00ol0003oio;Bo`000002omkmc`?o00000_oJolL00ol0003ofoo7
o`000003omcnc`;o00000_oIn=l00ol0003og>oNo`000002om?Ui005o`000?o7fNOoamWWolOIiol0
00000onjbnL01Ol0003oZkcUoj^liOn[_>Go000000GoWJgR00Go0000oi2NgOn@W]goT9kMo`000005
ohBBf@;oNXOD00?o0000oeb;i_l000000omAO^02o`0000?oAgCJ00Go0000od5/e_m1K=Ko@FcFo`00
0002oaIZg@04o`000?lEI][o5FKJo`0000?o5fCI0olLIMT00ol0003o8goXo`00000Nooooo`;o0000
6_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03o`000?mn
M;koOWBn00KoOWBn00?o0000ogmd_OmoM;d02?moM;d00ol0003oPWFloh9e_002oh9e_003o`000?nI
Q[goVHJm00?oVHJm0_l0000<oib8_@03o`000?nORkgoWh^m00GoWh^m00Co0000ok6L`_naW<;o/Ic2
0_l00009okFP``;o00002?niY<@00ol0003o_ZW5o`000006ol^ncPGo00000_o@a<l2o`0000?oe<W?
00?o0000omW@d?l000000ooMim/3on7/f0;o00000_oTkmD00ol0003oio;Bo`000002omkmc`03o`00
0?oQoL[o000000;of_o700?ogok2o`000?l000000ooLo/l00ol0003ogo_Eomoke@02o`000003omc_
g_l0003odnGT00;odnGT00Go0000olOIioo7fNOoamWWo`000003ok[;i`05o`000?n[_>GoZkcUoj^l
iOl000001?nM[N800ol0003oT9kMoi2Ng@02oi2Ng@03o`000?n4T]WoQ9;I00;oQ9;I00Ko0000ogZ7
e?mjQmCoNXODoeb;i_l00004oe5nh005o`000?m7M=[oAgCJodMdf_l000001?m1K=H2o`000005oaIZ
gOl0003o5FKJoaEVf_l000000_lGI=T01?l0003o76GIoaaUfOlLIMT3o`0001oooooo00?o0000oooo
ooooool05oooool002Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;ooooo`03
o`000?mMH[oo000000KoOWBn00?o0000ogmd_OmoM;d02?moM;d00ol0003oPWFloh9e_004oh9e_005
o`000?nIQ[goVHJmoiV6_Ol000003?nLR;d2o`0000SoWh^m00Co0000ok6L`_naW<;o00002OneX<<2
o`0000So^JC40_l00002okjYa@03o`000?o;_/kobkk>00?obkk>0ol00004om34c`03o`000?oDbLoo
e<W?00;oe<W?00Go0000omW@d?oId=3o0000omgWf`04on7/f007o`000?oTkmGoi>oEonC_eOl0003o
io;Bo`000002omkmc`06o`000?oQoL[ohog5o`000?oJolOogok21?l000000ooLo/oo0000omoke@02
omoke@04o`000?oLkmkog>oNo`0000;odnGT00?o0000olOIioo7fNL00_o7fNL01Ol0003o^/_Wok[;
ionjbnOo000000?oZkcU00?o0000oif]h_nM[N800_nM[N800ol0003oT9kMoi2Ng@02oi2Ng@03o`00
0?n4T]WoQ9;I00;oQ9;I00?o0000ogZ7e?mjQm@00_mjQm@2o`0000?oDGkP00Go0000odMdf_m7M=[o
AgCJo`000004od5/eP;o?FOC00?o5V[Mo`000?lEI]X00_lEI]X3oaMTf@?o76GI0_lSImX2o`0001oo
oooo00?o0000ooooooooool05_ooool002Oooooo0_l0000`ooooo`03o`000?oooooooooo00[ooooo
00Co0000oeeR_omMH[oo00001?mnM;h00ol0003oOgBmogmd_@08ogmd_@03o`000?n2MKcoPWFl00Go
PWFl00Co0000oiV6_Ol0003o00003?nLR;d00ol0003oWh^moin;_@08oin;_@;o00002OneX<<2o`00
00So^JC40_l00005okjYa@03o`000?o;_/ko000000;o00001Oo@a<l2o`0000?oe<W?0_l00002omW@
d0;o00001?oQk=P00ol0003oi>oEonC_e@02o`000006onObd_oYmLko0000omkmcol0003ohOg:0_oS
oLD01OoJolOogok2o`000?oPo/;o000000;ohOk700Ko0000omokeOoOnmGo0000on?eeol00002omc_
gP03o`000?oCiNCo000000ko00001?nM[N801Ol0003oT9kMoi2NgOn@W]go000000GoQ9;I00?o0000
ogZ7e?mjQm@00_mjQm@2og9nd0;o000000?oDGkPo`000?l000000_m7M=X00ol0003o@FcFod5/eP02
od5/eP?o?FOC00Go5V[Mo`000?lEI][o5FKJo`000002oaMTf@04o`000?lLIMWo76GIoaaUf@?o8fOJ
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`009_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo00Go0000oeeR_omMH[ooGF:oo`000003ogid_P03o`00
0?moM;goOgBm00SoOgBm00?o0000oh9e_?n2MK`01on2MK`00ol0003oW8Rmoib8_@0:oib8_@;o0000
2_nORkd00ol0003oY8jno`000007okFP``;o00002OniY<@00ol0003o_ZW5okjYa@05okjYa@?o0000
1Oo@a<l2o`0000Coe<W?00Oo0000omW@d?oId=3ofM3@o`000?oNe]3o000000?ohNcH00Co0000onC_
eOoTkmGo00000_oWl]82onWecP03omkmcooQoL[o000000;ohog500Go0000omon`_l0003oh?k2o`00
0002on7na`03onClc?l0003o000000;ohoGG00?o0000omc_g_oLkmh00ol000000ooGfm_o0000olc>
f`02olc>f`05o`000?o1`M[o`L7Jol71f_l000000onf/mL00ol0003oZjOCo`000003o`0000CoT9kM
00?o0000ohBBfOn4T]T00_n4T]T00ol0003oNXODogZ7e002ogZ7e003o`000?mbO]3oLWk@00;oLWk@
00CoDGkPo`000?m7M=[o00000_m7M=X01Ol0003o@FcFod5/e_m1K=Ko000000?o?FOC00Go0000oaEV
f_lEI][o5FKJo`000002oaMTf@?o76GI00Go0000ob=Wf_lSIm[o8fOJo`00000Nooooo`03o`000?oo
oooooooo01Gooooo000Vooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool0
0ol0003oGF:ooeeR_`02oeeR_`03o`000?mnM;ko000000[oOgBm00?o0000oh9e_?n2MK`01on2MK`2
o`0000_oW8Rm00?o0000oin;_OnORkd02?nORkd2o`0000?oY8jn00?o0000okFP`oneX<<00oneX<<0
0ol0003o^JC4okVTa007okVTa0;o00001OnnZLD4o`0000Kod<C?00?o0000omC9cooDbLl00_oDbLl2
o`0000?ofM3@00Co0000omkFd?oNe]3o00000_oQk=P3onC_e@03o`000?oWl];oio;B00;ojOG>00?o
0000on7mb_oSoLD00_oSoLD00ol0003ogok2on;m_P02o`000005on7naol0003oi?c<onClc?l00000
0ooSmML01?l0003og>oNo`000?l00002omOKf`05o`000?o<c]_oc<kKolc>fol000000oo1`MX01Ol0
003o][?GokJceonf/mOo000000GoZjOC0_l00003oi2Ng@03o`000?n4T]WoQ9;I00;oQ9;I00?o0000
ogZ7e?mjQm@00_mjQm@00ol0003oLWk@og9nd003og9nd0;o000000CoAgCJo`000?m7M=[o00000om1
K=H00ol0003o?FOCoceWd`02oceWd`;o000000Go5FKJo`000?lGI=Wo5fCIo`000003oaaUf@?o8fOJ
00?o0000ooooooooool07?ooool2o`0001Kooooo000Vooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool01Oooool00ol0003oGF:ooeeR_`04oeeR_`03o`000?moM;goOgBm00SoOgBm00?o
0000oh9e_?n2MK`01on2MK`01?l0003oQGNlohEg_?l00008oib8_@;o00002_nORkd00ol0003oY8jn
ojB>_P03ojB>_P04o`000?neX<?o]J33okFP``;o00002?niY<@2o`0000Co_ZW50ol000001?nnZLGo
0000ol>^a_l00004om34c`;o00001?oDbLl00ol0003ofM3@omW@d002omW@d006o`000?oNe]3og]K@
omkFd?l0003ohNcH0ooTkmD00ol0003oio;BonObdP02onWecP03on[gbol0003ohog500;ohog500Oo
iOc1o`000?oRoKkoh_fno`000?oQo/Oo000000;oi?c<0_l00003on?ee`;o000000GognKHo`000?oG
fm_oem_Ko`000003olc>f`05o`000?o1`M[o`L7Jol71f_l000000onf/mL00ol0003oZjOCoj^Wd`03
oj^Wd`03o`000?nQW<oo000000;o00001On4T]T00ol0003oNXODogZ7e002ogZ7e003o`000?mbO]3o
LWk@00?oLWk@0_m[Ml`2o`000003odMdf_l0003o@FcF00;o@FcF00?o0000oceWdolmIm<00_lmIm<2
oc]Sd003o`000?lEI][o000000;o5fCI00Co0000oaaUfOlLIMWo00000olSImX00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?ooool00ol0003oooooooooo`04
ooooo`03o`000?mMH[ooGF:o00CoGF:o00?o0000ogmd_OmoM;d01omoM;d00ol0003oPWFloh9e_007
oh9e_005o`000?n5MkcoQGNlohEg_?l000001onLR;d00ol0003oWh^moin;_@09oin;_@03o`000?nT
S[koY8jn00CoY8jn00Co0000okFP`oneX<?o00002OniY<@01?l0003o_ZW5okjYaOnnZLD3o`0000;o
_ZW50_l00002ol>^aP05o`000?o@a<ood<C?om34col000001OoDbLl01?l0003ofM3@omW@d?oId=02
o`0000?og]K@0_l00003onC_e@?oio;B0_oYmLh2on[gb`?ohog50_oUo<42on;m_P?o00000_oTo<`0
1?l0003oioS>o`000?oSmML2o`0000;ognKH00Co0000omOKfooGfm_o00000oo<c]/01Ol0003o`L7J
ol71f_o1`M[o000000?o][?G00?o0000oj^Wdon[Ym<00on[Ym<00ol0003oXIc?oj6Lc`02oj6Lc`;o
00000on4T]T00ol0003oNXODogZ7e002ogZ7e003o`000?mbO]3oLWk@00?oLWk@00Co0000of]gc?m[
MlcoJgO<0ol00003od5/eP03o`000?lmIm?o?FOC00;o?FOC1?lkHm001?l0003o5fCIoaMTfOl00002
oaaUf@05o`000?lSIm[o8fOJob=Wf_l000007oooool00ol0003oooooooooo`0Cooooo`009_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000oeeR_omMH[l01?mMH[l0
0ol0003oGF:no`000007ogmd_@03o`000?n2MKcoPWFl00OoPWFl00?o0000ohEg_?n5Mk`00on5Mk`0
0ol0003oW8Rmoib8_@03oib8_@03o`000?nORkgoWh^m00SoWh^m0_l00007ojB>_P;o00002OniY<@2
o`000004okjYaOl0003o0000o`0000Co_ZW500?o0000ol>^a_o3[/H00oo3[/H00ol0003od<C?omC9
c`05omC9c`05o`000?oId=3ofM3@omW@d?l000001?oNe]000ol0003oh]c?o`000002onC_e@?oio;B
0_oYmLh2on[gb`?ohog50_oUo<42on;m_P0<onCl_Ol0003oi?g1o`000?oTo<co0000onOhc_l0003o
hoGGo`000?oUkmCo00000_oOi]P01?l0003oem_KomOKfol00002olc>f`03o`000?o1`M[o`L7J00;o
`L7J00Go0000okJceonf/mOo][?Go`000004oj^Wd`03o`000?nQW<ooXIc?00?oXIc?00?o0000oiRB
c?l000000_n4T]T00ol0003oNXODogZ7e002ogZ7e003o`000?mbO]3oLWk@00?oLWk@00?o0000of]g
c?m[Ml`00_m[Ml`00om7M=[o0000od5/eP02od5/eP03o`000?lmIm?o?FOC00;o?FOC00?o0000oc]S
d?lkHm000_lkHm000ol0003o5fCIo`000003oaaUf@04o`000?lSIm[o8fOJo`00023ooooo00?o0000
ooooooooool04_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo03Kooooo00Co0000oooooooooooo00001omMH[l00ol0003oGF:no`000006ogmd_@03o`000?n2
MKcoPWFl00OoPWFl00?o0000ohEg_?n5Mk`01On5Mk`00ol0003oW8Rmoib8_@02o`0000[oWh^m00?o
0000ojB>__nTS[h01_nTS[h00ol0003oZ9>oo`000008okVTa0Co00001OnnZLD2o`0000Go`jk60_l0
0005omC9c`03o`000?oId=3ofM3@00;ofM3@00?o0000omkFd?oNe]000_oNe]001Ol0003oh]c?on;L
col0003oi>oE00?oio;B0_oYmLh2on[gb`03o`000?oSoLGohog500;oiOc10_oRoKh2onCl_@04onCm
`Ol0003oi_c4o`0000;oioS>0_l000001OoUkmCo0000omoVf?oOi]So000000?oem_K00Co0000olc>
foo<c]_o00000oo1`MX01Ol0003o][?GokJceonf/mOo000000GoZjOC00?o0000oj6LconQW<l00_nQ
W<l01ol0003oV9;<oiRBc?nHT/co0000ohBBfOl000001?mjQm@00ol0003oLWk@og9nd003og9nd003
o`000?m[MlcoJgO<00?oJgO<0_l00002od5/eP03o`000?lmIm?o?FOC00;o?FOC00?o0000oc]Sd?lk
Hm000_lkHm001?lkH/oo0000oaMTfOl00002oaaUf@05o`000?lSIm[o8fOJob=Wf_l000007oooool0
0ol0003oooooooooo`0Booooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000
ooooooooool0>?ooool3o`0000KoGF:o00Go0000oeeR__mMH[koGF:no`000004ogmd_@03o`000?n2
MKcoPWFl00OoPWFl00?o0000ohEg_?n5Mk`01_n5Mk`00ol0003oW8Rmo`00000:oin;_@;o00002?nT
S[h01Ol0003oZ9>oojRC_onXTkoo000000Go^JC40ol00007okjYa@03o`000?o3[/Ko`jk600Co`jk6
00?o0000olReaol000001?oDbLl00ol0003ofM3@omW@d002omW@d003o`000?oNe]3og]K@00;og]K@
00?o0000on;LcooRg<l00_l00003onObdP;ojOG>0_oZml/2o`00000:on?maOoUo<7oiOc1o`000?oR
oKko0000onCl_OoToL7o0000onKla0;o000000?oioS>o`000?l000000_oUkm@01?l0003ognKHomoV
f?l00002omOKf`04o`000?o<c]_oc<kKo`0000Co`L7J00Co0000okJceonf/mOo00001On[Ym<00ol0
003oXIc?oj6Lc`03oj6Lc`03o`000?nHT/coV9;<00;oV9;<0_l00003ogZ7e003o`000?mbO]3oLWk@
00?oLWk@00?o0000of]gc?m[Ml`01?m[Ml`01OmVLLWo0000od5/e_m1K=Ko000000Co?FOC00?o0000
oc]Sd?lkHm000_lkHm02oc]Rc`;o00000olLIMT01?l0003o8fOJob=Wf_l0000Pooooo`03o`000?oo
oooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`006oooool01Ol@413ooooooooooooo
oooo410@00Gooooo0ol0000iooooo`03o`000?mMH[ooGF:o00GoGF:o00?o0000oeeR__mMH[h00_mM
H[h01?l0003oOgBmogmd_Ol00009oh9e_003o`000?n5MkcoQGNl00SoQGNl00?o0000oin;_OnORkd0
2?nORkd00ol0003oY8jnojB>_P07ojB>_P03o`000?nXTkooZ9>o00?oZ9>o00?o0000okVTa?l00000
0_l00008okjYa@;o00001_o3[/H01?l0003ob;G7olReaol00003omC9c`GofM3@00Co0000omkFd?oN
e]3og]K@0_l00002on;Lc`03o`000?oVh/oo000000;oio;B0_oYmLh2on[gb`;o000000Oohog5onGl
`OoUo<7oiobmon;m__oUo;_oi?bm00;o000000?oi_c4o`000?oYn/H00_l000001?oYm<ko0000onG_
e?l00002omoVf005o`000?oGfm_oem_KomOKfol000000_o<c]/01Ol0003o`L7Jol71f_o1`M[o0000
00?o][?G00?o0000oj^Wdon[Ym<00_n[Ym<00ol0003oXIc?oj6Lc`03oj6Lc`03o`000?nHT/coV9;<
00?oV9;<0_nAR/P01?l0003oNXODogZ7e?l00005og9nd003o`000?m[MlcoJgO<00?oJgO<00Ko0000
ofIabOmVLLWo0000od5/e_l00004oceWd`03o`000?lkHm3o>f?@00;o>f?@00Go0000oc]RcolkH/oo
5fCIo`000002oaaUf@05o`000?lSIm[o8fOJob=Wf_l000007_ooool3o`0000[ooooo00?o0000oooo
ooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
03Wooooo00?o0000oeeR_omMH[l01?mMH[l00ol0003oGF:noeeR_P03oeeR_P03o`000?moM;go0000
00WoPWFl00?o0000ohEg_?n5Mk`02?n5Mk`2o`0000SoWh^m0_l00009ojB>_P03o`000?nXTkooZ9>o
00?oZ9>o0ol000000oniY<Co_ZW5okjYa@06okjYa@;o00001_o3[/H2o`0000Cob;G700?o0000omC9
cooId=001?oId=001Ol0003og]K@omkFd?oNe]3o000000?oh]c?00Go0000onKRcooVh/oo0000onOb
dP02onWecP;oj_O;00?o0000on_haol000000_oUo<400ooWo;go0000onGl^`03o`000003onKla?l0
003ojO[600;o000000GojOC>o`000?oUkmCoiNoDo`000002omoVf0Wo00000_o1`MX01?l0003o][?G
okJceol00005oj^Wd`03o`000?nQW<ooXIc?00;oXIc?00?o0000oiRBc?nHT/`00onHT/`01ol0003o
TH[8oi6:b?nAR/So0000ogZ7e?l000001?mbO]000ol0003oJgO<of]gc004of]gc004o`000?mVLLWo
IW79ofIab@;o00001?lmIm<00ol0003o>f?@oc]Sd002oc]Sd005o`000?lkH/oo>f;?oc]Rcol00000
0olLIMT01?l0003o8fOJob=Wf_l0000Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03So
oooo00?o0000oeeR_omMH[l01OmMH[l00ol0003oGF:noeeR_P04oeeR_P03o`000?n2MKcoPWFl00Oo
PWFl00?o0000ohEg_?n5Mk`02?n5Mk`01?l0003oR7ZmohQj_Ol00006oin;_@03o`000?nTS[koY8jn
00OoY8jn0_l00003ojRC_`?o000000?oZ9>oo`000?l000002?nnZLD00ol0003o`jk6ol>^aP05ol>^
aP03o`000?o8]LOob;G700?ob;G70_l00005omW@d0Cog]K@00Go0000on;LcooRg<ooh]c?o`000002
onKRc`;o00000_oYmLh2on[gb`0:o`000?o[n<Oo0000o`000?oUo<7oiobmo`000?oUo;_o0000onKk
^@?o00000_oYn/H01?l0003ojOC>onWdc_l00002onG_e0Co00000_oKem<01?l0003od/_Com;;dol0
0002olVod@Co000000?o][?Go`000?n[Ym<00on[Ym<00ol0003oXIc?oj6Lc`03oj6Lc`03o`000?nH
T/coV9;<00;oV9;<00?o0000oi6:b?nAR/P00onAR/P00ol0003oLWk@og9nd003og9nd003o`000?m[
MlcoJgO<00CoJgO<00?o0000ofIabOmVLLT00_mVLLT00ol0003o?FOCoceWd`02oceWd`03o`000?lk
Hm3o>f?@00;o>f?@00?o0000oc]RcolkH/l00_lkH/l2o`000003oaaUfOl0003o8fOJ00;o8fOJ00?o
0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo000K
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0hooooo`03o`000?mM
H[ooGF:o00CoGF:o00?o0000oeeR__mMH[h01OmMH[h00ol0003oPWFloh9e_006oh9e_003o`000?n5
MkcoQGNl00SoQGNl00Go0000ohQj_On8N[goR7Zmo`000005oin;_@03o`000?nTS[koY8jn00OoY8jn
00?o0000ojRC_onXTkl00ol00003ojRC_`03o`000?n]V<7o000000Ko_ZW50_l00007ol>^aP03o`00
0?o8]LOob;G700?ob;G700?o0000olflbOl000001?oId=04omkFd005o`000?oRg<ooh]c?on;Lcol0
00000_oVh/l01?l0003ojNS=o`000?oYmLh3on[gb`05on_haol0003ojoW3onGl`OoWo;d00ol00002
onKk^@04onOk^ol0003ojO[6onWjaP;o000000?ojOC>o`000?oUkm@00ol000001OoSh];o0000om_G
dooKem?o000000;od/_C00?o0000olVodOo9_m400_o9_m400ol0003o`;C>ol2dcP02o`0000CoZjOC
00?o0000oj6LconQW<l00_nQW<l00ol0003oV9;<oiRBc003oiRBc003o`000?nAR/SoTH[800?oTH[8
00?oRh?5o`000?mbO]000_mbO]000ol0003oJgO<of]gc004of]gc003o`000?mVLLWoIW7900?oIW79
0_l00003oceWd`03o`000?lkHm3o>f?@00;o>f?@00?o0000oc]RcolkH/l00_lkH/l2ocaRc`;o0000
0olSImX00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool001_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000>?ooool00ol0003oGF:o
oeeR_`04oeeR_`03o`000?mMH[koGF:n00GoGF:n00?o0000oemR__l000001_n2MK`00ol0003oQGNl
ohEg_008ohEg_003o`000?n8N[goR7Zm00?oR7Zm00?o0000oin;_OnORkd00_l00009ojB>_PCo0000
1OnXTkl01Ol0003o[IS1ojfH`On]V<7o000000Co_ZW500?o0000ol>^a_o3[/H01_o3[/H00ol0003o
b;G7olRea`03olRea`05o`000?o=_<WocKc9olflbOl000000_oId=04omkFd005o`000?oRg<ooh]c?
on;Lcol000000_oVh/l01?l0003ojNS=onWXcOl00003on[gb`0>on_haol0003ojoW3o`000?oWo;go
0000onSk^_oWnkSo0000onKk^OoWnk_oj?^mo`000?oYn/H2o`0000;ojOC>0_l000001?oXjm3o0000
on?Rd_l00002om_Gd`04o`000?oBbm?od/_Co`0000CobKoA00Ko0000ol2dc_o0]<ko`;C>o`000?nh
ZL/2o`000003oj^Wdol0003oXIc?00CoXIc?00?o0000oiRBc?nHT/`00_nHT/`00ol0003oTH[8oi6:
b003oi6:b004o`000?n;PlGoRh?5o`0000;oLWk@00?o0000of]gc?m[Ml`01?m[Ml`00ol0003oIW79
ofIab@02ofIab@04o`000?mRKLOo0000o`0000;o?FOC00?o0000oc]Sd?lkHm000_lkHm000ol0003o
>f;?oc]Rc`02oc]Rc`?o?6;?00Go76GIo`000?lSIm[o8fOJo`00000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo03Oooooo00?o0000oeeR_omMH[l01?mMH[l00ol0003oGF:noeeR_P05oeeR
_P04o`000?mOH[koGf:no`0000CoPWFl00?o0000ohEg_?n5Mk`02?n5Mk`00ol0003oR7ZmohQj_@04
ohQj_@03o`000?nORkgo000000WoY8jn0ol00007ojRC_`03o`000?n]V<7o[IS100;o[IS100Go0000
okjYaOnnZLGo_ZW5o`000007ol>^aP;o00001Oo8]LL00ol0003ocKc9olflb@02olflb@;o00001?oN
e]04on;Lc`04o`000?oVh/ooi^;?o`0000;ojNS=0_l00002on[gb`03on_haol0003ojoW300;o0000
00GoiobmonSk^_oWnkSoio^honKk^@06o`000003onWdc_l0003o000000;oj>_@00?o0000on?Rd_l0
00000ooKem<01?l0003od/_Com;;dol00003olVod@05o`000?o0]<ko`;C>ol2dc_l000001?nhZL/2
o`0000CoXIc?00?o0000oiRBc?nHT/`00_nHT/`00ol0003oTH[8oi6:b003oi6:b003o`000?n;PlGo
Rh?500;oRh?500?o0000og9nd?l000001Om[Ml`00ol0003oIW79ofIab@03ofIab@03o`000?mRKLOo
HVg700;o000000?o?FOCo`000?lkHm000olkHm000ol0003o>f;?oc]Rc`02oc]Rc`05o`000?llH/oo
?6;?ocaRcol000000olSImX00ol0003oooooooooo`0Nooooo`;o00001oooool00ol0003ooooooooo
o`05ooooo`009?ooool00ol0003oooooooooo`0gooooo`03o`000?mMH[ooGF:o00CoGF:o00?o0000
oeeR__mMH[h01OmMH[h01Ol0003oGf:noemR__mOH[ko000000?oPWFl00?o0000ohEg_?n5Mk`02?n5
Mk`00ol0003oR7ZmohQj_@06ohQj_@03o`000?nTS[koY8jn00GoY8jn1?l00008ojRC_`03o`000?n]
V<7o[IS100?o[IS100?o0000okjYaOnnZLD02?o3[/H00ol0003ob;G7olRea`04olRea`03o`000?o=
_<WocKc900;ocKc900?o0000om?3bol000000ooNe]04on;Lc`?oi^;?00ko0000onWXcOoYj<go0000
onc]bol0003oj_O;on_haol0003ojoW3o`000?o[n[ooiobmonSk^P;oio^h00Ooi_^io`000?l0003o
0000on[j_ol0003ojoS600;o000000Cok?;;o`000?oXjm3o00000_oSh]801?l0003ofmOCom_Gdol0
0002om;;d`05o`000?o9_m7obKoAolVodOl000000oo0]<h00ol0003o^:W;okRYb`03okRYb`03o`00
0?n`X<So000000;oXIc?00?o0000oiRBc?nHT/`00onHT/`00ol0003oTH[8oi6:b003oi6:b003o`00
0?n;PlGoRh?500?oRh?500?o0000of]gc?m[Ml`01?m[Ml`00ol0003oIW79ofIab@03ofIab@04o`00
0?mRKLOoHVg7of9]a`?o00001?lkHm000ol0003o>f;?oc]Rc`02oc]Rc`03o`000?llH/oo?6;?00;o
?6;?0_l000000olSIm[o0000ooooo`0Nooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l0
00001oooool002Cooooo00?o0000ooooooooool0=oooool00ol0003oGF:ooeeR_`04oeeR_`03o`00
0?mMH[koGF:n00CoGF:n00?o0000oemR__mOH[h00omOH[h00ol0003oPWFlo`00000:ohEg_003o`00
0?n8N[goR7Zm00OoR7Zm00?o0000ojB>__nTS[h00onTS[h2o`000003ojB>__l0003o000000OoZ9>o
0_l00006ojfH`@;o00002?o3[/H00ol0003ob;G7olRea`03olRea`;o00001?o=_<T01_l0003odl?;
om?3booC`l_o0000omkFd0Coh]c?0ooVh/l01?l0003ojNS=onWXcOl00002onc]b`0:o`000?o[n<Oo
0000on_i`ol0003ojoZoo`000?oXnk[o0000onOk^0Co000000Coj_Zoon_i_ol0003o00000_o/l//0
1_l0003oj>_@onS[d?l0003ohn;Bo`0000;ofmOC00Co0000om;;dooBbm?o00001?o9_m401Ol0003o
`;C>ol2dc_o0]<ko000000Co^:W;00Oo0000ok2Pb?n`X<So/:38o`000?nQW<oo000000CoV9;<00?o
0000oi6:b?nAR/P00onAR/P00ol0003oRh?5oh^3a@04oh^3a@03ohIm`ol0003oJgO<00CoJgO<00?o
0000ofIabOmVLLT00_mVLLT00ol0003oHVg7of9]a`02of9]a`03o`000?mRKLOo000000Co>f?@00?o
0000oc]RcolkH/l00_lkH/l00ol0003o?6;?ocaRc`02ocaRc`;o@6C?00?o0000ob=Wf_l000008Ooo
ool00ol0003oooooooooo`0<ooooo`009?ooool2o`0003Sooooo00?o:dc1o`000?mMH[l00omMH[l0
0ol0003oGF:noeeR_P05oeeR_P03o`000?mOH[koGf:n00CoGf:n00?o0000ohEg_?n5Mk`02?n5Mk`0
0ol0003oR7ZmohQj_@07ohQj_@04o`000?n=O[ko0000ojB>_P?o00000_nTS[h00ol0003oZ9>oojRC
_`06ojRC_`03o`000?n]V<7o[IS100Go[IS100?o0000ok:N`ol000001oo3[/H00ol0003ob;G7olRe
a`03olRea`03o`000?o=_<WocKc900?ocKc900?o0000om?3booC`l/00_oC`l/00ol0003oh]c?on;L
c`02on;Lc`?oi^;?00Co0000onWXcOoYj<go00000oo/kL/02ol0003ojoS7on_i`ol0003ojoZoo`00
0?oXnk[o0000onOk^?l0003oj?Zg00?o000000CojoVoo`000?l0003o00000_o/l//01Ol0003oj>_@
o`000?oSh];o000000;ofmOC00Go0000om;;dooBbm?od/_Co`000003olVod@05o`000?o0]<ko`;C>
ol2dc_l000001?nhZL/00ol0003o/:38ok2Pb003ok2Pb003o`000?nHT/coV9;<00;oV9;<00?o0000
oi6:b?nAR/P01?nAR/P00ol0003oRh?5oh^3a@03oh^3a@04o`000?n6OL?oQWg3o`0000?oJgO<00?o
0000ofIabOmVLLT00omVLLT00ol0003oHVg7of9]a`03of9]a`03o`000?mPJ/Ko000000?o>f?@00?o
0000oc]RcolkH/l00_lkH/l00ol0003o?6;?ocaRc`02ocaRc`?o@6C?0_l0000Pooooo`?o00003Ooo
ool002Cooooo00?o0000ooooooooool0=oooool2ob]<`@05o`000?mMH[ooGF:ooeeR_ol000001_mM
H[h00ol0003oGf:noemR_P05oemR_P03o`000?n5MkcoQGNl00OoQGNl00?o0000ohQj_On8N[d01on8
N[d00ol0003oSGjno`000002o`0000GoY8jn2?nXTkl00ol0003o[IS1ojfH`@05ojfH`@05o`000?nb
W/?o/Yk3ok:N`ol000001Oo3[/H6olRea`03o`000?o=_<WocKc900?ocKc900?o0000om?3booC`l/0
0_oC`l/2o`0000?oh]c?1?oVh/l2onWXc@06o`000?o/kL_ok>g;onc]bol0003ojoS70_o[nL<02_o[
n[oo0000o`000?oXnk[o0000onOk^?l0003oj?ZgonSj^?l00002on_i_`;o00000_o/l//01_l0003o
j>_@onS[d?l0003ohn;Bo`0000;ofmOC00Co0000om;;dooBbm?o00000oo9_m401Ol0003o`;C>ol2d
c_o0]<ko000000Co^:W;00?o0000ok2Pb?n`X<P01?n`X<P2o`0000?oV9;<00?o0000oi6:b?nAR/P0
0onAR/P00ol0003oRh?5oh^3a@03oh^3a@03o`000?n6OL?oQWg300;oQWg300Co0000of]gc?m[Mlco
00001OmVLLT00ol0003oHVg7of9]a`03of9]a`;o000000GoH6[6o`000?lkHm3o>f?@o`000004oc]R
c`03o`000?llH/oo?6;?00;o?6;?00Go0000od1Tcom0I<oo@6C?o`00000Mooooo`?o00000_ooool0
0ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0gooooo`;o:dc100Co0000oeeR
_omMH[oo00001omMH[h00ol0003oGf:noemR_P04oemR_P03o`000?mSIKko000000OoQGNl00?o0000
ohQj_On8N[d01on8N[d3o`0000;oSGjn00?o0000ojB>__nTS[h00_nTS[h8ojRC_`03o`000?n]V<7o
[IS100Go[IS100?o0000ok:N`onbW/<00onbW/<01?l0003o`jk6ol>^a_o3[/H6olRea`03o`000?o=
_<WocKc900?ocKc900?o0000om?3booC`l/00_oC`l/01Ol0003ofL_<omW;c?l0003oh]c?00Coi^;?
0_oYj<d01?l0003ok>g;onc]boo/kL/2o`0000;ojoW300[ojoZoo`000?o[n[coj?^jonWj^?l0003o
j?ZfonSj]ooXn[So00000_o[nKl01Ol0003okOK5o`000?o/l/_o000000;oj>_@00?o0000on?Rd_l0
00000_oKem<01Ol0003od/_Com;;dooBbm?o000000?obKoA00Go0000ol2dc_o0]<ko`;C>o`000004
okRYb`03o`000?n`X<So/:3800?o/:3800Ko0000ojVHaOnYV<Go0000oiRBc?l00005oi6:b003o`00
0?n;PlGoRh?500CoRh?500?o0000ohIm`on6OL<00on6OL<00ol0003oJgO<o`000004ofIab@03o`00
0?mRKLOoHVg700CoHVg700Oo0000of1Za_l0003oH6[6o`000?lkHm3o000000Co>f;?00?o0000ocaR
collH/l00_llH/l00ol0003o@6C?od1Tc`02od1Tc`03o`000?oooooooooo01Oooooo0ol00005oooo
o`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Kooooo00Oo0000ob]<`Ol[
C<7o:dc1o`000?mMH[oo000000KoGF:n00?o0000oemR__mOH[h01OmOH[h00ol0003oHfFno`000006
ohEg_003o`000?n8N[goR7Zm00GoR7Zm0ol00006ohen_P03o`000?nTS[koY8jn00SoZ9>o00?o0000
ojfH`On]V<401On]V<400ol0003o/Yk3ok:N``04ok:N``03o`000?o3[/Ko`jk600Kob;G700?o0000
olflbOo=_<T00oo=_<T00ol0003odl?;om?3b`02om?3b`05o`000?oIblcofL_<omW;c?l000001?oV
h/l3onWXc@?ok>g;00Co0000ongab?l0003ojoW30_o[n[l01_o[n[co0000onWj^?l0003oj?ZfonSj
]`Co000000?ok?Voo`000?l000000_o/l//:o`000003om;;dol0003obKoA00;obKoA00Go0000ol2d
c_o0]<ko`;C>o`000004okRYb`03o`000?n`X<So/:3800?o/:3800?o0000ojVHaOnYV<D00_nYV<D0
0ol0003oTH[8oi6:b004oi6:b003o`000?n;PlGoRh?500?oRh?500?o0000ohIm`on6OL<01On6OL<0
0ol0003oIW79ofIab@03ofIab@03o`000?mRKLOoHVg700CoHVg700?o0000of1Za_l000000_mPJ/H2
o`0000Co>f;?00?o0000ocaRcollH/l00_llH/l00ol0003o@6C?od1Tc`02od1Tc`03o`000?oooooo
oooo01?ooooo1?l00008ooooo`03o`000?oooooooooo00_ooooo000Sooooo`?o0000=oooool00ol0
003o:dc1ob]<`@02ob]<`@03o`000?mMH[koGF:n00GoGF:n00?o0000oemR__mOH[h01?mOH[h01Ol0
003oHfFnof=U__mSIKko000000CoQGNl00?o0000ohQj_On8N[d00on8N[d3o`000003ohQj_Ol0003o
SGjn00OoSGjn00?o0000ojRC_onXTkl01OnXTkl2o`0000Oo[IS100?o0000ok:N`onbW/<01OnbW/<2
o`0000Kob;G71_o=_<T00ol0003odl?;om?3b`02om?3b`03o`000?oIblcofL_<00;ofL_<00Co0000
onKRcooVh/ooi^;?0ooYj<d3onc]b`04o`000?o]lLSo0000o`0000;ojoZo0_o[n[`8o`000003onci
_ol0003okOK500Co000000Cojnc<o`000?oWhlko00000_oQf/l00ol0003of/o>om[?cP03o`000003
olVodOl0003o`;C>00;o`;C>00?o0000okRYbonhZL/00_nhZL/00ol0003o/:38ok2Pb003ok2Pb003
o`000?nYV<GoZIS500?oZIS50_l00004oi6:b003o`000?n;PlGoRh?500CoRh?500?o0000ohIm`on6
OL<01On6OL<00ol0003oIW79ofIab@03ofIab@03o`000?mRKLOoHVg700?oHVg700Go0000of1Za_mP
J/KoH6[6o`000002of1ZaP03o`000?lkH/oo>f;?00;o>f;?00?o0000ocaRcollH/l00_llH/l00ol0
003o@6C?od1Tc`02od1Tc`03o`000?oooooooooo013ooooo0ol0000=ooooo`03o`000?oooooooooo
00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000ob]<`Ol[C<400_l[C<400ol0003o
GF:noeeR_P04oeeR_P03o`000?mOH[koGf:n00CoGf:n00?o0000of=U__mSIKh00omSIKh01?l0003o
QGNlohEg_?l00003ohQj_@?o00000on8N[d00ol0003oSGjnohen_P07ohen_P03o`000?nXTkooZ9>o
00CoZ9>o00?o0000ojfH`On]V<401_n]V<400ol0003o/Yk3ok:N``05ok:N``03o`000?niYLGo0000
00Gob;G71_o=_<T00ol0003odl?;om?3b`02om?3b`03o`000?oIblcofL_<00;ofL_<00Co0000omkC
cOl0003oi^;?0ooYj<d3onc]b`06o`000?o]lLSo0000onkdaOl0003ojoZo0_o[n[`2o`000003onWj
]_l0003o000000?o000000_ok?Voo`000?o]m/GokOK5o`000?o]l/So0000on_/c?l0003oin?>o`00
0002on7Jc`05o`000?oJclkof/o>om[?c_l000000_oCaL`2o`0000?o`;C>00Go0000okRYbonhZL_o
^:W;o`000005ok2Pb003o`000?nYV<GoZIS500?oZIS500Co0000oj>A`_nSTL;o00000onAR/P00ol0
003oRh?5oh^3a@03oh^3a@03o`000?n6OL?oQWg300GoQWg300?o0000oh5i`Ol000000omVLLT00ol0
003oHVg7of9]a`04of9]a`03o`000?mPJ/KoH6[600;oH6[600Co0000of1Za_mNJLGo00000olkH/l0
0ol0003o?6;?ocaRc`02ocaRc`03o`000?m0I<oo@6C?00;o@6C?00?o0000ooooooooool03Oooool3
o`00013ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0
003o:dc1ob]<`@02ob]<`@03obU:_ol0003oGF:n00CoGF:n00?o0000oemR__mOH[h01?mOH[h00ol0
003oHfFnof=U_P03of=U_P04o`000?n5Mkco0000ohQj_@?o00001On8N[d00ol0003oSGjnohen_P07
ohen_P03o`000?nBPl3o000000CoZ9>o00?o0000ojfH`On]V<401_n]V<400ol0003o/Yk3ok:N``05
ok:N``05o`000?niYLGo^JG5okVUaOl000000oo8]LL6olflb@03o`000?oC`l_odl?;00;odl?;00?o
0000omW;c?oIbl`00_oIbl`01?l0003og]?=omkCcOl00003onWXc@?ok>g;00Co0000ongab?l0003o
k_C50_l00002on_j_0;o000000?ojOZfo`000?oYn[D01?l000002_o/nKoo0000o`000?l0003okO;8
o`000?o[k<co0000onOSc_l00002on7Jc`05o`000?oJclkof/o>om[?c_l000000ooCaL`01Ol0003o
c;_:o`000?o0]<ko000000Co^:W;00?o0000ok2Pb?n`X<P00_n`X<P00ol0003oZIS5ojVHa@03ojVH
a@03o`000?nSTL;oXi7200;oXi7200?o0000oi6:b?l000001On;PlD00ol0003oQWg3ohIm``05ohIm
``05o`000?n1NL7oPGW1oh5i`Ol000000_mVLLT00ol0003oHVg7of9]a`04of9]a`03o`000?mPJ/Ko
H6[600?oH6[600Co0000oeiYaOmNJLGo00000_lkH/l00ol0003o?6;?ocaRc`02ocaRc`03o`000?m0
I<oo@6C?00;o@6C?00?o0000ooooooooool02Oooool4o`0001?ooooo00?o0000ooooooooool02_oo
ool002?ooooo00?o0000ooooooooool0=oooool00ol0003o:dc1ob]<`@02ob]<`@;o:DZo00Go0000
oeeR__mMH[koGF:no`000006oemR_P03o`000?mSIKkoHfFn00GoHfFn0ol00007ohQj_@03o`000?n=
O[koSGjn00OoSGjn00Go0000oi:3`?nBPl3oTX?0o`000003ojRC_`So[IS100?o0000ok:N`onbW/<0
1OnbW/<00ol0003o^JG5okVUa@02okVUa@03o`000?o8]LOob;G700KocKc900?o0000om?3booC`l/0
0_oC`l/00ol0003ofL_<omW;c002omW;c005o`000?oNdlgog]?=omkCcOl000000_oYj<d3onc]b`08
o`000?o]lLSo0000onkdaOl0003ok_O2o`000?o[n[`2o`000003onWj]_l0003o000000;ojOZe1Ol0
00000oo^m/?o0000o`000002on_/c005o`000?oWhlko0000on7Jcol000000ooJclh01Ol0003odlG<
om?5c?oCaLco000000?oc;_:0_l00003okRYb`03o`000?n`X<So/:3800;o/:3800?o0000ojVHaOnY
V<D00onYV<D00ol0003oXi72oj>A`P04oj>A`P03o`000?n;PlGoRh?500CoRh?500?o0000ohIm`on6
OL<01?n6OL<00ol0003oPGW1oh5i`@03oh5i`@03o`000?mVLLWo000000GoHVg700?o0000of1Za_mP
J/H01?mPJ/H01ol0003oGVW5oeiYaOmNJLGo0000oc]Rcol000001?llH/l00ol0003o@6C?od1Tc`02
od1Tc`03o`000?oooooooooo00Kooooo0ol0000Gooooo`03o`000?oooooooooo00[ooooo000Soooo
o`?o0000=oooool00ol0003o:dc1ob]<`@02ob]<`@;o:DZo00Co0000oeeR__mMH[ko00001omOH[h0
0ol0003oHfFnof=U_P02of=U_PCo00002?n8N[d00ol0003oSGjnohen_P07ohen_P03o`000?nBPl3o
TX?000;oTX?000?o0000ojRC_onXTkl02?n]V<400ol0003o/Yk3ok:N``05ok:N``03o`000?niYLGo
^JG500Co^JG500?o0000olflbOo=_<T01?o=_<T00ol0003odl?;om?3b`02om?3b`03o`000?oIblco
fL_<00;ofL_<00Oo0000omkCcOoNdlgog]?=o`000?oTflgo000000?ok>g;00?o0000ongab?o]lLP0
0_l000001Oo^ml;o0000o`000?o[n[cojoZi00;o0000013ojOZdonWj]OoYn[Go0000on_j^_l0003o
kORno`000?o^m/?o0000ongbb?l0003ojnc<o`000?oWhlko00000_oQf/l01?l0003of/o>om[?c_l0
0003om?5c003o`000?o<^l[oc;_:00;oc;_:00Go0000olBbb?l0003o^:W;o`000004ok2Pb003o`00
0?nYV<GoZIS500?oZIS500?o0000oj>A`_nSTL801OnSTL82o`0000CoRh?500?o0000ohIm`on6OL<0
1On6OL<00ol0003oPGW1oh5i`@04oh5i`@03o`000?mRKLOoHVg700CoHVg700?o0000of1Za_mPJ/H0
0omPJ/H00ol0003oGVW5o`000003oeiYa@;o00001?llH/l00ol0003o@6C?od1Tc`02od1Tc`03o`00
0?oooooooooo00?ooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oo
oooooooo03Oooooo00Go0000ob]<`Ol[C<7o:dc1o`000003obU:_`03o`000?mMH[ko000000KoGf:n
00?o0000of=U__mSIKh00ol00002of=U_P03o`000?mWJ<3o000000KoR7Zm00?o0000ohen__n=O[h0
1on=O[h00ol0003oTX?0oi:3`004oi:3`003o`000?n]V<7o[IS100Ko[IS100?o0000ok:N`onbW/<0
1OnbW/<00ol0003o^JG5okVUa@05okVUa@03o`000?o=_<WocKc900?ocKc900?o0000om?3booC`l/0
0_oC`l/00ol0003ofL_<omW;c002omW;c005o`000?oNdlgog]?=omkCcOl000000_oTfld2o`0000;o
k>g;0_o]lLP2o`000007onkg`_l0003okORno`000?o[n[Wo0000onWj]P04o`00000<on_j^_l0003o
kORno`000?o^m/?o0000ongbb?l0003ojnc<o`000?oWhlko00000_oQf/l01?l0003of/o>om[?c_l0
0003om?5c003o`000?o<^l[oc;_:00;oc;_:00Go0000olBbb?o4//Soa;;8o`000004ok2Pb003o`00
0?nYV<GoZIS500?oZIS500?o0000oj>A`_nSTL801OnSTL801?l0003oWXc0oij<`?l00003oh^3a@03
o`000?n6OL?oQWg300CoQWg300?o0000oh5i`On1NL401On1NL400omnM/3o0000of9]a`04of9]a`03
o`000?mPJ/KoH6[600?oH6[600Co0000oeiYaOmNJLGo00000omNJLD00ol0003o?6;?ocaRc`02ocaR
c`03o`000?m0I<oo@6C?00;o@6C?00?o0000ooooooooool00ol0000Mooooo`03o`000?oooooooooo
00[ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0>?ooool01Ol0003o:dc1ob]<`Ol[
C<7o000000Co:DZo00?o0000oemR__mOH[h01OmOH[h3o`0000CoHfFn00Go0000ofMX`?mWJ<3oIfS0
o`000004ohQj_@03o`000?n=O[koSGjn00OoSGjn00?o0000oi:3`?nBPl001OnBPl000ol0003o[IS1
ojfH`@05ojfH`@03o`000?nbW/?o/Yk300Go/Yk300?o0000okVUaOniYLD01OniYLD00ol0003o_jg7
o`000004olflb@Codl?;00?o0000omW;c?oIbl`00_oIbl`01Ol0003og]?=omkCcOoNdlgo000000;o
i=_=00Co0000onSSc?oXhlco00000_o]lLP01?l0003ok_C5o`000?l00002ongh_P04o`000?o[n[Wo
0000onWj]0Oo000000Sok_K3o`000?o]l/So0000on_/c?l0003oin?>o`0000;ohM[?00Co0000om[?
c_oJclko00000ooCaL`00ol0003oc;_:olbkbP02olbkbP03o`000?o4//Soa;;800;oa;;800Go0000
ok2Pb?n`X<So/:38o`000005ojVHa@03o`000?nSTL;oXi7200GoXi7200?o0000oij<`?nNS<000_nN
S<000ol0003oRh?5o`000006ohIm``03o`000?n1NL7oPGW100GoPGW100Co0000ogif`?mnM/3o0000
0omRKLL00ol0003oH6[6of1ZaP04of1ZaP04o`000?mNJLGoGVW5o`0000CoGVW500Go0000ocaRcoll
H/oo?6;?o`000004od1Tc`?o00008?ooool00ol0003oooooooooo`0:ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0hooooo`05o`000?l[C<7o:dc1ob]<`Ol000001?lY
B[l00ol0003oGf:noemR_P02oemR_P?o00001omSIKh01Ol0003oIfS0ofMX`?mWJ<3o000000?oR7Zm
00?o0000ohen__n=O[h01on=O[h00ol0003oTX?0oi:3`005oi:3`003o`000?nHRL;o000000Go[IS1
00?o0000ok:N`onbW/<01OnbW/<00ol0003o^JG5okVUa@05okVUa@05o`000?no[LOo_jg7okn]aol0
00000_o=_<T4om?3b`03o`000?oIblcofL_<00;ofL_<00Go0000omkCcOoNdlgog]?=o`000002onCK
c@05o`000?oXhlcoj>?<onSSc?l000000_o]lLP01Oo^m<Go0000onkg`_l0003okORn00;o000000?o
j_Zfo`000?l000001Ol000002_o]n;ko0000onkf`ol0003okO;8o`000?o[k<co0000onOSc_l00002
on7Jc`04o`000?oJclkof/o>o`0000;odlG<00?o0000olbkb_o<^lX00_o<^lX00ol0003oa;;8olBb
b002olBbb005o`000?nnZLGo0000ok2Pb?l000001_nYV<D00ol0003oXi72oj>A`P04oj>A`P03o`00
0?nNS<3oWXc000CoWXc000?o0000ohIm`on6OL<01?n6OL<00ol0003oPGW1oh5i`@05oh5i`@03o`00
0?mnM/3oOWK000;oOWK000Co0000of9]aomRKLOo00001OmPJ/H00ol0003oGVW5oeiYa@02oeiYa@03
o`000?mNJLGo000000;oGVW500Co0000ocaRcollH/oo00001?m0I<l00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o0000>?ooool00ol0003o:dc1ob]<`@02ob]<
`@03o`000?lYB[oo:DZo00;o:DZo00?o:TZoo`000?mOH[h00_l00002oemR_P03o`000?mSIKkoHfFn
00CoHfFn00?o0000ofMX`?mWJ<000omWJ<000ol0003oR7Zmo`000009ohen_P03o`000?nBPl3oTX?0
00GoTX?000Go0000oiR9`_nHRL;oV8W2o`000003ojfH`@03o`000?nbW/?o/Yk300Go/Yk300?o0000
okVUaOniYLD01OniYLD00ol0003o_jg7okn]a`03okn]a`03o`000?oC`l_odl?;00;odl?;00?o0000
omW;c?oIbl`00_oIbl`01Ol0003og]?=omkCcOoNdlgo000000;oi=_=00Oo0000onSSc?oXhlcoj>?<
o`000?o/j/_o000000;ok_C500Gok_O2o`000?o]n;ko0000onci^P05o`00000=on[j]_l0003o0000
ongh__l0003ok_K3o`000?o]l/So0000on_/c?l0003oin?>o`000002on7Jc`04o`000?oJclkof/o>
o`0000?odlG<00Go0000olbkb_o<^l[oc;_:o`000004olBbb005o`000?nnZLGo_ZW5okjYaOl00000
1_nYV<D00ol0003oXi72oj>A`P04oj>A`P03o`000?nNS<3oWXc000CoWXc00_l00005ohIm``03o`00
0?n1NL7oPGW100GoPGW100?o0000ogif`?mnM/001?mnM/000ol0003oHVg7o`000005of1ZaP03o`00
0?mNJLGoGVW500?oGVW50_l00003oeiYa@03o`000?llH/oo000000Co@6C?00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0gooooo`03o`00
0?l[C<7o:dc100;o:dc100?o0000obU:_olYB[l00_lYB[l3o`0000?oGf:n00?o0000of=U__mSIKh0
1OmSIKh00ol0003oIfS0ofMX`004ofMX`003o`000?n=O[koSGjn00OoSGjn00?o0000oi:3`?nBPl00
1OnBPl000ol0003oV8W2oiR9`P03oiR9`P03o`000?n]V<7o[IS100Oo/Yk300?o0000okVUaOniYLD0
1OniYLD00ol0003o_jg7okn]a`03okn]a`;o00001?oC`l/4omW;c005o`000?oNdlgog]?=omkCcOl0
00000ooTfld01?l0003oj>?<onSSc?l00002oncZb`;o000000Gok_O2o`000?o]n;ko0000onci^P0C
o`000005on7Jcol0003of/o>om[?c_l000000ooCaL`01Ol0003oc;_:olbkb_o<^l[o000000Coa;;8
00?o0000okjYaOnnZLD00_nnZLD00ol0003oZIS5ojVHa@03ojVHa@03o`000?nSTL;oXi7200CoXi72
00?o0000oij<`?nNS<001?nNS<001?l0003oVXNnoiZ7__l00004ohIm``03o`000?n1NL7oPGW100Go
PGW100?o0000ogif`?mnM/001OmnM/000ol0003oH6[6of1ZaP03of1ZaP03o`000?mNJLGoGVW500Go
GVW500?o0000oeiYaOmNJLD00_mNJLD2o`0000Co@6C?00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo00?o0000ob]<
`Ol[C<400_l[C<400ol0003o:DZoo`000003o`000005obY:_ol0003oGf:noemR__l000001omSIKh0
0ol0003oIfS0ofMX`005ofMX`003o`000?n=O[koSGjn00KoSGjn00?o0000oi:3`?nBPl001OnBPl00
0ol0003oV8W2oiR9`P05oiR9`P03o`000?nbW/?o/Yk300Go/Yk300?o0000okVUaOniYLD01OniYLD0
0ol0003o_jg7okn]a`03okn]a`04o`000?o6]/[oa[K:o`0000;odl?;1?oIbl`01Ol0003og]?=omkC
cOoNdlgo000000?oi=_=00Co0000onSSc?oXhlco00000_o/j//01ol0003ok_38o`000?l0003okORn
o`000?o/nKX02Ol000002oo]nKco0000onkg`Ol0003ok_?5o`000?o]klSo0000on_Xbol0003oin7<
00;o000000?of/o>o`000?oCaL`00_oCaL`01Ol0003oc;_:olbkb_o<^l[o000000Coa;;800?o0000
okjYaOnnZLD00_nnZLD00ol0003o^:?3o`000003ojVHa@03o`000?nSTL;oXi7200CoXi7200?o0000
oij<`?nNS<001?nNS<000ol0003oVXNnoiZ7_P02oiZ7_P04o`000?n6OL?oQWg3o`0000OoPGW100?o
0000ogif`?mnM/001_mnM/000ol0003oH6[6of1ZaP03of1ZaP03o`000?mNJLGoGVW500CoGVW50_l0
0005oeiYa@03o`000?m0I<oo@6C?00;o@6C?00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`04o`000?l[C<7o:dc1ob]<`@?o0000
0_lYB[l01ol0003o:TZoobY:_olZB[oo0000oemR__l000001_mSIKh00ol0003oIfS0ofMX`005ofMX
`003o`000?m]K/;o000000KoSGjn00?o0000oi:3`?nBPl001OnBPl000ol0003oV8W2oiR9`P06oiR9
`P03o`000?nbW/?o/Yk300Co/Yk300?o0000okVUaOniYLD01OniYLD00ol0003o_jg7okn]a`03okn]
a`03o`000?o6]/[oa[K:00;oa[K:0_l00003omW;c005o`000?oNdlgog]?=omkCcOl000000ooTfld0
1?l0003oj>?<onSSc?l00002oncZb`04o`000?o^l<So0000onkda0;o000000Cok?Vjo`000?l0003o
j_Ze1Ol000002oo/nKSo0000o`000?o^ml7o0000onkcaOl0003okNo8o`000?o[j<_o000000;oin7<
00?o0000on;IcOl000000ooCaL`01Ol0003oc;_:olbkb_o<^l[o000000Coa;;800?o0000okjYaOnn
ZLD00_nnZLD01ol0003o^:?3okRS`onhXl?o0000ojVHaOl000001_nSTL800ol0003oWXc0oij<`004
oij<`003o`000?nJQkkoVXNn00?oVXNn00?o0000ohIm`ol000001on1NL400ol0003oOWK0ogif`006
ogif`003o`000?mlM;oo000000?oH6[600?o0000oeiYaOmNJLD01OmNJLD00ol0003oGVW5o`000004
oeiYa@03oemZa_l0003o@6C?00;o@6C?00?o0000ooooooooool08Oooool00ol0003oooooooooo`09
ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?oo
ool00ol0003oooooooooo`06ooooo`;o0000>?ooool4o`000003ob]<`Ol0003o:DZo00;o:DZo00?o
0000obY:_olZB[l00_lZB[l00ol0003oHfFnof=U_P05of=U_P03o`000?mWJ<3oIfS000GoIfS000Co
0000ofe^`_m]K/;o00001?n=O[h00ol0003oTX?0oi:3`005oi:3`003o`000?nHRL;oV8W200KoV8W2
00?o0000oinAaOl000001?nbW/<00ol0003o^JG5okVUa@05okVUa@03o`000?no[LOo_jg700?o_jg7
00?o0000olJfb_o6]/X00oo6]/X00ol0003oc[o<o`000002omW;c0?og]?=00Go0000onCKcOoTflgo
i=_=o`000002onSSc009o`000?o/j/_ok>[;o`000?o^l<So0000onkda?l0003ok_O000?o000000?o
j_Zeo`000?l000000_l000003?oZn[Go0000o`000?l0003ok_O1o`000?o^llGo0000ong_b?l0003o
jnS;o`0000;oin7<00?o0000on;IcOoRfLd00_l000000ooCaLco0000olbkbP02olbkbP03o`000?o4
//Soa;;800;oa;;800?o0000okjYaOnnZLD00_nnZLD00ol0003o^:?3okRS``03okRS``03o`000?nS
TL;oXi7200CoXi7200?o0000oij<`?nNS<001?nNS<000ol0003oVXNnoiZ7_P05oiZ7_P03o`000?n1
NL7oPGW100GoPGW100?o0000ogif`?mnM/001_mnM/001Ol0003oO7Boogad_omlM;oo000000;oH6[6
00?o0000oeiYaOmNJLD01?mNJLD01Ol0003oGVW5oeiYaOmNJLGo000000;oGVW500Co0000oemZa_mO
J/Ko00000_m0I<l00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool2
o`0003Oooooo1?l00003ob]<`@05o`000?lYB[oo:DZoobU:_ol000001?lZB[l00ol0003oHfFnof=U
_P04of=U_P03o`000?mWJ<3oIfS000GoIfS000Go0000ofe^`_m]K/;oKFk2o`000003ohen_P03o`00
0?nBPl3oTX?000GoTX?000?o0000oiR9`_nHRL801_nHRL801Ol0003oWi75oinAaOnOTLGo000000;o
/Yk300?o0000okVUaOniYLD01OniYLD00ol0003o_jg7okn]a`03okn]a`03o`000?o6]/[oa[K:00?o
a[K:00Go0000oljoc?o>_lcoc[o<o`000003omkCc@05o`000?oTflgoi=_=onCKcOl000000ooXhl`0
2_l0003ok>[;o`000?o^l<So0000onkda?l0003ok_O0o`000?o]nK`5o`000005on[j]?l0003o0000
o`000?o]nK`00_l000001_o^llGo0000ong_b?l0003ojnS;o`0000;oin7<00Co0000on;IcOoRfLgo
00000_oMd<`01Ol0003oc;_:olbkb_o<^l[o000000Coa;;800?o0000okjYaOnnZLD00_nnZLD00ol0
003o^:?3okRS``03okRS``;o00001OnSTL800ol0003oWXc0oij<`004oij<`003o`000?nJQkkoVXNn
00GoVXNn0_l00006oh5i`@03o`000?mnM/3oOWK000KoOWK000?o0000ogad_omlM;l00omlM;l00ol0
003oH6[6o`000006oeiYa@03o`000?mNJLGoGVW500;oGVW500?o0000oeiYaOl000000omOJ/H00ol0
003o@6C?o`00000Sooooo`03o`000?oooooooooo00Wooooo000Qooooo`03o`000?oooooooooo03?o
oooo0ol00003ooooo`04o`0c^_l0003o:dc1o`0000Co:DZo00?o0000obY:_olZB[l00_lZB[l00ol]
CL7o0000of=U_P04of=U_P03o`000?mWJ<3oIfS000GoIfS000?o0000ofe^`_m]K/800_m]K/800ol0
003oSGjno`000008oi:3`003o`000?nHRL;oV8W200GoV8W200?o0000oinAaOnOTLD00_nOTLD00ol0
003o/Yk3ok:N``07okVUa@03o`000?no[LOo_jg700?o_jg700?o0000olJfb_o6]/X00oo6]/X00ol0
003oc[o<oljoc002oljoc0;o00000_oNdld4onCKc@0:o`000?oXhlcoj>?<o`000?o/j/_o0000onk`
b?l0003ok_C4o`0000;ok_O02Ol000001_o/nKSo0000o`000?o^ml7o0000onkca@;o00000_o[j</0
0ol0003oin7<o`000002on;Ic@04o`000?oMd<cogM3<omg@c0;o000000?oc;_:o`000?o4//P00oo4
//P00ol0003o_ZW5okjYa@02okjYa@03o`000?nhXl?o^:?300?o^:?300Co0000ok>L`OncW<7o0000
0onSTL800ol0003oWXc0oij<`004oij<`003o`000?nJQkkoVXNn00GoVXNn00Co0000oiJ3_OnFPkgo
00001On1NL400ol0003oOWK0ogif`005ogif`003o`000?mlM;ooO7Bo00GoO7Bo00?o0000oeiYaOmN
JLD01OmNJLD00ol0003oGVW5oeiYa@02oeiYa@;o00001OmOJ/H2o`0002Cooooo00?o0000oooooooo
ool02?ooool0027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo0_l000000ol[C<7o0000
obU:_`03obU:_`03o`000?lZB[oo:TZo00;o:TZo0_l]CL401Ol0003oHfFnof=U__mSIKko000000Oo
IfS000?o0000ofe^`_m]K/801?m]K/800ol0003oTX?0oi:3`006oi:3`003o`000?nHRL;oV8W200Go
V8W200?o0000oinAaOnOTLD01?nOTLD00ol0003o^JG5okVUa@05okVUa@03o`000?no[LOo_jg700?o
_jg700?o0000olJfb_o6]/X00oo6]/X00ol0003oc[o<oljoc002oljoc003o`000?oEbLkoeLW>00;o
00000ooTfld01_l0003oj>?<onSSc?l0003ok>[;o`0000;ok_3800Co0000onkda?l0003ok_O00_l0
00000oo/nKSo0000o`000002o`000003on[j]Ol0003ojoVg00;o000000[ok_O1o`000?o^llGo0000
ong_b?l0003ojnS;o`000?oWhLco00000_oRfLd01Ol0003ogM3<omg@c?oMd<co000000;oelO;00?o
0000olBbb?o4//P00_o4//P00ol0003o_ZW5okjYa@02okjYa@03o`000?nhXl?o^:?300?o^:?300?o
0000ok>L`OncW<400_ncW<400ol0003oXi72o`000006oij<`003o`000?nJQkkoVXNn00GoVXNn00?o
0000oiJ3_OnFPkd00_nFPkd01Ol0003oPGW1oh5i`On1NL7o000000OoOWK000?o0000ogad_omlM;l0
1_mlM;l00ol0003oGVW5oeiYa@04oeiYa@03o`000?mNJLGoGVW500CoGVW500?o0000oemZa_mOJ/H0
1?mOJ/H00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`;o0000;_oo
ool3o`0000[ooooo00?o03>jo`000?l000001?lYB[l00ol0003o:TZoobY:_`02obY:_`03o`000?l]
CL7o000000;oHfFn00?o0000ofMX`?mWJ<001_mWJ<000ol0003oKFk2ofe^`P04ofe^`P03o`000?nB
Pl3oTX?000GoTX?000?o0000oiR9`_nHRL801OnHRL800ol0003oWi75oinAa@05oinAa@;o00001Oni
YLD00ol0003o_jg7okn]a`03okn]a`03o`000?o6]/[oa[K:00?oa[K:00?o0000oljoc?o>_l`00_o>
_l`02Ol0003oeLW>omG9c_oEbLko0000omcCcol0003oi=_=o`000002onSSc003o`000?o/j/_o0000
00;ok_3800Ko0000onkda?l0003ok_O0o`000?o]nK`6o`000004on[j]Oo[nKOo0000onci^P;o0000
00Sok_?5o`000?o]klSo0000on_Xbol0003oin7<o`0000;oh]W=00Go0000omg@c?oMd<cogM3<o`00
0002omO7b`;o00000oo4//P00ol0003o_ZW5okjYa@02okjYa@03o`000?nhXl?o^:?300?o^:?300?o
0000ok>L`OncW<400oncW<42o`0000KoWXc000?o0000oiZ7__nJQkh01OnJQkh00ol0003oUX>moiJ3
_@04oiJ3_@03o`000?n1NL7o000000OoOWK000?o0000ogad_omlM;l01_mlM;l00ol0003oNW:oo`00
0005oeiYa@03o`000?mNJLGoGVW500CoGVW50_l00005oemZaP03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3o`0000gooooo00?o0000
o`0c^_l000001?lYB[l00ol0003o:TZoobY:_`02obY:_`06o`000?l]CL7o;Dg1o`000?mSIKko0000
1omWJ<000ol0003oKFk2ofe^`P04ofe^`P03o`000?mdM<Go000000GoTX?000?o0000oiR9`_nHRL80
1OnHRL800ol0003oWi75oinAa@05oinAa@04o`000?nWVLSoYiW8o`0000?o^JG500?o0000okn]aono
[LL00ono[LL00ol0003oa[K:olJfbP03olJfbP03o`000?o>_lcoc[o<00;oc[o<00Go0000omG9c_oE
bLkoeLW>o`000003omcCc`;o000000Coj>?<o`000?o/j/_ok>[;0_o^l<P00ol0003ok_C4o`000002
onkg`0;o000000?ok?Vio`000?l000000ol000001Oo[nKOo0000onci^_l0003okORn00;o000000Wo
kNo8o`000?o[j<_ojnS;o`000?oWhLco0000on;IcOl000000ooMd<`01?l0003oelO;omO7bol00002
om6ob@03o`000?o4//So000000Co_ZW500?o0000okRS`onhXl<00onhXl<00ol0003o/ic1ok>L`@03
ok>L`@03o`000?n^Ukoo000000GoWXc000?o0000oiZ7__nJQkh01OnJQkh00ol0003oUX>moiJ3_@05
oiJ3_@;o00002?mnM/000ol0003oO7Boogad_`05ogad_`05o`000?mjL[ooNW:oogYb_ol000000omN
JLD00ol0003oGVW5oeiYa@04oeiYa@04o`000?mOJ/KoGf[6o`0000?oGf[600?o0000ooooooooool0
8oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?o00004?oo
ool00ol0003o03>jo`000004obU:_`03o`000?lZB[oo:TZo00;o:TZo00Go0000obe=`Ol]CL7o;Dg1
o`000007ofMX`003o`000?m]K/;oKFk200GoKFk200Co0000ogAdaOmdM<Go00000onBPl000ol0003o
V8W2oiR9`P05oiR9`P03o`000?nOTLGoWi7500GoWi7500?o0000ojNIb?nWVLP00_nWVLP00ol0003o
^JG5okVUa@05okn]a`03o`000?o6]/[oa[K:00?oa[K:00?o0000oljoc?o>_l`00_o>_l`01Ol0003o
eLW>omG9c_oEbLko000000Cog=??00?o0000on?Mcol000002_l000001?o]n;ko0000o`000?oZn[H5
o`000005onci^_l0003okORno`000?o^ml800_l00002on_Xb`03o`000?oWhLco000000;oh]W=00Co
0000omg@c?oMd<co00000_oGal/01?l0003odKo9om6obOoA_lT2o`0000Co_ZW500?o0000okRS`onh
Xl<00onhXl<00ol0003o/ic1ok>L`@03ok>L`@05o`000?n^Ukoo[YNoojjG_ol000000onNS<000ol0
003oVXNnoiZ7_P05oiZ7_P03o`000?nFPkgoUX>m00GoUX>m00?o0000oi>1_?l000001omnM/000ol0
003oO7Boogad_`05ogad_`03o`000?mjL[ooNW:o00?oNW:o00Co0000oeiYaOmNJLGo00001_mNJLD0
1?l0003oGf[6oemZa_l00003oemZaP03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?oo
ool0023ooooo00?o0000ooooooooool09Oooool3o`0001Cooooo00?o0000o`0c^_l000000_lYB[l0
0ol0003o:TZoobY:_`03obY:_`05o`000?l]CL7o;Dg1obe=`Ol000001omWJ<000ol0003oKFk2ofe^
`P04ofe^`P03o`000?mdM<GoM7C500;oM7C500?o0000oi:3`?l000002?nHRL800ol0003oWi75oinA
a@04oinAa@03o`000?nWVLSoYiW800CoYiW800?o0000okn]aono[LL00ono[LL00ol0003oa[K:olJf
bP04olJfbP05o`000?o>_lcoc[o<oljoc?l000000ooEbLh00ol0003og=??omcCc`02omcCc`06o`00
0?oSgLoohmg?o`000?oXiLko00000_o/kL/00ol0003okO?7o`000002onkf``?o000000?oj_Zfo`00
0?l000000ol000003?o/nK[o0000ongh__l0003ok_O2o`000?o^m<Ko0000on_Xbol0003oin7<o`00
00;oh]W=00Co0000omg@c?oMd<co00000_oGal/01ol0003odKo9om6obOoA_lWo0000ol^haol00000
0onnZLD00ol0003o^:?3okRS``03okRS``03o`000?ncW<7o/ic100?o/ic100?o0000ojjG_on^Ukl0
0on^Ukl00ol0003oWXc0o`000007oiZ7_P03o`000?nFPkgoUX>m00GoUX>m00Go0000oi>1_?nCPKco
Th6lo`000005ogif`003o`000?mlM;ooO7Bo00GoO7Bo00?o0000ogYb_omjL[l01OmjL[l00ol0003o
GVW5o`000005oeiYa@03o`000?mOJ/KoGf[600;oGf[600?o0000oemZa_l000009_ooool00ol0003o
ooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Rooooo`?o00005oooool01_l0003o03>j
o`0^]_l0003o:DZoo`0000Co:TZo00?o0000obe=`Ol]CL400_l]CL400olbD/?o0000ofMX`004ofMX
`003o`000?m]K/;oKFk200CoKFk200?o0000ogAdaOmdM<D01?mdM<D00ol0003oV8W2oiR9`P06oiR9
`P03o`000?nOTLGoWi7500CoWi7500?o0000ojNIb?nWVLP01OnWVLP2o`0000?o_jg700?o0000olJf
b_o6]/X01?o6]/X01Ol0003oc[o<oljoc?o>_lco000000CoeLW>00Go0000omcCcooLdloog=??o`00
0002on?Mc`03o`000?oXiLko000000;ok>g;00?o0000ongcaol000000_o^m/<2o`000003on_j^_l0
003o000000?o000000goj_Zfo`000?o/nK[okORno`000?o^ml;o0000onkda_l0003okO39o`000?oW
hLco000000;oh]W=00Co0000omg@c?oMd<co00000_oGal/01Ol0003odKo9om6obOoA_lWo000000?o
bkS700?o0000okjYaOl000001OnhXl<00ol0003o/ic1ok>L`@03ok>L`@03o`000?n^Ukoo[YNo00Co
[YNo0_l00007oiZ7_P03o`000?nFPkgoUX>m00GoUX>m00?o0000oi>1_?nCPK`00onCPK`01Ol0003o
OWK0ogif`?mnM/3o000000SoO7Bo00?o0000ogYb_omjL[l01_mjL[l00ol0003oGVW5oeiYa@04oeiY
a@03o`000?mOJ/KoGf[600?oGf[60_l0000Vooooo`03o`000?oooooooooo00Sooooo000Pooooo`;o
00008Oooool2o`0001[ooooo00Co0000o`0c^_l0003o02jf0_l00004obY:_`03o`000?l]CL7o;Dg1
00;o;Dg10_lbD/<00ol0003oIfS0ofMX`002ofMX`003o`000?m]K/;oKFk200CoKFk200?o0000ogAd
aOmdM<D01?mdM<D00ol0003oV8W2oiR9`P05oiR9`P03o`000?nOTLGoWi7500GoWi7500?o0000ojNI
b?nWVLP01?nWVLP01?l0003o[j;;ojnRbol00002okn]a`Koa[K:00?o0000oljoc?o>_l`00_o>_l`0
1Ol0003oeLW>omG9c_oEbLko000000?og=??00Ko0000on?McooSgLoo0000onSUc_l00002onc]b`03
o`000?o]llOo000000;ok_K30_l000000oo[n[[o0000o`000006o`0000;okORn0_l000001?o^m<Ko
0000ong`bOo]l<T2o`0000;oh]W=00Co0000omg@c?oMd<co00000_oGal/01Ol0003odKo9om6obOoA
_lWo000000CobkS70_l00005okRS``03o`000?ncW<7o/ic100?o/ic100?o0000ojjG_on^Ukl01?n^
Ukl00ol0003oZY>no`000006oiZ7_P03o`000?nFPkgoUX>m00GoUX>m00?o0000oi>1_?nCPK`01OnC
PK`00ol0003oOWK0o`000008ogad_`03o`000?mjL[ooNW:o00OoNW:o00?o0000oeiYaOmNJLD00omN
JLD00ol0003oGf[6oemZaP05oemZaP03o`000?oooooooooo02Gooooo00?o0000ooooooooool01ooo
ool0023ooooo00?o0000ooooooooool07Oooool3o`0001gooooo00Go0000o`0c^_l0;[Ko02jfo`00
0004obY:_`03o`000?l]CL7o;Dg100;o;Dg100Co0000oc9B`olbD/?o00000_mWJ<000ol0003oKFk2
ofe^`P04ofe^`P03o`000?mdM<GoM7C500CoM7C500?o0000ogalb?l000001OnHRL800ol0003oWi75
oinAa@05oinAa@03o`000?nWVLSoYiW800CoYiW800?o0000ojnRbon_X//00_n_X//2o`0000Goa[K:
00?o0000oljoc?o>_l`00_o>_l`01Ol0003oeLW>omG9c_oEbLko000000?og=??00Co0000on?McooS
gLoo00000_oXiLh01_l0003ok>g;onc]bol0003okO?7o`0000;ok_K30_l000000oo[n[[o0000o`00
0004o`000003on_j^Ol0003okORn00;o000000Cok_C6o`000?o]l<WokO390ol00002on;Ic@;ogM3<
00Co0000omO7booGal_o00000ooA_lT00ol0003obkS7ol^ha`02ol^ha`03o`000?o6/LKo000000Co
^:?300?o0000ok>L`OncW<400_ncW<42o`0000Ko[YNo00Go0000ojZC__nZTkkoZY>no`000004oiZ7
_P03o`000?nFPkgoUX>m00GoUX>m00?o0000oi>1_?nCPK`01_nCPK`2o`0000SoO7Bo00?o0000ogYb
_omjL[l01omjL[l00ol0003oNG:oo`000004oeiYa@03o`000?mOJ/KoGf[600CoGf[60_l0000Woooo
o`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo0ol0000Pooooo`06
o`000?l0<k[o0000o`0^]_l0;;Go00000olZB[l00ol0003o;Dg1obe=`@02obe=`@07o`000?lbD/?o
<U;3oc9B`ol0003oIfS0o`000006ofe^`P03o`000?mdM<GoM7C500CoM7C500Co0000ogalb?mlO<So
00000onHRL800ol0003oWi75oinAa@05oinAa@03o`000?nWVLSoYiW800CoYiW800?o0000ojnRbon_
X//00on_X//00ol0003o^:g>o`000003olJfbP03o`000?o>_lcoc[o<00;oc[o<00?o0000omG9c_oE
bLh00_oEbLh01?l0003og=??omcCcol00003on?Mc`03o`000?oXiLko000000;ok>g;00?o0000ongc
aol000000_o^m/<2o`000003on_j^_l0003o000000So000000?ok_O2o`000?l000000_o]l<T2o`00
00;oj>K=00Co0000omg@c?oMd<co00000_oGal/01Ol0003odKo9om6obOoA_lWo000000CobkS700Go
0000olJaa_o6/LKoa[76o`000002okRS``03o`000?ncW<7o/ic100;o/ic100?o0000ojjG_on^Ukl0
1On^Ukl00ol0003oZY>nojZC_P03ojZC_P04o`000?nJQkkoVXNno`0000OoUX>m00?o0000oi>1_?nC
PK`01_nCPK`00ol0003oTGjlo`000007ogad_`03o`000?mjL[ooNW:o00OoNW:o00Go0000ogUb_omi
L[ooNG:oo`000003oeiYa@03o`000?mOJ/KoGf[600CoGf[600?o0000ooooool000009_ooool00ol0
003oooooooooo`07ooooo`008?ooool3o`0001Oooooo0ol0000Sooooo`03o`000?l0<k[o03>j00;o
02jf00Go02beo`000?lZB[oo:TZoo`000004obe=`@03o`000?lbD/?o<U;300;o<U;300?o0000ofe^
`_m]K/801?m]K/800ol0003oM7C5ogAda@04ogAda@03o`000?mlO<SoO7c800;oO7c800?o0000oiR9
`_l000001onOTLD00ol0003oYiW8ojNIb005ojNIb003o`000?n_X/_o[j;;00;o[j;;00Oo0000okR]
c_nh[Lko^:g>o`000?o6]/[o000000Coc[o<00?o0000omG9c_oEbLh00_oEbLh01Ol0003og=??omcC
cooLdloo000000;ohmg?00?o0000onSUc_l000000oo/kL/00ol0003okO?7o`000002o`000005onci
_ol0003o0000o`000?oYn[D01Ol000001oo[n[co0000onkg`_l0003ok_C6o`000?o]l<T00_l00002
onSVc@;o00000_oMd<`2omO7b`05o`000?oA_lWodKo9om6obOl000001?o;^<L00ol0003oa[76olJa
aP02olJaaP03o`000?nhXl?o000000Co/ic100?o0000ojjG_on^Ukl01?n^Ukl2o`0000KoZY>n00?o
0000oiZ7__l000001onFPkd00ol0003oTh6loi>1_006oi>1_005o`000?nAO[coTGjloi5n_?l00000
1_mlM;l00ol0003oNW:oogYb_`06ogYb_`03o`000?miL[ooNG:o00;oNG:o00Co0000oeiYaOmNJLGo
00001_mOJ/H01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool01oooool001oo
oooo0_l0000Fooooo`?o00009oooool01?l0003o03>jo`000?l0;[H2o`0/]@03o`000?lZB[oo0000
00Co;Dg100?o0000oc9B`olbD/<00_lbD/<00ol0003oKFk2ofe^`P04ofe^`P03o`000?mdM<GoM7C5
00CoM7C500?o0000ogalb?mlO<P00omlO<P00ol0003oWi75oinAa@05oinAa@03o`000?nWVLSoYiW8
00GoYiW800?o0000ojnRbon_X//00_n_X//00ol0003o^:g>okR]cP03okR]cP;o00000oo>_l`00ol0
003oeLW>omG9cP02omG9cP05o`000?oLdloog=??omcCcol000000_oSgLl01?l0003oj>G>onSUc_l0
0002onc]b`07o`000?o]llOo0000o`000?o]mlGo0000onci_`02o`000007onWj]Ol0003o0000onSj
]_oYn[So0000on_j_003o`000003onkda_l0003okO3900;o00000_oXi/d01?l0003oiMo?o`000?l0
0002omO7b`05o`000?oA_lWodKo9om6obOl000000oo;^<L2o`0000Goa[760_l00004ok>L`@03o`00
0?n^Ukoo[YNo00Co[YNo00?o0000ojZC__nZTkh01_nZTkh2o`0000OoUX>m00?o0000oi>1_?nCPK`0
1_nCPK`00ol0003oTGjloi5n_003oi5n_003o`000?mlM;ooO7Bo00;oO7Bo00?o0000ogYb_omjL[l0
1_mjL[l00ol0003oNG:oogUb_`04ogUb_`03o`000?mNJLGo000000KoGf[600?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo01;ooooo0ol0000Zooooo`03o`000?l0<k[o000000;o02jf0_l0;;D2o`0000?o
;Dg100?o0000oc9B`olbD/<00olbD/<00oliFLOo0000ofe^`P03ofe^`P03o`000?mdM<GoM7C500Co
M7C500?o0000ogalb?mlO<P01?mlO<P00ol0003oWi75oinAa@05oinAa@03o`000?nWVLSoYiW800Co
YiW800?o0000ojnRbon_X//00on_X//00ol0003o^:g>okR]cP03okR]cP05o`000?o2^=7o0000oljo
c?l000001?oEbLh01Ol0003og=??omcCcooLdloo000000?ohmg?00?o0000onSUc_l000000_o/kL/3
o`0000;okOO51_l000002ooXn[Oo0000onWj^?oYn[SojoZlo`000?o[n[oo0000onkda_l0003okO39
00;o00000_oXi/d01Ol0003oiMo?o`000?oQfLoo000000;oelO;0ooA_lT01Ol0003obkS7ol^haoo;
^<Oo000000Koa[7600?o0000ol6[a?l000000oncW<400ol0003o[YNoojjG_`04ojjG_`03o`000?nZ
TkkoZY>n00KoZY>n00?o0000ojN?_Ol000001_nFPkd00ol0003oTh6loi>1_006oi>1_003o`000?nA
O[coTGjl00CoTGjl00Go0000ogad_omlM;ooO7Boo`000008ogYb_`03o`000?miL[ooNG:o00KoNG:o
00?o0000oemZa_mOJ/H01?mOJ/H00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool01oooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo0ol0000]ooooo`05o`00
0?l0<k[o03>jo`000?l0;[H00ol0;;D01Ol0003o;Dg1obe=`Ol]CL7o000000Go<U;30_liFLL01?l0
003oKFk2ofe^`_l00007ogAda@03o`000?mlO<SoO7c800?oO7c800?o0000ohF6c?l000001OnOTLD0
0ol0003oYiW8ojNIb004ojNIb003o`000?n_X/_o[j;;00?o[j;;00?o0000okR]c_nh[Lh00onh[Lh0
1?l0003o`[SAol:hdOo2^=42o`0000CoeLW>00Co0000omcCcooLdloo00000ooSgLl01?l0003oj>G>
onSUc_l00002onc]b`04o`000?o/ll_o0000ongga@;o000000CojoZoo`000?l0003ojOZh0_l00002
onWj^007on_j_?l0003ojoZoon_j_ol0003ok_C6ong`b@02o`0000;oj>K=00?o0000onGOcol00000
0_oQfLl00ol0003oelO;om6ob@02om6ob@05o`000?o;^<OobkS7ol^haol000001_o6/LH01ol0003o
`J_4ol6[a?o1ZlCo0000ok>L`Ol000001_n^Ukl00ol0003oZY>nojZC_P06ojZC_P05o`000?nWSkgo
YhnmojN?_Ol000001?nFPkd00ol0003oTh6loi>1_006oi>1_003o`000?nAO[coTGjl00KoTGjl00?o
0000ogad_ol000002?mjL[l00ol0003oNG:oogUb_`07ogUb_`03ogUc`?l0003oGf[600CoGf[600?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo0004
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo0ol0000aooooo`05o`000?l0<k[o0000o`0^]_l000000_l0;;D01Ol0003o;Dg1
obe=`Ol]CL7o000000Co<U;300Oo0000ocUIaoliFLOo>EW7o`000?m]K/;o000000KoM7C500?o0000
ogalb?mlO<P01?mlO<P01?l0003oQHK<ohF6c?l00003oinAa@03o`000?nWVLSoYiW800GoYiW800?o
0000ojnRbon_X//00_n_X//00ol0003o^:g>okR]cP03okR]cP03o`000?o2^=7o`[SA00;o`[SA00Ko
0000ol_4dol0003o0000omG9c_l00002omcCc`05o`000?oSgLoohmg?on?Mcol000000_oXiLh4o`00
0004onccbol0003okOO5o`0000;ojoZo0_l000001OoYn[So0000o`000?l0003ojOZh00;o00000_o[
n[l2o`000003ong`bOl0003ojnc<00;oj>K=00?o0000onGOcol000000_oQfLl2o`0000?odKo900Go
0000ol^haoo;^<OobkS7o`000005olJaaP;o00001?o1Zl@2o`0000Go[YNo0_l00007ojZC_P;o0000
1OnWSkd01?l0003oUX>moiJ3_Ol00007oi>1_0;o00002OnAO[`2o`0000SoNW:o00?o0000ogUb_omi
L[l01omiL[l01?l0003oNG?0ogUc`?l00004oemZaP03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool01?ooool2o`0000[ooooo0ol0000dooooo`05o`0VZ_l0003o03>j
o`000?l0;[H00ol0;;D01?l0003o;Dg1obe=`Ol00004oc9B``03o`000?liFLOo>EW700;o>EW700?o
0000ogAdaOmdM<D01OmdM<D00ol0003oO7c8ogalb003ogalb003o`000?n5Q/coQHK<00;oQHK<00?o
0000oinAaOl000001onWVLP00ol0003o[j;;ojnRb`03ojnRb`03o`000?nh[Lko^:g>00;o^:g>00?o
0000ol:hdOo2^=400_o2^=400ol0003oblCCol_4d`02ol_4d`co00000_oYkLl01?l0003ok??;o`00
0?l00002on_j_`09o`000?oZn[Wo0000o`000?oXn[Oo0000onWj^?l0003ojoZl00;ojoZo00Go0000
on_i`ol0003okO39on_/c002onSVc@03o`000?oUgloo000000;ohMW?00?o0000omcBcol000000ooA
_lT3ol^ha`03o`000?o6/LKoa[7600?oa[7600?o0000ol6[a?o1Zl@00oo1Zl@00ol0003o_JK3o`00
0004ojjG_`03o`000?nZTkkoZY>n00KoZY>n00?o0000ojN?_OnWSkd01OnWSkd00ol0003oUX>mo`00
0007oi>1_003o`000?nAO[coTGjl00SoTGjl00?o0000ohmm_?l000001omjL[l00ol0003oNG:oogUb
_`07ogUb_`03o`000?miLl3oNG?000;oNG?000Co0000oemZa_mOJ/Ko00002Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3o`0003So
oooo00Go02JZo`000?l0003o02jfo`000002o`0/]@04o`0^]ol0003o;Dg1o`0000Co<U;300?o0000
ocUIaoliFLL00_liFLL00om3Hlgo0000ogAda@04ogAda@03o`000?mlO<SoO7c800CoO7c800?o0000
ohF6c?n5Q/`00on5Q/`2o`0000KoYiW800?o0000ojnRbon_X//00on_X//00ol0003o^:g>okR]cP03
okR]cP05o`000?o2^=7o`[SAol:hdOl000001Oo;a=<01?l0003oe=3DomC@e?l00003omgKe004o`00
0?oTiM?oi>GCo`0000;ojNg?00?o0000onccbol000000_l000000oo[n[oo0000o`000005o`000006
onWj^?l0003ojoZoon_j_ol0003ojoW30_l000001_o[k<coj>K=onSVcOl0003oiMo?o`0000;ohMW?
00Ko0000omcBcooLd/oog=;?o`000?oA_lT3ol^ha`Koa[7600?o0000ol6[a?o1Zl@00_o1Zl@2o`00
00?o_JK300Co0000ojjG_on^Ukoo00002?nZTkh00ol0003oYhnmojN?_@06ojN?_@;o00001onCPK`0
0ol0003oTGjloi5n_008oi5n_005o`000?n?OKcoSgflohmm_?l000001OmjL[l00ol0003oNG:oogUb
_`07ogUb_`03o`000?miLl3oNG?000CoNG?000?o0000oemZa_l000002Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000looooo`04o`0VZ_l0
003o02jfo`0^]P;o02be00Co0000o`0^]ol0003o00001?lbD/<00ol0003o>EW7ocUIa`02ocUIa`;o
@f?=00?o0000ogAdaOmdM<D00_mdM<D00ol0003oO7c8ogalb003ogalb003o`000?n5Q/coQHK<00Co
QHK<0_n@TM000ol0003oYiW8ojNIb003ojNIb003o`000?n_X/_o[j;;00;o[j;;00?o0000okR]c_nh
[Lh00onh[Lh00ol0003o`[SAol:hd@02ol:hd@03o`000?o;a=?oblCC00;oblCC00Co0000omC@e?oD
d=Co00000ooMfm@01?l0003oi>GConCUdol00002onW]c`03o`000?o/ll_o000000;o000000?ojoZo
o`000?oYnkl00ol000002ooVnkWo0000o`000?oXnk[o0000on_j_ol0003ojoW3o`000?oZm/_o0000
00;oj>K=00?o0000onGOcol000000_oQfLl01?l0003og=;?omcBcooLd/l2o`0000?obkS71Oo6/LH2
o`0000Co`J_400?o0000okfV`onmY/<00onmY/<00ol0003o[YNoo`000007ojZC_P;o00002?nWSkd0
0ol0003oY8flo`000006oi>1_003o`000?nAO[coTGjl00OoTGjl0_l00004ohmm_003o`000?mjL[oo
NW:o00;oNW:o00?o0000ogUb_omiL[l01omiL[l00ol0003oNG?0ogUc`006ogUc`003o`000?oooooo
oooo00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool01?l0003ooooooooooooo
ool3o`00043ooooo00Co02JZo`000?l0;[Ko00000_l0;;D2o`0^]`03o`000?lbD/?o<U;300;o<U;3
00?o0000ocUIaoliFLL00_liFLL3od=Sc@04o`000?mdM<GoM7C5o`0000KoO7c800?o0000ohF6c?n5
Q/`00on5Q/`01Ol0003oT97@oi2Ad?n@TM3o000000?oYiW800?o0000ojnRbon_X//00on_X//00ol0
003o^:g>okR]cP02okR]cP03o`000?o2^=7o`[SA00;o`[SA00?o0000ol_4doo;a=<00_o;a=<01Ol0
003oe=3DomC@e?oDd=Co000000;ogM_D00Go0000onCUdooTiM?oi>GCo`000002onW]c`04o`000?o/
ll_o0000on_haP;o00000_oYnkl2o`000004onKk^Ol0003o0000onSk^P?o000000CojoW3o`000?oZ
m/_oj_K;0ooXi/d2onGOc`;ohMW?00Oo0000omcBcooLd/oog=;?o`000?oGc<ko000000;obkS71Oo6
/LH00ol0003o`J_4ol6[a003ol6[a003o`000?nmY/?o_JK300Co_JK30_l00007ojZC_P03o`000?nW
SkgoYhnm00KoYhnm0_l00003ojB=_003o`000?nCPKcoTh6l00;oTh6l00?o0000oi5n_?nAO[`01onA
O[`00ol0003oSgflohmm_005ohmm_004o`000?mjL[ooNW:oo`0000WoNG:o00?o0000ogUc`?miLl00
1_miLl000ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1_ooool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool4o`0004Cooooo
00So01jQo`000?l0;[Ko0000o`0/]Ol0003o02jgo`0000Co<U;300Go0000ocUIaoliFLOo>EW7o`00
0004od=Sc@03o`000?mdM<Go000000GoO7c800?o0000ohF6c?n5Q/`01?n5Q/`00ol0003oT97@oi2A
d002oi2Ad003o`000?nWVLSo000000Go[j;;00?o0000okR]c_nh[Lh00onh[Lh00ol0003o`[SAol:h
d@02ol:hd@03o`000?o;a=?oblCC00;oblCC00Co0000omC@e?oDd=Co00000ooMfm@01?l0003oi>GC
onCUdol00002onW]c`?o00000_o[n<H00ol0003ojO^oonWk_`04o`000007onGl^_l0003o0000o`00
0?o[n[oojoW3o`000002on[fb`03o`000?oXi/goj>K=00;oiMo?0_oQfLl01Ol0003og=;?omcBcooL
d/oo000000;oelc>0_l00005olJaaP03o`000?o1ZlCo`J_400;o`J_40_l00006okfV``03o`000?ni
X/;o000000KoZY>n00?o0000ojN?_OnWSkd01_nWSkd00ol0003oY8flojB=_004ojB=_004o`000?nC
PKcoTh6lo`0000WoTGjl00?o0000ohmm_?n?OK`01_n?OK`00ol0003oNW:oo`000009ogUb_`03o`00
0?miLl3oNG?000KoNG?000?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Kooooo000Nooooo`;o0000Aoooool01Ol07Z7o0000o`000?l0;;Go000000;o02jg
00Go0000oc9B`olbD/?o<U;3o`000003ocUIa`03o`000?m3Hlgo@f?=00?o@f?=00?o0000ogalb?ml
O<P01?mlO<P00ol0003oQHK<ohF6c003ohF6c003o`000?n@TM3oT97@00CoT97@0_l00004ojnRb`03
o`000?nh[Lko^:g>00?o^:g>00?o0000ol:hdOo2^=400_o2^=400ol0003oblCCol_4d`02ol_4d`04
o`000?oDd=Coe=3Do`0000?ogM_D00Co0000onCUdooTiM?o00000ooYkLl01Ol0003ojOK=o`000?o[
n<Ko000000;ojO^o1?l00002onGl^P?o000000OojoW3o`000?oZm/_oj_K;onWdcol0003oj>K=00;o
iMo?0_oQfLl01Ol0003og=;?omcBcooLd/oo000000;oelc>00?o0000om;6c_l000001?o6/LH00ol0
003o`J_4ol6[a002ol6[a003o`000?nmY/?o_JK300Co_JK30_l00003okVR`P04o`000?nZTkkoZY>n
ojZC_P;o00001onWSkd2o`0000OoY8fl00?o0000oi>1_?l000002?nAO[`2o`0000WoSgfl0_l00009
ogUb_`03o`000?miLl3oNG?000KoNG?000?o0000ooooooooool03_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`000?oooooooooo04Gooooo00[o01jQo`00
0?l0;;Go02beo`000?l0;[Oo03Bko`000?lbD/?o00001?liFLL00ol0003o@f?=od=Sc@03od=Sc@03
o`000?mlO<SoO7c800?oO7c800?o0000ohF6c?n5Q/`01?n5Q/`00ol0003oT97@oi2Ad004oi2Ad0;o
VigD00Go0000ojnRbon_X/_o[j;;o`000004okR]cP03o`000?o2^=7o`[SA00;o`[SA00?o0000ol_4
doo;a=<00_o;a=<01Ol0003oe=3DomC@e?oDd=Co000000;ogM_D00Go0000onCUdooTiM?oi>GCo`00
0002onW]c`04o`000?oYm/go0000on_haP;o000000?ojO^oo`000?l000000_l00002onGl^P;o0000
00?oiOc1o`000?o[nL<00_oZm//00ooYm<oo0000o`000002onGOc`?ohMW?0_oLd/l2o`0000;oelc>
00Co0000om;6c_oBa/ko00000oo6/LH4ol6[a0;o00001OnmY/<2o`0000Go^J;200Co0000ojZC__nZ
Tkko00001onWSkd2o`0000WoY8fl0_l00008oi5n_003o`000?n?OKcoSgfl00SoSgfl00?o0000ohel
_?l000002?miL[l00ol0003oNG?0ogUc`006ogUc`003o`000?oooooooooo013ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`15ooooo`07
o`0NXOl0003o02beo`000?l0;[Oo0000o`0d^`02o`0000Co>EW700?o0000od=ScOm3Hld00om3Hld0
0om?Km?o0000ogalb003ogalb003o`000?n5Q/coQHK<00?oQHK<00?o0000oi2Ad?n@TM001?n@TM00
1ol0003oVigDoi^Me?nKWMCo0000ojnRbol000001?nh[Lh00ol0003o`[SAol:hd@03ol:hd@03o`00
0?o;a=?oblCC00;oblCC00Co0000omC@e?oDd=Co00000ooMfm@01Ol0003oi>GConCUdol0003ojNg?
00;o00000_oYm/d2o`000003onSjaOl0003o000000;o000000?ohoblo`000?oUo;X00_l00002onGl
`@08on_i`ooZm/_oj_K;onWdcol0003oio7Bo`000?oUgll3on7Ic`;og=;?00Go0000omO<c_oGc<ko
elc>o`000004om;6cP03o`000?o6/LKo`J_400?o`J_400?o0000okfV`onmY/<01?nmY/<00ol0003o
^J;2okVR`P05okVR`P03o`000?nZTkko000000OoYhnm00?o0000ojB=_?nTSK`01onTSK`2o`000003
oj6:_?l0003oTGjl00KoTGjl00?o0000ohmm_?n?OK`02?n?OK`01Ol0003oSGblohel_?n=O;co0000
00KoNG:o00?o0000ogUc`?miLl001_miLl000ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01Oooool002;ooooo00?o0000ooooooooool0A?ooool2o`000004
o`0/]Ol0003o02jgo`0^]`;o03Bk00?o0000ocUIaoliFLL00_liFLL00ol0003o@f?=od=Sc@03od=S
c@;oCfoC00Co0000ogalb?mlO<So00001_n5Q/`00ol0003oT97@oi2Ad004oi2Ad003o`000?nKWMCo
VigD00;oVigD0_l00004okR]cP03o`000?o2^=7o`[SA00;o`[SA00?o0000ol_4doo;a=<00_o;a=<0
1Ol0003oe=3DomC@e?oDd=Co000000;ogM_D00Co0000onCUdooTiM?oi>GC0_l000001OoVlM?o0000
onWfcOoYm/go000000;oj?[50ol00002on?l_003onGl^_oRoKgo000000;oiOc100Ko0000on[fbooZ
m/_ojOC?o`000?oWlM82o`0000?ohMW?0_oLd/l00ol0003oelc>omO<cP02o`0000Cod/K>0_l00004
ol6[a003o`000?nmY/?o_JK300?o_JK30_l00008okVR`P;o00001_nWSkd2o`0000WoY8fl00?o0000
oj6:_?nQR[`00_nQR[`00ol0003oTGjloi5n_002oi5n_0;o00002On?OK`2o`0000GoSGbl00?o0000
ogUb_omiL[l00_miL[l00ol0003oNG?0ogUc`006ogUc`003o`000?oooooooooo01Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`05ooooo`008oooool2o`0004Gooooo0_l000001_l0
;;Go0000o`0^]ol0003o03Bko`0000Co>EW700?o0000od=ScOm3Hld00_m3Hld01ol0003oCfoCodm_
dom?Km?o0000ogalb?l000001_n5Q/`00ol0003oT97@oi2Ad003oi2Ad003o`000?nKWMCoVigD00?o
VigD00Ko0000ojR[fOl0003o0000okR]c_l00005ol:hd@05o`000?o;a=?oblCCol_4dol000000ooD
d=@01_l0003ogM_DomgKe?oMfmCo0000onCUd`;o00000_oVlM<01?l0003ojOK=o`000?l00002onSj
a@;o000000Coi?g0o`000?oSo;coiObj0_oRoKd2onGl`@09on?maOoZm/_oj_K;onWdcol0003oio7B
o`000?oTk]Ko000000;ohMW?0_oLd/l01?l0003oelc>omO<c_l00005om;6cP03o`000?o>`<go0000
00?o`J_400?o0000okfV`onmY/<00_nmY/<2o`0000So^J;20_l000000oneW/7o0000ojN?_@04ojN?
_@03o`000?nTSKcoY8fl00OoY8fl0_l00006oj6:_004o`000?nAO[coTGjlo`0000[oSgfl00?o0000
ohel_?n=O;`01On=O;`01Ol0003oNG:oogUb_omiL[oo000000SoNG?000?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo000Uooooo`03o`000?oooooo
oooo04?ooooo0ol00002o`0^]`;o03Bk00Go0000ocUIaoliFLOo>EW7o`000004od=Sc@03o`000?m?
Km?oCfoC00;oCfoC0_l00005ohF6c003o`000?n@TM3oT97@00?oT97@00?o0000oi^Me?nKWM@00onK
WM@00ol0003oZ:_IojR[f@02ojR[f@Co00000_o2^=400ol0003oblCCol_4d`02ol_4d`04o`000?oD
d=Coe=3Do`0000?ogM_D0ol000001?oPjMWo0000onKadooVlM<2o`000005onKicOl0003oj?[5o`00
0?oVo<<00_l000001?oSo;co0000on;m_OoRoKd2onGl`@07on?maOoZm/_oj_K;onWdcol0003oio7B
o`000002onC^eP04o`000?oQfLoog=;?omcBc`?oelc>00?o0000om;6c_oBa/h00_oBa/h2o`0000?o
c/3=00?o0000ol6[a?nmY/<01?nmY/<00ol0003o^J;2okVR`P06okVR`P;o00001?neW/400ol0003o
YhnmojN?_@02o`0000SoY8fl0_l00008oj6:_003o`000?nAO[co000000[oSgfl00?o0000ohel_?n=
O;`01on=O;`00ol0003oNG:oo`000008ogUc`003o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`05ooooo`009_ooool00ol0003oooooooooo`13ooooo`;o0000
0_l0;[L01_l0003o03Bko`000?l0003o>EW7o`0000Go@f?=00?o0000odm_dom?Km<00_m?Km<2oeim
f@03o`000?n5Q/coQHK<00;oQHK<00?o0000oi2Ad?n@TM000on@TM000ol0003oVigDoi^Me003oi^M
e003o`000?nXZmWoZ:_I00;oZ:_I00Co0000okFhg?ne^=co]KSL1?l00002ol_4d`04o`000?oDd=Co
e=3DomC@e0Co00000ooPjMT00ol0003oi_7ConKad`02o`0000;oi_W=0_l000001OoVo<?o0000o`00
0?oSo;co000000;oh_fm0_oUo<401ooSoLGo0000on[fbooYm<oo0000onOad_l000000_oTk]H2o`00
00;og=;?0ooGc<h01?l0003od/K>om;6c_oBa/h2o`0000Coc/3=0_l00004okfV``;o00001oniX/82
o`0000Ko]Ik100?o0000ojN?_Ol000002?nTSK`2o`0000[oXHZl0_l00009ohmm_0;o00002_n=O;`2
o`0000SoNG?000?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo0_l000001Ol0;[Oo0000o`0d^ol0003o
03k200;o00001Om3Hld00ol0003oCfoCodm_d`02odm_d`?oGWgI00Co0000ohF6c?n5Q/co00001On@
TM000ol0003oVigDoi^Me003oi^Me003o`000?nXZmWoZ:_I00;oZ:_I00?o0000okFhg?ne^=`00one
^=`00ol0003o`/KNol;6gP07o`0000;of>3M00Go0000on3YfOoPjMWoh>WIo`000002onKad`03o`00
0?oVnLgoi_W=00;o000000coi_c3o`000?oToL3o0000omon`?l0003oh_fmo`000?oUo<7ohog5o`00
0?oZm//2onWdc`08onOad_l0003oi>kFonC^e_l0003ohN[Ho`000?oLd/l3omO<cP05o`000?oBa/ko
d/K>om;6c_l000001?o>`<d2o`000004olVjc?l0003o_JK3okfV``;o00001oniX/82o`0000So]Ik1
0_l00008ojB=_003o`000?nQR[coXHZl00SoXHZl0_l000000onORKco0000ohmm_007ohmm_003o`00
0?n=O;coSGbl00WoSGbl00?o0000oham_Ol000001omiLl000ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Sooooo0_l00014ooooo`;o000000Ko
02jgo`000?l0=;_o0000o`0n`_l00005od=Sc@03o`000?m?Km?oCfoC00;oCfoC00Oo0000oeimfOmN
OMWoGWgIo`000?n5Q/co000000GoT97@00?o0000oi^Me?nKWM@00onKWM@00ol0003oZ:_IojR[f@02
ojR[f@03o`000?ne^=co]KSL00;o]KSL00?o0000ol;6g_o2a]h00_o2a]h01Ol0003oc]CNolkDg_o>
e=ko000000;of>3M00Ko0000on3YfOoPjMWoh>WIo`000?oVlM<2o`0000;oi_W=0_l000002_oVo<?o
0000onCm`?l0003ogok0o`000?oRoKgo0000onGl`OoSoLD2o`0000;ojOC?00Koio7Bo`000?oTk]Ko
i>kFo`000?oQj]P2o`0000?oelc>0ooBa/h2o`0000Coc/3=00?o0000olVjc?o9^/`00_o9^/`2o`00
00So^J;200?o0000okFN`OneW/401_neW/42o`000003ok:K`?l0003oY8fl00GoY8fl0_l00009oj6:
_0;o00001?nORK`00ol0003oSgflohmm_004ohmm_003o`000?n=O;coSGbl00SoSGbl0_l00003oham
_@03o`000?miLl3oNG?000?oNG?000?o0000ooooooooool07?ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooooooo04;ooooo0ol000001Ol0=;_o
0000o`0n`_l0C<_o000000Co@f?=00Go0000odm_dom?Km?oCfoCo`000005oeimf@;o00001?n@TM00
0ol0003oVigDoi^Me003oi^Me003o`000?nXZmWoZ:_I00;oZ:_I00?o0000okFhg?ne^=`00one^=`0
1Ol0003o`/KNol;6g_o2a]ko000000?oc]CN00Go0000omSPgOoHh=gof>3Mo`000002on3Yf@?o0000
00CohoOFo`000?oVnLgo00000_oSoL/3o`00000;omon`?l0003oh_fmomgn`Ol0003ohog5o`000?oN
o/ko0000onWdcooWlM800_oTk]H2o`000004on7Zf?l0003ogNKJo`0000;oelc>0ooBa/h00ol0003o
c/3=olk0c@02olk0c@;o00001?o9^/`2o`0000Oo^J;20_l00007okFN`@;o00000onbVl000ol0003o
Y8flojB=_002ojB=_0;o00002_nQR[`00ol0003oWhVloin9_004oin9_003o`000?n?OKcoSgfl00;o
Sgfl0_l0000:ohel_003o`000?n<OKgoS7fm00CoS7fm00Go0000ogUc`?miLl3oNG?0o`00000Poooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool002_ooooo00?o0000oooooooo
ool0@oooool01ol0003o03Bko`0d^ol0003o03k2o`1<bol000000om3Hld01Ol0003oCfoCodm_dom?
Km?o000000GoGWgI0_m_SN001?l0003oT97@oi2Ad?l00006oi^Me003o`000?nXZmWoZ:_I00;oZ:_I
00?o0000okFhg?ne^=`00_ne^=`00ol0003o`/KNol;6gP02ol;6gP05o`000?o>e=koc]CNolkDg_l0
00000ooHh=d01?l0003oh>WIon3YfOl00003on?geP;o00000_oSoL/01Ol0003oh?k6on3na_l0003o
gok000?o000000Kohog5o`000?oNo/ko0000onWdcooWlM82onC^eP04o`000?oQj]So0000o`0000;o
gNKJ00Co0000omO<c_oBa/kod/K>0_l00003olk0c@;o00001?o9^/`2o`000003olFfc?l0003o^J;2
00Co^J;20_l00007okFN`@;o00001_nbVl001?l0003oY8flojB=_?l0000:oj6:_0;o00002?nORK`0
1?l0003oSgflohmm_?l0000:ohel_0;o00002?n<OKd00ol0003oNG?0o`00000Rooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@oooool0
2Ol0003o03Bko`000?l0?/;o0000o`1<bol0003o@f?=o`000004odm_d`03o`000?mNOMWoGWgI00?o
GWgI0om_SN000ol0003oT97@o`000005oi^Me003o`000?nXZmWoZ:_I00;oZ:_I00?o0000okFhg?ne
^=`00one^=`01Ol0003o`/KNol;6g_o2a]ko000000?oc]CN00Ko0000omSPgOoHh=gof>3Mo`000?oP
jMT2o`0000?ohoOF0_l00002on?mb`03o`000?oPo/Koh?k600Co000000Cof?o5o`000?l0003og_k>
0_l000001_oWlM;oi>kFonC^e_l0003ohN[Ho`0000?ogNKJ0_l00002om;6cP03o`000?o>`<goc/3=
00;oc/3=00?o0000olVjc?o9^/`00_o9^/`2o`0000?oaKK<00Co0000okVR`_niX/;o^J;20_l00007
okFN`@;o00002?nbVl03o`0000WoXHZl0_l0000:oin9_003o`000?n?OKco000000WoSGbl0_l0000:
oham_@;o00008oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000]oooo
o`;o0000@oooool01Ol0?:Oo0000o`0d^ol0003o03k200;o04c;0_l00004odm_d`03o`000?mNOMWo
GWgI00?oGWgI00Co0000ofn=h?m_SN3oKhgP0_l00005oi^Me003o`000?nXZmWoZ:_I00;oZ:_I00?o
0000okFhg?ne^=`00_ne^=`00ol0003o`/KNol;6gP02ol;6gP05o`000?o>e=koc]CNolkDg_l00000
0ooHh=d2o`000004omcbg_l0003ohoOFon?geP;o00000_oSoL/00ol0003oh?k6on3naP04o`000007
omSoaOl0003o0000omknc_l0003of_kDo`000002onC^eP?o00000_oMi]X2o`000003omWQg?l0003o
d/K>00Coc/3=0_l00004olVjc003o`000?o5]/coaKK<00CoaKK<0ol00007okFN`@;o00002OnbVl02
o`0000WoXHZl0_l0000<oin9_0;o00002On=O;`00ol0003oS7fmoham_@09oham_@03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`00;oooool00ol0
003oooooooooo`12ooooo`;o000000Co03k2o`000?l0C<_o04c;0_l00003odm_d`03o`000?mNOMWo
GWgI00;oGWgI00?o0000ofn=h?m_SN000_m_SN02oh6NiP;o00000_nKWM@00ol0003oZ:_IojR[f@03
ojR[f@05o`000?ne^=co]KSLokFhg?l000001?o2a]h00ol0003oc]CNolkDgP02olkDgP05o`000?oH
h=gof>3MomSPgOl000000_oLl]h01ol0003ohoOFo`000?oNo=Co0000on?mbol000000_oPo/H01?l0
003ofOo5o`000?oHolD2o`0000;og_k>0ol00002onC^eP;o00000ooMi]X00ol0003ofN7LomWQg002
o`0000?oc/3=0_l00004olVjc0;o00001_o5]/`2o`0000Oo]Ik10_l00009ok:K`0;o000000?o[iW0
o`000?nQR[`01_nQR[`2o`0000coWhVl0_l000000onMR;go0000ohel_006ohel_0;o00002_n<OKd2
o`0002Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`00<?ooool00ol0
003oooooooooo`12ooooo`05o`000?l0?/;o03k2o`000?l0C</00_l8G]H00ol0003oCfoCo`000005
oeimf@03o`000?m_SN3oKhgP00;oKhgP1?n1W^H00ol0003oVigDo`000004ojR[f@03o`000?ne^=co
]KSL00;o]KSL00?o0000ol;6g_o2a]h00_o2a]h01Ol0003oc]CNolkDg_o>e=ko000000;of>3M0_l0
0002omcbgP03o`000?oSmmKo000000?og_cD1?l000000ooIolGo0000omSoa@02o`000009omknc_l0
003o0000o`000?oFo][o0000onC^e_oQj]So000000;ogNKJ0_l000001OoIhMco0000o`000?oDg=go
000000;oc/3=00?o0000olVjc?o9^/`00_o9^/`2o`0000GoaKK<0ol000000oo1//_o0000okFN`@04
okFN`@;o00002?nbVl03o`0000Co[iW000?o0000oj6:_?nQR[`00onQR[`00ol0003oWhVloin9_00:
oin9_0;o00001?nMR;d00ol0003oSGblohel_003ohel_003o`000?n<OKgoS7fm00SoS7fm0_l0000[
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0037ooooo0_l00013oooo
o`?o00000_l0C</2o`QNeP;o00001OmNOMT00ol0003oKhgPofn=h002ofn=h003o`000?n1W^KoPIkV
00;oPIkV1?l00002ojR[f@05o`000?ne^=co]KSLokFhg?l000001?o2a]h00ol0003oc]CNolkDgP02
olkDgP?o000000Codn_Uo`000?oLl]kog?;N0_l00004omkle003o`000?oJolgo000000;o000000_o
f?o5o`000?l0003og_k>o`000?oJo]Co0000omKnf_l0003oi>kFo`000002omgVfP;o000000?ofN7L
o`000?l000000ooDg=d00ol0003oc/3=o`000003olVjc0;o00001Oo5]/`2o`0000Co`K;;00Co0000
okFN`OneW/7o]Ik10_l00008ok:K`0;o00001on_VL001?l0003oXHZloj6:_?nQR[`2o`0000_oWhVl
0_l00007oif8_@03o`000?n=O;coSGbl00;o00002_n<OKd00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00oooool003?ooooo00?o0000ooooooooool0@Ooo
ool3o`000004o`1<bol0003o25kFo`QNeP;o00001?mNOMT00ol0003oKhgPofn=h002ofn=h003o`00
0?n1W^KoPIkV00;oPIkV1?nD/N/4o`0000;o]KSL00?o0000ol;6g_o2a]h00_o2a]h00ol0003oc]CN
o`000002o`0000?odn_U00?o0000omcbg_oLl]h00_l00004omkle005o`000?oJolgo0000o`000?oA
ol/00ol000001OoNo/ko0000om[ne?l0003oe_kJ00?o000000CogNKJo`000?l0003ofN7L0_l00004
omCLg@;o00001?o9^/`00ol0003oaKK<olFfc002olFfc0?o00001oo1///3o`0000So/Y_00_l00009
ojnI`004o`000?nQR[co0000o`0000_oWhVl0_l00009oif8_@03o`000?n=O;co000000[oS7fm0_l0
000_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool003Cooooo00?o0000
ooooooooool0@_ooool00ol0003o04c;o`1<b`02o`QNeP;o7gCR00Go0000oeimfOmNOMWoGWgIo`00
0004ofn=h003o`000?n1W^KoPIkV00;oPIkV1OnD/N/00ol0003oY/;^ojK2kP09o`0000;oan3[00Wo
0000om?[iOoCjnGodn_Uo`000?oLl]ko0000omOkg_l000000ooNo=@00ol0003of_o=o`000002om7o
b`06o`000?oAolWob?o>o`000?oJo]Co00000_oFo]X2o`0000;ogNKJ00Co0000omWQg?l0003o0000
1?oDg=d2o`000005om3Gg_l0003obK[<olVjc?l000001?o5]/`2o`0000Wo`K;;0_l00008ok:K`0;o
00002on_VL02o`0000[oWhVl0ol0000;oif8_@;o00002_n<OKd00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0
@_ooool00ol0003o04c;o`000002o`QNeP;o7gCR00?o0000oeimfOl000001?m_SN000ol0003oPIkV
oh6NiP02oh6NiP03o`000?nD/N_oU;7[00?oU;7[00Go0000ojK2k_nV`^koY/;^o`000004okSBkP03
o`000?o7h>_oan3[00;oan3[00Co0000om?[iOoCjnGodn_U0_l00003omOkgP03o`000?oNo=Co0000
00;o00000_oAol/2o`000005olSoc_l0003of_kDo`000?oFo]X00ol000001OoMi][o0000omWQg?oI
hMco000000?oe=cM0ol00003om3GgP03o`000?o9^/co000000;oaKK<0ol00008ol6bb`?o000000?o
_Jk;o`000?nbVl001OnbVl02o`0000[o[iW00ol000000on/Ul7o0000oin9_007oin9_0;o00002onM
R;d3o`000003oib8__l0003oS7fm00OoS7fm0_l0000dooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00oooool003Kooooo0_l00013ooooo`;o00000_l8G]H00ol0003o7gCRoamdhP02
o`0000CoKhgP00?o0000oh6Ni_n1W^H00_n1W^H00ol0003oU;7[oiBaj`02oiBaj`03o`000?nV`^ko
Y/;^00;oY/;^00?o0000okSBk_nhd^h00_nhd^h00ol0003oan3[olOPj`02olOPj`03o`000?oCjnGo
dn_U00;o00001?oGnmh4o`000003om7obol0003o000000?o000000?of_kDo`000?l000000_l00000
1?o;nnGo0000o`000?oIhM`2o`0000;oe=cM0_l00004om3GgP?o00000_o5]/`2o`0000So`K;;0ol0
0004okf^b`04o`000?nbVl3o/Y_0ok:K`0?o00002On_VL03o`0000Go[9O100?o0000oin9_?nORK`0
0onORK`2o`0000_oWHRm0_l00005oib8_P03o`000?n<OKgoS7fm00CoS7fm00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000hooooo`03o`000?oo
oooooooo047ooooo00Go04c;o`000?l8G]Ko25kFo`000002oamdhP;o00000om_SN000ol0003oPIkV
oh6NiP02oh6NiP03o`000?nD/N_oU;7[00;oU;7[00?o0000ojK2k_nV`^h00_nV`^h00ol0003o^=;^
okSBkP02okSBkP05o`000?o7h>_oan3[olOPjol000000_oCjnD2o`0000Coeo_N00?o0000om7oeOoA
omD01_l000000onloM?o0000omKnfP02o`000003ol_kiOl0003o000000;ofN7L00?o0000omCLgOoD
g=d00_l00003om3GgP?o00000_o;d]l3o`0000Oo`K;;0ol00008okf^b`?o00002_n_VL02o`0000So
[9O100Co0000oin9_?nORKcoWhVl0_l0000:oif8_@?o00001onLR;h00ol0003oS7fmoham_@02oham
_@;o0000>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03
o`000?oooooooooo047ooooo00Co0000o`QNe_l8G]Ko00000_lOM>82ocZ=kPCo00001?n1W^H00ol0
003oU;7[oiBaj`02oiBaj`03o`000?nV`^koY/;^00;oY/;^00Go0000okSBk_nhd^ko^=;^o`000004
olOPj`?o000000?ocOSXo`000?oGnmh00_oGnmh00ol0003odOoEom7oe@02o`000005olGod?l0003o
0000o`000?nloM<00ol000001?o;nnGo0000o`000?o5nN/2o`0000;oe=cM0_l00002om3GgP?o0000
0_o;d]l3o`0000Oo`K;;0ol00009okf^b`?o00002On_VL03o`0000[o[9O100Co0000oin9_?l0003o
00002_nMR;d2o`0000[oW8Rn00?o0000oham_On<OKd00_l0000kooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool003[ooooo00?o0000ooooooooool0@Oooool3o`0000?o7gCR
1?ljSNh2o`0000?oPIkV00?o0000oiBajonD/N/00_nD/N/01Ol0003oY/;^ojK2k_nV`^ko000000Co
^=;^00Co0000olOPjoo7h>_oan3[0_l00004olghj003o`000?oGnmko000000?o000000GoaOo@o`00
0?l0003o0000okcmd`03o`000004ol_kiOl0003o0000olGij`;o00000_oDg=d2o`000004om3Gg_l0
003o0000o`0000;obm;O0ol00002olK=g`03o`000?o1//_o`K;;00;o`K;;0ol00008okf^b`Co0000
0_niZl/00ol0003o[iW0ojnI`005ojnI`0;o00003?n/Ul43o`0000[oWHRm0_l0000=oib8_P;o0000
?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000kooooo`;o0000@ooo
ool01Ol8G]Ko0000oamdh_lOM>;o000000?o>Xg^0_mHYoP3o`0000GoU;7[00Go0000ojK2k_nV`^ko
Y/;^o`000004okSBkPCo000000?o__7bo`000?o=n>P00oo=n>P3o`000003olGngol0003oaOo@00;o
000000Go_?gCo`000?l0003o0000ol_ki@05o`000004okkel?l0003o0000om3GgP?o00000_o;d]l3
o`0000Goa/gO00?o0000ol6bboo1///00_l00008okf^b`?o00001_niZl/00ol0003o[iW0ojnI`002
ojnI`0?o00002_n/Ul44o`0000;oZYK100?o0000oif8_OnMR;d01OnMR;d3o`0000koW8Rn0_l0000o
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003gooooo00?o0000oooo
ooooool0@Oooool01Ol0003o7gCRoamdh_lOM>;o000000?o>Xg^0omHYoP4o`000003oiBajol0003o
Y/;^00?oY/;^00?o0000okSBk_nhd^h00ol00004okkalP03o`000?o=n>SocOSX00;o00000oo5o]l0
0ol0003oaOo@o`000006o`000004olGijol0003o0000okkel0?o000000?od=ONo`000?l000000oo;
d]l2o`0000Koa/gO1?l00007okf^b`Co00002_niZl/4o`0000[o[9O10ol00007ojZF`@03o`000?nM
R;goWHRm00;oWHRm0_l0000>oib8_P?o0000@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo000nooooo`03o`000?oooooooooo047ooooo0_l000000olOM>;o0000ocZ=kP02
ocZ=kP04o`000?mHYoSoF:Oho`0000?oMl3m2Ol00002oj_VnP03o`000?nnlO;o__7b00?o__7b0_l0
0004olGng`Co000000?o[_[Go`000?l000000ol000000onnmO3o0000o`000004o`0000?obm;O0_l0
0004olK=g`Go00000_o1b>000ol0003o_Jk;okf^b`02okf^b`Co00003?niZl/3o`0000Wo[9O11?l0
000:ojZF`@03o`000?nMR;go000000;o00003OnLR;h3o`0004Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00?oooool00ol0003oooooooooo`11ooooo`?o00001?ljSNh0
1?l0003oF:OhoeRWn?l00003ogO0o@03o`000?nCe_koTmKn00;oTmKn00?o0000oj_Vn_n[i_X00on[
i_X01?l0003o__7bokkal_nnlO89o`0000;o[_[G00?o0000ol_kiOl000001_l00002ojk[n004o`00
0?o;d]oobm;Oo`0000;oa/gO1Ol00007ol78h003o`000?nm[/_o_Jk;00;o00002oniZl/5o`0000;o
]ZS;00?o0000ojbG`On/Ul400on/Ul44o`0000goZYK10ol0000=oib8_P?o0000B_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0010ooooo`;o0000@oooool3o`0000;o>Xg^
00Co0000oeRWn?mHYoSo00001?mg`?d00ol0003oTmKnoi?FoP02oi?FoP03o`000?n[i_[oZnKj00;o
ZnKj00Co0000okkal_l0003o00001?ndn^P3o`0000;o[_[G1Ol000000onflOGo0000ojk[n002ojk[
n0Co000000?oa/gOo`000?l000000_l00009ol78h0Go00002OniZl/5o`0000So]ZS;00?o0000ojbG
`Ol000000_l0000=ojZF`@Co00000_nXUL800ol0003oW8Rnoib8_P09oib8_P;o0000COooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0012ooooo`03o`000?oooooooooo04;o
oooo1?l00003oeRWn003o`000?mg`?goMl3m00;oMl3m00Go0000oi?Fo_nCe_koTmKno`000003oj_V
nP?o000000?o]?[Xo`000?l000001?l000000on^n]Oo0000ohS/g@03o`000003okKamOn^joSo[^_h
00Wo00001oo1b>07o`0000?o_<?P00?o0000okV[boniZl/01?niZl/4o`0000[o]ZS;1Ol0000<ojZF
`@Co00001onXUL800ol0003oW8Rnoib8_P05oib8_P?o0000D?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo04?ooooo00?o05:ko`000?l0
00000ol00004ogO0o@03o`000?nCe_koTmKn00Go00001?nMl_09o`000003okKamOl0003o000000[o
00000oo1b>06o`0000[o_<?P00Co0000okV[boniZl_o^J_;0ol00008okJXb`Ko00000oncY/`00ol0
003oZYK1ojZF`@08ojZF`@?o00002onXUL800ol0003oW8Rnoib8_P02oib8_P?o0000E?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo04Co
oooo2ol00006ogoSm0?o000000?oQN_Lo`000?l000004_l000000oo1b>3o0000o`000006okc3h0go
00001onfZ</6o`0000Wo/jK<00?o0000ojZF`OnZU/401?nZU/44o`0000koZ9G200?o0000oib8__l0
00000_l0001Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Gooooo
0_l00017ooooo`Oo00000omIc?<4o`000003ohG[g?mTf][o000000Oo00000_nCdOd:o`0000;o_<?P
2Ol0000;okNoh003o`000?nfZ<_o]ZS;00Ko00004?ncY/`00ol0003oZYK1o`000003o`00017oZ9G2
0ol0001Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Oooooo00?o
0000ooooooooool0Aoooool7o`000003ofCJf_oooooooooo00?ooooo0_l00002ohc5nP?o000000?o
Sl_lo`000?l000001Ol00004oi?Ao@03o`000?ng_n3o]koP00So]koP3ol0000Bok>Vc0Ko00004?nX
UL85o`0005oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00B?ooool0
0ol0003oooooooooo`1Hooooo`ko00000ong_n08o`0000co/kcP00?o0000ok>Vc?ncY/`02OncY/`9
o`0000Co/:G=00?o0000ojRE`_nXUL802_nXUL85o`0006Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`01ooooo`00BOooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
00;ooooo2?l00005ok>lh0So00002onc_>001?l0003o/jK<ok>Vc?ncY/`8o`0000go/:G=00?o0000
ojRE`_nXUL801OnXUL85o`0006_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01
ooooo`00B_ooool2o`0005Oooooo00?o0000ooooooooool01oooool2o`0000ko[kSP3ol0000Fok2U
c@03o`000?nXUL;o000000Co0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
007ooooo001<ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool03Oooool9o`0000co
[kSP00?o0000ok2UcOn`YLd04On`YLd8o`0007Kooooo00?o0000ooooooooool02?ooool1o`00007o
oooo0Oooool004gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Fooooo`Wo0000
0on_^>000ol0003o/:G=ok2Uc@04ok2Uc@go0000Ooooool00ol0003oooooooooo`07ooooo`7o0000
0Oooool1ooooo`00C_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01oooooo2_l0
002<ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001?ooooo`;o0000D_ooool0
0ol0003oooooooooo`2fooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`05oooo
o`7o00000Oooool1ooooo`00D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0;So
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005?ooooo0_l0001>ooooo`03o`00
0?oooooooooo0;Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005Gooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000
ooooooooool00oooool1o`00007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool0_?ooool01Ol0003ooooooooooooooooo0000007o
oooo001Kooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0_Oooool01?l0003ooooo
ooooool00001ooooo`00G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;kooooo
00?o0000ooooool000000Oooool005gooooo0_l00014ooooo`03o`000?oooooooooo0;kooooo00?o
0000ooooooooool00Ol0000005oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2o
ooooo`7o00000Oooool1o`000000H?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
0<3ooooo0_l00000067ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2oooooo`?o
0000001Rooooo`;o0000?oooool00ol0003oooooooooo`2kooooo`Co00000oooool006Cooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`2gooooo`Co00001oooool006Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`2cooooo`Co00002oooool006Kooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2`ooooo`?o00003oooool006Oooooo0_l0000jooooo`03
o`000?oooooooooo0:cooooo1?l0000Booooo`00JOooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo0:Sooooo1?l0000Fooooo`00J_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0:Cooooo1?l0000Jooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo0:7ooooo1?l0000Nooooo`00K?ooool2o`0003Cooooo00?o0000ooooooooool0WOooool4o`00
02;ooooo001^ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0VOooool4o`0002Ko
oooo001_ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0UOooool4o`0002[ooooo
001`ooooo`;o0000<?ooool00ol0003oooooooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`2>ooooo`?o0000<_ooool007?ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`2:ooooo`Co0000=Oooool007Cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`26ooooo`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`00
0?oooooooooo08;ooooo1?l0000mooooo`00Moooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo07kooooo1?l00011ooooo`00N?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo07[ooooo1?l00015ooooo`00NOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
07Kooooo1?l00019ooooo`00N_ooool2o`0002Kooooo00?o0000ooooooooool0L_ooool4o`0004go
oooo001looooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Koooool3o`00057ooooo
001mooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Cooooo001n
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005Sooooo001ooooo
o`;o00008Oooool00ol0003oooooooooo`1Sooooo`Co0000G?ooool0087ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Oooooo`Co0000H?ooool008;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Kooooo`Co0000I?ooool008?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Gooooo`Co0000J?ooool008Cooooo0_l0000Looooo`03o`000?oooooo
oooo05?ooooo1?l0001/ooooo`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04oooooo1?l0001`ooooo`00Qoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04co
oooo0ol0001dooooo`00R?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo
1?l0001gooooo`00ROooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`0007_ooooo002;
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0007oooooo002<oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008?ooooo002=ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0>?ooool4o`0008Oooooo002>ooooo`;o0000
4_ooool00ol0003oooooooooo`0dooooo`Co0000Roooool0093ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0aooooo`Co0000Soooool0097ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`?o0000Toooool009;ooooo0_l0000=ooooo`03o`000?oooooooooo
02[ooooo1?l0002Fooooo`00U?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Ko
oooo1?l0002Jooooo`00UOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo
1?l0002Nooooo`00U_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0
002Rooooo`00Uoooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:Kooooo002Ioooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:[ooooo002Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:kooooo002Kooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;;ooooo002Looooo`;o00000ooo
ool00ol0003oooooooooo`0;ooooo`?o0000]_ooool009kooooo00Co0000oooooooooooo00002Ooo
ool4o`000;Wooooo002Oooooo`03o`000?oooooo000000Gooooo1?l0002mooooo`00X?ooool2o`00
0003ooooool0003o000000;o0000`Oooool00:7ooooo0_l00035ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51726 .64569 m .51694 .65827 L .43899 .65168 L p .718 .659 .791 r
F P
0 g
s
.51694 .65827 m .51726 .64569 L .59245 .63827 L p .692 .602 .75 r
F P
0 g
s
.59245 .63827 m .59527 .65394 L .51694 .65827 L p .692 .602 .75 r
F P
0 g
s
.43899 .65168 m .4423 .64294 L .51726 .64569 L p .718 .659 .791 r
F P
0 g
s
.51758 .63292 m .51726 .64569 L .4423 .64294 L p .728 .666 .789 r
F P
0 g
s
.51726 .64569 m .51758 .63292 L .58961 .62237 L p .7 .605 .747 r
F P
0 g
s
.58961 .62237 m .59245 .63827 L .51726 .64569 L p .7 .605 .747 r
F P
0 g
s
.59527 .65394 m .59245 .63827 L .66423 .621 L p .652 .554 .73 r
F P
0 g
s
.66423 .621 m .67023 .63881 L .59527 .65394 L p .652 .554 .73 r
F P
0 g
s
.4423 .64294 m .43899 .65168 L .36521 .63435 L p .706 .723 .863 r
F P
0 g
s
.59245 .63827 m .58961 .62237 L .65821 .60293 L p .658 .555 .727 r
F P
0 g
s
.65821 .60293 m .66423 .621 L .59245 .63827 L p .658 .555 .727 r
F P
0 g
s
.4423 .64294 m .44563 .6341 L .51758 .63292 L p .728 .666 .789 r
F P
0 g
s
.5179 .6201 m .51758 .63292 L .44563 .6341 L p .739 .676 .789 r
F P
0 g
s
.51758 .63292 m .5179 .6201 L .58677 .60643 L p .708 .611 .746 r
F P
0 g
s
.58677 .60643 m .58961 .62237 L .51758 .63292 L p .708 .611 .746 r
F P
0 g
s
.58961 .62237 m .58677 .60643 L .65219 .58487 L p .664 .558 .726 r
F P
0 g
s
.65219 .58487 m .65821 .60293 L .58961 .62237 L p .664 .558 .726 r
F P
0 g
s
.58392 .59064 m .58677 .60643 L .5179 .6201 L p .717 .618 .746 r
F P
0 g
s
.58677 .60643 m .58392 .59064 L .64618 .56705 L p .671 .564 .726 r
F P
0 g
s
.64618 .56705 m .65219 .58487 L .58677 .60643 L p .671 .564 .726 r
F P
0 g
s
.44563 .6341 m .44898 .6252 L .5179 .6201 L p .739 .676 .789 r
F P
0 g
s
.51823 .60734 m .5179 .6201 L .44898 .6252 L p .751 .687 .79 r
F P
0 g
s
.5179 .6201 m .51823 .60734 L .58392 .59064 L p .717 .618 .746 r
F P
0 g
s
.36521 .63435 m .37124 .63001 L .4423 .64294 L p .706 .723 .863 r
F P
0 g
s
.44563 .6341 m .4423 .64294 L .37124 .63001 L p .72 .738 .865 r
F P
0 g
s
.58107 .5752 m .58392 .59064 L .51823 .60734 L p .727 .628 .748 r
F P
0 g
s
.58392 .59064 m .58107 .5752 L .64018 .54973 L p .679 .572 .728 r
F P
0 g
s
.64018 .54973 m .64618 .56705 L .58392 .59064 L p .679 .572 .728 r
F P
0 g
s
.44898 .6252 m .45235 .61628 L .51823 .60734 L p .751 .687 .79 r
F P
0 g
s
.51856 .59477 m .51823 .60734 L .45235 .61628 L p .764 .701 .793 r
F P
0 g
s
.51823 .60734 m .51856 .59477 L .58107 .5752 L p .727 .628 .748 r
F P
0 g
s
.57822 .56029 m .58107 .5752 L .51856 .59477 L p .738 .641 .752 r
F P
0 g
s
.58107 .5752 m .57822 .56029 L .6342 .53314 L p .689 .583 .732 r
F P
0 g
s
.6342 .53314 m .64018 .54973 L .58107 .5752 L p .689 .583 .732 r
F P
0 g
s
.37124 .63001 m .37731 .62567 L .44563 .6341 L p .72 .738 .865 r
F P
0 g
s
.44898 .6252 m .44563 .6341 L .37731 .62567 L p .735 .754 .868 r
F P
0 g
s
.51856 .59477 m .51889 .58251 L .57822 .56029 L p .738 .641 .752 r
F P
0 g
s
.57537 .54609 m .57822 .56029 L .51889 .58251 L p .751 .657 .758 r
F P
0 g
s
.57822 .56029 m .57537 .54609 L .62825 .51748 L p .7 .597 .738 r
F P
0 g
s
.62825 .51748 m .6342 .53314 L .57822 .56029 L p .7 .597 .738 r
F P
0 g
s
.67023 .63881 m .66423 .621 L .72894 .59448 L p .603 .513 .725 r
F P
0 g
s
.72894 .59448 m .73799 .61332 L .67023 .63881 L p .603 .513 .725 r
F P
0 g
s
.66423 .621 m .65821 .60293 L .71989 .57539 L p .606 .513 .722 r
F P
0 g
s
.71989 .57539 m .72894 .59448 L .66423 .621 L p .606 .513 .722 r
F P
0 g
s
.45235 .61628 m .45575 .60741 L .51856 .59477 L p .764 .701 .793 r
F P
0 g
s
.51889 .58251 m .51856 .59477 L .45575 .60741 L p .778 .718 .797 r
F P
0 g
s
.65821 .60293 m .65219 .58487 L .71086 .55636 L p .611 .515 .721 r
F P
0 g
s
.71086 .55636 m .71989 .57539 L .65821 .60293 L p .611 .515 .721 r
F P
0 g
s
.65219 .58487 m .64618 .56705 L .70186 .53766 L p .616 .519 .721 r
F P
0 g
s
.70186 .53766 m .71086 .55636 L .65219 .58487 L p .616 .519 .721 r
F P
0 g
s
.64618 .56705 m .64018 .54973 L .6929 .51957 L p .624 .527 .724 r
F P
0 g
s
.6929 .51957 m .70186 .53766 L .64618 .56705 L p .624 .527 .724 r
F P
0 g
s
.64018 .54973 m .6342 .53314 L .684 .50237 L p .632 .537 .728 r
F P
0 g
s
.684 .50237 m .6929 .51957 L .64018 .54973 L p .632 .537 .728 r
F P
0 g
s
.51889 .58251 m .51921 .57068 L .57537 .54609 L p .751 .657 .758 r
F P
0 g
s
.57252 .53274 m .57537 .54609 L .51921 .57068 L p .765 .677 .765 r
F P
0 g
s
.57537 .54609 m .57252 .53274 L .62231 .50297 L p .713 .614 .745 r
F P
0 g
s
.62231 .50297 m .62825 .51748 L .57537 .54609 L p .713 .614 .745 r
F P
0 g
s
.37731 .62567 m .38344 .62129 L .44898 .6252 L p .735 .754 .868 r
F P
0 g
s
.45235 .61628 m .44898 .6252 L .38344 .62129 L p .75 .774 .872 r
F P
0 g
s
.6342 .53314 m .62825 .51748 L .67516 .48629 L p .643 .55 .735 r
F P
0 g
s
.67516 .48629 m .684 .50237 L .6342 .53314 L p .643 .55 .735 r
F P
0 g
s
.37124 .63001 m .36521 .63435 L .29943 .6068 L p .588 .752 .956 r
F P
0 g
s
.45575 .60741 m .45916 .59862 L .51889 .58251 L p .778 .718 .797 r
F P
0 g
s
.51921 .57068 m .51889 .58251 L .45916 .59862 L p .792 .738 .803 r
F P
0 g
s
.62825 .51748 m .62231 .50297 L .66638 .47156 L p .656 .567 .743 r
F P
0 g
s
.66638 .47156 m .67516 .48629 L .62825 .51748 L p .656 .567 .743 r
F P
0 g
s
.51921 .57068 m .51954 .55938 L .57252 .53274 L p .765 .677 .765 r
F P
0 g
s
.56968 .52039 m .57252 .53274 L .51954 .55938 L p .781 .7 .774 r
F P
0 g
s
.57252 .53274 m .56968 .52039 L .6164 .48976 L p .728 .636 .755 r
F P
0 g
s
.6164 .48976 m .62231 .50297 L .57252 .53274 L p .728 .636 .755 r
F P
0 g
s
.62231 .50297 m .6164 .48976 L .65766 .45837 L p .671 .589 .754 r
F P
0 g
s
.65766 .45837 m .66638 .47156 L .62231 .50297 L p .671 .589 .754 r
F P
0 g
s
.38344 .62129 m .38962 .61684 L .45235 .61628 L p .75 .774 .872 r
F P
0 g
s
.45575 .60741 m .45235 .61628 L .38962 .61684 L p .766 .795 .877 r
F P
0 g
s
.45916 .59862 m .4626 .58996 L .51921 .57068 L p .792 .738 .803 r
F P
0 g
s
.51954 .55938 m .51921 .57068 L .4626 .58996 L p .808 .762 .81 r
F P
0 g
s
.6105 .47801 m .6164 .48976 L .56968 .52039 L p .746 .662 .767 r
F P
0 g
s
.6164 .48976 m .6105 .47801 L .64899 .44689 L p .69 .616 .768 r
F P
0 g
s
.64899 .44689 m .65766 .45837 L .6164 .48976 L p .69 .616 .768 r
F P
0 g
s
.51954 .55938 m .51987 .54871 L .56968 .52039 L p .781 .7 .774 r
F P
0 g
s
.56683 .50917 m .56968 .52039 L .51987 .54871 L p .799 .728 .785 r
F P
0 g
s
.56968 .52039 m .56683 .50917 L .6105 .47801 L p .746 .662 .767 r
F P
0 g
s
.29943 .6068 m .30784 .6072 L .37124 .63001 L p .588 .752 .956 r
F P
0 g
s
.37731 .62567 m .37124 .63001 L .30784 .6072 L p .595 .775 .966 r
F P
0 g
s
.60462 .46785 m .6105 .47801 L .56683 .50917 L p .767 .694 .782 r
F P
0 g
s
.6105 .47801 m .60462 .46785 L .64036 .43726 L p .712 .649 .785 r
F P
0 g
s
.64036 .43726 m .64899 .44689 L .6105 .47801 L p .712 .649 .785 r
F P
0 g
s
.38962 .61684 m .39586 .61229 L .45575 .60741 L p .766 .795 .877 r
F P
0 g
s
.45916 .59862 m .45575 .60741 L .39586 .61229 L p .783 .819 .881 r
F P
0 g
s
.4626 .58996 m .46606 .58147 L .51954 .55938 L p .808 .762 .81 r
F P
0 g
s
.51987 .54871 m .51954 .55938 L .46606 .58147 L p .825 .788 .818 r
F P
0 g
s
.51987 .54871 m .52021 .53874 L .56683 .50917 L p .799 .728 .785 r
F P
0 g
s
.56398 .49916 m .56683 .50917 L .52021 .53874 L p .818 .76 .798 r
F P
0 g
s
.56683 .50917 m .56398 .49916 L .60462 .46785 L p .767 .694 .782 r
F P
0 g
s
.684 .50237 m .67516 .48629 L .71354 .45406 L p .577 .513 .747 r
F P
0 g
s
.67516 .48629 m .66638 .47156 L .70232 .44012 L p .59 .531 .757 r
F P
0 g
s
.70232 .44012 m .71354 .45406 L .67516 .48629 L p .59 .531 .757 r
F P
0 g
s
.30784 .6072 m .31632 .60772 L .37731 .62567 L p .595 .775 .966 r
F P
0 g
s
.38344 .62129 m .37731 .62567 L .31632 .60772 L p .603 .8 .975 r
F P
0 g
s
.6929 .51957 m .684 .50237 L .72487 .46948 L p .566 .499 .739 r
F P
0 g
s
.71354 .45406 m .72487 .46948 L .684 .50237 L p .577 .513 .747 r
F P
0 g
s
.66638 .47156 m .65766 .45837 L .69121 .42785 L p .607 .555 .771 r
F P
0 g
s
.69121 .42785 m .70232 .44012 L .66638 .47156 L p .607 .555 .771 r
F P
0 g
s
.59875 .45937 m .60462 .46785 L .56398 .49916 L p .791 .732 .798 r
F P
0 g
s
.60462 .46785 m .59875 .45937 L .63177 .42958 L p .738 .689 .804 r
F P
0 g
s
.63177 .42958 m .64036 .43726 L .60462 .46785 L p .738 .689 .804 r
F P
0 g
s
.70186 .53766 m .6929 .51957 L .7363 .48614 L p .558 .488 .733 r
F P
0 g
s
.72487 .46948 m .7363 .48614 L .6929 .51957 L p .566 .499 .739 r
F P
0 g
s
.65766 .45837 m .64899 .44689 L .68019 .41743 L p .628 .585 .787 r
F P
0 g
s
.68019 .41743 m .69121 .42785 L .65766 .45837 L p .628 .585 .787 r
F P
0 g
s
.71086 .55636 m .70186 .53766 L .74783 .50378 L p .552 .481 .73 r
F P
0 g
s
.7363 .48614 m .74783 .50378 L .70186 .53766 L p .558 .488 .733 r
F P
0 g
s
.46606 .58147 m .46954 .57319 L .51987 .54871 L p .825 .788 .818 r
F P
0 g
s
.52021 .53874 m .51987 .54871 L .46954 .57319 L p .842 .818 .826 r
F P
0 g
s
.39586 .61229 m .40215 .6076 L .45916 .59862 L p .783 .819 .881 r
F P
0 g
s
.4626 .58996 m .45916 .59862 L .40215 .6076 L p .799 .845 .886 r
F P
0 g
s
.52021 .53874 m .52054 .52955 L .56398 .49916 L p .818 .76 .798 r
F P
0 g
s
.56113 .49045 m .56398 .49916 L .52054 .52955 L p .839 .798 .811 r
F P
0 g
s
.56398 .49916 m .56113 .49045 L .59875 .45937 L p .791 .732 .798 r
F P
0 g
s
.71989 .57539 m .71086 .55636 L .75944 .52212 L p .548 .477 .728 r
F P
0 g
s
.74783 .50378 m .75944 .52212 L .71086 .55636 L p .552 .481 .73 r
F P
0 g
s
.64899 .44689 m .64036 .43726 L .66925 .40901 L p .653 .623 .807 r
F P
0 g
s
.66925 .40901 m .68019 .41743 L .64899 .44689 L p .653 .623 .807 r
F P
0 g
s
.72894 .59448 m .71989 .57539 L .77113 .54086 L p .545 .476 .729 r
F P
0 g
s
.75944 .52212 m .77113 .54086 L .71989 .57539 L p .548 .477 .728 r
F P
0 g
s
.59287 .45262 m .59875 .45937 L .56113 .49045 L p .816 .777 .816 r
F P
0 g
s
.59875 .45937 m .59287 .45262 L .62319 .42392 L p .768 .738 .825 r
F P
0 g
s
.62319 .42392 m .63177 .42958 L .59875 .45937 L p .768 .738 .825 r
F P
0 g
s
.73799 .61332 m .72894 .59448 L .78288 .55969 L p .544 .478 .732 r
F P
0 g
s
.77113 .54086 m .78288 .55969 L .72894 .59448 L p .545 .476 .729 r
F P
0 g
s
.31632 .60772 m .32488 .60824 L .38344 .62129 L p .603 .8 .975 r
F P
0 g
s
.38962 .61684 m .38344 .62129 L .32488 .60824 L p .614 .828 .982 r
F P
0 g
s
.64036 .43726 m .63177 .42958 L .65838 .40269 L p .683 .669 .831 r
F P
0 g
s
.65838 .40269 m .66925 .40901 L .64036 .43726 L p .683 .669 .831 r
F P
0 g
s
.78288 .55969 m .79464 .57831 L .73799 .61332 L p .544 .478 .732 r
F P
0 g
s
.46954 .57319 m .47304 .56515 L .52021 .53874 L p .842 .818 .826 r
F P
0 g
s
.52054 .52955 m .52021 .53874 L .47304 .56515 L p .859 .852 .834 r
F P
0 g
s
.40215 .6076 m .4085 .60273 L .4626 .58996 L p .799 .845 .886 r
F P
0 g
s
.46606 .58147 m .4626 .58996 L .4085 .60273 L p .815 .873 .889 r
F P
0 g
s
.52054 .52955 m .52087 .52118 L .56113 .49045 L p .839 .798 .811 r
F P
0 g
s
.55827 .48308 m .56113 .49045 L .52087 .52118 L p .861 .84 .824 r
F P
0 g
s
.56113 .49045 m .55827 .48308 L .59287 .45262 L p .816 .777 .816 r
F P
0 g
s
.63177 .42958 m .62319 .42392 L .64756 .39854 L p .717 .725 .856 r
F P
0 g
s
.64756 .39854 m .65838 .40269 L .63177 .42958 L p .717 .725 .856 r
F P
0 g
s
.58699 .44766 m .59287 .45262 L .55827 .48308 L p .843 .829 .833 r
F P
0 g
s
.59287 .45262 m .58699 .44766 L .61462 .42032 L p .8 .795 .847 r
F P
0 g
s
.61462 .42032 m .62319 .42392 L .59287 .45262 L p .8 .795 .847 r
F P
0 g
s
.32488 .60824 m .33352 .60864 L .38962 .61684 L p .614 .828 .982 r
F P
0 g
s
.39586 .61229 m .38962 .61684 L .33352 .60864 L p .626 .858 .986 r
F P
0 g
s
.47304 .56515 m .47656 .55738 L .52054 .52955 L p .859 .852 .834 r
F P
0 g
s
.52087 .52118 m .52054 .52955 L .47656 .55738 L p .874 .887 .84 r
F P
0 g
s
.30784 .6072 m .29943 .6068 L .24558 .56996 L p .286 .625 .961 r
F P
0 g
s
.4085 .60273 m .41491 .59766 L .46606 .58147 L p .815 .873 .889 r
F P
0 g
s
.46954 .57319 m .46606 .58147 L .41491 .59766 L p .829 .902 .89 r
F P
0 g
s
.52087 .52118 m .52121 .51368 L .55827 .48308 L p .861 .84 .824 r
F P
0 g
s
.5554 .4771 m .55827 .48308 L .52121 .51368 L p .88 .886 .834 r
F P
0 g
s
.55827 .48308 m .5554 .4771 L .58699 .44766 L p .843 .829 .833 r
F P
0 g
s
.62319 .42392 m .61462 .42032 L .63677 .3966 L p .756 .79 .881 r
F P
0 g
s
.63677 .3966 m .64756 .39854 L .62319 .42392 L p .756 .79 .881 r
F P
0 g
s
.58108 .44447 m .58699 .44766 L .5554 .4771 L p .867 .884 .846 r
F P
0 g
s
.58699 .44766 m .58108 .44447 L .60604 .41878 L p .832 .858 .865 r
F P
0 g
s
.60604 .41878 m .61462 .42032 L .58699 .44766 L p .832 .858 .865 r
F P
0 g
s
.70232 .44012 m .69121 .42785 L .71499 .39987 L p .529 .537 .808 r
F P
0 g
s
.69121 .42785 m .68019 .41743 L .7022 .39128 L p .553 .575 .83 r
F P
0 g
s
.7022 .39128 m .71499 .39987 L .69121 .42785 L p .553 .575 .83 r
F P
0 g
s
.71354 .45406 m .70232 .44012 L .72791 .41034 L p .51 .508 .79 r
F P
0 g
s
.71499 .39987 m .72791 .41034 L .70232 .44012 L p .529 .537 .808 r
F P
0 g
s
.33352 .60864 m .34226 .60881 L .39586 .61229 L p .626 .858 .986 r
F P
0 g
s
.40215 .6076 m .39586 .61229 L .34226 .60881 L p .638 .887 .986 r
F P
0 g
s
.68019 .41743 m .66925 .40901 L .68954 .38469 L p .583 .621 .856 r
F P
0 g
s
.68954 .38469 m .7022 .39128 L .68019 .41743 L p .583 .621 .856 r
F P
0 g
s
.41491 .59766 m .42137 .59237 L .46954 .57319 L p .829 .902 .89 r
F P
0 g
s
.47304 .56515 m .46954 .57319 L .42137 .59237 L p .841 .93 .888 r
F P
0 g
s
.47656 .55738 m .48011 .5499 L .52087 .52118 L p .874 .887 .84 r
F P
0 g
s
.52121 .51368 m .52087 .52118 L .48011 .5499 L p .886 .923 .842 r
F P
0 g
s
.72487 .46948 m .71354 .45406 L .74097 .42251 L p .495 .486 .776 r
F P
0 g
s
.72791 .41034 m .74097 .42251 L .71354 .45406 L p .51 .508 .79 r
F P
0 g
s
.24558 .56996 m .25595 .57522 L .30784 .6072 L p .286 .625 .961 r
F P
0 g
s
.31632 .60772 m .30784 .6072 L .25595 .57522 L p .251 .628 .96 r
F P
0 g
s
.66925 .40901 m .65838 .40269 L .67699 .38023 L p .619 .678 .884 r
F P
0 g
s
.67699 .38023 m .68954 .38469 L .66925 .40901 L p .619 .678 .884 r
F P
0 g
s
.61462 .42032 m .60604 .41878 L .62598 .39687 L p .793 .86 .9 r
F P
0 g
s
.62598 .39687 m .63677 .3966 L .61462 .42032 L p .793 .86 .9 r
F P
0 g
s
.7363 .48614 m .72487 .46948 L .75419 .43618 L p .484 .469 .765 r
F P
0 g
s
.74097 .42251 m .75419 .43618 L .72487 .46948 L p .495 .486 .776 r
F P
0 g
s
.52121 .51368 m .52155 .50705 L .5554 .4771 L p .88 .886 .834 r
F P
0 g
s
.55251 .47248 m .5554 .4771 L .52155 .50705 L p .892 .931 .836 r
F P
0 g
s
.5554 .4771 m .55251 .47248 L .58108 .44447 L p .867 .884 .846 r
F P
0 g
s
.65838 .40269 m .64756 .39854 L .66451 .37794 L p .66 .745 .913 r
F P
0 g
s
.66451 .37794 m .67699 .38023 L .65838 .40269 L p .66 .745 .913 r
F P
0 g
s
.74783 .50378 m .7363 .48614 L .76756 .45112 L p .477 .457 .757 r
F P
0 g
s
.75419 .43618 m .76756 .45112 L .7363 .48614 L p .484 .469 .765 r
F P
0 g
s
.42137 .59237 m .4279 .58682 L .47304 .56515 L p .841 .93 .888 r
F P
0 g
s
.47656 .55738 m .47304 .56515 L .4279 .58682 L p .848 .956 .881 r
F P
0 g
s
.34226 .60881 m .3511 .60863 L .40215 .6076 L p .638 .887 .986 r
F P
0 g
s
.4085 .60273 m .40215 .6076 L .3542 .60857 L p .65 .915 .979 r
F P
0 g
s
.4085 .60273 m .3542 .60857 L .35755 .60797 L .65 .915 .979 r
F
.3542 .60857 m .3511 .60863 L p .35755 .60797 L F P
0 g
s
.3511 .60863 m .36004 .60799 L .4085 .60273 L p .65 .915 .979 r
F P
0 g
s
.41491 .59766 m .36761 .60717 L .37002 .60636 L .66 .939 .965 r
F
.41491 .59766 m .36357 .60761 L .36733 .60662 L F
.36761 .60717 m .36357 .60761 L p .37002 .60636 L F P
0 g
s
.36357 .60761 m .36004 .60799 L p .36733 .60662 L .66 .939 .965 r
F P
0 g
s
.36004 .60799 m .36909 .60678 L .41403 .59784 L p .66 .939 .965 r
F P
0 g
s
.41296 .59803 m .36004 .60799 L .41403 .59784 L .66 .939 .965 r
F
.41403 .59784 m .41491 .59766 L p .41296 .59803 L F P
0 g
s
.42137 .59237 m .41491 .59766 L .37736 .60513 L p .668 .958 .943 r
F P
0 g
s
.37736 .60513 m .36909 .60678 L p .38174 .60329 L .668 .958 .943 r
F P
0 g
s
.42137 .59237 m .37736 .60513 L .38174 .60329 L .668 .958 .943 r
F
.36909 .60678 m .37824 .6049 L .38251 .60366 L p F P
0 g
s
.38251 .60366 m .42037 .59266 L p .38175 .60329 L .668 .958 .943 r
F P
0 g
s
.38175 .60329 m .36909 .60678 L .38251 .60366 L .668 .958 .943 r
F
.41917 .59298 m .36909 .60678 L .42037 .59266 L F
.42037 .59266 m .42137 .59237 L p .41917 .59298 L F P
0 g
s
.4279 .58682 m .42137 .59237 L .38714 .60232 L p .672 .971 .913 r
F P
0 g
s
.38714 .60232 m .37824 .6049 L p .39178 .59998 L .672 .971 .913 r
F P
0 g
s
.4279 .58682 m .38714 .60232 L .39178 .59998 L .672 .971 .913 r
F
.37824 .6049 m .3875 .60228 L .39208 .60053 L p F P
0 g
s
.39208 .60053 m .42582 .58762 L p .39178 .59998 L .672 .971 .913 r
F P
0 g
s
.39178 .59998 m .37824 .6049 L .39208 .60053 L .672 .971 .913 r
F
.42446 .58807 m .37824 .6049 L .42582 .58762 L F
.42582 .58762 m .4279 .58682 L p .42446 .58807 L F P
0 g
s
.43448 .58101 m .4279 .58682 L .39696 .59866 L p .672 .976 .876 r
F P
0 g
s
.39696 .59866 m .3875 .60228 L p .4018 .5958 L .672 .976 .876 r
F P
0 g
s
.43448 .58101 m .39696 .59866 L .4018 .5958 L .672 .976 .876 r
F
.3875 .60228 m .39686 .59883 L .40171 .59653 L p F P
0 g
s
.40171 .59653 m .43219 .58209 L p .4018 .59582 L .672 .976 .876 r
F P
0 g
s
.4018 .59582 m .3875 .60228 L .40171 .59653 L .672 .976 .876 r
F
.4307 .58272 m .3875 .60228 L .43219 .58209 L F
.43219 .58209 m .43448 .58101 L p .4307 .58272 L F P
0 g
s
.44112 .5749 m .43448 .58101 L .40681 .59412 L p .669 .974 .834 r
F P
0 g
s
.40681 .59412 m .39686 .59883 L p .41183 .59074 L .669 .974 .834 r
F P
0 g
s
.44112 .5749 m .40681 .59412 L .41183 .59074 L .669 .974 .834 r
F
.39686 .59883 m .40632 .59452 L .41142 .59164 L p F P
0 g
s
.41142 .59164 m .43864 .5763 L p .41182 .59077 L .669 .974 .834 r
F P
0 g
s
.41182 .59077 m .39686 .59883 L .41142 .59164 L .669 .974 .834 r
F
.43704 .57711 m .39686 .59883 L .43864 .5763 L F
.43864 .5763 m .44112 .5749 L p .43704 .57711 L F P
0 g
s
.44782 .5685 m .44112 .5749 L .41669 .58867 L p .662 .967 .789 r
F P
0 g
s
.41669 .58867 m .40632 .59452 L p .42185 .58478 L .662 .967 .789 r
F P
0 g
s
.44782 .5685 m .41669 .58867 L .42185 .58478 L .662 .967 .789 r
F
.40632 .59452 m .41587 .58929 L .42119 .58584 L p F P
0 g
s
.42119 .58584 m .44517 .57023 L p .42182 .58482 L .662 .967 .789 r
F P
0 g
s
.42182 .58482 m .40632 .59452 L .42119 .58584 L .662 .967 .789 r
F
.44346 .57123 m .40632 .59452 L .44517 .57023 L F
.44517 .57023 m .44782 .5685 L p .44346 .57123 L F P
0 g
s
.45458 .56179 m .44782 .5685 L .42661 .58231 L p .653 .955 .743 r
F P
0 g
s
.42661 .58231 m .41587 .58929 L p .43187 .57793 L .653 .955 .743 r
F P
0 g
s
.45458 .56179 m .42661 .58231 L .43187 .57793 L .653 .955 .743 r
F
.41587 .58929 m .42551 .58314 L .43101 .57911 L p F P
0 g
s
.43101 .57911 m .45177 .56386 L p .43182 .57799 L .653 .955 .743 r
F P
0 g
s
.43182 .57799 m .41587 .58929 L .43101 .57911 L .653 .955 .743 r
F
.44996 .56508 m .41587 .58929 L .45177 .56386 L F
.45177 .56386 m .45458 .56179 L p .44996 .56508 L F P
0 g
s
.4614 .55478 m .45458 .56179 L .43655 .57504 L p .642 .94 .698 r
F P
0 g
s
.43655 .57504 m .42551 .58314 L p .44189 .5702 L .642 .94 .698 r
F P
0 g
s
.4614 .55478 m .43655 .57504 L .44189 .5702 L .642 .94 .698 r
F
.42551 .58314 m .43524 .57607 L .44089 .57147 L p F P
0 g
s
.44089 .57147 m .45844 .55718 L p .44182 .57029 L .642 .94 .698 r
F P
0 g
s
.44182 .57029 m .42551 .58314 L .44089 .57147 L .642 .94 .698 r
F
.45654 .55862 m .42551 .58314 L .45844 .55718 L F
.45844 .55718 m .4614 .55478 L p .45654 .55862 L F P
0 g
s
.46827 .54747 m .4614 .55478 L .4465 .5669 L p .631 .923 .656 r
F P
0 g
s
.4465 .5669 m .43524 .57607 L p .45189 .56165 L .631 .923 .656 r
F P
0 g
s
.46827 .54747 m .4465 .5669 L .45189 .56165 L .631 .923 .656 r
F
.43524 .57607 m .44503 .5681 L .45081 .56297 L p F P
0 g
s
.45081 .56297 m .46519 .5502 L p .45179 .56178 L .631 .923 .656 r
F P
0 g
s
.45179 .56178 m .43524 .57607 L .45081 .56297 L .631 .923 .656 r
F
.46319 .55187 m .43524 .57607 L .46519 .5502 L F
.46519 .5502 m .46827 .54747 L p .46319 .55187 L F P
0 g
s
.47519 .53987 m .46827 .54747 L .45647 .55794 L p .619 .906 .617 r
F P
0 g
s
.45647 .55794 m .44503 .5681 L p .46188 .55233 L .619 .906 .617 r
F P
0 g
s
.47519 .53987 m .45647 .55794 L .46188 .55233 L .619 .906 .617 r
F
.44503 .5681 m .45489 .55928 L .46077 .55365 L p F P
0 g
s
.46077 .55365 m .472 .54292 L p .46173 .55251 L .619 .906 .617 r
F P
0 g
s
.46173 .55251 m .44503 .5681 L .46077 .55365 L .619 .906 .617 r
F
.4699 .54482 m .44503 .5681 L .472 .54292 L F
.472 .54292 m .47519 .53987 L p .4699 .54482 L F P
0 g
s
.48217 .532 m .47519 .53987 L .45489 .55928 L p .608 .89 .582 r
F P
0 g
s
.45489 .55928 m .4648 .54965 L .47888 .53534 L p .608 .89 .582 r
F P
0 g
s
.47668 .53749 m .45489 .55928 L .47888 .53534 L .608 .89 .582 r
F
.47888 .53534 m .48217 .532 L p .47668 .53749 L F P
0 g
s
.4892 .52388 m .48217 .532 L .47076 .5436 L p .598 .875 .552 r
F P
0 g
s
.47076 .5436 m .4648 .54965 L p .47639 .53741 L .598 .875 .552 r
F P
0 g
s
.4892 .52388 m .47076 .5436 L .47639 .53741 L .598 .875 .552 r
F
.4648 .54965 m .47477 .53932 L .48582 .52749 L p F P
0 g
s
.48351 .52989 m .4648 .54965 L .48582 .52749 L .598 .875 .552 r
F
.48582 .52749 m .4892 .52388 L p .48351 .52989 L F P
0 g
s
.49628 .51553 m .4892 .52388 L .48078 .53288 L p .589 .861 .526 r
F P
0 g
s
.48078 .53288 m .47477 .53932 L p .48641 .52644 L .589 .861 .526 r
F P
0 g
s
.49628 .51553 m .48078 .53288 L .48641 .52644 L .589 .861 .526 r
F
.47477 .53932 m .48477 .52835 L .49458 .51742 L p F P
0 g
s
.49244 .51977 m .47477 .53932 L .49458 .51742 L .589 .861 .526 r
F
.49458 .51742 m .49628 .51553 L p .49244 .51977 L F P
0 g
s
.50342 .50698 m .49628 .51553 L .49082 .52162 L p .581 .849 .505 r
F P
0 g
s
.49082 .52162 m .48477 .52835 L p .49643 .51499 L .581 .849 .505 r
F P
0 g
s
.50342 .50698 m .49082 .52162 L .49643 .51499 L .581 .849 .505 r
F
.48477 .52835 m .49482 .51686 L .50169 .50896 L p F P
0 g
s
.49947 .51151 m .48477 .52835 L .50169 .50896 L .581 .849 .505 r
F
.49482 .51686 m .50489 .50497 L .50886 .5003 L p .574 .84 .488 r
F P
0 g
s
.50886 .5003 m .5106 .49826 L p .50651 .50308 L .574 .84 .488 r
F P
0 g
s
.50651 .50308 m .49482 .51686 L .50886 .5003 L .574 .84 .488 r
F
.50169 .50896 m .50342 .50698 L p .49947 .51151 L .581 .849 .505 r
F P
0 g
s
.41491 .59766 m .4085 .60273 L .36761 .60717 L p .66 .939 .965 r
F P
0 g
s
.57514 .44302 m .58108 .44447 L .55251 .47248 L p .883 .937 .848 r
F P
0 g
s
.58108 .44447 m .57514 .44302 L .59742 .41927 L p .856 .921 .872 r
F P
0 g
s
.59742 .41927 m .60604 .41878 L .58108 .44447 L p .856 .921 .872 r
F P
0 g
s
.48011 .5499 m .48368 .54272 L .52121 .51368 L p .886 .923 .842 r
F P
0 g
s
.52155 .50705 m .52121 .51368 L .48368 .54272 L p .891 .956 .837 r
F P
0 g
s
.64756 .39854 m .63677 .3966 L .65209 .37788 L p .704 .82 .937 r
F P
0 g
s
.65209 .37788 m .66451 .37794 L .64756 .39854 L p .704 .82 .937 r
F P
0 g
s
.75944 .52212 m .74783 .50378 L .78107 .46707 L p .472 .45 .752 r
F P
0 g
s
.76756 .45112 m .78107 .46707 L .74783 .50378 L p .477 .457 .757 r
F P
0 g
s
.25595 .57522 m .2664 .58071 L .31632 .60772 L p .251 .628 .96 r
F P
0 g
s
.32488 .60824 m .31632 .60772 L .27407 .58486 L p .223 .635 .955 r
F P
0 g
s
.32488 .60824 m .27407 .58486 L .27598 .58546 L .223 .635 .955 r
F
.32488 .60824 m .27022 .58278 L .272 .58342 L F
.32488 .60824 m .26761 .58136 L .26911 .58199 L F
.27407 .58486 m .27022 .58278 L p .27598 .58546 L F P
0 g
s
.27022 .58278 m .26761 .58136 L p .272 .58342 L .223 .635 .955 r
F P
0 g
s
.26761 .58136 m .2664 .58071 L p .26911 .58199 L .223 .635 .955 r
F P
0 g
s
.2664 .58071 m .27695 .58625 L .32488 .60824 L p .223 .635 .955 r
F P
0 g
s
.33352 .60864 m .32488 .60824 L .28717 .59094 L p .202 .647 .948 r
F P
0 g
s
.28717 .59094 m .27695 .58625 L p .29145 .59199 L .202 .647 .948 r
F P
0 g
s
.33352 .60864 m .28717 .59094 L .29145 .59199 L .202 .647 .948 r
F
.27695 .58625 m .28762 .59164 L .29494 .59435 L p F P
0 g
s
.29494 .59435 m .33281 .60838 L p .29146 .592 L .202 .647 .948 r
F P
0 g
s
.29146 .592 m .27695 .58625 L .29494 .59435 L .202 .647 .948 r
F
.28762 .59164 m .29842 .59668 L .30233 .59776 L p .192 .664 .936 r
F P
0 g
s
.33183 .60797 m .27695 .58625 L .33281 .60838 L .202 .647 .948 r
F
.33281 .60838 m .33352 .60864 L p .33183 .60797 L F P
0 g
s
.34226 .60881 m .33352 .60864 L .30008 .59625 L p .192 .664 .936 r
F P
0 g
s
.30008 .59625 m .28762 .59164 L p .30497 .59709 L .192 .664 .936 r
F P
0 g
s
.34226 .60881 m .30008 .59625 L .30497 .59709 L .192 .664 .936 r
F
.30233 .59776 m .34043 .60831 L p .29924 .59531 L F P
0 g
s
.29924 .59531 m .28762 .59164 L .30233 .59776 L .192 .664 .936 r
F
.33904 .6078 m .28762 .59164 L .34043 .60831 L F
.34043 .60831 m .34226 .60881 L p .33904 .6078 L F P
0 g
s
.3511 .60863 m .34226 .60881 L .31288 .60068 L p .193 .686 .92 r
F P
0 g
s
.31288 .60068 m .29842 .59668 L p .31819 .60117 L .193 .686 .92 r
F P
0 g
s
.3511 .60863 m .31288 .60068 L .31819 .60117 L .193 .686 .92 r
F
.29842 .59668 m .30937 .60119 L .31943 .60298 L p F P
0 g
s
.31943 .60298 m .34779 .60804 L p .31824 .60124 L .193 .686 .92 r
F P
0 g
s
.31824 .60124 m .29842 .59668 L .31943 .60298 L .193 .686 .92 r
F
.30937 .60119 m .32046 .60496 L .3257 .60536 L p .204 .711 .9 r
F P
0 g
s
.34595 .60747 m .29842 .59668 L .34779 .60804 L .193 .686 .92 r
F
.34779 .60804 m .3511 .60863 L p .34595 .60747 L F P
0 g
s
.36004 .60799 m .3511 .60863 L .32558 .60408 L p .204 .711 .9 r
F P
0 g
s
.32558 .60408 m .30937 .60119 L p .33118 .60412 L .204 .711 .9 r
F P
0 g
s
.36004 .60799 m .32558 .60408 L .33118 .60412 L .204 .711 .9 r
F
.3257 .60536 m .35509 .60761 L p .32478 .60335 L F P
0 g
s
.32478 .60335 m .30937 .60119 L .3257 .60536 L .204 .711 .9 r
F
.35509 .60761 m .36004 .60799 L p .35252 .60698 L F P
0 g
s
.35252 .60698 m .30937 .60119 L .35509 .60761 L .204 .711 .9 r
F
.36909 .60678 m .36004 .60799 L .33824 .60632 L p .226 .738 .876 r
F P
0 g
s
.33824 .60632 m .32046 .60496 L p .34402 .60584 L .226 .738 .876 r
F P
0 g
s
.36909 .60678 m .33824 .60632 L .34402 .60584 L .226 .738 .876 r
F
.32046 .60496 m .3317 .60782 L .33751 .60766 L p F P
0 g
s
.33751 .60766 m .36267 .60696 L p .33732 .60576 L .226 .738 .876 r
F P
0 g
s
.33732 .60576 m .32046 .60496 L .33751 .60766 L .226 .738 .876 r
F
.36267 .60696 m .36909 .60678 L p .35954 .60642 L F P
0 g
s
.35954 .60642 m .32046 .60496 L .36267 .60696 L .226 .738 .876 r
F
.37824 .6049 m .36909 .60678 L .3317 .60782 L p .255 .765 .847 r
F P
0 g
s
.34309 .60961 m .37051 .60594 L p .34324 .60726 L .255 .765 .847 r
F P
0 g
s
.3317 .60782 m .34309 .60961 L p .34324 .60726 L .255 .765 .847 r
F P
0 g
s
.37051 .60594 m .37824 .6049 L p .36694 .60561 L .255 .765 .847 r
F P
0 g
s
.36694 .60561 m .3317 .60782 L .37051 .60594 L .255 .765 .847 r
F
.3875 .60228 m .37824 .6049 L .35623 .60785 L p .29 .789 .814 r
F P
0 g
s
.35623 .60785 m .34309 .60961 L p .36226 .60644 L .29 .789 .814 r
F P
0 g
s
.3875 .60228 m .35623 .60785 L .36226 .60644 L .29 .789 .814 r
F
.34309 .60961 m .35464 .61017 L .37859 .60442 L p F P
0 g
s
.37859 .60442 m .3875 .60228 L p .37468 .60439 L .29 .789 .814 r
F P
0 g
s
.37468 .60439 m .34309 .60961 L .37859 .60442 L .29 .789 .814 r
F
.39686 .59883 m .3875 .60228 L .36857 .60683 L p .328 .81 .778 r
F P
0 g
s
.36857 .60683 m .35464 .61017 L p .37468 .60479 L .328 .81 .778 r
F P
0 g
s
.39686 .59883 m .36857 .60683 L .37468 .60479 L .328 .81 .778 r
F
.36633 .6094 m .38689 .60229 L p .3675 .60703 L F P
0 g
s
.35464 .61017 m .36633 .6094 L p .3675 .60703 L .328 .81 .778 r
F P
0 g
s
.38689 .60229 m .39686 .59883 L p .38272 .60263 L .328 .81 .778 r
F P
0 g
s
.38272 .60263 m .35464 .61017 L .38689 .60229 L .328 .81 .778 r
F
.40632 .59452 m .39686 .59883 L .38093 .60435 L p .366 .827 .741 r
F P
0 g
s
.38093 .60435 m .36633 .6094 L p .38707 .60168 L .366 .827 .741 r
F P
0 g
s
.40632 .59452 m .38093 .60435 L .38707 .60168 L .366 .827 .741 r
F
.3901 .6035 m .40215 .5983 L .4169 .58873 L p .437 .846 .668 r
F P
0 g
s
.36633 .6094 m .37815 .6072 L .39868 .59796 L p .366 .827 .741 r
F P
0 g
s
.39868 .59796 m .40632 .59452 L p .3944 .59896 L .366 .827 .741 r
F P
0 g
s
.3944 .59896 m .36633 .6094 L .39868 .59796 L .366 .827 .741 r
F
.41587 .58929 m .40632 .59452 L .39333 .60037 L p .403 .839 .704 r
F P
0 g
s
.39333 .60037 m .37815 .6072 L p .39943 .5971 L .403 .839 .704 r
F P
0 g
s
.41587 .58929 m .39333 .60037 L .39943 .5971 L .403 .839 .704 r
F
.40215 .5983 m .4143 .59158 L .42623 .58275 L p .466 .85 .634 r
F P
0 g
s
.3901 .6035 m .40429 .59534 L p .37815 .6072 L .403 .839 .704 r
F P
0 g
s
.40772 .59379 m .41587 .58929 L p .4033 .59526 L .403 .839 .704 r
F P
0 g
s
.4033 .59526 m .37815 .6072 L .40772 .59379 L .403 .839 .704 r
F
.4143 .59158 m .42652 .58341 L .43567 .57584 L p .492 .852 .604 r
F P
0 g
s
.42551 .58314 m .41587 .58929 L .40574 .59488 L p .437 .846 .668 r
F P
0 g
s
.42551 .58314 m .40574 .59488 L .41176 .59105 L .437 .846 .668 r
F
.4169 .58873 m .42551 .58314 L p .41239 .59069 L F P
0 g
s
.40574 .59488 m .3901 .6035 L p .41176 .59105 L .437 .846 .668 r
F P
0 g
s
.41239 .59069 m .3901 .6035 L .4169 .58873 L .437 .846 .668 r
F
.42551 .58314 m .40215 .5983 L p .4261 .58221 L .466 .85 .634 r
F P
0 g
s
.43524 .57607 m .42551 .58314 L p .4261 .58221 L .466 .85 .634 r
F P
0 g
s
.42623 .58275 m .43524 .57607 L p .42165 .5852 L .466 .85 .634 r
F P
0 g
s
.42165 .5852 m .40215 .5983 L .42623 .58275 L .466 .85 .634 r
F
.4388 .57386 m .45112 .56303 L .4549 .55933 L p .53 .849 .551 r
F P
0 g
s
.44503 .5681 m .43524 .57607 L .43057 .57953 L p .492 .852 .604 r
F P
0 g
s
.44503 .5681 m .43057 .57953 L .43502 .57584 L .492 .852 .604 r
F
.44503 .5681 m .42249 .58551 L .42907 .58029 L F
.43057 .57953 m .42249 .58551 L p .43502 .57584 L F P
0 g
s
.43567 .57584 m .44503 .5681 L p .43107 .57877 L .492 .852 .604 r
F P
0 g
s
.42249 .58551 m .4143 .59158 L p .42907 .58029 L .492 .852 .604 r
F P
0 g
s
.43107 .57877 m .4143 .59158 L .43567 .57584 L .492 .852 .604 r
F
.45489 .55928 m .44503 .5681 L .44296 .56982 L p .513 .851 .576 r
F P
0 g
s
.44296 .56982 m .42652 .58341 L p .44848 .56473 L .513 .851 .576 r
F P
0 g
s
.45489 .55928 m .44296 .56982 L .44848 .56473 L .513 .851 .576 r
F
.45112 .56303 m .46346 .55106 L .46466 .54982 L p .544 .846 .53 r
F P
0 g
s
.4388 .57386 m .44703 .56619 L p .42652 .58341 L .513 .851 .576 r
F P
0 g
s
.45006 .56365 m .45489 .55928 L p .44542 .56733 L .513 .851 .576 r
F P
0 g
s
.44542 .56733 m .42652 .58341 L .45006 .56365 L .513 .851 .576 r
F
.4648 .54965 m .45601 .55819 L p .46058 .55358 L .53 .849 .551 r
F P
0 g
s
.45489 .55928 m .4388 .57386 L p .46058 .55358 L .53 .849 .551 r
F P
0 g
s
.45601 .55819 m .45489 .55928 L p .46058 .55358 L .53 .849 .551 r
F P
0 g
s
.4549 .55933 m .4648 .54965 L p .45031 .56314 L .53 .849 .551 r
F P
0 g
s
.45031 .56314 m .4388 .57386 L .4549 .55933 L .53 .849 .551 r
F
.4648 .54965 m .45112 .56303 L p .46104 .55308 L .544 .846 .53 r
F P
0 g
s
.46516 .54895 m .465 .54926 L .46104 .55308 L .544 .846 .53 r
F
.465 .54926 m .4648 .54965 L .46104 .55308 L F
.4601 .55402 m .45112 .56303 L .46466 .54982 L F
.28762 .59164 m .27695 .58625 L .2497 .56176 L p 0 .369 .81 r
F P
0 g
s
.28762 .59164 m .2497 .56176 L .25272 .56378 L 0 .369 .81 r
F
.28762 .59164 m .24581 .55827 L .24913 .56069 L F
.2497 .56176 m .24581 .55827 L p .25272 .56378 L F P
0 g
s
.24581 .55827 m .24331 .55602 L p .24913 .56069 L 0 .369 .81 r
F P
0 g
s
.24331 .55602 m .25546 .56625 L .28762 .59164 L p 0 .369 .81 r
F P
0 g
s
.29842 .59668 m .28762 .59164 L .26942 .57727 L p 0 .378 .8 r
F P
0 g
s
.29842 .59668 m .26942 .57727 L .27288 .57908 L 0 .378 .8 r
F
.29842 .59668 m .26367 .57273 L .26897 .57582 L F
.26942 .57727 m .26367 .57273 L p .27288 .57908 L F P
0 g
s
.26367 .57273 m .25546 .56625 L p .26897 .57582 L 0 .378 .8 r
F P
0 g
s
.25546 .56625 m .26777 .57604 L .27215 .57899 L p 0 .378 .8 r
F P
0 g
s
.27215 .57899 m .29661 .59546 L p .26905 .57589 L 0 .378 .8 r
F P
0 g
s
.26905 .57589 m .25546 .56625 L .27215 .57899 L 0 .378 .8 r
F
.29394 .59351 m .25546 .56625 L .29661 .59546 L F
.29661 .59546 m .29842 .59668 L p .29394 .59351 L F P
0 g
s
.30937 .60119 m .29842 .59668 L .2839 .58691 L p 0 .4 .795 r
F P
0 g
s
.30937 .60119 m .2839 .58691 L .29034 .58968 L 0 .4 .795 r
F
.2839 .58691 m .26777 .57604 L p .29034 .58968 L F P
0 g
s
.28584 .58821 m .30525 .59892 L p .26777 .57604 L 0 .4 .795 r
F P
0 g
s
.26777 .57604 m .28025 .58513 L .28584 .58821 L p 0 .4 .795 r
F P
0 g
s
.30525 .59892 m .30937 .60119 L p .30187 .59666 L 0 .4 .795 r
F P
0 g
s
.30187 .59666 m .26777 .57604 L .30525 .59892 L 0 .4 .795 r
F
.32046 .60496 m .30937 .60119 L .28025 .58513 L p 0 .435 .793 r
F P
0 g
s
.28025 .58513 m .29292 .59325 L .31495 .60262 L p 0 .435 .793 r
F P
0 g
s
.31495 .60262 m .32046 .60496 L p .31077 .60018 L 0 .435 .793 r
F P
0 g
s
.31077 .60018 m .28025 .58513 L .31495 .60262 L 0 .435 .793 r
F
.3317 .60782 m .32046 .60496 L .30538 .59855 L p 0 .482 .792 r
F P
0 g
s
.30538 .59855 m .29292 .59325 L p .31186 .60037 L 0 .482 .792 r
F P
0 g
s
.3317 .60782 m .30538 .59855 L .31186 .60037 L 0 .482 .792 r
F
.30577 .60016 m .32283 .6052 L p .30502 .59809 L F P
0 g
s
.29292 .59325 m .30577 .60016 L p .30502 .59809 L 0 .482 .792 r
F P
0 g
s
.32283 .6052 m .3317 .60782 L p .318 .60268 L 0 .482 .792 r
F P
0 g
s
.318 .60268 m .29292 .59325 L .32283 .6052 L 0 .482 .792 r
F
.33202 .60947 m .34541 .61151 L .35667 .61037 L p .107 .661 .776 r
F P
0 g
s
.34309 .60961 m .3317 .60782 L .31931 .60416 L p 0 .539 .792 r
F P
0 g
s
.34309 .60961 m .31931 .60416 L .32592 .60526 L 0 .539 .792 r
F
.31931 .60416 m .30577 .60016 L p .32592 .60526 L F P
0 g
s
.33108 .60764 m .33243 .60786 L p .30577 .60016 L 0 .539 .792 r
F P
0 g
s
.30577 .60016 m .3188 .60563 L .33108 .60764 L p 0 .539 .792 r
F P
0 g
s
.33243 .60786 m .34309 .60961 L p .3271 .60556 L 0 .539 .792 r
F P
0 g
s
.3271 .60556 m .30577 .60016 L .33243 .60786 L 0 .539 .792 r
F
.35464 .61017 m .34309 .60961 L .3188 .60563 L p .035 .6 .787 r
F P
0 g
s
.3188 .60563 m .33202 .60947 L .34583 .6099 L p .035 .6 .787 r
F P
0 g
s
.34583 .6099 m .35464 .61017 L p .34036 .60836 L .035 .6 .787 r
F P
0 g
s
.34036 .60836 m .3188 .60563 L .34583 .6099 L .035 .6 .787 r
F
.35464 .61017 m .33945 .6097 L p .36633 .6094 L .107 .661 .776 r
F P
0 g
s
.36633 .6094 m .33945 .6097 L .34635 .60944 L .107 .661 .776 r
F
.35667 .61037 m .36633 .6094 L p .351 .60943 L F P
0 g
s
.33945 .6097 m .33202 .60947 L p .34635 .60944 L .107 .661 .776 r
F P
0 g
s
.351 .60943 m .33202 .60947 L .35667 .61037 L .107 .661 .776 r
F
.36954 .6088 m .36633 .6094 L .34541 .61151 L p .183 .716 .758 r
F P
0 g
s
.37815 .6072 m .36954 .6088 L p .35488 .61045 L .183 .716 .758 r
F P
0 g
s
.37815 .6072 m .35488 .61045 L .36022 .60956 L .183 .716 .758 r
F
.34541 .61151 m .35895 .61163 L .37276 .60844 L p F P
0 g
s
.37276 .60844 m .37815 .6072 L p .36706 .60866 L .183 .716 .758 r
F P
0 g
s
.36022 .60956 m .35488 .61045 L .34541 .61151 L .183 .716 .758 r
F
.36706 .60866 m .34541 .61151 L .37276 .60844 L F
.38049 .60647 m .37815 .6072 L .35895 .61163 L p .258 .762 .732 r
F P
0 g
s
.3901 .6035 m .38049 .60647 L p .36832 .60938 L .258 .762 .732 r
F P
0 g
s
.3901 .6035 m .36832 .60938 L .37414 .60767 L .258 .762 .732 r
F
.35895 .61163 m .37263 .60975 L .38442 .60553 L p F P
0 g
s
.38442 .60553 m .3901 .6035 L p .37861 .6065 L .258 .762 .732 r
F P
0 g
s
.37414 .60767 m .36832 .60938 L .35895 .61163 L .258 .762 .732 r
F
.37861 .6065 m .35895 .61163 L .38442 .60553 L F
.39202 .60267 m .3901 .6035 L .37263 .60975 L p .326 .796 .7 r
F P
0 g
s
.40215 .5983 m .39202 .60267 L p .38208 .6063 L .326 .796 .7 r
F P
0 g
s
.40215 .5983 m .38208 .6063 L .38807 .60376 L .326 .796 .7 r
F
.37263 .60975 m .38642 .60584 L .39624 .60113 L p F P
0 g
s
.39624 .60113 m .40215 .5983 L p .39036 .60287 L .326 .796 .7 r
F P
0 g
s
.38807 .60376 m .38208 .6063 L .37263 .60975 L .326 .796 .7 r
F
.39036 .60287 m .37263 .60975 L .39624 .60113 L F
.37992 .6048 m .39464 .60012 L .39553 .60009 L p .449 .88 .809 r
F P
0 g
s
.40408 .59723 m .40215 .5983 L .39144 .60344 L p .385 .82 .666 r
F P
0 g
s
.40408 .59723 m .39144 .60344 L .39156 .60334 L .385 .82 .666 r
F
.4143 .59158 m .40408 .59723 L p .39611 .60112 L F P
0 g
s
.40202 .59786 m .39611 .60112 L .38642 .60584 L .385 .82 .666 r
F
.4143 .59158 m .39611 .60112 L .40202 .59786 L F
.39144 .60344 m .38642 .60584 L p .39156 .60334 L F P
0 g
s
.38642 .60584 m .4003 .59993 L .4082 .59522 L p .385 .82 .666 r
F P
0 g
s
.4082 .59522 m .4143 .59158 L p .40229 .59773 L .385 .82 .666 r
F P
0 g
s
.40229 .59773 m .38642 .60584 L .4082 .59522 L .385 .82 .666 r
F
.41658 .59006 m .4143 .59158 L .40551 .59682 L p .434 .835 .631 r
F P
0 g
s
.41658 .59006 m .40551 .59682 L .40565 .59669 L .434 .835 .631 r
F
.42652 .58341 m .41658 .59006 L p .41038 .59382 L F P
0 g
s
.41597 .59006 m .41038 .59382 L .4003 .59993 L .434 .835 .631 r
F
.42652 .58341 m .41038 .59382 L .41597 .59006 L F
.40551 .59682 m .4003 .59993 L p .40565 .59669 L F P
0 g
s
.4003 .59993 m .41424 .59207 L .42028 .58781 L p .434 .835 .631 r
F P
0 g
s
.42028 .58781 m .42652 .58341 L p .41436 .59107 L .434 .835 .631 r
F P
0 g
s
.41436 .59107 m .4003 .59993 L .42028 .58781 L .434 .835 .631 r
F
.42941 .58116 m .42652 .58341 L .41972 .58821 L p .474 .842 .599 r
F P
0 g
s
.42941 .58116 m .41972 .58821 L .41988 .58802 L .474 .842 .599 r
F
.4388 .57386 m .42941 .58116 L p .42482 .58446 L F P
0 g
s
.4299 .58046 m .42482 .58446 L .41424 .59207 L .474 .842 .599 r
F
.4388 .57386 m .42482 .58446 L .4299 .58046 L F
.41972 .58821 m .41424 .59207 L p .41988 .58802 L F P
0 g
s
.41424 .59207 m .42822 .58238 L .43246 .57897 L p .474 .842 .599 r
F P
0 g
s
.43246 .57897 m .4388 .57386 L p .42656 .58293 L .474 .842 .599 r
F P
0 g
s
.42656 .58293 m .41424 .59207 L .43246 .57897 L .474 .842 .599 r
F
.44252 .57059 m .43425 .57741 L p .45112 .56303 L .504 .845 .569 r
F P
0 g
s
.45112 .56303 m .43425 .57741 L .43441 .57715 L .504 .845 .569 r
F
.42822 .58238 m .44221 .57102 L .44472 .56877 L p F P
0 g
s
.44472 .56877 m .45112 .56303 L p .43886 .57339 L .504 .845 .569 r
F P
0 g
s
.43425 .57741 m .42822 .58238 L p .43441 .57715 L .504 .845 .569 r
F P
0 g
s
.43886 .57339 m .42822 .58238 L .44472 .56877 L .504 .845 .569 r
F
.43889 .57287 m .44221 .57102 L p .435 .5762 L .543 .884 .636 r
F P
0 g
s
.42416 .58398 m .43546 .57546 L p .435 .5762 L .543 .884 .636 r
F P
0 g
s
.43546 .57546 m .43889 .57287 L p .435 .5762 L .543 .884 .636 r
F P
0 g
s
.43974 .57303 m .4388 .57386 L p .42822 .58238 L .504 .845 .569 r
F P
0 g
s
.42416 .58398 m .42822 .58238 L p .4213 .58633 L .523 .892 .69 r
F P
0 g
s
.4094 .59313 m .42234 .58511 L p .4213 .58633 L .523 .892 .69 r
F P
0 g
s
.42234 .58511 m .42416 .58398 L p .4213 .58633 L .523 .892 .69 r
F P
0 g
s
.4094 .59313 m .41424 .59207 L p .40757 .59481 L .492 .892 .749 r
F P
0 g
s
.39464 .60012 m .40919 .59323 L p .40757 .59481 L .492 .892 .749 r
F P
0 g
s
.40919 .59323 m .4094 .59313 L p .40757 .59481 L .492 .892 .749 r
F P
0 g
s
.39553 .60009 m .4003 .59993 L p .39384 .60147 L .449 .88 .809 r
F P
0 g
s
.39384 .60147 m .37992 .6048 L .39553 .60009 L .449 .88 .809 r
F
.46346 .55106 m .45112 .56303 L .45103 .56311 L p .528 .845 .543 r
F P
0 g
s
.45103 .56311 m .44883 .56508 L p .45763 .55654 L .528 .845 .543 r
F P
0 g
s
.45763 .55654 m .44883 .56508 L .44874 .56489 L .528 .845 .543 r
F
.46346 .55106 m .45103 .56311 L .45763 .55654 L F
.45617 .55819 m .46346 .55106 L p .45056 .56318 L F P
0 g
s
.45355 .56003 m .45617 .55819 L p .44862 .56461 L .556 .873 .589 r
F P
0 g
s
.43889 .57287 m .44853 .56442 L p .44862 .56461 L .556 .873 .589 r
F P
0 g
s
.44853 .56442 m .45355 .56003 L p .44862 .56461 L .556 .873 .589 r
F P
0 g
s
.44883 .56508 m .44221 .57102 L p .44874 .56489 L .528 .845 .543 r
F P
0 g
s
.47477 .53932 m .4648 .54965 L p .46516 .54895 L .544 .846 .53 r
F P
0 g
s
.46466 .54982 m .47477 .53932 L p .4601 .55402 L .544 .846 .53 r
F P
0 g
s
.47477 .53932 m .46346 .55106 L p .47357 .54029 L .554 .843 .512 r
F P
0 g
s
.48477 .52835 m .47897 .5347 L p .47596 .53782 L .554 .843 .512 r
F P
0 g
s
.48477 .52835 m .47596 .53782 L .478 .53557 L .554 .843 .512 r
F
.47897 .5347 m .47477 .53932 L p .47357 .54029 L F P
0 g
s
.478 .53557 m .47596 .53782 L .47357 .54029 L .554 .843 .512 r
F
.47582 .53813 m .48477 .52835 L p .46998 .54412 L F P
0 g
s
.49482 .51686 m .48477 .52835 L .48432 .52885 L p .561 .839 .497 r
F P
0 g
s
.48432 .52885 m .47582 .53813 L p .48618 .52652 L .561 .839 .497 r
F P
0 g
s
.4886 .52388 m .48432 .52885 L .48618 .52652 L .561 .839 .497 r
F
.47582 .53813 m .48817 .5244 L .48975 .52261 L p F P
0 g
s
.48523 .52759 m .47582 .53813 L .48975 .52261 L .561 .839 .497 r
F
.46346 .55106 m .47301 .54107 L p .46998 .54412 L .554 .843 .512 r
F P
0 g
s
.47301 .54107 m .47582 .53813 L p .46998 .54412 L .554 .843 .512 r
F P
0 g
s
.46346 .55106 m .45617 .55819 L p .46318 .55103 L .544 .842 .52 r
F P
0 g
s
.47582 .53813 m .46414 .55035 L p .46318 .55103 L .544 .842 .52 r
F P
0 g
s
.46414 .55035 m .46346 .55106 L p .46318 .55103 L .544 .842 .52 r
F P
0 g
s
.4701 .5441 m .47582 .53813 L p .4694 .54468 L .544 .842 .52 r
F P
0 g
s
.4701 .5441 m .4678 .54632 L p .46364 .55056 L .544 .842 .52 r
F P
0 g
s
.46812 .54574 m .4701 .5441 L p .46211 .55179 L .564 .862 .55 r
F P
0 g
s
.45355 .56003 m .46154 .55219 L p .46211 .55179 L .564 .862 .55 r
F P
0 g
s
.46154 .55219 m .46812 .54574 L p .46211 .55179 L .564 .862 .55 r
F P
0 g
s
.48509 .52775 m .47924 .5343 L .47777 .53574 L .556 .839 .502 r
F
.48397 .52901 m .48817 .5244 L p .47553 .53817 L F P
0 g
s
.48258 .53032 m .48397 .52901 L p .47543 .53803 L .567 .85 .519 r
F P
0 g
s
.46812 .54574 m .47447 .53897 L p .47543 .53803 L .567 .85 .519 r
F P
0 g
s
.47447 .53897 m .48258 .53032 L p .47543 .53803 L .567 .85 .519 r
F P
0 g
s
.47582 .53813 m .4701 .5441 L p .47777 .53574 L .556 .839 .502 r
F P
0 g
s
.47924 .5343 m .47582 .53813 L .47777 .53574 L .556 .839 .502 r
F
.48817 .5244 m .48351 .52957 L p .48509 .52775 L F P
0 g
s
.48351 .52957 m .47582 .53813 L p .48509 .52775 L .556 .839 .502 r
F P
0 g
s
.49011 .52213 m .4886 .52388 L .48618 .52652 L .561 .839 .497 r
F
.49482 .51686 m .48432 .52885 L .49011 .52213 L F
.48975 .52261 m .49482 .51686 L p .48523 .52759 L F P
0 g
s
.50489 .50497 m .49482 .51686 L .48817 .5244 L p .565 .835 .485 r
F P
0 g
s
.50051 .51007 m .50489 .50497 L p .49537 .51603 L .565 .835 .485 r
F P
0 g
s
.49777 .51318 m .50051 .51007 L p .48854 .52378 L .562 .835 .487 r
F P
0 g
s
.48397 .52901 m .48952 .52265 L p .48854 .52378 L .562 .835 .487 r
F P
0 g
s
.48952 .52265 m .49777 .51318 L p .48854 .52378 L .562 .835 .487 r
F P
0 g
s
.4701 .5441 m .47317 .54076 L p .47553 .53817 L .556 .839 .502 r
F P
0 g
s
.47317 .54076 m .48397 .52901 L p .47553 .53817 L .556 .839 .502 r
F P
0 g
s
.48817 .5244 m .49862 .51226 L p .49537 .51603 L .565 .835 .485 r
F P
0 g
s
.49862 .51226 m .50051 .51007 L p .49537 .51603 L .565 .835 .485 r
F P
0 g
s
.45617 .55819 m .46798 .54624 L p .46364 .55056 L .544 .842 .52 r
F P
0 g
s
.46798 .54624 m .4701 .5441 L p .46364 .55056 L .544 .842 .52 r
F P
0 g
s
.44221 .57102 m .44683 .56677 L p .45056 .56318 L .528 .845 .543 r
F P
0 g
s
.44683 .56677 m .45617 .55819 L p .45056 .56318 L .528 .845 .543 r
F P
0 g
s
.60604 .41878 m .59742 .41927 L .61518 .39932 L p .821 .928 .904 r
F P
0 g
s
.61518 .39932 m .62598 .39687 L .60604 .41878 L p .821 .928 .904 r
F P
0 g
s
.52155 .50705 m .52189 .5013 L .55251 .47248 L p .892 .931 .836 r
F P
0 g
s
.54961 .46922 m .55251 .47248 L .52189 .5013 L p .893 .969 .827 r
F P
0 g
s
.55251 .47248 m .54961 .46922 L .57514 .44302 L p .883 .937 .848 r
F P
0 g
s
.77113 .54086 m .75944 .52212 L .79472 .48374 L p .47 .446 .75 r
F P
0 g
s
.78107 .46707 m .79472 .48374 L .75944 .52212 L p .472 .45 .752 r
F P
0 g
s
.63677 .3966 m .62598 .39687 L .63971 .38004 L p .744 .894 .947 r
F P
0 g
s
.63971 .38004 m .65209 .37788 L .63677 .3966 L p .744 .894 .947 r
F P
0 g
s
.4279 .58682 m .43448 .58101 L .47656 .55738 L p .848 .956 .881 r
F P
0 g
s
.48011 .5499 m .47656 .55738 L .43448 .58101 L p .85 .978 .868 r
F P
0 g
s
.48368 .54272 m .48728 .53585 L .52155 .50705 L p .891 .956 .837 r
F P
0 g
s
.52189 .5013 m .52155 .50705 L .48728 .53585 L p .885 .981 .822 r
F P
0 g
s
.78288 .55969 m .77113 .54086 L .80848 .50086 L p .47 .446 .749 r
F P
0 g
s
.79472 .48374 m .80848 .50086 L .77113 .54086 L p .47 .446 .75 r
F P
0 g
s
.56916 .44326 m .57514 .44302 L .54961 .46922 L p .881 .979 .833 r
F P
0 g
s
.57514 .44302 m .56916 .44326 L .58875 .42172 L p .864 .972 .859 r
F P
0 g
s
.58875 .42172 m .59742 .41927 L .57514 .44302 L p .864 .972 .859 r
F P
0 g
s
.59742 .41927 m .58875 .42172 L .60432 .40386 L p .83 .979 .882 r
F P
0 g
s
.60432 .40386 m .61518 .39932 L .59742 .41927 L p .83 .979 .882 r
F P
0 g
s
.79464 .57831 m .78288 .55969 L .82234 .51809 L p .473 .45 .752 r
F P
0 g
s
.80848 .50086 m .82234 .51809 L .78288 .55969 L p .47 .446 .749 r
F P
0 g
s
.62598 .39687 m .61518 .39932 L .62732 .38437 L p .769 .956 .932 r
F P
0 g
s
.62732 .38437 m .63971 .38004 L .62598 .39687 L p .769 .956 .932 r
F P
0 g
s
.43448 .58101 m .44112 .5749 L .48011 .5499 L p .85 .978 .868 r
F P
0 g
s
.48368 .54272 m .48011 .5499 L .44112 .5749 L p .844 .993 .846 r
F P
0 g
s
.52189 .5013 m .52223 .49641 L .54961 .46922 L p .893 .969 .827 r
F P
0 g
s
.54668 .46726 m .54961 .46922 L .52223 .49641 L p .876 .992 .801 r
F P
0 g
s
.54961 .46922 m .54668 .46726 L .56916 .44326 L p .881 .979 .833 r
F P
0 g
s
.82234 .51809 m .83625 .53514 L .79464 .57831 L p .473 .45 .752 r
F P
0 g
s
.48728 .53585 m .49091 .52929 L .52189 .5013 L p .885 .981 .822 r
F P
0 g
s
.52223 .49641 m .52189 .5013 L .49091 .52929 L p .867 .995 .795 r
F P
0 g
s
.7022 .39128 m .68954 .38469 L .69971 .36587 L p .493 .654 .931 r
F P
0 g
s
.68954 .38469 m .67699 .38023 L .6862 .36365 L p .536 .725 .961 r
F P
0 g
s
.6862 .36365 m .69971 .36587 L .68954 .38469 L p .536 .725 .961 r
F P
0 g
s
.71499 .39987 m .7022 .39128 L .71336 .37007 L p .456 .593 .9 r
F P
0 g
s
.69971 .36587 m .71336 .37007 L .7022 .39128 L p .493 .654 .931 r
F P
0 g
s
.67699 .38023 m .66451 .37794 L .6728 .36349 L p .583 .802 .983 r
F P
0 g
s
.6728 .36349 m .6862 .36365 L .67699 .38023 L p .583 .802 .983 r
F P
0 g
s
.72791 .41034 m .71499 .39987 L .72715 .37617 L p .427 .544 .872 r
F P
0 g
s
.71336 .37007 m .72715 .37617 L .71499 .39987 L p .456 .593 .9 r
F P
0 g
s
.56312 .4451 m .56916 .44326 L .54668 .46726 L p .855 .998 .794 r
F P
0 g
s
.56916 .44326 m .56312 .4451 L .58002 .42601 L p .845 .998 .819 r
F P
0 g
s
.58002 .42601 m .58875 .42172 L .56916 .44326 L p .845 .998 .819 r
F P
0 g
s
.61518 .39932 m .60432 .40386 L .61491 .3908 L p .772 .991 .887 r
F P
0 g
s
.61491 .3908 m .62732 .38437 L .61518 .39932 L p .772 .991 .887 r
F P
0 g
s
.44112 .5749 m .44782 .5685 L .48368 .54272 L p .844 .993 .846 r
F P
0 g
s
.48728 .53585 m .48368 .54272 L .44782 .5685 L p .83 1 .817 r
F P
0 g
s
.66451 .37794 m .65209 .37788 L .65948 .36541 L p .628 .877 .988 r
F P
0 g
s
.65948 .36541 m .6728 .36349 L .66451 .37794 L p .628 .877 .988 r
F P
0 g
s
.58875 .42172 m .58002 .42601 L .5934 .4104 L p .812 1 .83 r
F P
0 g
s
.5934 .4104 m .60432 .40386 L .58875 .42172 L p .812 1 .83 r
F P
0 g
s
.74097 .42251 m .72791 .41034 L .74112 .38403 L p .405 .506 .848 r
F P
0 g
s
.72715 .37617 m .74112 .38403 L .72791 .41034 L p .427 .544 .872 r
F P
0 g
s
.25595 .57522 m .24558 .56996 L .20758 .52532 L p .038 .41 .86 r
F P
0 g
s
.75419 .43618 m .74097 .42251 L .75526 .39349 L p .39 .476 .828 r
F P
0 g
s
.74112 .38403 m .75526 .39349 L .74097 .42251 L p .405 .506 .848 r
F P
0 g
s
.65209 .37788 m .63971 .38004 L .64622 .3694 L p .663 .938 .966 r
F P
0 g
s
.64622 .3694 m .65948 .36541 L .65209 .37788 L p .663 .938 .966 r
F P
0 g
s
.52223 .49641 m .52258 .49235 L .54668 .46726 L p .876 .992 .801 r
F P
0 g
s
.54372 .46653 m .54668 .46726 L .52258 .49235 L p .839 .995 .756 r
F P
0 g
s
.54668 .46726 m .54372 .46653 L .56312 .4451 L p .855 .998 .794 r
F P
0 g
s
.49091 .52929 m .49457 .52303 L .52223 .49641 L p .867 .995 .795 r
F P
0 g
s
.52258 .49235 m .52223 .49641 L .49457 .52303 L p .834 .995 .755 r
F P
0 g
s
.44782 .5685 m .45458 .56179 L .48728 .53585 L p .83 1 .817 r
F P
0 g
s
.49091 .52929 m .48728 .53585 L .45458 .56179 L p .807 .997 .779 r
F P
0 g
s
.76756 .45112 m .75419 .43618 L .76959 .40438 L p .379 .454 .812 r
F P
0 g
s
.75526 .39349 m .76959 .40438 L .75419 .43618 L p .39 .476 .828 r
F P
0 g
s
.60432 .40386 m .5934 .4104 L .60245 .39921 L p .751 .993 .813 r
F P
0 g
s
.60245 .39921 m .61491 .3908 L .60432 .40386 L p .751 .993 .813 r
F P
0 g
s
.63971 .38004 m .62732 .38437 L .63299 .37543 L p .68 .972 .914 r
F P
0 g
s
.63299 .37543 m .64622 .3694 L .63971 .38004 L p .68 .972 .914 r
F P
0 g
s
.55702 .4484 m .56312 .4451 L .54372 .46653 L p .805 .988 .732 r
F P
0 g
s
.56312 .4451 m .55702 .4484 L .57119 .43202 L p .799 .992 .752 r
F P
0 g
s
.57119 .43202 m .58002 .42601 L .56312 .4451 L p .799 .992 .752 r
F P
0 g
s
.58002 .42601 m .57119 .43202 L .58238 .41877 L p .768 .987 .753 r
F P
0 g
s
.58238 .41877 m .5934 .4104 L .58002 .42601 L p .768 .987 .753 r
F P
0 g
s
.20758 .52532 m .21939 .5353 L .25595 .57522 L p .038 .41 .86 r
F P
0 g
s
.2664 .58071 m .25595 .57522 L .21939 .5353 L p 0 .387 .841 r
F P
0 g
s
.78107 .46707 m .76756 .45112 L .78411 .41646 L p .374 .44 .8 r
F P
0 g
s
.76959 .40438 m .78411 .41646 L .76756 .45112 L p .379 .454 .812 r
F P
0 g
s
.62732 .38437 m .61491 .3908 L .61977 .38341 L p .679 .978 .839 r
F P
0 g
s
.61977 .38341 m .63299 .37543 L .62732 .38437 L p .679 .978 .839 r
F P
0 g
s
.49457 .52303 m .49826 .51706 L .52258 .49235 L p .834 .995 .755 r
F P
0 g
s
.52293 .48906 m .52258 .49235 L .49826 .51706 L p .79 .98 .705 r
F P
0 g
s
.52258 .49235 m .52293 .48906 L .54372 .46653 L p .839 .995 .756 r
F P
0 g
s
.45458 .56179 m .4614 .55478 L .49091 .52929 L p .807 .997 .779 r
F P
0 g
s
.49457 .52303 m .49091 .52929 L .4614 .55478 L p .777 .985 .736 r
F P
0 g
s
.54072 .46691 m .54372 .46653 L .52293 .48906 L p .785 .977 .697 r
F P
0 g
s
.54372 .46653 m .54072 .46691 L .55702 .4484 L p .805 .988 .732 r
F P
0 g
s
.79472 .48374 m .78107 .46707 L .7988 .4295 L p .373 .431 .792 r
F P
0 g
s
.78411 .41646 m .7988 .4295 L .78107 .46707 L p .374 .44 .8 r
F P
0 g
s
.5934 .4104 m .58238 .41877 L .5899 .40947 L p .713 .969 .727 r
F P
0 g
s
.5899 .40947 m .60245 .39921 L .5934 .4104 L p .713 .969 .727 r
F P
0 g
s
.21939 .5353 m .23129 .54562 L .2664 .58071 L p 0 .387 .841 r
F P
0 g
s
.27695 .58625 m .2664 .58071 L .23129 .54562 L p 0 .372 .824 r
F P
0 g
s
.61491 .3908 m .60245 .39921 L .60651 .39324 L p .663 .961 .755 r
F P
0 g
s
.60651 .39324 m .61977 .38341 L .61491 .3908 L p .663 .961 .755 r
F P
0 g
s
.80848 .50086 m .79472 .48374 L .81366 .44324 L p .375 .427 .787 r
F P
0 g
s
.7988 .4295 m .81366 .44324 L .79472 .48374 L p .373 .431 .792 r
F P
0 g
s
.55083 .45301 m .55702 .4484 L .54072 .46691 L p .741 .956 .659 r
F P
0 g
s
.55702 .4484 m .55083 .45301 L .56225 .43957 L p .737 .96 .672 r
F P
0 g
s
.56225 .43957 m .57119 .43202 L .55702 .4484 L p .737 .96 .672 r
F P
0 g
s
.4614 .55478 m .46827 .54747 L .49457 .52303 L p .777 .985 .736 r
F P
0 g
s
.49826 .51706 m .49457 .52303 L .46827 .54747 L p .743 .966 .689 r
F P
0 g
s
.57119 .43202 m .56225 .43957 L .57125 .42879 L p .712 .952 .668 r
F P
0 g
s
.57125 .42879 m .58238 .41877 L .57119 .43202 L p .712 .952 .668 r
F P
0 g
s
.49826 .51706 m .50198 .51134 L .52293 .48906 L p .79 .98 .705 r
F P
0 g
s
.52328 .48646 m .52293 .48906 L .50198 .51134 L p .738 .953 .65 r
F P
0 g
s
.52293 .48906 m .52328 .48646 L .54072 .46691 L p .785 .977 .697 r
F P
0 g
s
.69971 .36587 m .6862 .36365 L .68499 .35427 L p .425 .792 .995 r
F P
0 g
s
.6862 .36365 m .6728 .36349 L .67151 .35634 L p .471 .855 .981 r
F P
0 g
s
.67151 .35634 m .68499 .35427 L .6862 .36365 L p .471 .855 .981 r
F P
0 g
s
.53769 .46829 m .54072 .46691 L .52328 .48646 L p .723 .943 .632 r
F P
0 g
s
.54072 .46691 m .53769 .46829 L .55083 .45301 L p .741 .956 .659 r
F P
0 g
s
.6728 .36349 m .65948 .36541 L .65813 .36021 L p .512 .902 .942 r
F P
0 g
s
.65813 .36021 m .67151 .35634 L .6728 .36349 L p .512 .902 .942 r
F P
0 g
s
.71336 .37007 m .69971 .36587 L .69859 .35397 L p .379 .721 .989 r
F P
0 g
s
.68499 .35427 m .69859 .35397 L .69971 .36587 L p .425 .792 .995 r
F P
0 g
s
.82234 .51809 m .80848 .50086 L .82867 .45741 L p .381 .428 .785 r
F P
0 g
s
.81366 .44324 m .82867 .45741 L .80848 .50086 L p .375 .427 .787 r
F P
0 g
s
.23129 .54562 m .24331 .55602 L .27695 .58625 L p 0 .372 .824 r
F P
0 g
s
.63528 .37 m .64769 .36301 L .65489 .36108 L p .467 .879 .743 r
F P
0 g
s
.65489 .36108 m .65813 .36021 L p .65372 .3621 L .467 .879 .743 r
F P
0 g
s
.64601 .36886 m .64484 .36587 L p .6496 .36572 L .542 .928 .882 r
F P
0 g
s
.64484 .36587 m .65813 .36021 L .65948 .36541 L p .542 .928 .882 r
F P
0 g
s
.63161 .37326 m .64484 .36587 L .64622 .3694 L p .562 .933 .81 r
F P
0 g
s
.63299 .37543 m .63161 .37326 L p .6367 .37192 L .562 .933 .81 r
F P
0 g
s
.64622 .3694 m .63318 .37534 L p .6367 .37192 L .562 .933 .81 r
F P
0 g
s
.63318 .37534 m .63299 .37543 L p .6367 .37192 L .562 .933 .81 r
F P
0 g
s
.62295 .37831 m .63528 .37 L .64137 .36737 L p .493 .878 .688 r
F P
0 g
s
.61841 .38233 m .63161 .37326 L .63299 .37543 L p .572 .923 .736 r
F P
0 g
s
.61977 .38341 m .61841 .38233 L p .62388 .37974 L .572 .923 .736 r
F P
0 g
s
.63299 .37543 m .62141 .38242 L p .62388 .37974 L .572 .923 .736 r
F P
0 g
s
.62141 .38242 m .61977 .38341 L p .62388 .37974 L .572 .923 .736 r
F P
0 g
s
.61068 .38789 m .62295 .37831 L .62782 .37547 L p .513 .872 .638 r
F P
0 g
s
.60521 .39298 m .61841 .38233 L .61977 .38341 L p .576 .907 .668 r
F P
0 g
s
.60651 .39324 m .60521 .39298 L p .61113 .38909 L .576 .907 .668 r
F P
0 g
s
.61977 .38341 m .60962 .39093 L p .61113 .38909 L .576 .907 .668 r
F P
0 g
s
.60962 .39093 m .60651 .39324 L p .61113 .38909 L .576 .907 .668 r
F P
0 g
s
.59844 .39864 m .61068 .38789 L .61416 .38539 L p .53 .865 .594 r
F P
0 g
s
.592 .40506 m .60521 .39298 L .60651 .39324 L p .576 .888 .609 r
F P
0 g
s
.59321 .40476 m .592 .40506 L p .59844 .39981 L .576 .888 .609 r
F P
0 g
s
.60651 .39324 m .59778 .4008 L p .59844 .39981 L .576 .888 .609 r
F P
0 g
s
.59778 .4008 m .59321 .40476 L p .59844 .39981 L .576 .888 .609 r
F P
0 g
s
.58623 .41047 m .59844 .39864 L .60022 .39716 L p .543 .856 .558 r
F P
0 g
s
.57876 .41841 m .592 .40506 L .59321 .40476 L p .574 .87 .561 r
F P
0 g
s
.57982 .4178 m .57876 .41841 L p .58582 .41174 L .574 .87 .561 r
F P
0 g
s
.59321 .40476 m .58589 .41189 L p .58582 .41174 L .574 .87 .561 r
F P
0 g
s
.58589 .41189 m .57982 .4178 L p .58582 .41174 L .574 .87 .561 r
F P
0 g
s
.592 .40506 m .58078 .41637 L p .58527 .41187 L .552 .849 .528 r
F P
0 g
s
.58623 .41047 m .592 .40506 L p .58569 .41145 L .552 .849 .528 r
F P
0 g
s
.56546 .43286 m .57876 .41841 L .57982 .4178 L p .572 .854 .524 r
F P
0 g
s
.56546 .43286 m .56183 .4368 L p .57322 .42443 L .559 .842 .505 r
F P
0 g
s
.57876 .41841 m .57092 .42693 L p .57322 .42443 L .559 .842 .505 r
F P
0 g
s
.57092 .42693 m .56546 .43286 L p .57322 .42443 L .559 .842 .505 r
F P
0 g
s
.57815 .41908 m .58527 .41187 L .57876 .41841 L .552 .849 .528 r
F
.56183 .4368 m .57403 .42324 L .57876 .41841 L p .559 .842 .505 r
F P
0 g
s
.57876 .41841 m .57403 .42324 L p .57815 .41908 L .552 .849 .528 r
F P
0 g
s
.58078 .41637 m .57876 .41841 L p .58527 .41187 L .552 .849 .528 r
F P
0 g
s
.57815 .41908 m .58556 .41117 L .58569 .41145 L .552 .849 .528 r
F
.57403 .42324 m .58178 .41514 L p .57815 .41908 L F P
0 g
s
.58178 .41514 m .58556 .41117 L p .57815 .41908 L .552 .849 .528 r
F P
0 g
s
.58556 .41117 m .58623 .41047 L p .58569 .41145 L .552 .849 .528 r
F P
0 g
s
.60521 .39298 m .59956 .39815 L p .59954 .39817 L .543 .856 .558 r
F P
0 g
s
.59956 .39815 m .592 .40506 L p .59954 .39817 L .543 .856 .558 r
F P
0 g
s
.592 .40506 m .59133 .40568 L p .59954 .39817 L .543 .856 .558 r
F P
0 g
s
.59133 .40568 m .58623 .41047 L p .59728 .40029 L .543 .856 .558 r
F P
0 g
s
.59728 .40029 m .60521 .39298 L .59133 .40568 L .543 .856 .558 r
F
.59154 .40558 m .60022 .39716 L .59948 .39826 L F
.58623 .41047 m .59469 .40242 L .59154 .40558 L F
.59469 .40242 m .60022 .39716 L .59154 .40558 L F
.60022 .39716 m .60521 .39298 L p .59948 .39826 L F P
0 g
s
.61841 .38233 m .61326 .38649 L p .61321 .38655 L .53 .865 .594 r
F P
0 g
s
.61326 .38649 m .60521 .39298 L p .61321 .38655 L .53 .865 .594 r
F P
0 g
s
.60521 .39298 m .60334 .39454 L p .61321 .38655 L .53 .865 .594 r
F P
0 g
s
.60334 .39454 m .59844 .39864 L p .60928 .38979 L .53 .865 .594 r
F P
0 g
s
.60928 .38979 m .61841 .38233 L .60334 .39454 L .53 .865 .594 r
F
.60496 .39332 m .61416 .38539 L .61312 .38665 L F
.59844 .39864 m .60769 .39085 L .60496 .39332 L F
.60769 .39085 m .61416 .38539 L .60496 .39332 L F
.61416 .38539 m .61841 .38233 L p .61312 .38665 L F P
0 g
s
.63161 .37326 m .62682 .37655 L p .62675 .37663 L .513 .872 .638 r
F P
0 g
s
.62682 .37655 m .61841 .38233 L p .62675 .37663 L .513 .872 .638 r
F P
0 g
s
.61841 .38233 m .61536 .38452 L p .62675 .37663 L .513 .872 .638 r
F P
0 g
s
.62128 .38048 m .63161 .37326 L .61536 .38452 L .513 .872 .638 r
F
.61842 .38248 m .62782 .37547 L .62668 .37671 L F
.61536 .38452 m .61068 .38789 L p .62128 .38048 L F P
0 g
s
.61068 .38789 m .62103 .38039 L .61842 .38248 L .513 .872 .638 r
F
.62103 .38039 m .62782 .37547 L .61842 .38248 L F
.62782 .37547 m .63161 .37326 L p .62668 .37671 L F P
0 g
s
.64484 .36587 m .6403 .3684 L p .64024 .36846 L .493 .878 .688 r
F P
0 g
s
.6403 .3684 m .63161 .37326 L p .64024 .36846 L .493 .878 .688 r
F P
0 g
s
.63161 .37326 m .62742 .3757 L p .64024 .36846 L .493 .878 .688 r
F P
0 g
s
.63329 .37244 m .64484 .36587 L .62742 .3757 L .493 .878 .688 r
F
.63194 .3732 m .64137 .36737 L .6402 .36851 L F
.62742 .3757 m .62295 .37831 L p .63329 .37244 L F P
0 g
s
.62295 .37831 m .63455 .37142 L .63194 .3732 L .493 .878 .688 r
F
.63455 .37142 m .64137 .36737 L .63194 .3732 L F
.64137 .36737 m .64484 .36587 L p .6402 .36851 L F P
0 g
s
.65813 .36021 m .65375 .36208 L p .65372 .3621 L .467 .879 .743 r
F P
0 g
s
.65375 .36208 m .64484 .36587 L p .65372 .3621 L .467 .879 .743 r
F P
0 g
s
.64484 .36587 m .63528 .37 L p .65372 .3621 L .467 .879 .743 r
F P
0 g
s
.64555 .3656 m .65489 .36108 L .65372 .3621 L .467 .879 .743 r
F
.63528 .37 m .64821 .36412 L .64555 .3656 L F
.64821 .36412 m .65489 .36108 L .64555 .3656 L F
.65948 .36541 m .64622 .3694 L .64601 .36886 L p .542 .928 .882 r
F P
0 g
s
.6496 .36572 m .65948 .36541 L .64601 .36886 L .542 .928 .882 r
F
.58238 .41877 m .57125 .42879 L .57724 .42136 L p .669 .932 .644 r
F P
0 g
s
.57724 .42136 m .5899 .40947 L .58238 .41877 L p .669 .932 .644 r
F P
0 g
s
.60245 .39921 m .5899 .40947 L .59321 .40476 L p .641 .932 .674 r
F P
0 g
s
.59321 .40476 m .60651 .39324 L .60245 .39921 L p .641 .932 .674 r
F P
0 g
s
.72715 .37617 m .71336 .37007 L .71234 .35538 L p .339 .653 .97 r
F P
0 g
s
.69859 .35397 m .71234 .35538 L .71336 .37007 L p .379 .721 .989 r
F P
0 g
s
.46827 .54747 m .47519 .53987 L .49826 .51706 L p .743 .966 .689 r
F P
0 g
s
.50198 .51134 m .49826 .51706 L .47519 .53987 L p .706 .942 .642 r
F P
0 g
s
.74112 .38403 m .72715 .37617 L .72626 .35843 L p .306 .593 .945 r
F P
0 g
s
.71234 .35538 m .72626 .35843 L .72715 .37617 L p .339 .653 .97 r
F P
0 g
s
.83625 .53514 m .82234 .51809 L .84382 .4717 L p .39 .434 .786 r
F P
0 g
s
.82867 .45741 m .84382 .4717 L .82234 .51809 L p .381 .428 .785 r
F P
0 g
s
.50198 .51134 m .50574 .50586 L .52328 .48646 L p .738 .953 .65 r
F P
0 g
s
.52364 .48448 m .52328 .48646 L .50574 .50586 L p .687 .92 .595 r
F P
0 g
s
.52328 .48646 m .52364 .48448 L .53769 .46829 L p .723 .943 .632 r
F P
0 g
s
.54456 .45875 m .55083 .45301 L .53769 .46829 L p .676 .914 .588 r
F P
0 g
s
.55083 .45301 m .54456 .45875 L .55319 .44844 L p .673 .916 .595 r
F P
0 g
s
.55319 .44844 m .56225 .43957 L .55083 .45301 L p .673 .916 .595 r
F P
0 g
s
.56225 .43957 m .55319 .44844 L .55997 .44024 L p .656 .909 .59 r
F P
0 g
s
.55997 .44024 m .57125 .42879 L .56225 .43957 L p .656 .909 .59 r
F P
0 g
s
.75526 .39349 m .74112 .38403 L .74036 .36301 L p .283 .543 .919 r
F P
0 g
s
.72626 .35843 m .74036 .36301 L .74112 .38403 L p .306 .593 .945 r
F P
0 g
s
.5899 .40947 m .57724 .42136 L .57982 .4178 L p .618 .901 .604 r
F P
0 g
s
.57982 .4178 m .59321 .40476 L .5899 .40947 L p .618 .901 .604 r
F P
0 g
s
.84382 .4717 m .85906 .48583 L .83625 .53514 L p .39 .434 .786 r
F P
0 g
s
.53462 .47052 m .53769 .46829 L .52364 .48448 L p .664 .904 .57 r
F P
0 g
s
.53769 .46829 m .53462 .47052 L .54456 .45875 L p .676 .914 .588 r
F P
0 g
s
.47519 .53987 m .48217 .532 L .50198 .51134 L p .706 .942 .642 r
F P
0 g
s
.50574 .50586 m .50198 .51134 L .48217 .532 L p .67 .916 .597 r
F P
0 g
s
.57125 .42879 m .55997 .44024 L .56445 .43468 L p .629 .894 .573 r
F P
0 g
s
.56445 .43468 m .57724 .42136 L .57125 .42879 L p .629 .894 .573 r
F P
0 g
s
.76959 .40438 m .75526 .39349 L .75464 .36898 L p .268 .503 .896 r
F P
0 g
s
.74036 .36301 m .75464 .36898 L .75526 .39349 L p .283 .543 .919 r
F P
0 g
s
.50574 .50586 m .50953 .50057 L .52364 .48448 L p .687 .92 .595 r
F P
0 g
s
.524 .48301 m .52364 .48448 L .50953 .50057 L p .64 .887 .547 r
F P
0 g
s
.52364 .48448 m .524 .48301 L .53462 .47052 L p .664 .904 .57 r
F P
0 g
s
.78411 .41646 m .76959 .40438 L .76913 .37616 L p .261 .475 .877 r
F P
0 g
s
.75464 .36898 m .76913 .37616 L .76959 .40438 L p .268 .503 .896 r
F P
0 g
s
.57724 .42136 m .56445 .43468 L .56634 .43215 L p .598 .873 .549 r
F P
0 g
s
.56634 .43215 m .57982 .4178 L .57724 .42136 L p .598 .873 .549 r
F P
0 g
s
.48217 .532 m .4892 .52388 L .50574 .50586 L p .67 .916 .597 r
F P
0 g
s
.50953 .50057 m .50574 .50586 L .4892 .52388 L p .638 .89 .557 r
F P
0 g
s
.21939 .5353 m .20758 .52532 L .18911 .47507 L p .053 .32 .803 r
F P
0 g
s
.53819 .4654 m .54456 .45875 L .53462 .47052 L p .621 .873 .529 r
F P
0 g
s
.54456 .45875 m .53819 .4654 L .54399 .4584 L p .619 .874 .532 r
F P
0 g
s
.54399 .4584 m .55319 .44844 L .54456 .45875 L p .619 .874 .532 r
F P
0 g
s
.55319 .44844 m .54399 .4584 L .54853 .45287 L p .611 .87 .529 r
F P
0 g
s
.54853 .45287 m .55997 .44024 L .55319 .44844 L p .611 .87 .529 r
F P
0 g
s
.5315 .47342 m .53462 .47052 L .524 .48301 L p .615 .868 .521 r
F P
0 g
s
.53462 .47052 m .5315 .47342 L .53819 .4654 L p .621 .873 .529 r
F P
0 g
s
.55997 .44024 m .54853 .45287 L .55151 .44917 L p .597 .862 .52 r
F P
0 g
s
.55151 .44917 m .56445 .43468 L .55997 .44024 L p .597 .862 .52 r
F P
0 g
s
.7988 .4295 m .78411 .41646 L .78381 .38439 L p .261 .455 .862 r
F P
0 g
s
.76913 .37616 m .78381 .38439 L .78411 .41646 L p .261 .475 .877 r
F P
0 g
s
.18911 .47507 m .20175 .48936 L .21939 .5353 L p .053 .32 .803 r
F P
0 g
s
.23129 .54562 m .21939 .5353 L .20175 .48936 L p .009 .297 .792 r
F P
0 g
s
.4892 .52388 m .49628 .51553 L .50953 .50057 L p .638 .89 .557 r
F P
0 g
s
.51337 .49543 m .50953 .50057 L .49628 .51553 L p .61 .867 .524 r
F P
0 g
s
.50953 .50057 m .51337 .49543 L .524 .48301 L p .64 .887 .547 r
F P
0 g
s
.52437 .48194 m .524 .48301 L .51337 .49543 L p .603 .859 .509 r
F P
0 g
s
.524 .48301 m .52437 .48194 L .5315 .47342 L p .615 .868 .521 r
F P
0 g
s
.67151 .35634 m .65813 .36021 L .64769 .36301 L p .436 .872 .8 r
F P
0 g
s
.56445 .43468 m .55151 .44917 L .55273 .44757 L p .582 .851 .509 r
F P
0 g
s
.55273 .44757 m .56634 .43215 L .56445 .43468 L p .582 .851 .509 r
F P
0 g
s
.57982 .4178 m .56634 .43215 L .56546 .43286 L p .572 .854 .524 r
F P
0 g
s
.68499 .35427 m .67151 .35634 L .66019 .35737 L p .4 .855 .854 r
F P
0 g
s
.64769 .36301 m .66019 .35737 L .67151 .35634 L p .436 .872 .8 r
F P
0 g
s
.81366 .44324 m .7988 .4295 L .79868 .39343 L p .266 .444 .851 r
F P
0 g
s
.78381 .38439 m .79868 .39343 L .7988 .4295 L p .261 .455 .862 r
F P
0 g
s
.69859 .35397 m .68499 .35427 L .6728 .35311 L p .36 .827 .901 r
F P
0 g
s
.66019 .35737 m .6728 .35311 L .68499 .35427 L p .4 .855 .854 r
F P
0 g
s
.71234 .35538 m .69859 .35397 L .68554 .3502 L p .32 .787 .934 r
F P
0 g
s
.6728 .35311 m .68554 .3502 L .69859 .35397 L p .36 .827 .901 r
F P
0 g
s
.53171 .47272 m .53819 .4654 L .5315 .47342 L p .583 .843 .489 r
F P
0 g
s
.53819 .4654 m .53171 .47272 L .53463 .46917 L p .583 .843 .489 r
F P
0 g
s
.53463 .46917 m .54399 .4584 L .53819 .4654 L p .583 .843 .489 r
F P
0 g
s
.54399 .4584 m .53463 .46917 L .53692 .46638 L p .58 .842 .488 r
F P
0 g
s
.53692 .46638 m .54853 .45287 L .54399 .4584 L p .58 .842 .488 r
F P
0 g
s
.20175 .48936 m .21448 .50406 L .23129 .54562 L p .009 .297 .792 r
F P
0 g
s
.24331 .55602 m .23129 .54562 L .21448 .50406 L p 0 .285 .786 r
F P
0 g
s
.52833 .4768 m .5315 .47342 L .52437 .48194 L p .581 .842 .486 r
F P
0 g
s
.5315 .47342 m .52833 .4768 L .53171 .47272 L p .583 .843 .489 r
F P
0 g
s
.54853 .45287 m .53692 .46638 L .5384 .46454 L p .576 .839 .486 r
F P
0 g
s
.5384 .46454 m .55151 .44917 L .54853 .45287 L p .576 .839 .486 r
F P
0 g
s
.49628 .51553 m .50342 .50698 L .51337 .49543 L p .61 .867 .524 r
F P
0 g
s
.51724 .49041 m .51337 .49543 L .50342 .50698 L p .588 .849 .497 r
F P
0 g
s
.51337 .49543 m .51724 .49041 L .52437 .48194 L p .603 .859 .509 r
F P
0 g
s
.82867 .45741 m .81366 .44324 L .81374 .40308 L p .277 .439 .843 r
F P
0 g
s
.79868 .39343 m .81374 .40308 L .81366 .44324 L p .266 .444 .851 r
F P
0 g
s
.56634 .43215 m .55273 .44757 L .5521 .44818 L p .57 .842 .497 r
F P
0 g
s
.5521 .44818 m .56546 .43286 L .56634 .43215 L p .57 .842 .497 r
F P
0 g
s
.72626 .35843 m .71234 .35538 L .69842 .3486 L p .283 .74 .953 r
F P
0 g
s
.68554 .3502 m .69842 .3486 L .71234 .35538 L p .32 .787 .934 r
F P
0 g
s
.52474 .48114 m .52437 .48194 L .51724 .49041 L p .578 .839 .483 r
F P
0 g
s
.52437 .48194 m .52474 .48114 L .52833 .4768 L p .581 .842 .486 r
F P
0 g
s
.55151 .44917 m .5384 .46454 L .539 .46377 L p .571 .836 .482 r
F P
0 g
s
.539 .46377 m .55273 .44757 L .55151 .44917 L p .571 .836 .482 r
F P
0 g
s
.74036 .36301 m .72626 .35843 L .71145 .34825 L p .252 .691 .96 r
F P
0 g
s
.69842 .3486 m .71145 .34825 L .72626 .35843 L p .283 .74 .953 r
F P
0 g
s
.21448 .50406 m .22731 .51888 L .24331 .55602 L p 0 .285 .786 r
F P
0 g
s
.25546 .56625 m .24331 .55602 L .22731 .51888 L p 0 .284 .785 r
F P
0 g
s
.84382 .4717 m .82867 .45741 L .82897 .41309 L p .292 .441 .839 r
F P
0 g
s
.81374 .40308 m .82897 .41309 L .82867 .45741 L p .277 .439 .843 r
F P
0 g
s
.50342 .50698 m .5106 .49826 L .51724 .49041 L p .588 .849 .497 r
F P
0 g
s
.52116 .48543 m .51724 .49041 L .5106 .49826 L p .573 .836 .479 r
F P
0 g
s
.51724 .49041 m .52116 .48543 L .52474 .48114 L p .578 .839 .483 r
F P
0 g
s
.55273 .44757 m .539 .46377 L .53865 .46413 L p .568 .833 .479 r
F P
0 g
s
.53865 .46413 m .5521 .44818 L .55273 .44757 L p .568 .833 .479 r
F P
0 g
s
.5106 .49826 m .50342 .50698 L .49482 .51686 L p .574 .84 .488 r
F P
0 g
s
.56546 .43286 m .5521 .44818 L .54961 .45099 L p .564 .836 .488 r
F P
0 g
s
.54961 .45099 m .56183 .4368 L .56546 .43286 L p .564 .836 .488 r
F P
0 g
s
.75464 .36898 m .74036 .36301 L .72466 .34907 L p .229 .644 .958 r
F P
0 g
s
.71145 .34825 m .72466 .34907 L .74036 .36301 L p .252 .691 .96 r
F P
0 g
s
.52511 .48046 m .53171 .47272 L .52833 .4768 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53463 .46917 L .53171 .47272 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53692 .46638 L .53463 .46917 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .52833 .4768 L .52474 .48114 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .5384 .46454 L .53692 .46638 L closepath p .565 .828 .469 r
F P
0 g
s
.85906 .48583 m .84382 .4717 L .84435 .4232 L p .311 .448 .838 r
F P
0 g
s
.82897 .41309 m .84435 .4232 L .84382 .4717 L p .292 .441 .839 r
F P
0 g
s
.22731 .51888 m .24029 .5335 L .25546 .56625 L p 0 .284 .785 r
F P
0 g
s
.26777 .57604 m .25546 .56625 L .24029 .5335 L p 0 .295 .792 r
F P
0 g
s
.52511 .48046 m .52474 .48114 L .52116 .48543 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .539 .46377 L .5384 .46454 L closepath p .565 .828 .469 r
F P
0 g
s
.51783 .48941 m .5106 .49826 L .50489 .50497 L p .569 .833 .476 r
F P
0 g
s
.5106 .49826 m .51783 .48941 L .52116 .48543 L p .573 .836 .479 r
F P
0 g
s
.5521 .44818 m .53865 .46413 L .53738 .46561 L p .566 .832 .476 r
F P
0 g
s
.53738 .46561 m .54961 .45099 L .5521 .44818 L p .566 .832 .476 r
F P
0 g
s
.76913 .37616 m .75464 .36898 L .73804 .35094 L p .216 .603 .95 r
F P
0 g
s
.72466 .34907 m .73804 .35094 L .75464 .36898 L p .229 .644 .958 r
F P
0 g
s
.52511 .48046 m .52116 .48543 L .51783 .48941 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53865 .46413 L .539 .46377 L closepath p .565 .828 .469 r
F P
0 g
s
.54961 .45099 m .54544 .45584 L p .55482 .44495 L .566 .836 .485 r
F P
0 g
s
.56183 .4368 m .55148 .44882 L p .55482 .44495 L .566 .836 .485 r
F P
0 g
s
.55148 .44882 m .54961 .45099 L p .55482 .44495 L .566 .836 .485 r
F P
0 g
s
.55564 .44379 m .56588 .43208 L .5663 .43162 L p .563 .841 .499 r
F P
0 g
s
.54544 .45584 m .55564 .44379 L .56183 .4368 L p .566 .836 .485 r
F P
0 g
s
.57403 .42324 m .56183 .4368 L .56037 .43845 L p .563 .841 .499 r
F P
0 g
s
.56499 .43335 m .57403 .42324 L .56037 .43845 L .563 .841 .499 r
F
.5663 .43162 m .57403 .42324 L p .56025 .43864 L F P
0 g
s
.56037 .43845 m .55564 .44379 L p .56499 .43335 L .563 .841 .499 r
F P
0 g
s
.55564 .44379 m .5663 .43162 L .56025 .43864 L .563 .841 .499 r
F
.56588 .43208 m .57615 .42081 L .57868 .41822 L p .559 .846 .517 r
F P
0 g
s
.58623 .41047 m .57403 .42324 L .5705 .42707 L p .559 .846 .517 r
F P
0 g
s
.57516 .42223 m .58623 .41047 L .5705 .42707 L .559 .846 .517 r
F
.57868 .41822 m .58623 .41047 L p .57243 .42512 L F P
0 g
s
.5705 .42707 m .56588 .43208 L p .57516 .42223 L .559 .846 .517 r
F P
0 g
s
.56588 .43208 m .57868 .41822 L .57243 .42512 L .559 .846 .517 r
F
.59844 .39864 m .58623 .41047 L .58066 .41619 L p .553 .853 .539 r
F P
0 g
s
.58066 .41619 m .57615 .42081 L p .58533 .41169 L .553 .853 .539 r
F P
0 g
s
.58533 .41169 m .59844 .39864 L .58066 .41619 L .553 .853 .539 r
F
.57615 .42081 m .58646 .41009 L .59108 .40568 L p F P
0 g
s
.59108 .40568 m .59844 .39864 L p .58469 .41232 L .553 .853 .539 r
F P
0 g
s
.57615 .42081 m .59108 .40568 L .58469 .41232 L .553 .853 .539 r
F
.60726 .39058 m .61775 .38192 L .62177 .37919 L p .525 .877 .636 r
F P
0 g
s
.61068 .38789 m .59844 .39864 L .59519 .40175 L p .545 .861 .566 r
F P
0 g
s
.59861 .39885 m .61068 .38789 L .59519 .40175 L .545 .861 .566 r
F
.59551 .40179 m .61068 .38789 L .59085 .4059 L F
.59519 .40175 m .59085 .4059 L p .59861 .39885 L F P
0 g
s
.59085 .4059 m .58646 .41009 L p .59551 .40179 L .545 .861 .566 r
F P
0 g
s
.58646 .41009 m .59683 .39998 L .60352 .39414 L p .545 .861 .566 r
F P
0 g
s
.60352 .39414 m .61068 .38789 L p .59704 .40039 L .545 .861 .566 r
F P
0 g
s
.58646 .41009 m .60352 .39414 L .59704 .40039 L .545 .861 .566 r
F
.62295 .37831 m .61068 .38789 L .60523 .39264 L p .536 .869 .599 r
F P
0 g
s
.60851 .39017 m .62295 .37831 L .60523 .39264 L .536 .869 .599 r
F
.60571 .39261 m .62295 .37831 L .60107 .39627 L F
.62223 .37888 m .62295 .37831 L p .62246 .37872 L F P
0 g
s
.60948 .38949 m .62223 .37888 L .62246 .37872 L .536 .869 .599 r
F
.61601 .38373 m .62223 .37888 L p .60948 .38949 L F P
0 g
s
.60523 .39264 m .60107 .39627 L p .60851 .39017 L .536 .869 .599 r
F P
0 g
s
.60107 .39627 m .59683 .39998 L p .60571 .39261 L .536 .869 .599 r
F P
0 g
s
.59683 .39998 m .60726 .39058 L .61601 .38373 L p .536 .869 .599 r
F P
0 g
s
.59683 .39998 m .61601 .38373 L .60948 .38949 L .536 .869 .599 r
F
.63528 .37 m .62295 .37831 L .61532 .38428 L p .525 .877 .636 r
F P
0 g
s
.61846 .38221 m .63528 .37 L .61532 .38428 L .525 .877 .636 r
F
.61595 .38419 m .63528 .37 L .61135 .38737 L F
.62857 .37456 m .63528 .37 L p .62203 .37973 L F P
0 g
s
.61532 .38428 m .61135 .38737 L p .61846 .38221 L .525 .877 .636 r
F P
0 g
s
.62177 .37919 m .62857 .37456 L p .6154 .3846 L .525 .877 .636 r
F P
0 g
s
.6154 .3846 m .62857 .37456 L .62203 .37973 L .525 .877 .636 r
F
.61135 .38737 m .60726 .39058 L p .61595 .38419 L F P
0 g
s
.60726 .39058 m .62177 .37919 L .6154 .3846 L .525 .877 .636 r
F
.64769 .36301 m .63528 .37 L .62545 .37668 L p .513 .884 .679 r
F P
0 g
s
.62545 .37668 m .61775 .38192 L p .63029 .374 L .513 .884 .679 r
F P
0 g
s
.63029 .374 m .64769 .36301 L .62545 .37668 L .513 .884 .679 r
F
.64122 .3667 m .64769 .36301 L p .6347 .37121 L F P
0 g
s
.62809 .37539 m .63331 .37145 L .63682 .36961 L .513 .884 .679 r
F
.63331 .37145 m .63459 .37049 L .63682 .36961 L F
.63459 .37049 m .64122 .3667 L p .63682 .36961 L F P
0 g
s
.62809 .37539 m .64122 .3667 L .6347 .37121 L .513 .884 .679 r
F
.61775 .38192 m .62833 .37406 L .63459 .37049 L p F P
0 g
s
.61775 .38192 m .63459 .37049 L .62809 .37539 L .513 .884 .679 r
F
.64976 .36079 m .66064 .35539 L .6739 .35262 L p .464 .889 .827 r
F P
0 g
s
.66019 .35737 m .64769 .36301 L .63564 .36988 L p .498 .89 .726 r
F P
0 g
s
.6404 .36774 m .66019 .35737 L .63564 .36988 L .498 .89 .726 r
F
.63899 .36701 m .64976 .36079 L .66063 .35717 L p .482 .892 .776 r
F P
0 g
s
.63564 .36988 m .62833 .37406 L p .6404 .36774 L .498 .89 .726 r
F P
0 g
s
.62833 .37406 m .63899 .36701 L .64754 .36313 L p .498 .89 .726 r
F P
0 g
s
.64754 .36313 m .66019 .35737 L p .64097 .36744 L .498 .89 .726 r
F P
0 g
s
.62833 .37406 m .64754 .36313 L .64097 .36744 L .498 .89 .726 r
F
.6728 .35311 m .66019 .35737 L .64589 .36388 L p .482 .892 .776 r
F P
0 g
s
.64589 .36388 m .63899 .36701 L p .65054 .36226 L .482 .892 .776 r
F P
0 g
s
.65054 .36226 m .6728 .35311 L .64589 .36388 L .482 .892 .776 r
F
.66064 .35539 m .67163 .35077 L .68736 .3495 L p .445 .88 .874 r
F P
0 g
s
.65946 .35782 m .66599 .35591 L p .65403 .36083 L .482 .892 .776 r
F P
0 g
s
.63899 .36701 m .66063 .35717 L .65403 .36083 L .482 .892 .776 r
F
.68554 .3502 m .6728 .35311 L .65313 .35967 L p .464 .889 .827 r
F P
0 g
s
.65313 .35967 m .64976 .36079 L p .65733 .35855 L .464 .889 .827 r
F P
0 g
s
.65733 .35855 m .68554 .3502 L .65313 .35967 L .464 .889 .827 r
F
.6739 .35262 m .68554 .3502 L p .66732 .35559 L F P
0 g
s
.64976 .36079 m .6739 .35262 L .66732 .35559 L .464 .889 .827 r
F
.69842 .3486 m .68554 .3502 L .66378 .35473 L p .445 .88 .874 r
F P
0 g
s
.66378 .35473 m .66064 .35539 L p .66781 .3541 L .445 .88 .874 r
F P
0 g
s
.66781 .3541 m .69842 .3486 L .66378 .35473 L .445 .88 .874 r
F
.68736 .3495 m .69311 .34903 L p .68085 .35176 L F P
0 g
s
.69311 .34903 m .69842 .3486 L p .68706 .35064 L .445 .88 .874 r
F P
0 g
s
.68085 .35176 m .69311 .34903 L .68706 .35064 L .445 .88 .874 r
F
.66064 .35539 m .68736 .3495 L .68085 .35176 L F
.71145 .34825 m .69842 .3486 L .67453 .35054 L p .426 .864 .915 r
F P
0 g
s
.67453 .35054 m .67163 .35077 L p .67834 .35035 L .426 .864 .915 r
F P
0 g
s
.67834 .35035 m .71145 .34825 L .67453 .35054 L .426 .864 .915 r
F
.68275 .34691 m .694 .34374 L .72008 .34828 L p .408 .841 .948 r
F P
0 g
s
.67163 .35077 m .68275 .34691 L .70649 .34802 L p .426 .864 .915 r
F P
0 g
s
.70649 .34802 m .71145 .34825 L p .70068 .34894 L .426 .864 .915 r
F P
0 g
s
.67163 .35077 m .70649 .34802 L .70068 .34894 L .426 .864 .915 r
F
.72466 .34907 m .71145 .34825 L .68275 .34691 L p .408 .841 .948 r
F P
0 g
s
.72008 .34828 m .72466 .34907 L p .71456 .34855 L .408 .841 .948 r
F P
0 g
s
.68275 .34691 m .72008 .34828 L .71456 .34855 L .408 .841 .948 r
F
.50489 .50497 m .51499 .4928 L .51783 .48941 L p .569 .833 .476 r
F P
0 g
s
.52511 .48046 m .51783 .48941 L .51499 .4928 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53738 .46561 L .53865 .46413 L closepath p .565 .828 .469 r
F P
0 g
s
.84435 .4232 m .85986 .43317 L .85906 .48583 L p .311 .448 .838 r
F P
0 g
s
.24029 .5335 m .25343 .54761 L .26777 .57604 L p 0 .295 .792 r
F P
0 g
s
.28025 .58513 m .26777 .57604 L .25343 .54761 L p 0 .32 .805 r
F P
0 g
s
.51499 .4928 m .50489 .50497 L .50051 .51007 L p .566 .831 .475 r
F P
0 g
s
.54961 .45099 m .53738 .46561 L .53526 .4681 L p .566 .832 .475 r
F P
0 g
s
.53526 .4681 m .54544 .45584 L .54961 .45099 L p .566 .832 .475 r
F P
0 g
s
.78381 .38439 m .76913 .37616 L .7516 .35374 L p .212 .569 .939 r
F P
0 g
s
.73804 .35094 m .7516 .35374 L .76913 .37616 L p .216 .603 .95 r
F P
0 g
s
.50051 .51007 m .51282 .49536 L .51499 .4928 L p .566 .831 .475 r
F P
0 g
s
.52511 .48046 m .51499 .4928 L .51282 .49536 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53526 .4681 L .53738 .46561 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .53245 .47146 L .53526 .4681 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .52911 .47544 L .53245 .47146 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .5255 .47978 L .52911 .47544 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .52184 .48419 L .5255 .47978 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51841 .48834 L .52184 .48419 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51543 .49196 L .51841 .48834 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51312 .49478 L .51543 .49196 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51164 .49662 L .51312 .49478 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51108 .49734 L .51164 .49662 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51149 .49691 L .51108 .49734 L closepath p .565 .828 .469 r
F P
0 g
s
.52511 .48046 m .51282 .49536 L .51149 .49691 L closepath p .565 .828 .469 r
F P
0 g
s
.49777 .51318 m .51149 .49691 L .51282 .49536 L p .565 .832 .476 r
F P
0 g
s
.51282 .49536 m .50051 .51007 L .49777 .51318 L p .565 .832 .476 r
F P
0 g
s
.54544 .45584 m .53526 .4681 L .53245 .47146 L p .569 .833 .476 r
F P
0 g
s
.25343 .54761 m .26675 .56087 L .28025 .58513 L p 0 .32 .805 r
F P
0 g
s
.29292 .59325 m .28025 .58513 L .26675 .56087 L p 0 .358 .826 r
F P
0 g
s
.50051 .51007 m .48817 .5244 L .48397 .52901 L p .562 .835 .487 r
F P
0 g
s
.54726 .4534 m .55475 .44442 L .56008 .4385 L p .581 .85 .506 r
F P
0 g
s
.55564 .44379 m .54544 .45584 L .54155 .46041 L p .574 .84 .489 r
F P
0 g
s
.54394 .45757 m .55564 .44379 L .54155 .46041 L .574 .84 .489 r
F
.53983 .46242 m .54726 .4534 L .55564 .44379 L p F P
0 g
s
.56588 .43208 m .55564 .44379 L .54896 .45145 L p .581 .85 .506 r
F P
0 g
s
.54896 .45145 m .54726 .4534 L p .55124 .44884 L .581 .85 .506 r
F P
0 g
s
.55124 .44884 m .56588 .43208 L .54896 .45145 L .581 .85 .506 r
F
.55475 .44442 m .5623 .43552 L .57045 .42686 L p .59 .862 .527 r
F P
0 g
s
.56008 .4385 m .56588 .43208 L p .55428 .44536 L .581 .85 .506 r
F P
0 g
s
.54726 .4534 m .56008 .4385 L .55428 .44536 L .581 .85 .506 r
F
.57615 .42081 m .56588 .43208 L .55642 .44257 L p .59 .862 .527 r
F P
0 g
s
.55642 .44257 m .55475 .44442 L p .55862 .44016 L .59 .862 .527 r
F P
0 g
s
.55862 .44016 m .57615 .42081 L .55642 .44257 L .59 .862 .527 r
F
.5623 .43552 m .5699 .42672 L .58087 .4157 L p .6 .876 .554 r
F P
0 g
s
.57045 .42686 m .57615 .42081 L p .56464 .43351 L .59 .862 .527 r
F P
0 g
s
.55475 .44442 m .57045 .42686 L .56464 .43351 L .59 .862 .527 r
F
.58646 .41009 m .57615 .42081 L .56393 .43378 L p .6 .876 .554 r
F P
0 g
s
.56393 .43378 m .5623 .43552 L p .56605 .43156 L .6 .876 .554 r
F P
0 g
s
.56605 .43156 m .58646 .41009 L .56393 .43378 L .6 .876 .554 r
F
.5699 .42672 m .57756 .41806 L .59136 .40512 L p .612 .893 .586 r
F P
0 g
s
.58087 .4157 m .58646 .41009 L p .57509 .42205 L .6 .876 .554 r
F P
0 g
s
.5623 .43552 m .58087 .4157 L .57509 .42205 L .6 .876 .554 r
F
.59683 .39998 m .58646 .41009 L .5715 .42511 L p .612 .893 .586 r
F P
0 g
s
.5715 .42511 m .5699 .42672 L p .57355 .4231 L .612 .893 .586 r
F P
0 g
s
.57355 .4231 m .59683 .39998 L .5715 .42511 L .612 .893 .586 r
F
.57756 .41806 m .58528 .40955 L .60192 .39519 L p .625 .91 .622 r
F P
0 g
s
.59136 .40512 m .59683 .39998 L p .58562 .41111 L .612 .893 .586 r
F P
0 g
s
.5699 .42672 m .59136 .40512 L .58562 .41111 L .612 .893 .586 r
F
.60726 .39058 m .59683 .39998 L .57912 .4166 L p .625 .91 .622 r
F P
0 g
s
.57912 .4166 m .57756 .41806 L p .5811 .41478 L .625 .91 .622 r
F P
0 g
s
.5811 .41478 m .60726 .39058 L .57912 .4166 L .625 .91 .622 r
F
.58528 .40955 m .59306 .40122 L .61256 .38598 L p .639 .928 .663 r
F P
0 g
s
.60192 .39519 m .60726 .39058 L p .59625 .40076 L .625 .91 .622 r
F P
0 g
s
.57756 .41806 m .60192 .39519 L .59625 .40076 L .625 .91 .622 r
F
.61775 .38192 m .60726 .39058 L .58679 .40824 L p .639 .928 .663 r
F P
0 g
s
.58679 .40824 m .58528 .40955 L p .58871 .40663 L .639 .928 .663 r
F P
0 g
s
.58871 .40663 m .61775 .38192 L .58679 .40824 L .639 .928 .663 r
F
.59306 .40122 m .60092 .39306 L .6233 .37755 L p .652 .946 .708 r
F P
0 g
s
.61256 .38598 m .61775 .38192 L p .60699 .39108 L .639 .928 .663 r
F P
0 g
s
.58528 .40955 m .61256 .38598 L .60699 .39108 L .639 .928 .663 r
F
.62833 .37406 m .61775 .38192 L .59453 .40007 L p .652 .946 .708 r
F P
0 g
s
.59453 .40007 m .59306 .40122 L p .59638 .39866 L .652 .946 .708 r
F P
0 g
s
.59638 .39866 m .62833 .37406 L .59453 .40007 L .652 .946 .708 r
F
.60092 .39306 m .60884 .3851 L .63414 .36993 L p .665 .962 .755 r
F P
0 g
s
.6233 .37755 m .62833 .37406 L p .61784 .38213 L .652 .946 .708 r
F P
0 g
s
.59306 .40122 m .6233 .37755 L .61784 .38213 L .652 .946 .708 r
F
.63899 .36701 m .62833 .37406 L .60232 .39209 L p .665 .962 .755 r
F P
0 g
s
.60232 .39209 m .60092 .39306 L p .6041 .39088 L .665 .962 .755 r
F P
0 g
s
.6041 .39088 m .63899 .36701 L .60232 .39209 L .665 .962 .755 r
F
.60884 .3851 m .61683 .37734 L .6451 .36313 L p .677 .973 .802 r
F P
0 g
s
.63414 .36993 m .63899 .36701 L p .62882 .37397 L .665 .962 .755 r
F P
0 g
s
.60092 .39306 m .63414 .36993 L .62882 .37397 L .665 .962 .755 r
F
.64976 .36079 m .63899 .36701 L .61018 .3843 L p .677 .973 .802 r
F P
0 g
s
.61018 .3843 m .60884 .3851 L p .61188 .3833 L .677 .973 .802 r
F P
0 g
s
.61188 .3833 m .64976 .36079 L .61018 .3843 L .677 .973 .802 r
F
.61683 .37734 m .62491 .36976 L .65619 .35718 L p .685 .98 .847 r
F P
0 g
s
.6451 .36313 m .64976 .36079 L p .63994 .36663 L .677 .973 .802 r
F P
0 g
s
.60884 .3851 m .6451 .36313 L .63994 .36663 L .677 .973 .802 r
F
.66064 .35539 m .64976 .36079 L .61683 .37734 L p .685 .98 .847 r
F P
0 g
s
.65619 .35718 m .66064 .35539 L p .65122 .36011 L .685 .98 .847 r
F P
0 g
s
.61683 .37734 m .65619 .35718 L .65122 .36011 L .685 .98 .847 r
F
.54155 .46041 m .53983 .46242 L p .54394 .45757 L .574 .84 .489 r
F P
0 g
s
.53245 .47146 m .53983 .46242 L .54544 .45584 L p .569 .833 .476 r
F P
0 g
s
.79868 .39343 m .78381 .38439 L .76534 .35731 L p .216 .545 .929 r
F P
0 g
s
.7516 .35374 m .76534 .35731 L .78381 .38439 L p .212 .569 .939 r
F P
0 g
s
.20175 .48936 m .18911 .47507 L .19318 .42214 L p .209 .336 .774 r
F P
0 g
s
.4969 .51407 m .51108 .49734 L .51149 .49691 L p .567 .833 .478 r
F P
0 g
s
.51149 .49691 m .49777 .51318 L .4969 .51407 L p .567 .833 .478 r
F P
0 g
s
.53983 .46242 m .53245 .47146 L .52911 .47544 L p .573 .836 .479 r
F P
0 g
s
.49797 .51264 m .51164 .49662 L .51108 .49734 L p .571 .836 .482 r
F P
0 g
s
.51108 .49734 m .4969 .51407 L .49797 .51264 L p .571 .836 .482 r
F P
0 g
s
.52911 .47544 m .53316 .4703 L .53983 .46242 L p .573 .836 .479 r
F P
0 g
s
.53316 .4703 m .52911 .47544 L .5255 .47978 L p .577 .839 .482 r
F P
0 g
s
.26675 .56087 m .28026 .57299 L .29292 .59325 L p 0 .358 .826 r
F P
0 g
s
.30577 .60016 m .29292 .59325 L .28026 .57299 L p 0 .412 .851 r
F P
0 g
s
.48258 .53032 m .4969 .51407 L .49777 .51318 L p .568 .841 .495 r
F P
0 g
s
.49777 .51318 m .48397 .52901 L .48258 .53032 L p .568 .841 .495 r
F P
0 g
s
.54726 .4534 m .53983 .46242 L .53316 .4703 L p .588 .849 .497 r
F P
0 g
s
.50093 .50897 m .51312 .49478 L .51164 .49662 L p .575 .839 .485 r
F P
0 g
s
.51164 .49662 m .49797 .51264 L .50093 .50897 L p .575 .839 .485 r
F P
0 g
s
.5255 .47978 m .52588 .47895 L .53316 .4703 L p .577 .839 .482 r
F P
0 g
s
.52588 .47895 m .5255 .47978 L .52184 .48419 L p .581 .841 .486 r
F P
0 g
s
.81374 .40308 m .79868 .39343 L .77926 .3615 L p .227 .528 .919 r
F P
0 g
s
.76534 .35731 m .77926 .3615 L .79868 .39343 L p .216 .545 .929 r
F P
0 g
s
.19318 .42214 m .20592 .44005 L .20175 .48936 L p .209 .336 .774 r
F P
0 g
s
.21448 .50406 m .20175 .48936 L .20592 .44005 L p .189 .323 .77 r
F P
0 g
s
.50557 .50332 m .51543 .49196 L .51312 .49478 L p .579 .842 .488 r
F P
0 g
s
.51312 .49478 m .50093 .50897 L .50557 .50332 L p .579 .842 .488 r
F P
0 g
s
.52184 .48419 m .51851 .48774 L .52588 .47895 L p .581 .841 .486 r
F P
0 g
s
.51851 .48774 m .52184 .48419 L .51841 .48834 L p .583 .843 .488 r
F P
0 g
s
.51158 .49607 m .51841 .48834 L .51543 .49196 L p .582 .843 .489 r
F P
0 g
s
.51543 .49196 m .50557 .50332 L .51158 .49607 L p .582 .843 .489 r
F P
0 g
s
.51841 .48834 m .51158 .49607 L .51851 .48774 L p .583 .843 .488 r
F P
0 g
s
.28026 .57299 m .29398 .58366 L .30577 .60016 L p 0 .412 .851 r
F P
0 g
s
.3188 .60563 m .30577 .60016 L .29398 .58366 L p .03 .48 .88 r
F P
0 g
s
.48397 .52901 m .4701 .5441 L .46812 .54574 L p .567 .85 .519 r
F P
0 g
s
.55475 .44442 m .54726 .4534 L .53725 .465 L p .609 .867 .523 r
F P
0 g
s
.53316 .4703 m .53725 .465 L .54726 .4534 L p .588 .849 .497 r
F P
0 g
s
.48412 .52817 m .49797 .51264 L .4969 .51407 L p .58 .85 .507 r
F P
0 g
s
.4969 .51407 m .48258 .53032 L .48412 .52817 L p .58 .85 .507 r
F P
0 g
s
.53725 .465 m .53316 .4703 L .52588 .47895 L p .602 .858 .508 r
F P
0 g
s
.20592 .44005 m .21871 .45842 L .21448 .50406 L p .189 .323 .77 r
F P
0 g
s
.22731 .51888 m .21448 .50406 L .21871 .45842 L p .177 .319 .77 r
F P
0 g
s
.82897 .41309 m .81374 .40308 L .79336 .36612 L p .245 .519 .912 r
F P
0 g
s
.77926 .3615 m .79336 .36612 L .81374 .40308 L p .227 .528 .919 r
F P
0 g
s
.4701 .5441 m .45617 .55819 L .45355 .56003 L p .564 .862 .55 r
F P
0 g
s
.29398 .58366 m .30789 .5926 L .3188 .60563 L p .03 .48 .88 r
F P
0 g
s
.33202 .60947 m .3188 .60563 L .30789 .5926 L p .089 .56 .906 r
F P
0 g
s
.5623 .43552 m .55475 .44442 L .54138 .45947 L p .636 .889 .555 r
F P
0 g
s
.53725 .465 m .54138 .45947 L .55475 .44442 L p .609 .867 .523 r
F P
0 g
s
.48854 .52267 m .50093 .50897 L .49797 .51264 L p .595 .86 .518 r
F P
0 g
s
.49797 .51264 m .48412 .52817 L .48854 .52267 L p .595 .86 .518 r
F P
0 g
s
.52588 .47895 m .52628 .47781 L .53725 .465 L p .602 .858 .508 r
F P
0 g
s
.52628 .47781 m .52588 .47895 L .51851 .48774 L p .614 .867 .519 r
F P
0 g
s
.45617 .55819 m .44221 .57102 L .43889 .57287 L p .556 .873 .589 r
F P
0 g
s
.30789 .5926 m .32199 .59959 L .33202 .60947 L p .089 .56 .906 r
F P
0 g
s
.34541 .61151 m .33202 .60947 L .32199 .59959 L p .161 .646 .923 r
F P
0 g
s
.73804 .35094 m .72466 .34907 L .694 .34374 L p .393 .813 .971 r
F P
0 g
s
.4701 .54284 m .48412 .52817 L .48258 .53032 L p .592 .869 .543 r
F P
0 g
s
.48258 .53032 m .46812 .54574 L .4701 .54284 L p .592 .869 .543 r
F P
0 g
s
.21871 .45842 m .2316 .47689 L .22731 .51888 L p .177 .319 .77 r
F P
0 g
s
.24029 .5335 m .22731 .51888 L .2316 .47689 L p .172 .322 .776 r
F P
0 g
s
.54138 .45947 m .53725 .465 L .52628 .47781 L p .638 .885 .545 r
F P
0 g
s
.49554 .5142 m .50557 .50332 L .50093 .50897 L p .608 .868 .527 r
F P
0 g
s
.50093 .50897 m .48854 .52267 L .49554 .5142 L p .608 .868 .527 r
F P
0 g
s
.51851 .48774 m .51513 .49091 L .52628 .47781 L p .614 .867 .519 r
F P
0 g
s
.51513 .49091 m .51851 .48774 L .51158 .49607 L p .619 .872 .527 r
F P
0 g
s
.84435 .4232 m .82897 .41309 L .80763 .371 L p .268 .517 .906 r
F P
0 g
s
.79336 .36612 m .80763 .371 L .82897 .41309 L p .245 .519 .912 r
F P
0 g
s
.44221 .57102 m .42822 .58238 L .42416 .58398 L p .543 .884 .636 r
F P
0 g
s
.5699 .42672 m .5623 .43552 L .54556 .45367 L p .667 .914 .594 r
F P
0 g
s
.54138 .45947 m .54556 .45367 L .5623 .43552 L p .636 .889 .555 r
F P
0 g
s
.50463 .50334 m .51158 .49607 L .50557 .50332 L p .617 .872 .53 r
F P
0 g
s
.50557 .50332 m .49554 .5142 L .50463 .50334 L p .617 .872 .53 r
F P
0 g
s
.51158 .49607 m .50463 .50334 L .51513 .49091 L p .619 .872 .527 r
F P
0 g
s
.32199 .59959 m .33627 .60442 L .34541 .61151 L p .161 .646 .923 r
F P
0 g
s
.35895 .61163 m .34541 .61151 L .33627 .60442 L p .241 .729 .923 r
F P
0 g
s
.42822 .58238 m .41424 .59207 L .4094 .59313 L p .523 .892 .69 r
F P
0 g
s
.33627 .60442 m .3507 .60695 L .35895 .61163 L p .241 .729 .923 r
F P
0 g
s
.37263 .60975 m .35895 .61163 L .3507 .60695 L p .32 .8 .903 r
F P
0 g
s
.7516 .35374 m .73804 .35094 L .70538 .3412 L p .381 .783 .985 r
F P
0 g
s
.694 .34374 m .70538 .3412 L .73804 .35094 L p .393 .813 .971 r
F P
0 g
s
.2316 .47689 m .24462 .49515 L .24029 .5335 L p .172 .322 .776 r
F P
0 g
s
.25343 .54761 m .24029 .5335 L .24462 .49515 L p .174 .335 .786 r
F P
0 g
s
.41424 .59207 m .4003 .59993 L .39464 .60012 L p .492 .892 .749 r
F P
0 g
s
.3507 .60695 m .36526 .60708 L .37263 .60975 L p .32 .8 .903 r
F P
0 g
s
.38642 .60584 m .37263 .60975 L .36526 .60708 L p .391 .85 .863 r
F P
0 g
s
.45592 .5563 m .4701 .54284 L .46812 .54574 L p .606 .893 .592 r
F P
0 g
s
.46812 .54574 m .45355 .56003 L .45592 .5563 L p .606 .893 .592 r
F P
0 g
s
.47597 .53552 m .48854 .52267 L .48412 .52817 L p .623 .889 .567 r
F P
0 g
s
.48412 .52817 m .4701 .54284 L .47597 .53552 L p .623 .889 .567 r
F P
0 g
s
.4003 .59993 m .38642 .60584 L .37992 .6048 L p .449 .88 .809 r
F P
0 g
s
.36526 .60708 m .37992 .6048 L .38642 .60584 L p .391 .85 .863 r
F P
0 g
s
.57756 .41806 m .5699 .42672 L .54978 .44755 L p .701 .939 .637 r
F P
0 g
s
.54556 .45367 m .54978 .44755 L .5699 .42672 L p .667 .914 .594 r
F P
0 g
s
.52628 .47781 m .52668 .47622 L .54138 .45947 L p .638 .885 .545 r
F P
0 g
s
.52668 .47622 m .52628 .47781 L .51513 .49091 L p .66 .901 .567 r
F P
0 g
s
.54556 .45367 m .54138 .45947 L .52668 .47622 L p .682 .917 .591 r
F P
0 g
s
.85986 .43317 m .84435 .4232 L .82205 .37594 L p .295 .521 .902 r
F P
0 g
s
.80763 .371 m .82205 .37594 L .84435 .4232 L p .268 .517 .906 r
F P
0 g
s
.24462 .49515 m .25778 .51282 L .25343 .54761 L p .174 .335 .786 r
F P
0 g
s
.26675 .56087 m .25343 .54761 L .25778 .51282 L p .185 .358 .803 r
F P
0 g
s
.48535 .52425 m .49554 .5142 L .48854 .52267 L p .65 .905 .584 r
F P
0 g
s
.48854 .52267 m .47597 .53552 L .48535 .52425 L p .65 .905 .584 r
F P
0 g
s
.76534 .35731 m .7516 .35374 L .71691 .3392 L p .375 .753 .99 r
F P
0 g
s
.70538 .3412 m .71691 .3392 L .7516 .35374 L p .381 .783 .985 r
F P
0 g
s
.51513 .49091 m .5117 .49344 L .52668 .47622 L p .66 .901 .567 r
F P
0 g
s
.5117 .49344 m .51513 .49091 L .50463 .50334 L p .671 .911 .583 r
F P
0 g
s
.58528 .40955 m .57756 .41806 L .55404 .44105 L p .737 .963 .682 r
F P
0 g
s
.54978 .44755 m .55404 .44105 L .57756 .41806 L p .701 .939 .637 r
F P
0 g
s
.44161 .5682 m .45592 .5563 L .45355 .56003 L p .62 .919 .654 r
F P
0 g
s
.45355 .56003 m .43889 .57287 L .44161 .5682 L p .62 .919 .654 r
F P
0 g
s
.49757 .50987 m .50463 .50334 L .49554 .5142 L p .668 .912 .59 r
F P
0 g
s
.49554 .5142 m .48535 .52425 L .49757 .50987 L p .668 .912 .59 r
F P
0 g
s
.50463 .50334 m .49757 .50987 L .5117 .49344 L p .671 .911 .583 r
F P
0 g
s
.82205 .37594 m .8366 .38074 L .85986 .43317 L p .295 .521 .902 r
F P
0 g
s
.54978 .44755 m .54556 .45367 L .52708 .47404 L p .731 .949 .642 r
F P
0 g
s
.52668 .47622 m .52708 .47404 L .54556 .45367 L p .682 .917 .591 r
F P
0 g
s
.46323 .54714 m .47597 .53552 L .4701 .54284 L p .657 .924 .632 r
F P
0 g
s
.4701 .54284 m .45592 .5563 L .46323 .54714 L p .657 .924 .632 r
F P
0 g
s
.67163 .35077 m .66064 .35539 L .62491 .36976 L p .69 .979 .888 r
F P
0 g
s
.25778 .51282 m .2711 .52957 L .26675 .56087 L p .185 .358 .803 r
F P
0 g
s
.28026 .57299 m .26675 .56087 L .2711 .52957 L p .204 .39 .826 r
F P
0 g
s
.52708 .47404 m .52668 .47622 L .5117 .49344 L p .717 .939 .625 r
F P
0 g
s
.59306 .40122 m .58528 .40955 L .55834 .43416 L p .77 .982 .728 r
F P
0 g
s
.55404 .44105 m .55834 .43416 L .58528 .40955 L p .737 .963 .682 r
F P
0 g
s
.42719 .57825 m .44161 .5682 L .43889 .57287 L p .632 .944 .726 r
F P
0 g
s
.43889 .57287 m .42416 .58398 L .42719 .57825 L p .632 .944 .726 r
F P
0 g
s
.77926 .3615 m .76534 .35731 L .72859 .33764 L p .373 .724 .989 r
F P
0 g
s
.71691 .3392 m .72859 .33764 L .76534 .35731 L p .375 .753 .99 r
F P
0 g
s
.2711 .52957 m .28461 .54503 L .28026 .57299 L p .204 .39 .826 r
F P
0 g
s
.29398 .58366 m .28026 .57299 L .28461 .54503 L p .232 .435 .854 r
F P
0 g
s
.68275 .34691 m .67163 .35077 L .63306 .36237 L p .69 .971 .923 r
F P
0 g
s
.62491 .36976 m .63306 .36237 L .67163 .35077 L p .69 .979 .888 r
F P
0 g
s
.47501 .53315 m .48535 .52425 L .47597 .53552 L p .701 .946 .657 r
F P
0 g
s
.47597 .53552 m .46323 .54714 L .47501 .53315 L p .701 .946 .657 r
F P
0 g
s
.55404 .44105 m .54978 .44755 L .52749 .47114 L p .781 .975 .695 r
F P
0 g
s
.52708 .47404 m .52749 .47114 L .54978 .44755 L p .731 .949 .642 r
F P
0 g
s
.5117 .49344 m .50821 .49513 L .52708 .47404 L p .717 .939 .625 r
F P
0 g
s
.50821 .49513 m .5117 .49344 L .49757 .50987 L p .733 .952 .651 r
F P
0 g
s
.60092 .39306 m .59306 .40122 L .56269 .42682 L p .799 .995 .771 r
F P
0 g
s
.55834 .43416 m .56269 .42682 L .59306 .40122 L p .77 .982 .728 r
F P
0 g
s
.4127 .58616 m .42719 .57825 L .42416 .58398 L p .637 .961 .804 r
F P
0 g
s
.42416 .58398 m .4094 .59313 L .4127 .58616 L p .637 .961 .804 r
F P
0 g
s
.20592 .44005 m .19318 .42214 L .22154 .37026 L p .365 .386 .749 r
F P
0 g
s
.45034 .55719 m .46323 .54714 L .45592 .5563 L p .695 .959 .709 r
F P
0 g
s
.45592 .5563 m .44161 .5682 L .45034 .55719 L p .695 .959 .709 r
F P
0 g
s
.28461 .54503 m .29829 .55889 L .29398 .58366 L p .232 .435 .854 r
F P
0 g
s
.30789 .5926 m .29398 .58366 L .29829 .55889 L p .27 .491 .887 r
F P
0 g
s
.79336 .36612 m .77926 .3615 L .7404 .33643 L p .377 .7 .984 r
F P
0 g
s
.72859 .33764 m .7404 .33643 L .77926 .3615 L p .373 .724 .989 r
F P
0 g
s
.4904 .51536 m .49757 .50987 L .48535 .52425 L p .728 .955 .663 r
F P
0 g
s
.48535 .52425 m .47501 .53315 L .4904 .51536 L p .728 .955 .663 r
F P
0 g
s
.49757 .50987 m .4904 .51536 L .50821 .49513 L p .733 .952 .651 r
F P
0 g
s
.52749 .47114 m .52708 .47404 L .50821 .49513 L p .776 .973 .687 r
F P
0 g
s
.39817 .59172 m .4127 .58616 L .4094 .59313 L p .63 .962 .881 r
F P
0 g
s
.4094 .59313 m .39464 .60012 L .39817 .59172 L p .63 .962 .881 r
F P
0 g
s
.694 .34374 m .68275 .34691 L .64129 .35515 L p .686 .956 .95 r
F P
0 g
s
.63306 .36237 m .64129 .35515 L .68275 .34691 L p .69 .971 .923 r
F P
0 g
s
.22154 .37026 m .2335 .39083 L .20592 .44005 L p .365 .386 .749 r
F P
0 g
s
.21871 .45842 m .20592 .44005 L .2335 .39083 L p .36 .38 .746 r
F P
0 g
s
.60884 .3851 m .60092 .39306 L .56707 .41903 L p .822 1 .809 r
F P
0 g
s
.56269 .42682 m .56707 .41903 L .60092 .39306 L p .799 .995 .771 r
F P
0 g
s
.29829 .55889 m .31216 .57085 L .30789 .5926 L p .27 .491 .887 r
F P
0 g
s
.32199 .59959 m .30789 .5926 L .31216 .57085 L p .317 .561 .924 r
F P
0 g
s
.55834 .43416 m .55404 .44105 L .5279 .46741 L p .825 .993 .744 r
F P
0 g
s
.52749 .47114 m .5279 .46741 L .55404 .44105 L p .781 .975 .695 r
F P
0 g
s
.38364 .59476 m .39817 .59172 L .39464 .60012 L p .605 .94 .946 r
F P
0 g
s
.39464 .60012 m .37992 .6048 L .38364 .59476 L p .605 .94 .946 r
F P
0 g
s
.31216 .57085 m .3262 .58064 L .32199 .59959 L p .317 .561 .924 r
F P
0 g
s
.33627 .60442 m .32199 .59959 L .3262 .58064 L p .375 .642 .96 r
F P
0 g
s
.43732 .56537 m .45034 .55719 L .44161 .5682 L p .728 .986 .792 r
F P
0 g
s
.44161 .5682 m .42719 .57825 L .43732 .56537 L p .728 .986 .792 r
F P
0 g
s
.46452 .54056 m .47501 .53315 L .46323 .54714 L p .754 .981 .738 r
F P
0 g
s
.46323 .54714 m .45034 .55719 L .46452 .54056 L p .754 .981 .738 r
F P
0 g
s
.36915 .59517 m .38364 .59476 L .37992 .6048 L p .562 .89 .987 r
F P
0 g
s
.37992 .6048 m .36526 .60708 L .36915 .59517 L p .562 .89 .987 r
F P
0 g
s
.80763 .371 m .79336 .36612 L .75236 .33546 L p .385 .68 .976 r
F P
0 g
s
.7404 .33643 m .75236 .33546 L .79336 .36612 L p .377 .7 .984 r
F P
0 g
s
.2335 .39083 m .24549 .41182 L .21871 .45842 L p .36 .38 .746 r
F P
0 g
s
.2316 .47689 m .21871 .45842 L .24549 .41182 L p .359 .38 .746 r
F P
0 g
s
.3262 .58064 m .3404 .58805 L .33627 .60442 L p .375 .642 .96 r
F P
0 g
s
.3507 .60695 m .33627 .60442 L .3404 .58805 L p .438 .729 .988 r
F P
0 g
s
.70538 .3412 m .694 .34374 L .6496 .34808 L p .677 .934 .968 r
F P
0 g
s
.64129 .35515 m .6496 .34808 L .694 .34374 L p .686 .956 .95 r
F P
0 g
s
.35472 .59293 m .36915 .59517 L .36526 .60708 L p .504 .816 1 r
F P
0 g
s
.36526 .60708 m .3507 .60695 L .35472 .59293 L p .504 .816 1 r
F P
0 g
s
.50821 .49513 m .50468 .49577 L .52749 .47114 L p .776 .973 .687 r
F P
0 g
s
.50468 .49577 m .50821 .49513 L .4904 .51536 L p .795 .985 .721 r
F P
0 g
s
.3404 .58805 m .35472 .59293 L .3507 .60695 L p .438 .729 .988 r
F P
0 g
s
.61683 .37734 m .60884 .3851 L .5715 .41077 L p .838 .996 .84 r
F P
0 g
s
.56707 .41903 m .5715 .41077 L .60884 .3851 L p .822 1 .809 r
F P
0 g
s
.5279 .46741 m .52749 .47114 L .50468 .49577 L p .83 .993 .745 r
F P
0 g
s
.48312 .51954 m .4904 .51536 L .47501 .53315 L p .788 .988 .74 r
F P
0 g
s
.47501 .53315 m .46452 .54056 L .48312 .51954 L p .788 .988 .74 r
F P
0 g
s
.56269 .42682 m .55834 .43416 L .52832 .46273 L p .858 .997 .785 r
F P
0 g
s
.5279 .46741 m .52832 .46273 L .55834 .43416 L p .825 .993 .744 r
F P
0 g
s
.4904 .51536 m .48312 .51954 L .50468 .49577 L p .795 .985 .721 r
F P
0 g
s
.24549 .41182 m .25755 .4329 L .2316 .47689 L p .359 .38 .746 r
F P
0 g
s
.24462 .49515 m .2316 .47689 L .25755 .4329 L p .363 .386 .75 r
F P
0 g
s
.4242 .57139 m .43732 .56537 L .42719 .57825 L p .748 .993 .869 r
F P
0 g
s
.42719 .57825 m .4127 .58616 L .4242 .57139 L p .748 .993 .869 r
F P
0 g
s
.82205 .37594 m .80763 .371 L .76445 .3346 L p .398 .664 .967 r
F P
0 g
s
.75236 .33546 m .76445 .3346 L .80763 .371 L p .385 .68 .976 r
F P
0 g
s
.62491 .36976 m .61683 .37734 L .57596 .40202 L p .845 .984 .864 r
F P
0 g
s
.5715 .41077 m .57596 .40202 L .61683 .37734 L p .838 .996 .84 r
F P
0 g
s
.71691 .3392 m .70538 .3412 L .658 .34114 L p .667 .908 .978 r
F P
0 g
s
.6496 .34808 m .658 .34114 L .70538 .3412 L p .677 .934 .968 r
F P
0 g
s
.45392 .54619 m .46452 .54056 L .45034 .55719 L p .797 .999 .815 r
F P
0 g
s
.45034 .55719 m .43732 .56537 L .45392 .54619 L p .797 .999 .815 r
F P
0 g
s
.25755 .4329 m .26969 .45372 L .24462 .49515 L p .363 .386 .75 r
F P
0 g
s
.25778 .51282 m .24462 .49515 L .26969 .45372 L p .372 .397 .758 r
F P
0 g
s
.50468 .49577 m .5011 .49516 L .5279 .46741 L p .83 .993 .745 r
F P
0 g
s
.5011 .49516 m .50468 .49577 L .48312 .51954 L p .846 .998 .783 r
F P
0 g
s
.56707 .41903 m .56269 .42682 L .52874 .45703 L p .88 .988 .814 r
F P
0 g
s
.52832 .46273 m .52874 .45703 L .56269 .42682 L p .858 .997 .785 r
F P
0 g
s
.52832 .46273 m .5279 .46741 L .5011 .49516 L p .869 .995 .791 r
F P
0 g
s
.41101 .57502 m .4242 .57139 L .4127 .58616 L p .748 .971 .928 r
F P
0 g
s
.4127 .58616 m .39817 .59172 L .41101 .57502 L p .748 .971 .928 r
F P
0 g
s
.63306 .36237 m .62491 .36976 L .58046 .39279 L p .846 .965 .88 r
F P
0 g
s
.57596 .40202 m .58046 .39279 L .62491 .36976 L p .845 .984 .864 r
F P
0 g
s
.72859 .33764 m .71691 .3392 L .66649 .3343 L p .654 .878 .981 r
F P
0 g
s
.658 .34114 m .66649 .3343 L .71691 .3392 L p .667 .908 .978 r
F P
0 g
s
.26969 .45372 m .28194 .47393 L .25778 .51282 L p .372 .397 .758 r
F P
0 g
s
.2711 .52957 m .25778 .51282 L .28194 .47393 L p .385 .415 .769 r
F P
0 g
s
.8366 .38074 m .82205 .37594 L .77667 .33373 L p .414 .653 .957 r
F P
0 g
s
.76445 .3346 m .77667 .33373 L .82205 .37594 L p .398 .664 .967 r
F P
0 g
s
.47576 .52215 m .48312 .51954 L .46452 .54056 L p .835 .999 .808 r
F P
0 g
s
.46452 .54056 m .45392 .54619 L .47576 .52215 L p .835 .999 .808 r
F P
0 g
s
.48312 .51954 m .47576 .52215 L .5011 .49516 L p .846 .998 .783 r
F P
0 g
s
.39779 .57609 m .41101 .57502 L .39817 .59172 L p .726 .921 .959 r
F P
0 g
s
.39817 .59172 m .38364 .59476 L .39779 .57609 L p .726 .921 .959 r
F P
0 g
s
.44321 .54978 m .45392 .54619 L .43732 .56537 L p .819 .989 .875 r
F P
0 g
s
.43732 .56537 m .4242 .57139 L .44321 .54978 L p .819 .989 .875 r
F P
0 g
s
.28194 .47393 m .29432 .49315 L .2711 .52957 L p .385 .415 .769 r
F P
0 g
s
.28461 .54503 m .2711 .52957 L .29432 .49315 L p .404 .44 .785 r
F P
0 g
s
.5715 .41077 m .56707 .41903 L .52917 .45025 L p .889 .967 .833 r
F P
0 g
s
.52874 .45703 m .52917 .45025 L .56707 .41903 L p .88 .988 .814 r
F P
0 g
s
.64129 .35515 m .63306 .36237 L .58499 .3831 L p .84 .942 .89 r
F P
0 g
s
.58046 .39279 m .58499 .3831 L .63306 .36237 L p .846 .965 .88 r
F P
0 g
s
.52874 .45703 m .52832 .46273 L .49748 .49315 L p .89 .978 .821 r
F P
0 g
s
.5011 .49516 m .49748 .49315 L .52832 .46273 L p .869 .995 .791 r
F P
0 g
s
.7404 .33643 m .72859 .33764 L .67506 .32753 L p .641 .849 .979 r
F P
0 g
s
.66649 .3343 m .67506 .32753 L .72859 .33764 L p .654 .878 .981 r
F P
0 g
s
.49748 .49315 m .5011 .49516 L .47576 .52215 L p .876 .986 .826 r
F P
0 g
s
.38457 .57449 m .39779 .57609 L .38364 .59476 L p .685 .851 .962 r
F P
0 g
s
.38364 .59476 m .36915 .59517 L .38457 .57449 L p .685 .851 .962 r
F P
0 g
s
.29432 .49315 m .30684 .51105 L .28461 .54503 L p .404 .44 .785 r
F P
0 g
s
.29829 .55889 m .28461 .54503 L .30684 .51105 L p .427 .473 .804 r
F P
0 g
s
.77667 .33373 m .78901 .33274 L .8366 .38074 L p .414 .653 .957 r
F P
0 g
s
.30684 .51105 m .31949 .52728 L .29829 .55889 L p .427 .473 .804 r
F P
0 g
s
.31216 .57085 m .29829 .55889 L .31949 .52728 L p .457 .514 .828 r
F P
0 g
s
.46831 .52298 m .47576 .52215 L .45392 .54619 L p .858 .982 .854 r
F P
0 g
s
.45392 .54619 m .44321 .54978 L .46831 .52298 L p .858 .982 .854 r
F P
0 g
s
.37138 .57018 m .38457 .57449 L .36915 .59517 L p .635 .772 .946 r
F P
0 g
s
.36915 .59517 m .35472 .59293 L .37138 .57018 L p .635 .772 .946 r
F P
0 g
s
.57596 .40202 m .5715 .41077 L .5296 .44233 L p .889 .939 .842 r
F P
0 g
s
.52917 .45025 m .5296 .44233 L .5715 .41077 L p .889 .967 .833 r
F P
0 g
s
.6496 .34808 m .64129 .35515 L .58956 .37295 L p .83 .915 .895 r
F P
0 g
s
.58499 .3831 m .58956 .37295 L .64129 .35515 L p .84 .942 .89 r
F P
0 g
s
.43242 .55111 m .44321 .54978 L .4242 .57139 L p .817 .949 .907 r
F P
0 g
s
.4242 .57139 m .41101 .57502 L .43242 .55111 L p .817 .949 .907 r
F P
0 g
s
.47576 .52215 m .46831 .52298 L .49748 .49315 L p .876 .986 .826 r
F P
0 g
s
.31949 .52728 m .33229 .54155 L .31216 .57085 L p .457 .514 .828 r
F P
0 g
s
.3262 .58064 m .31216 .57085 L .33229 .54155 L p .493 .564 .856 r
F P
0 g
s
.35826 .56318 m .37138 .57018 L .35472 .59293 L p .584 .694 .918 r
F P
0 g
s
.35472 .59293 m .3404 .58805 L .35826 .56318 L p .584 .694 .918 r
F P
0 g
s
.33229 .54155 m .34522 .55359 L .3262 .58064 L p .493 .564 .856 r
F P
0 g
s
.3404 .58805 m .3262 .58064 L .34522 .55359 L p .535 .624 .887 r
F P
0 g
s
.34522 .55359 m .35826 .56318 L .3404 .58805 L p .535 .624 .887 r
F P
0 g
s
.75236 .33546 m .7404 .33643 L .68373 .32081 L p .629 .819 .974 r
F P
0 g
s
.67506 .32753 m .68373 .32081 L .7404 .33643 L p .641 .849 .979 r
F P
0 g
s
.52917 .45025 m .52874 .45703 L .49383 .48958 L p .894 .946 .835 r
F P
0 g
s
.49748 .49315 m .49383 .48958 L .52874 .45703 L p .89 .978 .821 r
F P
0 g
s
.2335 .39083 m .22154 .37026 L .27399 .32374 L p .484 .44 .733 r
F P
0 g
s
.49383 .48958 m .49748 .49315 L .46831 .52298 L p .883 .952 .847 r
F P
0 g
s
.658 .34114 m .6496 .34808 L .59416 .36238 L p .816 .888 .895 r
F P
0 g
s
.58956 .37295 m .59416 .36238 L .6496 .34808 L p .83 .915 .895 r
F P
0 g
s
.58046 .39279 m .57596 .40202 L .53003 .43326 L p .88 .907 .843 r
F P
0 g
s
.5296 .44233 m .53003 .43326 L .57596 .40202 L p .889 .939 .842 r
F P
0 g
s
.42159 .55003 m .43242 .55111 L .41101 .57502 L p .792 .888 .914 r
F P
0 g
s
.41101 .57502 m .39779 .57609 L .42159 .55003 L p .792 .888 .914 r
F P
0 g
s
.27399 .32374 m .28421 .34571 L .2335 .39083 L p .484 .44 .733 r
F P
0 g
s
.24549 .41182 m .2335 .39083 L .28421 .34571 L p .485 .438 .729 r
F P
0 g
s
.4608 .52183 m .46831 .52298 L .44321 .54978 L p .857 .94 .875 r
F P
0 g
s
.44321 .54978 m .43242 .55111 L .4608 .52183 L p .857 .94 .875 r
F P
0 g
s
.76445 .3346 m .75236 .33546 L .69248 .31409 L p .618 .792 .966 r
F P
0 g
s
.68373 .32081 m .69248 .31409 L .75236 .33546 L p .629 .819 .974 r
F P
0 g
s
.46831 .52298 m .4608 .52183 L .49383 .48958 L p .883 .952 .847 r
F P
0 g
s
.28421 .34571 m .29441 .36803 L .24549 .41182 L p .485 .438 .729 r
F P
0 g
s
.25755 .4329 m .24549 .41182 L .29441 .36803 L p .489 .439 .728 r
F P
0 g
s
.5296 .44233 m .52917 .45025 L .49014 .48436 L p .886 .906 .836 r
F P
0 g
s
.49383 .48958 m .49014 .48436 L .52917 .45025 L p .894 .946 .835 r
F P
0 g
s
.66649 .3343 m .658 .34114 L .5988 .35141 L p .801 .861 .894 r
F P
0 g
s
.59416 .36238 m .5988 .35141 L .658 .34114 L p .816 .888 .895 r
F P
0 g
s
.58499 .3831 m .58046 .39279 L .53046 .42305 L p .867 .874 .84 r
F P
0 g
s
.53003 .43326 m .53046 .42305 L .58046 .39279 L p .88 .907 .843 r
F P
0 g
s
.41072 .54641 m .42159 .55003 L .39779 .57609 L p .756 .818 .901 r
F P
0 g
s
.39779 .57609 m .38457 .57449 L .41072 .54641 L p .756 .818 .901 r
F P
0 g
s
.29441 .36803 m .30465 .39038 L .25755 .4329 L p .489 .439 .728 r
F P
0 g
s
.26969 .45372 m .25755 .4329 L .30465 .39038 L p .496 .446 .73 r
F P
0 g
s
.49014 .48436 m .49383 .48958 L .4608 .52183 L p .873 .904 .85 r
F P
0 g
s
.45324 .51858 m .4608 .52183 L .43242 .55111 L p .838 .882 .874 r
F P
0 g
s
.43242 .55111 m .42159 .55003 L .45324 .51858 L p .838 .882 .874 r
F P
0 g
s
.77667 .33373 m .76445 .3346 L .70132 .30735 L p .608 .768 .956 r
F P
0 g
s
.69248 .31409 m .70132 .30735 L .76445 .3346 L p .618 .792 .966 r
F P
0 g
s
.30465 .39038 m .31493 .41245 L .26969 .45372 L p .496 .446 .73 r
F P
0 g
s
.28194 .47393 m .26969 .45372 L .31493 .41245 L p .506 .456 .735 r
F P
0 g
s
.39985 .54023 m .41072 .54641 L .38457 .57449 L p .714 .749 .879 r
F P
0 g
s
.38457 .57449 m .37138 .57018 L .39985 .54023 L p .714 .749 .879 r
F P
0 g
s
.53003 .43326 m .5296 .44233 L .48643 .47741 L p .87 .862 .829 r
F P
0 g
s
.49014 .48436 m .48643 .47741 L .5296 .44233 L p .886 .906 .836 r
F P
0 g
s
.4608 .52183 m .45324 .51858 L .49014 .48436 L p .873 .904 .85 r
F P
0 g
s
.67506 .32753 m .66649 .3343 L .60347 .3401 L p .784 .834 .89 r
F P
0 g
s
.5988 .35141 m .60347 .3401 L .66649 .3343 L p .801 .861 .894 r
F P
0 g
s
.58956 .37295 m .58499 .3831 L .5309 .41173 L p .852 .841 .834 r
F P
0 g
s
.53046 .42305 m .5309 .41173 L .58499 .3831 L p .867 .874 .84 r
F P
0 g
s
.31493 .41245 m .32527 .43389 L .28194 .47393 L p .506 .456 .735 r
F P
0 g
s
.29432 .49315 m .28194 .47393 L .32527 .43389 L p .518 .471 .743 r
F P
0 g
s
.389 .53149 m .39985 .54023 L .37138 .57018 L p .674 .686 .853 r
F P
0 g
s
.37138 .57018 m .35826 .56318 L .389 .53149 L p .674 .686 .853 r
F P
0 g
s
.48643 .47741 m .49014 .48436 L .45324 .51858 L p .852 .851 .841 r
F P
0 g
s
.32527 .43389 m .33569 .45435 L .29432 .49315 L p .518 .471 .743 r
F P
0 g
s
.30684 .51105 m .29432 .49315 L .33569 .45435 L p .534 .49 .753 r
F P
0 g
s
.44564 .51312 m .45324 .51858 L .42159 .55003 L p .808 .82 .86 r
F P
0 g
s
.42159 .55003 m .41072 .54641 L .44564 .51312 L p .808 .82 .86 r
F P
0 g
s
.3782 .52028 m .389 .53149 L .35826 .56318 L p .637 .631 .828 r
F P
0 g
s
.35826 .56318 m .34522 .55359 L .3782 .52028 L p .637 .631 .828 r
F P
0 g
s
.78901 .33274 m .77667 .33373 L .71025 .30054 L p .601 .746 .946 r
F P
0 g
s
.70132 .30735 m .71025 .30054 L .77667 .33373 L p .608 .768 .956 r
F P
0 g
s
.33569 .45435 m .34619 .47352 L .30684 .51105 L p .534 .49 .753 r
F P
0 g
s
.31949 .52728 m .30684 .51105 L .34619 .47352 L p .554 .516 .767 r
F P
0 g
s
.53046 .42305 m .53003 .43326 L .48271 .46871 L p .851 .821 .819 r
F P
0 g
s
.48643 .47741 m .48271 .46871 L .53003 .43326 L p .87 .862 .829 r
F P
0 g
s
.59416 .36238 m .58956 .37295 L .53134 .39935 L p .835 .811 .827 r
F P
0 g
s
.5309 .41173 m .53134 .39935 L .58956 .37295 L p .852 .841 .834 r
F P
0 g
s
.36745 .50675 m .3782 .52028 L .34522 .55359 L p .605 .585 .804 r
F P
0 g
s
.34522 .55359 m .33229 .54155 L .36745 .50675 L p .605 .585 .804 r
F P
0 g
s
.68373 .32081 m .67506 .32753 L .60817 .32847 L p .767 .81 .886 r
F P
0 g
s
.60347 .3401 m .60817 .32847 L .67506 .32753 L p .784 .834 .89 r
F P
0 g
s
.34619 .47352 m .35678 .49108 L .31949 .52728 L p .554 .516 .767 r
F P
0 g
s
.33229 .54155 m .31949 .52728 L .35678 .49108 L p .577 .547 .784 r
F P
0 g
s
.35678 .49108 m .36745 .50675 L .33229 .54155 L p .577 .547 .784 r
F P
0 g
s
.45324 .51858 m .44564 .51312 L .48643 .47741 L p .852 .851 .841 r
F P
0 g
s
.43802 .50542 m .44564 .51312 L .41072 .54641 L p .774 .76 .84 r
F P
0 g
s
.41072 .54641 m .39985 .54023 L .43802 .50542 L p .774 .76 .84 r
F P
0 g
s
.48271 .46871 m .48643 .47741 L .44564 .51312 L p .827 .8 .826 r
F P
0 g
s
.5988 .35141 m .59416 .36238 L .53178 .38598 L p .818 .784 .82 r
F P
0 g
s
.53134 .39935 m .53178 .38598 L .59416 .36238 L p .835 .811 .827 r
F P
0 g
s
.71025 .30054 m .71927 .29362 L .78901 .33274 L p .601 .746 .946 r
F P
0 g
s
.5309 .41173 m .53046 .42305 L .47896 .45827 L p .83 .782 .807 r
F P
0 g
s
.48271 .46871 m .47896 .45827 L .53046 .42305 L p .851 .821 .819 r
F P
0 g
s
.69248 .31409 m .68373 .32081 L .61291 .31658 L p .751 .787 .882 r
F P
0 g
s
.60817 .32847 m .61291 .31658 L .68373 .32081 L p .767 .81 .886 r
F P
0 g
s
.44564 .51312 m .43802 .50542 L .48271 .46871 L p .827 .8 .826 r
F P
0 g
s
.43039 .49549 m .43802 .50542 L .39985 .54023 L p .742 .707 .819 r
F P
0 g
s
.39985 .54023 m .389 .53149 L .43039 .49549 L p .742 .707 .819 r
F P
0 g
s
.47896 .45827 m .48271 .46871 L .43802 .50542 L p .8 .753 .809 r
F P
0 g
s
.60347 .3401 m .5988 .35141 L .53223 .37171 L p .802 .759 .814 r
F P
0 g
s
.53178 .38598 m .53223 .37171 L .5988 .35141 L p .818 .784 .82 r
F P
0 g
s
.53134 .39935 m .5309 .41173 L .47521 .44613 L p .81 .748 .795 r
F P
0 g
s
.47896 .45827 m .47521 .44613 L .5309 .41173 L p .83 .782 .807 r
F P
0 g
s
.28421 .34571 m .27399 .32374 L .34782 .287 L p .572 .493 .727 r
F P
0 g
s
.42277 .4834 m .43039 .49549 L .389 .53149 L p .712 .661 .798 r
F P
0 g
s
.389 .53149 m .3782 .52028 L .42277 .4834 L p .712 .661 .798 r
F P
0 g
s
.70132 .30735 m .69248 .31409 L .61769 .30448 L p .735 .767 .878 r
F P
0 g
s
.61291 .31658 m .61769 .30448 L .69248 .31409 L p .751 .787 .882 r
F P
0 g
s
.34782 .287 m .35527 .30889 L .28421 .34571 L p .572 .493 .727 r
F P
0 g
s
.29441 .36803 m .28421 .34571 L .35527 .30889 L p .576 .493 .724 r
F P
0 g
s
.43802 .50542 m .43039 .49549 L .47896 .45827 L p .8 .753 .809 r
F P
0 g
s
.35527 .30889 m .3627 .33102 L .29441 .36803 L p .576 .493 .724 r
F P
0 g
s
.30465 .39038 m .29441 .36803 L .3627 .33102 L p .582 .496 .722 r
F P
0 g
s
.41517 .46927 m .42277 .4834 L .3782 .52028 L p .686 .623 .78 r
F P
0 g
s
.3782 .52028 m .36745 .50675 L .41517 .46927 L p .686 .623 .78 r
F P
0 g
s
.3627 .33102 m .37013 .35314 L .30465 .39038 L p .582 .496 .722 r
F P
0 g
s
.31493 .41245 m .30465 .39038 L .37013 .35314 L p .59 .502 .723 r
F P
0 g
s
.47521 .44613 m .47896 .45827 L .43039 .49549 L p .775 .711 .792 r
F P
0 g
s
.60817 .32847 m .60347 .3401 L .53267 .35665 L p .786 .738 .808 r
F P
0 g
s
.53223 .37171 m .53267 .35665 L .60347 .3401 L p .802 .759 .814 r
F P
0 g
s
.53178 .38598 m .53134 .39935 L .47146 .43238 L p .791 .718 .784 r
F P
0 g
s
.47521 .44613 m .47146 .43238 L .53134 .39935 L p .81 .748 .795 r
F P
0 g
s
.37013 .35314 m .37757 .37494 L .31493 .41245 L p .59 .502 .723 r
F P
0 g
s
.32527 .43389 m .31493 .41245 L .37757 .37494 L p .6 .512 .727 r
F P
0 g
s
.40759 .45326 m .41517 .46927 L .36745 .50675 L p .663 .591 .764 r
F P
0 g
s
.36745 .50675 m .35678 .49108 L .40759 .45326 L p .663 .591 .764 r
F P
0 g
s
.37757 .37494 m .38503 .39614 L .32527 .43389 L p .6 .512 .727 r
F P
0 g
s
.33569 .45435 m .32527 .43389 L .38503 .39614 L p .612 .525 .732 r
F P
0 g
s
.43039 .49549 m .42277 .4834 L .47521 .44613 L p .775 .711 .792 r
F P
0 g
s
.40003 .43557 m .40759 .45326 L .35678 .49108 L p .643 .564 .751 r
F P
0 g
s
.35678 .49108 m .34619 .47352 L .40003 .43557 L p .643 .564 .751 r
F P
0 g
s
.38503 .39614 m .39252 .41644 L .33569 .45435 L p .612 .525 .732 r
F P
0 g
s
.34619 .47352 m .33569 .45435 L .39252 .41644 L p .626 .543 .74 r
F P
0 g
s
.71025 .30054 m .70132 .30735 L .62251 .29222 L p .719 .748 .875 r
F P
0 g
s
.61769 .30448 m .62251 .29222 L .70132 .30735 L p .735 .767 .878 r
F P
0 g
s
.39252 .41644 m .40003 .43557 L .34619 .47352 L p .626 .543 .74 r
F P
0 g
s
.47146 .43238 m .47521 .44613 L .42277 .4834 L p .752 .676 .777 r
F P
0 g
s
.53223 .37171 m .53178 .38598 L .4677 .41715 L p .773 .693 .774 r
F P
0 g
s
.47146 .43238 m .4677 .41715 L .53178 .38598 L p .791 .718 .784 r
F P
0 g
s
.61291 .31658 m .60817 .32847 L .53312 .34093 L p .771 .719 .804 r
F P
0 g
s
.53267 .35665 m .53312 .34093 L .60817 .32847 L p .786 .738 .808 r
F P
0 g
s
.42277 .4834 m .41517 .46927 L .47146 .43238 L p .752 .676 .777 r
F P
0 g
s
.71927 .29362 m .71025 .30054 L .62737 .27986 L p .704 .733 .873 r
F P
0 g
s
.62251 .29222 m .62737 .27986 L .71025 .30054 L p .719 .748 .875 r
F P
0 g
s
.4677 .41715 m .47146 .43238 L .41517 .46927 L p .732 .646 .764 r
F P
0 g
s
.41517 .46927 m .40759 .45326 L .4677 .41715 L p .732 .646 .764 r
F P
0 g
s
.53267 .35665 m .53223 .37171 L .46394 .40058 L p .758 .671 .766 r
F P
0 g
s
.4677 .41715 m .46394 .40058 L .53223 .37171 L p .773 .693 .774 r
F P
0 g
s
.61769 .30448 m .61291 .31658 L .53357 .32468 L p .757 .704 .802 r
F P
0 g
s
.53312 .34093 m .53357 .32468 L .61291 .31658 L p .771 .719 .804 r
F P
0 g
s
.46394 .40058 m .4677 .41715 L .40759 .45326 L p .714 .621 .753 r
F P
0 g
s
.40759 .45326 m .40003 .43557 L .46394 .40058 L p .714 .621 .753 r
F P
0 g
s
.46018 .38285 m .46394 .40058 L .40003 .43557 L p .698 .601 .744 r
F P
0 g
s
.40003 .43557 m .39252 .41644 L .46018 .38285 L p .698 .601 .744 r
F P
0 g
s
.53312 .34093 m .53267 .35665 L .46018 .38285 L p .743 .653 .76 r
F P
0 g
s
.46394 .40058 m .46018 .38285 L .53267 .35665 L p .758 .671 .766 r
F P
0 g
s
.62737 .27986 m .63227 .26744 L .71927 .29362 L p .704 .733 .873 r
F P
0 g
s
.45642 .36416 m .46018 .38285 L .39252 .41644 L p .684 .584 .737 r
F P
0 g
s
.39252 .41644 m .38503 .39614 L .45642 .36416 L p .684 .584 .737 r
F P
0 g
s
.62251 .29222 m .61769 .30448 L .53402 .30803 L p .743 .69 .8 r
F P
0 g
s
.53357 .32468 m .53402 .30803 L .61769 .30448 L p .757 .704 .802 r
F P
0 g
s
.45266 .34472 m .45642 .36416 L .38503 .39614 L p .672 .571 .733 r
F P
0 g
s
.38503 .39614 m .37757 .37494 L .45266 .34472 L p .672 .571 .733 r
F P
0 g
s
.4489 .32475 m .45266 .34472 L .37757 .37494 L p .662 .561 .73 r
F P
0 g
s
.37757 .37494 m .37013 .35314 L .4489 .32475 L p .662 .561 .73 r
F P
0 g
s
.44513 .30449 m .4489 .32475 L .37013 .35314 L p .653 .554 .73 r
F P
0 g
s
.37013 .35314 m .3627 .33102 L .44513 .30449 L p .653 .554 .73 r
F P
0 g
s
.44135 .28414 m .44513 .30449 L .3627 .33102 L p .645 .549 .731 r
F P
0 g
s
.3627 .33102 m .35527 .30889 L .44135 .28414 L p .645 .549 .731 r
F P
0 g
s
.53357 .32468 m .53312 .34093 L .45642 .36416 L p .73 .638 .756 r
F P
0 g
s
.46018 .38285 m .45642 .36416 L .53312 .34093 L p .743 .653 .76 r
F P
0 g
s
.43754 .26392 m .44135 .28414 L .35527 .30889 L p .639 .547 .735 r
F P
0 g
s
.35527 .30889 m .34782 .287 L .43754 .26392 L p .639 .547 .735 r
F P
0 g
s
.62737 .27986 m .62251 .29222 L .53447 .29113 L p .73 .68 .801 r
F P
0 g
s
.53402 .30803 m .53447 .29113 L .62251 .29222 L p .743 .69 .8 r
F P
0 g
s
.45642 .36416 m .45266 .34472 L .53357 .32468 L p .73 .638 .756 r
F P
0 g
s
.53402 .30803 m .53357 .32468 L .45266 .34472 L p .719 .626 .754 r
F P
0 g
s
.45266 .34472 m .4489 .32475 L .53402 .30803 L p .719 .626 .754 r
F P
0 g
s
.63227 .26744 m .62737 .27986 L .53493 .27412 L p .718 .671 .803 r
F P
0 g
s
.53447 .29113 m .53493 .27412 L .62737 .27986 L p .73 .68 .801 r
F P
0 g
s
.53447 .29113 m .53402 .30803 L .4489 .32475 L p .708 .617 .753 r
F P
0 g
s
.4489 .32475 m .44513 .30449 L .53447 .29113 L p .708 .617 .753 r
F P
0 g
s
.53493 .27412 m .53447 .29113 L .44513 .30449 L p .698 .61 .755 r
F P
0 g
s
.44513 .30449 m .44135 .28414 L .53493 .27412 L p .698 .61 .755 r
F P
0 g
s
.53539 .25714 m .53493 .27412 L .44135 .28414 L p .689 .606 .759 r
F P
0 g
s
.44135 .28414 m .43754 .26392 L .53539 .25714 L p .689 .606 .759 r
F P
0 g
s
.53493 .27412 m .53539 .25714 L .63227 .26744 L p .718 .671 .803 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ok2K`P03o`00
0?ngZlgo]j_=00?o]j_=2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo0_l00002ooooo`03o`000?oooooooooo07Sooooo2_l0000Hok2K`P03o`000?ng
Zlgo]j_=00ko]j_=2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_oo
ool002cooooo0_l00004ooooo`03o`000?oooooooooo07?ooooo1?l00002oj><_003o`000?n`Vl;o
/9_201go/9_200?o0000okN[cOngZld06OngZld7o`0001?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06oooooo0ol00006oj><_003o`000?n`Vl;o/9_201go/9_200?o0000okN[cOngZld07OngZld00ol0
003o];_OokBkg`03o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]oooo
o`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l00009oj><_003
o`000?n`Vl;o/9_201Wo/9_21Ol00007okN[c@03o`000?ngZlgo]j_=01Co]j_=00?o0000okBkgond
^ml01?nd^ml3o`0000gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00
;?ooool3o`0000Kooooo00?o0000ooooooooool0IOooool4o`0000koXhbl00?o0000ok2K`_n`Vl80
4?n`Vl88o`0000Co/Yc100?o0000okZ^cOnj[/d01_nj[/d?o`0000Oo]j_=00?o0000okBkgond^ml0
1ond^ml3o`0000[ooooo00?o0000ooooooooool0<_ooool2o`0002gooooo000/ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0H?ooool4o`0001;oXhbl00?o0000ok2K`_n`Vl802On`
Vl87o`0000co/Yc100?o0000okZ^cOnj[/d05Onj[/d7o`0000go];_O0ol00007ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:oooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Looooo`?o00005_nSS;`00ol0003o/9_2ok2K`P02ok2K`POo0000
4onbW<400ol0003o^Zk=okZ^c@0KokZ^c@04o`000?nh_moo^;oOo`0000go];_O0ol00005ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0017ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0Eoooool4o`0001OoXhbl0ol000000on`Vl;o0000o`00000Kok:L`@03
o`000?nj[/go^Zk=01_o^Zk=00?o0000okRogonh_ml01?nh_ml3o`0000[o];_O0ol00002ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002oooool00ol0003o
ooooooooo`1Cooooo`?o00006?nSS;`3o`0000;oYHbk00?o0000ok:L`OnbW<407?nbW<400ol0003o
^Zk=okZ^c@0JokZ^c@03o`000?nh_moo^;oO00Wo^;oO1?l00008okBkg`?o0000=_ooool00ol0003o
ooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo0_l000000onBO[[o
0000oj><_00Doj><_0Co00001OnUS;/00ol0003o/Yc1ok:L`@0Hok:L`@Go00000onj[/dJo`0000oo
^;oO0ol00007okBkg`Co0000=?ooool00ol0003oooooooooo`0Xooooo`004Oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0COooool2o`0000CoTWjj00?o0000oj><_?nSS;`03onSS;`3o`00
00WoYHbk00?o0000ok:L`OnbW<404OnbW<47o`0000Co]Ig000?o0000okj`c?nn/<`06_nn/<`01?l0
003o_<CPokc4h?nla>02o`0000go^;oO1?l00003okBkg`04o`000?nd^moo];_OokBkg`?o0000<Ooo
ool2o`0002Wooooo000Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`;o00003oooool00ol0003oooooooooo`1:ooooo`;o00001_nBO[X00ol0003oXhbloj><
_00;oj><_0Co00003OnUS;/00ol0003o/Yc1ok:L`@08ok:L`@So00002oneWL000ol0003o_[3<okj`
c00Iokj`c003o`000?nla>3o_<CP00Oo_<CP1Ol00009okRog`Co00000_nd^ml01?l0003oVKkboiVn
l_nI__82o`0002oooooo0_l0000Yooooo`004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Oooooo
0_l00009oi9n^P03o`000?nSS;coXhbl00OoXhbl0ol0000AojF<^`03o`000?nbW<7o/Yc100;o/Yc1
1_l0000CokFM`003o`000?nn/<co_[3<01Wo_[3<00?o0000okc4h?nla>003?nla>05o`0000Oo^;oO
0ol00006oiVnlP03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool0017ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0@ooooo`;o0000
AOooool2o`0000_oTWjj00?o0000oj><_?nSS;`00onSS;`4o`0001?oYHbk0_l000000onbW<7o0000
o`00000IokFM`003o`000?nn/<co_[3<01;o_[3<2?l0000Dokc4h0Go000000?o^;oOo`000?l00000
0onKa?@6oiVnlP;o0000;_ooool00ol0003oooooooooo`0Vooooo`00:_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo043ooooo0_l0000=oi9n^P04o`000?nSS;coXhbloj><_0;o0000
5?nUS;/3o`000003ojN=^_l0003o]Ig001_o]Ig000?o0000okj`c?nn/<`01Onn/<`=o`0000Oo`KC=
00Co0000ol39hOo0bN7o`<WQ1_l0000>okc4h0Go00001OnKa?@00ol0003oVKkboiVnlP03oiVnlP;o
0000;Oooool00ol0003oooooooooo`0Uooooo`00:_ooool2o`0001Gooooo00?o0000ooooooooool0
?Oooool2o`0000ooTWjj0ol0000DojF<^`?o00001?nWSKX00ol0003o]Ig0okFM`00GokFM`0Co0000
0_nn/<`4o`0001Co`KC=00?o0000ol39hOo0bN402?o0bN47o`0000Co_<CP0ol00003okc4h003o`00
0?nNb_Oo000000KoVlCd00?o0000oiVnl_nI__800onI__82o`0002cooooo00?o0000ooooooooool0
9?ooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0jooooo`;o00003onB
O[X2o`000003oi=n^Ol0003oYHbk017oYHbk0ol00008ojN=^P03o`000?neWL3o]Ig0017o]Ig01Ol0
0003okRP`@03o`000?o1]<go`KC=01So`KC=00?o0000ol39hOo0bN403oo0bN46o`0000?o_<CP00Ko
0000oik:monNb_OoW/[go`000?nNb_L6oi_4m003o`000?nI__;oVKkb00?oVKkb0_l0000Zooooo`;o
00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0gooooo`;o0000
3onBO[X2o`0000?oTgji00?o0000ojF<^onUS;/03OnUS;/3o`0000_oYhfj00?o0000okFM`?neWL00
2oneWL06o`0000So^:3100?o0000ol6dcOo1]<d04oo1]<d5o`00013o`<WQ0ol00005ol39h@?o0000
1OnNb_L01?l0003oW/[goik:mol00005oi_4m0;o00001?nI__800ol0003oooooooooo`0Wooooo`;o
00002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01oooool002[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0doooo
o`;o00003onBO[X2o`0000KoTgji00?o0000ojF<^onUS;/02OnUS;/3o`0000koYhfj00?o0000okFM
`?neWL001_neWL05o`0000ko^:3100?o0000ol6dcOo1]<d02_o1]<d9o`0000CoaKS=00?o0000olC?
h_o4cn801?o4cn8<o`0000Ko`<WQ00Go0000oj7AnOnQdOWoXM7io`000003oik:m`03o`000?nNb_Oo
W/[g00;oW/[g0_l00004oi_4m0;o00000onI__82o`0002Sooooo00?o0000ooooooooool01_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Z
ooooo`;o00006Oooool00ol0003oooooooooo`0aooooo`;o00003onBO[X2o`0000SoTgji00?o0000
ojF<^onUS;/01_nUS;/3o`0001;oYhfj00Co0000okFM`?neWL3o]Ig01?l0000CokRP`@03o`000?o1
]<go`KC=00?o`KC=1ol0000=olFhc@03o`000?o4cn;oa<oR00Soa<oR0ol00005olC?hPKo00001onQ
dOT3o`0000KoW/[g0_l00003oi_4m0;o00000onI__82o`0002Oooooo00?o0000ooooooooool01Ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Oooool002Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`;o00003onBO[X2o`0000[oTgji00?o
0000ojF<^onUS;/00onUS;/3o`0001CoYhfj1?l0000FokRP`@?o000000?o`KC=o`000?l000005Oo5
^<d00ol0003oa<oRolC?hP06olC?hP?o00002oo4cn800ol0003oY=WjojCInP02ojCInPSoXM7i0ol0
0005oik:m`;o00000onKa?@2o`0000?oVKkb0_l0000Vooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo000Yooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0;?ooool00ol0003oNg2ko`00000=oi9n^P;o00003OnC
O[T00ol0003oYHbkojF<^`02o`0001CoYhfj0ol000000onYSk[o0000okRP`@0CokRP`@Co00000_nj
Xl400ol0003oaKS=olFhc@0ColFhc@Co00001Oo4cn8Ao`0000SoY=Wj0_l00004oj7An@04o`000?nQ
dOWo0000o`0000GoW/[g0ol00002oi_4m0;o00000onI__800ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01oooool002Wooooo0ol0000Looooo`03o`000?oooooooooo02[ooooo00Go0000og]`^omk
L;_oNg2ko`00000:oi9n^P;o00003_nCO[T3o`0001CoYhfj0ol00004ojV?^P03o`000?nhX<7o^:31
00oo^:310ol00006okZS`@03o`000?o5^<goaKS=00goaKS=1_l00003olVlcP03o`000?o8eN?ob=GS
00?o00003_o8eN<00ol0003oYn3kojOPn`03ojOPn`03o`000?nTfO[oY=Wj00KoY=Wj0ol00003oj7A
n@?o00001OnNb_L2o`0000;oVlCd0_l00002oiVnlP;o00009?ooool00ol0003oooooooooo`03oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000og]`^omkL;/00_mkL;/00ol0
003oTWjjoi9n^P06oi9n^P;o00003_nCO[T2o`000003oiAn^?l0003oYhfj017oYhfj0ol00007ojV?
^P03o`000?nhX<7o^:3100_o^:311?l00009okZS`@03o`000?o5^<goaKS=00KoaKS=1ol00008olVl
cPCo00002oo8eN<6o`0000coYn3k0_l00004ojCInP?o00000onQdOT3o`0000;oW/[g00?o0000oik:
mol000002?l0000Rooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool02Oooool002Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?mkL;_oNg2k00CoNg2k00?o0000oi9n^_nBO[X00onBO[X2o`0000koTgji0_l00004oiAn
^003o`000?nWSK[oYhfj00coYhfj0ol0000;ojV?^P03o`000?nhX<7o^:3100Ko^:311?l0000=okZS
`@03o`000?o5^<goaKS=00;oaKS=1?l0000=olVlcP?o00001oo8eN<7o`0000CocMcT00?o0000oj[X
n_nZj?X00onZj?X6o`0000OoYn3k1?l000000onTfO[o0000o`000002o`000003oj7AnOl0003o0000
00CoHZki1?mUZOL3ofVWm003o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?mkL;_oNg2k00GoNg2k00Co
0000oi9n^_nBO[[oTWjj0_l0000?oi=n^@03o`000?nDO[SoU7jh00CoU7jh00?o0000ojN=^_nWSKX0
2OnWSKX3o`0000koZHnj00?o0000okRP`OnhX<400onhX<43o`0000oo^Z?10ol000000oo5^<go0000
olVlcP0?olVlcPGo00000_o8eN<2o`0000kocMcT00?o0000oj[Xn_nZj?X03OnZj?X5o`0000;oGl3m
00?o0000oenioOmO^Od00_mO^Od4of2cn`GoHZki1?mUZOL3ofVWm003o`000?oooooooooo027ooooo
00?o0000ooooooooool07_ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`00027o
oooo00?o0000ooooooooool08_ooool00ol0003oNg2kog]`^`06og]`^`04o`000?nBO[[o0000o`00
00ooTgji0_l00008oiAn^003o`000?nWSK[oYhfj00GoYhfj0ol0000AojV?^P03o`000?nhX<7o^:31
00?o00003onjXl43o`0000;o_ZO200?o0000olVlc_o9_<h03_o9_<h4o`0000;ocL;@00?o0000olgL
i?o=g>@03?o=g>@4o`0000WoZ^Sj2?l00004of78o0;oGl3m00?o0000oeo0oOmO`?d00omO^Od01?l0
003oH;?kof2cnomP/o/5of:^n@CoIJWg0omYYo@00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo01gooooo0004o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01oooooo0_l00009og]`^`;o00003onCO[T2o`0000[oU7jh00?o0000ojN=^_nWSKX00_nWSKX3
o`0001?oZHnj0ol0000@okZS`@?o00001OnnYl800ol0003obKc>olVlcP0:olVlcPCo00001_o=`]00
0ol0003ocMcTolgLi005olgLi0Oo000000?od>?Uo`000?n]koL02on]koL3o`000003ofSGl_mTd?So
I=3h00;oI=3h1OmQb?`2o`0000;oGl3m00Go0000oenioOmO^OgoGkWmo`000003of2cn`CoHZki00Co
0000ofFYmomUZOOoIJWg0omYYo@00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo
0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`00
0?mkL;_oNg2k00SoNg2k00?o0000oga`^_l000003OnCO[T2o`0000coU7jh00?o0000ojN=^_nWSKX0
0_l0000CojV?^P?o000000?o[9:ko`000?njXl403OnjXl43o`0000So_ZO200?o0000olVlc_o9_<h0
1oo9_<h4o`0000SocL;@00?o0000olgLi?o=g>@00_o=g>@4o`0000God>?U0ol00004ojg_m`Co[oCc
00?o0000ofgMj_m]gNX01?m]gNX2o`000003ofSGl_l0003o000000;o00000_mTd?P01Ol0003oHLSl
of78o?mQb?co000000?oGl3m00Co0000oenioOmO^OgoGkWm0omP/o/01Ol0003oHZkiof:^nOmR[_Wo
000000?oIJWg00Co0000ofVWm?mYYoCo00008_ooool2o`0001gooooo0006ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oNg2kog]`^`08og]`^`05o`00
0?mlL;[oO72joga`^_l000002_nCO[T2o`0000koU7jh0_l0000DojV?^P;o00001?n/T[/00ol0003o
^Z?1okZS`@09okZS`@?o00002onnYl800ol0003obKc>olVlcP03olVlcPGo00002Oo=`]03o`000003
olgLi?l0003od>?U00Kod>?U1?l000000ooDj^Go0000ojodl`03ojodl`;o/?S/0ol00007ofgMjP;o
DLW_00?o0000odRmlom8_O<00_m8_O<3od2`m@07o`000?ljY?Go0000of78o?l0003oHLSlo`000002
oeo0o@04o`000?mO^OgoGkWmo`0000;oH;?k00Go0000of:^nOmR[_WoHZkio`000003ofFYm`04o`00
0?mYYoCoJJOdo`00023ooooo00?o0000ooooool000007Oooool000Kooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool2o`0002Oo
oooo00?o0000ooooooooool06?ooool00ol0003oNg2kog]`^`08og]`^`03o`000?mlL;[oO72j00;o
O72j00?o0000oi=n^OnCO[T01_nCO[T2o`0000koU7jh0_l000000onGP;Wo0000ojV?^P0@ojV?^P?o
00001_n/T[/00ol0003o^Z?1okZS`@06okZS`@?o00003_nnYl801?l0003obKc>olVlc_o9_<h4o`00
00WocL;@0ol00002om78d@03o`000?o@hnGod>?U00Cod>?U0_l00004omCZi@;o000000Co[oCcok3h
k?n`n>co/?S/0ol000000on`n^?oLN7Oog7Qg`02ofKJfP?o00000omLdnH3o`000003oe79kol0003o
B;gc00;oB;gc0_m0/?D01?l0003o>ZCeocZTmOl00002ocNJl`03of78o?l0003oGl3m00;o00000_mO
^Od01?l0003oH;?kof2cnol00003of:^n@04o`000?mUZOOoIJWgo`0000;oJJOd00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0Fooooo`03o`000?mkL;_oNg2k00SoNg2k00?o0000oga`
^_mlL;X01?mlL;X00ol0003oTgjioi=n^@04oi=n^@03o`000?nDO[SoU7jh00goU7jh00Go0000oiN0
^OnGP;WoUh2io`00000?ojV?^P;o00002_n/T[/00ol0003o^Z?1okZS`@02okZS`@?o00004?nnYl86
o`0000WocL;@0ol00004om78d@04o`000?o@hnGod>?Uom3Si@;o00001OoDj^D3o`0000?o/?S/00Co
0000ok3jhon`n^?o/?[S0_mfhm<2ofKJfP05o`000?mhf__oN=[kogSJnol000001?m/b_h4of6ho@Co
EZOh00CoB;gco`000?m0/?Go00000_ljY?D01?l0003o=i[cocNJlol00002ocJAl0Co000000?oGkWm
o`000?mP/o/00_l00002of:^n@04o`000?mUZOOoIJWgo`0000;oJJOd00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Jooooo`001_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo01Cooooo00?o0000og]`^omkL;/02?mkL;/00ol0003oO72joga`^P06oga`^P04o`00
0?nCO[WoTgjioi=n^@;o00003_nDO[P2o`0000GoUh2i00?o0000ojV?^_nYSkX02OnYSkX3o`0000co
[9:k00?o0000okZS`OnjXl400_l0000@okjW`PKo00002Oo=`]03o`0000GodLSA0_l000000oo@hnGo
e>[UomCZi@06omCZi@;o000000?oeo7So`000?n`n>`01?n`n^<2o`000003ofoOc?n3i_7oPnKa00;o
PnKa00Go0000ogSJnomhf__oN=[ko`000004ofc:oP05o`000?mQ^?goHKSmof6hoOl000001?mFYoP2
odjGl@05od2`mOl0003o>ZCeocZTmOl000000_lgV_<00ol0003o=Y7`ocJAl004ocN;k@?o000000Go
H;?ko`000?mR[_WoHZkio`000002ofFYm`04o`000?mYYoCoJJOdo`00023ooooo00?o0000oooooooo
ool06_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`03o`00
0?mkL;_oNg2k00SoNg2k00?o0000oga`^_mlL;X01omlL;X01?l0003oTgjio`000?l0000>oiAn^0;o
00001onGP;T00ol0003oZHnjojV?^P07ojV?^P;o00003_n/T[/3o`00013o_ZO21_l000000oo2ZlCo
0000olg2d006olg2d0?o00001OoAb=43o`000003omG?dol0003oe>[U00Goe>[U0_l00002omOah`;o
00001?n`n^<01?l0003oNnC6o`000?n:kN44o`000003oh?VlOl0003o000000Ko000000?oK<[no`00
0?mQ^?d00_mQ^?d00ol0003oEZOhoeJWn002oeJWn004o`000?m>Uo7oCYOaodjGl@Co00000_lgV_<0
0ol0003o=Y7`ocJAl004ocN;k@;o>XO[00?o0000of2cnol000000_mR[_T01?l0003oIJWgofFYmol0
0002ofVWm003o`000?oooooooooo01kooooo00?o0000ooooooooool06Oooool002Oooooo0_l0000/
ooooo`03o`000?oooooooooo013ooooo00?o0000og]`^omkL;/02?mkL;/00ol0003oO72joga`^P08
oga`^P;o00003onDO[P00ol0003oUh2ioiN0^@07oiN0^@03o`000?nYSk[oZHnj00CoZHnj0ol0000>
ojbB^`;o000000?o[iFlo`000?nnYl803OnnYl86o`0000Co`Z_400?o0000olg2d?o=`]000_o=`]03
o`0000KodLSA0_l00004omG?d`03o`000?oDj^Goe>[U00;oe>[U00Oo0000omOahooGlN?oeo7So`00
0?oHmn7o000000;o/?[S00Co0000ojojf?l0003oMn6n0_l000000on:kN7oZO3go`000003oj3Po005
o`000?nEcO_oULgkoiG=nol000000on9^OH4o`000003of6hoOl0003oEZOh00?oEZOh00Co0000odjG
lOm>Uo7oCYOa0_m8Rn/3o`0000;o=i[c00?o0000ocJAl?lfTO001?lgRnd4ocZ7j`Co00000_mUZOL0
1?l0003oJJOdofVWm?l0000Pooooo`03o`000?oooooooooo01Sooooo000Wooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool03_ooool00ol0003oNg2kog]`^`08og]`^`03o`000?mlL;[o
O72j00SoO72j00?o0000oge`^_l000003OnDO[P2o`0000[oUh2i00?o0000ojV?^_nYSkX00_nYSkX2
o`0000oo[9:k0_l00003ojnE_003o`000?nnYl;o_ZO200Wo_ZO21_l00007ol:[a003o`000?o=`]3o
cL;@00;o00001_oAb=43o`0000GoeLoC00Co0000omCZiOoDj^Goe>[U0ooGlN<00ol0003of?OQomSg
h@05o`000004ogoS^OmghKko0000o`0000?oZO3g00Go0000oj3Po?nPh?coX>3lo`000003oiG=n`03
o`000?n9^OKoRKWf00?oRKWf0omnYnh3o`0000?oEZOh00Go0000odjGlOm>Uo7oCYOao`000003odR;
j`?o000000Co=i[co`000?lfTO3o00000olgRnd01?l0003o>XO[ocZ7joljQn/3ocj4j@?o000000Go
IJWgo`000?mYYoCoJJOdo`00000Nooooo`;o00006_ooool002Oooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?mkL;_oNg2k00OoNg2k00?o0000oga`^_mlL;X02?ml
L;X01Ol0003oOG2joge`^_mmL;[o000000[oU7jh0_l0000=oiN0^@04o`000?nYSk[o0000o`0000oo
[9:k0_l00005ojnE_003o`000?nnYl;o_ZO200Ko_ZO21_l00009ol:[a0?o00001ooAb=42o`0000Oo
eLoC0_l00004omOah`03o`000?oHmn7of?OQ00Go000000Ko[OW=ogkP/?l0003o0000ojkhjOl00002
ojW`m`05o`000?nPh?coX>3loj3Po?l000000onEcO/00ol0003oRKWfohVimP03ohVimP03o`000?mn
YnkoOZO^00;oOZO^0_mdUnH2o`000003oeJWn?l0003oCYOa00;oCYOa00?o0000odR;jom8Rn/00_m8
Rn/00ol0003oA83Uo`000002o`000003ocJAl?l0003o=h_]00;o=h_]00Co0000ocZ7joljQn_o>XO[
0olnQ>T2odB4i`?o00000_mYYo@00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo
000Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool00ol0003oGF:oo`00
0007og]`^`03o`000?mlL;[oO72j00SoO72j00?o0000oge`^_mmL;X00_mmL;X00ol0003oU7jhoiAn
^007oiAn^003o`000?nGP;WoUh2i00coUh2i0_l0000@ojbB^`;o00002?n_UK`00ol0003o_ZO2okjW
`P02okjW`PKo00002Oo2Zl@3o`000003olFaa_l0003odLSA00GodLSA0_l00007omG?d`;o000000Go
f]OEo`000?oGlN?oeo7So`000002omSgh@;o000000Gof?_Mo`000?l0003o[OW=oh?R[@02o`0000;o
[_SY00Go0000ojW`monYl?OoZO3go`000003oj3Po005o`000?nEcO_oULgkoiG=nol000001On9^OH0
1Ol0003oOZO^ogjWk_mnYnko000000GoM9OV0_l00002odjGl@03o`000?m8Rn_oB8_[00;oB8_[00?o
0000odB0iOm4P>D00_m4P>D00ol0003o=Y7`o`000002ocN;k@05o`000?ljQn_o>XO[ocZ7jol00000
0olnQ>T4odB4i`;o000000?oJJOdo`000?ooool07_ooool00ol0003oooooooooo`0Fooooo`009ooo
ool2o`00033ooooo00?o0000ooooooooool02_ooool00ol0003oGF:oo`000006og]`^`03o`000?ml
L;[oO72j00SoO72j00?o0000oge`^_mmL;X00ommL;X00ol0003oU7jhoiAn^005oiAn^0;o00003OnG
P;T2o`000003oiV3^_l0003o[9:k00co[9:k0ol0000:ojnE_003o`000?nnYl;o_ZO200Go00002_o2
Zl@2o`0000CoaK7600?o0000om78dOoAb=400_oAb=400ol0003oeLoComG?d`06omG?d`;o00000_oJ
emD00ol0003oeo7SomSgh@03omSgh@03o`000?oHnmgo000000;o000000CoZ_K1ohKPX_l0003o[O[F
4?l00004ohVimP03o`000?mnYnkoOZO^00;oOZO^00?o0000ogBGi_mdUnH00omdUnH2off;g`03o`00
0?m>Uo7o000000CoB8_[0_l00003odB0i@;o@WWP00Go0000ocN;kOlgRngo=h_]o`000003ocZ7j`04
o`000?lnQ>Wo?XCYo`0000?oA8CW0_m;QNH3o`0001kooooo00?o0000ooooooooool05_ooool002Ko
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`05o`000?mMH[ooGF:ooeeR
_ol000001?mkL;/00ol0003oO72joga`^P08oga`^P03o`000?mmL;[oOG2j00GoOG2j00?o0000oiAn
^?nDO[P00_nDO[P2o`0000koUh2i00?o0000oiV3^_nIPkX00_nIPkX00ol0003o[9:kojbB^`08ojbB
^`;o00003?n_UK`3o`000003ol:[a?l0003o000000[o`Z_40ol00006olFaaP04o`000?oAb=7odLSA
o`0000SoeLoC0_l00002om[Ge@;o00001?oHmn400ol0003of?_MomSkg@02o`000003ojgicOnVl[Go
000000;o[O[F0_l000000oo4m>ko0000okkTlP02okkTlP05o`000?nddNoo]=7_okCAkol000000onX
_^T00ol0003oWZgRo`000002o`000003ohVim_l0003oOZO^00;oOZO^00?o0000ogBGi_mdUnH00omd
UnH01_l0003oKH_Ooff;gom]RmooCYOao`0000CoB8_[00?o0000odB0iOl000000_m4P>D01?l0003o
@WWPod9ih?l00003ocN;k@04o`000?ljQn_o>XO[o`0000?o?XCY1?m4Q>L4od^5iP03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05Oooool002Kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`07ooooo`03o`000?mMH[ooGF:o00;oGF:o00Co0000og]`^omkL;_o00002_mlL;X0
0ol0003oOG2joge`^P06oge`^P05o`000?nDO[SoU7jhoiAn^?l000003_nGP;T2o`0000GoVH>j00?o
0000ojbB^on/T[/01_n/T[/2o`0000co[iFl0_l000001?nbVKko0000o`000?l00009ol:[a0?o0000
2?o5/LH2o`0000SoeLoC0ol00002om[Ge@;o000000GogMoGo`000?oHmn7of?OQo`000002omSkg@06
o`000?oFo]Oo0000oj[f`Ol0003oZOK10ol00002olCdkP05o`000?nni?;o_^CbokkTl_l000000ond
dNl01Ol0003oZ;kYojRnjOnX_^Wo000000GoWZgR0_l00003ogjWkP03o`000?mdUnKoM9OV00?oM9OV
00?o0000off;gom]Rml00_m]Rml2o`0000?oB8_[00Ko0000odB0iOm4P>Go0000odB0iOl00003od9i
h0;o000000?o=h_]o`000?ljQn/00_ljQn/01?l0003o?XCYocj4jOl00003odB4i`05o`000?m;QNKo
BhGVod^5i_l000007_ooool2o`0001Kooooo000Vooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool01Oooool00ol0003oGF:ooeeR_`03oeeR_`03o`000?mkL;_o000000[oO72j00?o0000
oge`^_mmL;X01ommL;X01?l0003oU7jho`000?l0000=oiN0^@;o00002?nIPkX00ol0003o[9:kojbB
^`03ojbB^`;o00003?n_UK`6o`0000Wo`Z_40_l00009olFaaP;o000000?ob[O8o`000?oEcm<01OoE
cm<2o`0000?of]OE0_l00002omgOe`03o`000?oHmn7of?OQ00?of?_M0ol000000onZm/7o0000ojWf
`@02o`000004olGmhol0003oa?C^o`0000?o_^Cb00Go0000okCAkonddNoo]=7_o`000003ojRnj@03
o`000?nN[N;oWZgR00CoWZgR00Ko0000oiFNfol0003o0000ogjWk_l00004ogBGiP03o`000?m]Rmoo
KH_O00?oKH_O0_mWPMT2o`000007odR;jol0003oA83UodB0iOl0003oA83Uo`000003od9ih0;o@WCL
00?o0000ocN;kOl000000_ljQn/01Ol0003o?XCYocj4jOlnQ>Wo000000?oA8CW1?m;QNH00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?mMH[ooGF:o00CoGF:o00?o0000oga`^_mlL;X02?mlL;X00ol0003oOG2j
oge`^P08oge`^P;o00003_nGP;T00ol0003oVH>joiV3^P08oiV3^P04o`000?n/T[_o[9:kojbB^`;o
00003?n_UK`4o`0000?o/YVn00?o0000ol:[a?o2Zl@01?o2Zl@3o`0000WoaK760_l00003olZgb003
o`000?oEcm?oeLoC00;oeLoC0_l00004om[Ge@04o`000?oMgmOogMoGomgOe`;o00001?oHnmd01ooF
o]Oo0000o`000?nVl[Go0000ojWf`Ol000000_o5oN<01?l0003oa?C^olCdk_l00002okkTlP05o`00
0?nddNoo]=7_okCAkol000000onX_^T00ol0003oWZgRoij]hP04oij]hP03o`000?nEW]_oUIkK00;o
UIkK0_l00004ogBGiP03o`000?m]RmooKH_O00;oKH_O00?o0000ofN1fOmWPMT00_mWPMT00om8Rn_o
0000odB0i@02odB0i@;o00000om2NN001Ol0003o@WCLod9dg?m2M=co000000?o>XO[00Co0000ocj4
jOlnQ>Wo00000om4Q>L01Ol0003oBhGVod^5i_m;QNKo000001oooooo00?o0000ooooooooool04ooo
ool002Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`02ooooo`03o`000?mMH[oo
GF:o00GoGF:o00?o0000oga`^_mlL;X01omlL;X00ol0003oOG2joge`^P08oge`^P03o`000?mnL[[o
000000coUh2i0_l0000;oiV3^P04o`000?n/T[_o[9:ko`0000co[iFl0ol00007ok:I_P04o`000?o2
ZlCo`Z_4ol:[a0;o00002_o5/LH2o`0000Gob[O800Go0000omG?dooEcm?oeLoCo`000004om[Ge@;o
00000_oMgmL2o`000007on7Xeol0003of?_MomSkgOoFo]Oo0000om;oc`03o`000005ojWf`Oo0o]3o
0000olGmhol000000_o4m>h01?l0003o_^CbokkTl_l00003okCAk`03o`000?nX_^WoZ;kY00;oZ;kY
00?o0000oij]h_nN[N800onN[N800ol0003oUIkKoiFNf`03oiFNf`03o`000?n=TmCo000000;oM9OV
00?o0000off;gom]Rml00om]Rml00ol0003oIh7IofN1f@03ofN1f@;o00000om4P>D01Ol0003o@WWP
od9ih?m2NN3o000000Co@WCL0_l000000oljQn_o0000ocj4j@02ocj4j@04o`000?m4Q>OoA8CWodB4
i`?oBhGV00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`006oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00007
oeeR_`03o`000?mLHKko000000OoO72j00?o0000oge`^_mmL;X02?mmL;X01Ol0003oOW:jogib^_mn
L[[o000000WoUh2i0_l0000=oiV3^P;o00002on_UK`3o`0000[o/YVn00Co0000ol:[a?l0003o0000
2_o5/LH2o`0000Oob[O800?o0000omG?dol000001?oJemD2o`0000?ogMoG00Co0000on7XeooQj=Oo
00000_oHnmd02_oFo]Oo0000om;ocol0003oXnfYojC^[?l0003o`?k@o`000?o5oN<<o`0000?oZ;kY
00?o0000oij]h_nN[N800onN[N800ol0003oUIkKoiFNf`03oiFNf`07o`000?n=TmCoSI?DohfCe?l0
003oM9OVo`000004off;g`03o`000?mWPMWoIh7I00CoIh7I0_mSNM<2o`000003odB0iOl0003o0000
00;o@WWP00?o0000od9dg?m2M=`00_m2M=`2odAaf@03o`000?ljQn_o000000;o?XCY00Go0000odB4
iom4Q>OoA8CWo`000003od^5iP03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool0
01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo0ol00007
oeeR_`03o`000?mLHKko000000KoO72j00?o0000oge`^_mmL;X02?mmL;X00ol0003oOW:jogib^P02
ogib^P03o`000?nGP;WoUh2i00KoUh2i00?o0000oiV3^_nIPkX02onIPkX2o`000003oib6^ol0003o
[iFl00Oo[iFl1?l0000;ok:I_P;o00002_o5/LH3o`0000Sob[O80_l00005om[Ge@04o`000?oMgmOo
gMoGomgOe`;o00000ooQj=L01?l0003oe_kGomKneooBoll2o`000004oj?]ZOnTkZco0000ol3nd0Co
000000?od^gWo`000?o;g>H00_o;g>H02Ol0003o`L[Qol7:hOo1b^7o0000okNifol0003oZ;kYo`00
0005oij]hP03o`000?nEW]_oUIkK00?oUIkK00?o0000ohfCe?n=Tm@00on=Tm@2o`0000CoKH_O00?o
0000ofN1fOmWPMT00omWPMT00ol0003oHgWCof=id`02of=id`03odB0iOl0003o000000;o@WWP00?o
0000od9dg?m2M=`00_m2M=`4odAaf@05o`000?lnQ>Wo?XCYocj4jOl000000om4Q>L01?l0003oBhGV
od^5i_l0000Pooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413oooooooooo`03ooooo`00
6oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0000iooooo`03o`000?mMH[ooGF:o00Go
GF:o00Go0000oeaQ__mLHKkoG66no`000004oga`^P03o`000?mmL;[oOG2j00SoOG2j00?o0000ogib
^_mnL[X01?mnL[X00ol0003oUh2ioiN0^@03oiN0^@;o00003OnIPkX00ol0003oW8Jkoib6^`02oib6
^`03o`000?n_UKco[iFl00;o[iFl1Ol0000;ok:I_P;o000000?o]Yk0o`000?o5/LH01oo5/LH2o`00
00Wob[O80_l000000oo?_l_o0000om[Ge@02om[Ge@04o`000?oMgmOogMoGomgOe`;o00000ooQj=L2
o`000003omKneol0003od_o?00;o000000?oXnfYojC^[?l000001?l00002om;]i`05o`000?o;g>Ko
bmcVol_Li_l000000oo1b^401?l0003o]kWKokNifong^M/2o`0000CoWZgR00?o0000oiFNfonEW]/0
0onEW]/00ol0003oSI?DohfCe004ohfCe0;oQhW>00Co0000off;gom]Rmoo00001_mWPMT00ol0003o
HgWCof=id`03of=id`?o00000_m2NN001Ol0003o@WCLod9dg?m2M=co000000CoA77I0_l000000oln
Q>Wo0000odB4i`02odB4i`05o`000?m;QNKoBhGVod^5i_l000007_ooool3o`0000[ooooo00?o0000
ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000oeeR_omMH[l01?mMH[l00ol0003oG66noeaQ_P03oeaQ_P04o`000?mlL;[o
O72jo`0000[oOG2j00?o0000ogib^_mnL[X01_mnL[X00ol0003oUh2ioiN0^@02o`0000goVH>j0_l0
0005oib6^`03o`000?n_UKco000000;o000000?o[iFlo`000?l000003?nbVKh00ol0003o]Yk0okJN
`002okJN`003o`000?o5/LKoaK7600?oaK760_l00009olZgb0;o00000oo?_l/00ol0003of]OEom[G
e@04omgOe`03o`000?oQj=OohNSG00;ohNSG00?o0000on?`eol000000_oBoll00oo<o/Go0000oj?]
Z@04o`000005omCjhOl0003od^gWom;]iol000000oo;g>H01Ol0003o`L[Qol7:hOo1b^7o000000Co
]kWK00Ko0000ojj[e?l0003o0000oij]h_l00005oiFNf`03o`000?n=TmCoSI?D00CoSI?D00Oo0000
ohN9c_n7RLkoQhW>o`000?m]Rmoo000000GoIh7I00?o0000of=idomSNM<01?mSNM<2of5dc`;o0000
00?o@WWPo`000?m2M=`00_m2M=`00ol0003oA77IodAaf@02odAaf@;oAW3G00?o0000ocj4jOl00000
0_m4Q>L01Ol0003oBhGVod^5i_m;QNKo0000023ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`05ooooo`006oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0>?ooool00ol0003oGF:ooeeR_`05oeeR_`03o`000?mLHKkoG66n00?oG66n00?o0000oga`^_l0
00002_mmL;X00ol0003oOW:jogib^P07ogib^P03o`000?nGP;Wo000000goVH>j0_l00006oib6^`?o
00000_n_UK`2o`0000co/YVn0_l00005okJN`003o`000?o5/LKoaK7600;oaK7600?o0000olZgb?o:
]lP01oo:]lP2o`0000Cocko;00?o0000om[GeOl000000ooMgmL2o`0000?ohNSG1?l000001OoBoloo
0000olcnaOl0003oXnfY00;o000000CocooDo`000?oDn^7o00000_oBkNL01Ol0003obmcVol_Li_o;
g>Ko000000?o`L[Q00?o0000okNifong^M/00_ng^M/01?l0003o[Z_Dojj[e?n^Zm@2o`0000GoUIkK
00?o0000ohfCe?n=Tm@01?n=Tm@00ol0003oQhW>ohN9cP03ohN9cP03o`000?mWPMWoIh7I00?oIh7I
00?o0000of=idomSNM<01?mSNM<01?l0003oHGC?of5dcomQM<l3o`0000?o@WCL00?o0000odAafOm4
LMT00_m4LMT4odI`e`05o`000?m4Q>OoA8CWodB4iol000000om;QNH00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go410@oooooooo
oooooooooa0@4005ooooo`03o`000?oooooooooo03Sooooo00?o0000oeeR_omMH[l01?mMH[l00ol0
003oG66noeaQ_P05oeaQ_P03o`000?mmL;[oOG2j00SoOG2j00?o0000ogib^_mnL[X02?mnL[X2o`00
00goVH>j00?o0000oib6^onLQ[/00onLQ[/3o`0000;oW8Jk00?o0000ojnE_?l000003?nbVKh2o`00
00Oo]Yk000Co0000olFaa_o5/LKo00002Oo:]lP2o`0000Gocko;0_l00004omgOe`03o`000?oQj=Oo
hNSG00;ohNSG00Go0000on?`eol0003ohoOEo`000002olcna@04okcf[_l0003o0000olCl`0;o0000
00Goe?[Qo`000?oBkNOod^gWo`000003ol_LiP05o`000?o1b^7o`L[Qol7:hOl000001?ng^M/01Ol0
003o[Z_Dojj[e?n^ZmCo000000;oYio>00Go0000oiFNfonEW]_oUIkKo`000006ohfCe003o`000?n7
RLkoQhW>00CoQhW>00?oPX;:o`000?mWPMT00omWPMT00ol0003oHgWCof=id`04of=id`03o`000?mQ
M<ooHGC?00;oHGC?0_l00003od9dg003o`000?m4LMWoA77I00;oA77I00?o0000odI`eom6L=L00_m6
L=L2o`000003odB4iol0003oBhGV00;oBhGV00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2o`0003Sooooo00?o0000oeeR_omMH[l01OmMH[l00ol0003oG66noeaQ_P05oeaQ_P03o`000?mm
L;[oOG2j00OoOG2j00?o0000ogib^_mnL[X02?mnL[X00ol0003oPGBlo`00000;oiV3^P;o00000onL
Q[/3o`0000CoW8Jk0_l0000<ok:I_P;o00002OnfW/02o`0000Wob[O80_l00006olnob`03o`000?oD
b<ko000000;ogMoG00?o0000on7XeooQj=L00_oQj=L2o`000004on?`eol0003ohoOEo`0000;oc?k5
00Co_?J^o`000?l0003oa?c00_l000001OoDn^7o0000om;]iooBkNOo000000?obmcV00Go0000ol7:
hOo1b^7o`L[Qo`000004okNif`05o`000?n^ZmCo[Z_Dojj[e?l000001?nWWlh00ol0003oUIkKo`00
0006ohfCe003o`000?n7RLkoQhW>00CoQhW>00Co0000oh:2b_n2P/[o00000_mWPMT00ol0003oHgWC
of=id`04of=id`03o`000?mQM<ooHGC?00CoHGC?00Go0000od9dg?m2M=co@WCLo`000004odAaf@03
o`000?m6L=OoAW3G00;oAW3G0_m:L=H00ol0003oA8CWo`000002od^5iP03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`006oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0=oooool00ol0003oGF:ooeeR_`04oeeR_`03
o`000?mLHKkoG66n00GoG66n00?o0000oe]Q__l000001ommL;X00ol0003oOW:jogib^P08ogib^P05
o`000?n1M;coPGBloh5d_?l000002?nIPkX2o`0000;oW8Jk0ol00006oib6^`03o`000?nPRkgo0000
00_o/YVn00?o0000okJN`?nfW/001onfW/02o`000003ok^U`ol0003ob[O800Kob[O80_l00006olno
b`;o00000_oDb<h00ol0003ogMoGo`000004on7Xe`03o`000?oSl=Ooho3G00?o00000_o<o/D01?nl
mZko0000o`000?o4o<09o`000003ol_Li_l0003o`L[Q00;o`L[Q00?o0000okNifong^M/00_ng^M/0
1Ol0003o[Z_Dojj[e?n^ZmCo000000GoYio>0ol00005ohfCe003o`000?n7RLkoQhW>00CoQhW>00?o
0000oh:2b_n2P/X00_n2P/X00ol0003oIh7Io`000006of=id`03o`000?mQM<ooHGC?00CoHGC?0_l0
0002od9dg003o`000?m4LMWoA77I00;oA77I00?o0000odI`eom6L=L00_m6L=L4odY`eP05o`000?m;
QNKoBhGVod^5i_l000008?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool002Cooooo00?o
0000ooooooooool0=oooool00ol0003oGF:ooeeR_`05oeeR_`03o`000?mLHKkoG66n00CoG66n00Co
0000oe]Q__mKHKko00001_mmL;X00ol0003oOW:jogib^P08ogib^P03o`000?n1M;coPGBl00;oPGBl
00?o0000oiV3^_nIPkX01OnIPkX00ol0003oW8Jko`000002o`0000OoW8Jk0_l00002oj2;_@03o`00
0?nbVKko/YVn00Oo/YVn0_l00009okJN`005o`000?nkYL?o^jG3ok^U`ol000001Oo:]lP2o`0000Ko
cko;0_l00003omC8cP;o00001?oQj=L2o`0000;oho3G0_l000001_oQo=3o0000olcnaOnlmZko/o2S
oiWPS@Co000000CogOSKo`000?oKjmoo00000_oDfmd4o`000003ol7:hOl0003o]kWK00?o]kWK00Go
0000ojj[e?n^ZmCo[Z_Do`000005ojNOcP05o`000?nPULWoX9G9oj2EbOl000000on=Tm@00ol0003o
QhW>ohN9cP04ohN9cP03o`000?n2P/[oPX;:00CoPX;:00?o0000of=idomSNM<01?mSNM<00ol0003o
HGC?of5dc`04of5dc`06o`000?mOL<co0000o`000?m2M=co00001?m4LMT00ol0003oAW3GodI`e`02
odI`e`03o`000?m:L=KoBW3F00;oBW3F0_l000000om;QNKo0000ooooo`0Nooooo`03o`000?oooooo
000000Gooooo00?oEEEEofIVI_l000001oooool002Cooooo00?o0000ooooooooool0=oooool00ol0
003oGF:ooeeR_`04oeeR_`03o`000?mLHKkoG66n00GoG66n00Go0000oe]Q__mKHKkoFf6no`000004
oge`^P03o`000?mnL[[oOW:j00SoOW:j00?o0000oh5d_?n1M;`01?n1M;`00ol0003oVH>joiV3^P02
oiV3^PCo00002OnLQ[/00ol0003oX8^moj2;_@03oj2;_@03o`000?nbVKko/YVn00Co/YVn0_l00009
okJN`0;o00001OnkYL<00ol0003ob[O8olZgb002o`0000Oocko;00?o0000omC8c_oDb<h00_oDb<h0
0ol0003ofM;Ao`000003on7Xe`06o`000?oSl=Ooho3Go`000?oSmmGo00000_oQo=001?o<o/Go_?J^
ok?`XonIh8d2o`000006omSodOl0003ogOSKo`000?oKjmoo00000_oDfmd01?l0003oc<_Holc;f?o<
bmP3o`0000?o]kWK00Go0000ojj[e?n^ZmCo[Z_Do`000005ojNOcP03o`000?nPULWoX9G900?oX9G9
00?o0000ohfCe?l000001_n7RLh00ol0003oPX;:oh:2bP05oh:2bP03ogila_l0003oHgWC00CoHgWC
00?o0000of5dcomQM<l01?mQM<l01_l0003oGg3<oem`c?l0003o@WCLo`0000CoA77I00?o0000odI`
eom6L=L00_m6L=L00ol0003oBW3FodY`eP02odY`eP;oCg;F00?o0000od^5i_l000008Oooool00ol0
003oooooooooo`0<ooooo`009?ooool2o`0003Sooooo00?o=EK6o`000?mMH[l01?mMH[l00ol0003o
G66noeaQ_P04oeaQ_P03o`000?mKHKkoFf6n00?oFf6n00Co0000oge`^_mmL;[o00002_mnL[X00ol0
003oPGBloh5d_005oh5d_003o`000?nIPk[oVH>j00Co00002OnLQ[/2o`0000KoX8^m00?o0000ok:I
__nbVKh00_nbVKh2o`0000Wo]Yk00_l00007ok^U``03o`000?o:]lSo000000Oocko;0_l00003omC8
cP;o00000_oId]401?l0003ohNSGon7Xeol00002on?`e`03o`000?oSmmGo000000;ohOc@00Ko0000
okcf[_ncl:?oUmb6o`000?o<oL02o`000004omghfol0003ofn_Oo`0000;oe=_M00Go0000olc;f?o<
bmSoc<_Ho`000003olBld`03o`000?ng^M_o000000?o[Z_D00?o0000ojNOc_nWWlh00onWWlh00ol0
003oX9G9oj2Eb@04oj2Eb@;o00001on7RLh00ol0003oPX;:oh:2bP04oh:2bP04o`000?mnO<KoOWc6
o`0000CoHgWC00?o0000of5dcomQM<l00omQM<l00ol0003oGg3<oem`c002oem`c0;o00001?m4LMT0
0ol0003oAW3GodI`e`02odI`e`03o`000?m:L=KoBW3F00;oBW3F0om?L]H00om;QNKo0000ooooo`0O
ooooo`?o00003Oooool002Cooooo00?o0000ooooooooool0=oooool2ocEFaP05o`000?mMH[ooGF:o
oeeR_ol000001omLHKh00ol0003oFf6noe]Q_P03oe]Q_P03o`000?mmL;[o000000WoOW:j0_l00008
oh5d_0Co00002onLQ[/00ol0003oX8^moj2;_@06oj2;_@05o`000?nbVKko/YVnok:I__l000002_nf
W/000ol0003o^jG3ok^U``06ok^U``;o00001oo?_l/2o`0000Coe<S>00?o0000omWBdOoId]400_oI
d]400ol0003ohNSGon?`e`02on?`e`03o`000?oSmmGo000000;ohOc@00?ofoo8okcf[_ncl:<00_l0
00001oo<oL3o0000o`000?oMn=_o0000om_[gol000000_oDfmd01Ol0003oc<_Holc;f?o<bmSo0000
00Coa;cC0_l00003ojj[e003o`000?nWWlkoYio>00?oYio>00?o0000oj2EbOnPULT01?nPULT01?l0
003oVhk5oi^>aOl00005ohN9cP03o`000?n2P/[oPX;:00CoPX;:00?o0000ogila_mnO<H00_mnO<H0
1?l0003oHgWCof=idol00006of5dc`03o`000?mOL<coGg3<00?oGg3<0_l00003odAaf@03o`000?m6
L=OoAW3G00;oAW3G00?o0000odY`e_m:L=H00_m:L=H01Ol0003oCg;Fodmbe_m?L]Ko000001gooooo
0ol00002ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Oooooo0_le
E/H01?l0003oGF:ooeeR_ol00007oeaQ_P03o`000?mKHKkoFf6n00GoFf6n00?o0000ogib^_mnL[X0
1omnL[X00ol0003oPGBloh5d_006oh5d_0Co00002onLQ[/2o`0000[oX8^m00?o0000ok:I__l00000
2OnfW/02o`0000So^jG300?o0000ol2]a_l000001_o?_l/00ol0003oe<S>omC8cP03omC8cP03o`00
0?oId]7ofM;A00;ofM;A0_l00003on?`e`;ohoOE00Ko0000on7ld?oQo=3ofoo8okcf[_ncl:<5o`00
0004omghfol0003ofn_Oo`0000;oe=_M00Go0000olc;f?o<bmSoc<_Ho`000004olBld`06o`000?nl
/<go_;3=o`000?n^ZmCo00001OnWWlh00ol0003oX9G9oj2Eb@04oj2Eb@03o`000?nKS/GoVhk500;o
Vhk500Go0000ohN9c_n7RLkoQhW>o`000006oh:2bP03o`000?mnO<KoOWc600CoOWc600?o0000of=i
dol000001OmQM<l00ol0003oGg3<oem`c004oem`c003oem^b_l0003o000000;oA77I00?o0000odI`
eom6L=L00_m6L=L00ol0003oBW3FodY`eP02odY`eP03o`000?m?L]KoCg;F00;oCg;F00?o0000oooo
ooooool05oooool3o`0000Gooooo00?o0000ooooooooool02oooool002Cooooo00?o0000oooooooo
ool0=_ooool01ol0003o=EK6ocEFa_leE/Ko0000oeeR_ol000001_mLHKh00ol0003oFf6noe]Q_P06
oe]Q_P03o`000?mnL[[oOW:j00KoOW:j00?o0000oh5d_?n1M;`01?n1M;`3o`000004oh5d_?l0003o
Q7Rno`0000[oW8Jk00?o0000oj2;_OnPRkd02OnPRkd2o`0000Wo]Yk00_l00008ok^U``;o00000_o0
[LH00ol0003ocko;olnob`02olnob`;o00001?oDb<h2o`0000CofM;A00?o0000omkLe?l000000_oS
l=L2on?ge@?ohOc@00?ofoo8o`000?ncl:<01Ol000001?oMn=_o0000om_[gol00002omCKg@05o`00
0?o<bmSoc<_Holc;f?l000001?o4_=<01?l0003o_;3=okb`cOnl/<d2o`0000GoYio>00?o0000oj2E
bOnPULT01?nPULT00ol0003oVhk5oi^>a@04oi^>a@03o`000?n7RLko000000KoPX;:00?o0000ogil
a_mnO<H01_mnO<H00ol0003oHGC?of5dc`04of5dc`03o`000?mOL<coGg3<00?oGg3<00Oo0000oem^
b_l0003oGfk:o`000?m4LMWo000000CoAW3G00?o0000odY`e_m:L=H00_m:L=H00ol0003oCg;Fodmb
eP02odmbeP03o`000?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo00_ooooo000S
ooooo`?o0000=oooool00ol0003o=EK6ocEFaP02ocEFaP03o`000?mLHKkoG66n00GoG66n00?o0000
oe]Q__mKHKh01OmKHKh00ol0003oG6:oo`000006ogib^P03o`000?n1M;coPGBl00;oPGBl0ol00003
oh5d_005o`000?n4N;koQ7RnohAh__l000002?nLQ[/00ol0003oX8^moj2;_@09oj2;_@03o`000?nT
T<3o000000So]Yk000?o0000ok^U`onkYL<01onkYL<00ol0003o`:g6ol2]aP03ol2]aP04o`000?o?
_l_ocko;o`0000Goe<S>00?o0000omWBdOoId]400ooId]401Ol0003og]cDomkLe?l0003oho3G00;o
hoOE0ooQo=001?oKolSodojnok?`XonRhhh4o`000004omghfol0003ofn_Oo`0000;oe=_M00Go0000
olc;f?o<bmSoc<_Ho`000004olBld`05o`000?nl/<go_;3=okb`cOl000000_nfY/P01Ol0003oYio>
ojNOc_nWWlko000000KoX9G900?o0000oi^>aOnKS/D01OnKS/D2o`0000KoPX;:00?o0000ogila_mn
O<H01omnO<H00ol0003oHGC?of5dc`03of5dc`03o`000?mOL<coGg3<00CoGg3<00Go0000oem^b_mO
K/[o0000oem^bP02o`0000CoAW3G00?o0000odY`e_m:L=H00_m:L=H00ol0003oCg;FodmbeP02odmb
eP03o`000?oooooooooo013ooooo0ol0000=ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03
o`000?oooooooooo03Oooooo00?o0000ocEFa_leE/H00_leE/H00ol0003oG66noeaQ_P04oeaQ_P03
o`000?mKHKkoFf6n00GoFf6n00Go0000oeaR_omLH[ooG6:oo`000004ogib^P03o`000?n1M;coPGBl
00?o00001On1M;`00ol0003oQ7RnohAh_P02ohAh_P03o`000?nLQ[_oW8Jk00CoW8Jk0_l0000:oj2;
_@;o00000onTT<000ol0003o]Yk0okJN`003okJN`0;o00002?nkYL<2o`0000Ko`:g600?o0000olno
booDb<h01?oDb<h2o`0000CofM;A0_l00002omkLe0;o00000_oSmmD3on7ld004om_ob?oCo[ko0000
oj;SSPWo000000?oe=_Mo`000?o<bmP00_o<bmP01?l0003oa;cColBldoo4_=<2o`0000?o_;3=00?o
0000okJVb?nfY/P00_nfY/P00ol0003oYio>o`000006oj2Eb@03o`000?nKS/GoVhk500GoVhk500?o
0000oiN7`Ol000001_n2P/X00ol0003oOWc6ogilaP06ogilaP03o`000?mkN<?o000000CoHGC?00?o
0000oem`c?mOL<`01?mOL<`01ol0003oGfk:oem^b_mOK/[o0000oem^b_l000001?m6L=L00ol0003o
BW3FodY`eP02odY`eP03o`000?m?L]KoCg;F00;oCg;F00?o0000ooooooooool03Oooool3o`00013o
oooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003o=EK6
ocEFaP02ocEFaP03oc1BaOl0003oG66n00CoG66n00?o0000oe]Q__mKHKh01OmKHKh01Ol0003oG6:o
oeaR_omLH[oo000000?oOW:j1?l00007oh5d_003o`000?n4N;koQ7Rn00CoQ7Rn00?o0000oib6^onL
Q[/00_nLQ[/00ol0003oX8^moj2;_@09oj2;_@03o`000?nTT<3oY93000CoY93000Go0000okJN`?nf
W/3o]Yk0o`000009ok^U``03o`000?o0[LKo`:g600Go`:g60_l00005omC8cP03o`000?oId]7ofM;A
00?ofM;A00So0000omkLe?oNg=Cog]cDo`000?oRimKo0000on?ge@?ohOc@00Cofoo8om?n__o7nK7o
X^>>0ol000001OoJol_o0000on7jeOl0003oh^oI00?o00000oo<bmP01Ol0003oa;cColBldoo4_=?o
000000Co_;3=00?o0000okJVb?nfY/P00onfY/P2o`0000KoX9G900?o0000oi^>aOnKS/D01OnKS/D0
1Ol0003oUhO1oiN7`OnGQl7o000000CoPX;:00?o0000ogila_mnO<H01_mnO<H01Ol0003oNgS3og]h
`omkN<?o000000;oHGC?00?o0000oem`c?mOL<`01?mOL<`00ol0003oGfk:oem^bP03oem^bP03o`00
0?mOKLWo000000?oAW3G00?o0000odY`e_m:L=H00_m:L=H00ol0003oCg;FodmbeP02odmbeP03o`00
0?oooooooooo00Wooooo1?l0000Cooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oo
oooooooo03Oooooo00?o0000ocEFa_leE/H00_leE/H2oc1Ba@05o`000?mLHKkoG66noeaQ__l00000
1omKHKh00ol0003oG6:ooeaR_`03oeaR_`Co00002On1M;`00ol0003oQ7RnohAh_P05ohAh_P03o`00
0?nLQ[_oW8Jk00;o00002onPRkd00ol0003oY930ojB@`005ojB@`003o`000?nfW/3o]Yk000Wo^jG3
0_l00007ol2]aP03o`000?o6]/[o000000Coe<S>00?o0000omWBdOoId]400_oId]42o`0000?og]cD
00Co0000on;We_oRimKo00000ooQo=001ooKolSodojnolOi/OnRhhkoT]Mmo`000?o>o;/00_l00000
0ooQn]Go0000on;_f@02o`0000;oemCE00?o0000olc;f?l000000oo4_=<00ol0003o_;3=okb`c@02
okb`c@03o`000?nfY/So]ZK800?o]ZK800?o0000ok2Ma?l000001OnPULT00ol0003oVhk5oi^>a@05
oi^>a@03o`000?nGQl7oUhO100?oUhO100Co0000oh:2b_n2P/[o00002?mnO<H00ol0003oNgS3og]h
``03og]h``03o`000?mQM<oo000000KoGg3<00?o0000oem^b_mOK/X00omOK/X01?l0003oGfg9oem]
bOl00002odI`e`03o`000?m:L=KoBW3F00;oBW3F00?o0000odmbe_m?L]H00_m?L]H00ol0003ooooo
ooooo`06ooooo`?o00005oooool00ol0003oooooooooo`0:ooooo`008oooool3o`0003Oooooo00?o
0000ocEFa_leE/H00_leE/H00ol0003o<5;5o`000002oeaQ_P03o`000?mKHKkoFf6n00GoFf6n00?o
0000oeaR_omLH[l00_mLH[l4o`0000[oPGBl00?o0000ohAh__n4N;h01_n4N;h00ol0003oW8Jko`00
000;oj2;_@;o00002?nTT<02o`0000Wo^jG300?o0000ol2]a_o0[LH01Oo0[LH2o`0000;oa[K:00Go
0000omC8c_oDb<koe<S>o`000004omWBd@03o`000?oNg=Cog]cD00;og]cD00Go0000on;We_oRimKo
i?;Eo`000002on7ld006om_ob?oCo[koaoVaok_bY?nBeggo_OBX0ol000000ooQn]Go0000on;_f@02
o`0000?oemCE0_l00003olBld`03o`000?nl/<go_;3=00;o_;3=00?o0000okJVb?nfY/P00onfY/P0
1Ol0003o/9g4ok2Ma?n`WLCo000000?oX9G900?o0000oi^>aOnKS/D01OnKS/D00ol0003oUhO1oiN7
`@04oiN7`@03o`000?n2P/[o000000SoOWc600?o0000og]h`omkN<<01OmkN<<00ol0003oGg3<oem`
c004oem`c003o`000?mOK/[oGfk:00CoGfk:0_l00002oem]b@03o`000?m6L=Oo000000CoBW3F00?o
0000odmbe_m?L]H00_m?L]H00ol0003oooooooooo`03ooooo`?o00006_ooool00ol0003ooooooooo
o`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`05o`000?leE/Ko=EK6ocEFa_l000000ol`
D/D00ol0003oG66no`000007oe]Q_P03o`000?mLH[oo000000;o00000omLH[l00ol0003oPGBloh5d
_007oh5d_003o`000?n4N;koQ7Rn00OoQ7Rn0_l0000;oj2;_@03o`000?nTT<3oY93000OoY93000?o
0000ojVG`ol000002?nkYL<00ol0003o`:g6ol2]aP05ol2]aP03o`000?o6]/[oa[K:00?oa[K:00?o
0000omC8c_oId]401?oId]401?l0003og]cDomkLe?oNg=@2o`0000;oh^OF0_oTl]D01_l0003ohOc@
om_ob?oCo[koaoVaok_bY0Go000000?ohO[Eo`000?oRkmT00_l00003omODe@06o`000?o@a]3od<K@
o`000?o4_=?o00001?nl/<d00ol0003o]ZK8okJVb003okJVb003o`000?n`WLCo/9g400?o/9g400?o
0000oj2EbOl000001_nKS/D2o`0000OoUhO10_l00008ogilaP03o`000?mkN<?oNgS300KoNgS300?o
NWC1o`000?mOL<`01?mOL<`00ol0003oGfk:oem^bP03oem^bP04o`000?mOKLWoGfg9o`0000;oGfg9
0_l00004odY`eP03o`000?m?L]KoCg;F00;oCg;F00?o0000ooooooooool00ol0000Mooooo`03o`00
0?oooooooooo00[ooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0>?ooool01Ol0003o
=EK6ocEFa_leE/Ko000000Co<5;500?o0000oe]Q__mKHKh01OmKHKh3o`0000GoG6:o00?o0000oemU
`_l000001on1M;`00ol0003oQ7RnohAh_P07ohAh_P03o`000?n8OL3o000000WoX8^m0_l00009ojB@
`005o`000?nYUl?oZIO3ojVG`ol000001OnkYL<2o`0000Oo`:g600?o0000olJfb_o6]/X00oo6]/X2
o`0000GofM;A00Go0000omkLe?oNg=Cog]cDo`000003on;WeP;oi?;E0_l000001?oKolSodojnolOi
/OnklZ@5o`000003on7jeOl0003oh^oI00;o00000ooGe=D01?l0003od<K@om36d?o@a]02o`0000Co
_;3=00?o0000okJVb?nfY/P00onfY/P00ol0003o/9g4ok2Ma004ok2Ma0;o00001_nKS/D00ol0003o
UhO1oiN7`@06oiN7`@03o`000?nCPkoo000000OoOWc600?o0000og]h`omkN<<01_mkN<<01?l0003o
NWC1ogYd`Ol00003oem`c003o`000?mOK/[oGfk:00CoGfk:00Co0000oem]bOmOKLWo00000omOKLT2
o`0000?oBW3F00?o0000odmbe_m?L]H00_m?L]H3o`00023ooooo00?o0000ooooooooool02_ooool0
0005ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A007ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool01Ol0003o=EK6ocEF
a_leE/Ko000000Co<5;500?o0000oe]Q__mKHKh00_mKHKh4o`0000KoG6:o00Co0000oemU`_mOIL;o
00001_n1M;`00ol0003oQ7RnohAh_P07ohAh_P05o`000?n8OL3oR7g0ohQm`?l000001onPRkd00ol0
003oY930ojB@`007ojB@`0;o00001?nYUl<00ol0003o^jG3ok^U``02ok^U``03o`000?o0[LKo`:g6
00Go`:g60_l00005olJfbP03o`000?o<`<oo000000CofM;A1?oNg=@01?l0003oh^OFon;We_oRimH2
onCbe@06o`000?oSn];o0000om?n__o7nK7o^o:T1Ol000000ooQn]Go0000on;_f@02o`0000?oemCE
00Oo0000om36d?o@a]3od<K@o`000?o:^lco000000?o_;3=00?o0000okJVb?nfY/P00_nfY/P2o`00
00Ko/9g400?o0000oj^F`Ol000001OnKS/D00ol0003oUhO1oiN7`@06oiN7`@05o`000?nCPkooTh>o
oi>3_ol000001OmnO<H00ol0003oNgS3og]h``06og]h``03o`000?mjM<7oNWC100;oNWC100Co0000
oem`c?mOL<co00001OmOK/X00ol0003oGfg9oem]b@02oem]b@03o`000?mOKLWoGfg900;oHFg800Co
0000odY`e_m:L=Ko00001?m?L]H00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo
00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooo
ooooo`02ooooo`;o0000>?ooool00ol0003o=EK6ocEFaP02ocEFaP03o`000?l`D/Go<5;500;o<5;5
00?o;E75o`000?mKHKh00_l00002oe]Q_P03o`000?mLH[ooG6:o00GoG6:o00Go0000oemU`_mOIL;o
GfG2o`000004oh5d_003o`000?n4N;koQ7Rn00OoQ7Rn00?o0000ohQm`?n8OL000on8OL000ol0003o
X8^moj2;_@03oj2;_@03o`000?nTT<3oY93000OoY93000?o0000ojVG`onYUl<01?nYUl<01Ol0003o
^jG3ok^U`onkYL?o000000Oo`:g600?o0000olJfb_o6]/X01?o6]/X01Ol0003oc<3?olc0coo<`<oo
000000;ofM;A1?oNg=@01?l0003oh^OFon;We_oRimH2onCbe@06o`000?oSn];og_k:o`000?o7nK7o
^o:T0ol000001Oo>o;_of_o;on7jeOl0003oh^oI00;o00000ooGe=D01Ol0003od<K@om36d?o@a]3o
000000?ob[_<00?o0000okb`cOl000001?nfY/P00ol0003o/9g4ok2Ma005ok2Ma005o`000?n[U/7o
ZiK1oj^F`Ol000000onKS/D00ol0003oUhO1oiN7`@06oiN7`@03o`000?nCPkooTh>o00?oTh>o00Go
0000ogila_mnO<KoOWc6o`000008og]h``03o`000?mjM<7oNWC100CoNWC100?o0000oem`c?l00000
1OmOK/X00ol0003oGfg9oem]b@03oem]b@;o00000omQKLP00ol0003oBW3Fo`000004odmbeP03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool00000
3Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
=oooool00ol0003o=EK6ocEFaP02ocEFaP03o`000?l`D/Go<5;500;o<5;50ol00003oe]Q_P03o`00
0?mLH[ooG6:o00GoG6:o00?o0000oemU`_mOIL800omOIL801?l0003oPGBloh5d_?l00009ohAh_P03
o`000?n8OL3oR7g000CoR7g000Co0000oj2;_OnPRkgoX8^m0_l00009ojB@`003o`000?nYUl?oZIO3
00KoZIO300?o0000ok^U`oo0[LH01_o0[LH2o`0000Goa[K:0_l00004olc0c`;o00001?oNg=@4on;W
eP;oi?;E00Ko0000on?jd_oNo/[og_k:olOi/OnklZ@5o`0000;ohO[E00?oh^oIo`000?oMh]P00_oG
e=D2o`0000?od<K@00?o0000olZkc?o:^l`00_o:^l`2o`0000Co]ZK800?o0000ok2Ma?n`WL@01?n`
WL@2o`0000GoZiK100?o0000oi^>aOl000002?nGQl400ol0003oTh>ooi>3_`05oi>3_`03o`000?mn
O<Ko000000SoNgS300?o0000ogYd`OmjM<401_mjM<400ol0003oGfk:oem^bP04oem^bP03o`000?mO
KLWoGfg900CoGfg900?o0000of5]b?mQKLP00_mQKLP2o`0000CoCg;F00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo
00?o0000ocEFa_leE/H00_leE/H00ol0003o<5;5o`000003o`000003obeAaOl0003oFf6n00;oFf6n
00?o0000oeaR_omLH[l01?mLH[l00ol0003oGfG2oemU`P04oemU`P03o`000?n1M;co000000WoQ7Rn
00?o0000ohQm`?n8OL001_n8OL000ol0003oX8^mo`000009ojB@`0;o00002?nYUl<2o`0000Oo`:g6
00?o0000olJfb_o6]/X01?o6]/X00ol0003oc<3?olc0c`03olc0c`03o`000?oCc=?o000000?og]cD
1?oRimH2onCbe@08o`000?oSn];og_k:omknb_l0003o^o:TojkZUonJfh83o`000005on3mcOl0003o
h^oIon;_fOoMh]P00ooGe=D4om36d003o`000?o:^lcob[_<00;ob[_<00?o0000olBab?l000000onf
Y/P00ol0003o/9g4ok2Ma004ok2Ma003o`000?n[U/7oZiK100GoZiK10_l00007oiN7`@;o00002?nC
Pkl2o`0000SoNgS300?o0000ogYd`OmjM<401omjM<400ol0003oGfk:oem^bP03oem^bP03o`000?mO
KLWoGfg900CoGfg90_l00005of5]b003o`000?m?L]KoCg;F00;oCg;F00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`04o`000?le
E/Ko=EK6ocEFaP?o00000ol`D/D01_l0003o;E75obeAaOl0003oFf6no`0000OoG6:o00?o0000oemU
`_mOIL801OmOIL800ol0003oQ7RnohAh_P07ohAh_P03o`000?n8OL3oR7g000OoR7g00_l00009ojB@
`003o`000?nYUl?oZIO300OoZIO300?o0000ojnOaol000001_o0[LH00ol0003oa[K:olJfbP04olJf
bP03o`000?o<`<ooc<3?00?oc<3?00Ko0000om?<dooCc=?odlcCo`000?oNg=@4on;WeP;oi?;E00Co
0000on?jd_oNo/[og_k:0_l000001_n^jYOoV]^2o`000?o8n[;oe_k1on3mc@?o000000CogN;HomOD
eOoGe=GoemCE0oo@a]02o`0000?ob[_<0_l00003olBab003o`000?nfY/So000000Ko/9g400?o0000
oj^F`On[U/401On[U/400ol0003oYi6no`000006oiN7`@03o`000?nCPkooTh>o00OoTh>o00?o0000
oi1o_Ol000001omkN<<00ol0003oNWC1ogYd`@07ogYd`@03o`000?mhLl3o000000CoGfk:00?o0000
oem]bOmOKLT01?mOKLT00ol0003oHFg8o`000004of5]b003of=_bOl0003oCg;F00;oCg;F00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000>?oo
ool4o`000003ocEFa_l0003o<5;500?o<5;500Go0000obeAaOl]DLGo;E75o`000007oeaR_`03o`00
0?mOIL;oGfG200KoGfG200?o0000ohAh__n4N;h01_n4N;h00ol0003oR7g0ohQm`007ohQm`003o`00
0?n=Q<Co000000SoY93000?o0000ojVG`onYUl<01onYUl<01Ol0003o[io7ojnOaon_WlOo000000Co
`:g600?o0000olJfb_o6]/X00oo6]/X2o`0000Goc<3?00Co0000om?<dooCc=?odlcC0_l00004on;W
eP;oi?;E0_oSn]82omknbP?o000000GoV]^2ojWWTOo8n[;oe_k1on3mc@02o`000003onC^e_l0003o
emCE00;oemCE0oo@a]000ol0003ob[_<olZkc002olZkc003o`000?o4/LSoa;7800?oa;780_l00006
ok2Ma003o`000?n[U/7oZiK100GoZiK100Go0000ojNA__nWTKkoYi6no`000004oiN7`@03o`000?nC
PkooTh>o00OoTh>o00Go0000oi1o_On@OkgoT7nmo`000005og]h``03o`000?mjM<7oNWC100OoNWC1
00Go0000ogQc`?mhLl3oN7?0o`000002oem^bP03o`000?mOKLWoGfg900GoGfg900Co0000of5]b?mQ
KLSo00000_mQKLP01?l0003oHfo9of=_bOl00002odmbeP03o`000?oooooooooo027ooooo00?o0000
ooooooooool02Oooool00005onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00004ooooo`;o0000=oooool4o`0000;o=EK600?o0000oc1BaOl`D/D00ol`
D/D01Ol0003o;E75obeAaOl]DLGo000000OoG6:o00?o0000oemU`_mOIL801OmOIL800ol0003oHV[4
o`000006ohAh_P03o`000?n8OL3oR7g000OoR7g000Go0000ohf4a?n=Q<CoSHC4o`000006ojB@`003
o`000?nYUl?oZIO300OoZIO300?o0000ojnOaon_WlL00on_WlL00ol0003o`:g6ol2]aP06olJfbP03
o`000?o<`<ooc<3?00?oc<3?0_l00003om?<d`03o`000?oJfMOo000000?oh^OF0_oTl]D2on?jdP;o
g_k:1?l000001?nYii7ob?ZbomKn`OoPoLd2o`000003onC^e_oQh]Go000000;oemCE1?o@a]04olZk
c003o`000?o4/LSoa;7800?oa;7800?o0000okjYa?l000001?n`WL@2o`0000KoZiK10_l00005ojNA
_P04o`000?nGQl7oUhO1o`0000SoTh>o0_l00005oi1o_@05o`000?mkN<?oNgS3og]h`ol000002Omj
M<400ol0003oN7?0ogQc`003ogQc`003o`000?mOK/[o000000KoGfg900?o0000of5]b?mQKLP00_mQ
KLP00ol0003oHFg8o`000003of=_b@03o`000?m?L]Ko000002?ooooo00?o0000ooooooooool02Ooo
ool0027ooooo00?o0000ooooooooool0<oooool3o`0000?ooooo00Co3E7=o`000?leE/Ko00001?l`
D/D00ol0003o;E75obeAa@02obeAa@03obaBa_l0003oG6:o00CoG6:o00?o0000oemU`_mOIL801OmO
IL801Ol0003oHV[4of9Za?mRJ/Co000000CoQ7Rn00?o0000ohQm`?n8OL001on8OL000ol0003oSHC4
ohf4a002ohf4a003o`000?nTT<3oY93000;oY9300_l00008ojVG``;o00001_n_WlL2o`0000Koa[K:
00?o0000olc0coo<`<l00oo<`<l00ol0003odlcCom?<d`02om?<d`06o`000?oJfMOof]WGom[Ieol0
003oh^OF0_oTl]D2on?jdP;og_k:1Ol000000oo8n[;oe_k1on3mc@02o`000003onC^e_oQh]GohN;E
00;o00001?o@a]03olZkc0;o00001Oo4/LP01Ol0003o_ZW4okjYa?nnZLCo000000;o/9g400?o0000
oj^F`On[U/401On[U/400ol0003oYi6nojNA_P05ojNA_P03o`000?nGQl7o000000SoTh>o00?o0000
oi1o_On@Okd01_n@Okd00ol0003oNgS3o`000009ogYd`@03o`000?mhLl3oN7?000GoN7?000?o0000
oem]bOmOKLT01OmOKLT00ol0003oHFg8of5]b002of5]b0;o00001OmSKlT2o`0002Cooooo00?o0000
ooooooooool02?ooool0027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo00Co0000o`eA
cOl0003o00001?l`D/D00ol0003o;E75obeAa@02obeAa@;o;5;600Go0000oeaR_omLH[ooG6:oo`00
0008oemU`P05o`000?mRJ/CoHV[4of9Za?l000000on4N;h00ol0003oR7g0ohQm`007ohQm`003o`00
0?n=Q<CoSHC400CoSHC400Co0000ojB@`?nTT<3oY9302OnYUl<00ol0003o[io7ojnOa`05ojnOa`03
o`000?nfZLco000000Goa[K:00?o0000olc0coo<`<l00oo<`<l00ol0003odlcCom?<d`02om?<d`04
o`000?oJfMOof]WGom[Ie`;o00000_oTl]D2on?jdP?og_k:1?l000000oo8n[;oe_k1on3mc@02o`00
0006onC^e_oQh]GohN;Eo`000?oLem;o00000oo@a]03olZkc003o`000?o4/LSoa;7800?oa;780_l0
0004okjYa003o`000?n`WLCo000000KoZiK10_l00008ojNA_P;o00002?nCPkl00ol0003oT7nmoi1o
_@07oi1o_@;o00002OmjM<400ol0003oN7?0ogQc`006ogQc`003o`000?mOKLWoGfg900CoGfg900?o
0000of5]b?mQKLP01?mQKLP00ol0003oHfo9of=_b@04of=_b@03o`000?oooooooooo02;ooooo00?o
0000ooooooooool02?ooool0027ooooo0_l0000^ooooo`?o00002_ooool2o`eAc@03o`000?l`D/Go
<5;500;o<5;500?o0000obeAaOl]DLD00_l]DLD00ol0003o;5;6o`000003oeaR_`03o`000?mOIL;o
GfG200GoGfG200?o0000of9Za?mRJ/@00omRJ/@00ol0003oQ7Rno`000009ohQm`003o`000?n=Q<Co
SHC400GoSHC400?o0000ojB@`?nTT<002OnYUl<00ol0003o[io7ojnOa`05ojnOa`05o`000?nfZLco
]ZW<okJYc?l000000oo6]/X6olc0c`03o`000?oCc=?odlcC00;odlcC00Go0000om[IeooJfMOof]WG
o`000002omoWf@03o`000?oSn];oho[B00?og_k:00?oe?jnolKi[ol000000_l000000ooFo/7oh?g=
on3mc@02onC^eP;ohN;E00Ko0000omcGd_oLem;og=OBo`000?o@a]03olZkc003o`000?o4/LSoa;78
00?oa;7800?o0000okjYa?nnZL@01?nnZL@2o`0000KoZiK100?o0000ojNA__nWTKh01onWTKh00ol0
003oY8blo`000007oi>3_`03o`000?n@OkgoT7nm00OoT7nm00?o0000ohil^ol000002?mjM<400ol0
003oN7?0ogQc`006ogQc`003o`000?mhL[oo000000GoGfg900?o0000of5]b?mQKLP01?mQKLP2o`00
00GoHfo900?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003o
ooooooooo`0Zooooo`?o00003Oooool01?l0003o3E7=o`9<b_l00003oc1Ba@03o`000?l]DLGo;E75
00;o;E7500Ko0000obaBa_l/D/Ko0000oeaR_ol00008oemU`P03o`000?mRJ/CoHV[400CoHV[400?o
0000ohQm`?n8OL001on8OL000ol0003oSHC4ohf4a007ohf4a003o`000?nYUl?oZIO300OoZIO300?o
0000ojnOaon_WlL01On_WlL00ol0003o]ZW<okJYc002okJYc003o`000?o6]/[oa[K:00Koc<3?00?o
0000om?<dooCc=<00_oCc=<01Ol0003of]WGom[IeooJfMOo000000;ognOI00Co0000on;cf?l0003o
00000_oNo/X01_oDo[koa_V_okO`Wol0003o[n^Ho`0000;oh?g=0_oTk]H2on7Re@04o`000?oLem;o
g=OBomcGdP;o00000oo:^l`5olBab0;o00001_nnZL@00ol0003o^Z;1o`000005oj^F`@03o`000?nW
TKkoYi6n00KoYi6n0_l00003ojB<_003o`000?nCPkooTh>o00;oTh>o0_l00009oi1o_@05o`000?n>
O;_oSWbkohil^ol000001_mjM<400ol0003oN7?0ogQc`006ogQc`005o`000?mhL[ooN7:oogQb_ol0
00000omOKLT00ol0003oHFg8of5]b004of5]b004o`000?mSKlWoHfo9o`0000?oHfo900?o0000oooo
ooooool08oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?o
00004?ooool01Ol0003o3E7=o`eAcOl2C<[o000000;o<5;500?o0000obeAaOl]DLD00_l]DLD01Ol0
003o;5;6obaBa_l/D/Ko000000SoGfG200?o0000of9Za?mRJ/@01OmRJ/@00ol0003oR7g0ohQm`006
ohQm`003o`000?n=Q<CoSHC400OoSHC40_l00007ojVG``;o00001_n_WlL2o`0000Go]ZW<0_l00006
olc0c`CodlcC0_l00003om[Ie`04o`000?oOimWognOIo`0000;oh_?H00?o0000on3ldol000001?l0
00001?n_jiSob_Zdo`000?oPoLd2onC^eP;ohN;E00Oo0000omcGd_oLem;og=OBo`000?oFc<oo0000
00;ob[_<1Oo4/LP00ol0003o_ZW4okjYa004okjYa0;o00000_njX/401?l0003oZiK1oj^F`On[U/42
o`0000OoYi6n0_l00006ojB<_004o`000?nCPkooTh>oo`0000[oT7nm00?o0000ohil^on>O;/00on>
O;/00ol0003oNWC1ogYd`@02ogYd`@03o`000?mhLl3oN7?000KoN7?000?o0000ogQb_omhL[l00omh
L[l01?l0003oGfg9oem]bOl00006of5]b004o`000?mSKlWoHfo9o`0000?oHfo900?o0000oooooooo
ool08oooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Uooooo`?o0000
5?ooool01ol0003o3E7=o`9<b_l2C<[o0000oc1BaOl000001?l]DLD01Ol0003o;5;6obaBa_l/D/Ko
000000OoGfG200?o0000of9Za?mRJ/@01OmRJ/@00ol0003oIg38o`000006ohQm`003o`000?n=Q<Co
SHC400OoSHC400Co0000oi><b?nCS<So00001OnYUl<00ol0003o[io7ojnOa`05ojnOa`03o`000?nf
ZLco]ZW<00Co]ZW<00Co0000okfddOnm]=7o00001?o<`<l5om?<d`Cof]WG00Co0000omoWfOoOimWo
00000_oRlmP01?l0003oh?cCo`000?oHolP4o`000003ol[j]?oEo/7o000000;oi>kF0_oQh]D01Ol0
003og=OBomcGd_oLem;o000000;oe/c?0_l00005olBab003o`000?nnZLCo_ZW400?o_ZW40_l00005
okZR`@03o`000?n[U/7o000000SoYi6n00?o0000ojB<_?nTS;`01_nTS;`00ol0003oTh>oo`000009
oi1o_@;o00001_n>O;/01Ol0003oNWC1ogYd`OmjM<7o000000SoN7?000?o0000ogQb_omhL[l01Omh
L[l00ol0003oGfg9o`000005of5]b003o`000?mSKlWoHfo900;oHfo900?o0000of=_bOl000009_oo
ool00ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Rooooo`?o00005oooool0
0ol0003o3E7=o`000002o`9<bP;o00000ol]DLD00ol0003o;5;6obaBaP02obaBaP03obaEbOl0003o
GfG200GoGfG200?o0000of9Za?mRJ/@01?mRJ/@01Ol0003oIg38ofM`b?mWL<So000000CoR7g000?o
0000ohf4a?n=Q<@01on=Q<@00ol0003oThc8oi><b002oi><b003o`000?nYUl?oZIO300;oZIO31on_
WlL00ol0003o]ZW<okJYc004okJYc003o`000?nm]=7o_KCA00;o_KCA00?o0000olc0coo<`<l01OoC
c=<4om[Ie`04o`000?oOimWognOIo`0000;oh_?H00Co0000on3ldol0003of?o80_l000001On[jIGo
0000ol[j]?oEo/7o000000;oi>kF0_oQh]D3omcGdP;o00000_oFc<l00ol0003odL;<o`000004olBa
b003o`000?nnZLCo_ZW400?o_ZW400?o0000okZR`OnjX/401OnjX/42o`0000OoYi6n0_l00009ojB<
_0;o00002On@Okd00ol0003oSWbkohil^`07ohil^`03o`000?mjM<7o000000SoN7?000?o0000ogQb
_omhL[l01omhL[l00ol0003oHFg8of5]b004of5]b003o`000?mSKlWoHfo900?oHfo90_l0000Voooo
o`03o`000?oooooooooo00Sooooo000Pooooo`;o00008Oooool2o`0001[ooooo00?o0000o`eAcOl=
DLd00ol2C<X01Ol0003o;E75obeAaOl]DLGo000000Co;5;60_l/ELT00ol0003oGfG2oemU`P02oemU
`P03o`000?mRJ/CoHV[400GoHV[400Go0000ofM`b?mWL<SoIg38o`000003ohQm`003o`000?n=Q<Co
SHC400OoSHC400?o0000oi><b?nCS<P01?nCS<P00ol0003oZIO3ojVG``07ojnOa`03o`000?nfZLco
]ZW<00Co]ZW<00?o0000okfddOnm]=400onm]=42o`0000GodlcC1?oJfML01?l0003ognOIomoWfOl0
0002on;cf004o`000?oPo=?o0000omSob0Co000000Gob_ZdomGn`OoRnm;o0000onC^eP02on7Re@?o
g=OB00?o0000omK<cooFc<l00_l00002om72c004o`000?o4/LSoa;78olBab0Go_ZW40_l00007okZR
`@;o00001onWTKh00ol0003oY8blojB<_008ojB<_003o`000?nQRK[o000000SoT7nm00?o0000ohil
^on>O;/02?n>O;/2o`0000SoN7?000?o0000ogQb_omhL[l01omhL[l2o`0000GoHFg800?o0000of=_
bOmSKlT01OmSKlT00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo000Pooooo`03
o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?l=DLgo000000;o0Tc:00Go0000obeAaOl]
DLGo;E75o`000004obaBaP04o`000?l/ELWo;5G9o`0000?oGfG200?o0000of9Za?mRJ/@01?mRJ/@0
0ol0003oIg38ofM`b003ofM`b003o`000?n8OL3o000000WoSHC400?o0000oi><b?nCS<P01OnCS<P2
o`0000Ko[io70_l00006okJYc003o`000?nm]=7o_KCA00?o_KCA00?o0000olK2eol000001?oCc=<4
om[Ie`04o`000?oOimWognOIo`0000;oh_?H00Co0000on3ldol0003of?o81?l000000oo:n[CoeOk1
on;kdP02o`0000;ohN;E0ooLem801?l0003oe/c?omK<col00005om72c003o`000?o4/LSo_ZW400Co
_ZW400?o0000okZR`OnjX/401OnjX/42o`000003okJM__l0003oYi6n00CoYi6n0_l00009ojB<_0;o
00000onQRKX00ol0003oT7nmoi1o_@03oi1o_@;o00002_n>O;/00ol0003oSG^jo`000007ogQc`003
o`000?mhL[ooN7:o00OoN7:o00Co0000ogQb_omhL[oo00001?mQKLP00ol0003oHfo9of=_b@04of=_
b@;o00009oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o
00008?ooool00ol0003o3E7=o`eAc@03o`9<bP04o`000?l]DLGo;E75o`0000Co;5;600Oo0000obaE
bOl/ELWo;5G9o`000?mOIL;o000000KoHV[400?o0000ofM`b?mWL<P01OmWL<P00ol0003oSHC4ohf4
a007ohf4a003o`000?nCS<SoThc800GoThc800?o0000oiZEcOl000001On_WlL00ol0003o]ZW<okJY
c005okJYc003o`000?nm]=7o_KCA00?o_KCA00Go0000olK2eoo6`]Ooa/;Go`000002om?<d`Gof]WG
0ooOimT2on;cf004o`000?oPo=?o0000omSob0Go000000KoeOk1on;kd_l0003oi?CFo`000?oQh]D3
omcGdP04o`000?oFc<ooe/c?o`0000GodL;<0_l00004okjYa0;o00001onjX/400ol0003o]YfnokJM
_P02okJM_P03o`000?nWTKkoYi6n00;o00002_nTS;`00ol0003oXHVjoj69^P03oj69^P03o`000?n@
OkgoT7nm00;oT7nm00?o0000ohil^on>O;/02On>O;/01Ol0003oSG^johek^_n=Nk[o000000GoN7?0
00?o0000ogQb_omhL[l01omhL[l00ol0003oN7:oogQb_`02ogQb_`05o`000?mQKLSoHFg8of5]b?l0
00001_mSKlT00ol0003oooooo`00000Vooooo`03o`000?oooooooooo00Oooooo000Pooooo`?o0000
5oooool3o`0002?ooooo00Co0000o`eAcOl=DLgo00000_l2C<X01?l0B<Wo0000obeAaOl00004obaB
aP03o`000?l/ELWo;5G900;o;5G900?o0000of9Za?mRJ/@01OmRJ/@00ol0003oIg38ofM`b005ofM`
b003o`000?n=Q<CoSHC400KoSHC400?o0000oi><b?nCS<P01OnCS<P01Ol0003oVYG=oiZEcOnJULgo
000000Co[io71onfZL`00ol0003o_KCAokfdd@03okfdd@03o`000?o6`]Ooa/;G00?oa/;G0_l00004
om[Ie`?ognOI0_oRlmP00ol0003oh?cCo`000002omSob008ol_l^?l0003o0000o`000?oEo/7oh__B
o`000?oTm=H2o`0000?og=OB00Co0000omK<col0003o00001?oA`/`2o`000003olbjb?l0003o_ZW4
00;o_ZW400?o0000okZR`OnjX/401OnjX/42o`0000Go]Yfn00?o0000ojNA__l000002_nTS;`2o`00
00OoXHVj00Co0000oi1o_On@Okgo00002_n>O;/2o`0000CoSG^j00?o0000ogQc`?mhLl000_mhLl00
0ol0003oN7:oogQb_`07ogQb_`03o`000?mhL[ooN7:o00?oN7:o00Co0000of5]b?mQKLSo00001_mS
KlT01Ol0003ooooooooooooooooo000002Gooooo00?o0000ooooooooool01oooool001oooooo0_l0
000Fooooo`?o00009oooool00ol0003o3E7=o`000002o`9<bP04o`000?l0B<Wo0000o`0000?o;5;6
00?o0000obaEbOl/ELT00ol/ELT00ol0003oHV[4of9Za004of9Za003o`000?mWL<SoIg3800GoIg38
00?o0000ofeicOl000001_n=Q<@00ol0003oThc8oi><b005oi><b003o`000?nJULgoVYG=00?oVYG=
00?o0000ojnOaon_WlL01onfZL`00ol0003o_KCAokfdd@03okfdd@03o`000?o6`]Ooa/;G00?oa/;G
00Co0000olkAg?o>dMco00000_oJfML3omoWf@?oh_?H00Coh?cCo`000?oHolSof?o81?l000001ooE
o/7oh__Bo`000?oTm=Ko0000on;/eol000000_oLem82omK<c`03o`000?oA`/codL;<00?odL;<00?o
0000olbjb?o<^/P00_o<^/P00ol0003o_ZW4okZR`@06okZR`@;o00001onfWKh2o`0000WoY8bl0_l0
0009oj69^P03o`000?n@Okgo000000[oSWbk00?o0000ohek^_n=NkX01On=NkX01?l0003oN7?0ogQc
`?l00009ogQb_`03o`000?mhL[ooN7:o00GoN7:o00?o0000of5]b?l000001_mSKlT00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Go
oooo00?o0000ooooooooool04_ooool3o`0002[ooooo00Co0000o`eAcOl=DLgo00000_l2C<X2o`18
b@05o`000?l/D/Ko;5;6obaBa_l000001Ol/ELT00ol_Flgo0000of9Za003of9Za003o`000?mWL<So
Ig3800GoIg3800Go0000ofeicOm]NLgoKGW=o`000004ohf4a003o`000?nCS<SoThc800GoThc800?o
0000oiZEcOnJULd01OnJULd00ol0003o]ZW<okJYc005okJYc003o`000?nm]=7o_KCA00?o_KCA00?o
0000olK2eoo6`]L00oo6`]L00ol0003oc]7LolkAg002olkAg0;o00000_oOimT3on;cf0;oh?cC0_l0
00002Oo9o;go0000o`000?nAegko0000on;kd_l0003oi?CFo`000002on;/e`05o`000?oLem;oe/c?
omK<col000001?oA`/`2o`0000Coc;[80_l00006okZR`@;o00001onfWKh2o`000003ok>H_?l0003o
Y8bl00OoY8bl00?o0000oj69^_nQRKX02OnQRKX2o`0000WoSWbk0_l00008ohek^P03o`000?mhLl3o
000000WoN7:o00?o0000ogQb_omhL[l01omhL[l00ol0003oHfo9of=_b@04of=_b@03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03oooool3o`0002gooooo00Co0000o`eAcOl=DLgo00000_l2C<X00ol0003o04S9o`00
0003obaBaP03o`000?l/ELWo;5G900?o;5G90_l_Fld01Ol0003oHV[4of9Za?mRJ/Co000000OoIg38
00Go0000ofeicOm]NLgoKGW=o`000003ohf4a003o`000?nCS<SoThc800GoThc800?o0000oiZEcOnJ
ULd01OnJULd00ol0003oXj7Co`000005okJYc003o`000?nm]=7o_KCA00?o_KCA00?o0000olK2eoo6
`]L00oo6`]L00ol0003oc]7LolkAg002olkAg003o`000?oFhMooe^7O00Oo000000OoeOo>o`000?l0
003o0000oi7GO_l0003oh__B00;oi?CF00?o0000on;/eooRk=L00_l00002omK<c`CodL;<0_l00005
olbjb003o`000?o7/lKo000000Co^Z;10_l00008okJM_P03o`000?ncV;co/iRl00;o/iRl00?o0000
ojB<_?nTS;`00onTS;`2o`0000[oXHVj0_l000000onOQ[Wo0000ohil^`07ohil^`03o`000?n=Nk[o
SG^j00SoSG^j0_l00009ogQb_`03o`000?mhL[ooN7:o00OoN7:o00?o0000ogUc`?l000001OmSKlT0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool0
00Cooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03?ooool3o`00037ooooo0_l000001?l=DLgo0000o`9<b_l00002o`18b@04o`000?l/
D/Ko;5;6o`0000Co;5G900Oo0000obmKcOl_Flgo;e_=o`000?mRJ/Co000000OoIg3800?o0000ofei
cOm]NLd00om]NLd00ol0003oSHC4o`000007oi><b003o`000?nJULgoVYG=00GoVYG=00Go0000oj>Q
donSXM?oXj7Co`000003okJYc003o`000?nm]=7o_KCA00?o_KCA00?o0000olK2eoo6`]L00oo6`]L0
0ol0003oc]7LolkAg002olkAg004o`000?oFhMooe^7Oo`0000?ofo3O00Co0000om_kf_l0003oeOo>
1?l000001Oo6o;coh__BonCde_oTm=Ko000000;oh^cG00Co0000omoSeol0003oe/c?1?oA`/`00ol0
003oc;[8olbjb003olbjb0;o00000_o7/lH01Ol0003o^Z;1okZR`OnjX/7o000000So]Yfn0_l00005
ok>H_003o`000?nTS;coY8bl00;oY8bl00?o0000oj69^_nQRKX02?nQRKX2o`0000CoWhJi00?o0000
ohil^on>O;/01?n>O;/00ol0003oSG^johek^P08ohek^P03o`000?n<N[[o000000SoN7:o00?o0000
ogQb_omhL[l01omhL[l01Ol0003oNG?0ogUc`?miLl3o000000CoHfo900?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooo
ooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00Co
0000o`UXg?l0003o00000_l2C<X01_l0003o04S9o`000?l0003o;5;6o`0000Co;5G900?o0000obmK
cOl_Fld00_l_Fld00ol0003oIg38ofM`b005ofM`b003o`000?m]NLgoKGW=00GoKGW=00?o0000oi><
b?nCS<P01OnCS<P00ol0003oVYG=oiZEc@05oiZEc@03o`000?nSXM?oXj7C00?oXj7C00?o0000okJY
c?nfZL`01Onm]=400ol0003oa/;GolK2e`03olK2e`03o`000?o>dMcoc]7L00;oc]7L00Co0000omKQ
gooFhMoo00000ooKl=l01?l0003ofo_Jo`000?oEolh4o`000006olKl_?oRnm;oi?CFonCde_l0003o
h^cG0_l000000ooOhmOo0000o`000003om72c0;o00001?o<^/P2o`0000Goak?60ol00007okJM_P;o
00001oncV;`00ol0003oY8blojB<_002o`0000[oXHVj00?o0000oin6^OnOQ[T01?nOQ[T00ol0003o
SWbkohil^`02ohil^`;o00002_n=NkX01Ol0003oS7Zjohaj^_n<N[[o000000KoN7:o00?o0000ogQb
_omhL[l01omhL[l00ol0003oNG?0ogUc`003ogUc`004o`000?mSKlWoHfo9o`0000Wooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Kooooo0ol0
000hooooo`03o`000?l9J=co000000;o0Tc:00Co0000o`18bOl0003o04S80_l00004obaEb@03o`00
0?l_Flgo;e_=00;o;e_=00?o=6?Co`000?mWL<P01OmWL<P00ol0003oKGW=ofeic@05ofeic@03ogB3
dol0003oThc800CoThc800?o0000oiZEcOnJULd01OnJULd00ol0003oXj7Coj>Qd`05oj>Qd`03o`00
0?nm]=7o_KCA00?o_KCA00?o0000olK2eoo6`]L00oo6`]L00ol0003oc]7LolkAg002olkAg004o`00
0?oFhMooe^7Oo`0000?ofo3O00Co0000om_kf_l0003oeOo>1?l000001?o6o;co0000onCde_oTm=H2
on;/e`06o`000?oOhmOogn?Go`000?oKf]Go00000_oA`/`00ol0003oc;[8olbjb003olbjb003o`00
0?o7/lKoak?600Coak?60_l00008okJM_P03o`000?ncV;co/iRl00So/iRl0_l0000:oj69^P;o0000
2?nOQ[T01?l0003oSWbkohil^ol0000:ohek^P;o00001On<N[X00ol0003oN7:oogQb_`02ogQb_`03
o`000?mhL[ooN7:o00OoN7:o00?o0000ogUc`?miLl001OmiLl000ol0003oHfo9o`000009ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3o`0003co
oooo00Go0000o`UXg?l0003o0Tc:o`000002o`18b@03o`000?l0B<So000000Co;5G900?o0000obmK
cOl_Fld00_l_Fld2ocASd`03o`000?mWL<SoIg3800;oIg3800?o0000ofeicOm]NLd01Om]NLd01?l0
003oM8?CogB3dol00003oi><b003o`000?nJULgoVYG=00GoVYG=00?o0000oj>QdonSXM<01OnSXM<0
0ol0003o[:oJo`000003okfdd@03o`000?o6`]Ooa/;G00?oa/;G00?o0000olkAg?o>dM`00_o>dM`0
1?l0003oe^7OomKQgol00003om_`g`04o`000?oKnm[o0000omGocPCo000000Goa_blo`000?oTm=Ko
i?CFon;/e`02o`000003omoSeol0003o000000;ofm[E00?o0000om72c?o<^/P01?o<^/P2o`0000Go
ak?60_l000000oo3[L?o0000okJM_P05okJM_P;o00002_ncV;`2o`0000WoXHVj0_l0000:oin6^@03
o`000?n>O;_o000000[oSG^j00?o0000ohaj^_n<N[X01On<N[X01Ol0003oN7:oogQb_omhL[oo0000
00WoN7:o00?o0000ogUc`?miLl001omiLl000ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01_ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooooooo0ol00010ooooo`?o000000Oo0Tc:
o`000?l0B<Wo0000o`18b?l0Bl[o000000?o;5G900?o0000obmKcOl_Fld00_l_Fld01?l0003o=6?C
ocASdol00003ofM`b003o`000?m]NLgoKGW=00CoKGW=00?o0000ogB3domdPm<00_mdPm<00ol0003o
Thc8o`000007oiZEc@03o`000?nSXM?oXj7C00GoXj7C00Go0000ojb_f_n/[m[o[:oJo`000002okfd
d@Goa/;G00?o0000olkAg?o>dM`00_o>dM`01?l0003oe^7OomKQgol00003om_`g`04o`000?oKnm[o
0000omGocPCo000000Koa_blomCodOl0003oi?CFon;/eol00002omoSe`04o`000?oKf]Gofm[Eom_J
e@;o00001Oo<^/P00ol0003oak?6olNcaP03olNcaP;o00000oo3[L<00ol0003o]YfnokJM_P02okJM
_P;o00002_ncV;`2o`000003ok2E^ol0003oXHVj00KoXHVj0_l0000<oin6^@;o00002On=NkX2o`00
00WoS7Zj00?o0000ogQb_ol000002OmhL[l00ol0003oNG?0ogUc`007ogUc`003o`000?oooooooooo
00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`Co0000A?ooool4o`0000;o04S900Ko0000o`18
b?l0Bl[o0000obaEbOl00005obmKc@07o`000?ldHm?o=6?CocASdol0003oIg38o`000007ofeic@03
o`000?mdPm?oM8?C00?oM8?C00?o0000oiZEcOnJULd01OnJULd00ol0003oXj7Coj>Qd`05oj>Qd`03
o`000?n/[m[o[:oJ00?o[:oJ0_l00004olK2e`03o`000?o>dMcoc]7L00;oc]7L00Co0000omKQgooF
hMoo00000ooKl=l00ol0003ofo_Jo`000005o`000006olKl_?oDom7o0000onCde_oRk=Oo00000_oO
hmL00ol0003ofm[Eom_Je@02o`000003omOAdol0003oc;[800;oc;[80_l00004olNcaP;o00001_o3
[L<01?l0003o]YfnokJM__l00009ok>H_0?o00001?n`UK/00ol0003oXHVjoj69^P02oj69^P;o0000
3?nOQ[T2o`000003oif4^?l0003oSG^j00OoSG^j00?o0000ohaj^_n<N[X02On<N[X2o`0000WoN7:o
00?o0000ogUc`?miLl001omiLl000ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01_ooool001kooooo0_l00017ooooo`?o00000_l0B<T01?l0003o04S8o`00
0?l0BlX2o`0000Go;e_=00?o0000ocASdoldHm<00_ldHm<00ol0003oKGW=ofeic@05ofeic@03o`00
0?mdPm?oM8?C00CoM8?C00?oOY3Ko`000?nJULd01?nJULd00ol0003oXj7Coj>Qd`05oj>Qd`03o`00
0?n/[m[o[:oJ00Co[:oJ00Co0000okJohOl0003o00000_o6`]L4olkAg004o`000?oFhMooe^7Oo`00
00?ofo3O00?o0000om_kf_oKnmX01Ol000001oo6o;coe?oAo`000?l0003oh^cGo`000?oOhmL00_l0
0002om_Je@05o`000?oGdM?oem7ComOAdol000000_o<^/P00ol0003oak?6olNcaP02olNcaP;o0000
2?o3[L<3o`0000So/iRl0_l00007ok2E^`05o`000?nQRK[oXHVjoj69^_l000003?nOQ[T2o`0000Co
WHBh00?o0000ohek^_n=NkX01?n=NkX00ol0003oS7Zjohaj^P09ohaj^P03o`000?n;NK[o000000So
N7:o00?o0000ogUc`?miLl001omiLl000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0AOooool4o`000003o`18
bOl0003o04S800;o04_:00?o0000obmKcOl_Fld00_l_Fld00ol0003o=6?CocASd`03ocASd`03o`00
0?m]NLgoKGW=00CoKGW=00?o0000ogB3domdPm<01?mdPm<01?l0003oOY3Kogj@fol00003oiZEc@03
o`000?nSXM?oXj7C00GoXj7C00?o0000ojb_f_n/[mX01?n/[mX00ol0003o][oQokJoh@02okJoh@?o
00000_o>dM`01?l0003oe^7OomKQgooFhMl3om_`g`?o000000?oc?o@o`000?l000000_l000001Oo6
o;coe?oAo`000?oHo]So000000;ogn?G00?o0000om_JeOoKf]D00_l00004omOAd`03o`000?o<^/So
ak?600Coak?600?o0000ol>]`oo3[L<01oo3[L<2o`0000So/iRl0_l00009ok2E^`04o`000?nQRK[o
0000o`0000_oWhJi0_l00006oif4^003o`000?n=Nk[oSG^j00;oSG^j0_l0000:ohaj^P;o00000on;
NKX00ol0003oN7:oogQb_`04ogQb_`03o`000?miLl3oNG?000OoNG?000?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo04Gooooo0_l000002?l0HmOo0000o`000?l0B<So0000o`1;b_l0DLko00000ol_Fld00ol0003o
=6?CocASd`03ocASd`03oc]_f_l0003oKGW=00?oKGW=00?o0000ogB3domdPm<01?mdPm<00ol0003o
OY3Kogj@f`02ogj@f`03o`000?nJULgo000000OoXj7C00?o0000ojb_f_n/[mX01?n/[mX00ol0003o
][oQokJoh@02okJoh@04o`000?o1dNKo`M7Vol7AiP[o000000CodOgOo`000?l0003o/OFe1ol00002
omoSe`04o`000?oKf]Go0000o`0000Goem7C0_l00004olNcaP;o00002?o3[L<2o`000003ol2X`_l0
003o/iRl00Go/iRl0_l0000;ok2E^`;o00002onOQ[T2o`0000WoWHBh00Co0000ohek^_n=Nk[o0000
2on<N[X00ol0003oRgVjoh]i^P04oh]i^P03o`000?mhL[ooN7:o00;oN7:o00?o0000ogUc`?miLl00
1omiLl000ol0003oooooooooo`0Booooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
1Oooool002;ooooo00?o0000ooooooooool0A?ooool01Ol0003o2FSLo`000?l0HmOo000000;o04S8
00Co0000o`1;b_l0DLko00000_l_Fld00ol0003o=6?CocASd`02ocASd`04o`000?lkKm[o>foJo`00
00?oKGW=00?o0000ogB3domdPm<01?mdPm<00ol0003oOY3Kogj@f`03ogj@f`;o00001_nSXM<00ol0
003o[:oJojb_fP04ojb_fP03o`000?nf_n7o][oQ00;o][oQ00?o0000ol7Ai_o1dNH00oo1dNH01?l0
003ob^?Yol[SjOl00002om7bj003o`000?oAoMoodOgO00;o000000?o/OFeo`000?l000000_l00000
1_oHo]So0000omWjg_l0003ogn?Gom_Je@;o00001OoGdM<2o`000004om?9dOl0003oak?6olNcaP;o
00001oo3[L<3o`0000?o`:S200Co0000ok>H_?ncV;co/iRl0ol0000:ok2E^`?o000000?o[I:jo`00
0?nOQ[T02OnOQ[T00ol0003oWHBhoif4^009oif4^003o`000?n=Nk[o000000[oS7Zj0_l00007oh]i
^P05o`000?mhL[ooN7:oogQb_ol000002OmiLl000ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01Oooool002?ooooo0_l00015ooooo`04o`000?l9J=co0000
o`1Se`?o000000Ko04_:o`000?l0DLko0000obmKcOl00004ocASd`07o`000?lkKm[o>foJoc]_f_l0
003oKGW=o`000006ogB3d`03o`000?mnT=_oOY3K00CoOY3K0_n8Wn<2o`0000?oXj7C00?o0000ojb_
f_n/[mX01?n/[mX00ol0003o][oQokJoh@02okJoh@03o`000?o1dNKo`M7V00?o`M7V00Co0000ol[S
jOo:hnWo00000_oAl^P00ol0003odOgOom7mg`09o`000005omWjg_l0003ogn?Gom_JeOl000001OoG
dM<2o`0000?odlWA00?o0000olNca_l000001oo3[L<2o`0000Oo`:S20ol0000;ok2E^`;o00001On]
T[X00ol0003oWhJioin6^@05oin6^@;o00003?nMQ;P2o`0000[oS7Zj00?o0000oh]i^_n;NKX02?n;
NKX00ol0003oN7:oo`000009ogUc`003o`000?oooooooooo01Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`05ooooo`009Oooool00ol0003oooooooooo`13ooooo`05o`000?l9J=co
0000o`1Seol0Gm800_l000000ol0Bl[o057>o`1AcP02o`0000Co=6?C00?o0000oc]_f_lkKmX00_lk
KmX2o`0000KoM8?C00?o0000ogj@fomnT=/00omnT=/00ol0003oR9oSohROh`02ohROh`03o`000?nS
XM?o000000Ko[:oJ00?o0000okJohOnf_n400_nf_n400ol0003o`M7Vol7AiP03ol7AiP04o`000?o:
hnWob^?Yo`0000;odO;X00Go0000om7mgooAoMoo0000ok[lbP04o`000004omSnf?l0003ofO[NomWj
gP?o00001OoGdM<2o`0000CodlWA0_l00007ol>]``;o00002?o0Z<82o`0000_o/9Fk0_l00007ojfB
^P03o`000?nOQ[WoWhJi00?oWhJi0_l0000<oif4^0;o000000?oW8>ho`000?n<N[X02?n<N[X00ol0
003oRgVjoh]i^P09oh]i^P;o00002OmiLl000ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o0000ooooooooool0@oooool02?l0003o
2FSLo`000?l0HmOo05oBo`000?l0Bl[o00000_l0DLh00ol0003o=6?CocASd`02ocASd`03o`000?lk
Km[o>foJ00;o>foJ0_m5ON<00ol0003oM8?CogB3d`02ogB3d`03o`000?mnT=_oOY3K00?oOY3K00?o
0000ohROhon8Wn<01?n8Wn<2o`0000Go[:oJ00?o0000okJohOnf_n400_nf_n400ol0003o`M7Vol7A
iP03ol7AiP04o`000?o:hnWob^?Yo`0000;odO;X00Go0000om7mgooAoMoo0000ok[lbP05o`0000;o
fO[N1?l00003omOAd`?o00000ooCbM43o`000003olk3col0003o`jg300Co`jg30_l00007ol2X`P?o
000000?o_:C0o`000?n`UK/01on`UK/3o`0000Wo[I:j00Co0000oin6^OnOQ[WoWhJi0_l0000<oif4
^0;o00001?nLPkP00ol0003oS7Zjohaj^P04ohaj^P;o00002on;NKX00ol0003oRgZko`000008ogUc
`003o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05oooo
o`009oooool00ol0003oooooooooo`13ooooo`0;o`000?l9J=co0000o`1Seol0Gm;o0000o`1;b_l0
003o057>o`1Kdol000000oldHm<00ol0003o>foJoc]_fP02oc]_fP?oAGgS00Co0000ogB3domdPm?o
00001_mnT=/00ol0003oR9oSohROh`04ohROh`03o`000?nE/N_o000000?o[:oJ00?o0000okJohOnf
_n400_nf_n400ol0003o`M7Vol7AiP03ol7AiP04o`000?o:hnWob^?Yo`0000;odO;X00Go0000om7m
gol0003o0000ok[lbP03o`000003omSnf?l0003ofO[N00Co00000ooGdM<2o`0000CodlWA0_l00004
olk3c`03o`000?o3[L?o`jg300?o00001oo0Z<82o`0000Co_:C000?o0000ok2E^on`UK/01?n`UK/2
o`0000go[I:j0ol0000<oif4^0;o00001_nLPkP00ol0003oS7Zjohaj^P03ohaj^P03o`000?n;NK[o
RgVj00WoRgVj0_l00003oh]j^`03o`000?miLl3oNG?000CoNG?000?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Xooooo`;o0000A?ooool01?l0
003o2FSLo`000?l0HmL3o`0000;o057>00Co05_Co`000?ldHm?o00001OlkKmX01ol0003oAGgSodEm
hom5ON?o0000ogB3dol000001OmnT=/00ol0003oR9oSohROh`04ohROh`07o`000?nE/N_oUK7[oiFa
jol0003o[:oJo`000004okJoh@03o`000?o1dNKo`M7V00?o`M7V00Co0000ol[SjOo:hnWo00000_oA
l^P9o`000007omWjg_l0003o0000omWdhOl0003oenkSo`000002omOAd`04o`000?oCbM7odlWAom?9
d@?o00001_o>`ll00ol0003o`jg3o`000007ol2X`P?o00001onlY<001?l0003o/9Fkok2E^on`UK/2
o`0000ko[I:j0_l0000<oif4^0;o00002OnLPkP00ol0003oS7Zjohaj^P02o`0000_oRgVj00?o0000
oh]j^on;N[/01?n;N[/00ol0003oNG?0ogUc`002ogUc`003o`000?oooooooooo01cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`12oooo
o`?o000000Oo06?Go`000?l0Bl[o0000o`1Ac_l0003o05_C00;o00001OlkKmX00ol0003oAGgSodEm
h`02odEmh`;o00001?mnT=/00ol0003oR9oSohROh`04ohROh`03o`000?nE/N_oUK7[00?oUK7[0ol0
0002okJoh@03o`000?o1dNKo`M7V00?o`M7V00?o0000ol[SjOo:hnT01?l00002okongP;o000000Co
XO6io`000?l0003ofO[N0_l000001ooIm>7o0000omO^hooGk^?o0000omOAdol000000_oCbM43o`00
00Ooc/??0ol00007ol2X`P;o00002_nlY<04o`0000go[I:j0ol000000on[T;Wo0000oif4^009oif4
^0;o00002onLPkP00ol0003oS7Zjo`00000;oh]i^P;o00001on;N[/01Ol0003oNG?0ogUc`?miLl3o
0000023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`00:oooool00ol0
003oooooooooo`13ooooo`03odVOm_l0003o000000;o00000_l0DLh01?l0003o05_Co`000?l00003
oc]_fP03o`000?m5ON?oAGgS00?oAGgS0_mASn`01Ol0003oOY3Kogj@fomnT=_o000000KoR9oS00?o
0000oiFajonE/N/00onE/N/00ol0003oX/Gboj;5lP05o`0000;o`M7V1Ol00002okohk@04o`000?no
o]ko0000oj7a^@?o000000CofO[No`000?oIm>7o00000ooGk^<2o`0000;odlWA0_l00007olk3c`?o
00000_o:_<d00ol0003o`:S2ol2X`P02ol2X`P?o00002onlY<02o`0000go[I:j0ol00005oj^@^@03
o`000?nMQ;SoWHBh00GoWHBh0_l0000=oib3^0;o00002on;NKX00ol0003oRgZkoh]j^`08oh]j^`03
o`000?miLl3o000002;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`00
;?ooool00ol0003oooooooooo`13ooooo`03o`000?m9WoKo000000Co000000?o05_Co`1YfOl0JMT0
0_l000000olkKm[o0000odEmh`04odEmh`06o`000?mASncoDHo/o`000?mnT=_o00001_n8Wn<00ol0
003oUK7[oiFaj`03oiFaj`03o`000?nRaO;oX/Gb00;oX/Gb00Co0000ojoIm_n_fOKo[mWf0ol00002
okW[m@03o`000?non>go_oS]00So000000CofOCQo`000?oGk^?oenkS0ol000001?oDi^?o0000om?9
dOl00006olk3c`?o00001Oo:_<d00ol0003o`:S2ol2X`P02o`0000_o_:C00ol000000onjX;oo0000
ojfB^P09ojfB^P?o00002?n[T;T00ol0003oWHBhoif4^003oif4^0;o00003?nLPkP3o`000003oi^3
^?l0003oRgVj00SoRgVj0_l0000;oh]j^`;o00008oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Cooooo000]ooooo`;o0000AOooool01om9WoKo0000o`000?l0003o057>o`000?l0
Fm<00ol0JMT2o`0000CoAGgS00?o0000oe6?k?mASn`00_mASn`2o`0000GoR9oS00?o0000oiFajonE
/N/00onE/N/00ol0003oX/Gboj;5lP02oj;5lP03o`000?n_fOKo[mWf00?o[mWf00Co0000okW[mOni
joGo00000_non>d2o`000003oj?fcOl0003oRn:R00;o000000?ofOCQo`000?oGk^<00ol00002omCV
h`;o00001_o>`ll3o`0000Oob[c=00Co0000ol2X`_l0003o00002_nlY<03o`0000Co^Z2o00?o0000
ojfB^_n]T[X01On]T[X3o`0000_oZi2i00Co0000oif4^?nMQ;SoWHBh0_l0000<oib3^0;o00001?nK
PkP00ol0003oRgVjoh]i^P06oh]i^P03o`000?n;N[_oRgZk00[oRgZk00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo000_ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ocVRm?l000000_l00002o`1Kd`?o06WI0_l00003odEmh`03o`000?mASnco
DHo/00;oDHo/0_mOY?D2o`0000?oR9oS00?o0000oiFajonE/N/00_nE/N/00ol0003oX/Gboj;5lP02
oj;5lP03o`000?n_fOKo[mWf00?o[mWf00Co0000okW[mOnijoGo00000onon>d6o`000004omWdhOoG
k^?o0000o`0000;oe>KS0ol000000oo@gn?o0000olk3c`02olk3c`?o00002?o:_<d3o`0000[o_:C0
0ol00008okZP_`04o`000?n]T[[o[I:jojfB^P?o00003on[T;T3o`0000coW8>h0_l00007oi^3^003
o`000?n;NK[oRgVj00?oRgVj0_l0000;oh]j^`;o0000:?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?ooooo1ol00002o`1Yf@03o`00
0?l7N^7o000000;oAGgS00?o0000oe6?k?mASn`00_mASn`01ol0003oGjCeoenTmOmOY?Go0000ohRO
hol000001OnE/N/01Ol0003oX/Gboj;5l_nRaO;o000000Go[mWf00Ko0000okW[mOnijoGo^N_eo`00
0?non>d7o`000004omO^hol0003o0000omCVh`?o00000oo@gn<00ol0003oc/??olk3c`02o`0000Oo
b[c=1?l00002olNgc003o`000?nlY<3o_:C000Go_:C00ol0000;okZP_`Co00004On[T;T2o`0000_o
W8>h0ol00009oi^3^003o`000?n;NK[oRgVj00;oRgVj00?o0000oh]j^on;N[/02On;N[/2o`0002_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`0004Gooooo
00?o0000odVOm_liX_@00ol00002o`1Yf@04o`000?l7N^7o0000o`0000GoDHo/00?o0000oenTmOmO
Y?D00_mOY?D4o`0000;oUK7[00?o0000oj;5l_nRaO800_nRaO800ol0003o[mWfojoImP02ojoImP04
o`000?nijoGo^N_eokW[m@?o000000?oXOKQo`000?l000000_l000001?oGk^?o0000omCVhooDi^<2
o`0000Cod=oS1?l00006olZlc@Co00001_o7]l`00ol0003o_:C0okbT`002okbT`0?o00003?njX;l3
o`00017oZi2i0ol000000onYS[Wo0000oib3^008oib3^0;o00003?nKPkP00ol0003oRgVjoh]i^P02
o`0000_oRgZk00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00?ooooo000cooooo`03o`000?oooooooooo04?ooooo0_l000001_m9WoKo0000o`000?l0003o
06WIo`0000;o1g[Q0_l00003oe6?k003o`000?mOY?GoGjCe00?oGjCe1?m`^_`4o`0000;oX/Gb00?o
0000ojoIm_n_fOH00_n_fOH00ol0003o^N_eo`000002o`0000;oXOKQ0ol000000on/n>Wo0000omCV
h`02omCVh`03o`000?o@gn?od=oS00Go00000_o<f>800ol0003ob[c=olZlc@02olZlc@?o00002_o7
]l`00ol0003o_:C0o`000002o`0000_o^Z2o1?l00002okNN_P03o`000?n[T;WoZi2i00coZi2i0ol0
0005ojV>^@03o`000?nLPkSoW8>h00CoW8>h0_l0000?oi^3^0;o00002on;N[/2o`0002oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?ooool00ol0003oooooooooo`14
ooooo`03o`000?m9WoKo000000;o000000Co06WIo`000?l7N^7o1g[Q1Ol00005oenTm@03o`000?m`
^_coL;[l00;oL;[l00?o0000oh7@oon1d?l02Ol00002oi[`lPCo000000KoKmFQo`000?l0003oe>KS
o`000?o@gn<4o`0000Koc=SR00?o0000olZlcOo:_<d00ol0000;olNgc0Co00002onjX;l3o`0000Ko
]ijn00?o0000oj^@^On[T;T02On[T;T3o`0000SoZHji00Co0000oib3^?nLPkSoW8>h0ol0000@oi^3
^0;o00002on;N[/00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool003Gooooo00?o0000ooooooooool0A?ooool00ol0003oBIofodVOmP03o`0000?o
1g[Q00?o0000oaJ?iolFSnL00_l00003oenTm@03o`000?m`^_coL;[l00;oL;[l00?o0000oh7@oon1
d?l00_n1d?l00ol0003oSn?lohoSo002ohoSo004o`000?nJl?;oV_3boi[`lP;o000000?oONBoo`00
0?l000000_l000001?o@gn?o0000o`000?l00007olcHhPGo00002_o7]l`5o`0000;o`k?;00?o0000
okZP_onjX;l01_njX;l4o`0000Wo]ijn00?o0000oj^@^On[T;T01_n[T;T3o`0000_oZHji00Co0000
oib3^?l0003o00004?nKPkP3o`000003oiZ3^Ol0003oRgZk00SoRgZk0_l0000dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool003Kooooo0_l00015ooooo`;o000000?oBIof
o`000?l000001Ol000000olFSnOo0000obVUk002o`000003oenTmOl0003oL;[l00?oL;[l00?o0000
oh7@oon1d?l00_n1d?l01Ol0003oSn?lohoSo?n?hoco000000;oV_3b2?l00005olcHhPOo00000oo8
dN400ol0003oakO<olNgc004olNgc0Go00001oo3/l/00ol0003o^Z2ookZP_`02okZP_`Co00003_ng
W[h00ol0003oZi2ioj^@^@02oj^@^@?o00003OnYS[T3o`0000ooVh>h0ol00005oiZ3^@03o`000?n;
N[_oRgZk00GoRgZk00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00?ooooo000hooooo`03o`000?oooooooooo04Cooooo00Oo0000odVOm_m9WoKo0000od2P
mOl0003o08W:00Co00000olYYN`3o`0000;oL;[l00Go0000oh7@oon1d?ooPM3oo`000002ohoSo0So
00000_nVj_X01?l0003oc=SRolcHh_o<f>84o`0000Wob=7Q00Co0000olNgc?o7]lcoakO<1?l0000<
ol>cb`03o`000?njX;oo^Z2o00;o00004_ngW[h00ol0003oZi2io`000002o`0000goZHji0ol00002
ojR>^P03o`000?nKPkSoVh>h00_oVh>h0_l00008oiZ3^@03o`000?n;N[_oRgZk00?oRgZk0_l0000h
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool003Wooooo00?o0000oooo
ooooool0A?ooool;o`0000Co:JG/2_l000000omTfMco0000o`000007o`000003olcHh_l0003ob=7Q
00Wob=7Q2?l0000>ol>cb`Go00004_ngW[h5o`0000goZHji0ol00006ojR>^P03o`000?nKPkSoVh>h
00OoVh>h0ol0000;oiZ3^@03o`000?n;N[_oRgZk00;o0000>oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00?ooooo000jooooo`03o`000?oooooooooo04Gooooo00Co0000oiK0m?nF
`?CoU/3d0onHa_L2oi[<n@So000000?o?K[/o`000?l000000_mAc>L5o`0000CoXn?l00?o0000olSA
hOo8dN400_o8dN49o`0000Goa<_P00?o0000ol>cboo3/l/01oo3/l/7o`0000?o`:o:00?o0000okNN
__ngW[h02ongW[h6o`0000?o]Ibn00?o0000ojV>^OnYS[T02OnYS[T3o`0000WoZ8jj00?o0000oi^3
^?nKPkP01OnKPkP2o`0000koVX>i00?o0000oh]j^ol00000?_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo000kooooo`;o0000B?ooool01Ol0003oU/3doiK0m?nF`?Co0000
00;oV<Kg0_l00002oi[<n@Co00000_nMdo/6o`000003oj3Ko?l0003o000000;o000000Cob=7Qo`00
0?l0003o00003_o4bn000ol0003o`k?;ol>cb`02ol>cb`Ko00002_o0[lX00ol0003o]ijnokNN_P06
okNN_PGo00002OneW;h00ol0003oZHjiojV>^@06ojV>^@?o00003?nXS[X00ol0003oVh>hoi^3^002
oi^3^0?o00004?nJPkT2o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`00?Oooool00ol0003oooooooooo`17ooooo`?o00000_nF`?@2o`000004oiS6mol0003o0000
o`0000;oV/ci0ol00005oigCn`?o00000oo4bn0Bo`000003ol>cbol0003o0000017o`:o:00?o0000
okNN__ngW[h01_l0000?okFL_P03o`000?nYS[WoZHji00;oZHji0ol0000@ojR>^PCo00004?nJPkT3
o`0004;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00?_ooool00ol0
003oooooooooo`19ooooo`;o00000onF`?@2o`0000;oV<Kg0ol000000onJc?Wo0000o`000002o`00
00;oWM?k00?o0000oko6gonoa]l04onoa]l00ol0003o`:o:ol2_bP0=ol2_bPSo00005OneW;h00ol0
003oZHjio`000002o`00017oZ8jj0ol0000@oiZ3^@?o0000A_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo04[ooooo0_l00004oiK0m0?o
000000CoV<Kgo`000?l0003o00000_nJc?T2o`0000Go_lKO1_l0000:oko6g`03o`000?o0[l[o`:o:
00?o`:o:2ol00005okf]b@03o`000?neW;ko]Ibn017o]Ibn1_l0000@ojR>^PCo00000_nVSKX00ol0
003oVX>ioiZ3^@0;oiZ3^@?o0000B_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo0010ooooo`;o0000C?ooool3o`0000CoU/3d0ol000000onHa_Oo0000o`00000=okc1gP_o
000000?o`:o:o`000?l000000_l0000@okf]b@03o`000?neW;ko]Ibn00Wo]Ibn2?l00004ok>J_`03
o`000?nXS[[oZ8jj00_oZ8jj1?l00007ojJ=^P03o`000?nJPkWoVX>i00SoVX>i0_l0001=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool004;ooooo00?o0000ooooooooool0
C?ooool2o`0000GoU/3d00?o0000okRlgOnh_=d01?nh_=d7o`0000co_<7N00?o0000okf]bOnm[LT0
4onm[LT01?l0003o]IbnokFL__neW;h8o`0000co/iZo00?o0000ojR>^_nXS[X02?nXS[X3o`0000_o
YXfj00?o0000oiZ3^OnJPkT01OnJPkT3o`00053ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`00@oooool00ol0003oooooooooo`1=ooooo`?o000000?oU/3do`000?nd^M`0
0_nd^M`4o`0000Oo^;cM1ol00004okc1gP03o`000?nm[LWo_Jg900So_Jg94?l0000Eok>J_`03o`00
0?nXS[[oZ8jj00?oZ8jj1?l0000>ojJ=^P03o`000?nJPkWoVX>i00;oVX>i0ol0001Dooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0Cooo
ool00ol0003o];WLokBig007okBig0Go00002?nh_=d4o`000003okf]bOl0003o000000So00003?nj
Z/T00ol0003o/iZook>J_`0Fok>J_`03o`000?nXS[[o000000?o00004onVSKX4o`0005Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2o`0005;ooooo0_l0000:
okBig0Co00001onh_=d00ol0003o^Z[9okZZb@0EokZZb@03o`000?ncV[oo/iZo01;o/iZo1_l0000E
ojJ=^P?o0000Foooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0017oooo
o`03o`000?oooooooooo05Cooooo1Ol00006okBig0Go000000?o^;cMo`000?njZ/T05onjZ/T00ol0
003o/iZook>J_`09ok>J_`Wo00001?naV[l00ol0003oYXfjojJ=^P0?ojJ=^PGo0000Goooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo05So
oooo1Ol00006okBig0;o00000_njZ/T;o`0000_o^Z[900Co0000ok>J_oncV[oo/iZo2?l0000=ok6J
_`03o`000?nVSK[oYXfj00[oYXfj1Ol0001Uooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool004Wooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`02ooooo`Go
00000_nd^M`00ol0003o]jS:okNXbP0;okNXbPoo00005_naV[l00ol0003oYXfjojJ=^P04ojJ=^PGo
0000Joooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000
Eoooool00ol0003oooooooooo`07ooooo`;o00006OngZ<X00ol0003o/IZook6J_`0Gok6J_`03o`00
0?nVSK[o000000Co0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo
001<ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool03Oooool9o`0000co]jS:00?o
0000ok6J_onaV[l04OnaV[l8o`0007Kooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Ooo
ool004gooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Fooooo`Wo00000ongZ<X0
0ol0003o/IZook6J_`04ok6J_`go0000Ooooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00C_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01oooooo2_l0002<oooo
o`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001?ooooo`;o0000D_ooool00ol0003o
ooooooooo`2fooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`05ooooo`7o0000
0Oooool1ooooo`00D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0;Sooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool005?ooooo0_l0001>ooooo`03o`000?oooooo
oooo0;Sooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005Gooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oo
oooooooo0;_ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0_?ooool01Ol0003ooooooooooooooooo0000007ooooo001K
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0_Oooool01?l0003oooooooooool0
0001ooooo`00G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;kooooo00?o0000
ooooool000000Oooool005gooooo0_l00014ooooo`03o`000?oooooooooo0;kooooo00?o0000oooo
ooooool00Ol0000005oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2oooooo`7o
00000Oooool1o`000000H?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo
0_l00000067ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2oooooo`?o0000001R
ooooo`;o0000?oooool00ol0003oooooooooo`2kooooo`Co00000oooool006Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`2gooooo`Co00001oooool006Gooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`2cooooo`Co00002oooool006Kooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`2`ooooo`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oo
oooooooo0:cooooo1?l0000Booooo`00JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo0:Sooooo1?l0000Fooooo`00J_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
0:Cooooo1?l0000Jooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7o
oooo1?l0000Nooooo`00K?ooool2o`0003Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo
001^ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0UOooool4o`0002[ooooo001`oooo
o`;o0000<?ooool00ol0003oooooooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`2>ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`2:ooooo`Co0000=Oooool007Cooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`26ooooo`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooo
oooo08;ooooo1?l0000mooooo`00Moooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
07kooooo1?l00011ooooo`00N?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[o
oooo1?l00015ooooo`00NOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo
1?l00019ooooo`00N_ooool2o`0002Kooooo00?o0000ooooooooool0L_ooool4o`0004gooooo001l
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Koooool3o`00057ooooo001moooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o0000
8Oooool00ol0003oooooooooo`1Sooooo`Co0000G?ooool0087ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`1Oooooo`Co0000H?ooool008;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Kooooo`Co0000I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Gooooo`Co0000J?ooool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?o
oooo1?l0001/ooooo`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo
1?l0001`ooooo`00Qoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0
001dooooo`00R?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001g
ooooo`00ROooool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool0
0ol0003oooooooooo`0dooooo`Co0000Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0aooooo`Co0000Soooool0097ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0^ooooo`?o0000Toooool009;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo
1?l0002Fooooo`00U?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0
002Jooooo`00UOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002N
ooooo`00U_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Roooo
o`00Uoooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0
003oooooooooo`0;ooooo`?o0000]_ooool009kooooo00Co0000oooooooooooo00002Oooool4o`00
0;Wooooo002Oooooo`03o`000?oooooo000000Gooooo1?l0002mooooo`00X?ooool2o`000003oooo
ool0003o000000;o0000`Oooool00:7ooooo0_l00035ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .64193 m .51694 .65827 L .43899 .65168 L p .726 .625 .745 r
F P
0 g
s
.51694 .65827 m .51727 .64193 L .59239 .63529 L p .692 .579 .723 r
F P
0 g
s
.59239 .63529 m .59527 .65394 L .51694 .65827 L p .692 .579 .723 r
F P
0 g
s
.43899 .65168 m .4424 .63865 L .51727 .64193 L p .726 .625 .745 r
F P
0 g
s
.5176 .62535 m .51727 .64193 L .4424 .63865 L p .733 .63 .743 r
F P
0 g
s
.51727 .64193 m .5176 .62535 L .5895 .61638 L p .697 .58 .721 r
F P
0 g
s
.5895 .61638 m .59239 .63529 L .51727 .64193 L p .697 .58 .721 r
F P
0 g
s
.59527 .65394 m .59239 .63529 L .66415 .61899 L p .65 .539 .716 r
F P
0 g
s
.66415 .61899 m .67023 .63881 L .59527 .65394 L p .65 .539 .716 r
F P
0 g
s
.4424 .63865 m .44583 .62542 L .5176 .62535 L p .733 .63 .743 r
F P
0 g
s
.51793 .60873 m .5176 .62535 L .44583 .62542 L p .741 .636 .743 r
F P
0 g
s
.5176 .62535 m .51793 .60873 L .5866 .59745 L p .702 .584 .72 r
F P
0 g
s
.5866 .59745 m .5895 .61638 L .5176 .62535 L p .702 .584 .72 r
F P
0 g
s
.59239 .63529 m .5895 .61638 L .65805 .5989 L p .652 .539 .713 r
F P
0 g
s
.65805 .5989 m .66415 .61899 L .59239 .63529 L p .652 .539 .713 r
F P
0 g
s
.5895 .61638 m .5866 .59745 L .65197 .57884 L p .656 .541 .712 r
F P
0 g
s
.65197 .57884 m .65805 .5989 L .5895 .61638 L p .656 .541 .712 r
F P
0 g
s
.44583 .62542 m .44927 .61215 L .51793 .60873 L p .741 .636 .743 r
F P
0 g
s
.51826 .59228 m .51793 .60873 L .44927 .61215 L p .749 .644 .745 r
F P
0 g
s
.51793 .60873 m .51826 .59228 L .58371 .57877 L p .708 .59 .721 r
F P
0 g
s
.58371 .57877 m .5866 .59745 L .51793 .60873 L p .708 .59 .721 r
F P
0 g
s
.4424 .63865 m .43899 .65168 L .36521 .63435 L p .746 .68 .786 r
F P
0 g
s
.5866 .59745 m .58371 .57877 L .64589 .5591 L p .66 .546 .714 r
F P
0 g
s
.64589 .5591 m .65197 .57884 L .5866 .59745 L p .66 .546 .714 r
F P
0 g
s
.58082 .56058 m .58371 .57877 L .51826 .59228 L p .715 .598 .725 r
F P
0 g
s
.58371 .57877 m .58082 .56058 L .63984 .53995 L p .665 .552 .717 r
F P
0 g
s
.63984 .53995 m .64589 .5591 L .58371 .57877 L p .665 .552 .717 r
F P
0 g
s
.44927 .61215 m .45272 .59896 L .51826 .59228 L p .749 .644 .745 r
F P
0 g
s
.51859 .57619 m .51826 .59228 L .45272 .59896 L p .758 .655 .748 r
F P
0 g
s
.51826 .59228 m .51859 .57619 L .58082 .56058 L p .715 .598 .725 r
F P
0 g
s
.57794 .54313 m .58082 .56058 L .51859 .57619 L p .722 .609 .73 r
F P
0 g
s
.58082 .56058 m .57794 .54313 L .63382 .52166 L p .672 .561 .722 r
F P
0 g
s
.63382 .52166 m .63984 .53995 L .58082 .56058 L p .672 .561 .722 r
F P
0 g
s
.36521 .63435 m .37144 .62545 L .4424 .63865 L p .746 .68 .786 r
F P
0 g
s
.44583 .62542 m .4424 .63865 L .37144 .62545 L p .756 .688 .786 r
F P
0 g
s
.51859 .57619 m .51893 .56067 L .57794 .54313 L p .722 .609 .73 r
F P
0 g
s
.57507 .52663 m .57794 .54313 L .51893 .56067 L p .732 .623 .737 r
F P
0 g
s
.57794 .54313 m .57507 .52663 L .62784 .50449 L p .68 .574 .729 r
F P
0 g
s
.62784 .50449 m .63382 .52166 L .57794 .54313 L p .68 .574 .729 r
F P
0 g
s
.45272 .59896 m .45619 .586 L .51859 .57619 L p .758 .655 .748 r
F P
0 g
s
.51893 .56067 m .51859 .57619 L .45619 .586 L p .767 .669 .754 r
F P
0 g
s
.51893 .56067 m .51926 .54589 L .57507 .52663 L p .732 .623 .737 r
F P
0 g
s
.57221 .51129 m .57507 .52663 L .51926 .54589 L p .742 .64 .747 r
F P
0 g
s
.57507 .52663 m .57221 .51129 L .62189 .48866 L p .689 .59 .739 r
F P
0 g
s
.62189 .48866 m .62784 .50449 L .57507 .52663 L p .689 .59 .739 r
F P
0 g
s
.37144 .62545 m .37772 .61644 L .44583 .62542 L p .756 .688 .786 r
F P
0 g
s
.44927 .61215 m .44583 .62542 L .37772 .61644 L p .767 .699 .788 r
F P
0 g
s
.45619 .586 m .45966 .57341 L .51893 .56067 L p .767 .669 .754 r
F P
0 g
s
.51926 .54589 m .51893 .56067 L .45966 .57341 L p .778 .686 .762 r
F P
0 g
s
.51926 .54589 m .51959 .53202 L .57221 .51129 L p .742 .64 .747 r
F P
0 g
s
.56936 .49729 m .57221 .51129 L .51959 .53202 L p .755 .663 .759 r
F P
0 g
s
.57221 .51129 m .56936 .49729 L .61597 .47437 L p .701 .61 .752 r
F P
0 g
s
.61597 .47437 m .62189 .48866 L .57221 .51129 L p .701 .61 .752 r
F P
0 g
s
.37772 .61644 m .38402 .60738 L .44927 .61215 L p .767 .699 .788 r
F P
0 g
s
.45272 .59896 m .44927 .61215 L .38402 .60738 L p .777 .712 .791 r
F P
0 g
s
.45966 .57341 m .46313 .5613 L .51926 .54589 L p .778 .686 .762 r
F P
0 g
s
.51959 .53202 m .51926 .54589 L .46313 .5613 L p .791 .708 .773 r
F P
0 g
s
.64589 .5591 m .63984 .53995 L .69268 .51524 L p .61 .515 .722 r
F P
0 g
s
.63984 .53995 m .63382 .52166 L .68375 .4973 L p .615 .523 .727 r
F P
0 g
s
.68375 .4973 m .69268 .51524 L .63984 .53995 L p .615 .523 .727 r
F P
0 g
s
.65197 .57884 m .64589 .5591 L .70167 .53413 L p .606 .509 .718 r
F P
0 g
s
.69268 .51524 m .70167 .53413 L .64589 .5591 L p .61 .515 .722 r
F P
0 g
s
.63382 .52166 m .62784 .50449 L .6749 .48056 L p .622 .535 .736 r
F P
0 g
s
.6749 .48056 m .68375 .4973 L .63382 .52166 L p .622 .535 .736 r
F P
0 g
s
.65805 .5989 m .65197 .57884 L .71071 .55368 L p .603 .506 .716 r
F P
0 g
s
.70167 .53413 m .71071 .55368 L .65197 .57884 L p .606 .509 .718 r
F P
0 g
s
.62784 .50449 m .62189 .48866 L .6661 .46525 L p .63 .551 .747 r
F P
0 g
s
.6661 .46525 m .6749 .48056 L .62784 .50449 L p .63 .551 .747 r
F P
0 g
s
.66415 .61899 m .65805 .5989 L .71978 .5736 L p .602 .505 .717 r
F P
0 g
s
.71071 .55368 m .71978 .5736 L .65805 .5989 L p .603 .506 .716 r
F P
0 g
s
.51959 .53202 m .51992 .5192 L .56936 .49729 L p .755 .663 .759 r
F P
0 g
s
.56652 .48478 m .56936 .49729 L .51992 .5192 L p .77 .691 .776 r
F P
0 g
s
.56936 .49729 m .56652 .48478 L .61008 .46178 L p .715 .637 .769 r
F P
0 g
s
.61008 .46178 m .61597 .47437 L .56936 .49729 L p .715 .637 .769 r
F P
0 g
s
.67023 .63881 m .66415 .61899 L .72889 .59359 L p .601 .506 .719 r
F P
0 g
s
.71978 .5736 m .72889 .59359 L .66415 .61899 L p .602 .505 .717 r
F P
0 g
s
.72889 .59359 m .73799 .61332 L .67023 .63881 L p .601 .506 .719 r
F P
0 g
s
.62189 .48866 m .61597 .47437 L .65738 .45159 L p .641 .573 .762 r
F P
0 g
s
.65738 .45159 m .6661 .46525 L .62189 .48866 L p .641 .573 .762 r
F P
0 g
s
.38402 .60738 m .39036 .59834 L .45272 .59896 L p .777 .712 .791 r
F P
0 g
s
.45619 .586 m .45272 .59896 L .39036 .59834 L p .788 .728 .797 r
F P
0 g
s
.46313 .5613 m .46662 .54979 L .51959 .53202 L p .791 .708 .773 r
F P
0 g
s
.51992 .5192 m .51959 .53202 L .46662 .54979 L p .804 .734 .786 r
F P
0 g
s
.61597 .47437 m .61008 .46178 L .64871 .43975 L p .655 .6 .782 r
F P
0 g
s
.64871 .43975 m .65738 .45159 L .61597 .47437 L p .655 .6 .782 r
F P
0 g
s
.51992 .5192 m .52025 .50757 L .56652 .48478 L p .77 .691 .776 r
F P
0 g
s
.56368 .47388 m .56652 .48478 L .52025 .50757 L p .787 .726 .796 r
F P
0 g
s
.56652 .48478 m .56368 .47388 L .60421 .45104 L p .732 .671 .791 r
F P
0 g
s
.60421 .45104 m .61008 .46178 L .56652 .48478 L p .732 .671 .791 r
F P
0 g
s
.39036 .59834 m .39673 .58938 L .45619 .586 L p .788 .728 .797 r
F P
0 g
s
.45966 .57341 m .45619 .586 L .39673 .58938 L p .8 .748 .804 r
F P
0 g
s
.37144 .62545 m .36521 .63435 L .29943 .6068 L p .73 .734 .854 r
F P
0 g
s
.46662 .54979 m .47011 .53899 L .51992 .5192 L p .804 .734 .786 r
F P
0 g
s
.52025 .50757 m .51992 .5192 L .47011 .53899 L p .82 .766 .802 r
F P
0 g
s
.61008 .46178 m .60421 .45104 L .64009 .42986 L p .672 .636 .806 r
F P
0 g
s
.64009 .42986 m .64871 .43975 L .61008 .46178 L p .672 .636 .806 r
F P
0 g
s
.39673 .58938 m .40313 .58057 L .45966 .57341 L p .8 .748 .804 r
F P
0 g
s
.46313 .5613 m .45966 .57341 L .40313 .58057 L p .813 .771 .814 r
F P
0 g
s
.52025 .50757 m .52058 .49722 L .56368 .47388 L p .787 .726 .796 r
F P
0 g
s
.56084 .4647 m .56368 .47388 L .52058 .49722 L p .806 .77 .82 r
F P
0 g
s
.56368 .47388 m .56084 .4647 L .59836 .44225 L p .752 .715 .817 r
F P
0 g
s
.59836 .44225 m .60421 .45104 L .56368 .47388 L p .752 .715 .817 r
F P
0 g
s
.29943 .6068 m .30813 .60267 L .37144 .62545 L p .73 .734 .854 r
F P
0 g
s
.37772 .61644 m .37144 .62545 L .30813 .60267 L p .742 .75 .859 r
F P
0 g
s
.60421 .45104 m .59836 .44225 L .63152 .42205 L p .692 .683 .837 r
F P
0 g
s
.63152 .42205 m .64009 .42986 L .60421 .45104 L p .692 .683 .837 r
F P
0 g
s
.47011 .53899 m .4736 .52899 L .52025 .50757 L p .82 .766 .802 r
F P
0 g
s
.52058 .49722 m .52025 .50757 L .4736 .52899 L p .836 .805 .821 r
F P
0 g
s
.40313 .58057 m .40956 .57196 L .46313 .5613 L p .813 .771 .814 r
F P
0 g
s
.46662 .54979 m .46313 .5613 L .40956 .57196 L p .826 .799 .825 r
F P
0 g
s
.30813 .60267 m .31689 .59853 L .37772 .61644 L p .742 .75 .859 r
F P
0 g
s
.38402 .60738 m .37772 .61644 L .31689 .59853 L p .754 .769 .865 r
F P
0 g
s
.52058 .49722 m .52092 .48824 L .56084 .4647 L p .806 .77 .82 r
F P
0 g
s
.55801 .4573 m .56084 .4647 L .52092 .48824 L p .826 .824 .847 r
F P
0 g
s
.56084 .4647 m .55801 .4573 L .59251 .43549 L p .775 .77 .849 r
F P
0 g
s
.59251 .43549 m .59836 .44225 L .56084 .4647 L p .775 .77 .849 r
F P
0 g
s
.68375 .4973 m .6749 .48056 L .71366 .45599 L p .554 .508 .758 r
F P
0 g
s
.6749 .48056 m .6661 .46525 L .70244 .44224 L p .561 .525 .773 r
F P
0 g
s
.70244 .44224 m .71366 .45599 L .6749 .48056 L p .561 .525 .773 r
F P
0 g
s
.6661 .46525 m .65738 .45159 L .69133 .43013 L p .571 .549 .792 r
F P
0 g
s
.69133 .43013 m .70244 .44224 L .6661 .46525 L p .571 .549 .792 r
F P
0 g
s
.59836 .44225 m .59251 .43549 L .62296 .41639 L p .715 .743 .873 r
F P
0 g
s
.62296 .41639 m .63152 .42205 L .59836 .44225 L p .715 .743 .873 r
F P
0 g
s
.69268 .51524 m .68375 .4973 L .72497 .47119 L p .548 .495 .748 r
F P
0 g
s
.71366 .45599 m .72497 .47119 L .68375 .4973 L p .554 .508 .758 r
F P
0 g
s
.4736 .52899 m .47711 .51986 L .52058 .49722 L p .836 .805 .821 r
F P
0 g
s
.52092 .48824 m .52058 .49722 L .47711 .51986 L p .852 .851 .841 r
F P
0 g
s
.65738 .45159 m .64871 .43975 L .68031 .41983 L p .584 .581 .816 r
F P
0 g
s
.68031 .41983 m .69133 .43013 L .65738 .45159 L p .584 .581 .816 r
F P
0 g
s
.70167 .53413 m .69268 .51524 L .73639 .4876 L p .545 .486 .74 r
F P
0 g
s
.72497 .47119 m .73639 .4876 L .69268 .51524 L p .548 .495 .748 r
F P
0 g
s
.40956 .57196 m .41602 .56361 L .46662 .54979 L p .826 .799 .825 r
F P
0 g
s
.47011 .53899 m .46662 .54979 L .41602 .56361 L p .84 .831 .838 r
F P
0 g
s
.31689 .59853 m .3257 .59436 L .38402 .60738 L p .754 .769 .865 r
F P
0 g
s
.39036 .59834 m .38402 .60738 L .3257 .59436 L p .766 .79 .873 r
F P
0 g
s
.71071 .55368 m .70167 .53413 L .74791 .50497 L p .543 .48 .735 r
F P
0 g
s
.73639 .4876 m .74791 .50497 L .70167 .53413 L p .545 .486 .74 r
F P
0 g
s
.64871 .43975 m .64009 .42986 L .66937 .41149 L p .6 .623 .846 r
F P
0 g
s
.66937 .41149 m .68031 .41983 L .64871 .43975 L p .6 .623 .846 r
F P
0 g
s
.71978 .5736 m .71071 .55368 L .75951 .52302 L p .542 .477 .733 r
F P
0 g
s
.74791 .50497 m .75951 .52302 L .71071 .55368 L p .543 .48 .735 r
F P
0 g
s
.64009 .42986 m .63152 .42205 L .65849 .40521 L p .62 .677 .883 r
F P
0 g
s
.65849 .40521 m .66937 .41149 L .64009 .42986 L p .62 .677 .883 r
F P
0 g
s
.52092 .48824 m .52125 .48069 L .55801 .4573 L p .826 .824 .847 r
F P
0 g
s
.55516 .45172 m .55801 .4573 L .52125 .48069 L p .842 .888 .873 r
F P
0 g
s
.55801 .4573 m .55516 .45172 L .58666 .43079 L p .796 .838 .883 r
F P
0 g
s
.58666 .43079 m .59251 .43549 L .55801 .4573 L p .796 .838 .883 r
F P
0 g
s
.59251 .43549 m .58666 .43079 L .61441 .41291 L p .738 .817 .913 r
F P
0 g
s
.61441 .41291 m .62296 .41639 L .59251 .43549 L p .738 .817 .913 r
F P
0 g
s
.72889 .59359 m .71978 .5736 L .77118 .54146 L p .543 .478 .732 r
F P
0 g
s
.75951 .52302 m .77118 .54146 L .71978 .5736 L p .542 .477 .733 r
F P
0 g
s
.41602 .56361 m .42251 .55556 L .47011 .53899 L p .84 .831 .838 r
F P
0 g
s
.4736 .52899 m .47011 .53899 L .42251 .55556 L p .852 .868 .852 r
F P
0 g
s
.47711 .51986 m .48063 .51166 L .52092 .48824 L p .852 .851 .841 r
F P
0 g
s
.52125 .48069 m .52092 .48824 L .48063 .51166 L p .863 .903 .86 r
F P
0 g
s
.3257 .59436 m .33457 .59015 L .39036 .59834 L p .766 .79 .873 r
F P
0 g
s
.39673 .58938 m .39036 .59834 L .33457 .59015 L p .778 .815 .882 r
F P
0 g
s
.73799 .61332 m .72889 .59359 L .7829 .55999 L p .545 .481 .734 r
F P
0 g
s
.77118 .54146 m .7829 .55999 L .72889 .59359 L p .543 .478 .732 r
F P
0 g
s
.63152 .42205 m .62296 .41639 L .64766 .40107 L p .641 .746 .925 r
F P
0 g
s
.64766 .40107 m .65849 .40521 L .63152 .42205 L p .641 .746 .925 r
F P
0 g
s
.7829 .55999 m .79464 .57831 L .73799 .61332 L p .545 .481 .734 r
F P
0 g
s
.33457 .59015 m .3435 .58588 L .39673 .58938 L p .778 .815 .882 r
F P
0 g
s
.40313 .58057 m .39673 .58938 L .3435 .58588 L p .79 .843 .892 r
F P
0 g
s
.42251 .55556 m .42902 .54787 L .4736 .52899 L p .852 .868 .852 r
F P
0 g
s
.47711 .51986 m .4736 .52899 L .42902 .54787 L p .86 .908 .865 r
F P
0 g
s
.5808 .42816 m .58666 .43079 L .55516 .45172 L p .808 .914 .911 r
F P
0 g
s
.58666 .43079 m .5808 .42816 L .60586 .41162 L p .751 .899 .944 r
F P
0 g
s
.60586 .41162 m .61441 .41291 L .58666 .43079 L p .751 .899 .944 r
F P
0 g
s
.52125 .48069 m .52158 .47458 L .55516 .45172 L p .842 .888 .873 r
F P
0 g
s
.5523 .44795 m .55516 .45172 L .52158 .47458 L p .842 .951 .888 r
F P
0 g
s
.55516 .45172 m .5523 .44795 L .5808 .42816 L p .808 .914 .911 r
F P
0 g
s
.48063 .51166 m .48416 .50443 L .52125 .48069 L p .863 .903 .86 r
F P
0 g
s
.52158 .47458 m .52125 .48069 L .48416 .50443 L p .861 .955 .87 r
F P
0 g
s
.62296 .41639 m .61441 .41291 L .63686 .39909 L p .658 .827 .964 r
F P
0 g
s
.63686 .39909 m .64766 .40107 L .62296 .41639 L p .658 .827 .964 r
F P
0 g
s
.3435 .58588 m .3525 .58153 L .40313 .58057 L p .79 .843 .892 r
F P
0 g
s
.40956 .57196 m .40313 .58057 L .3525 .58153 L p .8 .873 .902 r
F P
0 g
s
.30813 .60267 m .29943 .6068 L .24558 .56996 L p .625 .746 .934 r
F P
0 g
s
.42902 .54787 m .43557 .54057 L .47711 .51986 L p .86 .908 .865 r
F P
0 g
s
.48063 .51166 m .47711 .51986 L .43557 .54057 L p .86 .949 .872 r
F P
0 g
s
.61441 .41291 m .60586 .41162 L .62606 .39928 L p .656 .906 .981 r
F P
0 g
s
.62606 .39928 m .63686 .39909 L .61441 .41291 L p .656 .906 .981 r
F P
0 g
s
.3525 .58153 m .36155 .57708 L .40956 .57196 L p .8 .873 .902 r
F P
0 g
s
.41602 .56361 m .40956 .57196 L .36155 .57708 L p .807 .906 .91 r
F P
0 g
s
.5749 .42756 m .5808 .42816 L .5523 .44795 L p .789 .977 .909 r
F P
0 g
s
.5808 .42816 m .5749 .42756 L .59727 .41248 L p .729 .965 .938 r
F P
0 g
s
.59727 .41248 m .60586 .41162 L .5808 .42816 L p .729 .965 .938 r
F P
0 g
s
.48416 .50443 m .48771 .49818 L .52158 .47458 L p .861 .955 .87 r
F P
0 g
s
.52192 .46993 m .52158 .47458 L .48771 .49818 L p .832 .993 .856 r
F P
0 g
s
.52158 .47458 m .52192 .46993 L .5523 .44795 L p .842 .951 .888 r
F P
0 g
s
.24558 .56996 m .25628 .57102 L .30813 .60267 L p .625 .746 .934 r
F P
0 g
s
.31689 .59853 m .30813 .60267 L .25628 .57102 L p .627 .768 .947 r
F P
0 g
s
.54943 .44598 m .5523 .44795 L .52192 .46993 L p .805 .994 .869 r
F P
0 g
s
.5523 .44795 m .54943 .44598 L .5749 .42756 L p .789 .977 .909 r
F P
0 g
s
.70244 .44224 m .69133 .43013 L .71567 .4112 L p .482 .547 .847 r
F P
0 g
s
.69133 .43013 m .68031 .41983 L .70287 .40321 L p .492 .587 .877 r
F P
0 g
s
.70287 .40321 m .71567 .4112 L .69133 .43013 L p .492 .587 .877 r
F P
0 g
s
.71366 .45599 m .70244 .44224 L .72858 .42089 L p .475 .517 .822 r
F P
0 g
s
.71567 .4112 m .72858 .42089 L .70244 .44224 L p .482 .547 .847 r
F P
0 g
s
.43557 .54057 m .44216 .53368 L .48063 .51166 L p .86 .949 .872 r
F P
0 g
s
.48416 .50443 m .48063 .51166 L .44216 .53368 L p .844 .983 .866 r
F P
0 g
s
.68031 .41983 m .66937 .41149 L .69019 .39703 L p .504 .638 .914 r
F P
0 g
s
.69019 .39703 m .70287 .40321 L .68031 .41983 L p .504 .638 .914 r
F P
0 g
s
.72497 .47119 m .71366 .45599 L .74162 .43211 L p .47 .496 .802 r
F P
0 g
s
.72858 .42089 m .74162 .43211 L .71366 .45599 L p .475 .517 .822 r
F P
0 g
s
.66937 .41149 m .65849 .40521 L .67759 .39277 L p .516 .702 .954 r
F P
0 g
s
.67759 .39277 m .69019 .39703 L .66937 .41149 L p .516 .702 .954 r
F P
0 g
s
.36155 .57708 m .37067 .57253 L .41602 .56361 L p .807 .906 .91 r
F P
0 g
s
.42251 .55556 m .41602 .56361 L .37067 .57253 L p .808 .939 .914 r
F P
0 g
s
.73639 .4876 m .72497 .47119 L .7548 .44468 L p .468 .48 .788 r
F P
0 g
s
.74162 .43211 m .7548 .44468 L .72497 .47119 L p .47 .496 .802 r
F P
0 g
s
.25628 .57102 m .26705 .57218 L .31689 .59853 L p .627 .768 .947 r
F P
0 g
s
.3257 .59436 m .31689 .59853 L .26705 .57218 L p .629 .792 .961 r
F P
0 g
s
.65849 .40521 m .64766 .40107 L .66507 .39049 L p .525 .776 .989 r
F P
0 g
s
.66507 .39049 m .67759 .39277 L .65849 .40521 L p .525 .776 .989 r
F P
0 g
s
.60586 .41162 m .59727 .41248 L .61524 .4016 L p .61 .946 .935 r
F P
0 g
s
.61524 .4016 m .62606 .39928 L .60586 .41162 L p .61 .946 .935 r
F P
0 g
s
.74791 .50497 m .73639 .4876 L .76811 .45838 L p .468 .47 .777 r
F P
0 g
s
.7548 .44468 m .76811 .45838 L .73639 .4876 L p .468 .48 .788 r
F P
0 g
s
.48771 .49818 m .49129 .49292 L .52192 .46993 L p .832 .993 .856 r
F P
0 g
s
.52226 .46671 m .52192 .46993 L .49129 .49292 L p .76 .994 .802 r
F P
0 g
s
.52192 .46993 m .52226 .46671 L .54943 .44598 L p .805 .994 .869 r
F P
0 g
s
.44216 .53368 m .44878 .52722 L .48416 .50443 L p .844 .983 .866 r
F P
0 g
s
.48771 .49818 m .48416 .50443 L .44878 .52722 L p .803 .999 .837 r
F P
0 g
s
.56896 .42894 m .5749 .42756 L .54943 .44598 L p .71 .986 .842 r
F P
0 g
s
.5749 .42756 m .56896 .42894 L .58863 .41542 L p .645 .968 .856 r
F P
0 g
s
.58863 .41542 m .59727 .41248 L .5749 .42756 L p .645 .968 .856 r
F P
0 g
s
.37067 .57253 m .37985 .56785 L .42251 .55556 L p .808 .939 .914 r
F P
0 g
s
.42902 .54787 m .42251 .55556 L .37985 .56785 L p .801 .969 .91 r
F P
0 g
s
.75951 .52302 m .74791 .50497 L .78154 .47298 L p .469 .464 .769 r
F P
0 g
s
.76811 .45838 m .78154 .47298 L .74791 .50497 L p .468 .47 .777 r
F P
0 g
s
.64766 .40107 m .63686 .39909 L .65259 .39022 L p .518 .846 .998 r
F P
0 g
s
.65259 .39022 m .66507 .39049 L .64766 .40107 L p .518 .846 .998 r
F P
0 g
s
.54653 .44573 m .54943 .44598 L .52226 .46671 L p .71 .981 .791 r
F P
0 g
s
.54943 .44598 m .54653 .44573 L .56896 .42894 L p .71 .986 .842 r
F P
0 g
s
.26705 .57218 m .2779 .57334 L .3257 .59436 L p .629 .792 .961 r
F P
0 g
s
.33457 .59015 m .3257 .59436 L .2779 .57334 L p .63 .82 .973 r
F P
0 g
s
.77118 .54146 m .75951 .52302 L .79509 .48824 L p .473 .461 .765 r
F P
0 g
s
.78154 .47298 m .79509 .48824 L .75951 .52302 L p .469 .464 .769 r
F P
0 g
s
.63686 .39909 m .62606 .39928 L .64014 .39195 L p .48 .883 .949 r
F P
0 g
s
.64014 .39195 m .65259 .39022 L .63686 .39909 L p .48 .883 .949 r
F P
0 g
s
.37985 .56785 m .3891 .56304 L .42902 .54787 L p .801 .969 .91 r
F P
0 g
s
.43557 .54057 m .42902 .54787 L .3891 .56304 L p .779 .989 .892 r
F P
0 g
s
.59727 .41248 m .58863 .41542 L .60438 .40598 L p .508 .909 .806 r
F P
0 g
s
.60438 .40598 m .61524 .4016 L .59727 .41248 L p .508 .909 .806 r
F P
0 g
s
.2779 .57334 m .28884 .57441 L .33457 .59015 L p .63 .82 .973 r
F P
0 g
s
.3435 .58588 m .33457 .59015 L .28884 .57441 L p .63 .849 .983 r
F P
0 g
s
.44878 .52722 m .45544 .5212 L .48771 .49818 L p .803 .999 .837 r
F P
0 g
s
.49129 .49292 m .48771 .49818 L .45544 .5212 L p .727 .983 .776 r
F P
0 g
s
.7829 .55999 m .77118 .54146 L .80874 .50386 L p .478 .463 .763 r
F P
0 g
s
.79509 .48824 m .80874 .50386 L .77118 .54146 L p .473 .461 .765 r
F P
0 g
s
.49129 .49292 m .49489 .48862 L .52226 .46671 L p .76 .994 .802 r
F P
0 g
s
.5226 .46486 m .52226 .46671 L .49489 .48862 L p .639 .939 .7 r
F P
0 g
s
.52226 .46671 m .5226 .46486 L .54653 .44573 L p .71 .981 .791 r
F P
0 g
s
.56297 .43217 m .56896 .42894 L .54653 .44573 L p .565 .912 .701 r
F P
0 g
s
.56896 .42894 m .56297 .43217 L .57992 .42033 L p .503 .884 .697 r
F P
0 g
s
.57992 .42033 m .58863 .41542 L .56896 .42894 L p .503 .884 .697 r
F P
0 g
s
.79464 .57831 m .7829 .55999 L .82247 .51959 L p .484 .467 .763 r
F P
0 g
s
.80874 .50386 m .82247 .51959 L .7829 .55999 L p .478 .463 .763 r
F P
0 g
s
.3891 .56304 m .39841 .55808 L .43557 .54057 L p .779 .989 .892 r
F P
0 g
s
.44216 .53368 m .43557 .54057 L .39841 .55808 L p .738 .992 .855 r
F P
0 g
s
.54361 .44712 m .54653 .44573 L .5226 .46486 L p .561 .897 .654 r
F P
0 g
s
.54653 .44573 m .54361 .44712 L .56297 .43217 L p .565 .912 .701 r
F P
0 g
s
.62606 .39928 m .61524 .4016 L .62769 .39565 L p .407 .859 .829 r
F P
0 g
s
.62769 .39565 m .64014 .39195 L .62606 .39928 L p .407 .859 .829 r
F P
0 g
s
.28884 .57441 m .29986 .57528 L .3435 .58588 L p .63 .849 .983 r
F P
0 g
s
.3525 .58153 m .3435 .58588 L .29986 .57528 L p .626 .879 .988 r
F P
0 g
s
.82247 .51959 m .83625 .53514 L .79464 .57831 L p .484 .467 .763 r
F P
0 g
s
.49489 .48862 m .49129 .49292 L .46215 .51562 L p .62 .928 .682 r
F P
0 g
s
.45544 .5212 m .46215 .51562 L .47584 .50495 L p .727 .983 .776 r
F P
0 g
s
.46215 .51562 m .4689 .51047 L .47915 .50185 L p .62 .928 .682 r
F P
0 g
s
.47915 .50185 m .49489 .48862 L p .47669 .50363 L .62 .928 .682 r
F P
0 g
s
.47669 .50363 m .46215 .51562 L .47915 .50185 L .62 .928 .682 r
F
.49852 .48525 m .49489 .48862 L .47648 .5041 L p .495 .841 .569 r
F P
0 g
s
.49489 .48862 m .49852 .48525 L .5226 .46486 L p .639 .939 .7 r
F P
0 g
s
.50218 .48275 m .49852 .48525 L .48361 .49864 L p 0 0 0 r
F P
0 g
s
.47584 .50495 m .49129 .49292 L p .47556 .50532 L .727 .983 .776 r
F P
0 g
s
.48361 .49864 m .47571 .50573 L p .48521 .49749 L 0 0 0 r
F P
0 g
s
.50218 .48275 m .48361 .49864 L .48521 .49749 L 0 0 0 r
F
.47648 .5041 m .4689 .51047 L p .47665 .50387 L .495 .841 .569 r
F P
0 g
s
.49852 .48525 m .47648 .5041 L .47665 .50387 L .495 .841 .569 r
F
.47556 .50532 m .45544 .5212 L .47584 .50495 L .727 .983 .776 r
F
.58863 .41542 m .57992 .42033 L .59344 .4123 L p .379 .806 .629 r
F P
0 g
s
.59344 .4123 m .60438 .40598 L .58863 .41542 L p .379 .806 .629 r
F P
0 g
s
.29986 .57528 m .31099 .57586 L .3525 .58153 L p .626 .879 .988 r
F P
0 g
s
.36155 .57708 m .3525 .58153 L .31099 .57586 L p .615 .905 .985 r
F P
0 g
s
.39841 .55808 m .40779 .55297 L .44216 .53368 L p .738 .992 .855 r
F P
0 g
s
.44878 .52722 m .44216 .53368 L .40779 .55297 L p .675 .972 .795 r
F P
0 g
s
.61524 .4016 m .60438 .40598 L .61521 .40125 L p .316 .783 .666 r
F P
0 g
s
.61521 .40125 m .62769 .39565 L .61524 .4016 L p .316 .783 .666 r
F P
0 g
s
.52294 .46431 m .5226 .46486 L .49852 .48525 L p .491 .838 .566 r
F P
0 g
s
.5226 .46486 m .52294 .46431 L .54361 .44712 L p .561 .897 .654 r
F P
0 g
s
.25628 .57102 m .24558 .56996 L .20758 .52532 L p .414 .642 .951 r
F P
0 g
s
.71567 .4112 m .70287 .40321 L .71461 .39101 L p .364 .627 .954 r
F P
0 g
s
.70287 .40321 m .69019 .39703 L .70092 .38752 L p .36 .682 .979 r
F P
0 g
s
.70092 .38752 m .71461 .39101 L .70287 .40321 L p .36 .682 .979 r
F P
0 g
s
.5569 .43713 m .56297 .43217 L .54361 .44712 L p 0 0 0 r
F P
0 g
s
.56297 .43217 m .5569 .43713 L .57112 .42706 L p 0 0 0 r
F P
0 g
s
.57112 .42706 m .57992 .42033 L .56297 .43217 L p 0 0 0 r
F P
0 g
s
.69019 .39703 m .67759 .39277 L .68733 .38566 L p .35 .736 .986 r
F P
0 g
s
.68733 .38566 m .70092 .38752 L .69019 .39703 L p .35 .736 .986 r
F P
0 g
s
.31099 .57586 m .32221 .57604 L .36155 .57708 L p .615 .905 .985 r
F P
0 g
s
.37067 .57253 m .36155 .57708 L .32747 .57618 L p .596 .924 .967 r
F P
0 g
s
.32747 .57618 m .32466 .5761 L p .32965 .57572 L .596 .924 .967 r
F P
0 g
s
.37067 .57253 m .32747 .57618 L .32965 .57572 L .596 .924 .967 r
F
.37067 .57253 m .32466 .5761 L .32783 .57563 L F
.32466 .5761 m .32221 .57604 L p .32783 .57563 L F P
0 g
s
.32221 .57604 m .33354 .57573 L .37067 .57253 L p .596 .924 .967 r
F P
0 g
s
.37985 .56785 m .37067 .57253 L .34254 .57496 L p .566 .93 .932 r
F P
0 g
s
.37985 .56785 m .34254 .57496 L .34462 .57427 L .566 .93 .932 r
F
.37985 .56785 m .33927 .57524 L .34336 .57406 L F
.34254 .57496 m .33927 .57524 L p .34462 .57427 L F P
0 g
s
.33927 .57524 m .33354 .57573 L p .34336 .57406 L .566 .93 .932 r
F P
0 g
s
.33354 .57573 m .34497 .57486 L .34792 .57427 L p .566 .93 .932 r
F P
0 g
s
.34792 .57427 m .37946 .56793 L p .34337 .57406 L .566 .93 .932 r
F P
0 g
s
.34337 .57406 m .33354 .57573 L .34792 .57427 L .566 .93 .932 r
F
.37887 .56802 m .33354 .57573 L .37946 .56793 L F
.37946 .56793 m .37985 .56785 L p .37887 .56802 L F P
0 g
s
.3891 .56304 m .37985 .56785 L .34497 .57486 L p .524 .919 .877 r
F P
0 g
s
.34497 .57486 m .3565 .57336 L .38827 .5633 L p .524 .919 .877 r
F P
0 g
s
.38756 .56345 m .34497 .57486 L .38827 .5633 L .524 .919 .877 r
F
.38827 .5633 m .3891 .56304 L p .38756 .56345 L F P
0 g
s
.39841 .55808 m .3891 .56304 L .36303 .57129 L p .472 .891 .805 r
F P
0 g
s
.36303 .57129 m .3565 .57336 L p .36775 .56926 L .472 .891 .805 r
F P
0 g
s
.39841 .55808 m .36303 .57129 L .36775 .56926 L .472 .891 .805 r
F
.3565 .57336 m .36813 .57115 L .3975 .55847 L p F P
0 g
s
.3975 .55847 m .39841 .55808 L p .3967 .5587 L .472 .891 .805 r
F P
0 g
s
.3967 .5587 m .3565 .57336 L .3975 .55847 L .472 .891 .805 r
F
.40779 .55297 m .39841 .55808 L .36813 .57115 L p .413 .847 .719 r
F P
0 g
s
.36813 .57115 m .37985 .56821 L .40638 .55374 L p .413 .847 .719 r
F P
0 g
s
.40542 .55406 m .36813 .57115 L .40638 .55374 L .413 .847 .719 r
F
.40779 .55297 m .41723 .54771 L .44878 .52722 L p .675 .972 .795 r
F P
0 g
s
.37985 .56821 m .39166 .56449 L .41618 .54839 L p .353 .793 .629 r
F P
0 g
s
.41618 .54839 m .41723 .54771 L p .41521 .54881 L .353 .793 .629 r
F P
0 g
s
.40638 .55374 m .40779 .55297 L p .40542 .55406 L .413 .847 .719 r
F P
0 g
s
.41723 .54771 m .40779 .55297 L .37985 .56821 L p .353 .793 .629 r
F P
0 g
s
.41521 .54881 m .37985 .56821 L .41618 .54839 L .353 .793 .629 r
F
.72858 .42089 m .71567 .4112 L .72843 .39606 L p .366 .581 .924 r
F P
0 g
s
.71461 .39101 m .72843 .39606 L .71567 .4112 L p .364 .627 .954 r
F P
0 g
s
.66712 .38932 m .67383 .38549 L p .67501 .38777 L .328 .777 .957 r
F P
0 g
s
.67383 .38549 m .68733 .38566 L .67759 .39277 L p .328 .777 .957 r
F P
0 g
s
.68733 .38566 m .67383 .38549 L .67293 .38669 L p .153 .695 .749 r
F P
0 g
s
.67293 .38669 m .68654 .38464 L .68711 .38538 L p .153 .695 .749 r
F P
0 g
s
.68711 .38538 m .68733 .38566 L p .68476 .38584 L .153 .695 .749 r
F P
0 g
s
.67293 .38669 m .68711 .38538 L .68476 .38584 L .153 .695 .749 r
F
.67759 .39277 m .66507 .39049 L .66712 .38932 L p .328 .777 .957 r
F P
0 g
s
.67501 .38777 m .67759 .39277 L .66712 .38932 L .328 .777 .957 r
F
.54064 .45001 m .54361 .44712 L .52294 .46431 L p 0 0 0 r
F P
0 g
s
.54361 .44712 m .54064 .45001 L .5569 .43713 L p 0 0 0 r
F P
0 g
s
.45544 .5212 m .44878 .52722 L .41723 .54771 L p .593 .926 .714 r
F P
0 g
s
.74162 .43211 m .72858 .42089 L .74239 .40254 L p .368 .544 .896 r
F P
0 g
s
.72843 .39606 m .74239 .40254 L .72858 .42089 L p .366 .581 .924 r
F P
0 g
s
.66195 .38817 m .66507 .39049 L .65344 .38987 L .291 .785 .878 r
F
.66041 .38702 m .67383 .38549 L .66507 .39049 L p F P
0 g
s
.6594 .39001 m .67293 .38669 L .67355 .38586 L p 0 0 0 r
F P
0 g
s
.67355 .38586 m .67383 .38549 L p .67105 .38636 L 0 0 0 r
F P
0 g
s
.6594 .39001 m .67355 .38586 L .67105 .38636 L 0 0 0 r
F
.66507 .39049 m .65259 .39022 L .65344 .38987 L p .291 .785 .878 r
F P
0 g
s
.65344 .38987 m .66041 .38702 L p .66195 .38817 L .291 .785 .878 r
F P
0 g
s
.57992 .42033 m .57112 .42706 L .58241 .42043 L p 0 0 0 r
F P
0 g
s
.58241 .42043 m .59344 .4123 L .57992 .42033 L p 0 0 0 r
F P
0 g
s
.7548 .44468 m .74162 .43211 L .75649 .41034 L p .371 .516 .872 r
F P
0 g
s
.74239 .40254 m .75649 .41034 L .74162 .43211 L p .368 .544 .896 r
F P
0 g
s
.60438 .40598 m .59344 .4123 L .60268 .40864 L p 0 0 0 r
F P
0 g
s
.60268 .40864 m .61521 .40125 L .60438 .40598 L p 0 0 0 r
F P
0 g
s
.20758 .52532 m .21972 .53173 L .25628 .57102 L p .414 .642 .951 r
F P
0 g
s
.26705 .57218 m .25628 .57102 L .21972 .53173 L p .386 .649 .961 r
F P
0 g
s
.65259 .39022 m .64014 .39195 L .64703 .39026 L p .242 .755 .755 r
F P
0 g
s
.64703 .39026 m .66041 .38702 L .65259 .39022 L p .242 .755 .755 r
F P
0 g
s
.76811 .45838 m .7548 .44468 L .77074 .41928 L p .376 .496 .853 r
F P
0 g
s
.75649 .41034 m .77074 .41928 L .7548 .44468 L p .371 .516 .872 r
F P
0 g
s
.49852 .48525 m .50218 .48275 L .52294 .46431 L p .491 .838 .566 r
F P
0 g
s
.52329 .46494 m .52294 .46431 L .50218 .48275 L p 0 0 0 r
F P
0 g
s
.52294 .46431 m .52329 .46494 L .54064 .45001 L p 0 0 0 r
F P
0 g
s
.41723 .54771 m .42673 .54228 L .45544 .5212 L p .593 .926 .714 r
F P
0 g
s
.46215 .51562 m .45544 .5212 L .42673 .54228 L p .499 .86 .619 r
F P
0 g
s
.4689 .51047 m .47571 .50573 L .49852 .48525 L p .495 .841 .569 r
F P
0 g
s
.64014 .39195 m .62769 .39565 L .63367 .39517 L p 0 0 0 r
F P
0 g
s
.63367 .39517 m .64703 .39026 L .64014 .39195 L p 0 0 0 r
F P
0 g
s
.21972 .53173 m .23194 .53835 L .26705 .57218 L p .386 .649 .961 r
F P
0 g
s
.2779 .57334 m .26705 .57218 L .23194 .53835 L p .357 .659 .97 r
F P
0 g
s
.78154 .47298 m .76811 .45838 L .78514 .4292 L p .383 .482 .837 r
F P
0 g
s
.77074 .41928 m .78514 .4292 L .76811 .45838 L p .376 .496 .853 r
F P
0 g
s
.55076 .44364 m .5569 .43713 L .54064 .45001 L p 0 0 0 r
F P
0 g
s
.5569 .43713 m .55076 .44364 L .5622 .43544 L p 0 0 0 r
F P
0 g
s
.5622 .43544 m .57112 .42706 L .5569 .43713 L p 0 0 0 r
F P
0 g
s
.53764 .45425 m .54064 .45001 L .52329 .46494 L p 0 0 0 r
F P
0 g
s
.54064 .45001 m .53764 .45425 L .55076 .44364 L p 0 0 0 r
F P
0 g
s
.59344 .4123 m .58241 .42043 L .59007 .41767 L p 0 0 0 r
F P
0 g
s
.59007 .41767 m .60268 .40864 L .59344 .4123 L p 0 0 0 r
F P
0 g
s
.42673 .54228 m .43629 .53669 L .46215 .51562 L p .499 .86 .619 r
F P
0 g
s
.4689 .51047 m .46215 .51562 L .43629 .53669 L p 0 0 0 r
F P
0 g
s
.79509 .48824 m .78154 .47298 L .79969 .43988 L p .391 .475 .826 r
F P
0 g
s
.78514 .4292 m .79969 .43988 L .78154 .47298 L p .383 .482 .837 r
F P
0 g
s
.62769 .39565 m .61521 .40125 L .62031 .40167 L p 0 0 0 r
F P
0 g
s
.62031 .40167 m .63367 .39517 L .62769 .39565 L p 0 0 0 r
F P
0 g
s
.57112 .42706 m .5622 .43544 L .57127 .43017 L p 0 0 0 r
F P
0 g
s
.57127 .43017 m .58241 .42043 L .57112 .42706 L p 0 0 0 r
F P
0 g
s
.23194 .53835 m .24424 .54501 L .2779 .57334 L p .357 .659 .97 r
F P
0 g
s
.28884 .57441 m .2779 .57334 L .24424 .54501 L p .327 .671 .976 r
F P
0 g
s
.50218 .48275 m .50589 .48104 L .52329 .46494 L p 0 0 0 r
F P
0 g
s
.52365 .46663 m .52329 .46494 L .50589 .48104 L p 0 0 0 r
F P
0 g
s
.52329 .46494 m .52365 .46663 L .53764 .45425 L p 0 0 0 r
F P
0 g
s
.47571 .50573 m .48257 .50137 L .50218 .48275 L p 0 0 0 r
F P
0 g
s
.50589 .48104 m .50218 .48275 L .48257 .50137 L p 0 0 0 r
F P
0 g
s
.80874 .50386 m .79509 .48824 L .81437 .45112 L p .402 .472 .818 r
F P
0 g
s
.79969 .43988 m .81437 .45112 L .79509 .48824 L p .391 .475 .826 r
F P
0 g
s
.43629 .53669 m .44592 .53095 L .4689 .51047 L p 0 0 0 r
F P
0 g
s
.47571 .50573 m .4689 .51047 L .44592 .53095 L p 0 0 0 r
F P
0 g
s
.61521 .40125 m .60268 .40864 L .60694 .40968 L p 0 0 0 r
F P
0 g
s
.60694 .40968 m .62031 .40167 L .61521 .40125 L p 0 0 0 r
F P
0 g
s
.24424 .54501 m .25665 .55153 L .28884 .57441 L p .327 .671 .976 r
F P
0 g
s
.29986 .57528 m .28884 .57441 L .25665 .55153 L p .298 .685 .975 r
F P
0 g
s
.58241 .42043 m .57127 .43017 L .57735 .42819 L p 0 0 0 r
F P
0 g
s
.57735 .42819 m .59007 .41767 L .58241 .42043 L p 0 0 0 r
F P
0 g
s
.82247 .51959 m .80874 .50386 L .82917 .46268 L p .414 .473 .813 r
F P
0 g
s
.81437 .45112 m .82917 .46268 L .80874 .50386 L p .402 .472 .818 r
F P
0 g
s
.54451 .45148 m .55076 .44364 L .53764 .45425 L p 0 0 0 r
F P
0 g
s
.55076 .44364 m .54451 .45148 L .55316 .44524 L p 0 0 0 r
F P
0 g
s
.55316 .44524 m .5622 .43544 L .55076 .44364 L p 0 0 0 r
F P
0 g
s
.53459 .45965 m .53764 .45425 L .52365 .46663 L p 0 0 0 r
F P
0 g
s
.53764 .45425 m .53459 .45965 L .54451 .45148 L p 0 0 0 r
F P
0 g
s
.25665 .55153 m .26918 .55773 L .29986 .57528 L p .298 .685 .975 r
F P
0 g
s
.31099 .57586 m .27166 .55914 L .27516 .56032 L .268 .699 .965 r
F
.27166 .55914 m .26918 .55773 L p .27516 .56032 L F P
0 g
s
.26918 .55773 m .28184 .56342 L .31099 .57586 L p .268 .699 .965 r
F P
0 g
s
.32221 .57604 m .31099 .57586 L .29209 .56779 L p .237 .709 .941 r
F P
0 g
s
.29209 .56779 m .2882 .56614 L p .29501 .56812 L .237 .709 .941 r
F P
0 g
s
.32221 .57604 m .29209 .56779 L .29501 .56812 L .237 .709 .941 r
F
.32221 .57604 m .2882 .56614 L .29127 .56664 L F
.32221 .57604 m .28475 .56467 L .28881 .5656 L F
.2882 .56614 m .28475 .56467 L p .29127 .56664 L F P
0 g
s
.28475 .56467 m .28184 .56342 L p .28881 .5656 L .237 .709 .941 r
F P
0 g
s
.28184 .56342 m .29463 .56844 L .32087 .57567 L p .237 .709 .941 r
F P
0 g
s
.31875 .57496 m .28184 .56342 L .32087 .57567 L .237 .709 .941 r
F
.32087 .57567 m .32221 .57604 L p .31875 .57496 L F P
0 g
s
.33354 .57573 m .32221 .57604 L .29463 .56844 L p .207 .713 .901 r
F P
0 g
s
.29463 .56844 m .30756 .5726 L .33196 .57554 L p .207 .713 .901 r
F P
0 g
s
.33196 .57554 m .33354 .57573 L p .32949 .57497 L .207 .713 .901 r
F P
0 g
s
.32949 .57497 m .29463 .56844 L .33196 .57554 L .207 .713 .901 r
F
.34497 .57486 m .33354 .57573 L .30756 .5726 L p .178 .708 .843 r
F P
0 g
s
.30756 .5726 m .32063 .57578 L .34167 .57499 L p .178 .708 .843 r
F P
0 g
s
.34167 .57499 m .34497 .57486 L p .3386 .57448 L .178 .708 .843 r
F P
0 g
s
.3386 .57448 m .30756 .5726 L .34167 .57499 L .178 .708 .843 r
F
.3565 .57336 m .34497 .57486 L .32063 .57578 L p .151 .694 .771 r
F P
0 g
s
.32063 .57578 m .33383 .57782 L .35135 .57437 L p .151 .694 .771 r
F P
0 g
s
.35135 .57437 m .3565 .57336 L p .34762 .57396 L .151 .694 .771 r
F P
0 g
s
.34762 .57396 m .32063 .57578 L .35135 .57437 L .151 .694 .771 r
F
.31099 .57586 m .29986 .57528 L .27166 .55914 L p .268 .699 .965 r
F P
0 g
s
.5622 .43544 m .55316 .44524 L .55998 .44131 L p 0 0 0 r
F P
0 g
s
.55998 .44131 m .57127 .43017 L .5622 .43544 L p 0 0 0 r
F P
0 g
s
.60268 .40864 m .59007 .41767 L .59351 .41907 L p 0 0 0 r
F P
0 g
s
.59351 .41907 m .60694 .40968 L .60268 .40864 L p 0 0 0 r
F P
0 g
s
.44592 .53095 m .45561 .52506 L .47571 .50573 L p 0 0 0 r
F P
0 g
s
.48257 .50137 m .47571 .50573 L .45561 .52506 L p 0 0 0 r
F P
0 g
s
.83625 .53514 m .82247 .51959 L .84407 .47433 L p .428 .479 .811 r
F P
0 g
s
.82917 .46268 m .84407 .47433 L .82247 .51959 L p .414 .473 .813 r
F P
0 g
s
.48257 .50137 m .48949 .49735 L .50589 .48104 L p 0 0 0 r
F P
0 g
s
.50963 .48003 m .50589 .48104 L .48949 .49735 L p 0 0 0 r
F P
0 g
s
.50589 .48104 m .50963 .48003 L .52365 .46663 L p 0 0 0 r
F P
0 g
s
.42673 .54228 m .41723 .54771 L .39166 .56449 L p 0 0 0 r
F P
0 g
s
.524 .46921 m .52365 .46663 L .50963 .48003 L p 0 0 0 r
F P
0 g
s
.52365 .46663 m .524 .46921 L .53459 .45965 L p 0 0 0 r
F P
0 g
s
.70092 .38752 m .68733 .38566 L .68654 .38464 L p .184 .713 .845 r
F P
0 g
s
.84407 .47433 m .85906 .48583 L .83625 .53514 L p .428 .479 .811 r
F P
0 g
s
.67383 .38549 m .66041 .38702 L .6594 .39001 L p 0 0 0 r
F P
0 g
s
.71461 .39101 m .70092 .38752 L .70025 .38386 L p .213 .71 .915 r
F P
0 g
s
.68654 .38464 m .70025 .38386 L .70092 .38752 L p .184 .713 .845 r
F P
0 g
s
.66041 .38702 m .64703 .39026 L .64594 .39459 L p 0 0 0 r
F P
0 g
s
.64594 .39459 m .6594 .39001 L .66041 .38702 L p 0 0 0 r
F P
0 g
s
.57127 .43017 m .55998 .44131 L .56452 .43997 L p 0 0 0 r
F P
0 g
s
.56452 .43997 m .57735 .42819 L .57127 .43017 L p 0 0 0 r
F P
0 g
s
.72843 .39606 m .71461 .39101 L .71408 .38429 L p .239 .69 .954 r
F P
0 g
s
.70025 .38386 m .71408 .38429 L .71461 .39101 L p .213 .71 .915 r
F P
0 g
s
.45561 .52506 m .46536 .51902 L .48257 .50137 L p 0 0 0 r
F P
0 g
s
.48949 .49735 m .48257 .50137 L .46536 .51902 L p 0 0 0 r
F P
0 g
s
.39166 .56449 m .40355 .56 L .42673 .54228 L p 0 0 0 r
F P
0 g
s
.43629 .53669 m .42673 .54228 L .40355 .56 L p 0 0 0 r
F P
0 g
s
.64703 .39026 m .63367 .39517 L .63253 .40041 L p 0 0 0 r
F P
0 g
s
.63253 .40041 m .64594 .39459 L .64703 .39026 L p 0 0 0 r
F P
0 g
s
.59007 .41767 m .57735 .42819 L .58003 .42968 L p 0 0 0 r
F P
0 g
s
.58003 .42968 m .59351 .41907 L .59007 .41767 L p 0 0 0 r
F P
0 g
s
.74239 .40254 m .72843 .39606 L .72803 .38589 L p .262 .66 .966 r
F P
0 g
s
.71408 .38429 m .72803 .38589 L .72843 .39606 L p .239 .69 .954 r
F P
0 g
s
.63367 .39517 m .62031 .40167 L .61915 .40742 L p 0 0 0 r
F P
0 g
s
.61915 .40742 m .63253 .40041 L .63367 .39517 L p 0 0 0 r
F P
0 g
s
.53817 .46042 m .54451 .45148 L .53459 .45965 L p 0 0 0 r
F P
0 g
s
.54451 .45148 m .53817 .46042 L .54397 .4562 L p 0 0 0 r
F P
0 g
s
.54397 .4562 m .55316 .44524 L .54451 .45148 L p 0 0 0 r
F P
0 g
s
.48949 .49735 m .49648 .49363 L .50963 .48003 L p 0 0 0 r
F P
0 g
s
.51343 .4796 m .50963 .48003 L .49648 .49363 L p 0 0 0 r
F P
0 g
s
.50963 .48003 m .51343 .4796 L .524 .46921 L p 0 0 0 r
F P
0 g
s
.75649 .41034 m .74239 .40254 L .74211 .38856 L p .281 .628 .962 r
F P
0 g
s
.72803 .38589 m .74211 .38856 L .74239 .40254 L p .262 .66 .966 r
F P
0 g
s
.53149 .46598 m .53459 .45965 L .524 .46921 L p 0 0 0 r
F P
0 g
s
.53459 .45965 m .53149 .46598 L .53817 .46042 L p 0 0 0 r
F P
0 g
s
.40355 .56 m .41551 .55472 L .43629 .53669 L p 0 0 0 r
F P
0 g
s
.44592 .53095 m .43629 .53669 L .41551 .55472 L p 0 0 0 r
F P
0 g
s
.55316 .44524 m .54397 .4562 L .54853 .4536 L p 0 0 0 r
F P
0 g
s
.54853 .4536 m .55998 .44131 L .55316 .44524 L p 0 0 0 r
F P
0 g
s
.21972 .53173 m .20758 .52532 L .18911 .47507 L p .27 .49 .886 r
F P
0 g
s
.62031 .40167 m .60694 .40968 L .60578 .41552 L p 0 0 0 r
F P
0 g
s
.60578 .41552 m .61915 .40742 L .62031 .40167 L p 0 0 0 r
F P
0 g
s
.46536 .51902 m .47517 .51285 L .48949 .49735 L p 0 0 0 r
F P
0 g
s
.49648 .49363 m .48949 .49735 L .47517 .51285 L p 0 0 0 r
F P
0 g
s
.77074 .41928 m .75649 .41034 L .75634 .39221 L p .298 .598 .949 r
F P
0 g
s
.74211 .38856 m .75634 .39221 L .75649 .41034 L p .281 .628 .962 r
F P
0 g
s
.52437 .47252 m .524 .46921 L .51343 .4796 L p 0 0 0 r
F P
0 g
s
.524 .46921 m .52437 .47252 L .53149 .46598 L p 0 0 0 r
F P
0 g
s
.57735 .42819 m .56452 .43997 L .56646 .44134 L p 0 0 0 r
F P
0 g
s
.56646 .44134 m .58003 .42968 L .57735 .42819 L p 0 0 0 r
F P
0 g
s
.41551 .55472 m .42754 .54869 L .44592 .53095 L p 0 0 0 r
F P
0 g
s
.45561 .52506 m .44592 .53095 L .42754 .54869 L p 0 0 0 r
F P
0 g
s
.55998 .44131 m .54853 .4536 L .55154 .45279 L p 0 0 0 r
F P
0 g
s
.55154 .45279 m .56452 .43997 L .55998 .44131 L p 0 0 0 r
F P
0 g
s
.60694 .40968 m .59351 .41907 L .59242 .42464 L p 0 0 0 r
F P
0 g
s
.59242 .42464 m .60578 .41552 L .60694 .40968 L p 0 0 0 r
F P
0 g
s
.78514 .4292 m .77074 .41928 L .77072 .39671 L p .315 .574 .933 r
F P
0 g
s
.75634 .39221 m .77072 .39671 L .77074 .41928 L p .298 .598 .949 r
F P
0 g
s
.18911 .47507 m .20202 .48668 L .21972 .53173 L p .27 .49 .886 r
F P
0 g
s
.23194 .53835 m .21972 .53173 L .20202 .48668 L p .229 .478 .887 r
F P
0 g
s
.49648 .49363 m .50353 .49014 L .51343 .4796 L p 0 0 0 r
F P
0 g
s
.51727 .47962 m .51343 .4796 L .50353 .49014 L p 0 0 0 r
F P
0 g
s
.51343 .4796 m .51727 .47962 L .52437 .47252 L p 0 0 0 r
F P
0 g
s
.42754 .54869 m .43962 .54193 L .45561 .52506 L p 0 0 0 r
F P
0 g
s
.46536 .51902 m .45561 .52506 L .43962 .54193 L p 0 0 0 r
F P
0 g
s
.47517 .51285 m .48504 .50655 L .49648 .49363 L p 0 0 0 r
F P
0 g
s
.50353 .49014 m .49648 .49363 L .48504 .50655 L p 0 0 0 r
F P
0 g
s
.59351 .41907 m .58003 .42968 L .57903 .43463 L p 0 0 0 r
F P
0 g
s
.57903 .43463 m .59242 .42464 L .59351 .41907 L p 0 0 0 r
F P
0 g
s
.79969 .43988 m .78514 .4292 L .78525 .40193 L p .332 .556 .917 r
F P
0 g
s
.77072 .39671 m .78525 .40193 L .78514 .4292 L p .315 .574 .933 r
F P
0 g
s
.36813 .57115 m .3565 .57336 L .33383 .57782 L p 0 0 0 r
F P
0 g
s
.5317 .47018 m .53817 .46042 L .53149 .46598 L p 0 0 0 r
F P
0 g
s
.53817 .46042 m .5317 .47018 L .53463 .46805 L p 0 0 0 r
F P
0 g
s
.53463 .46805 m .54397 .4562 L .53817 .46042 L p 0 0 0 r
F P
0 g
s
.20202 .48668 m .215 .4986 L .23194 .53835 L p .229 .478 .887 r
F P
0 g
s
.24424 .54501 m .23194 .53835 L .215 .4986 L p .189 .471 .89 r
F P
0 g
s
.56452 .43997 m .55154 .45279 L .55279 .45384 L p 0 0 0 r
F P
0 g
s
.55279 .45384 m .56646 .44134 L .56452 .43997 L p 0 0 0 r
F P
0 g
s
.52833 .47301 m .53149 .46598 L .52437 .47252 L p 0 0 0 r
F P
0 g
s
.53149 .46598 m .52833 .47301 L .5317 .47018 L p 0 0 0 r
F P
0 g
s
.54397 .4562 m .53463 .46805 L .53692 .46675 L p 0 0 0 r
F P
0 g
s
.53692 .46675 m .54853 .4536 L .54397 .4562 L p 0 0 0 r
F P
0 g
s
.43962 .54193 m .45175 .53451 L .46536 .51902 L p 0 0 0 r
F P
0 g
s
.47517 .51285 m .46536 .51902 L .45175 .53451 L p 0 0 0 r
F P
0 g
s
.52474 .47634 m .52437 .47252 L .51727 .47962 L p 0 0 0 r
F P
0 g
s
.52437 .47252 m .52474 .47634 L .52833 .47301 L p 0 0 0 r
F P
0 g
s
.58003 .42968 m .56646 .44134 L .56562 .44538 L p 0 0 0 r
F P
0 g
s
.56562 .44538 m .57903 .43463 L .58003 .42968 L p 0 0 0 r
F P
0 g
s
.81437 .45112 m .79969 .43988 L .79992 .40772 L p .35 .544 .903 r
F P
0 g
s
.78525 .40193 m .79992 .40772 L .79969 .43988 L p .332 .556 .917 r
F P
0 g
s
.33383 .57782 m .34715 .57863 L .36813 .57115 L p 0 0 0 r
F P
0 g
s
.37985 .56821 m .36813 .57115 L .34715 .57863 L p 0 0 0 r
F P
0 g
s
.54853 .4536 m .53692 .46675 L .53841 .46638 L p 0 0 0 r
F P
0 g
s
.53841 .46638 m .55154 .45279 L .54853 .4536 L p 0 0 0 r
F P
0 g
s
.48504 .50655 m .49497 .50015 L .50353 .49014 L p 0 0 0 r
F P
0 g
s
.51065 .48682 m .50353 .49014 L .49497 .50015 L p 0 0 0 r
F P
0 g
s
.50353 .49014 m .51065 .48682 L .51727 .47962 L p 0 0 0 r
F P
0 g
s
.215 .4986 m .22806 .5106 L .24424 .54501 L p .189 .471 .89 r
F P
0 g
s
.25665 .55153 m .24424 .54501 L .22806 .5106 L p .152 .47 .893 r
F P
0 g
s
.45175 .53451 m .46392 .52649 L .47517 .51285 L p 0 0 0 r
F P
0 g
s
.48504 .50655 m .47517 .51285 L .46392 .52649 L p 0 0 0 r
F P
0 g
s
.52116 .47996 m .51727 .47962 L .51065 .48682 L p 0 0 0 r
F P
0 g
s
.51727 .47962 m .52116 .47996 L .52474 .47634 L p 0 0 0 r
F P
0 g
s
.34715 .57863 m .3606 .57812 L .37985 .56821 L p 0 0 0 r
F P
0 g
s
.39166 .56449 m .37985 .56821 L .3606 .57812 L p 0 0 0 r
F P
0 g
s
.82917 .46268 m .81437 .45112 L .81473 .41391 L p .369 .537 .891 r
F P
0 g
s
.79992 .40772 m .81473 .41391 L .81437 .45112 L p .35 .544 .903 r
F P
0 g
s
.56646 .44134 m .55279 .45384 L .55217 .45671 L p 0 0 0 r
F P
0 g
s
.55217 .45671 m .56562 .44538 L .56646 .44134 L p 0 0 0 r
F P
0 g
s
.55154 .45279 m .53841 .46638 L .53901 .46697 L p 0 0 0 r
F P
0 g
s
.53901 .46697 m .55279 .45384 L .55154 .45279 L p 0 0 0 r
F P
0 g
s
.3606 .57812 m .37414 .57625 L .39166 .56449 L p 0 0 0 r
F P
0 g
s
.40355 .56 m .39166 .56449 L .37414 .57625 L p 0 0 0 r
F P
0 g
s
.46392 .52649 m .47612 .51794 L .48504 .50655 L p 0 0 0 r
F P
0 g
s
.49497 .50015 m .48504 .50655 L .47612 .51794 L p 0 0 0 r
F P
0 g
s
.22806 .5106 m .24125 .52242 L .25665 .55153 L p .152 .47 .893 r
F P
0 g
s
.26918 .55773 m .25665 .55153 L .24125 .52242 L p .119 .475 .896 r
F P
0 g
s
.6594 .39001 m .64594 .39459 L .63651 .40499 L p 0 0 0 r
F P
0 g
s
.64594 .39459 m .63253 .40041 L .62398 .41134 L p 0 0 0 r
F P
0 g
s
.62398 .41134 m .63651 .40499 L .64594 .39459 L p 0 0 0 r
F P
0 g
s
.63253 .40041 m .61915 .40742 L .6115 .41835 L p 0 0 0 r
F P
0 g
s
.6115 .41835 m .62398 .41134 L .63253 .40041 L p 0 0 0 r
F P
0 g
s
.67293 .38669 m .6594 .39001 L .64911 .39934 L p 0 0 0 r
F P
0 g
s
.63651 .40499 m .64911 .39934 L .6594 .39001 L p 0 0 0 r
F P
0 g
s
.61915 .40742 m .60578 .41552 L .59908 .42597 L p 0 0 0 r
F P
0 g
s
.59908 .42597 m .6115 .41835 L .61915 .40742 L p 0 0 0 r
F P
0 g
s
.68654 .38464 m .67293 .38669 L .66179 .39441 L p 0 0 0 r
F P
0 g
s
.64911 .39934 m .66179 .39441 L .67293 .38669 L p 0 0 0 r
F P
0 g
s
.49497 .50015 m .50496 .49366 L .51065 .48682 L p 0 0 0 r
F P
0 g
s
.51784 .48362 m .51065 .48682 L .50496 .49366 L p 0 0 0 r
F P
0 g
s
.51065 .48682 m .51784 .48362 L .52116 .47996 L p 0 0 0 r
F P
0 g
s
.60578 .41552 m .59242 .42464 L .58669 .43415 L p 0 0 0 r
F P
0 g
s
.58669 .43415 m .59908 .42597 L .60578 .41552 L p 0 0 0 r
F P
0 g
s
.37414 .57625 m .38777 .57298 L .40355 .56 L p 0 0 0 r
F P
0 g
s
.41551 .55472 m .40355 .56 L .38777 .57298 L p 0 0 0 r
F P
0 g
s
.84407 .47433 m .82917 .46268 L .82966 .42034 L p .389 .535 .881 r
F P
0 g
s
.81473 .41391 m .82966 .42034 L .82917 .46268 L p .369 .537 .891 r
F P
0 g
s
.52511 .48046 m .5317 .47018 L .52833 .47301 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .53463 .46805 L .5317 .47018 L closepath p 0 0 0 r
F P
0 g
s
.70025 .38386 m .68654 .38464 L .67603 .38951 L p .205 .725 .705 r
F P
0 g
s
.67929 .38903 m .70025 .38386 L .67603 .38951 L .205 .725 .705 r
F
.67603 .38951 m .67455 .3902 L p .67929 .38903 L F P
0 g
s
.67455 .3902 m .68741 .38671 L .70025 .38386 L p .205 .725 .705 r
F P
0 g
s
.71408 .38429 m .70025 .38386 L .68878 .3864 L p .244 .759 .799 r
F P
0 g
s
.68878 .3864 m .68741 .38671 L p .69181 .38631 L .244 .759 .799 r
F P
0 g
s
.69181 .38631 m .71408 .38429 L .68878 .3864 L .244 .759 .799 r
F
.68741 .38671 m .70038 .38391 L .71163 .38422 L p F P
0 g
s
.71163 .38422 m .71408 .38429 L p .70664 .38497 L .244 .759 .799 r
F P
0 g
s
.68741 .38671 m .71163 .38422 L .70664 .38497 L .244 .759 .799 r
F
.72803 .38589 m .71408 .38429 L .70038 .38391 L p .283 .78 .879 r
F P
0 g
s
.70038 .38391 m .71346 .38177 L .72576 .38525 L p .283 .78 .879 r
F P
0 g
s
.72576 .38525 m .72803 .38589 L p .72111 .38539 L .283 .78 .879 r
F P
0 g
s
.70038 .38391 m .72576 .38525 L .72111 .38539 L .283 .78 .879 r
F
.66179 .39441 m .67455 .3902 L .68654 .38464 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .52833 .47301 L .52474 .47634 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .53692 .46675 L .53463 .46805 L closepath p 0 0 0 r
F P
0 g
s
.47612 .51794 m .48834 .50897 L .49497 .50015 L p 0 0 0 r
F P
0 g
s
.50496 .49366 m .49497 .50015 L .48834 .50897 L p 0 0 0 r
F P
0 g
s
.59242 .42464 m .57903 .43463 L .57433 .44281 L p 0 0 0 r
F P
0 g
s
.57433 .44281 m .58669 .43415 L .59242 .42464 L p 0 0 0 r
F P
0 g
s
.55279 .45384 m .53901 .46697 L .53867 .46847 L p 0 0 0 r
F P
0 g
s
.53867 .46847 m .55217 .45671 L .55279 .45384 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .52474 .47634 L .52116 .47996 L closepath p 0 0 0 r
F P
0 g
s
.24125 .52242 m .25456 .53381 L .26918 .55773 L p .119 .475 .896 r
F P
0 g
s
.28184 .56342 m .26918 .55773 L .25456 .53381 L p .089 .487 .897 r
F P
0 g
s
.38777 .57298 m .40147 .56834 L .41551 .55472 L p 0 0 0 r
F P
0 g
s
.42754 .54869 m .41551 .55472 L .40147 .56834 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .53841 .46638 L .53692 .46675 L closepath p 0 0 0 r
F P
0 g
s
.57903 .43463 m .56562 .44538 L .562 .45187 L p 0 0 0 r
F P
0 g
s
.562 .45187 m .57433 .44281 L .57903 .43463 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .52116 .47996 L .51784 .48362 L closepath p 0 0 0 r
F P
0 g
s
.40147 .56834 m .41522 .56236 L .42754 .54869 L p 0 0 0 r
F P
0 g
s
.43962 .54193 m .42754 .54869 L .41522 .56236 L p 0 0 0 r
F P
0 g
s
.85906 .48583 m .84407 .47433 L .84472 .42682 L p .409 .538 .875 r
F P
0 g
s
.82966 .42034 m .84472 .42682 L .84407 .47433 L p .389 .535 .881 r
F P
0 g
s
.52511 .48046 m .53901 .46697 L .53841 .46638 L closepath p 0 0 0 r
F P
0 g
s
.48834 .50897 m .50059 .49966 L .50496 .49366 L p 0 0 0 r
F P
0 g
s
.51501 .48709 m .50496 .49366 L .50059 .49966 L p 0 0 0 r
F P
0 g
s
.50496 .49366 m .51501 .48709 L .51784 .48362 L p 0 0 0 r
F P
0 g
s
.56562 .44538 m .55217 .45671 L .54969 .46123 L p 0 0 0 r
F P
0 g
s
.54969 .46123 m .562 .45187 L .56562 .44538 L p 0 0 0 r
F P
0 g
s
.41522 .56236 m .42901 .55512 L .43962 .54193 L p 0 0 0 r
F P
0 g
s
.45175 .53451 m .43962 .54193 L .42901 .55512 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51784 .48362 L .51501 .48709 L closepath p 0 0 0 r
F P
0 g
s
.25456 .53381 m .26802 .5445 L .28184 .56342 L p .089 .487 .897 r
F P
0 g
s
.29463 .56844 m .28184 .56342 L .26802 .5445 L p .063 .505 .895 r
F P
0 g
s
.52511 .48046 m .53867 .46847 L .53901 .46697 L closepath p 0 0 0 r
F P
0 g
s
.42901 .55512 m .44281 .54672 L .45175 .53451 L p 0 0 0 r
F P
0 g
s
.46392 .52649 m .45175 .53451 L .44281 .54672 L p 0 0 0 r
F P
0 g
s
.55217 .45671 m .53867 .46847 L .5374 .4708 L p 0 0 0 r
F P
0 g
s
.5374 .4708 m .54969 .46123 L .55217 .45671 L p 0 0 0 r
F P
0 g
s
.74211 .38856 m .72803 .38589 L .71346 .38177 L p .319 .785 .938 r
F P
0 g
s
.44281 .54672 m .45661 .53729 L .46392 .52649 L p 0 0 0 r
F P
0 g
s
.47612 .51794 m .46392 .52649 L .45661 .53729 L p 0 0 0 r
F P
0 g
s
.84472 .42682 m .85986 .43317 L .85906 .48583 L p .409 .538 .875 r
F P
0 g
s
.50059 .49966 m .51284 .49012 L .51501 .48709 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51501 .48709 L .51284 .49012 L closepath p 0 0 0 r
F P
0 g
s
.45661 .53729 m .47039 .52698 L .47612 .51794 L p 0 0 0 r
F P
0 g
s
.48834 .50897 m .47612 .51794 L .47039 .52698 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .5374 .4708 L .53867 .46847 L closepath p 0 0 0 r
F P
0 g
s
.26802 .5445 m .28164 .55426 L .29463 .56844 L p .063 .505 .895 r
F P
0 g
s
.30756 .5726 m .29463 .56844 L .28164 .55426 L p .041 .527 .884 r
F P
0 g
s
.47039 .52698 m .48414 .51596 L .48834 .50897 L p 0 0 0 r
F P
0 g
s
.50059 .49966 m .48834 .50897 L .48414 .51596 L p 0 0 0 r
F P
0 g
s
.75634 .39221 m .74211 .38856 L .72665 .38024 L p .351 .775 .974 r
F P
0 g
s
.71346 .38177 m .72665 .38024 L .74211 .38856 L p .319 .785 .938 r
F P
0 g
s
.48414 .51596 m .49785 .5044 L .50059 .49966 L p 0 0 0 r
F P
0 g
s
.51284 .49012 m .50059 .49966 L .49785 .5044 L p 0 0 0 r
F P
0 g
s
.49785 .5044 m .51151 .49251 L .51284 .49012 L p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51284 .49012 L .51151 .49251 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .53528 .4738 L .5374 .4708 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .53246 .47727 L .53528 .4738 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .52912 .48098 L .53246 .47727 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .5255 .48466 L .52912 .48098 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .52184 .48806 L .5255 .48466 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .5184 .49095 L .52184 .48806 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51542 .49311 L .5184 .49095 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51312 .4944 L .51542 .49311 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51164 .49473 L .51312 .4944 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .5111 .49408 L .51164 .49473 L closepath p 0 0 0 r
F P
0 g
s
.52511 .48046 m .51151 .49251 L .5111 .49408 L closepath p 0 0 0 r
F P
0 g
s
.54969 .46123 m .5374 .4708 L .53528 .4738 L p 0 0 0 r
F P
0 g
s
.562 .45187 m .54969 .46123 L .54551 .46711 L p 0 0 0 r
F P
0 g
s
.53528 .4738 m .54551 .46711 L .54969 .46123 L p 0 0 0 r
F P
0 g
s
.28164 .55426 m .29541 .56284 L .30756 .5726 L p .041 .527 .884 r
F P
0 g
s
.32063 .57578 m .29817 .56506 L .30365 .56707 L .024 .549 .86 r
F
.29817 .56506 m .29541 .56284 L p .30365 .56707 L F P
0 g
s
.29541 .56284 m .30935 .57004 L .32063 .57578 L p .024 .549 .86 r
F P
0 g
s
.33383 .57782 m .32063 .57578 L .31231 .57155 L p .013 .568 .818 r
F P
0 g
s
.31231 .57155 m .30935 .57004 L p .3182 .57286 L .013 .568 .818 r
F P
0 g
s
.33383 .57782 m .31231 .57155 L .3182 .57286 L .013 .568 .818 r
F
.30935 .57004 m .32343 .57567 L .33193 .57743 L p F P
0 g
s
.33193 .57743 m .33383 .57782 L p .3276 .57584 L .013 .568 .818 r
F P
0 g
s
.3276 .57584 m .30935 .57004 L .33193 .57743 L .013 .568 .818 r
F
.34715 .57863 m .33383 .57782 L .32343 .57567 L p .007 .58 .759 r
F P
0 g
s
.32343 .57567 m .33766 .57957 L .34513 .57883 L p .007 .58 .759 r
F P
0 g
s
.34513 .57883 m .34715 .57863 L p .34045 .57779 L .007 .58 .759 r
F P
0 g
s
.34045 .57779 m .32343 .57567 L .34513 .57883 L .007 .58 .759 r
F
.32063 .57578 m .30756 .5726 L .29817 .56506 L p .024 .549 .86 r
F P
0 g
s
.57433 .44281 m .562 .45187 L .5558 .46042 L p 0 0 0 r
F P
0 g
s
.54551 .46711 m .5558 .46042 L .562 .45187 L p 0 0 0 r
F P
0 g
s
.77072 .39671 m .75634 .39221 L .73997 .37926 L p .377 .757 .99 r
F P
0 g
s
.72665 .38024 m .73997 .37926 L .75634 .39221 L p .351 .775 .974 r
F P
0 g
s
.49696 .50755 m .5111 .49408 L .51151 .49251 L p 0 0 0 r
F P
0 g
s
.51151 .49251 m .49785 .5044 L .49696 .50755 L p 0 0 0 r
F P
0 g
s
.58669 .43415 m .57433 .44281 L .56615 .45375 L p 0 0 0 r
F P
0 g
s
.5558 .46042 m .56615 .45375 L .57433 .44281 L p 0 0 0 r
F P
0 g
s
.54551 .46711 m .53528 .4738 L .53246 .47727 L p 0 0 0 r
F P
0 g
s
.20202 .48668 m .18911 .47507 L .19318 .42214 L p .292 .416 .817 r
F P
0 g
s
.59908 .42597 m .58669 .43415 L .57657 .4471 L p 0 0 0 r
F P
0 g
s
.56615 .45375 m .57657 .4471 L .58669 .43415 L p 0 0 0 r
F P
0 g
s
.4827 .5206 m .49696 .50755 L .49785 .5044 L p 0 0 0 r
F P
0 g
s
.49785 .5044 m .48414 .51596 L .4827 .5206 L p 0 0 0 r
F P
0 g
s
.6115 .41835 m .59908 .42597 L .58705 .4405 L p 0 0 0 r
F P
0 g
s
.57657 .4471 m .58705 .4405 L .59908 .42597 L p 0 0 0 r
F P
0 g
s
.498 .50885 m .51164 .49473 L .5111 .49408 L p 0 0 0 r
F P
0 g
s
.5111 .49408 m .49696 .50755 L .498 .50885 L p 0 0 0 r
F P
0 g
s
.78525 .40193 m .77072 .39671 L .75341 .37876 L p .399 .734 .991 r
F P
0 g
s
.73997 .37926 m .75341 .37876 L .77072 .39671 L p .377 .757 .99 r
F P
0 g
s
.53246 .47727 m .53988 .47397 L .54551 .46711 L p 0 0 0 r
F P
0 g
s
.53988 .47397 m .53246 .47727 L .52912 .48098 L p 0 0 0 r
F P
0 g
s
.62398 .41134 m .6115 .41835 L .5976 .43396 L p 0 0 0 r
F P
0 g
s
.58705 .4405 m .5976 .43396 L .6115 .41835 L p 0 0 0 r
F P
0 g
s
.46834 .53297 m .4827 .5206 L .48414 .51596 L p 0 0 0 r
F P
0 g
s
.48414 .51596 m .47039 .52698 L .46834 .53297 L p 0 0 0 r
F P
0 g
s
.5558 .46042 m .54551 .46711 L .53988 .47397 L p 0 0 0 r
F P
0 g
s
.50093 .5082 m .51312 .4944 L .51164 .49473 L p 0 0 0 r
F P
0 g
s
.51164 .49473 m .498 .50885 L .50093 .5082 L p 0 0 0 r
F P
0 g
s
.19318 .42214 m .20607 .43848 L .20202 .48668 L p .292 .416 .817 r
F P
0 g
s
.215 .4986 m .20202 .48668 L .20607 .43848 L p .265 .403 .816 r
F P
0 g
s
.63651 .40499 m .62398 .41134 L .60821 .42749 L p 0 0 0 r
F P
0 g
s
.5976 .43396 m .60821 .42749 L .62398 .41134 L p 0 0 0 r
F P
0 g
s
.52912 .48098 m .53319 .48133 L .53988 .47397 L p 0 0 0 r
F P
0 g
s
.53319 .48133 m .52912 .48098 L .5255 .48466 L p 0 0 0 r
F P
0 g
s
.45388 .5444 m .46834 .53297 L .47039 .52698 L p 0 0 0 r
F P
0 g
s
.47039 .52698 m .45661 .53729 L .45388 .5444 L p 0 0 0 r
F P
0 g
s
.3606 .57812 m .34715 .57863 L .33766 .57957 L p 0 0 0 r
F P
0 g
s
.50556 .50562 m .51542 .49311 L .51312 .4944 L p 0 0 0 r
F P
0 g
s
.51312 .4944 m .50093 .5082 L .50556 .50562 L p 0 0 0 r
F P
0 g
s
.64911 .39934 m .63651 .40499 L .6189 .42109 L p 0 0 0 r
F P
0 g
s
.60821 .42749 m .6189 .42109 L .63651 .40499 L p 0 0 0 r
F P
0 g
s
.79992 .40772 m .78525 .40193 L .76698 .37865 L p .418 .71 .984 r
F P
0 g
s
.75341 .37876 m .76698 .37865 L .78525 .40193 L p .399 .734 .991 r
F P
0 g
s
.5255 .48466 m .52589 .48869 L .53319 .48133 L p 0 0 0 r
F P
0 g
s
.52589 .48869 m .5255 .48466 L .52184 .48806 L p 0 0 0 r
F P
0 g
s
.48419 .52252 m .498 .50885 L .49696 .50755 L p 0 0 0 r
F P
0 g
s
.49696 .50755 m .4827 .5206 L .48419 .52252 L p 0 0 0 r
F P
0 g
s
.43936 .55465 m .45388 .5444 L .45661 .53729 L p 0 0 0 r
F P
0 g
s
.45661 .53729 m .44281 .54672 L .43936 .55465 L p 0 0 0 r
F P
0 g
s
.56615 .45375 m .5558 .46042 L .54738 .47049 L p 0 0 0 r
F P
0 g
s
.53988 .47397 m .54738 .47049 L .5558 .46042 L p 0 0 0 r
F P
0 g
s
.51156 .50129 m .5184 .49095 L .51542 .49311 L p 0 0 0 r
F P
0 g
s
.51542 .49311 m .50556 .50562 L .51156 .50129 L p 0 0 0 r
F P
0 g
s
.52184 .48806 m .5185 .4955 L .52589 .48869 L p 0 0 0 r
F P
0 g
s
.5185 .4955 m .52184 .48806 L .5184 .49095 L p 0 0 0 r
F P
0 g
s
.33766 .57957 m .352 .58163 L .3606 .57812 L p 0 0 0 r
F P
0 g
s
.37414 .57625 m .3606 .57812 L .35444 .58064 L p 0 0 0 r
F P
0 g
s
.37414 .57625 m .35444 .58064 L .35609 .58064 L 0 0 0 r
F
.352 .58163 m .36645 .58179 L .37414 .57625 L p F P
0 g
s
.38777 .57298 m .37414 .57625 L .36891 .58002 L p 0 0 0 r
F P
0 g
s
.36891 .58002 m .36645 .58179 L p .3707 .58003 L 0 0 0 r
F P
0 g
s
.38777 .57298 m .36891 .58002 L .3707 .58003 L 0 0 0 r
F
.36645 .58179 m .38098 .58001 L .38777 .57298 L p F P
0 g
s
.38098 .58001 m .36645 .58179 L .36984 .58029 L p .138 .684 .75 r
F P
0 g
s
.36984 .58029 m .38426 .58018 L .38389 .58016 L p .138 .684 .75 r
F P
0 g
s
.38389 .58016 m .38098 .58001 L p .37739 .5801 L .138 .684 .75 r
F P
0 g
s
.37739 .5801 m .36984 .58029 L .38389 .58016 L .138 .684 .75 r
F
.35547 .57803 m .36984 .58029 L .36902 .58065 L p .151 .686 .846 r
F P
0 g
s
.36902 .58065 m .36645 .58179 L p .36312 .58065 L .151 .686 .846 r
F P
0 g
s
.36312 .58065 m .35547 .57803 L .36902 .58065 L .151 .686 .846 r
F
.35444 .58064 m .352 .58163 L p .35609 .58064 L 0 0 0 r
F P
0 g
s
.5184 .49095 m .51156 .50129 L .5185 .4955 L p 0 0 0 r
F P
0 g
s
.20607 .43848 m .21902 .45521 L .215 .4986 L p .265 .403 .816 r
F P
0 g
s
.22806 .5106 m .215 .4986 L .21902 .45521 L p .241 .396 .819 r
F P
0 g
s
.66179 .39441 m .64911 .39934 L .62967 .41478 L p 0 0 0 r
F P
0 g
s
.6189 .42109 m .62967 .41478 L .64911 .39934 L p 0 0 0 r
F P
0 g
s
.42478 .56351 m .43936 .55465 L .44281 .54672 L p 0 0 0 r
F P
0 g
s
.44281 .54672 m .42901 .55512 L .42478 .56351 L p 0 0 0 r
F P
0 g
s
.54738 .47049 m .53988 .47397 L .53319 .48133 L p 0 0 0 r
F P
0 g
s
.41017 .57078 m .42478 .56351 L .42901 .55512 L p 0 0 0 r
F P
0 g
s
.42901 .55512 m .41522 .56236 L .41017 .57078 L p 0 0 0 r
F P
0 g
s
.40147 .56834 m .38777 .57298 L .38098 .58001 L p 0 0 0 r
F P
0 g
s
.39556 .57632 m .41017 .57078 L .41522 .56236 L p 0 0 0 r
F P
0 g
s
.41522 .56236 m .40147 .56834 L .39556 .57632 L p 0 0 0 r
F P
0 g
s
.38098 .58001 m .39556 .57632 L .40147 .56834 L p 0 0 0 r
F P
0 g
s
.81473 .41391 m .79992 .40772 L .78067 .37885 L p .435 .689 .972 r
F P
0 g
s
.76698 .37865 m .78067 .37885 L .79992 .40772 L p .418 .71 .984 r
F P
0 g
s
.57657 .4471 m .56615 .45375 L .55496 .46675 L p 0 0 0 r
F P
0 g
s
.54738 .47049 m .55496 .46675 L .56615 .45375 L p 0 0 0 r
F P
0 g
s
.67455 .3902 m .66179 .39441 L .64141 .40794 L p .365 .803 .641 r
F P
0 g
s
.64141 .40794 m .64097 .40824 L p .64191 .40773 L .365 .803 .641 r
F P
0 g
s
.64191 .40773 m .67455 .3902 L .64141 .40794 L .365 .803 .641 r
F
.64181 .40784 m .67455 .3902 L .64097 .40824 L F
.6405 .40855 m .65142 .40241 L .67455 .3902 L p F P
0 g
s
.68741 .38671 m .67455 .3902 L .65227 .40196 L p .428 .857 .732 r
F P
0 g
s
.65227 .40196 m .65142 .40241 L p .65318 .40164 L .428 .857 .732 r
F P
0 g
s
.65318 .40164 m .68741 .38671 L .65227 .40196 L .428 .857 .732 r
F
.65142 .40241 m .66241 .39636 L .66283 .3962 L p F P
0 g
s
.66283 .3962 m .68477 .38773 L p .65323 .40161 L .428 .857 .732 r
F P
0 g
s
.65142 .40241 m .66283 .3962 L .65323 .40161 L .428 .857 .732 r
F
.68477 .38773 m .68741 .38671 L p .68062 .38967 L F P
0 g
s
.65142 .40241 m .68477 .38773 L .68062 .38967 L .428 .857 .732 r
F
.70038 .38391 m .68741 .38671 L .66241 .39636 L p .487 .9 .818 r
F P
0 g
s
.66241 .39636 m .67349 .39039 L .6952 .38516 L p .487 .9 .818 r
F P
0 g
s
.6952 .38516 m .70038 .38391 L p .6905 .38715 L .487 .9 .818 r
F P
0 g
s
.66241 .39636 m .6952 .38516 L .6905 .38715 L .487 .9 .818 r
F
.71346 .38177 m .70038 .38391 L .67349 .39039 L p .54 .926 .888 r
F P
0 g
s
.67349 .39039 m .68465 .38449 L .70857 .38223 L p .54 .926 .888 r
F P
0 g
s
.70857 .38223 m .71346 .38177 L p .70419 .38377 L .54 .926 .888 r
F P
0 g
s
.67349 .39039 m .70857 .38223 L .70419 .38377 L .54 .926 .888 r
F
.64097 .40824 m .6405 .40855 L p .64181 .40784 L .365 .803 .641 r
F P
0 g
s
.62967 .41478 m .6405 .40855 L .66179 .39441 L p 0 0 0 r
F P
0 g
s
.48855 .52152 m .50093 .5082 L .498 .50885 L p 0 0 0 r
F P
0 g
s
.498 .50885 m .48419 .52252 L .48855 .52152 L p 0 0 0 r
F P
0 g
s
.47022 .5354 m .48419 .52252 L .4827 .5206 L p 0 0 0 r
F P
0 g
s
.4827 .5206 m .46834 .53297 L .47022 .5354 L p 0 0 0 r
F P
0 g
s
.21902 .45521 m .23204 .47203 L .22806 .5106 L p .241 .396 .819 r
F P
0 g
s
.24125 .52242 m .22806 .5106 L .23204 .47203 L p .22 .396 .825 r
F P
0 g
s
.53319 .48133 m .53731 .48137 L .54738 .47049 L p 0 0 0 r
F P
0 g
s
.53731 .48137 m .53319 .48133 L .52589 .48869 L p 0 0 0 r
F P
0 g
s
.58705 .4405 m .57657 .4471 L .56261 .46269 L p 0 0 0 r
F P
0 g
s
.55496 .46675 m .56261 .46269 L .57657 .4471 L p 0 0 0 r
F P
0 g
s
.82966 .42034 m .81473 .41391 L .79449 .37926 L p .452 .672 .958 r
F P
0 g
s
.78067 .37885 m .79449 .37926 L .81473 .41391 L p .435 .689 .972 r
F P
0 g
s
.55496 .46675 m .54738 .47049 L .53731 .48137 L p 0 0 0 r
F P
0 g
s
.49551 .51764 m .50556 .50562 L .50093 .5082 L p 0 0 0 r
F P
0 g
s
.50093 .5082 m .48855 .52152 L .49551 .51764 L p 0 0 0 r
F P
0 g
s
.23204 .47203 m .24518 .48863 L .24125 .52242 L p .22 .396 .825 r
F P
0 g
s
.25456 .53381 m .24125 .52242 L .24518 .48863 L p .203 .402 .836 r
F P
0 g
s
.45611 .54717 m .47022 .5354 L .46834 .53297 L p 0 0 0 r
F P
0 g
s
.46834 .53297 m .45388 .5444 L .45611 .54717 L p 0 0 0 r
F P
0 g
s
.52589 .48869 m .52628 .4923 L .53731 .48137 L p 0 0 0 r
F P
0 g
s
.52628 .4923 m .52589 .48869 L .5185 .4955 L p 0 0 0 r
F P
0 g
s
.5976 .43396 m .58705 .4405 L .57034 .45824 L p 0 0 0 r
F P
0 g
s
.56261 .46269 m .57034 .45824 L .58705 .4405 L p 0 0 0 r
F P
0 g
s
.50458 .51114 m .51156 .50129 L .50556 .50562 L p 0 0 0 r
F P
0 g
s
.50556 .50562 m .49551 .51764 L .50458 .51114 L p 0 0 0 r
F P
0 g
s
.5185 .4955 m .5151 .50247 L .52628 .4923 L p 0 0 0 r
F P
0 g
s
.5151 .50247 m .5185 .4955 L .51156 .50129 L p 0 0 0 r
F P
0 g
s
.47599 .534 m .48855 .52152 L .48419 .52252 L p 0 0 0 r
F P
0 g
s
.48419 .52252 m .47022 .5354 L .47599 .534 L p 0 0 0 r
F P
0 g
s
.84472 .42682 m .82966 .42034 L .80842 .37978 L p .468 .658 .944 r
F P
0 g
s
.79449 .37926 m .80842 .37978 L .82966 .42034 L p .452 .672 .958 r
F P
0 g
s
.51156 .50129 m .50458 .51114 L .5151 .50247 L p 0 0 0 r
F P
0 g
s
.24518 .48863 m .25844 .5047 L .25456 .53381 L p .203 .402 .836 r
F P
0 g
s
.26802 .5445 m .25456 .53381 L .25844 .5047 L p .19 .417 .851 r
F P
0 g
s
.44187 .55755 m .45611 .54717 L .45388 .5444 L p 0 0 0 r
F P
0 g
s
.45388 .5444 m .43936 .55465 L .44187 .55755 L p 0 0 0 r
F P
0 g
s
.56261 .46269 m .55496 .46675 L .54149 .48093 L p 0 0 0 r
F P
0 g
s
.53731 .48137 m .54149 .48093 L .55496 .46675 L p 0 0 0 r
F P
0 g
s
.60821 .42749 m .5976 .43396 L .57814 .45334 L p 0 0 0 r
F P
0 g
s
.57034 .45824 m .57814 .45334 L .5976 .43396 L p 0 0 0 r
F P
0 g
s
.54149 .48093 m .53731 .48137 L .52628 .4923 L p 0 0 0 r
F P
0 g
s
.72665 .38024 m .71346 .38177 L .68465 .38449 L p .58 .933 .94 r
F P
0 g
s
.85986 .43317 m .84472 .42682 L .82246 .38031 L p .484 .649 .931 r
F P
0 g
s
.80842 .37978 m .82246 .38031 L .84472 .42682 L p .468 .658 .944 r
F P
0 g
s
.25844 .5047 m .27184 .51993 L .26802 .5445 L p .19 .417 .851 r
F P
0 g
s
.28164 .55426 m .26802 .5445 L .27184 .51993 L p .18 .44 .87 r
F P
0 g
s
.42754 .56625 m .44187 .55755 L .43936 .55465 L p 0 0 0 r
F P
0 g
s
.43936 .55465 m .42478 .56351 L .42754 .56625 L p 0 0 0 r
F P
0 g
s
.4853 .5288 m .49551 .51764 L .48855 .52152 L p 0 0 0 r
F P
0 g
s
.48855 .52152 m .47599 .534 L .4853 .5288 L p 0 0 0 r
F P
0 g
s
.6189 .42109 m .60821 .42749 L .586 .44796 L p 0 0 0 r
F P
0 g
s
.57814 .45334 m .586 .44796 L .60821 .42749 L p 0 0 0 r
F P
0 g
s
.46326 .54527 m .47599 .534 L .47022 .5354 L p 0 0 0 r
F P
0 g
s
.47022 .5354 m .45611 .54717 L .46326 .54527 L p 0 0 0 r
F P
0 g
s
.73997 .37926 m .72665 .38024 L .69589 .37866 L p .608 .924 .971 r
F P
0 g
s
.68465 .38449 m .69589 .37866 L .72665 .38024 L p .58 .933 .94 r
F P
0 g
s
.52628 .4923 m .52668 .49526 L .54149 .48093 L p 0 0 0 r
F P
0 g
s
.52668 .49526 m .52628 .4923 L .5151 .50247 L p 0 0 0 r
F P
0 g
s
.27184 .51993 m .28541 .534 L .28164 .55426 L p .18 .44 .87 r
F P
0 g
s
.29541 .56284 m .28164 .55426 L .28541 .534 L p .173 .473 .893 r
F P
0 g
s
.57034 .45824 m .56261 .46269 L .54572 .47984 L p 0 0 0 r
F P
0 g
s
.54149 .48093 m .54572 .47984 L .56261 .46269 L p 0 0 0 r
F P
0 g
s
.41314 .57305 m .42754 .56625 L .42478 .56351 L p 0 0 0 r
F P
0 g
s
.42478 .56351 m .41017 .57078 L .41314 .57305 L p 0 0 0 r
F P
0 g
s
.82246 .38031 m .8366 .38074 L .85986 .43317 L p .484 .649 .931 r
F P
0 g
s
.49748 .52014 m .50458 .51114 L .49551 .51764 L p 0 0 0 r
F P
0 g
s
.49551 .51764 m .4853 .5288 L .49748 .52014 L p 0 0 0 r
F P
0 g
s
.57814 .45334 m .57034 .45824 L .55001 .47798 L p 0 0 0 r
F P
0 g
s
.586 .44796 m .57814 .45334 L .55435 .4752 L p .465 .817 .539 r
F P
0 g
s
.55001 .47798 m .55435 .4752 L .56609 .46441 L p 0 0 0 r
F P
0 g
s
.56609 .46441 m .57814 .45334 L p .55865 .47041 L 0 0 0 r
F P
0 g
s
.55001 .47798 m .56609 .46441 L .55865 .47041 L 0 0 0 r
F
.55435 .4752 m .55873 .47139 L .57819 .45467 L p .465 .817 .539 r
F P
0 g
s
.57819 .45467 m .586 .44796 L p .57781 .45501 L .465 .817 .539 r
F P
0 g
s
.55435 .4752 m .57819 .45467 L .57781 .45501 L .465 .817 .539 r
F
.56316 .46646 m .56745 .46304 L .57978 .45326 L .692 .967 .742 r
F
.59394 .44203 m .586 .44796 L .57819 .45467 L p .584 .904 .647 r
F P
0 g
s
.57819 .45467 m .55873 .47139 L p .59394 .44203 L .584 .904 .647 r
F P
0 g
s
.57971 .45332 m .57978 .45326 L .58798 .44676 L .692 .967 .742 r
F
.56316 .46646 m .57978 .45326 L .57971 .45332 L F
.59394 .44203 m .58771 .44698 L p .58798 .44676 L F P
0 g
s
.58771 .44698 m .56316 .46646 L p .58798 .44676 L .692 .967 .742 r
F P
0 g
s
.62447 .41782 m .6189 .42109 L .59394 .44203 L p .473 .84 .593 r
F P
0 g
s
.586 .44796 m .59394 .44203 L .6189 .42109 L p 0 0 0 r
F P
0 g
s
.60193 .43555 m .59394 .44203 L p .56745 .46304 L .692 .967 .742 r
F P
0 g
s
.62967 .41478 m .62447 .41782 L p .59394 .44203 L .473 .84 .593 r
F P
0 g
s
.5151 .50247 m .51164 .50867 L .52668 .49526 L p 0 0 0 r
F P
0 g
s
.51164 .50867 m .5151 .50247 L .50458 .51114 L p 0 0 0 r
F P
0 g
s
.28541 .534 m .29913 .54663 L .29541 .56284 L p .173 .473 .893 r
F P
0 g
s
.30935 .57004 m .29541 .56284 L .29913 .54663 L p .169 .515 .915 r
F P
0 g
s
.54572 .47984 m .54149 .48093 L .52668 .49526 L p 0 0 0 r
F P
0 g
s
.50458 .51114 m .49748 .52014 L .51164 .50867 L p 0 0 0 r
F P
0 g
s
.3987 .57774 m .41314 .57305 L .41017 .57078 L p 0 0 0 r
F P
0 g
s
.41017 .57078 m .39556 .57632 L .3987 .57774 L p 0 0 0 r
F P
0 g
s
.75341 .37876 m .73997 .37926 L .70722 .37289 L p .626 .903 .985 r
F P
0 g
s
.69589 .37866 m .70722 .37289 L .73997 .37926 L p .608 .924 .971 r
F P
0 g
s
.29913 .54663 m .31301 .55756 L .30935 .57004 L p .169 .515 .915 r
F P
0 g
s
.32343 .57567 m .30935 .57004 L .31301 .55756 L p .167 .565 .933 r
F P
0 g
s
.45039 .55501 m .46326 .54527 L .45611 .54717 L p 0 0 0 r
F P
0 g
s
.45611 .54717 m .44187 .55755 L .45039 .55501 L p 0 0 0 r
F P
0 g
s
.38426 .58018 m .3987 .57774 L .39556 .57632 L p 0 0 0 r
F P
0 g
s
.39556 .57632 m .38098 .58001 L .38426 .58018 L p 0 0 0 r
F P
0 g
s
.59394 .44203 m .60193 .43555 L .62967 .41478 L p .473 .84 .593 r
F P
0 g
s
.6405 .40855 m .62967 .41478 L .60193 .43555 L p .563 .907 .686 r
F P
0 g
s
.54572 .47984 m .55001 .47798 L .57034 .45824 L p 0 0 0 r
F P
0 g
s
.31301 .55756 m .32704 .56655 L .32343 .57567 L p .167 .565 .933 r
F P
0 g
s
.33766 .57957 m .32343 .57567 L .32704 .56655 L p .164 .617 .935 r
F P
0 g
s
.47492 .53873 m .4853 .5288 L .47599 .534 L p 0 0 0 r
F P
0 g
s
.47599 .534 m .46326 .54527 L .47492 .53873 L p 0 0 0 r
F P
0 g
s
.76698 .37865 m .75341 .37876 L .71864 .36716 L p .634 .875 .986 r
F P
0 g
s
.70722 .37289 m .71864 .36716 L .75341 .37876 L p .626 .903 .985 r
F P
0 g
s
.32704 .56655 m .3412 .57342 L .33766 .57957 L p .164 .617 .935 r
F P
0 g
s
.352 .58163 m .33766 .57957 L .3412 .57342 L p .16 .662 .909 r
F P
0 g
s
.36645 .58179 m .352 .58163 L .35547 .57803 L p .151 .686 .846 r
F P
0 g
s
.20607 .43848 m .19318 .42214 L .22154 .37026 L p .388 .415 .767 r
F P
0 g
s
.3412 .57342 m .35547 .57803 L .352 .58163 L p .16 .662 .909 r
F P
0 g
s
.52668 .49526 m .52709 .49733 L .54572 .47984 L p 0 0 0 r
F P
0 g
s
.52709 .49733 m .52668 .49526 L .51164 .50867 L p 0 0 0 r
F P
0 g
s
.60193 .43555 m .60999 .42848 L .6405 .40855 L p .563 .907 .686 r
F P
0 g
s
.65142 .40241 m .6405 .40855 L .60999 .42848 L p .645 .957 .768 r
F P
0 g
s
.55001 .47798 m .54572 .47984 L .52709 .49733 L p 0 0 0 r
F P
0 g
s
.22154 .37026 m .23353 .39051 L .20607 .43848 L p .388 .415 .767 r
F P
0 g
s
.21902 .45521 m .20607 .43848 L .23353 .39051 L p .376 .406 .765 r
F P
0 g
s
.43738 .56291 m .45039 .55501 L .44187 .55755 L p 0 0 0 r
F P
0 g
s
.44187 .55755 m .42754 .56625 L .43738 .56291 L p 0 0 0 r
F P
0 g
s
.49026 .52797 m .49748 .52014 L .4853 .5288 L p 0 0 0 r
F P
0 g
s
.4853 .5288 m .47492 .53873 L .49026 .52797 L p 0 0 0 r
F P
0 g
s
.78067 .37885 m .76698 .37865 L .73014 .36146 L p .637 .845 .98 r
F P
0 g
s
.71864 .36716 m .73014 .36146 L .76698 .37865 L p .634 .875 .986 r
F P
0 g
s
.51164 .50867 m .50812 .5138 L .52709 .49733 L p 0 0 0 r
F P
0 g
s
.50812 .5138 m .51164 .50867 L .49748 .52014 L p 0 0 0 r
F P
0 g
s
.60999 .42848 m .6181 .42082 L .65142 .40241 L p .645 .957 .768 r
F P
0 g
s
.66241 .39636 m .65142 .40241 L .6181 .42082 L p .711 .986 .834 r
F P
0 g
s
.49748 .52014 m .49026 .52797 L .50812 .5138 L p 0 0 0 r
F P
0 g
s
.23353 .39051 m .24555 .41116 L .21902 .45521 L p .376 .406 .765 r
F P
0 g
s
.23204 .47203 m .21902 .45521 L .24555 .41116 L p .367 .403 .767 r
F P
0 g
s
.46441 .54708 m .47492 .53873 L .46326 .54527 L p 0 0 0 r
F P
0 g
s
.46326 .54527 m .45039 .55501 L .46441 .54708 L p 0 0 0 r
F P
0 g
s
.79449 .37926 m .78067 .37885 L .74174 .35576 L p .637 .815 .969 r
F P
0 g
s
.73014 .36146 m .74174 .35576 L .78067 .37885 L p .637 .845 .98 r
F P
0 g
s
.42428 .5687 m .43738 .56291 L .42754 .56625 L p 0 0 0 r
F P
0 g
s
.42754 .56625 m .41314 .57305 L .42428 .5687 L p 0 0 0 r
F P
0 g
s
.67349 .39039 m .66241 .39636 L .62627 .41256 L p .759 .992 .879 r
F P
0 g
s
.6181 .42082 m .62627 .41256 L .66241 .39636 L p .711 .986 .834 r
F P
0 g
s
.24555 .41116 m .25763 .4319 L .23204 .47203 L p .367 .403 .767 r
F P
0 g
s
.24518 .48863 m .23204 .47203 L .25763 .4319 L p .361 .405 .772 r
F P
0 g
s
.55435 .4752 m .55001 .47798 L .52751 .49828 L p .461 .814 .536 r
F P
0 g
s
.52709 .49733 m .52751 .49828 L .55001 .47798 L p 0 0 0 r
F P
0 g
s
.52751 .49828 m .52709 .49733 L .50812 .5138 L p 0 0 0 r
F P
0 g
s
.80842 .37978 m .79449 .37926 L .75342 .35006 L p .635 .788 .956 r
F P
0 g
s
.74174 .35576 m .75342 .35006 L .79449 .37926 L p .637 .815 .969 r
F P
0 g
s
.68465 .38449 m .67349 .39039 L .63448 .40374 L p .788 .981 .905 r
F P
0 g
s
.62627 .41256 m .63448 .40374 L .67349 .39039 L p .759 .992 .879 r
F P
0 g
s
.48294 .53427 m .49026 .52797 L .47492 .53873 L p 0 0 0 r
F P
0 g
s
.47492 .53873 m .46441 .54708 L .48294 .53427 L p 0 0 0 r
F P
0 g
s
.41111 .57215 m .42428 .5687 L .41314 .57305 L p .31 .795 .744 r
F P
0 g
s
.41314 .57305 m .3987 .57774 L .41111 .57215 L p .31 .795 .744 r
F P
0 g
s
.25763 .4319 m .26979 .45238 L .24518 .48863 L p .361 .405 .772 r
F P
0 g
s
.25844 .5047 m .24518 .48863 L .26979 .45238 L p .359 .413 .781 r
F P
0 g
s
.55873 .47139 m .56316 .46646 L .59394 .44203 L p .584 .904 .647 r
F P
0 g
s
.45376 .55354 m .46441 .54708 L .45039 .55501 L p 0 0 0 r
F P
0 g
s
.45039 .55501 m .43738 .56291 L .45376 .55354 L p 0 0 0 r
F P
0 g
s
.50812 .5138 m .50454 .51756 L .52751 .49828 L p 0 0 0 r
F P
0 g
s
.50454 .51756 m .50812 .5138 L .49026 .52797 L p 0 0 0 r
F P
0 g
s
.49026 .52797 m .48294 .53427 L .50454 .51756 L p 0 0 0 r
F P
0 g
s
.26979 .45238 m .28206 .47225 L .25844 .5047 L p .359 .413 .781 r
F P
0 g
s
.27184 .51993 m .25844 .5047 L .28206 .47225 L p .359 .427 .795 r
F P
0 g
s
.82246 .38031 m .80842 .37978 L .7652 .34434 L p .632 .764 .942 r
F P
0 g
s
.75342 .35006 m .7652 .34434 L .80842 .37978 L p .635 .788 .956 r
F P
0 g
s
.69589 .37866 m .68465 .38449 L .64275 .39437 L p .801 .957 .916 r
F P
0 g
s
.63448 .40374 m .64275 .39437 L .68465 .38449 L p .788 .981 .905 r
F P
0 g
s
.39791 .5731 m .41111 .57215 L .3987 .57774 L p .371 .837 .881 r
F P
0 g
s
.3987 .57774 m .38426 .58018 L .39791 .5731 L p .371 .837 .881 r
F P
0 g
s
.55873 .47139 m .55435 .4752 L .52793 .49792 L p .602 .916 .664 r
F P
0 g
s
.52751 .49828 m .52793 .49792 L .55435 .4752 L p .461 .814 .536 r
F P
0 g
s
.60999 .42848 m .60193 .43555 L .56762 .46033 L p .775 .997 .811 r
F P
0 g
s
.56316 .46646 m .56762 .46033 L .60193 .43555 L p .692 .967 .742 r
F P
0 g
s
.52793 .49792 m .52751 .49828 L .50454 .51756 L p .525 .871 .619 r
F P
0 g
s
.28206 .47225 m .29446 .49117 L .27184 .51993 L p .359 .427 .795 r
F P
0 g
s
.28541 .534 m .27184 .51993 L .29446 .49117 L p .362 .448 .814 r
F P
0 g
s
.3847 .57144 m .39791 .5731 L .38426 .58018 L p .411 .828 .969 r
F P
0 g
s
.38426 .58018 m .36984 .58029 L .3847 .57144 L p .411 .828 .969 r
F P
0 g
s
.70722 .37289 m .69589 .37866 L .65106 .38448 L p .804 .927 .916 r
F P
0 g
s
.64275 .39437 m .65106 .38448 L .69589 .37866 L p .801 .957 .916 r
F P
0 g
s
.8366 .38074 m .82246 .38031 L .77706 .33857 L p .629 .743 .93 r
F P
0 g
s
.7652 .34434 m .77706 .33857 L .82246 .38031 L p .632 .764 .942 r
F P
0 g
s
.44301 .55783 m .45376 .55354 L .43738 .56291 L p .441 .867 .747 r
F P
0 g
s
.43738 .56291 m .42428 .5687 L .44301 .55783 L p .441 .867 .747 r
F P
0 g
s
.29446 .49117 m .30699 .50878 L .28541 .534 L p .362 .448 .814 r
F P
0 g
s
.29913 .54663 m .28541 .534 L .30699 .50878 L p .369 .477 .839 r
F P
0 g
s
.47551 .53875 m .48294 .53427 L .46441 .54708 L p .456 .851 .652 r
F P
0 g
s
.46441 .54708 m .45376 .55354 L .47551 .53875 L p .456 .851 .652 r
F P
0 g
s
.37152 .56712 m .3847 .57144 L .36984 .58029 L p .425 .775 .996 r
F P
0 g
s
.36984 .58029 m .35547 .57803 L .37152 .56712 L p .425 .775 .996 r
F P
0 g
s
.30699 .50878 m .31965 .52475 L .29913 .54663 L p .369 .477 .839 r
F P
0 g
s
.31301 .55756 m .29913 .54663 L .31965 .52475 L p .379 .516 .869 r
F P
0 g
s
.6181 .42082 m .60999 .42848 L .57211 .45296 L p .828 .995 .852 r
F P
0 g
s
.56762 .46033 m .57211 .45296 L .60999 .42848 L p .775 .997 .811 r
F P
0 g
s
.56316 .46646 m .55873 .47139 L .52835 .49606 L p .727 .982 .771 r
F P
0 g
s
.52793 .49792 m .52835 .49606 L .55873 .47139 L p .602 .916 .664 r
F P
0 g
s
.50454 .51756 m .50092 .51969 L .52793 .49792 L p .525 .871 .619 r
F P
0 g
s
.50092 .51969 m .50454 .51756 L .48294 .53427 L p .525 .885 .663 r
F P
0 g
s
.35841 .56017 m .37152 .56712 L .35547 .57803 L p .42 .702 .98 r
F P
0 g
s
.35547 .57803 m .3412 .57342 L .35841 .56017 L p .42 .702 .98 r
F P
0 g
s
.31965 .52475 m .33245 .53881 L .31301 .55756 L p .379 .516 .869 r
F P
0 g
s
.32704 .56655 m .31301 .55756 L .33245 .53881 L p .392 .567 .905 r
F P
0 g
s
.71864 .36716 m .70722 .37289 L .65941 .37413 L p .799 .895 .912 r
F P
0 g
s
.65106 .38448 m .65941 .37413 L .70722 .37289 L p .804 .927 .916 r
F P
0 g
s
.34538 .55069 m .35841 .56017 L .3412 .57342 L p .407 .629 .945 r
F P
0 g
s
.3412 .57342 m .32704 .56655 L .34538 .55069 L p .407 .629 .945 r
F P
0 g
s
.48294 .53427 m .47551 .53875 L .50092 .51969 L p .525 .885 .663 r
F P
0 g
s
.33245 .53881 m .34538 .55069 L .32704 .56655 L p .392 .567 .905 r
F P
0 g
s
.77706 .33857 m .78901 .33274 L .8366 .38074 L p .629 .743 .93 r
F P
0 g
s
.52835 .49606 m .52793 .49792 L .50092 .51969 L p .674 .965 .757 r
F P
0 g
s
.43218 .5597 m .44301 .55783 L .42428 .5687 L p .543 .927 .895 r
F P
0 g
s
.42428 .5687 m .41111 .57215 L .43218 .5597 L p .543 .927 .895 r
F P
0 g
s
.62627 .41256 m .6181 .42082 L .57664 .44433 L p .855 .972 .868 r
F P
0 g
s
.57211 .45296 m .57664 .44433 L .6181 .42082 L p .828 .995 .852 r
F P
0 g
s
.73014 .36146 m .71864 .36716 L .66781 .36336 L p .791 .864 .904 r
F P
0 g
s
.65941 .37413 m .66781 .36336 L .71864 .36716 L p .799 .895 .912 r
F P
0 g
s
.468 .54115 m .47551 .53875 L .45376 .55354 L p .595 .947 .816 r
F P
0 g
s
.45376 .55354 m .44301 .55783 L .468 .54115 L p .595 .947 .816 r
F P
0 g
s
.56762 .46033 m .56316 .46646 L .52878 .49255 L p .812 .999 .838 r
F P
0 g
s
.52835 .49606 m .52878 .49255 L .56316 .46646 L p .727 .982 .771 r
F P
0 g
s
.23353 .39051 m .22154 .37026 L .27399 .32374 L p .486 .444 .735 r
F P
0 g
s
.74174 .35576 m .73014 .36146 L .67626 .35223 L p .78 .836 .895 r
F P
0 g
s
.66781 .36336 m .67626 .35223 L .73014 .36146 L p .791 .864 .904 r
F P
0 g
s
.42131 .559 m .43218 .5597 L .41111 .57215 L p .604 .917 .976 r
F P
0 g
s
.41111 .57215 m .39791 .5731 L .42131 .559 L p .604 .917 .976 r
F P
0 g
s
.50092 .51969 m .49726 .51997 L .52835 .49606 L p .674 .965 .757 r
F P
0 g
s
.49726 .51997 m .50092 .51969 L .47551 .53875 L p .671 .973 .81 r
F P
0 g
s
.63448 .40374 m .62627 .41256 L .58119 .43445 L p .863 .937 .869 r
F P
0 g
s
.57664 .44433 m .58119 .43445 L .62627 .41256 L p .855 .972 .868 r
F P
0 g
s
.27399 .32374 m .28413 .34669 L .23353 .39051 L p .486 .444 .735 r
F P
0 g
s
.24555 .41116 m .23353 .39051 L .28413 .34669 L p .483 .439 .733 r
F P
0 g
s
.47551 .53875 m .468 .54115 L .49726 .51997 L p .671 .973 .81 r
F P
0 g
s
.52878 .49255 m .52835 .49606 L .49726 .51997 L p .781 .998 .849 r
F P
0 g
s
.28413 .34669 m .29427 .37002 L .24555 .41116 L p .483 .439 .733 r
F P
0 g
s
.25763 .4319 m .24555 .41116 L .29427 .37002 L p .481 .439 .733 r
F P
0 g
s
.57211 .45296 m .56762 .46033 L .52921 .48729 L p .855 .976 .865 r
F P
0 g
s
.52878 .49255 m .52921 .48729 L .56762 .46033 L p .812 .999 .838 r
F P
0 g
s
.75342 .35006 m .74174 .35576 L .68475 .34081 L p .768 .809 .886 r
F P
0 g
s
.67626 .35223 m .68475 .34081 L .74174 .35576 L p .78 .836 .895 r
F P
0 g
s
.46042 .54123 m .468 .54115 L .44301 .55783 L p .694 .972 .923 r
F P
0 g
s
.44301 .55783 m .43218 .5597 L .46042 .54123 L p .694 .972 .923 r
F P
0 g
s
.64275 .39437 m .63448 .40374 L .58575 .42334 L p .86 .899 .861 r
F P
0 g
s
.58119 .43445 m .58575 .42334 L .63448 .40374 L p .863 .937 .869 r
F P
0 g
s
.4104 .55558 m .42131 .559 L .39791 .5731 L p .62 .853 .987 r
F P
0 g
s
.39791 .5731 m .3847 .57144 L .4104 .55558 L p .62 .853 .987 r
F P
0 g
s
.29427 .37002 m .30444 .3934 L .25763 .4319 L p .481 .439 .733 r
F P
0 g
s
.26979 .45238 m .25763 .4319 L .30444 .3934 L p .482 .442 .737 r
F P
0 g
s
.7652 .34434 m .75342 .35006 L .6933 .32917 L p .755 .786 .878 r
F P
0 g
s
.68475 .34081 m .6933 .32917 L .75342 .35006 L p .768 .809 .886 r
F P
0 g
s
.49726 .51997 m .49355 .5182 L .52878 .49255 L p .781 .998 .849 r
F P
0 g
s
.49355 .5182 m .49726 .51997 L .468 .54115 L p .767 .988 .897 r
F P
0 g
s
.3995 .54942 m .4104 .55558 L .3847 .57144 L p .608 .771 .958 r
F P
0 g
s
.3847 .57144 m .37152 .56712 L .3995 .54942 L p .608 .771 .958 r
F P
0 g
s
.30444 .3934 m .31466 .41649 L .26979 .45238 L p .482 .442 .737 r
F P
0 g
s
.28206 .47225 m .26979 .45238 L .31466 .41649 L p .486 .45 .743 r
F P
0 g
s
.65106 .38448 m .64275 .39437 L .59034 .41107 L p .851 .862 .85 r
F P
0 g
s
.58575 .42334 m .59034 .41107 L .64275 .39437 L p .86 .899 .861 r
F P
0 g
s
.468 .54115 m .46042 .54123 L .49355 .5182 L p .767 .988 .897 r
F P
0 g
s
.57664 .44433 m .57211 .45296 L .52965 .4802 L p .867 .932 .864 r
F P
0 g
s
.52921 .48729 m .52965 .4802 L .57211 .45296 L p .855 .976 .865 r
F P
0 g
s
.52921 .48729 m .52878 .49255 L .49355 .5182 L p .834 .973 .885 r
F P
0 g
s
.31466 .41649 m .32496 .43892 L .28206 .47225 L p .486 .45 .743 r
F P
0 g
s
.29446 .49117 m .28206 .47225 L .32496 .43892 L p .491 .463 .753 r
F P
0 g
s
.4528 .53883 m .46042 .54123 L .43218 .5597 L p .733 .927 .955 r
F P
0 g
s
.43218 .5597 m .42131 .559 L .4528 .53883 L p .733 .927 .955 r
F P
0 g
s
.38863 .54053 m .3995 .54942 L .37152 .56712 L p .586 .693 .916 r
F P
0 g
s
.37152 .56712 m .35841 .56017 L .38863 .54053 L p .586 .693 .916 r
F P
0 g
s
.77706 .33857 m .7652 .34434 L .70189 .31738 L p .742 .766 .872 r
F P
0 g
s
.6933 .32917 m .70189 .31738 L .7652 .34434 L p .755 .786 .878 r
F P
0 g
s
.32496 .43892 m .33534 .46033 L .29446 .49117 L p .491 .463 .753 r
F P
0 g
s
.30699 .50878 m .29446 .49117 L .33534 .46033 L p .499 .48 .767 r
F P
0 g
s
.65941 .37413 m .65106 .38448 L .59494 .39771 L p .839 .829 .838 r
F P
0 g
s
.59034 .41107 m .59494 .39771 L .65106 .38448 L p .851 .862 .85 r
F P
0 g
s
.37781 .52899 m .38863 .54053 L .35841 .56017 L p .562 .628 .875 r
F P
0 g
s
.35841 .56017 m .34538 .55069 L .37781 .52899 L p .562 .628 .875 r
F P
0 g
s
.33534 .46033 m .34582 .48035 L .30699 .50878 L p .499 .48 .767 r
F P
0 g
s
.31965 .52475 m .30699 .50878 L .34582 .48035 L p .51 .504 .786 r
F P
0 g
s
.36706 .51497 m .37781 .52899 L .34538 .55069 L p .542 .576 .839 r
F P
0 g
s
.34538 .55069 m .33245 .53881 L .36706 .51497 L p .542 .576 .839 r
F P
0 g
s
.58119 .43445 m .57664 .44433 L .53009 .47125 L p .862 .883 .85 r
F P
0 g
s
.52965 .4802 m .53009 .47125 L .57664 .44433 L p .867 .932 .864 r
F P
0 g
s
.34582 .48035 m .35639 .49867 L .31965 .52475 L p .51 .504 .786 r
F P
0 g
s
.33245 .53881 m .31965 .52475 L .35639 .49867 L p .524 .536 .809 r
F P
0 g
s
.35639 .49867 m .36706 .51497 L .33245 .53881 L p .524 .536 .809 r
F P
0 g
s
.49355 .5182 m .48982 .51423 L .52921 .48729 L p .834 .973 .885 r
F P
0 g
s
.48982 .51423 m .49355 .5182 L .46042 .54123 L p .803 .941 .918 r
F P
0 g
s
.78901 .33274 m .77706 .33857 L .71055 .30551 L p .73 .748 .867 r
F P
0 g
s
.70189 .31738 m .71055 .30551 L .77706 .33857 L p .742 .766 .872 r
F P
0 g
s
.52965 .4802 m .52921 .48729 L .48982 .51423 L p .846 .917 .881 r
F P
0 g
s
.46042 .54123 m .4528 .53883 L .48982 .51423 L p .803 .941 .918 r
F P
0 g
s
.66781 .36336 m .65941 .37413 L .59955 .38339 L p .826 .8 .827 r
F P
0 g
s
.59494 .39771 m .59955 .38339 L .65941 .37413 L p .839 .829 .838 r
F P
0 g
s
.44514 .53383 m .4528 .53883 L .42131 .559 L p .731 .849 .937 r
F P
0 g
s
.42131 .559 m .4104 .55558 L .44514 .53383 L p .731 .849 .937 r
F P
0 g
s
.58575 .42334 m .58119 .43445 L .53053 .46044 L p .85 .836 .832 r
F P
0 g
s
.53009 .47125 m .53053 .46044 L .58119 .43445 L p .862 .883 .85 r
F P
0 g
s
.71055 .30551 m .71927 .29362 L .78901 .33274 L p .73 .748 .867 r
F P
0 g
s
.67626 .35223 m .66781 .36336 L .60418 .36821 L p .813 .775 .817 r
F P
0 g
s
.59955 .38339 m .60418 .36821 L .66781 .36336 L p .826 .8 .827 r
F P
0 g
s
.43747 .52619 m .44514 .53383 L .4104 .55558 L p .71 .77 .9 r
F P
0 g
s
.4104 .55558 m .3995 .54942 L .43747 .52619 L p .71 .77 .9 r
F P
0 g
s
.53009 .47125 m .52965 .4802 L .48607 .50796 L p .836 .855 .86 r
F P
0 g
s
.48982 .51423 m .48607 .50796 L .52965 .4802 L p .846 .917 .881 r
F P
0 g
s
.48607 .50796 m .48982 .51423 L .4528 .53883 L p .8 .87 .9 r
F P
0 g
s
.4528 .53883 m .44514 .53383 L .48607 .50796 L p .8 .87 .9 r
F P
0 g
s
.59034 .41107 m .58575 .42334 L .53097 .44783 L p .834 .795 .814 r
F P
0 g
s
.53053 .46044 m .53097 .44783 L .58575 .42334 L p .85 .836 .832 r
F P
0 g
s
.68475 .34081 m .67626 .35223 L .60881 .35231 L p .8 .753 .809 r
F P
0 g
s
.60418 .36821 m .60881 .35231 L .67626 .35223 L p .813 .775 .817 r
F P
0 g
s
.28413 .34669 m .27399 .32374 L .34782 .287 L p .568 .484 .72 r
F P
0 g
s
.4298 .51592 m .43747 .52619 L .3995 .54942 L p .685 .703 .861 r
F P
0 g
s
.3995 .54942 m .38863 .54053 L .4298 .51592 L p .685 .703 .861 r
F P
0 g
s
.34782 .287 m .35515 .31111 L .28413 .34669 L p .568 .484 .72 r
F P
0 g
s
.29427 .37002 m .28413 .34669 L .35515 .31111 L p .569 .482 .717 r
F P
0 g
s
.6933 .32917 m .68475 .34081 L .61346 .33585 L p .787 .735 .804 r
F P
0 g
s
.60881 .35231 m .61346 .33585 L .68475 .34081 L p .8 .753 .809 r
F P
0 g
s
.53053 .46044 m .53009 .47125 L .4823 .49935 L p .818 .799 .834 r
F P
0 g
s
.48607 .50796 m .4823 .49935 L .53009 .47125 L p .836 .855 .86 r
F P
0 g
s
.59494 .39771 m .59034 .41107 L .53141 .43351 L p .819 .76 .797 r
F P
0 g
s
.53097 .44783 m .53141 .43351 L .59034 .41107 L p .834 .795 .814 r
F P
0 g
s
.35515 .31111 m .36247 .33556 L .29427 .37002 L p .569 .482 .717 r
F P
0 g
s
.30444 .3934 m .29427 .37002 L .36247 .33556 L p .571 .483 .716 r
F P
0 g
s
.4823 .49935 m .48607 .50796 L .44514 .53383 L p .781 .799 .868 r
F P
0 g
s
.44514 .53383 m .43747 .52619 L .4823 .49935 L p .781 .799 .868 r
F P
0 g
s
.42215 .50311 m .4298 .51592 L .38863 .54053 L p .661 .648 .826 r
F P
0 g
s
.38863 .54053 m .37781 .52899 L .42215 .50311 L p .661 .648 .826 r
F P
0 g
s
.36247 .33556 m .36979 .36001 L .30444 .3934 L p .571 .483 .716 r
F P
0 g
s
.31466 .41649 m .30444 .3934 L .36979 .36001 L p .575 .488 .718 r
F P
0 g
s
.41453 .48788 m .42215 .50311 L .37781 .52899 L p .64 .604 .798 r
F P
0 g
s
.37781 .52899 m .36706 .51497 L .41453 .48788 L p .64 .604 .798 r
F P
0 g
s
.36979 .36001 m .37714 .38413 L .31466 .41649 L p .575 .488 .718 r
F P
0 g
s
.32496 .43892 m .31466 .41649 L .37714 .38413 L p .58 .495 .723 r
F P
0 g
s
.70189 .31738 m .6933 .32917 L .61813 .31897 L p .775 .719 .8 r
F P
0 g
s
.61346 .33585 m .61813 .31897 L .6933 .32917 L p .787 .735 .804 r
F P
0 g
s
.59955 .38339 m .59494 .39771 L .53185 .4176 L p .804 .731 .783 r
F P
0 g
s
.53141 .43351 m .53185 .4176 L .59494 .39771 L p .819 .76 .797 r
F P
0 g
s
.37714 .38413 m .38452 .40757 L .32496 .43892 L p .58 .495 .723 r
F P
0 g
s
.33534 .46033 m .32496 .43892 L .38452 .40757 L p .588 .507 .731 r
F P
0 g
s
.40696 .47045 m .41453 .48788 L .36706 .51497 L p .623 .57 .774 r
F P
0 g
s
.36706 .51497 m .35639 .49867 L .40696 .47045 L p .623 .57 .774 r
F P
0 g
s
.53097 .44783 m .53053 .46044 L .47853 .48842 L p .798 .751 .809 r
F P
0 g
s
.4823 .49935 m .47853 .48842 L .53053 .46044 L p .818 .799 .834 r
F P
0 g
s
.38452 .40757 m .39195 .43 L .33534 .46033 L p .588 .507 .731 r
F P
0 g
s
.34582 .48035 m .33534 .46033 L .39195 .43 L p .597 .523 .742 r
F P
0 g
s
.47853 .48842 m .4823 .49935 L .43747 .52619 L p .757 .738 .835 r
F P
0 g
s
.43747 .52619 m .4298 .51592 L .47853 .48842 L p .757 .738 .835 r
F P
0 g
s
.39943 .45106 m .40696 .47045 L .35639 .49867 L p .609 .543 .756 r
F P
0 g
s
.35639 .49867 m .34582 .48035 L .39943 .45106 L p .609 .543 .756 r
F P
0 g
s
.39195 .43 m .39943 .45106 L .34582 .48035 L p .597 .523 .742 r
F P
0 g
s
.71055 .30551 m .70189 .31738 L .62281 .30184 L p .764 .707 .799 r
F P
0 g
s
.61813 .31897 m .62281 .30184 L .70189 .31738 L p .775 .719 .8 r
F P
0 g
s
.60418 .36821 m .59955 .38339 L .53229 .40028 L p .791 .706 .771 r
F P
0 g
s
.53185 .4176 m .53229 .40028 L .59955 .38339 L p .804 .731 .783 r
F P
0 g
s
.53141 .43351 m .53097 .44783 L .47476 .47522 L p .78 .711 .787 r
F P
0 g
s
.47853 .48842 m .47476 .47522 L .53097 .44783 L p .798 .751 .809 r
F P
0 g
s
.47476 .47522 m .47853 .48842 L .4298 .51592 L p .735 .689 .806 r
F P
0 g
s
.4298 .51592 m .42215 .50311 L .47476 .47522 L p .735 .689 .806 r
F P
0 g
s
.71927 .29362 m .71055 .30551 L .62752 .28461 L p .752 .697 .799 r
F P
0 g
s
.62281 .30184 m .62752 .28461 L .71055 .30551 L p .764 .707 .799 r
F P
0 g
s
.60881 .35231 m .60418 .36821 L .53273 .38173 L p .778 .687 .763 r
F P
0 g
s
.53229 .40028 m .53273 .38173 L .60418 .36821 L p .791 .706 .771 r
F P
0 g
s
.47099 .45989 m .47476 .47522 L .42215 .50311 L p .716 .649 .782 r
F P
0 g
s
.42215 .50311 m .41453 .48788 L .47099 .45989 L p .716 .649 .782 r
F P
0 g
s
.53185 .4176 m .53141 .43351 L .47099 .45989 L p .763 .679 .769 r
F P
0 g
s
.47476 .47522 m .47099 .45989 L .53141 .43351 L p .78 .711 .787 r
F P
0 g
s
.62752 .28461 m .63227 .26744 L .71927 .29362 L p .752 .697 .799 r
F P
0 g
s
.61346 .33585 m .60881 .35231 L .53317 .36216 L p .767 .671 .756 r
F P
0 g
s
.53273 .38173 m .53317 .36216 L .60881 .35231 L p .778 .687 .763 r
F P
0 g
s
.46724 .44259 m .47099 .45989 L .41453 .48788 L p .699 .617 .762 r
F P
0 g
s
.41453 .48788 m .40696 .47045 L .46724 .44259 L p .699 .617 .762 r
F P
0 g
s
.53229 .40028 m .53185 .4176 L .46724 .44259 L p .749 .653 .754 r
F P
0 g
s
.47099 .45989 m .46724 .44259 L .53185 .4176 L p .763 .679 .769 r
F P
0 g
s
.61813 .31897 m .61346 .33585 L .53361 .34179 L p .757 .658 .752 r
F P
0 g
s
.53317 .36216 m .53361 .34179 L .61346 .33585 L p .767 .671 .756 r
F P
0 g
s
.46349 .42353 m .46724 .44259 L .40696 .47045 L p .685 .592 .746 r
F P
0 g
s
.40696 .47045 m .39943 .45106 L .46349 .42353 L p .685 .592 .746 r
F P
0 g
s
.35515 .31111 m .34782 .287 L .43754 .26392 L p .634 .529 .717 r
F P
0 g
s
.43754 .26392 m .44126 .28746 L .35515 .31111 L p .634 .529 .717 r
F P
0 g
s
.36247 .33556 m .35515 .31111 L .44126 .28746 L p .638 .529 .714 r
F P
0 g
s
.44126 .28746 m .44495 .31125 L .36247 .33556 L p .638 .529 .714 r
F P
0 g
s
.36979 .36001 m .36247 .33556 L .44495 .31125 L p .642 .532 .713 r
F P
0 g
s
.45976 .40295 m .46349 .42353 L .39943 .45106 L p .673 .573 .734 r
F P
0 g
s
.39943 .45106 m .39195 .43 L .45976 .40295 L p .673 .573 .734 r
F P
0 g
s
.44495 .31125 m .44865 .33499 L .36979 .36001 L p .642 .532 .713 r
F P
0 g
s
.37714 .38413 m .36979 .36001 L .44865 .33499 L p .648 .537 .715 r
F P
0 g
s
.45605 .38114 m .45976 .40295 L .39195 .43 L p .663 .557 .725 r
F P
0 g
s
.39195 .43 m .38452 .40757 L .45605 .38114 L p .663 .557 .725 r
F P
0 g
s
.44865 .33499 m .45234 .35839 L .37714 .38413 L p .648 .537 .715 r
F P
0 g
s
.38452 .40757 m .37714 .38413 L .45234 .35839 L p .655 .545 .719 r
F P
0 g
s
.45234 .35839 m .45605 .38114 L .38452 .40757 L p .655 .545 .719 r
F P
0 g
s
.53273 .38173 m .53229 .40028 L .46349 .42353 L p .737 .632 .743 r
F P
0 g
s
.46724 .44259 m .46349 .42353 L .53229 .40028 L p .749 .653 .754 r
F P
0 g
s
.62281 .30184 m .61813 .31897 L .53405 .32087 L p .748 .648 .75 r
F P
0 g
s
.53361 .34179 m .53405 .32087 L .61813 .31897 L p .757 .658 .752 r
F P
0 g
s
.53317 .36216 m .53273 .38173 L .45976 .40295 L p .726 .616 .734 r
F P
0 g
s
.46349 .42353 m .45976 .40295 L .53273 .38173 L p .737 .632 .743 r
F P
0 g
s
.62752 .28461 m .62281 .30184 L .5345 .29963 L p .739 .64 .75 r
F P
0 g
s
.53405 .32087 m .5345 .29963 L .62281 .30184 L p .748 .648 .75 r
F P
0 g
s
.53361 .34179 m .53317 .36216 L .45605 .38114 L p .716 .603 .728 r
F P
0 g
s
.45976 .40295 m .45605 .38114 L .53317 .36216 L p .726 .616 .734 r
F P
0 g
s
.63227 .26744 m .62752 .28461 L .53494 .27831 L p .73 .635 .753 r
F P
0 g
s
.5345 .29963 m .53494 .27831 L .62752 .28461 L p .739 .64 .75 r
F P
0 g
s
.45605 .38114 m .45234 .35839 L .53361 .34179 L p .716 .603 .728 r
F P
0 g
s
.53405 .32087 m .53361 .34179 L .45234 .35839 L p .708 .593 .725 r
F P
0 g
s
.45234 .35839 m .44865 .33499 L .53405 .32087 L p .708 .593 .725 r
F P
0 g
s
.5345 .29963 m .53405 .32087 L .44865 .33499 L p .701 .585 .723 r
F P
0 g
s
.44865 .33499 m .44495 .31125 L .5345 .29963 L p .701 .585 .723 r
F P
0 g
s
.53494 .27831 m .53539 .25714 L .63227 .26744 L p .73 .635 .753 r
F P
0 g
s
.53494 .27831 m .5345 .29963 L .44495 .31125 L p .694 .581 .724 r
F P
0 g
s
.44495 .31125 m .44126 .28746 L .53494 .27831 L p .694 .581 .724 r
F P
0 g
s
.53539 .25714 m .53494 .27831 L .44126 .28746 L p .688 .579 .727 r
F P
0 g
s
.44126 .28746 m .43754 .26392 L .53539 .25714 L p .688 .579 .727 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ok2D^P03o`00
0?njX/3o^Z;000?o^Z;02ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?n`U;X00ol0003o^Z;0
okZR`00>okZR`0_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nRQkL00ol0003o/9Bjok2D
^P0Mok2D^P03o`000?njX/3o^Z;001Wo^Z;01ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001_nRQkL00ol0003o/9Bjok2D^P0Mok2D^P03o`000?njX/3o^Z;001go^Z;000?o0000
ol2bc?o0//`00ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool0
02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002OnRQkL00ol0
003o/9Bjok2D^P0Mok2D^P03o`000?njX/3o^Z;001co^Z;000?o0000ol2bc?o0//`01?o0//`3o`00
00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Ko
oooo00?o0000ooooooooool0IOooool4o`0000goXXNg00?o0000ok2D^_n`U;X07On`U;X00ol0003o
^Z;0okZR`00LokZR`003o`000?o0//co`;;<00Oo`;;<0ol0000:ooooo`03o`000?oooooooooo03;o
oooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo
1?l0000Boj:7]`03o`000?n`U;[o/9Bj01Oo/9Bj1_l00003okZR`0Go00005_njX/000ol0003o`;;<
ol2bc00:ol2bc0?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0001Ko
XXNg00?o0000ok2D^_n`U;X03?n`U;X;o`0000Go/IBi00?o0000okfS_onmXkl01_nmXkl?o`0000Ko
^Z;000?o0000ol2bc?o0//`03_o0//`3o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Zooooo`004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`Co
00006OnRQkL00ol0003o/9Bjok2D^P02ok2D^P[o00004?naU;T00ol0003o_J>ookfS_`0EokfS_`Oo
00004oo0//`3o`0000;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`00
2Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000;ooooo`03o`000?oooooooooo05?ooooo0ol0000Koj:7]`?o000000Co/9Bjo`000?l0
003o00006_naU;T00ol0003o_J>ookfS_`0KokfS_`03o`000?o3]<co`kC<00?o00004Oo0//`3o`00
03Kooooo00?o0000ooooooooool0:Oooool0017ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@oooo
o`;o000000?oTG^ho`000?nRQkL06?nRQkL3o`0000;oXhNf00?o0000ok6D^OnaU;T07?naU;T00ol0
003o_J>ookfS_`0KokfS_`03o`000?o3]<co`kC<00Co`kC<1?l0000>ol2bc0Co0000=?ooool00ol0
003oooooooooo`0Xooooo`004Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0COooool2
o`0000CoTG^h00?o0000oj:7]onRQkL04_nRQkL4o`0000GoXhNf00?o0000ok6D^OnaU;T07?naU;T0
0ol0003o_J>ookfS_`0KokfS_`03o`000?o3]<co`kC<00So`kC<1?l0000:ol2bc004o`000?o0//co
`;;<ol2bc0?o0000<Oooool2o`0002Wooooo000Aooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0B_oo
ool2o`0000KoTG^h00?o0000oj:7]onRQkL03onRQkL3o`0000WoXhNf00?o0000ok6D^OnaU;T07?na
U;T00ol0003o_J>ookfS_`0JokfS_`03o`000?o3]<co`kC<00go`kC<0ol00007ol2bc003o`000?o0
//co`;;<00;o`;;<00Co0000okZogOl0003o0000;oooool2o`0002Wooooo000Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00004?ooool00ol0003ooooo
ooooo`17ooooo`;o00002?nANkP00ol0003oXXNgoj:7]`0;oj:7]`Co00003?nSQkH00ol0003o/IBi
ok6D^@0Hok6D^@Go00000_nmXkl=o`0000go_J>o00?o0000ol>dc?o3]<`04?o3]<`4o`0000?o`;;<
00Go0000ol2bc?o0//co`;;<o`000004okZog@03o`000?oooooooooo02kooooo00?o0000oooooooo
ool09_ooool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`0@ooooo`;o0000AOooool2o`0000_oTG^h00?o0000oj:7]onRQkL01onRQkL3o`00017o
XhNf00?o0000ok6D^OnaU;T04?naU;T7o`0000Co/iFi00?o0000oknU_onoYKl03OnoYKl>o`0001Ko
`kC<1?l00002ol2bc003o`000?nj_mgo^[oM00Co^[oM0_l0000^ooooo`03o`000?oooooooooo02Ko
oooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?ooool2o`0000goTG^h
00?o0000oj:7]onRQkL00onRQkL4o`0001CoXhNf00?o0000ok6D^OnaU;T02?naU;T8o`0000_o/iFi
00?o0000oknU_onoYKl06_noYKl01?l0003oa[S<olJhc?o6^<`5o`0000go`kC<0ol000001?o3]<co
0000o`000?l00009okZog@;o0000;Oooool00ol0003oooooooooo`0Uooooo`00:_ooool2o`0001Go
oooo00?o0000ooooooooool0?Oooool2o`0000ooTG^h00?o0000oj:7]onRQkL00ol0000Hoj>7]P04
o`000?naU;Wo/IBiok6D^@Oo00004oncUKT00ol0003o_jFooknU_`0IoknU_`03o`000?o6^<coa[S<
00Ooa[S<1Ol00005ol>dc0?o00001Oo3]<`2o`000003okg4gonj_mgo^[oM00So^[oM0_l0000/oooo
o`03o`000?oooooooooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0>_ooool2o`00017oTG^h0ol0000Ioj>7]PKo00006OncUKT00ol0003o_jFooknU_`0JoknU_`03
o`000?o6^<coa[S<00coa[S<1Ol00008ol>dc0;o00000onma=l00ol0003o^[oMokZog@07okZog@;o
0000:_ooool2o`0002Gooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
=oooool2o`00017oTG^h0_l000000onANkOo0000oj>7]P0Foj>7]P?o00000_nTR;H00ol0003o/iFi
ok>E^@0Jok>E^@03o`000?noYKoo_jFo01[o_jFo00?o0000olJhc?o6^<`02oo6^<`3o`0000?oa[S<
1Ol00003ol>dc003o`000?nma=oo000000Co_LCO0_l00008okZog@03o`000?oooooooooo02Oooooo
0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@07ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Co
oooo0_l0000Aoi5k^0;o00000onANkL00ol0003oXhNfoj>7]P0Boj>7]P?o00001OnTR;H00ol0003o
/iFiok>E^@0Jok>E^@03o`000?noYKoo_jFo00_o_jFo3ol0000;olJhc0?o00002oo6^<`3o`0000;o
_LCO00?o0000okg4gonma=l01?nma=l2o`0000Oo^[oM0_l0000Xooooo`03o`000?oooooooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06oooo
o`00:_ooool2o`0001Wooooo00?o0000ooooooooool0<Oooool2o`00013oTG^h0ol00006oi5k]`03
o`000?nSQkKoXhNf00goXhNf1?l00008ojB8]P03o`000?ncUKWo/iFi01Oo/iFi1?l00002oknU_`_o
00003_o1Z<001?l0003obKc=olVlcOo9_<d8o`00013oa[S<00Go0000ol79h?l0003o_LCOo`000007
okg4g`;o00001onj_md2o`0002Oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooo
oooo410@013ooooo00?o0000ooooooooool01Oooool002Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0^ooooo`;o00004?nANkP2o`0000WoTG^g00?o0000oj>7]_nSQkH02_nSQkH3
o`0000goY8Rf00?o0000ok>E^OncUKT03oncUKT7o`0000?o]INi00?o0000ol6X`?o1Z<006Oo1Z<00
0ol0003obKc=olVlc@03olVlc@?o000000?obKc=o`000?l000001Ol0000:olJhc003o`000?o1bN3o
`LWP00;o`LWP0_l00008okg4g`;o00001onj_md2o`0002Kooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool002Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0/ooooo`03o`000?mlLKco000000koTG^h0_l0000;
oi5k]`03o`000?nSQkKoXhNf00KoXhNf1?l0000@ojB8]P03o`000?ncUKWo/iFi00So/iFi1ol0000:
okFG^@03o`000?o1Z<3o`JS001Wo`JS000?o0000olVlcOo9_<d00ol0000;olVlc@Ko00000oo6^<`0
0ol0003o`LWPol79h005ol79h0?o00001onma=l2o`0000Oo^[oM00?o0000ooooooooool08oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Oooooo000Yooooo`?o00007?ooool00ol0003oooooooooo`0Zooooo`05o`000?ml
LKcoO76logaa_?l000002onANkP2o`0000goTG^g00?o0000oj>7]_nSQkH00onSQkH3o`0001CoY8Rf
00Co0000ok>E^OncUKWo/iFi1ol0000AokFG^@03o`000?o1Z<3o`JS001So`JS01?l0000DolVlc@?o
00002?o1bN000ol0003o`LWPol79h002o`0000Oo_LCO0_l00006okZog@;o00009?ooool00ol0003o
ooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`09oooo
o`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo00?o0000ogaa_?ml
LK`00_mlLK`00ol0003oTG^hoi5k^007oi5k^0;o00004?nANkL00ol0003oXhNfo`000002o`0001Ko
Y8Rf1Ol0000HokFG^@03o`000?o1Z<3o`JS001Ko`JS00ol0000HolVlc@04o`000?o4cn;oa<oRolC?
hPOo`LWP00Co0000ol79h?o1bN3o`LWP0_l00007okg4g`;o00001Onj_md2o`0002;ooooo0ol00004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`09ooooo`00:Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ogaa_?mlLK`01?mlLK`0
0ol0003oTG^hoi5k^003oi5k^0?o00004OnANkL3o`0001KoY8Rf0ol000000onURKOo0000okFG^@0J
okFG^@03o`000?o1Z<3o`JS0017o`JS02?l00006olVlc@Ko00002oo9_<d00ol0003oa<oRolC?hP05
olC?hP;o00000oo1bN000ol0003o`LWPol79h002ol79h0;o00001onma=l2o`000003okZogOl0003o
000000;oXKk^00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Sooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o0000ogaa_?mlLK`01OmlLK`01?l0003oTG^h
oi5k^?nANkP2o`0001;oTG^g0_l000000onBNkOo0000ojB8]P0CojB8]P?o00001?nURKL00ol0003o
]INiokFG^@0IokFG^@03o`000?o1Z<3o`JS000Co`JS03ol00005olB[`@03o`000?o<`<ooc<3?00[o
c<3?2ol0000;olC?hPCo00001Oo1bN03o`0000Ko_LCO00?o0000oj6nk_nQ_^h00onQ_^h00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01kooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo
00?ooooo0ol0000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ogaa_?mlLK`01_mlLK`01?l0
003oTG^ho`000?l0000Boi5k]`;o00001?nBNkL00ol0003oY8RfojB8]P0>ojB8]P?o00002?nURKL0
0ol0003o]INiokFG^@0EokFG^@Co000000?o`JS0o`000?l000000ol0000:olB[`@;o00001oo4Zl40
0ol0003oc<3?olc0c`0Eolc0c`03o`000?o7e^GoamKU00;o00002_o4cn84o`0000Go`LWP0_l00000
0onma=oo0000o`000003oj73l@GoXKk^00?o0000ooooooooool08Oooool00ol0003oooooooooo`0M
ooooo`001?l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0O
ooooo`;o00002OmlLK`2o`0001;oTG^g0_l00006oi9k]`03o`000?nTR;KoY8Rf00_oY8Rf0ol0000;
ojF9]`03o`000?neUkWo]INi013o]INi1Ol00003okNJ^P03o`000?o4Zl7oa:_100_oa:_10ol00009
olB[`@03o`000?o<`<ooc<3?01Coc<3?00?o0000olOFiOo7e^D01Oo7e^D4o`0000Goa<oR00?o0000
olC?h_o4cn800ol00004ol79h003o`000?nQ`o7oXL?a00CoXL?a1OnQ_^h00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Mooooo`03o`000?mlLKcoO76l00SoO76l00?o0000og]`^ol000004?nANkL2
o`0000SoTW^g00?o0000ojB8]_nTR;H02OnTR;H2o`0000koYHVg00?o0000okFG^OneUkT02oneUkT5
o`0000So]iZj00?o0000olB[`Oo4Zl402?o4Zl43o`0000coa:_100?o0000olc0coo<`<l04oo<`<l0
0ol0003oamKUolOFi@0:olOFi@?o00000oo4cn800ol0003oa<oRolC?hP02olC?hP?o00000onRbO@6
oj73l@03o`000?nQ_^koXKk^00;oXKk^00?o0000ooooooooool08?ooool2o`0001gooooo0006oooo
o`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oO76logaa
_008ogaa_005o`000?mkL;_oNg2kog]`^ol000003OnANkL2o`0000_oTW^g00?o0000ojB8]_nTR;H0
1OnTR;H3o`00013oYHVg00?o0000okFG^OneUkT01_neUkT5o`0000go]iZj00?o0000olB[`Oo4Zl40
1Oo4Zl43o`0000[oa:_11Ol00002olc0caCo00004?o7e^D5o`000003olC?h_l0003o000000?oXm3h
1?nRbO@00ol0003oXL?aoj73l@03oj73l@03o`000?nQ_^koXKk^00;oXKk^00?o0000ooooooooool0
7_ooool00ol0003oooooo`00000Mooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o00009oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?mlLKcoO76l00SoO76l00?o0000og]`^omkL;/00_mkL;/00ol0003oTG^g
oi5k]`09oi5k]`;o00003OnBNkL00ol0003oY8RfojB8]P02ojB8]P?o00005?nURKL00ol0003o]INi
okFG^@05o`0001;o]iZj00?o0000olB[`Oo4Zl400_o4Zl43o`0000Coa:_12Ol00004olN_``03o`00
0?o@a]7od<KA01?od<KA00Co0000ol[Mioo:gNOob]gW1_l0000;olOFi@;o00001_nSd?P01Ol0003o
X/Wdoj;9m?nRbOCo000000GoXL?a00?o0000oj6nk_nQ_^h00_nQ_^h00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01_ooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01Kooooo00?o0000ogaa_?mlLK`02?mlLK`00ol0003oNg2kog]`^`04
og]`^`03o`000?nANkOoTG^g00KoTG^g0_l0000?oi9k]`03o`000?nTR;Ko000000;o00005_nURKL4
o`0001Oo]iZj00?o0000olB[`Ol000002Ol0000=olN_``03o`000?o@a]7od<KA01;od<KA00?o0000
ol[Mioo:gNL02?o:gNL6o`0000?oamKU0_l000000onSf?[o0000oj?HnP06oj?@n0;o00000onRbO@0
0ol0003oXL?aoj73l@02oj73l@;o00000onQ_^h00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?oo
ool00ol0003oO76logaa_008ogaa_003o`000?mkL;_oNg2k00GoNg2k00?o0000oi5k]onANkL01?nA
NkL2o`00017oTW^g0_l0000FojF9]`?o000000?oYh^ho`000?ngV[X05_ngV[X6o`0001Coajo300?o
0000om36dOo@a]404_o@a]400ol0003ob]gWol[Mi`0?ol[Mi`?o00001?nSf?X00ol0003oXmSjo`00
0006oj?@n004o`000?nRbOCoX/Wdoj;9m0;o00001?nQ`o401Ol0003oXKk^oj6nk_nQ_^ko0000023o
oooo00?o0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?mlLKcoO76l00SoO76l00?o0000og]`^omkL;/01omkL;/01?l0003oTG^g
oi5k]onANkL2o`00017oTW^g0_l000000onCO;Oo0000ojF9]`0BojF9]`?o00001?nWRkP00ol0003o
]iZjokNJ^P0BokNJ^PCo000000?o^Ifko`000?o7[l<05_o7[l<00ol0003od<KAom36d@07om36d@_o
00004Oo:gNL2o`0000?oX]ol0onSf?X01Ol0003oXmSjoj?Hn_nSf?[o000000GoXm3h00?o0000oj;9
m?nRbO@00_nRbO@00ol0003oXL?aoj73l@02oj73l@05o`000?nQ_^koXKk^oj6nk_l000008?ooool0
0ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000ooooooooool04?ooool00ol0
003oO76logaa_008ogaa_003o`000?mkL;_oNg2k00SoNg2k00Co0000oi5k]ol0003o00004OnBNkL2
o`0000?oTgbg00?o0000ojF9]onURKL03_nURKL3o`0000OoYh^h00?o0000okNJ^_ngV[X03_ngV[X5
o`0000Co^Ifk00?o0000olN_`oo7[l<04oo7[l<3o`000003om36dOl0003o000000Ko00002_oCc=<0
0ol0003oc>GYolcUj@07olcUj@So00001onRgo`00ol0003oXmSjo`000003oj?HnP;o00001?nSd?P0
0ol0003oX/Wdoj;9m002oj;9m003o`000?nQ`o7oXL?a00;oXL?a00Go0000oj6nk_nQ_^koXKk^o`00
000Pooooo`03o`000?oooooooooo01Sooooo000Wooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool03_ooool00ol0003oO76logaa_008ogaa_003o`000?mkL;_oNg2k00WoNg2k0_l0000A
oi9k]`;o00001_nCO;L00ol0003oYHVgojF9]`0:ojF9]`?o00002_nWRkP00ol0003o]iZjokNJ^P0:
okNJ^PKo00001oniWK/00ol0003oajo3olN_``0>olN_``Go00000_o:]<D00ol0003odlcCom?<d`0@
om?<d`03o`000?o<iNWoc>GY00coc>GY0_l00004oj3Wo0OoX]ol0_l00004oj?HnP03o`000?nSd?So
Xm3h00;oXm3h0_l00003oj;9m0;o00000onQ`o401Ol0003oXKk^oj6nk_nQ_^ko000001kooooo0_l0
000Jooooo`009oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00?o0000
ogaa_?mlLK`01omlLK`00ol0003oNg2kog]`^`09og]`^`03o`000?mkL;_o000000ooTW^g0_l00008
oi=l]`03o`000?nURKOoYHVg00SoYHVg0_l0000>ojN;^003o`000?ngV[[o]iZj00Ko]iZj1_l0000:
okVM^`03o`000?o7[l?oajo300Woajo31Ol00006olZda@03o`000?oCc=?odlcC00godlcC1?l00004
olcUj@_o00002OnPio`00ol0003oX]oloj;Oo003oj;Oo0;o00000onSf?X2o`0000CoXm3h00?o0000
oj;9m?nRbO@00_nRbO@01Ol0003oXL?aoj73lOnQ`o7o000000?oXKk^00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Gooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00_ooooo00?o0000of=Za?l000001omlLK`00ol0003oNg2kog]`^`09og]`^`05o`000?mkL;_o
Ng2kog]`^ol000003?nBNkL2o`0000[oTgbg00?o0000ojF9]onURKL01OnURKL3o`00013oYh^h00?o
0000okNJ^_ngV[X00_ngV[X7o`0000go^Ifk00?o0000olN_`oo7[l<01?o7[l<5o`0000_ob[C500?o
0000om?<dooCc=<01_oCc=<7o`0000?oe]CF00?o0000olg]j_o=kNX02_o=kNX00ol0003oVnchoi_/
n003oi_/n003o`000?nPiocoX>Ol00KoX>Ol0_l000000onRgoco0000oj;Oo002o`0000?oXmSj00?o
0000oj?@n?nSd?P00_nSd?P00ol0003oX/Wdoj;9m002oj;9m005o`000?nQ`o7oXL?aoj73lOl00000
0onQ_^h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Wooooo`;o0000<?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?mSJ/Co000000KoO76l00?o0000og]`^omkL;/02Omk
L;/00ol0003oNg2kog]`^`02og]`^`03o`000?nBNkOoTW^g00SoTW^g0_l0000<oi=l]`03o`000?nU
RKOoYHVg00;oYHVg0ol0000CojN;^003o`000?ngV[[o]iZj00;o000000Co^Ifko`000?l0003o0000
4?niWK/01?l0003oajo3olN_`oo7[l<3o`00013ob[C500Co0000om?<dooCc=?odlcC1Ol00009omKD
eP03o`000?o=kN[ocNgZ00KocNgZ1Ol0000;oi_/n0Co00000onPio`3o`000003oj;Oo?l0003o0000
01Go00007_ooool00ol0003oooooooooo`0Fooooo`009_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00Sooooo00Go0000of=Za?mSJ/CoHf[4o`000004ogaa_003o`000?mkL;_oNg2k
00WoNg2k00?o0000og]`^omkL;/00omkL;/00ol0003oTW^goi9k]`06oi9k]`;o00003onCO;L4o`00
01GoYh^h0ol00002okVM^`;o00004OniWK/4o`0001;ob[C50ol000000ooCc=?o0000omKDeP0>omKD
eP03o`000?o=kN[ocNgZ00?ocNgZ1?l00002olgdjP03o`000?nDk_3oU>k`00KoU>k`00?o0000oe78
l?mAb?000_mAb?04oeW6n@?oH<7m00Go0000ofJkoOl0003oI[_mo`000003of^en`03o`000?m_/?So
Kk3h00;oKk3h1Omc[?D4ogNXl@CoNjK^0_l0000Nooooo`03o`000?oooooooooo01Gooooo000Voooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00ol0003oHf[4of=Za002of=Z
a004o`000?mlLKcoO76lo`0000_oNg2k00?o0000og]`^omkL;/01OmkL;/00ol0003oTW^goi9k]`03
oi9k]`;o00004?nCO;L2o`0001GoYh^h0ol000000onYS[Wo0000o`000002o`00013o^Ifk0ol00002
okbQ_P03o`000?o:]<Gob[C500gob[C51?l00002olfkb003o`000?oFe=Koe]CF00coe]CF0ol00000
0oo=kN[o0000o`000006olgdjP;o00000onDk_001?l0003oR^gSoh[]hon:kN<4odS7h@03o`000?mA
b?3oDLS`00?oDLS`0omIa_T02?l0003oH<7mof31oOl0003oI[_mo`000?mV^ogo00000om[]O/00ol0
003oKk3hofn`n002ofn`n0GoLjce1?mgZ?44og^VkP03o`000?oooooooooo01cooooo0_l0000Foooo
o`009_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000of=Za?mS
J/@00omSJ/@00ol0003oO76lo`00000;og]`^`03o`000?mkL;_oNg2k00KoNg2k00Co0000oi9k]onB
NkOoTW^g0_l0000@oi=l]`;o000000?oU7jio`000?nWRkP04OnWRkP3o`0000;oZHji0ol0000?okVM
^`Co00001OnlXKh00ol0003ob[C5olZda@0:olZda@?o00001Oo=^lP00ol0003oe]CFomKDeP08omKD
ePGo000000?ofMcIo`000?o=m>X01Oo=m>X3o`000003olWkion:kN?oR^gS00?oR^gS00?o;kKHo`00
0?l000000olf]NX01?l0003o?K3docf`m?lm/?@4od>Xm`05oe78l?l0003o0000oeW6nOl000000_mP
`Od2o`0000;oI[_m00Go0000of^enom[]O_oJkGko`000004ofn`n0CoLjce00Go0000ogNXlOmgZ?7o
MjSao`000004og^VkP03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool002Kooooo
0ol0000dooooo`03o`000?oooooooooo00Cooooo00?o0000of=Za?mSJ/@01?mSJ/@00ol0003oNg2k
og]`^`08og]`^`;o00002OmkL;/01?l0003oTW^go`000?l0000@oi=l]`;o00000onDO[T00ol0003o
Yh^hojN;^00=ojN;^0?o00000_nYS[T3o`0000;oZHji00?o0000okVM^oniWK/02_niWK/3o`0000Wo
_:6n00?o0000olZdaOo:]<D01_o:]<D4o`0000SocK_800?o0000omKDe_oFe=H00ooFe=H5o`0000Go
fMcI00Co0000olgdj_o=m>[ocOCZ0_l00003olWki`03o`000?n:kN?oR^gS00;oO>KA0omI_?`00ol0
003oG:kjoeb^nP02oeb^nP?o00000_lm/?@00ol0003o@jSgod>Xm`02od>Xm`?oAj3f0ol000000omP
`Ogo0000o`000002ofJko@05o`000?m[]O_oJkGkof^enol000000om_/?P00ol0003oLjceog>/m@02
og>/m@04o`000?mgZ?7oMjSaogNXl@CoNjK^00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000
of=Za?mSJ/@01OmSJ/@00ol0003oNg2kog]`^`07og]`^`03o`000?mkL;_oNg2k00WoNg2k0_l0000@
oi=l]`;o00001_nDO[T00ol0003oYh^hojN;^009ojN;^0?o00000_nYS[T3o`0000KoZHji00?o0000
okVM^oniWK/01_niWK/3o`0000co_:6n00?o0000olZdaOo:]<D00_o:]<D4o`0000cocK_800?o0000
omKDe_oFe=H00ol00007omWLf@?o000000?ocOCZolWkioo9nnL00oo9nnL00ol0003o`_gQogcVd@02
ogcVd@;oQ;?d0_l000000omI_?co0000oeb^nP04oeb^nP06o`000?mMX?CoGJ3do`000?lm/?Co0000
1?m3Z?L01?l0003oAj3fodNPm_m7X?H2odbIlPCo00000_mV^od01Ol0003oJkGkof^enom[]O_o0000
00?oKk3h00Go0000og>/mOmc[?GoLjceo`000003ogNXl@05o`000?mkY^koNjK^og^Vk_l000008?oo
ool00ol0003oooooooooo`0Booooo`006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0=_ooool01?l0003oooooooooool00007of=Za003o`000?mPIl?o000000OoNg2k
00?o0000og]`^omkL;/02OmkL;/00ol0003oNg6lo`00000>oi=l]`;o00002?nDO[T00ol0003oYh^h
ojN;^006ojN;^0?o00000_nYS[T3o`0000WoZHji00?o0000okVM^oniWK/00_niWK/4o`0000oo_:6n
00?o0000olZdaOo:]<D00_l0000>olfkb0?o00002OoIg=T3o`000003omcVg?l0003obO_W00?obO_W
00Ko0000ol;mhOo2oN7o0000ogcVdOl00005ohBcm0?o00001?mL[_X00ol0003oGJ3doefPm003oefP
m0;o00000om3Z?L01Ol0003oAj3fodNPm_m7X?Ko000000CoC9Wb1Ol00002of^en`03o`000?m_/?So
Kk3h00;oKk3h00Go0000og>/mOmc[?GoLjceo`000003ogNXl@05o`000?mkY^koNjK^og^Vk_l00000
7oooool00ol0003oooooooooo`0Booooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
00?o0000ooooooooool0>?ooool3o`0000KoHf[400Co0000of1W`omPIl?o00001_mkL;/00ol0003o
Ng2kog]`^`09og]`^`05o`000?mkLKcoNg6log]a_?l000002_nCO;L3o`0000[oU7ji00?o0000ojN;
^?nWRkP00onWRkP3o`0000;oZHji0ol0000<ojV>^@03o`000?niWK_o^Ifk00;o00004_nlXKh3o`00
00kocK_80ol000000ooA`/co0000omWLf@06omWLf@?o00000ooLi]`01?l0003obO_WolWkiol00003
ol;mh@03o`000?n6a_go000000KoQ;?d00Co0000oh6SjOn1XnWoPJ?Y0_l000000omL[_[o0000oefP
m005oefPm0;oGIC/0_l000000om3Z?Oo0000odNPmP02odNPmP03o`000?m<VO;oC9Wb00;oC9Wb00Co
D9;^o`000?m@T^koD9;^0ol000000om[]O_o0000ofn`n002ofn`n005o`000?mc[?GoLjceog>/mOl0
00000omgZ?401Ol0003oNjK^og^Vk_mkY^ko0000023ooooo00?o0000ooooooooool01oooool4o`00
0003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool3o`00
03Wooooo00?o0000of=Za?mSJ/@01OmSJ/@01Ol0003oH6O3of1W`omPIl?o000000CoNg2k00?o0000
og]`^omkL;/02OmkL;/00ol0003oNg6log]a_002og]a_003o`000?nCO;OoTgbg00KoTgbg0_l0000>
oiAn^@03o`000?nWRkSo000000;o00000_nYS[T3o`0000koZHji0ol0000BokbQ_P?o000000?o_jO1
o`000?o=^lP02oo=^lP3o`0000CodL;<00?o0000omWLfOoIg=T00_oIg=T2o`0000Gog>KL0ol00003
ol;mh@05o`000?nfo=GoGLfTohK6oOl000001On4/o@2o`0000GoPJ?Y0ol00005oefPm003o`000?mM
U>coGIC/00?oGIC/0_l00003odNPmP07o`000?m<VO;oC9WbodbIl_l0003oD9;^o`000002oe2BkP;o
E8kZ0ol00003ofn`n005o`000?mc[?GoLjceog>/mOl000000omgZ?401Ol0003oNjK^og^Vk_mkY^ko
000001kooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0iooooo`03o`000?mSJ/CoHf[400CoHf[400?o0000
of1W`omPIl<00omPIl<01?l0003oNg2kog]`^ol0000:og]`^`;o00001_mkLK`00ol0003oTgbgoi=l
]`03oi=l]`;o00003onDO[T3o`0000;oZHji0ol0000>ojV>^@?o000000?o[9:ko`000?nlXKh03onl
XKh3o`0000Co_jO100?o0000olfkb?o=^lP01oo=^lP3o`0000KodL;<00Go0000omWLfOoIg=WofMcI
o`000006omcVg0;o000000Sog>oNo`000?o2oN7o`_gQo`000?nfo=GoGLfTojBnk0?o00001?n4/o@0
0ol0003oPJ?Yoh6Sj@04oh6Sj@05o`000?mmU^3oOIKPogfFh?l000000omMX?@00ol0003oGIC/oefD
k004oefDk0;oGX_U0_l000000om7X?Ko0000odbIlP02odbIlP06o`000?m@T^koD9;^o`000?m@T^ko
00001?mDS^X2o`000003ofn`n?l0003oLjce00;oLjce00Go0000ogNXlOmgZ?7oMjSao`000003og^V
kP03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05oooo
o`006oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>?ooool00ol0
003oHf[4of=Za005of=Za003o`000?mPIl?oH6O300?oH6O300?o0000og]`^ol000002_mkL;/00ol0
003oNg6log]a_006og]a_004o`000?nCO;OoTgbgoi=l]`;o00003onDO[T2o`000003oiJ1^ol0003o
000000;o00003onYS[T2o`0000Co[9:k00?o0000okbQ__nlXKh02onlXKh3o`0000Oo_jO100?o0000
olfkb?o=^lP01?o=^lP3o`0000SodL;<0ol00006omcVg0?o00000_oLkmh01_l0003o`_gQo`000?nf
o=Go0000ojBnk0;o00000onN[N82o`000003ohBcm?l0003oPJ?Y00CoPJ?Y0_l00005ogfFh003o`00
0?mMX?Co000000KoGIC/00?o0000oej;iOmNRnD00omNRnD2o`0000;oC9Wb00Co0000oe2Bk_m@T^ko
D9;^0_l00004oeB>jP;oFH_W0ol00003og>/m@05o`000?mgZ?7oMjSaogNXlOl000000omkY^h00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_o
oooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Sooooo00?o0000of=Z
a?mSJ/@01?mSJ/@00ol0003oH6O3of1W``05of1W``03o`000?mkL;_oNg2k00SoNg2k00?o0000og]a
_?mkLK`01omkLK`01?l0003oTgbgo`000?l0000@oiAn^@03o`000?nFPK_o000000?o00003_nYS[T3
o`0000Ko[9:k00?o0000okbQ__nlXKh02?nlXKh3o`0000[o_jO100?o0000olfkb?o=^lP00_o=^lP2
o`0000SodL;<0ol000000ooEbm3o0000omcVg005omcVg004o`000?oLkmkog>oNomc_gP;o00000onf
o=D00onT_^co0000o`000006oij]hP?o00001?n1XnT00ol0003oOIKPogfFh005ogfFh0?o00001OmM
U>`00ol0003oGX_Uoej;i@04oej;i@;oGXCO00?o0000odbIl_l000000om@T^h2o`0000CoE8kZ00?o
0000oeV;iomIRnL00_mIRnL2o`000003og>/mOl0003oMjSa00;oMjSa00Go0000og^Vk_mkY^koNjK^
o`00000Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000>?ooool00ol0003oHf[4of=Za004of=Za003o`00
0?mPIl?oH6O300KoH6O300?o0000og]`^omkL;/01omkL;/00ol0003oNg6log]a_008og]a_0;o0000
4?nDO[T4o`0000?oUX6k00?o0000ojV>^OnYS[T02_nYS[T2o`0000[o[9:k00?o0000okbQ__nlXKh0
1?nlXKh3o`0000go_jO100Co0000olfkb?o=^lSo00002OoA`/`2o`0000?oeL_@00?o0000omcVg?oL
i]`00ooLi]`01?l0003og>oNomc_g_oLkmh3o`0000;o]_cE0_nT_^`00ol0003oWZgRoij]hP04oij]
hP;o00000onIWmP2o`000003oh6SjOl0003oOIKP00KoOIKP00Go0000og^<f?mkS=SoNhcHo`000003
oefDk003o`000?mNRnGoGX_U00CoGX_U00Ko0000oej4gomNQ=ooGXCOodbIl_l00004oe2BkP03o`00
0?mDS^[oE8kZ00;oE8kZ00?o0000oeV;iomIRnL00_mIRnL2oej9i003o`000?mc[?Go000000?oMjSa
00Co0000og^Vk_mkY^ko00008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0gooooo`03
o`000?mSJ/CoHf[400CoHf[400?o0000of1W`omPIl<01OmPIl<00ol0003oGFO4o`000006og]`^`;o
00002_mkLK`00ol0003oO7>no`00000>oiAn^@?o00001_nFPK/00ol0003oZHjiojV>^@08ojV>^@;o
00003?n/T[/01?l0003o_:6nokbQ__nlXKh3o`0000oo_jO10_l0000:om72c0;o00001OoEbm001Ol0
003og>KLomcVg?oLi]co000000?og>oN0_l000001OoJn=ko0000okKleOn@j:ooY;k/00;o00001_nN
[N800ol0003oVIoHoiVOf004oiVOf0;o00001ommU^000ol0003oNhcHog^<f003og^<f003o`000?mM
U>co000000KoGX_U00?o0000oej4gomNQ=l00omNQ=l2o`0000?oD9;^0_l00003oeB>jP03o`000?mI
RnOoFH_W00;oFH_W1?mNRN@01Ol0003oMjSaogNXlOmgZ?7o000000?oNjK^00?o0000ooooooooool0
7_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool002Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oHf[4of=Za004of=Za003o`000?mPIl?oH6O300GoH6O300Go0000oeeWa?mMIlCoGFO4
o`000004og]`^`03o`000?mkLKcoNg6l00WoNg6l00Go0000ogac__mlLkkoO7>no`00000:oiAn^@?o
00002_nFPK/00ol0003oZHjiojV>^@04ojV>^@?o00003_n/T[/01?l0003o_:6no`000?l0000?oknW
`@?o000000?o`jg4o`000?oA`/`01_oA`/`3o`0000OoeL_@00?o0000omcVg?oLkmh00ooLkmh2o`00
0005om[hg_l0003o0000oi3X[ong_]l00_l00006oij]hP;o00001_nIWmP00ol0003oUIC@o`000005
ogfFh0;o00001_mkS=P3o`0000GoGX_U00?o0000oej4gomNQ=l01?mNQ=l2of1nfP;o000000CoD9;^
o`000?mDS^[o00000_mDS^X00ol0003oFH_WoeV;i`02oeV;i`03o`000?mNRNCoGXWT00;oGXWT0_l0
0002ogNXl@04o`000?mkY^koNjK^o`0001oooooo00?o0000ooooool000001Oooool00omEEEGoIVIV
o`000007ooooo`009?ooool00ol0003oooooooooo`0gooooo`03o`000?mSJ/CoHf[400CoHf[400?o
0000of1W`omPIl<01OmPIl<01Ol0003oGFO4oeeWa?mMIlCo000000?oNg2k00?o0000og]a_?mkLK`0
2OmkLK`00ol0003oO7>nogac_P02ogac_P03o`000?nDO[WoU7ji00KoU7ji0ol0000<oiJ1^`03o`00
0?nYS[WoZHji00;oZHji0_l0000@ojbB^`;o00003onoYl43o`0000Co`jg400?o0000om72c?oA`/`0
0ooA`/`2o`0000SoeL_@0_l00004omc_gP03o`000?oJn=kof_SN00;o000000CoYOC4oi3X[ong_]oo
00000_na[]H01?l0003oWZgRoij]h_nN[N82o`0000KoVIoH0_l00003oiFDd005o`000?mmU^3oOIKP
ogfFh?l000001omkS=P01?l0003oNHCBogV4d_miQ=82o`0000?oGX_U00?o0000oej4gomNQ=l00omN
Q=l00ol0003oH7kJof1nfP02of1nfP04oe2Bk_l0003oE8kZo`0000;oE8kZ00?o0000oeV;iomIRnL0
0_mIRnL00ol0003oGXWToej9i002oej9i0;oHhSQ0ol00003og^VkP03o`000?oooooooooo01oooooo
00?o0000ooooooooool03?ooool002Cooooo0_l0000hooooo`03odYZdOl0003oHf[400?oHf[400?o
0000of1W`omPIl<01OmPIl<00ol0003oGFO4oeeWa003oeeWa003o`000?mkL;_o000000_oNg6l00?o
0000ogac__mlLkh01?mlLkh00ol0003oU7jioiAn^@02oiAn^@Go00003OnFPK/00ol0003oZHjiojV>
^@02o`0000oo[9:k0ol000000on_Ukko0000oknW`@0<oknW`@;o00001oo3[L@01?l0003odL;<om72
c?oA`/`2o`0000SoeL_@0_l000001OoIe]Co0000omc_g_oLkmko000000;of_SN0_l000000ooCo][o
T>R_oi3X[`02o`0000Co/JkF00?o0000oij]h_l000001_nIWmP2o`0000KoUIC@00?o0000ogfFh?l0
00001omkS=P00ol0003oNHCBogV4dP04ogV4dP03o`000?mNRnGo000000KoGXCO00?o0000of1nf_mP
O]X00omPO]X2o`000004oeB>j_l0003oE8kZo`0000CoFH_W00?o0000oej9i?mNRN@00_mNRN@5of>8
h@;o000000?oNjK^o`000?ooool07oooool3o`0000gooooo000Tooooo`03o`000?oooooooooo03Oo
oooo0_m:J]401?l0003oHf[4of=Za?l00007of1W``03o`000?mMIlCoGFO400GoGFO400?o0000og]a
_?mkLK`02OmkLK`00ol0003oO7>nogac_P05ogac_P03o`000?nDO[Wo000000;o000000?oU7jio`00
0?l000003onFPK/2o`00013o[9:k0_l00005ojnG_P03o`000?noYl7o_jO100Oo_jO10ol00009ol>]
a004o`000?oA`/co0000o`0000OoeL_@0ol00002omWFe003o`000?oLkmkog>oN00?of_SN00Ko0000
om?nf_o6oloo0000okNngol00006ok6^eP;o00001_nIWmP00ol0003oUIC@oiFDd006oiFDd0;o0000
1omkS=P00ol0003oNHCBogV4dP05ogV4dP;o00001_mNQ=l00ol0003oH7kJof1nfP04of1nfP;oHW_F
00Co0000oeB>j_l0003o00001?mIRnL00ol0003oGXWToej9i002oej9i003o`000?mSR>7oHhSQ00;o
HhSQ0_mXRMl2o`0001gooooo0ol00002ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`00
0?oooooooooo03Oooooo0om:J]400ol0003oHf[4o`000007of1W``03o`000?mMIlCoGFO400GoGFO4
00?o0000og]a_?mkLK`01omkLK`2o`0000OoO7>n0ol00003oiAn^@03o`000?nFPK_oUX6k00goUX6k
0_l000000onHQKgo0000ojbB^`0=ojbB^`;o00001on_Ukh00ol0003o_jO1oknW`@05oknW`@;o0000
2oo3[L@2o`0000SoeL_@0_l00004omWFe0;o00000ooJn=h01ol0003odokJom?nf_o6oloo0000okNn
gol000001_na[]H01?l0003o[:;>ojbRc_l00003oiVOf0;o00002?nEU=001?l0003oTXc:oi:<b_l0
0005og^<f003o`000?miQ=;oNHCB00GoNHCB00?o0000ogQncOl000001OmNQ=l00ol0003oH7kJof1n
fP04of1nfP07o`000?mRNmKoHW_Fof9ke_l0003oE8kZo`000004oeV;i`03o`000?mNRNCoGXWT00;o
GXWT00?o0000of>8hOmSR>400_mSR>44ofR9g`03o`000?oooooooooo01Oooooo0ol00005ooooo`03
o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Kooooo00?o0000odYZdOm:J]40
0_m:J]400ol0003oH6O3of1W``05of1W``03o`000?mMIlCoGFO400GoGFO400?o0000oeaWaOl00000
1omkLK`00ol0003oO7>nogac_P04ogac_P?o00000_mlLkh01?l0003oU7jio`000?l0000>oiJ1^`;o
00000onHQKd00ol0003o[9:kojbB^`09ojbB^`?o00002On_Ukh00ol0003o_jO1oknW`@02oknW`@?o
00002oo3[L@2o`000003olNfbOl0003oeL_@00GoeL_@0_l00004omWFe0;o000000Cog>;Io`000?oJ
n=ko00000_oCo]X00oo6oloo0000o`000002o`0000Go/JkF0_l00004ojbRcP03o`000?nIWmSo0000
00SoUIC@0_l00004oi:<bP05o`000?mkS=SoNhcHog^<f?l000001omiQ=801Ol0003oN7k=ogQncOmh
O/go000000CoGXCO00?o0000of1nf_mPO]X00omPO]X00ol0003oHW_Fof9keP03of9keP03oeB>j_l0
003oFH_W00?oFH_W00?o0000oej9i?mNRN@00_mNRN@00ol0003oHhSQof>8h@02of>8h@05o`000?mX
RMooJ8WOofR9gol000005Oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0
000gooooo`03o`000?m:J]7oBV[A00;oBV[A00?o0000of1W`omPIl<01OmPIl<00ol0003oGFO4oeeW
a004oeeWa004o`000?mLIlGoG6O5o`0000KoNg6l00?o0000ogac__mlLkh00_mlLkh3o`0000GoO7>n
0_l0000>oiJ1^`;o00001_nHQKd00ol0003o[9:kojbB^`06ojbB^`;o00003On_Ukh01?l0003o_jO1
o`000?l0000;ol>]a0?o00000oo7]/T00ol0003oeL_@omG;d002omG;d0;o00001?oIe]@2o`0000;o
g>;I00?o0000om[hg_oCo]X00_oCo]X01?o6oloo0000okNngol00005ok6^eP;o00001_n/X/h2o`00
00OoUIC@0_l00007oi:<bP03o`000?mkS=So000000OoNHCB00?o0000ogQncOmhO/d00omhO/d01?l0
003oGXCOoej4gol00006of1nfP03o`000?mRNmKoHW_F00CoHW_F0_l00003oeV;i`03o`000?mNRNCo
GXWT00;oGXWT00?o0000of>8hOmSR>400_mSR>401Ol0003oJ8WOofR9gomXRMoo000001;ooooo0ol0
000=ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000
odYZdOm:J]400_m:J]400om3Im3o0000of1W``04of1W``03o`000?mMIlCoGFO400GoGFO400Go0000
oeaWaOmLIlGoG6O5o`000004og]a_003o`000?mlLkkoO7>n00?o00001omlLkh00ol0003oOGK0o`00
000<oiJ1^`;o00002?nHQKd00ol0003o[9:kojbB^`04ojbB^`;o00003_n_Ukh2o`0000co`jg40_l0
0005olNfb@04o`000?oEbm3oeL_@omG;d0;o00001?oIe]@2o`0000;og>;I0_l00003om?nfP03olKo
col0003o000000;o00001Ona[]H00ol0003o[:;>ojbRcP04ojbRcP;o000000?oYiW8o`000?nEU=00
1OnEU=000ol0003oTXc:oi:<bP07oi:<bP;o00001_miQ=82o`0000OoN7k=00?o0000oej4gol00000
1OmPO]X00ol0003oHW_Fof9keP05of9keP;oI7WC00Co0000oeV;iomIRnOo00000omNRN@00ol0003o
HhSQof>8h@03of>8h@05o`000?mXRMooJ8WOofR9gol000003oooool3o`00013ooooo00?o0000oooo
ooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003oBV[AodYZd@02odYZd@;o
@fO@00Go0000of1W`omPIl?oH6O3o`000007oeeWa003o`000?mLIlGoG6O500?oG6O500?o0000og]a
_?mkLK`01?l00009ogac_P05o`000?mmM/3oOGK0ogef`?l000002_nFPK/00ol0003oV8FmoiR5_@08
oiR5_@04o`000?n/T[_o[9:kojbB^`?o00003_n_Ukh2o`000003ok:M`ol0003o`jg400Wo`jg40_l0
0007olNfb@03o`000?oEbm3o000000GofMKD0_l00002omcRf@;o000000[ogNkMo`000?oCo][odokJ
olKocol0003o/ONmo`000?o0]m7o00000ona[]H2o`0000Go[:;>0_l00004ojNIb004o`000?nEU=3o
UIC@oiFDd0;o00002?nBS<X2o`000003ohn6aOl0003oNHCB00CoNHCB00?o0000ogQncOmhO/d01omh
O/d2o`0000KoH7kJ00?o0000of9ke_mRNmH01?mRNmH01ol0003oI7WCofAidomTNM?o0000oeV;iol0
00000omNRN@00ol0003oHhSQof>8h@03of>8h@05o`000?mXRMooJ8WOofR9gol000002oooool4o`00
01?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003o
BV[AodYZd@02odYZd@03o`000?m3Im3o000000?oH6O300?o0000oeeWa?mMIl@01?mMIl@00ol0003o
G6O5oeaWa@04oeaWa@Co00002omlLkh00ol0003oOGK0ogef`002ogef`003o`000?nFPK_oUX6k00Ko
UX6k0_l0000<oiR5_@03o`000?n/T[_o000000ko[iNn0ol00003ok:M``03o`000?o3[LCo`jg400Ko
`jg40_l00008olNfb@;o00001_oIe]@01Ol0003og>;IomcRfOoLh]Wo000000;ogNkM00Co0000om?n
f_o6olooa_o?0_l00004ol2gd@03o`000?na[]Ko000000Go[:;>0_l00007ojNIb003o`000?nEU=3o
000000WoTXc:00?o0000ohn6aOn?Q/D00_n?Q/D01Ol0003oNHCBogV4d_miQ=;o000000WoN7k=00Co
0000ogMjbOmgN/Wo00001?mPO]X00ol0003oHW_Fof9keP05of9keP04o`000?mTNM?oI7WCofAid`?o
00000omNRN@00ol0003oHhSQof>8h@03of>8h@05o`000?mXRMooJ8WOofR9gol000002?ooool3o`00
01Oooooo00?o0000ooooooooool02_ooool002?ooooo0ol0000gooooo`05o`000?m:J]7oBV[AodYZ
dOl000000om3Im000ol0003oH6O3o`000006oeeWa003o`000?mLIlGoG6O500?oG6O51?l0000;ogac
_P;o00001_mmM/000ol0003oUX6koiJ1^`03oiJ1^`;o00003OnHQKd2o`0000ko[iNn0_l00006ok:M
``03o`000?o3[LCo`jg400Co`jg40_l00008olNfb@;o000000?oc<3?o`000?oIe]@00ooIe]@2o`00
00;og>;I0_l00002omg^g@;o000000?oa_o?o`000?namkd01_o0]m42o`0000Go[:;>00?o0000ojNI
b?nWVLP01onWVLP2o`0000SoTXc:0_l00006ohn6a@03o`000?miQ=;o000000WoN7k=00?o0000ogMj
bOmgN/T00_mgN/T01?l0003oH7kJof1nf_l00007of9keP03o`000?mTNM?oI7WC00?oI7WC0ol00002
oej9i003o`000?mSR>7oHhSQ00;oHhSQ00?o0000ofR9gomXRMl00_mXRMl00ol0003oooooooooo`03
ooooo`?o00006_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0goooo
o`05o`000?m:J]7oBV[AodYZdOl000001?m3Im000ol0003oGFO4oeeWa005oeeWa003o`000?mLIlGo
G6O500?o00000omLIlD00ol0003oO7>nogac_P08ogac_P03o`000?mmM/3oOGK000KoOGK000Co0000
oiJ1^onFPK_oUX6k0_l0000=oiR5_@;o000000?oVh_1o`000?n_Ukh02on_Ukh2o`0000Wo/Yg300Co
0000ol>]a?o3[LCo`jg40_l00008olNfb@;o00000oo<`<l01Ol0003ofMKDomWFe?oIe]Co000000?o
g>;I00Ko0000omg^gOoMk]gogNkMo`000?oJnMd2o`000003ok7g_Oo0]m7o`;OA00?o`;OA0_l00000
0onkZl[o0000ojbRcP02ojbRcP;o00002?nWVLP2o`000003ojBB`ol0003oTXc:00GoTXc:0_l00008
ohn6a@;o00002OmhO/d00ol0003oMg[9ogMjb@04ogMjb@03o`000?mPO][o000000OoHW_F00?o0000
ofAidomTNM<01?mTNM<01Ol0003oIWSAo`000?mNRNCo000000CoHhSQ00?o0000ofR9gomXRMl00_mX
RMl00ol0003oooooooooo`03o`0001gooooo00?o0000ooooooooool02_ooool00005onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1?ooool00ol0003oooooooooo`0hooooo`05o`000?m:J]7oBV[AodYZdOl000001?m3Im000ol0003o
GFO4oeeWa004oeeWa0Co00001OmLIlD00ol0003oFfW7o`000008ogac_P03o`000?mmM/3oOGK000Oo
OGK000Co0000oiJ1^ol0003o00003OnHQKd2o`0000CoVh_100?o0000ojnG__n_Ukh01on_Ukh2o`00
00_o/Yg300?o0000ol>]a?l000002Oo7]/T2o`0000Goc<3?00?o0000omWFe?l000000ooLh]T01?l0
003ogNkMomg^gOoMk]d2o`000004om[igOl0003o/ONmok7g_@Co`;OA0_l00004ok^[bP?o00002?nW
VLP2o`0000CoY9;300?o0000oi:<b_nBS<X00_nBS<X00ol0003oShK5ohn6a@07ohn6a@03o`000?n=
P/;o000000OoN7k=0_l00008ogMjb@03o`000?mRNmKoHW_F00GoHW_F00?o0000ofAidomTNM<01?mT
NM<2o`0000;oIWSA0_l00004of>8h@03o`000?mXRMooJ8WO00;oJ8WO0ol0000Pooooo`03o`000?oo
oooooooo00[ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo
00Go0000odYZdOm:J]7oBV[Ao`000004od=Wd003oceUdOl0003oGFO400;oGFO40ol00007oeaWa@04
o`000?mKJLOoFfW7o`0000KoO7>n0_l0000:ogef`0;o00003OnHQKd2o`0000KoVh_100?o0000ojnG
__n_Ukh01On_Ukh2o`0000co/Yg30_l00009olNfb@;o00001_o<`<l2o`0000Cog>;I00Ko0000omg^
gOoMk]gogNkMo`000?oJnMd2o`000003ok7g_OmgdHWo`;OA00;o`;OA0_l00005ok^[bP;o00002?nW
VLP2o`0000OoY9;300Co0000oi:<b_l0003o00002?n?Q/D2o`0000?oSH;200?o0000ogQncOmhO/d0
0omhO/d00ol0003oMg[9ogMjb@07ogMjb@03o`000?mgN<Ko000000GoHW_F00?o0000ofAidomTNM<0
1OmTNM<00ol0003oIWSAo`000002ofIhd@;o00000omSR>400ol0003oJ8WOofR9g`02ofR9g`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02Oooool00005oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00;ooooo0_l0000hooooo`03o`00
0?m:J]7oBV[A00;oBV[A00?o0000od=Wd?m3Im000_m3Im02oceUd@?o000000?oGFO4o`000?mLIlD0
1omLIlD01Ol0003oFfW7oe]YaomKJLOo000000CoO7>n00?o0000ogef`?mmM/002OmmM/000ol0003o
Og[4o`00000;oiR5_@;o00002OnKRl401?l0003o[iNnojnG__n_Ukh3o`0000co/Yg30_l000000ong
Y/So0000olNfb@06olNfb@;o00001_o<`<l2o`000003om7<eOl0003og>;I00;og>;I0ooMk]d2o`00
0004om[igOl0003ocooFo`0000?o`;OA0_l00005ok^[bP;o000000?o]j?4o`000?nWVLP01OnWVLP2
o`0000WoY9;30_l00009ohn6a@03o`000?n=P/;oSH;200CoSH;200Go0000ogQncOmhO/goN7k=o`00
0009ogMjb@05o`000?mgN<KoMgS6ogMha_l000001?mRNmH00ol0003oI7WCofAid`04ofAid`06o`00
0?mVN=7oIWSAofIhdOl0003oIWSA0_mYNM001?l0003oHhSQof>8hOl00004ofR9g`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02Oooool00005o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=oooool0
0ol0003oBV[AodYZd@02odYZd@03o`000?m3Im3o@fO@00;o@fO@1?l000000omMIlCo0000oeaWa@07
oeaWa@03o`000?mKJLOoFfW700?oFfW700Co0000ogac__mlLkko00002ommM/001Ol0003oOg[4ogmj
a?moN/Co000000WoV8Fm00?o0000oi^;`OnKRl402OnKRl401?l0003o[iNnojnG__l0000=ok:M``;o
00000ongY/P00ol0003oakK9olNfb@03olNfb@;o00001_o<`<l2o`0000?odLcE00?o0000omcRfOoM
k]d00ooMk]d00ol0003of_WMom[ig@03o`0000;o`;OA0_l00006ok^[bP03o`000?ngXlCo]j?400;o
]j?400Co0000ojNIb?nWVLSoYiW80_l00009ojBB``;o000000?oXHfoo`000?n?Q/D01_n?Q/D2o`00
00SoSH;200?o0000ogQncOl000002OmgN/T00ol0003oMgS6ogMhaP03ogMhaP04o`000?mRNmKoHW_F
o`0000KoI7WC00?o0000ofIhdOmVN=400omVN=401ol0003oJGW@ofUid?mYNM3o0000of>8hOl00000
1?mXRMl00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool0=oooool00ol0003oBV[AodYZd@02odYZd@03o`000?m3Im3o000000?o
00000olmIM400ol0003oG6O5oeaWa@06oeaWa@03o`000?mKJLOoFfW700CoFfW700?o0000ogac__l0
00002_mmM/02o`0000GoOg[400?o0000oiR5_OnHQKd01?nHQKd2o`0000coVh_10_l0000=ok:M``;o
00001_ngY/P00ol0003oakK9olNfb@02o`0000Koc<3?0_l00004om7<e@;o00000ooMk]d01?l0003o
f_WMom[igOoJnMd6o`0000Ko^j_:0_l00005okNSa004o`000?nWVLSo0000o`0000WoY9;30_l00004
oj6=_`03o`000?n?Q/GoShK500?oShK500?o0000ohf2`_n=P/802?n=P/82o`0000WoMg[900?o0000
ogMha_mgN<H01OmgN<H00ol0003oHW_Fo`000006ofAid`03o`000?mVN=7oIWSA00?oIWSA00?o0000
ofUid?mYNM000_mYNM02o`0000CoJ8WO00?o0000ooooooooool08Oooool00ol0003oooooooooo`09
ooooo`0000Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0gooooo`04o`000?m:J]7oBV[AodYZd@?o00000om3
Im001Ol0003o?FGAoceUdOlmIM7o000000SoG6O500?o0000oe]YaomKJLL01OmKJLL00ol0003oOGK0
ogef`008ogef`003o`000?moN/CoOg[400GoOg[400?o0000oiR5_OnHQKd00_nHQKd2o`0000coVh_1
0_l000000onOTLKo0000ok:M``09ok:M``?o00002?ngY/P00ol0003oakK9o`000006olc0c`;o0000
1?oAc=D2o`000005omKJg?l0003ogNkMomg^gOl000000_oJnMd00ol0003ocooFo`000003o`0000Ko
^j_:0_l00007okNSa0;o00002OnTT/<2o`0000OoXHfo00?o0000ohn6aOn?Q/D00_l0000:ohf2`P03
o`000?n<O[oo000000SoMg[900?o0000ogMha_mgN<H01_mgN<H2o`0000KoI7WC00?o0000ofIhdOmV
N=400omVN=400ol0003oJGW@o`000004ofUid0;o00000omXRMl00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Wooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0000hooooo`03odEmh_l0003o0000
00;o00001Om3Im001_l0003o?FGAoceUdOlmIM7o>6GCo`0000KoG6O500?o0000oe]YaomKJLL01_mK
JLL00ol0003oOGK0ogef`007ogef`003o`000?moN/CoOg[400OoOg[400Co0000oiR5_Ol0003o0000
3?nKRl42o`0000CoWi7600?o0000ok:M`onbWL<01OnbWL<2o`0000[o]jK80_l00007olc0c`03o`00
0?oAc=GodLcE00?odLcE00Ko0000omKJg?oFf]coe][Lo`000?oMk]d3om[ig@03o`000?o?omKo0000
00;o000000?obKW;o`000?nkZlX00onkZlX2o`0000Oo]j?40_l000000oncW<3o0000ojBB``07ojBB
``03o`000?nQSKooXHfo00OoXHfo00?o0000ohn6aOl000002_n=P/82o`0000?oS7jo00?o0000ogMj
bOmgN/T01?mgN/T00ol0003oMgS6ogMhaP06ogMhaP03o`000?mhM/Co000000KoI7WC00?o0000ofIh
dOmVN=400omVN=401?l0003oJGW@ofUid?l00003ofUid0;oKG[?00Co0000ofR9gomXRMoo00008ooo
ool00ol0003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool0=_ooool3o`000004odEm
h_l0003oBV[Ao`0000Co@fO@00?o0000oceUdOlmIM400_lmIM42ocQUd`03o`000?mLIlGoG6O500;o
G6O500?o0000oe]YaomKJLL01_mKJLL00ol0003oFfg;o`000007ogef`003o`000?moN/CoOg[400So
Og[40_l0000<oi^;`@;o00001_nOTLH00ol0003o/Yg3ok:M``03ok:M``;o00002_ngY/P2o`000003
okb`c_l0003oc<3?00Coc<3?0_l00004om7<e@;o00000ooFf]`2o`0000?of_WM0_l000000onjnlGo
0000olVib`02olVib`05o`000?nkZl[o^j_:ok^[b_l000001ongXl@2o`0000Co/ic000?o0000ojBB
`onTT/<00onTT/<2o`0000[oXHfo0_l0000:ohf2`P03o`000?n<O[ooS7jo00CoS7jo00?o0000ogMj
bOmgN/T00_mgN/T00ol0003oMgS6ogMhaP06ogMhaP05o`000?mhM/CoN7K4ogQfa?l000001?mTNM<0
0ol0003oIWSAofIhd@04ofIhd@07o`000?mYNM3oJGW@ofUid?l0003oJGW@o`000003ofejc`03o`00
0?mXRMoo000002?ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000ooooooooool0<ooo
ool3o`0000?ooooo0_m5ON82o`0000Co@fO@00?o0000oceUdOlmIM400_lmIM401?l0003o>6GCocQU
dol00003oeaWa@03o`000?mKJLOoFfW700GoFfW700Go0000oe]]bomKKL_oFfg;o`000004ogef`0;o
00002_moN/@00ol0003oPX79o`00000:oi^;`@;o00002?nOTLH01?l0003o/Yg3ok:M`onbWL<2o`00
00[o]jK80_l00003okb`cP04o`000?o<`<ooc<3?olc0c`;o00001?oAc=D2o`0000Coe][L00?o0000
omSZhOl000000_oJnMd01?o?omKo0000o`000?l00005olVib`?o00001_ngXl@2o`0000Ko/ic000Co
0000ojBB`onTT/?oY9;30_l0000:oj6=_`;o000000?oWhRlo`000?n=P/801on=P/82o`0000OoS7jo
00Go0000ogMjbOmgN/WoMg[9o`000008ogMhaP03o`000?mhM/CoN7K400?oN7K400Co0000ofAidomT
NM?o00001_mVN=400ol0003oJGW@ofUid002ofUid003o`000?mYNM3o000000CoKG[?0_l0000Toooo
o`03o`000?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo033ooooo0ol00006ooooo`03
o`000?m5ON;oAGgR00;o00000om3Im000ol0003o?FGAoceUd@02oceUd@07o`000?lhIM?o>6GCocQU
dol0003oG6O5o`000007oe]Ya`03o`000?mKKL_oFfg;00;oFfg;00Go0000ogef`?mmM/3oOGK0o`00
000;ogmja005o`000?n2PLWoPX79oh:1bOl000002?nKRl400ol0003oWi76oinAaP09oinAaP03o`00
0?nbWL?o000000[o]jK80_l00006okb`cP03o`000?o<`<oo000000CodLcE0_l00004omKJg0;o0000
0_oHj^401Ol0003of_WMolooe_njnlGo000000KobKW;0_l00007okNSa003o`000?ncW<3o/ic000Ko
/ic000Co0000ojBB`ol0003o00002_nQSKl2o`0000CoWhRl00?o0000ohf2`_n=P/801?n=P/800ol0
003oS7joohan_`08ohan_`03o`000?mgN/Wo000000SoMgS600?o0000ogQfa?mhM/@01OmhM/@00ol0
003oI7WCo`000006ofIhd@03o`000?mYNM3oJGW@00?oJGW@00?o0000ofejcom]N/l01?m]N/l00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`;o0000;_ooool3o`0000[o
oooo0_m5ON82ocYjh`04o`000?m3Im3o@fO@o`0000Co?FGA00?o0000ocQUdolhIM<00_lhIM<00ol0
003oFfW7oe]Ya`05oe]Ya`03o`000?mKKL_oFfg;00CoFfg;00?o0000ogef`?l000002_moN/@2o`00
00CoPX7900?o0000oi^;`OnKRl401?nKRl42o`0000_oWi760_l0000:okNVb0;o00001onl/<h2o`00
00GodLcE00?o0000omKJg?oFf]`00ooFf]`01?l0003of>[QomSZhOoHj^42o`000003olooe_njnlGo
bKW;00GobKW;0_l000000oo5/<Ko0000okNSa004okNSa0;o00002OncW<02o`0000[oXHfo0_l00006
oin8_003o`000?n=P/;oSH;200?oSH;200?o0000ohan_on<O[l02On<O[l2o`0000SoMgS600?o0000
ogQfa?mhM/@01omhM/@00ol0003oIWSAofIhd@04ofIhd@03o`000?mYNM3oJGW@00CoJGW@0_l00005
ofejc`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000oooo
ooooool0:_ooool3o`0000gooooo00?o0000odEmh_m5ON800_ljN^<00ol0003o@fO@o`000003oceU
d@03o`000?lhIM?o>6GC00?o>6GC00?o0000oe]YaomKJLL01OmKJLL00ol0003oFfg;oe]]b`05oe]]
b`03o`000?moN/CoOg[400SoOg[400?o0000oh:1bOn2PLT01On2PLT01?l0003oVh_1oi^;`OnKRl42
o`0000_oWi760_l000000onSV/co0000okNVb008okNVb003o`000?nl/<ko_;3>00Go_;3>0_l00000
0oo1_=Go0000om7<e@02om7<e@03o`000?oFf]coe][L00?oe][L0_l00003omSZh@?o000000?o^__5
olViboo9^L/00oo9^L/2o`0000?oaK3600Co0000okNSa?ngXlCo]j?40_l00009ok>L`0;o000000?o
/9Nmo`000?nQSKl01onQSKl2o`0000WoWhRl00?o0000ohf2`_n=P/800_l0000;ohan_`03o`000?n;
O;go000000OoMgS600?o0000ogQfa?mhM/@01omhM/@00ol0003oNGK3o`000005ofIhd@03o`000?mY
NM3oJGW@00?oJGW@00Co0000ofejcom]N/oo00000om]N/l00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo02Oooooo0ol0000@ooooo`03o`000?m5
ON;oAGgR00?o>W[S0_l00003oceUd@03o`000?lhIM?o>6GC00?o>6GC00?o<fKFo`000?mKJLL01?mK
JLL00ol0003oFfg;oe]]b`06oe]]b`03o`000?moN/CoOg[400OoOg[400?o0000oh:1bOn2PLT01_n2
PLT01?l0003oVh_1oi^;`Ol0000<oinAaP03o`000?nSV/coXi[<00;oXi[<00?o0000okNVb?ngY/P0
1?ngY/P2o`0000Oo_;3>00?o0000ol6leOo1_=D00_o1_=D00ol0003odLcEo`000004omKJg0;o0000
0ooHj^45o`0000?obKW;0ol00006olF`aP?o00002?ncW<03o`0000Co/9Nm00?o0000oj6=_onQSKl0
0onQSKl2o`0000_oWhRl00?o0000ohf2`_l000002on<O[l2o`0000?oRgbm00?o0000ogMha_mgN<H0
0omgN<H00ol0003oN7K4ogQfa007ogQfa005o`000?miM/?oNGK3ogUf`ol000000omVN=400ol0003o
JGW@ofUid004ofUid004o`000?m]N/ooKG[?o`0000?oKG[?00?o0000ooooooooool08oooool00ol0
003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Uooooo`?o00005?ooool00ol0003o
AGgRo`000003ocYjh`05o`000?lmIM7o?FGAoceUdOl000001OlhIM<00ol0003o<fKFo`000003oe]Y
a`03o`000?mKKL_oFfg;00KoFfg;00?o0000oeabd?l000001omoN/@00ol0003oPX79oh:1b@07oh:1
b@;o00003?nOTLH2o`0000KoXi[<00Co0000okNVb?ngY/So]jK80_l00007okb`cP;o00001?o1_=D2
o`0000Goe][L00Co0000omSZhOoHj^7of>[Q0_l000001?oEnN;o0000o`000?l00002olVib`;o0000
2?o5/<H2o`0000So/ic00_l00007ok2G_@04o`000?nQSKooXHfooj6=_`;o00003OnOR;`2o`0000_o
S7jo00?o0000oh]l_On;O;d01?n;O;d01Ol0003oMgS6ogMha_mgN<Ko000000WoN7K400?o0000ogUf
`omiM/<00omiM/<01?l0003oIWSAofIhdOl00005ofUid003o`000?m]N/ooKG[?00;oKG[?00?o0000
ofejcol000009_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`0002?ooooo0ol0000Goooo
o`04o`000?m5ON;oAGgRo`0000;o>W[S00Go<7SSo`000?lmIM7o?FGAo`000004ocQUd`07o`000?lc
I]Ko<fKFoc=Ve_l0003oFfW7o`000008oe]]b`05o`000?mLL]3oG7;@oeabd?l000001?moN/@2o`00
00WoPX7900?o0000ohJ9col000002_nOTLH2o`0000SoXi[<00Co0000okNVb?ngY/So00001onl/<h2
o`0000Go`KcE00?o0000olO<g_l000001?oFf]`01Ol0003of>[QomSZhOoHj^7o000000;oeOWR0_l0
0002olVib`;o00002?o5/<H2o`000003ol6Y`_l0003o/ic000Go/ic00_l00009ok2G_@04o`000?nQ
SKoo0000o`0000goWhRl0_l000000onMQK[o0000ohan_`08ohan_`;o00002?n;O;d00ol0003oMgS6
o`000009ogQfa003o`000?miM/?oNGK300GoNGK300?o0000ofIhdOl000001OmYNM000ol0003oKG[?
ofejc`03ofejc`;o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool00ol0003ooooooooo
o`0Pooooo`;o00006_ooool01?l0003oAGgRodEmh_l00003ocYjh`04oc1hhol0003o?FGAo`0000Co
>6GC00?o0000oc=Ve_lcI]H00_lcI]H00ol0003oFfg;oe]]b`06oe]]b`03o`000?mLL]3oG7;@00;o
G7;@00Go0000ogmja?moN/CoOg[4o`00000:oh:1b@05o`000?n6RLooQXW?ohJ9col000002?nOTLH0
0ol0003oXi[<oj>Jc008oj>Jc0;o00001onl/<h2o`0000Go`KcE0_l00003olO<gP03o`000?oFf]co
e][L00?of>[Q0_l00002omGihP05olOofOl0003o0000olVibol000001oo5/<H3o`0000?o`JW200Co
0000ok>L`?ncW<3o/ic00ol0000;ok2G_@;o00003OnOR;`2o`0000CoWHFj00?o0000ohan_on<O[l0
1?n<O[l2o`0000[oRgbm0_l00009ogQfa003o`000?miM/?oNGK300KoNGK30_l00006ofUid003o`00
0?m]N/ooKG[?00CoKG[?00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`008?oo
ool00ol0003oooooooooo`0Mooooo`?o00007Oooool01?l0003oAGgRodEmh_l00002ocYjh`04o`00
0?l`N>?o0000o`0000Co>6GC00?o0000oc=Ve_lcI]H00_lcI]H00ol0003oFfg;oe]]b`05oe]]b`03
o`000?mLL]3oG7;@00CoG7;@00?o0000ogmja?l000002On2PLT2o`0000GoQXW?00?o0000oinAa_nO
TLH00onOTLH2o`0000WoXi[<0_l000000onYYM?o0000okb`cP04okb`cP;o00001_o1_=D00ol0003o
alcNolO<gP03olO<gP;o00000ooHj^400ol0003oeOWRomGihP02o`000003ojcg`Ol0003o000000Oo
aK360_l00007ol6Y`P?o00002on`Ukd3o`000003ojjB^_l0003oWhRl00[oWhRl0_l00006oif5^P03
o`000?n<O[ooS7jo00?oS7jo00?o0000oh]l_On;O;d02On;O;d00ol0003oRgZlo`000008ogQfa003
o`000?miM/?oNGK300KoNGK300?o0000ogYf`ol000001OmYNM000ol0003oKG[?ofejc`04ofejc`;o
00009oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o0000
8?ooool01?l0003oAGgRodEmh_l00002ocYjh`04o`000?l`N>?o<7SSo`0000Co>6GC00?o0000oc=V
e_lcI]H00_lcI]H00ol`J]Wo0000oe]]b`04oe]]b`03o`000?mLL]3oG7;@00KoG7;@00?o0000oh:1
bOn2PLT01on2PLT00ol0003oQXW?ohJ9c`05ohJ9c`03o`000?nOTLKoWi7600;oWi7600?o0000oj>J
c?nSV/`01onSV/`2o`0000CoZJGC00Go0000okb`c_nl/<ko_;3>o`000006ol6le@;o00001Oo7c=h0
0ol0003oc=kVo`000002omSZh@?oeOWR0_l000001?n/ml7o0000om74cOl00005olF`aP;o00002?o1
ZL82o`0000_o/9Nm0_l00005ojjB^P03o`000?nOR;coWhRl00GoWhRl0ol00009oif5^P03o`000?n<
O[ooS7jo00;o00002_n;O;d2o`0000?oRgZl00?o0000ogQfa?mhM/@01?mhM/@00ol0003oNGK3ogUf
``06ogUf``05o`000?mjM/?oNWK3ogYf`ol000001?mYNM000ol0003oKG[?ofejc`04ofejc`03o`00
0?oooooo000002Kooooo00?o0000ooooooooool01oooool0023ooooo0ol0000Gooooo`?o00008ooo
ool01?l0003oAGgRodEmh_l00003ocYjh`04o`000?l`N>?o9WSTo`0000?o>6GC00?o0000oc=Ve_lc
I]H00_lcI]H00ol0003o<6[Io`000003oe]]b`03o`000?mLL]3oG7;@00OoG7;@00?o0000oh:1bOn2
PLT01_n2PLT00ol0003oQXW?ohJ9c`07ohJ9c`03o`000?nOTLKoWi7600WoXi[<0_l00006ojVUd`04
o`000?nl/<ko_;3>o`0000Go`KcE0_l00005olO<gP;o00000_o<g^H2o`0000?oeOWR00?oaooIojcg
`On/ml400ooAa<d00ol0003oaK36olF`aP03o`0000Oo`JW20ol000000onmXkoo0000ok2G_@07ok2G
_@?o00001on^T[X00ol0003oWhRloin8_003oin8_0;o00003?nMQKX00ol0003oS7joo`00000;oh]l
_@03o`000?n;N[coRgZl00CoRgZl00?o0000ogQfa?mhM/@00_mhM/@00ol0003oNGK3ogUf``06ogUf
``03o`000?mjM/?oNWK300?oNWK300Co0000ofUid?mYNM3o00001_m]N/l01Ol0003ooooooooooooo
oooo000002Gooooo00?o0000ooooooooool01oooool001oooooo0_l0000Fooooo`?o00009oooool0
1?l0003oAGgRodEmh_l00002ocYjh`07o`000?l`N>?o<7SSobIhi?l0003o>6GCo`000005oc=VeP06
o`000?l`J]Wo<6[Io`000?mKKL_o00002OmLL]000ol0003oGW[Fo`000005oh:1b@;o00002_n6RLl2
o`0000WoXi[<00?o0000ojVUdonYYM<01_nYYM<2o`0000Ko`KcE00?o0000olO<g_o7c=h01?o7c=h0
1ol0003oc=kVolcNi_o<g^Ko0000olg`jol000000_oEnN800oo7omWo[?O1ojcg`@04om74c@03o`00
0?o5/<Ko000000So`JW20_l00004okfS_`03o`000?n`Ukgo/9Nm00Co/9Nm0_l0000:ojjB^P04o`00
0?nOR;coWhRloin8_0;o00003_nMQKX2o`0000[oRgbm0_l00007oh]j_005o`000?mhM/CoN7K4ogQf
a?l000002?miM/<00ol0003oNWK3ogYf``05ogYf``03o`000?mYNM3o000000KoKG[?00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01;ooooo0ol0000Zooooo`04o`000?m5ON;oAGgRo`0000?o>W[S00Co
0000oc1hhol0003o9WST0_l00005oc=VeP05o`000?l`J]Wo<6[Ioc1ZfOl000002OmLL]001Ol0003o
GW[Foeije_mNN]Ko000000?oPX7900?o0000ohJ9con6RLl02?n6RLl2o`000003ohZCe_l0003oXi[<
00KoXi[<0_l00008ojVUd`04o`000?n_/mco[k?Lo`0000Co`KcE00?o0000olO<g_o7c=h00oo7c=h2
o`0000;oc=kV0_l00002olg`j`Go00001?oAa<d2o`0000Oo`JW20ol00007okfS_`04o`000?n`Ukgo
/9Nmok2G_@;o00003On^T[X3o`0000koWHFj0_l000000onLPkSo0000oh]l_@08oh]l_@03o`000?n;
N[coRgZl00SoRgZl00?o0000ogQfa?l000002?miM/<00ol0003oNWK3ogYf``07ogYf``03o`000?m]
N/ooKG[?00CoKG[?00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`?o0000;Oooool01Ol0003oAGgRodEm
h_m5ON;o000000;o>W[S00?o0000oc1hhol`N><00_lVN>@2o`0000?o<fKF00?o0000oc1ZfOl`J]T0
0_l`J]T00ol^L=ko0000oeabd006oeabd003o`000?mNN]KoGW[F00?oGW[F00?o0000oh:1bOl00000
2_n6RLl00ol0003oRY?FohZCeP02ohZCeP03o`000?nSV/coXi[<00;oXi[<0_l00008ojVUd`;o0000
1?n_/m`00ol0003o`KcEol6le@05olO<gP;o00000oo<g^H01?l0003ocO3[olg`joo=l>/2o`000003
oj_icol0003odLC=00;odLC=0ol000000oo=^lWo0000ol6Y`P04ol6Y`P;o00002_nmXkl4o`0000ko
[Y:j0_l0000=oif5^P?o00001?nLPkP00ol0003oRgbmoh]l_@04oh]l_@;o00002on;N[`2o`0000So
NGK300?o0000ogYf`omjM/<01omjM/<00ol0003oNgO3o`000005ofejc`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o
0000<Oooool2o`000005odEmh_l0003o>W[SocYjhol000000_l`N><01Ol0003o9WSToaiiiOlNNNGo
000000;o<fKF00?o0000oc1ZfOl`J]T00_l`J]T00ol0003o;W3No`000005oeabd003o`000?mNN]Ko
GW[F00GoGW[F00?o0000ohJ9con6RLl01on6RLl2o`0000KoRY?F00Co0000oj>Jc?nSV/co00002?nY
YM<2o`0000Ko[k?L0_l00005olO<gP04o`000?o<g^Koc=kVolcNiP;o00000_o=l>/5o`000004om74
cOl0003o0000o`0000CocK_900Co0000ol6Y`_o1ZL;o`JW20_l0000;okfS_`;o00003_n^T[X3o`00
0003ojb?^?l0003oWHFj00[oWHFj0_l00007oib3^003o`000?n;O;goRgbm00?oRgbm00?o0000oh]j
_?n;N[`02On;N[`2o`000003ohYj^ol0003oNGK300KoNGK300?o0000ogYf`omjM/<01omjM/<01Ol0
003oNgO3og]g`omkMl?o000000CoKG[?00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00Co0000ofVTlol0003o00000olj
N^<01Ol0003o<7SSoc1hhol0003o9WST00;o7WWU00?o0000oc=Ve_l000001?l`J]T01?l0003o;W3N
obi`g_l00003oeabd003o`000?mNN]KoGW[F00GoGW[F00?o0000of64g_l000001_n6RLl2o`0000So
RY?F0_l00009ojVUd`03o`000?n_/mco[k?L00Go[k?L00?o0000okG5i_l000001?o7c=h01Ol0003o
c=kVolcNi_o<g^Ko000000;ocO3[0_l000001?o4o>Go0000o`000?n6hZT2o`0000OocK_900Co0000
ol6Y`_l0003o00002_nmXkl3o`000003ok^O_?l0003o[Y:j00_o[Y:j0_l00005ojb?^003o`000?nM
QK[oWHFj00KoWHFj0_l0000:oib3^003o`000?n;O;goRgbm00;o00002on;N[`00ol0003oRWZkohYj
^`02ohYj^`03o`000?miM/?oNGK300?oNGK300?o0000ogYf`omjM/<01omjM/<00ol0003oNgO3og]g
``03og]g``04o`000?m]N/ooKG[?o`0000Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo00Kooooo0ol0000hooooo`03o`000?mYY??oJJCc00;o
000000Oo>W[So`000?l`N>?o<7SSo`000?lVN>Co000000;o7WWU0_l00004oc1Zf@07o`000?l^L=ko
;W3Nobi`g_l0003oG7;@o`000007oeijeP05o`000?mQQ=koHHCNof64g_l000001?n6RLl00ol0003o
RY?FohZCeP07ohZCeP04o`000?n?X=ooSj3Oo`0000KoZJGC0_l00006ojncg0;o00000oneaNH00ol0
003oalcNolO<gP04olcNiP04o`000?o=l>_ocO3[o`0000;oa?cU00?oZoW?o`000?n6hZT02Oo=^lT2
o`0000_o_J>o0_l00004ok^O_003o`000?n^T[[o[Y:j00Oo[Y:j0ol00007ojb?^003o`000?nMQK[o
WHFj00CoWHFj0_l0000<oib3^003o`000?n;O;go000000_oRgZl0_l00005ohYj^`03o`000?miM/?o
NGK300;oNGK300?o0000ogYf`omjM/<01omjM/<00ol0003oNgO3og]g``05og]g``03o`000?m]N/oo
000000Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`001?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`?o0000??ooool01?l0003oJJCco`000?mRY_H2o`0000;o<7SS00Co0000obIhi?lVN>Co0000
0_lNNND2o`0000;o<6[I00?o0000obi`g_l^L=h00ol^L=h00ol0003oGW[FoeijeP05oeijeP03o`00
0?mQQ=koHHCN00?oHHCN00Co0000ohJ9col0003o00002?n:TmH2o`0000CoSj3O00?o0000ojVUdonY
YM<00_nYYM<00ol0003o[k?Lojncg004ojncg0;o00001OneaNH4o`0000;oc=kV0oo=l>/01?l0003o
a?cUolCliOn[nLl2o`0000OocK_90ol000000oo:]LGo0000okfS_`07okfS_`?o00001_nkWk`00ol0
003o[Y:jojjB^P04ojjB^P?o00002_n/SkP01?l0003oWHFjoif5^_nMQKX3o`0000koW8>h0_l0000:
oh]j_0;o00002?n:N[/01?l0003oNGK3ogUf`ol00009ogYf``03o`000?mkMl?oNgO300OoNgO300?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?oo
ooooooooooooo`?o0000@?ooool00ol0003oJJCco`000002of:VmP;o000000Co<7SSo`000?lVN>Co
00000_lNNND2oaIli@03o`000?l`J]Wo000000Go;W3N00?o;7WTo`000?mNN]H01?mNN]H00ol0003o
HHCNof64gP05of64gP;o00002?n:TmH00ol0003oSj3OohnPg`05ohnPg`03o`000?nYYM?oZJGC00Oo
[k?L00?o0000okG5i_neaNH01?neaNH01?l0003o^mW_ok_IkonkfNl3o`0000;ocO3[0oo4o>D2o`00
00KocK_90ol00004olZea@03o`000?nmXkoo_J>o00?o_J>o0ol0000:ok^O_004o`000?n^T[[o[Y:j
ojjB^P;o00003_n/SkP3o`0000koW8>h0ol000000onKP[Oo0000oh]j_008oh]j_003o`000?n:N[_o
RWZk00SoRWZk00?o0000ogUf`ol000002OmjM/<00ol0003oNgO3og]g``07og]g``03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`Co0000A?ooool00ol0003oJJCco`000003
of:VmP;o00000_lVN>@00ol0003o7WWUoaiii@02oaIli@;o00001Ol^L=h00ol0003o;7WTo`000003
oeijeP03o`000?mQQ=koHHCN00KoHHCN0_mTTNL00ol0003oRY?FohZCeP04ohZCeP03o`000?n?X=oo
Sj3O00KoSj3O0_l00006ojncg0;o00001OneaNH2o`0000?o^mW_00?o0000ok_]m?nkkO@01Ol00000
0omdfJKo0000olfkb@03olfkb@?o00001oo:]LD01?l0003o_J>ookfS_onmXkl2o`0000go^inl1?l0
000?ojb?^0;o00003_nLPkP2o`0000GoVh:g00?o0000oh]j_?n;N[`01?n;N[`2o`0000_oRWZk0_l0
0009ogYf``03o`000?mkMl?oNgO300OoNgO300?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Kooooo000Nooooo`;o0000Aoooool00ol0003oJJCco`000003
of:VmP04oe^Xn?l0003o0000o`0000;o7WWU00?o0000oaIliOlFO>D00_l00004obi`gP06o`000?l/
NNCo;7WTo`000?mNN]Ko00002?mQQ=h01Ol0003oI97WofBAiomTTNOo000000?oRY?F0_l00007ohnP
g`;o00000_nF/NX00ol0003o[k?Lojncg002ojncg003o`000?neaNKo]LGV00?o]LGV0_l00003ok_I
k`;o00000_nkkO@00ol0003o/OS/ok7hk002o`000004ogCIY_o=^lWocK_9olfkb@?o00002_o:]LD0
1?l0003o_J>oo`000?l0000=ok^O_0?o00003on/SkP3o`000003ojZ=]ol0003oW8>h00_oW8>h0_l0
0007oi^2]`03o`000?n;N[coRgZl00;oRgZl0_l0000<ohYj^`03o`000?n;N[_o000000SoNWK300?o
0000og]g`omkMl<01omkMl<00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01_ooool0023ooooo00?o0000ooooooooool0AOooool00ol0003oJJCco`000003
of:VmP;oFjSh00Wo9WSTo`000?lNNNGo7WWUo`000?lFO>Go0000oa21iOl000000_l^L=h00ol0003o
;7WTobaii002obaii0;o00001omQQ=h00ol0003oI97WofBAi`03ofBAi`03o`000?n:TmKoRY?F00So
Sj3O00?o0000oiJaj_nF/NX00onF/NX00ol0003o[k?Lojncg006okG5iP04o`000?nkfNoo^mW_ok_I
k`;o00000_nkkO@2o`0000;o/OS/0ol00002olfkb@;o00002oo:]LD3o`0000go^inl0ol00002okRK
^P03o`000?n/SkSo[8nh00[o[8nh0ol00005ojZ=]`03o`000?nLPkSoW8>h00KoW8>h0ol00009oi^2
]`05o`000?n;N[coRgZloh]j_?l000003?n:N[/2o`0000?oRgZk00?o0000ogYf`omjM/<01?mjM/<0
0ol0003oNgO3og]g``07og]g``03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`15ooooo`03o`000?mYY??o0000
00?oHZKf0_mKZ?P01?l0003o7WWUoaiiiOl00002oaIli@05o`000?l@PNGo0000obi`g_l000001?l/
NN@2ob^3jP03o`000?mQQ=koHHCN00?oHHCN00?o0000ofBAiomTTNL01?mTTNL3o`0000KoSj3O0_l0
0006oiJajP?o00001OneaNH01Ol0003o^mW_ok_IkonkfNoo000000?o^ngd00Co0000ok7hk?nan>co
/OS/1Ol0000:olZea@Co00000_o7[l<00ol0003o^inlok^O_008ok^O_0?o00001OnhVkX00ol0003o
[8nhojb?^007ojb?^0?o00002?nZSKL00ol0003oW8>hoib3^004oib3^0;o00003OnKP[L3o`0000co
RWZk00?o0000oh]j^on;N[/01?n;N[/00ol0003oNWK3ogYf``02ogYf``03o`000?mkMl?oNgO300Oo
NgO300?o0000ooooooooool04_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Go
oooo000Rooooo`03o`000?oooooooooo04Cooooo00Co0000ofVTlomYY??o00000omRY_H01_l0003o
FjSho`000?l0003o7WWUo`0000;o5WcU00Co0000oa21iOl0003o00001?l/NN@01?l0003o:h?Zob^3
j_l00003of64gP03o`000?mTTNOoI97W00CoI97W00Go0000ofRQlOmXXO7oJ:7ao`000003ohnPg`;o
00001onF/NX01?l0003oVlGeoi_5mOnKaOD2o`0000;o]LGV1?nkfNl01Ol0003o^ngdok_]m?nkkOCo
000000?o/OS/0_l00002om?<d`03o`000?o:]LGob[G500Gob[G51?l00006olN_``03o`000?nkWkco
^inl00Go^inl0ol00008okRK^P03o`000?n/SkSo[8nh00Go[8nh0_l0000;ojZ=]`03o`000?nLPkSo
W8>h00;oW8>h0_l0000>oi^2]`;o00003?n:N[/2o`0000OoRgZk00Go0000ogYf`omjM/?oNWK3o`00
0009og]g``03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`05ooooo`008oooool2o`0004Gooooo00Co0000ofVTlomYY??o00000omRY_H00ol0003oFjSho`00
0002o`0000?o5WcU00Co0000oa21iOl0003o00000_l/NN@00ol0003o:h?Zob^3jP02ob^3jP03o`00
0?mQQ=ko000000KoI97W00?o0000ofRQlOmXXO400omXXO400ol0003oSj3Oo`000007oiJajP;o0000
1OnKaOD4o`0000;o^mW_1?nkkO@4ok7hk003o`000?oCc=?odlcC00;odlcC00?o0000olZeaOo:]LD0
0_o:]LD3o`0000[oajo300?o0000ok^O_?nkWk`00_nkWk`3o`0000co^9^j00Co0000ojb?^?n/SkSo
[8nh0ol0000>ojZ=]`Co00003_nKP[L2o`000003oiZ1]ol0003oRWZk00WoRWZk0_l0000:oh]j^`03
o`000?mjM/?o000000WoNgO300?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo000Uooooo`03o`000?oooooooooo04?ooooo00Co0000ofVTlomYY??o
00000omRY_H00ol0003oFjSho`000003o`000004oaIliOl0003o487Uoa21i@Co00001Ol[PnX2o`00
00GoI97W00?o0000ofRQlOmXXO401?mXXO43o`0000KoU[7Z00?o0000oi_5mOnKaOD00onKaOD2o`00
00?oW][l2_l00005om?<d`03o`000?o:]LGob[G500?o00003Oo7[l<00ol0003o^inlo`000002o`00
00oo^9^j1?l0000@ojZ=]`;o00003onKP[L2o`0000CoVX6g00?o0000ohYj^on:N[/01_n:N[/00ol0
003oRgZkoh]j^`0:oh]j^`;o00002OmkMl<00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o0000ooooooooool0@oooool01?l0003o
JJCcofVTlol00003of:VmP04o`000?mKZ?So0000oe>[n@Co00000_l@PND01?l0003o2XKRo`000?l0
0004ob^3jP;o:Y3^00Go0000ofBAiomTTNOoI97Wo`000006ofRQl@05o`000?m[/o[oJk?jof^cn_l0
00000onF/NX2o`0000CoVlGe0_l00004oikJo003o`000?nJj_WoV^[i00;o000000CoRngUo`000?l0
003o00001?oCc=<5o`0000ooajo31?l0000@okRK^P?o00004?nZSKL3o`000003ojR;]_l0003oVh:g
00coVh:g0_l00006oiZ1]`03o`000?n:N[_oRWZk00CoRWZk0_l0000<oh]j^`03o`000?n;Nk_o0000
00SoNgO300?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Co0000ofVTlomYY??o00000omRY_H00ol0
003oFjSho`000002oe>[n@Ko000000Co2XKRo`000?l0003o00000_l[PnX01_l0003o:Y3^obZ@k_l0
003oI97Wo`0000KoJ:7a00?o0000of^cn_m[/oX00om[/oX00ol0003oU[7ZoiJajP05oi_5m@03o`00
0?nNf_coW][l00;oW][l0_l00002oi[Zn@03o`000?n;kNGoRngU00So00000oo@aM000ol0003oajo3
olN_``09olN_``Go00000_o4Zl400ol0003o^9^jokRK^P0;okRK^PCo00000_ngVKT00ol0003oZXfg
ojZ=]`0;ojZ=]`?o00001?nXRkH00ol0003oVh:goi^2]`08oi^2]`?o00002OnJPKL00ol0003oRWZk
ohYj^`02ohYj^`03o`000?n;N[_oRgZk00[oRgZk0_l00003oh]k^`03o`000?mkMl?oNgO300CoNgO3
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo
000Xooooo`;o0000A?ooool01?l0003oJJCcofVTlol00003of:VmP03o`000?mKZ?So000000;oDj_i
0_l000000om<[oWo0000o`000003o`000003o`J<g?l[Pn[o000000Co:Y3^0_l00005ofRQl@03o`00
0?m[/o[oJk?j00CoJk?j1?l00003oi_5m@03o`000?nNf_coW][l00;oW][l00Co0000oi[ZnOnJj_Wo
V^[i1_l00009om35d003o`000?o7[l?oajo300Coajo31Ol00007olB[`@03o`000?nhVk[o^9^j00Ko
^9^j1Ol00006okNI^@03o`000?nZSKOoZXfg00SoZXfg0ol00008ojR;]P03o`000?nKP[OoVh:g00Go
Vh:g0_l0000<oiZ1]`03o`000?n:N[_oRWZk00;o00002on;N[/2o`0000KoRg^k00?o0000og]g`omk
Ml<00_mkMl<00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01?ooool002[ooooo00?o0000ooooooooool0@_ooool:o`0000?oDj_i00?o0000odb_nOm<[oT0
1?l000000ol6S=co0000o`000003obZ@kP03o`000?lYWNoo000000;o000000?oJ:7ao`000?m[/oX0
1?m[/oX2o`0000CoK<Kn1Ol00003oikJo0Go00003Oo@aM000ol0003oajo3olN_``05o`0000_oa:_1
00?o0000okRK^_nhVkX00onhVkX4o`0000_o]iVi00?o0000ojZ=]onZSKL01OnZSKL3o`0000_oZ8^f
00?o0000oi^2]onKP[L00onKP[L2o`0000koVX6g00?o0000ohYj^ol000003?n;N[/00ol0003oRg^k
oh]k^`06oh]k^`05o`000?mkMl?oNgO3og]g`ol000008?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Cooooo000[ooooo`03o`000?oooooooooo04?ooooo0onO_^l4oj34lP03oj7:
m_l0003o000000co000000?o:Y3^o`000?lYWNl01?lYWNl4o`0000;oJk?j00?o0000ofc6o_m/a_h0
0om/a_h00ol0003oJM?hofWCn003ofWCn0Oo00002Oo@aM08o`00013oa:_100?o0000okRK^_nhVkX0
0ol0000@okNI^@04o`000?nZSKOoZXfgojZ=]`?o00003_nXRkH01?l0003oVh:goi^2]onKP[L2o`00
013oVX6g0_l0000;oh]j^`;o00002_n;Nk/00ol0003oNgO3o`00000Rooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool01?ooool002cooooo00?o0000ooooooooool0@oooool01?l0003o
Wkk_oinnkonO_^l4oj34lP;o00001?nQdOT4oj7In`So00000_lYWNl01?l0003o::WXobRYj?lXZNP5
o`0000;oK<Kn00Co0000ofWCn?mYdoSoJM?h1ol00003om35d0Wo00001Oo<_ld00ol0003oa:_1olB[
`@0=olB[`@Go00005?ngVKT4o`0001;oZ8^f0ol0000?oiZ1]`?o000000?oVX6go`000?n;N[/02?n;
N[/2o`0000coRg^k0_l0000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?oo
ool002gooooo0_l00015ooooo`03o`000?nO_^ooWkk_00;o00000_nPa?85o`0000?oXM7i0_l00002
oj7In`Co000000?oX>7lo`000?l000001ol00002obJ_f0co000000Cod<G@o`000?l0003o00003_o<
_ld00ol0003oa:_1olB[`@06olB[`@Oo00000oo2Ykl00ol0003o]iViokNI^@0@okNI^@Co00004onX
RkH3o`0000ooVX6g0_l00005oiZ1]`03o`000?n;N[_oRgZk00GoRgZk00?o0000oh]k^on;Nk/02on;
Nk/00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?oo
ool002oooooo00?o0000ooooooooool0@oooool01?l0003oWkk_oinnkonO_^l2o`0000;oX<Cb0_l0
00000onQb_Ko0000o`000004oj7An@?o00000_nQfO/3o`0000;oX>7l00?o0000ol[Gi?o:en@00_o:
en@4o`0000Wob]OT00?o0000olbocOo<_ld03oo<_ld01?l0003oa:_1olB[`Oo4Zl46o`0000[o`ZNo
00?o0000okNI^OngVKT02ongVKT5o`0000?o]INh00?o0000ojR;]_nXRkH03_nXRkH3o`0000;oYhZf
00?o0000oiZ1]onJPKL02_nJPKL3o`0000OoVX6g00?o0000oh]j^on;N[/00on;N[/2o`0000coRg^k
0_l0000Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0033ooooo00?o
0000ooooooooool0@oooool2o`0000?oWkk_00Co0000oj34l_nPa?;oX<Cb0_l000000onQb_Ko0000
o`000005oj7An@?o00000_nQfO/2o`0000Cob]OT1Ol00008ol[Gi003o`000?o<_lgoc;o=00Koc;o=
3Ol0000Aol:W_`03o`000?ngVKWo]iVi00Go]iVi1_l00008okFG^003o`000?nXRkKoZ8^f00[oZ8^f
1?l00006ojN:]P03o`000?nJPKOoVX6g00OoVX6g0_l0000;oiZ1]`03o`000?n;N[_oRgZk00;o0000
3?n;Nk/2o`0002_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Ooo
ool2o`0004Gooooo00Co0000oinnkonO_^ooWkk_0_l00003oj34lP;o000000CoXL[fo`000?l0003o
00001OnQdOT2o`0000_oam3Q2?l000000oo<_lgo0000o`000006o`0000[obK[<00?o0000ol:W_oo2
Ykl04Oo2Ykl00ol0003o]iViokNI^@05o`0000ko]INh00?o0000ojR;]_nXRkH01onXRkH3o`0000[o
YhZf00?o0000oiZ1]onJPKL01?nJPKL3o`0000goVX6g00?o0000oh]j^ol000003On;Nk/00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool003?ooooo
00?o0000ooooooooool0@oooool2o`0000?oWkk_0_l00003oj34lP04o`000?nQb_KoXL[foj7:mP;o
000000?oXM7io`000?o4b]l01?o4b]l6o`0000[oam3Q00?o0000olVjc?o9^/`04Oo9^/`00ol0003o
`ZNool:W_`0<ol:W_`So00005?neUkP00ol0003oZ8^fojR;]P02ojR;]PCo00003OnWR[H00ol0003o
VX6goiZ1]`02oiZ1]`;o00004?nJPKL2o`0000coRg^k0_l0000_ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003oWkk_
oinnk`02oinnk`04o`000?nPa?;oX<Cboj34lP;o00000_nQb_H2o`0000coa<[O1_l00003olO@h@03
o`000?o9^/cobK[<017obK[<00?o0000ol:W_oo2Ykl00_o2Ykl;o`0000Go_jBn00?o0000okFG^?ne
UkP05?neUkP00ol0003oZ8^fo`000002o`0001;oYhZf1?l0000?oiZ1]`?o000000?oVH6ho`000?n;
Nk/02_n;Nk/00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool00oooool003Gooooo00?o0000ooooooooool0A?ooool00ol0003oWkk_oinnk`02oinnk`;o0000
0_nPa?83o`0000Co`LCM1Ol0000;olC:g`?o00000_o9^/`Co`000004ol:W_ol0003o0000o`00013o
_jBn00?o0000okFG^?neUkP04?neUkP6o`0001?oYhZf0ol0000@oiZ1]`;o00001OnIPKP00ol0003o
Rg^koh]k^`06oh]k^`;o0000=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo000fooooo`;o0000AOooool2o`0000?oWkk_0ol00004okfof`;o00001_o1a=d5o`0000Soa<[O
00?o0000olJfb_o6]/X04_o6]/X00ol0003o_jBnoknT_P0BoknT_P03o`000?neUkSo]INh00So]INh
2?l00004ok>E^003o`000?nWR[KoYhZf00koYhZf1?l00002ojJ9]P03o`000?nJPKOoVX6g00coVX6g
0_l00007oiV1^003o`000?n;Nk_oRg^k00GoRg^k00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00?ooooo000hooooo`03o`000?oooooooooo04Cooooo00?o
0000oinnkol000000onj^mX00ol0003o_KoKokfof`04okfof`?o00001oo1a=d5o`0000;oa<[O00?o
0000olJfb_o6]/X04oo6]/X00ol0003o_jBnoknT_P0BoknT_P04o`000?neUkSo]INhokFG^0Oo0000
3?ncUKP00ol0003oYhZfojN:]P0;ojN:]P?o00001_nVRKH00ol0003oVX6goiZ1]`09oiZ1]`?o0000
2_nIPKP00ol0003oRg^koh]k^`02oh]k^`;o0000>?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo00?o0000okZkf_nj^mX01Onj
^mX3o`0000Co_KoK1?l00008ol74g@;o00000oo6]/X3o`0000ooa[K:00?o0000oknT__noY;h03_no
Y;h9o`0001?o/iFh00?o0000ojN:]_nWR[H01onWR[H4o`0000[oYXVf00?o0000oiZ1]onJPKL01_nJ
PKL2o`0000goVH6h00?o0000oh]k^on;Nk/00_l0000kooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00oooool003[ooooo00?o0000ooooooooool0AOooool00ol0003o^[_JokZkfP06
okZkfP;o00001_nm_m/3o`0000Ko`LCM00?o0000olBbbOo4//T01?o4//T;o`0000Coa[K:00?o0000
oknT__noY;h00onoY;h;o`0000Go_J:n00?o0000ok>E^?ncUKP05OncUKP00ol0003oYhZfojN:]P02
ojN:]PCo00003_nVRKH00ol0003oVX6goiZ1]`04oiZ1]`;o00003onIPKP00ol0003oRg^ko`00000n
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool003_ooooo0_l00018oooo
o`;o00001_nj^mX3o`0000Ko_KoK0ol00002ol74g@03o`000?o4//Woa;;9013oa;;91Ol000000ono
Y;ko0000o`000002o`00013o_J:n00?o0000ok>E^?ncUKP05OncUKP00ol0003oYhZfo`000002o`00
01;oYXVf00Co0000oiZ1]onJPKOoVX6g0ol0000AoiV1^0;o0000?oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;ooooo000mooooo`03o`000?oooooooooo04Oooooo0ol00006okZk
fP;o00001onm_m/2o`0001Ooa;;900?o0000okfR__nmX[h04onmX[h00ol0003o/iFhok>E^00Aok>E
^0Ko00005_nVRKH3o`00017oVH6h0ol00012ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool003kooooo00?o0000ooooooooool0BOooool2o`0000Ko^[_J0ol00005okfof`03
o`000?o1/<Wo`K3900;o`K391ol0000;olBbb@03o`000?nmX[ko_J:n01Co_J:n00?o0000ok>E^?nc
UKP02OncUKP8o`0000Co/YBh00?o0000ojJ9]_nVRKH04onVRKH3o`00013oVH6h0ol00016ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003oooooo00?o0000ooooooooool0
B_ooool2o`0000Oo^[_J0ol000000onm_m_o0000ol6`b@0;ol6`b@Oo00001?o4//T00ol0003o_J:n
okfR_P0DokfR_P04o`000?ncUKSo/iFhok>E^0So00003?nbU;P00ol0003oYXVfojJ9]P0>ojJ9]PGo
00000_nVRKL00ol0003oVH6hoiV1^00;oiV1^0?o0000B_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo0010ooooo`;o0000C?ooool3o`0000Oo^[_J00?o0000ol6`bOo1/<T0
4_o1/<T4o`000003okfR__l0003o000001So00005?nbU;P00ol0003oYXVfojJ9]P09ojJ9]PGo0000
2?nVRKL00ol0003oVH6hoiV1^008oiV1^0;o0000COooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo0012ooooo`03o`000?oooooooooo04cooooo0_l00005okZkfP04o`000?nn
[/Wo_Zk9okj^b@Ko00003_o1/<T00ol0003o^j6nok^Q_P0Eok^Q_P03o`000?nbU;So/YBh01Ko/YBh
00?o0000ojJ9]_nVRKH01?nVRKH4o`0000goYXVg00?o0000oiV1^?nIPKP01OnIPKP3o`00053ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003ooooooooo
o`1=ooooo`?o000000?o^[_Jo`000?nn[/T02Onn[/T5o`0000Wo`K3900?o0000ok^Q__nkXKh05Onk
XKh00ol0003o/YBhok:D^00Fok:D^003o`000?nVRKKo000000Co00004OnVRKL00ol0003oVH6hoiV1
^002oiV1^0?o0000E?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo0014
ooooo`03o`000?oooooooooo04oooooo00?o0000okj^bOnn[/T03_nn[/T6o`0000;o`K3900?o0000
ok^Q__nkXKh05_nkXKh00ol0003o/YBhok:D^00@ok:D^0So00005onVRKL4o`0005Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2o`0005;ooooo1Ol0000?okj^
b@?o00000_nkXKh;o`0000_o^j6n00?o0000ok:D^?nbU;P00onbU;P=o`0000Ko/IBi00?o0000ojJ9
]onVRKL05?nVRKL3o`0005_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01oooo
o`00Aoooool00ol0003oooooooooo`1Dooooo`Go00003?nn[/T00ol0003o^InnokVO_P0;okVO_Q7o
00004onaU;T00ol0003oYXVgojJ9]`0?ojJ9]`Go0000Goooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo05Sooooo1Ol00007okj^b@03o`00
0?niWkko^Inn01Ko^Inn00?o0000ok6D^OnaU;T05_naU;T00ol0003oYXVgojJ9]`0:ojJ9]`Go0000
IOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0019ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool00_ooool5o`000003okj^bOl0003o^Inn01So^Inn00?o
0000ok6D^OnaU;T05onaU;T00ol0003oYXVgojJ9]`04ojJ9]`Go0000Joooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000Eoooool00ol0003oooooooooo`07
ooooo`;o00000oniWkh00ol0003o^InnokVO_P0CokVO_P03o`000?naU;Wo/IBi01Oo/IBi00?o0000
ojJ9]ol000001?l0001`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
04cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`Wo00003?niWkh00ol0
003o/IBiok6D^@0Aok6D^@So0000M_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1oooo
o`00COooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Kooooo2Ol00003okVO_P03
o`000?naU;Wo/IBi00Co/IBi3Ol0001oooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo001>ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool07oooool:o`0008cooooo
00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004oooooo0_l0001Booooo`03o`000?oo
oooooooo0;Kooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0057ooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo001Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0^?ooool00ol0
003oooooooooo`04ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000oooooooo
ool0^?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00EOooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool01?ooool1o`00007ooooo
001Fooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0^_ooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool005Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`2k
ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F?ooool2o`0004Wooooo00?o0000oooo
ooooool0^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005[ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`2looooo`05o`000?ooooooooooooooool000000Oooool005_o
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2mooooo`04o`000?ooooooooooo`00
007ooooo001Looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0__ooool00ol0003o
ooooo`000001ooooo`00GOooool2o`0004Cooooo00?o0000ooooooooool0__ooool00ol0003ooooo
ooooo`01o`000000Goooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;oooooo0Ol0
0001ooooo`7o0000001Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0`?ooool2
o`000000HOooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;oooooo0ol0000006;o
oooo0_l0000oooooo`03o`000?oooooooooo0;_ooooo1?l00003ooooo`00I?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo0;Oooooo1?l00007ooooo`00IOooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo0;?ooooo1?l0000;ooooo`00I_ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo0;3ooooo0ol0000?ooooo`00Ioooool2o`0003[ooooo00?o0000oooo
ooooool0[?ooool4o`0001;ooooo001Yooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0Z?ooool4o`0001Kooooo001Zooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
Y?ooool4o`0001[ooooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0XOoo
ool4o`0001kooooo001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Mooooo`Co00008_ooool0
06kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Iooooo`Co00009_ooool006oo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Eooooo`Co0000:_ooool0073ooooo
0_l0000`ooooo`03o`000?oooooooooo097ooooo1?l0000^ooooo`00L_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo08kooooo0ol0000booooo`00Loooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo08[ooooo1?l0000eooooo`00M?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo08Kooooo1?l0000iooooo`00MOooool2o`0002_ooooo00?o0000oooooooo
ool0P_ooool4o`0003gooooo001gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
O_ooool4o`00047ooooo001hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0N_oo
ool4o`0004Gooooo001iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0M_ooool4
o`0004Wooooo001jooooo`;o00009_ooool00ol0003oooooooooo`1booooo`Co0000COooool007co
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1_ooooo`?o0000DOooool007gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000E?ooool007kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000F?ooool007oooooo0_l0000Q
ooooo`03o`000?oooooooooo06?ooooo1?l0001Looooo`00POooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo05oooooo1?l0001Pooooo`00P_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05_ooooo1?l0001Tooooo`00Poooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo05Oooooo1?l0001Xooooo`00Q?ooool2o`0001cooooo00?o0000ooooooooool0Dooo
ool4o`0006cooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool4
o`00073ooooo0027ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool3o`00
07Cooooo0028ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007Oo
oooo0029ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000Noooool008_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Ooooool008cooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0looooo`Co0000Poooool008gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0hooooo`Co0000Qoooool008kooooo0_l0000Booooo`03
o`000?oooooooooo03Cooooo1?l0002;ooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo037ooooo1?l0002?ooooo`00TOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02kooooo0ol0002Cooooo`00T_ooool2o`0000gooooo00?o0000ooooooooool0:_ooool4
o`0009Kooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool4o`00
09[ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0009ko
oooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:;ooooo
002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Y_ooool009Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003ooooo`03o`00
0?oooooooooo00_ooooo0ol0002fooooo`00W_ooool01?l0003oooooooooool00009ooooo`Co0000
^Oooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o000000?ooooo
o`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03003 .28261 -24 -2.73565 ]
[.03003 .28261 0 6.26435 ]
[.02107 .33874 -30 -2.78353 ]
[.02107 .33874 0 6.21647 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00213 .45746 -24 -2.88536 ]
[.00213 .45746 0 6.11464 ]
[-0.0079 .5203 -18 -2.93958 ]
[-0.0079 .5203 0 6.06042 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04225 .27781 m
.04836 .27542 L
s
[(-0.5)] .03003 .28261 1 -0.39208 Mshowa
.03334 .33406 m
.03947 .33172 L
s
[(-0.25)] .02107 .33874 1 -0.38144 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01448 .45303 m
.02066 .45081 L
s
[(0.25)] .00213 .45746 1 -0.35881 Mshowa
.00451 .516 m
.01071 .51384 L
s
[(0.5)] -0.0079 .5203 1 -0.34676 Mshowa
.125 Mabswid
.04049 .2889 m
.04416 .28747 L
s
.03872 .30007 m
.0424 .29864 L
s
.03694 .31131 m
.04062 .3099 L
s
.03515 .32265 m
.03882 .32124 L
s
.03151 .34556 m
.0352 .34416 L
s
.02968 .35715 m
.03336 .35576 L
s
.02783 .36882 m
.03152 .36744 L
s
.02597 .38058 m
.02966 .3792 L
s
.0222 .40436 m
.02589 .403 L
s
.02029 .41639 m
.02399 .41504 L
s
.01837 .42851 m
.02207 .42716 L
s
.01643 .44072 m
.02014 .43938 L
s
.01252 .46543 m
.01623 .4641 L
s
.01054 .47792 m
.01425 .47661 L
s
.00854 .49051 m
.01226 .48921 L
s
.00653 .50321 m
.01025 .50191 L
s
.04399 .26681 m
.04766 .26536 L
s
.04573 .25588 m
.04939 .25443 L
s
.00246 .52889 m
.00619 .5276 L
s
.0004 .54188 m
.00413 .5406 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .63912 m .51694 .65827 L .43899 .65168 L p .729 .607 .721 r
F P
0 g
s
.51694 .65827 m .51727 .63912 L .59235 .63348 L p .691 .568 .711 r
F P
0 g
s
.59235 .63348 m .59527 .65394 L .51694 .65827 L p .691 .568 .711 r
F P
0 g
s
.43899 .65168 m .44249 .63501 L .51727 .63912 L p .729 .607 .721 r
F P
0 g
s
.51761 .61969 m .51727 .63912 L .44249 .63501 L p .734 .61 .719 r
F P
0 g
s
.51727 .63912 m .51761 .61969 L .58943 .61274 L p .694 .568 .708 r
F P
0 g
s
.58943 .61274 m .59235 .63348 L .51727 .63912 L p .694 .568 .708 r
F P
0 g
s
.44249 .63501 m .446 .61809 L .51761 .61969 L p .734 .61 .719 r
F P
0 g
s
.51795 .60025 m .51761 .61969 L .446 .61809 L p .739 .613 .719 r
F P
0 g
s
.51761 .61969 m .51795 .60025 L .5865 .592 L p .697 .57 .708 r
F P
0 g
s
.5865 .592 m .58943 .61274 L .51761 .61969 L p .697 .57 .708 r
F P
0 g
s
.446 .61809 m .44952 .60115 L .51795 .60025 L p .739 .613 .719 r
F P
0 g
s
.51828 .58106 m .51795 .60025 L .44952 .60115 L p .744 .619 .721 r
F P
0 g
s
.51795 .60025 m .51828 .58106 L .58358 .57157 L p .7 .574 .71 r
F P
0 g
s
.58358 .57157 m .5865 .592 L .51795 .60025 L p .7 .574 .71 r
F P
0 g
s
.44952 .60115 m .45304 .58439 L .51828 .58106 L p .744 .619 .721 r
F P
0 g
s
.51862 .56238 m .51828 .58106 L .45304 .58439 L p .749 .628 .725 r
F P
0 g
s
.51828 .58106 m .51862 .56238 L .58068 .55173 L p .704 .58 .713 r
F P
0 g
s
.58068 .55173 m .58358 .57157 L .51828 .58106 L p .704 .58 .713 r
F P
0 g
s
.59527 .65394 m .59235 .63348 L .66412 .6183 L p .649 .535 .711 r
F P
0 g
s
.66412 .6183 m .67023 .63881 L .59527 .65394 L p .649 .535 .711 r
F P
0 g
s
.58943 .61274 m .5865 .592 L .65189 .57678 L p .65 .534 .709 r
F P
0 g
s
.5865 .592 m .58358 .57157 L .64579 .55637 L p .652 .537 .711 r
F P
0 g
s
.64579 .55637 m .65189 .57678 L .5865 .592 L p .652 .537 .711 r
F P
0 g
s
.59235 .63348 m .58943 .61274 L .658 .59752 L p .649 .533 .709 r
F P
0 g
s
.65189 .57678 m .658 .59752 L .58943 .61274 L p .65 .534 .709 r
F P
0 g
s
.658 .59752 m .66412 .6183 L .59235 .63348 L p .649 .533 .709 r
F P
0 g
s
.58358 .57157 m .58068 .55173 L .63973 .5366 L p .654 .542 .715 r
F P
0 g
s
.63973 .5366 m .64579 .55637 L .58358 .57157 L p .654 .542 .715 r
F P
0 g
s
.45304 .58439 m .45656 .56804 L .51862 .56238 L p .749 .628 .725 r
F P
0 g
s
.51896 .54446 m .51862 .56238 L .45656 .56804 L p .756 .638 .731 r
F P
0 g
s
.51862 .56238 m .51896 .54446 L .57778 .53275 L p .708 .588 .719 r
F P
0 g
s
.57778 .53275 m .58068 .55173 L .51862 .56238 L p .708 .588 .719 r
F P
0 g
s
.58068 .55173 m .57778 .53275 L .6337 .51775 L p .657 .549 .721 r
F P
0 g
s
.6337 .51775 m .63973 .5366 L .58068 .55173 L p .657 .549 .721 r
F P
0 g
s
.5749 .51489 m .57778 .53275 L .51896 .54446 L p .714 .6 .727 r
F P
0 g
s
.57778 .53275 m .5749 .51489 L .6277 .50006 L p .661 .559 .729 r
F P
0 g
s
.6277 .50006 m .6337 .51775 L .57778 .53275 L p .661 .559 .729 r
F P
0 g
s
.45656 .56804 m .46007 .55229 L .51896 .54446 L p .756 .638 .731 r
F P
0 g
s
.51929 .52752 m .51896 .54446 L .46007 .55229 L p .763 .652 .74 r
F P
0 g
s
.51896 .54446 m .51929 .52752 L .5749 .51489 L p .714 .6 .727 r
F P
0 g
s
.44249 .63501 m .43899 .65168 L .36521 .63435 L p .761 .655 .745 r
F P
0 g
s
.57203 .49836 m .5749 .51489 L .51929 .52752 L p .721 .615 .739 r
F P
0 g
s
.5749 .51489 m .57203 .49836 L .62174 .48379 L p .666 .573 .741 r
F P
0 g
s
.62174 .48379 m .6277 .50006 L .5749 .51489 L p .666 .573 .741 r
F P
0 g
s
.36521 .63435 m .37164 .62121 L .44249 .63501 L p .761 .655 .745 r
F P
0 g
s
.446 .61809 m .44249 .63501 L .37164 .62121 L p .767 .66 .744 r
F P
0 g
s
.46007 .55229 m .46358 .53734 L .51929 .52752 L p .763 .652 .74 r
F P
0 g
s
.51962 .51177 m .51929 .52752 L .46358 .53734 L p .771 .67 .752 r
F P
0 g
s
.51929 .52752 m .51962 .51177 L .57203 .49836 L p .721 .615 .739 r
F P
0 g
s
.56917 .48337 m .57203 .49836 L .51962 .51177 L p .728 .634 .754 r
F P
0 g
s
.57203 .49836 m .56917 .48337 L .61582 .46912 L p .672 .592 .757 r
F P
0 g
s
.61582 .46912 m .62174 .48379 L .57203 .49836 L p .672 .592 .757 r
F P
0 g
s
.37164 .62121 m .37809 .60789 L .446 .61809 L p .767 .66 .744 r
F P
0 g
s
.44952 .60115 m .446 .61809 L .37809 .60789 L p .774 .667 .745 r
F P
0 g
s
.46358 .53734 m .46708 .52336 L .51962 .51177 L p .771 .67 .752 r
F P
0 g
s
.51996 .49739 m .51962 .51177 L .46708 .52336 L p .781 .693 .767 r
F P
0 g
s
.51962 .51177 m .51996 .49739 L .56917 .48337 L p .728 .634 .754 r
F P
0 g
s
.37809 .60789 m .38456 .59453 L .44952 .60115 L p .774 .667 .745 r
F P
0 g
s
.45304 .58439 m .44952 .60115 L .38456 .59453 L p .781 .676 .748 r
F P
0 g
s
.56633 .4701 m .56917 .48337 L .51996 .49739 L p .738 .66 .774 r
F P
0 g
s
.56917 .48337 m .56633 .4701 L .60993 .45625 L p .679 .617 .779 r
F P
0 g
s
.60993 .45625 m .61582 .46912 L .56917 .48337 L p .679 .617 .779 r
F P
0 g
s
.38456 .59453 m .39105 .58129 L .45304 .58439 L p .781 .676 .748 r
F P
0 g
s
.45656 .56804 m .45304 .58439 L .39105 .58129 L p .789 .688 .753 r
F P
0 g
s
.46708 .52336 m .47058 .5105 L .51996 .49739 L p .781 .693 .767 r
F P
0 g
s
.52029 .48455 m .51996 .49739 L .47058 .5105 L p .791 .722 .788 r
F P
0 g
s
.51996 .49739 m .52029 .48455 L .56633 .4701 L p .738 .66 .774 r
F P
0 g
s
.39105 .58129 m .39754 .56833 L .45656 .56804 L p .789 .688 .753 r
F P
0 g
s
.46007 .55229 m .45656 .56804 L .39754 .56833 L p .797 .702 .76 r
F P
0 g
s
.5635 .45867 m .56633 .4701 L .52029 .48455 L p .749 .694 .799 r
F P
0 g
s
.56633 .4701 m .5635 .45867 L .60407 .44531 L p .688 .65 .807 r
F P
0 g
s
.60407 .44531 m .60993 .45625 L .56633 .4701 L p .688 .65 .807 r
F P
0 g
s
.63973 .5366 m .6337 .51775 L .68389 .50012 L p .6 .519 .736 r
F P
0 g
s
.6337 .51775 m .6277 .50006 L .67504 .48374 L p .601 .53 .746 r
F P
0 g
s
.67504 .48374 m .68389 .50012 L .6337 .51775 L p .601 .53 .746 r
F P
0 g
s
.64579 .55637 m .63973 .5366 L .6928 .51765 L p .599 .513 .728 r
F P
0 g
s
.68389 .50012 m .6928 .51765 L .63973 .5366 L p .6 .519 .736 r
F P
0 g
s
.65189 .57678 m .64579 .55637 L .70177 .53609 L p .599 .508 .724 r
F P
0 g
s
.6928 .51765 m .70177 .53609 L .64579 .55637 L p .599 .513 .728 r
F P
0 g
s
.6277 .50006 m .62174 .48379 L .66626 .46876 L p .604 .544 .76 r
F P
0 g
s
.66626 .46876 m .67504 .48374 L .6277 .50006 L p .604 .544 .76 r
F P
0 g
s
.658 .59752 m .65189 .57678 L .71079 .55517 L p .599 .507 .721 r
F P
0 g
s
.70177 .53609 m .71079 .55517 L .65189 .57678 L p .599 .508 .724 r
F P
0 g
s
.62174 .48379 m .61582 .46912 L .65753 .45536 L p .607 .563 .779 r
F P
0 g
s
.65753 .45536 m .66626 .46876 L .62174 .48379 L p .607 .563 .779 r
F P
0 g
s
.39754 .56833 m .40404 .55578 L .46007 .55229 L p .797 .702 .76 r
F P
0 g
s
.46358 .53734 m .46007 .55229 L .40404 .55578 L p .806 .721 .771 r
F P
0 g
s
.66412 .6183 m .658 .59752 L .71984 .5746 L p .6 .507 .721 r
F P
0 g
s
.71079 .55517 m .71984 .5746 L .658 .59752 L p .599 .507 .721 r
F P
0 g
s
.47058 .5105 m .47407 .4989 L .52029 .48455 L p .791 .722 .788 r
F P
0 g
s
.52062 .47337 m .52029 .48455 L .47407 .4989 L p .803 .76 .813 r
F P
0 g
s
.52029 .48455 m .52062 .47337 L .5635 .45867 L p .749 .694 .799 r
F P
0 g
s
.67023 .63881 m .66412 .6183 L .72892 .59408 L p .602 .51 .722 r
F P
0 g
s
.71984 .5746 m .72892 .59408 L .66412 .6183 L p .6 .507 .721 r
F P
0 g
s
.72892 .59408 m .73799 .61332 L .67023 .63881 L p .602 .51 .722 r
F P
0 g
s
.61582 .46912 m .60993 .45625 L .64886 .44372 L p .611 .59 .804 r
F P
0 g
s
.64886 .44372 m .65753 .45536 L .61582 .46912 L p .611 .59 .804 r
F P
0 g
s
.56067 .44922 m .5635 .45867 L .52062 .47337 L p .761 .739 .833 r
F P
0 g
s
.5635 .45867 m .56067 .44922 L .59823 .43642 L p .697 .694 .843 r
F P
0 g
s
.59823 .43642 m .60407 .44531 L .5635 .45867 L p .697 .694 .843 r
F P
0 g
s
.40404 .55578 m .41054 .5438 L .46358 .53734 L p .806 .721 .771 r
F P
0 g
s
.46708 .52336 m .46358 .53734 L .41054 .5438 L p .816 .744 .784 r
F P
0 g
s
.60993 .45625 m .60407 .44531 L .64024 .43397 L p .616 .625 .837 r
F P
0 g
s
.64024 .43397 m .64886 .44372 L .60993 .45625 L p .616 .625 .837 r
F P
0 g
s
.41054 .5438 m .41704 .5325 L .46708 .52336 L p .816 .744 .784 r
F P
0 g
s
.47058 .5105 m .46708 .52336 L .41704 .5325 L p .826 .773 .802 r
F P
0 g
s
.47407 .4989 m .47757 .48866 L .52062 .47337 L p .803 .76 .813 r
F P
0 g
s
.52095 .46395 m .52062 .47337 L .47757 .48866 L p .815 .809 .846 r
F P
0 g
s
.52062 .47337 m .52095 .46395 L .56067 .44922 L p .761 .739 .833 r
F P
0 g
s
.37164 .62121 m .36521 .63435 L .29943 .6068 L p .776 .708 .788 r
F P
0 g
s
.55785 .4418 m .56067 .44922 L .52095 .46395 L p .771 .798 .875 r
F P
0 g
s
.56067 .44922 m .55785 .4418 L .59239 .42965 L p .705 .753 .89 r
F P
0 g
s
.59239 .42965 m .59823 .43642 L .56067 .44922 L p .705 .753 .89 r
F P
0 g
s
.29943 .6068 m .30842 .5981 L .37164 .62121 L p .776 .708 .788 r
F P
0 g
s
.37809 .60789 m .37164 .62121 L .30842 .5981 L p .785 .718 .789 r
F P
0 g
s
.60407 .44531 m .59823 .43642 L .63165 .42623 L p .619 .673 .879 r
F P
0 g
s
.63165 .42623 m .64024 .43397 L .60407 .44531 L p .619 .673 .879 r
F P
0 g
s
.41704 .5325 m .42354 .522 L .47058 .5105 L p .826 .773 .802 r
F P
0 g
s
.47407 .4989 m .47058 .5105 L .42354 .522 L p .837 .809 .823 r
F P
0 g
s
.30842 .5981 m .31746 .58929 L .37809 .60789 L p .785 .718 .789 r
F P
0 g
s
.38456 .59453 m .37809 .60789 L .31746 .58929 L p .795 .73 .792 r
F P
0 g
s
.47757 .48866 m .48106 .47987 L .52095 .46395 L p .815 .809 .846 r
F P
0 g
s
.52128 .45636 m .52095 .46395 L .48106 .47987 L p .82 .869 .882 r
F P
0 g
s
.52095 .46395 m .52128 .45636 L .55785 .4418 L p .771 .798 .875 r
F P
0 g
s
.31746 .58929 m .32652 .58046 L .38456 .59453 L p .795 .73 .792 r
F P
0 g
s
.39105 .58129 m .38456 .59453 L .32652 .58046 L p .804 .745 .798 r
F P
0 g
s
.59823 .43642 m .59239 .42965 L .62309 .42057 L p .617 .736 .931 r
F P
0 g
s
.62309 .42057 m .63165 .42623 L .59823 .43642 L p .617 .736 .931 r
F P
0 g
s
.42354 .522 m .43005 .5124 L .47407 .4989 L p .837 .809 .823 r
F P
0 g
s
.47757 .48866 m .47407 .4989 L .43005 .5124 L p .845 .853 .849 r
F P
0 g
s
.55502 .43645 m .55785 .4418 L .52128 .45636 L p .771 .871 .921 r
F P
0 g
s
.55785 .4418 m .55502 .43645 L .58655 .42504 L p .703 .829 .942 r
F P
0 g
s
.58655 .42504 m .59239 .42965 L .55785 .4418 L p .703 .829 .942 r
F P
0 g
s
.32652 .58046 m .33562 .57167 L .39105 .58129 L p .804 .745 .798 r
F P
0 g
s
.39754 .56833 m .39105 .58129 L .33562 .57167 L p .814 .763 .806 r
F P
0 g
s
.68389 .50012 m .67504 .48374 L .71428 .46671 L p .531 .515 .783 r
F P
0 g
s
.67504 .48374 m .66626 .46876 L .70309 .45403 L p .529 .531 .801 r
F P
0 g
s
.70309 .45403 m .71428 .46671 L .67504 .48374 L p .529 .531 .801 r
F P
0 g
s
.6928 .51765 m .68389 .50012 L .72556 .48067 L p .533 .503 .769 r
F P
0 g
s
.71428 .46671 m .72556 .48067 L .68389 .50012 L p .531 .515 .783 r
F P
0 g
s
.66626 .46876 m .65753 .45536 L .69199 .4428 L p .527 .553 .825 r
F P
0 g
s
.69199 .4428 m .70309 .45403 L .66626 .46876 L p .527 .553 .825 r
F P
0 g
s
.33562 .57167 m .34474 .56302 L .39754 .56833 L p .814 .763 .806 r
F P
0 g
s
.40404 .55578 m .39754 .56833 L .34474 .56302 L p .823 .785 .816 r
F P
0 g
s
.48106 .47987 m .48456 .47259 L .52128 .45636 L p .82 .869 .882 r
F P
0 g
s
.52161 .45063 m .52128 .45636 L .48456 .47259 L p .808 .936 .914 r
F P
0 g
s
.52128 .45636 m .52161 .45063 L .55502 .43645 L p .771 .871 .921 r
F P
0 g
s
.43005 .5124 m .43657 .50377 L .47757 .48866 L p .845 .853 .849 r
F P
0 g
s
.48106 .47987 m .47757 .48866 L .43657 .50377 L p .847 .904 .876 r
F P
0 g
s
.70177 .53609 m .6928 .51765 L .73692 .4957 L p .536 .496 .759 r
F P
0 g
s
.72556 .48067 m .73692 .4957 L .6928 .51765 L p .533 .503 .769 r
F P
0 g
s
.65753 .45536 m .64886 .44372 L .68096 .43319 L p .524 .583 .857 r
F P
0 g
s
.68096 .43319 m .69199 .4428 L .65753 .45536 L p .524 .583 .857 r
F P
0 g
s
.59239 .42965 m .58655 .42504 L .61453 .41703 L p .595 .81 .982 r
F P
0 g
s
.61453 .41703 m .62309 .42057 L .59239 .42965 L p .595 .81 .982 r
F P
0 g
s
.71079 .55517 m .70177 .53609 L .74836 .51156 L p .539 .492 .752 r
F P
0 g
s
.73692 .4957 m .74836 .51156 L .70177 .53609 L p .536 .496 .759 r
F P
0 g
s
.34474 .56302 m .35388 .55457 L .40404 .55578 L p .823 .785 .816 r
F P
0 g
s
.41054 .5438 m .40404 .55578 L .35388 .55457 L p .833 .811 .829 r
F P
0 g
s
.64886 .44372 m .64024 .43397 L .66999 .42531 L p .517 .624 .896 r
F P
0 g
s
.66999 .42531 m .68096 .43319 L .64886 .44372 L p .517 .624 .896 r
F P
0 g
s
.71984 .5746 m .71079 .55517 L .75986 .52802 L p .543 .491 .748 r
F P
0 g
s
.74836 .51156 m .75986 .52802 L .71079 .55517 L p .539 .492 .752 r
F P
0 g
s
.55218 .43319 m .55502 .43645 L .52161 .45063 L p .737 .943 .951 r
F P
0 g
s
.55502 .43645 m .55218 .43319 L .5807 .4226 L p .665 .905 .979 r
F P
0 g
s
.5807 .4226 m .58655 .42504 L .55502 .43645 L p .665 .905 .979 r
F P
0 g
s
.72892 .59408 m .71984 .5746 L .77143 .54481 L p .548 .493 .746 r
F P
0 g
s
.75986 .52802 m .77143 .54481 L .71984 .5746 L p .543 .491 .748 r
F P
0 g
s
.35388 .55457 m .36305 .54642 L .41054 .5438 L p .833 .811 .829 r
F P
0 g
s
.41704 .5325 m .41054 .5438 L .36305 .54642 L p .841 .842 .845 r
F P
0 g
s
.64024 .43397 m .63165 .42623 L .65908 .41927 L p .503 .676 .942 r
F P
0 g
s
.65908 .41927 m .66999 .42531 L .64024 .43397 L p .503 .676 .942 r
F P
0 g
s
.43657 .50377 m .4431 .49619 L .48106 .47987 L p .847 .904 .876 r
F P
0 g
s
.48456 .47259 m .48106 .47987 L .4431 .49619 L p .831 .957 .895 r
F P
0 g
s
.73799 .61332 m .72892 .59408 L .78303 .56166 L p .553 .497 .747 r
F P
0 g
s
.77143 .54481 m .78303 .56166 L .72892 .59408 L p .548 .493 .746 r
F P
0 g
s
.48456 .47259 m .48807 .46685 L .52161 .45063 L p .808 .936 .914 r
F P
0 g
s
.52194 .44678 m .52161 .45063 L .48807 .46685 L p .746 .981 .912 r
F P
0 g
s
.52161 .45063 m .52194 .44678 L .55218 .43319 L p .737 .943 .951 r
F P
0 g
s
.78303 .56166 m .79464 .57831 L .73799 .61332 L p .553 .497 .747 r
F P
0 g
s
.58655 .42504 m .5807 .4226 L .60596 .4156 L p .523 .866 .992 r
F P
0 g
s
.60596 .4156 m .61453 .41703 L .58655 .42504 L p .523 .866 .992 r
F P
0 g
s
.36305 .54642 m .37224 .53861 L .41704 .5325 L p .841 .842 .845 r
F P
0 g
s
.42354 .522 m .41704 .5325 L .37224 .53861 L p .847 .878 .863 r
F P
0 g
s
.63165 .42623 m .62309 .42057 L .6482 .41513 L p .471 .735 .985 r
F P
0 g
s
.6482 .41513 m .65908 .41927 L .63165 .42623 L p .471 .735 .985 r
F P
0 g
s
.54932 .43199 m .55218 .43319 L .52194 .44678 L p .617 .956 .902 r
F P
0 g
s
.55218 .43319 m .54932 .43199 L .57482 .4223 L p .542 .92 .929 r
F P
0 g
s
.57482 .4223 m .5807 .4226 L .55218 .43319 L p .542 .92 .929 r
F P
0 g
s
.4431 .49619 m .44965 .48968 L .48456 .47259 L p .831 .957 .895 r
F P
0 g
s
.48807 .46685 m .48456 .47259 L .44965 .48968 L p .774 .991 .887 r
F P
0 g
s
.37224 .53861 m .38145 .53122 L .42354 .522 L p .847 .878 .863 r
F P
0 g
s
.43005 .5124 m .42354 .522 L .38145 .53122 L p .846 .918 .881 r
F P
0 g
s
.30842 .5981 m .29943 .6068 L .24558 .56996 L p .754 .755 .853 r
F P
0 g
s
.62309 .42057 m .61453 .41703 L .63735 .41292 L p .399 .781 .991 r
F P
0 g
s
.63735 .41292 m .6482 .41513 L .62309 .42057 L p .399 .781 .991 r
F P
0 g
s
.5807 .4226 m .57482 .4223 L .59735 .41625 L p .362 .832 .879 r
F P
0 g
s
.59735 .41625 m .60596 .4156 L .5807 .4226 L p .362 .832 .879 r
F P
0 g
s
.48807 .46685 m .4916 .46265 L .52194 .44678 L p .746 .981 .912 r
F P
0 g
s
.52228 .44477 m .52194 .44678 L .4916 .46265 L p .59 .945 .82 r
F P
0 g
s
.52194 .44678 m .52228 .44477 L .54932 .43199 L p .617 .956 .902 r
F P
0 g
s
.38145 .53122 m .39068 .52429 L .43005 .5124 L p .846 .918 .881 r
F P
0 g
s
.43657 .50377 m .43005 .5124 L .39068 .52429 L p .833 .958 .893 r
F P
0 g
s
.24558 .56996 m .25665 .56641 L .30842 .5981 L p .754 .755 .853 r
F P
0 g
s
.31746 .58929 m .30842 .5981 L .25665 .56641 L p .763 .772 .86 r
F P
0 g
s
.44965 .48968 m .45622 .48428 L .48807 .46685 L p .774 .991 .887 r
F P
0 g
s
.4916 .46265 m .48807 .46685 L .45622 .48428 L p .646 .965 .816 r
F P
0 g
s
.25665 .56641 m .26777 .56285 L .31746 .58929 L p .763 .772 .86 r
F P
0 g
s
.32652 .58046 m .31746 .58929 L .26777 .56285 L p .773 .792 .869 r
F P
0 g
s
.61453 .41703 m .60596 .4156 L .62649 .41264 L p .267 .762 .899 r
F P
0 g
s
.62649 .41264 m .63735 .41292 L .61453 .41703 L p .267 .762 .899 r
F P
0 g
s
.39068 .52429 m .39994 .51788 L .43657 .50377 L p .833 .958 .893 r
F P
0 g
s
.4431 .49619 m .43657 .50377 L .39994 .51788 L p .794 .988 .889 r
F P
0 g
s
.54645 .43276 m .54932 .43199 L .52228 .44477 L p .388 .834 .717 r
F P
0 g
s
.54932 .43199 m .54645 .43276 L .5689 .42405 L p .316 .796 .728 r
F P
0 g
s
.5689 .42405 m .57482 .4223 L .54932 .43199 L p .316 .796 .728 r
F P
0 g
s
.26777 .56285 m .27894 .55928 L .32652 .58046 L p .773 .792 .869 r
F P
0 g
s
.33562 .57167 m .32652 .58046 L .27894 .55928 L p .781 .815 .88 r
F P
0 g
s
.57482 .4223 m .5689 .42405 L .5887 .41892 L p 0 0 0 r
F P
0 g
s
.5887 .41892 m .59735 .41625 L .57482 .4223 L p 0 0 0 r
F P
0 g
s
.27894 .55928 m .29016 .55569 L .33562 .57167 L p .781 .815 .88 r
F P
0 g
s
.34474 .56302 m .33562 .57167 L .29016 .55569 L p .788 .842 .892 r
F P
0 g
s
.4916 .46265 m .49515 .45996 L .52228 .44477 L p .59 .945 .82 r
F P
0 g
s
.52261 .44453 m .52228 .44477 L .49515 .45996 L p .353 .791 .623 r
F P
0 g
s
.52228 .44477 m .52261 .44453 L .54645 .43276 L p .388 .834 .717 r
F P
0 g
s
.71428 .46671 m .70309 .45403 L .72982 .44043 L p .435 .547 .87 r
F P
0 g
s
.70309 .45403 m .69199 .4428 L .71692 .43221 L p .419 .573 .9 r
F P
0 g
s
.71692 .43221 m .72982 .44043 L .70309 .45403 L p .419 .573 .9 r
F P
0 g
s
.69199 .4428 m .68096 .43319 L .70411 .42534 L p .396 .607 .933 r
F P
0 g
s
.70411 .42534 m .71692 .43221 L .69199 .4428 L p .396 .607 .933 r
F P
0 g
s
.72556 .48067 m .71428 .46671 L .74282 .44987 L p .448 .527 .846 r
F P
0 g
s
.72982 .44043 m .74282 .44987 L .71428 .46671 L p .435 .547 .87 r
F P
0 g
s
.39994 .51788 m .40923 .51201 L .4431 .49619 L p .794 .988 .889 r
F P
0 g
s
.44965 .48968 m .4431 .49619 L .40923 .51201 L p .712 .987 .85 r
F P
0 g
s
.6156 .41426 m .62649 .41264 L .60596 .4156 L p 0 0 0 r
F P
0 g
s
.60596 .4156 m .59735 .41625 L .6156 .41426 L p 0 0 0 r
F P
0 g
s
.68096 .43319 m .66999 .42531 L .69138 .41993 L p .36 .645 .964 r
F P
0 g
s
.69138 .41993 m .70411 .42534 L .68096 .43319 L p .36 .645 .964 r
F P
0 g
s
.45622 .48428 m .46271 .48005 L p .4916 .46265 L .646 .965 .816 r
F P
0 g
s
.46321 .47975 m .4916 .46265 L p .46271 .48005 L .646 .965 .816 r
F P
0 g
s
.49515 .45996 m .4916 .46265 L .46283 .47998 L p .446 .849 .663 r
F P
0 g
s
.49874 .45872 m .49581 .45973 L p .46948 .47676 L 0 0 0 r
F P
0 g
s
.49581 .45973 m .49515 .45996 L .49074 .46285 L p 0 0 0 r
F P
0 g
s
.49074 .46285 m .46948 .47676 L p .49581 .45973 L 0 0 0 r
F P
0 g
s
.46271 .48005 m .46283 .47998 L .46321 .47975 L p .646 .965 .816 r
F P
0 g
s
.73692 .4957 m .72556 .48067 L .75592 .46038 L p .459 .513 .827 r
F P
0 g
s
.74282 .44987 m .75592 .46038 L .72556 .48067 L p .448 .527 .846 r
F P
0 g
s
.29016 .55569 m .30143 .55208 L .34474 .56302 L p .788 .842 .892 r
F P
0 g
s
.35388 .55457 m .34474 .56302 L .30143 .55208 L p .792 .872 .906 r
F P
0 g
s
.66999 .42531 m .65908 .41927 L .67871 .41606 L p .301 .679 .975 r
F P
0 g
s
.67871 .41606 m .69138 .41993 L .66999 .42531 L p .301 .679 .975 r
F P
0 g
s
.74836 .51156 m .73692 .4957 L .76912 .47179 L p .469 .504 .812 r
F P
0 g
s
.75592 .46038 m .76912 .47179 L .73692 .4957 L p .459 .513 .827 r
F P
0 g
s
.75986 .52802 m .74836 .51156 L .7824 .4839 L p .478 .5 .802 r
F P
0 g
s
.76912 .47179 m .7824 .4839 L .74836 .51156 L p .469 .504 .812 r
F P
0 g
s
.65908 .41927 m .6482 .41513 L .6661 .41377 L p .21 .688 .935 r
F P
0 g
s
.6661 .41377 m .67871 .41606 L .65908 .41927 L p .21 .688 .935 r
F P
0 g
s
.30143 .55208 m .31274 .54846 L .35388 .55457 L p .792 .872 .906 r
F P
0 g
s
.36305 .54642 m .35388 .55457 L .31274 .54846 L p .792 .904 .92 r
F P
0 g
s
.54354 .43541 m .54645 .43276 L .52261 .44453 L p 0 0 0 r
F P
0 g
s
.54645 .43276 m .54354 .43541 L .56292 .42776 L p 0 0 0 r
F P
0 g
s
.56292 .42776 m .5689 .42405 L .54645 .43276 L p 0 0 0 r
F P
0 g
s
.45622 .48428 m .44965 .48968 L .41856 .50671 L p .575 .929 .757 r
F P
0 g
s
.40923 .51201 m .41856 .50671 L .43524 .49757 L p .712 .987 .85 r
F P
0 g
s
.4351 .49772 m .40923 .51201 L .43524 .49757 L .712 .987 .85 r
F
.41856 .50671 m .42793 .50198 L .45622 .48428 L p .575 .929 .757 r
F P
0 g
s
.46283 .47998 m .45622 .48428 L .43561 .49717 L p .398 .812 .614 r
F P
0 g
s
.43561 .49717 m .42793 .50198 L p .4357 .49708 L .398 .812 .614 r
F P
0 g
s
.46283 .47998 m .43561 .49717 L .4357 .49708 L .398 .812 .614 r
F
.43524 .49757 m .44965 .48968 L p .4351 .49772 L .712 .987 .85 r
F P
0 g
s
.77143 .54481 m .75986 .52802 L .79578 .49651 L p .488 .498 .794 r
F P
0 g
s
.7824 .4839 m .79578 .49651 L .75986 .52802 L p .478 .5 .802 r
F P
0 g
s
.31274 .54846 m .3241 .54482 L .36305 .54642 L p .792 .904 .92 r
F P
0 g
s
.37224 .53861 m .36305 .54642 L .3241 .54482 L p .783 .937 .93 r
F P
0 g
s
.59735 .41625 m .5887 .41892 L .60467 .41771 L p .049 0 0 r
F P
0 g
s
.60467 .41771 m .6156 .41426 L .59735 .41625 L p .049 0 0 r
F P
0 g
s
.6482 .41513 m .63735 .41292 L .65351 .41311 L p .091 .643 .813 r
F P
0 g
s
.65351 .41311 m .6661 .41377 L .6482 .41513 L p .091 .643 .813 r
F P
0 g
s
.5689 .42405 m .56292 .42776 L .57997 .42349 L p .028 0 0 r
F P
0 g
s
.57997 .42349 m .5887 .41892 L .5689 .42405 L p .028 0 0 r
F P
0 g
s
.78303 .56166 m .77143 .54481 L .80922 .5094 L p .498 .5 .79 r
F P
0 g
s
.79578 .49651 m .80922 .5094 L .77143 .54481 L p .488 .498 .794 r
F P
0 g
s
.49515 .45996 m .49874 .45872 L .52261 .44453 L p .353 .791 .623 r
F P
0 g
s
.52296 .44597 m .52261 .44453 L .49874 .45872 L p 0 0 0 r
F P
0 g
s
.52261 .44453 m .52296 .44597 L .54354 .43541 L p 0 0 0 r
F P
0 g
s
.46283 .47998 m .46948 .47676 L .49515 .45996 L p .446 .849 .663 r
F P
0 g
s
.3241 .54482 m .33552 .54116 L .37224 .53861 L p .783 .937 .93 r
F P
0 g
s
.38145 .53122 m .37224 .53861 L .33552 .54116 L p .76 .965 .931 r
F P
0 g
s
.79464 .57831 m .78303 .56166 L .82272 .52235 L p .509 .505 .788 r
F P
0 g
s
.80922 .5094 m .82272 .52235 L .78303 .56166 L p .498 .5 .79 r
F P
0 g
s
.63735 .41292 m .62649 .41264 L .64094 .41405 L p .03 0 0 r
F P
0 g
s
.64094 .41405 m .65351 .41311 L .63735 .41292 L p .03 0 0 r
F P
0 g
s
.82272 .52235 m .83625 .53514 L .79464 .57831 L p .509 .505 .788 r
F P
0 g
s
.33552 .54116 m .34698 .5375 L .38145 .53122 L p .76 .965 .931 r
F P
0 g
s
.39068 .52429 m .38145 .53122 L .34698 .5375 L p .713 .978 .913 r
F P
0 g
s
.54059 .4398 m .54354 .43541 L .52296 .44597 L p .042 0 0 r
F P
0 g
s
.54354 .43541 m .54059 .4398 L .55687 .43329 L p .078 0 0 r
F P
0 g
s
.55687 .43329 m .56292 .42776 L .54354 .43541 L p .078 0 0 r
F P
0 g
s
.5887 .41892 m .57997 .42349 L .59367 .42288 L p .149 0 0 r
F P
0 g
s
.59367 .42288 m .60467 .41771 L .5887 .41892 L p .149 0 0 r
F P
0 g
s
.62649 .41264 m .6156 .41426 L .62837 .41657 L p .126 0 0 r
F P
0 g
s
.62837 .41657 m .64094 .41405 L .62649 .41264 L p .126 0 0 r
F P
0 g
s
.42793 .50198 m .43734 .49783 L .46283 .47998 L p .398 .812 .614 r
F P
0 g
s
.46948 .47676 m .46283 .47998 L .43734 .49783 L p 0 0 0 r
F P
0 g
s
.46948 .47676 m .47618 .47457 L .49874 .45872 L p 0 0 0 r
F P
0 g
s
.50235 .45886 m .49874 .45872 L .47618 .47457 L p 0 0 0 r
F P
0 g
s
.49874 .45872 m .50235 .45886 L .52296 .44597 L p 0 0 0 r
F P
0 g
s
.34698 .5375 m .35849 .53381 L .39068 .52429 L p .713 .978 .913 r
F P
0 g
s
.39994 .51788 m .39068 .52429 L .35849 .53381 L p .634 .964 .865 r
F P
0 g
s
.56292 .42776 m .55687 .43329 L .57116 .42982 L p .144 0 0 r
F P
0 g
s
.57116 .42982 m .57997 .42349 L .56292 .42776 L p .144 0 0 r
F P
0 g
s
.5233 .44897 m .52296 .44597 L .50235 .45886 L p .047 0 0 r
F P
0 g
s
.52296 .44597 m .5233 .44897 L .54059 .4398 L p .042 0 0 r
F P
0 g
s
.25665 .56641 m .24558 .56996 L .20758 .52532 L p .656 .751 .92 r
F P
0 g
s
.35849 .53381 m .37005 .53011 L .39994 .51788 L p .634 .964 .865 r
F P
0 g
s
.40923 .51201 m .39994 .51788 L .37005 .53011 L p .52 .91 .777 r
F P
0 g
s
.6156 .41426 m .60467 .41771 L .61576 .42061 L p .192 0 0 r
F P
0 g
s
.61576 .42061 m .62837 .41657 L .6156 .41426 L p .192 0 0 r
F P
0 g
s
.20758 .52532 m .22012 .5274 L .25665 .56641 L p .656 .751 .92 r
F P
0 g
s
.26777 .56285 m .25665 .56641 L .22012 .5274 L p .654 .771 .935 r
F P
0 g
s
.43734 .49783 m .4468 .49423 L .46948 .47676 L p 0 0 0 r
F P
0 g
s
.47618 .47457 m .46948 .47676 L .4468 .49423 L p 0 0 0 r
F P
0 g
s
.57997 .42349 m .57116 .42982 L .58258 .42964 L p .212 0 0 r
F P
0 g
s
.58258 .42964 m .59367 .42288 L .57997 .42349 L p .212 0 0 r
F P
0 g
s
.37005 .53011 m .38167 .52639 L .40923 .51201 L p .52 .91 .777 r
F P
0 g
s
.41856 .50671 m .40923 .51201 L .38167 .52639 L p .381 .815 .656 r
F P
0 g
s
.22012 .5274 m .23272 .52957 L .26777 .56285 L p .654 .771 .935 r
F P
0 g
s
.27894 .55928 m .26777 .56285 L .23272 .52957 L p .651 .794 .951 r
F P
0 g
s
.47618 .47457 m .48293 .47336 L .50235 .45886 L p 0 0 0 r
F P
0 g
s
.50601 .46026 m .50235 .45886 L .48293 .47336 L p .087 0 0 r
F P
0 g
s
.50235 .45886 m .50601 .46026 L .5233 .44897 L p .047 0 0 r
F P
0 g
s
.53761 .44576 m .54059 .4398 L .5233 .44897 L p .157 0 0 r
F P
0 g
s
.54059 .4398 m .53761 .44576 L .55073 .44044 L p .179 0 0 r
F P
0 g
s
.55073 .44044 m .55687 .43329 L .54059 .4398 L p .179 0 0 r
F P
0 g
s
.23272 .52957 m .24537 .53174 L .27894 .55928 L p .651 .794 .951 r
F P
0 g
s
.29016 .55569 m .27894 .55928 L .24537 .53174 L p .644 .82 .968 r
F P
0 g
s
.55687 .43329 m .55073 .44044 L .56223 .43773 L p .214 0 0 r
F P
0 g
s
.56223 .43773 m .57116 .42982 L .55687 .43329 L p .214 0 0 r
F P
0 g
s
.60467 .41771 m .59367 .42288 L .6031 .42607 L p .234 0 0 r
F P
0 g
s
.6031 .42607 m .61576 .42061 L .60467 .41771 L p .234 0 0 r
F P
0 g
s
.71692 .43221 m .70411 .42534 L .7164 .4208 L p .225 .648 .956 r
F P
0 g
s
.70411 .42534 m .69138 .41993 L .70263 .41834 L p .144 .643 .91 r
F P
0 g
s
.70263 .41834 m .7164 .4208 L .70411 .42534 L p .144 .643 .91 r
F P
0 g
s
.72982 .44043 m .71692 .43221 L .73025 .42433 L p .288 .635 .964 r
F P
0 g
s
.7164 .4208 m .73025 .42433 L .71692 .43221 L p .225 .648 .956 r
F P
0 g
s
.38167 .52639 m .39333 .52265 L .41856 .50671 L p .381 .815 .656 r
F P
0 g
s
.42793 .50198 m .41856 .50671 L .39333 .52265 L p 0 0 0 r
F P
0 g
s
.52365 .45335 m .5233 .44897 L .50601 .46026 L p .157 0 0 r
F P
0 g
s
.5233 .44897 m .52365 .45335 L .53761 .44576 L p .157 0 0 r
F P
0 g
s
.69138 .41993 m .67871 .41606 L .68894 .417 L p .048 .606 .811 r
F P
0 g
s
.68894 .417 m .70263 .41834 L .69138 .41993 L p .048 .606 .811 r
F P
0 g
s
.74282 .44987 m .72982 .44043 L .74419 .42883 L p .334 .614 .952 r
F P
0 g
s
.73025 .42433 m .74419 .42883 L .72982 .44043 L p .288 .635 .964 r
F P
0 g
s
.67871 .41606 m .6661 .41377 L .67531 .41681 L p .047 0 0 r
F P
0 g
s
.67531 .41681 m .68894 .417 L .67871 .41606 L p .047 0 0 r
F P
0 g
s
.4468 .49423 m .45632 .49118 L .47618 .47457 L p 0 0 0 r
F P
0 g
s
.48293 .47336 m .47618 .47457 L .45632 .49118 L p .059 0 0 r
F P
0 g
s
.75592 .46038 m .74282 .44987 L .75823 .43422 L p .369 .594 .933 r
F P
0 g
s
.74419 .42883 m .75823 .43422 L .74282 .44987 L p .334 .614 .952 r
F P
0 g
s
.24537 .53174 m .25808 .53383 L .29016 .55569 L p .644 .82 .968 r
F P
0 g
s
.30143 .55208 m .29016 .55569 L .25808 .53383 L p .632 .848 .982 r
F P
0 g
s
.6661 .41377 m .65351 .41311 L .66172 .41779 L p .127 0 0 r
F P
0 g
s
.66172 .41779 m .67531 .41681 L .6661 .41377 L p .127 0 0 r
F P
0 g
s
.76912 .47179 m .75592 .46038 L .77237 .44039 L p .396 .577 .912 r
F P
0 g
s
.75823 .43422 m .77237 .44039 L .75592 .46038 L p .369 .594 .933 r
F P
0 g
s
.39333 .52265 m .40505 .5189 L .42793 .50198 L p 0 0 0 r
F P
0 g
s
.43734 .49783 m .42793 .50198 L .40505 .5189 L p 0 0 0 r
F P
0 g
s
.25808 .53383 m .27087 .53576 L .30143 .55208 L p .632 .848 .982 r
F P
0 g
s
.31274 .54846 m .30143 .55208 L .27087 .53576 L p .61 .873 .991 r
F P
0 g
s
.57116 .42982 m .56223 .43773 L .57138 .43783 L p .252 0 0 r
F P
0 g
s
.57138 .43783 m .58258 .42964 L .57116 .42982 L p .252 0 0 r
F P
0 g
s
.65351 .41311 m .64094 .41405 L .64817 .41994 L p .186 0 0 r
F P
0 g
s
.64817 .41994 m .66172 .41779 L .65351 .41311 L p .186 0 0 r
F P
0 g
s
.7824 .4839 m .76912 .47179 L .7866 .4472 L p .419 .564 .893 r
F P
0 g
s
.77237 .44039 m .7866 .4472 L .76912 .47179 L p .396 .577 .912 r
F P
0 g
s
.48293 .47336 m .48976 .47303 L .50601 .46026 L p .087 0 0 r
F P
0 g
s
.50971 .46279 m .50601 .46026 L .48976 .47303 L p .177 0 0 r
F P
0 g
s
.50601 .46026 m .50971 .46279 L .52365 .45335 L p .157 0 0 r
F P
0 g
s
.59367 .42288 m .58258 .42964 L .59037 .43284 L p .262 0 0 r
F P
0 g
s
.59037 .43284 m .6031 .42607 L .59367 .42288 L p .262 0 0 r
F P
0 g
s
.27087 .53576 m .28373 .53744 L .31274 .54846 L p .61 .873 .991 r
F P
0 g
s
.3241 .54482 m .31274 .54846 L .28373 .53744 L p .575 .892 .988 r
F P
0 g
s
.79578 .49651 m .7824 .4839 L .80094 .45453 L p .438 .556 .877 r
F P
0 g
s
.7866 .4472 m .80094 .45453 L .7824 .4839 L p .419 .564 .893 r
F P
0 g
s
.64094 .41405 m .62837 .41657 L .63463 .42322 L p .226 0 0 r
F P
0 g
s
.63463 .42322 m .64817 .41994 L .64094 .41405 L p .226 0 0 r
F P
0 g
s
.45632 .49118 m .46591 .48862 L .48293 .47336 L p .059 0 0 r
F P
0 g
s
.48976 .47303 m .48293 .47336 L .46591 .48862 L p .146 0 0 r
F P
0 g
s
.40505 .5189 m .41682 .51514 L .43734 .49783 L p 0 0 0 r
F P
0 g
s
.4468 .49423 m .43734 .49783 L .41682 .51514 L p .004 0 0 r
F P
0 g
s
.53457 .45306 m .53761 .44576 L .52365 .45335 L p .229 0 0 r
F P
0 g
s
.53761 .44576 m .53457 .45306 L .5445 .449 L p .24 0 0 r
F P
0 g
s
.5445 .449 m .55073 .44044 L .53761 .44576 L p .24 0 0 r
F P
0 g
s
.80922 .5094 m .79578 .49651 L .81536 .46221 L p .456 .552 .864 r
F P
0 g
s
.80094 .45453 m .81536 .46221 L .79578 .49651 L p .438 .556 .877 r
F P
0 g
s
.55073 .44044 m .5445 .449 L .55318 .44702 L p .258 0 0 r
F P
0 g
s
.55318 .44702 m .56223 .43773 L .55073 .44044 L p .258 0 0 r
F P
0 g
s
.28373 .53744 m .29668 .5388 L .3241 .54482 L p .575 .892 .988 r
F P
0 g
s
.33552 .54116 m .3241 .54482 L .29668 .5388 L p .521 .896 .963 r
F P
0 g
s
.52401 .45893 m .52365 .45335 L .50971 .46279 L p .227 0 0 r
F P
0 g
s
.52365 .45335 m .52401 .45893 L .53457 .45306 L p .229 0 0 r
F P
0 g
s
.62837 .41657 m .61576 .42061 L .62109 .4276 L p .254 0 0 r
F P
0 g
s
.62109 .4276 m .63463 .42322 L .62837 .41657 L p .254 0 0 r
F P
0 g
s
.82272 .52235 m .80922 .5094 L .82987 .4701 L p .474 .551 .855 r
F P
0 g
s
.81536 .46221 m .82987 .4701 L .80922 .5094 L p .456 .552 .864 r
F P
0 g
s
.29668 .5388 m .3097 .53975 L .33552 .54116 L p .521 .896 .963 r
F P
0 g
s
.34698 .5375 m .33552 .54116 L .3097 .53975 L p .444 .876 .907 r
F P
0 g
s
.41682 .51514 m .42864 .51135 L .4468 .49423 L p .004 0 0 r
F P
0 g
s
.45632 .49118 m .4468 .49423 L .42864 .51135 L p .089 0 0 r
F P
0 g
s
.58258 .42964 m .57138 .43783 L .57756 .44078 L p .279 0 0 r
F P
0 g
s
.57756 .44078 m .59037 .43284 L .58258 .42964 L p .279 0 0 r
F P
0 g
s
.56223 .43773 m .55318 .44702 L .56004 .44725 L p .277 0 .002 r
F P
0 g
s
.56004 .44725 m .57138 .43783 L .56223 .43773 L p .277 0 .002 r
F P
0 g
s
.83625 .53514 m .82272 .52235 L .84444 .47802 L p .49 .553 .848 r
F P
0 g
s
.82987 .4701 m .84444 .47802 L .82272 .52235 L p .474 .551 .855 r
F P
0 g
s
.3097 .53975 m .3228 .54023 L .34698 .5375 L p .444 .876 .907 r
F P
0 g
s
.35849 .53381 m .34698 .5375 L .3228 .54023 L p .347 .825 .818 r
F P
0 g
s
.61576 .42061 m .6031 .42607 L .60754 .43299 L p .272 0 0 r
F P
0 g
s
.60754 .43299 m .62109 .4276 L .61576 .42061 L p .272 0 0 r
F P
0 g
s
.48976 .47303 m .49665 .47349 L .50971 .46279 L p .177 0 0 r
F P
0 g
s
.51347 .46627 m .50971 .46279 L .49665 .47349 L p .236 0 0 r
F P
0 g
s
.50971 .46279 m .51347 .46627 L .52401 .45893 L p .227 0 0 r
F P
0 g
s
.46591 .48862 m .47557 .48652 L .48976 .47303 L p .146 0 0 r
F P
0 g
s
.49665 .47349 m .48976 .47303 L .47557 .48652 L p .208 0 0 r
F P
0 g
s
.84444 .47802 m .85906 .48583 L .83625 .53514 L p .49 .553 .848 r
F P
0 g
s
.42864 .51135 m .44051 .50755 L .45632 .49118 L p .089 0 0 r
F P
0 g
s
.46591 .48862 m .45632 .49118 L .44051 .50755 L p .155 0 0 r
F P
0 g
s
.3228 .54023 m .33598 .54019 L .35849 .53381 L p .347 .825 .818 r
F P
0 g
s
.37005 .53011 m .35849 .53381 L .33598 .54019 L p .239 .746 .701 r
F P
0 g
s
.53148 .46147 m .53457 .45306 L .52401 .45893 L p .272 0 .028 r
F P
0 g
s
.53457 .45306 m .53148 .46147 L .53816 .45872 L p .277 0 .029 r
F P
0 g
s
.53816 .45872 m .5445 .449 L .53457 .45306 L p .277 0 .029 r
F P
0 g
s
.6031 .42607 m .59037 .43284 L .59395 .43931 L p .284 0 0 r
F P
0 g
s
.59395 .43931 m .60754 .43299 L .6031 .42607 L p .284 0 0 r
F P
0 g
s
.33598 .54019 m .34923 .53956 L .37005 .53011 L p .239 .746 .701 r
F P
0 g
s
.38167 .52639 m .37005 .53011 L .34923 .53956 L p 0 0 0 r
F P
0 g
s
.5445 .449 m .53816 .45872 L .54398 .45742 L p .285 0 .033 r
F P
0 g
s
.54398 .45742 m .55318 .44702 L .5445 .449 L p .285 0 .033 r
F P
0 g
s
.57138 .43783 m .56004 .44725 L .56464 .44972 L p .291 0 .02 r
F P
0 g
s
.56464 .44972 m .57756 .44078 L .57138 .43783 L p .291 0 .02 r
F P
0 g
s
.52437 .46548 m .52401 .45893 L .51347 .46627 L p .271 0 .031 r
F P
0 g
s
.52401 .45893 m .52437 .46548 L .53148 .46147 L p .272 0 .028 r
F P
0 g
s
.44051 .50755 m .45243 .50373 L .46591 .48862 L p .155 0 0 r
F P
0 g
s
.47557 .48652 m .46591 .48862 L .45243 .50373 L p .205 0 0 r
F P
0 g
s
.34923 .53956 m .36255 .53833 L .38167 .52639 L p 0 0 0 r
F P
0 g
s
.39333 .52265 m .38167 .52639 L .36255 .53833 L p 0 0 0 r
F P
0 g
s
.47557 .48652 m .48531 .48481 L .49665 .47349 L p .208 0 0 r
F P
0 g
s
.50363 .47461 m .49665 .47349 L .48531 .48481 L p .252 0 .013 r
F P
0 g
s
.49665 .47349 m .50363 .47461 L .51347 .46627 L p .236 0 0 r
F P
0 g
s
.55318 .44702 m .54398 .45742 L .54856 .45767 L p .293 0 .04 r
F P
0 g
s
.54856 .45767 m .56004 .44725 L .55318 .44702 L p .293 0 .04 r
F P
0 g
s
.22012 .5274 m .20758 .52532 L .18911 .47507 L p .501 .654 .927 r
F P
0 g
s
.51729 .47052 m .51347 .46627 L .50363 .47461 L p .274 0 .037 r
F P
0 g
s
.51347 .46627 m .51729 .47052 L .52437 .46548 L p .271 0 .031 r
F P
0 g
s
.59037 .43284 m .57756 .44078 L .58031 .44645 L p .292 0 .004 r
F P
0 g
s
.58031 .44645 m .59395 .43931 L .59037 .43284 L p .292 0 .004 r
F P
0 g
s
.36255 .53833 m .37594 .53645 L .39333 .52265 L p 0 0 0 r
F P
0 g
s
.40505 .5189 m .39333 .52265 L .37594 .53645 L p .043 0 0 r
F P
0 g
s
.18911 .47507 m .20239 .48293 L .22012 .5274 L p .501 .654 .927 r
F P
0 g
s
.23272 .52957 m .22012 .5274 L .20239 .48293 L p .477 .66 .942 r
F P
0 g
s
.45243 .50373 m .46441 .4999 L .47557 .48652 L p .205 0 0 r
F P
0 g
s
.48531 .48481 m .47557 .48652 L .46441 .4999 L p .243 0 0 r
F P
0 g
s
.37594 .53645 m .38938 .53393 L .40505 .5189 L p .043 0 0 r
F P
0 g
s
.41682 .51514 m .40505 .5189 L .38938 .53393 L p .108 0 0 r
F P
0 g
s
.70263 .41834 m .68894 .417 L .68847 .42232 L p .023 0 0 r
F P
0 g
s
.68894 .417 m .67531 .41681 L .67469 .42433 L p .096 0 0 r
F P
0 g
s
.67469 .42433 m .68847 .42232 L .68894 .417 L p .096 0 0 r
F P
0 g
s
.67531 .41681 m .66172 .41779 L .66097 .42695 L p .154 0 0 r
F P
0 g
s
.66097 .42695 m .67469 .42433 L .67531 .41681 L p .154 0 0 r
F P
0 g
s
.7164 .4208 m .70263 .41834 L .70231 .42093 L p .065 .629 .732 r
F P
0 g
s
.68847 .42232 m .70231 .42093 L .70263 .41834 L p .023 0 0 r
F P
0 g
s
.56004 .44725 m .54856 .45767 L .5516 .45945 L p .299 0 .048 r
F P
0 g
s
.5516 .45945 m .56464 .44972 L .56004 .44725 L p .299 0 .048 r
F P
0 g
s
.20239 .48293 m .21572 .49099 L .23272 .52957 L p .477 .66 .942 r
F P
0 g
s
.24537 .53174 m .23272 .52957 L .21572 .49099 L p .45 .67 .957 r
F P
0 g
s
.66172 .41779 m .64817 .41994 L .6473 .43018 L p .196 0 0 r
F P
0 g
s
.6473 .43018 m .66097 .42695 L .66172 .41779 L p .196 0 0 r
F P
0 g
s
.73025 .42433 m .7164 .4208 L .71622 .42012 L p .16 .693 .85 r
F P
0 g
s
.70231 .42093 m .71622 .42012 L .7164 .4208 L p .065 .629 .732 r
F P
0 g
s
.64817 .41994 m .63463 .42322 L .63367 .43401 L p .228 0 0 r
F P
0 g
s
.63367 .43401 m .6473 .43018 L .64817 .41994 L p .228 0 0 r
F P
0 g
s
.57756 .44078 m .56464 .44972 L .56662 .45429 L p .298 0 .034 r
F P
0 g
s
.56662 .45429 m .58031 .44645 L .57756 .44078 L p .298 0 .034 r
F P
0 g
s
.74419 .42883 m .73025 .42433 L .73021 .41987 L p .249 .73 .932 r
F P
0 g
s
.71622 .42012 m .73021 .41987 L .73025 .42433 L p .16 .693 .85 r
F P
0 g
s
.48531 .48481 m .49512 .48343 L .50363 .47461 L p .252 0 .013 r
F P
0 g
s
.5107 .47624 m .50363 .47461 L .49512 .48343 L p .281 0 .045 r
F P
0 g
s
.50363 .47461 m .5107 .47624 L .51729 .47052 L p .274 0 .037 r
F P
0 g
s
.38938 .53393 m .40286 .53077 L .41682 .51514 L p .108 0 0 r
F P
0 g
s
.42864 .51135 m .41682 .51514 L .40286 .53077 L p .159 0 0 r
F P
0 g
s
.52833 .4707 m .53148 .46147 L .52437 .46548 L p .297 0 .06 r
F P
0 g
s
.53148 .46147 m .52833 .4707 L .5317 .46931 L p .298 0 .061 r
F P
0 g
s
.5317 .46931 m .53816 .45872 L .53148 .46147 L p .298 0 .061 r
F P
0 g
s
.53816 .45872 m .5317 .46931 L .53463 .46867 L p .3 0 .062 r
F P
0 g
s
.53463 .46867 m .54398 .45742 L .53816 .45872 L p .3 0 .062 r
F P
0 g
s
.63463 .42322 m .62109 .4276 L .62007 .43841 L p .251 0 0 r
F P
0 g
s
.62007 .43841 m .63367 .43401 L .63463 .42322 L p .251 0 0 r
F P
0 g
s
.21572 .49099 m .22911 .49908 L .24537 .53174 L p .45 .67 .957 r
F P
0 g
s
.25808 .53383 m .24537 .53174 L .22911 .49908 L p .419 .681 .971 r
F P
0 g
s
.75823 .43422 m .74419 .42883 L .74428 .42014 L p .324 .741 .977 r
F P
0 g
s
.73021 .41987 m .74428 .42014 L .74419 .42883 L p .249 .73 .932 r
F P
0 g
s
.52474 .47275 m .52437 .46548 L .51729 .47052 L p .296 0 .061 r
F P
0 g
s
.52437 .46548 m .52474 .47275 L .52833 .4707 L p .297 0 .06 r
F P
0 g
s
.46441 .4999 m .47644 .49605 L .48531 .48481 L p .243 0 0 r
F P
0 g
s
.49512 .48343 m .48531 .48481 L .47644 .49605 L p .27 0 .029 r
F P
0 g
s
.40286 .53077 m .41639 .52699 L .42864 .51135 L p .159 0 0 r
F P
0 g
s
.44051 .50755 m .42864 .51135 L .41639 .52699 L p .198 0 0 r
F P
0 g
s
.62109 .4276 m .60754 .43299 L .60649 .44334 L p .268 0 0 r
F P
0 g
s
.60649 .44334 m .62007 .43841 L .62109 .4276 L p .268 0 0 r
F P
0 g
s
.77237 .44039 m .75823 .43422 L .75844 .42088 L p .382 .734 .991 r
F P
0 g
s
.74428 .42014 m .75844 .42088 L .75823 .43422 L p .324 .741 .977 r
F P
0 g
s
.54398 .45742 m .53463 .46867 L .53692 .46883 L p .302 0 .064 r
F P
0 g
s
.53692 .46883 m .54856 .45767 L .54398 .45742 L p .302 0 .064 r
F P
0 g
s
.22911 .49908 m .24257 .50703 L .25808 .53383 L p .419 .681 .971 r
F P
0 g
s
.27087 .53576 m .25808 .53383 L .24257 .50703 L p .381 .693 .981 r
F P
0 g
s
.52117 .47532 m .51729 .47052 L .5107 .47624 L p .297 0 .063 r
F P
0 g
s
.51729 .47052 m .52117 .47532 L .52474 .47275 L p .296 0 .061 r
F P
0 g
s
.7866 .4472 m .77237 .44039 L .77269 .42202 L p .426 .719 .986 r
F P
0 g
s
.75844 .42088 m .77269 .42202 L .77237 .44039 L p .382 .734 .991 r
F P
0 g
s
.60754 .43299 m .59395 .43931 L .59292 .44874 L p .28 0 0 r
F P
0 g
s
.59292 .44874 m .60649 .44334 L .60754 .43299 L p .28 0 0 r
F P
0 g
s
.56464 .44972 m .5516 .45945 L .55286 .46268 L p .302 0 .054 r
F P
0 g
s
.55286 .46268 m .56662 .45429 L .56464 .44972 L p .302 0 .054 r
F P
0 g
s
.41639 .52699 m .42995 .52261 L .44051 .50755 L p .198 0 0 r
F P
0 g
s
.45243 .50373 m .44051 .50755 L .42995 .52261 L p .229 0 0 r
F P
0 g
s
.24257 .50703 m .25613 .51468 L .27087 .53576 L p .381 .693 .981 r
F P
0 g
s
.28373 .53744 m .27087 .53576 L .25613 .51468 L p .335 .703 .983 r
F P
0 g
s
.54856 .45767 m .53692 .46883 L .53843 .46978 L p .304 0 .066 r
F P
0 g
s
.53843 .46978 m .5516 .45945 L .54856 .45767 L p .304 0 .066 r
F P
0 g
s
.80094 .45453 m .7866 .4472 L .78702 .4235 L p .458 .701 .972 r
F P
0 g
s
.77269 .42202 m .78702 .4235 L .7866 .4472 L p .426 .719 .986 r
F P
0 g
s
.47644 .49605 m .48853 .49218 L .49512 .48343 L p .27 0 .029 r
F P
0 g
s
.50503 .4823 m .49512 .48343 L .48853 .49218 L p .289 0 .052 r
F P
0 g
s
.49512 .48343 m .50503 .4823 L .5107 .47624 L p .281 0 .045 r
F P
0 g
s
.59395 .43931 m .58031 .44645 L .57937 .45455 L p .289 0 .018 r
F P
0 g
s
.57937 .45455 m .59292 .44874 L .59395 .43931 L p .289 0 .018 r
F P
0 g
s
.51786 .47825 m .5107 .47624 L .50503 .4823 L p .299 0 .065 r
F P
0 g
s
.5107 .47624 m .51786 .47825 L .52117 .47532 L p .297 0 .063 r
F P
0 g
s
.42995 .52261 m .44353 .51769 L .45243 .50373 L p .229 0 0 r
F P
0 g
s
.46441 .4999 m .45243 .50373 L .44353 .51769 L p .254 0 0 r
F P
0 g
s
.25613 .51468 m .26978 .52185 L .28373 .53744 L p .335 .703 .983 r
F P
0 g
s
.29668 .5388 m .28373 .53744 L .26978 .52185 L p .277 .705 .967 r
F P
0 g
s
.81536 .46221 m .80094 .45453 L .80143 .42524 L p .484 .684 .955 r
F P
0 g
s
.78702 .4235 m .80143 .42524 L .80094 .45453 L p .458 .701 .972 r
F P
0 g
s
.58031 .44645 m .56662 .45429 L .56581 .46071 L p .296 0 .041 r
F P
0 g
s
.56581 .46071 m .57937 .45455 L .58031 .44645 L p .296 0 .041 r
F P
0 g
s
.44353 .51769 m .45713 .51228 L .46441 .4999 L p .254 0 0 r
F P
0 g
s
.47644 .49605 m .46441 .4999 L .45713 .51228 L p .272 0 .016 r
F P
0 g
s
.5516 .45945 m .53843 .46978 L .53903 .47146 L p .305 0 .068 r
F P
0 g
s
.53903 .47146 m .55286 .46268 L .5516 .45945 L p .305 0 .068 r
F P
0 g
s
.26978 .52185 m .28353 .52839 L .29668 .5388 L p .277 .705 .967 r
F P
0 g
s
.3097 .53975 m .29668 .5388 L .28353 .52839 L p .206 .694 .926 r
F P
0 g
s
.52511 .48046 m .52833 .4707 L .52474 .47275 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .5317 .46931 L .52833 .4707 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .53463 .46867 L .5317 .46931 L closepath p .307 0 .075 r
F P
0 g
s
.82987 .4701 m .81536 .46221 L .81593 .42716 L p .505 .67 .938 r
F P
0 g
s
.80143 .42524 m .81593 .42716 L .81536 .46221 L p .484 .684 .955 r
F P
0 g
s
.52511 .48046 m .52474 .47275 L .52117 .47532 L closepath p .307 0 .075 r
F P
0 g
s
.48853 .49218 m .50067 .48829 L .50503 .4823 L p .289 0 .052 r
F P
0 g
s
.51502 .48134 m .50503 .4823 L .50067 .48829 L p .301 0 .067 r
F P
0 g
s
.50503 .4823 m .51502 .48134 L .51786 .47825 L p .299 0 .065 r
F P
0 g
s
.45713 .51228 m .47073 .50644 L .47644 .49605 L p .272 0 .016 r
F P
0 g
s
.48853 .49218 m .47644 .49605 L .47073 .50644 L p .286 0 .039 r
F P
0 g
s
.52511 .48046 m .53692 .46883 L .53463 .46867 L closepath p .307 0 .075 r
F P
0 g
s
.56662 .45429 m .55286 .46268 L .55225 .46714 L p .301 0 .057 r
F P
0 g
s
.55225 .46714 m .56581 .46071 L .56662 .45429 L p .301 0 .057 r
F P
0 g
s
.28353 .52839 m .29739 .53414 L .3097 .53975 L p .206 .694 .926 r
F P
0 g
s
.3228 .54023 m .3097 .53975 L .29895 .53485 L p .127 .663 .853 r
F P
0 g
s
.3228 .54023 m .29895 .53485 L .30278 .53543 L .127 .663 .853 r
F
.29895 .53485 m .29739 .53414 L p .30278 .53543 L F P
0 g
s
.29739 .53414 m .31135 .53896 L .3228 .54023 L p .127 .663 .853 r
F P
0 g
s
.33598 .54019 m .3228 .54023 L .31135 .53896 L p .044 .612 .751 r
F P
0 g
s
.31135 .53896 m .32542 .54275 L .33523 .54037 L p .044 .612 .751 r
F P
0 g
s
.33523 .54037 m .33598 .54019 L p .33309 .54004 L .044 .612 .751 r
F P
0 g
s
.33309 .54004 m .31135 .53896 L .33523 .54037 L .044 .612 .751 r
F
.52511 .48046 m .52117 .47532 L .51786 .47825 L closepath p .307 0 .075 r
F P
0 g
s
.84444 .47802 m .82987 .4701 L .83051 .42918 L p .523 .659 .922 r
F P
0 g
s
.81593 .42716 m .83051 .42918 L .82987 .4701 L p .505 .67 .938 r
F P
0 g
s
.52511 .48046 m .53843 .46978 L .53692 .46883 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51786 .47825 L .51502 .48134 L closepath p .307 0 .075 r
F P
0 g
s
.47073 .50644 m .48433 .50026 L .48853 .49218 L p .286 0 .039 r
F P
0 g
s
.50067 .48829 m .48853 .49218 L .48433 .50026 L p .296 0 .057 r
F P
0 g
s
.55286 .46268 m .53903 .47146 L .53869 .47376 L p .305 0 .069 r
F P
0 g
s
.53869 .47376 m .55225 .46714 L .55286 .46268 L p .305 0 .069 r
F P
0 g
s
.52511 .48046 m .53903 .47146 L .53843 .46978 L closepath p .307 0 .075 r
F P
0 g
s
.85906 .48583 m .84444 .47802 L .84515 .43121 L p .538 .652 .908 r
F P
0 g
s
.83051 .42918 m .84515 .43121 L .84444 .47802 L p .523 .659 .922 r
F P
0 g
s
.34923 .53956 m .33598 .54019 L .32542 .54275 L p .034 0 0 r
F P
0 g
s
.50067 .48829 m .51286 .48439 L .51502 .48134 L p .301 0 .067 r
F P
0 g
s
.52511 .48046 m .51502 .48134 L .51286 .48439 L closepath p .307 0 .075 r
F P
0 g
s
.48433 .50026 m .49793 .49381 L .50067 .48829 L p .296 0 .057 r
F P
0 g
s
.51286 .48439 m .50067 .48829 L .49793 .49381 L p .303 0 .068 r
F P
0 g
s
.32542 .54275 m .33957 .5454 L .34923 .53956 L p .034 0 0 r
F P
0 g
s
.36255 .53833 m .34923 .53956 L .33957 .5454 L p .1 0 0 r
F P
0 g
s
.84515 .43121 m .85986 .43317 L .85906 .48583 L p .538 .652 .908 r
F P
0 g
s
.52511 .48046 m .53869 .47376 L .53903 .47146 L closepath p .307 0 .075 r
F P
0 g
s
.33957 .5454 m .3538 .54683 L .36255 .53833 L p .1 0 0 r
F P
0 g
s
.37594 .53645 m .36255 .53833 L .3538 .54683 L p .153 0 0 r
F P
0 g
s
.49793 .49381 m .51153 .48718 L .51286 .48439 L p .303 0 .068 r
F P
0 g
s
.52511 .48046 m .51286 .48439 L .51153 .48718 L closepath p .307 0 .075 r
F P
0 g
s
.3538 .54683 m .3681 .54701 L .37594 .53645 L p .153 0 0 r
F P
0 g
s
.38938 .53393 m .37594 .53645 L .3681 .54701 L p .193 0 0 r
F P
0 g
s
.60649 .44334 m .59292 .44874 L .5872 .46059 L p .254 0 0 r
F P
0 g
s
.59292 .44874 m .57937 .45455 L .57467 .4646 L p .272 0 .016 r
F P
0 g
s
.57467 .4646 m .5872 .46059 L .59292 .44874 L p .272 0 .016 r
F P
0 g
s
.62007 .43841 m .60649 .44334 L .59979 .45656 L p .229 0 0 r
F P
0 g
s
.5872 .46059 m .59979 .45656 L .60649 .44334 L p .254 0 0 r
F P
0 g
s
.57937 .45455 m .56581 .46071 L .5622 .46859 L p .286 0 .039 r
F P
0 g
s
.5622 .46859 m .57467 .4646 L .57937 .45455 L p .286 0 .039 r
F P
0 g
s
.63367 .43401 m .62007 .43841 L .61243 .45251 L p .198 0 0 r
F P
0 g
s
.59979 .45656 m .61243 .45251 L .62007 .43841 L p .229 0 0 r
F P
0 g
s
.56581 .46071 m .55225 .46714 L .54978 .47257 L p .296 0 .057 r
F P
0 g
s
.54978 .47257 m .5622 .46859 L .56581 .46071 L p .296 0 .057 r
F P
0 g
s
.6473 .43018 m .63367 .43401 L .62513 .44844 L p .159 0 0 r
F P
0 g
s
.61243 .45251 m .62513 .44844 L .63367 .43401 L p .198 0 0 r
F P
0 g
s
.55225 .46714 m .53869 .47376 L .53742 .47653 L p .303 0 .068 r
F P
0 g
s
.53742 .47653 m .54978 .47257 L .55225 .46714 L p .303 0 .068 r
F P
0 g
s
.3681 .54701 m .38245 .54592 L .38938 .53393 L p .193 0 0 r
F P
0 g
s
.40286 .53077 m .38938 .53393 L .38245 .54592 L p .223 0 0 r
F P
0 g
s
.52511 .48046 m .53742 .47653 L .53869 .47376 L closepath p .307 0 .075 r
F P
0 g
s
.66097 .42695 m .6473 .43018 L .63789 .44436 L p .108 0 0 r
F P
0 g
s
.62513 .44844 m .63789 .44436 L .6473 .43018 L p .159 0 0 r
F P
0 g
s
.52511 .48046 m .5353 .47958 L .53742 .47653 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .53247 .48271 L .5353 .47958 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .52913 .48569 L .53247 .48271 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .5255 .48833 L .52913 .48569 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .52184 .49043 L .5255 .48833 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .5184 .49184 L .52184 .49043 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51543 .49247 L .5184 .49184 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51313 .49227 L .51543 .49247 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51166 .49127 L .51313 .49227 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51112 .48953 L .51166 .49127 L closepath p .307 0 .075 r
F P
0 g
s
.52511 .48046 m .51153 .48718 L .51112 .48953 L closepath p .307 0 .075 r
F P
0 g
s
.38245 .54592 m .39683 .54356 L .40286 .53077 L p .223 0 0 r
F P
0 g
s
.41639 .52699 m .40286 .53077 L .39683 .54356 L p .245 0 0 r
F P
0 g
s
.49703 .49846 m .51112 .48953 L .51153 .48718 L p .305 0 .069 r
F P
0 g
s
.51153 .48718 m .49793 .49381 L .49703 .49846 L p .305 0 .069 r
F P
0 g
s
.67469 .42433 m .66097 .42695 L .65071 .44025 L p .043 0 0 r
F P
0 g
s
.63789 .44436 m .65071 .44025 L .66097 .42695 L p .108 0 0 r
F P
0 g
s
.48287 .5071 m .49703 .49846 L .49793 .49381 L p .301 0 .058 r
F P
0 g
s
.49793 .49381 m .48433 .50026 L .48287 .5071 L p .301 0 .058 r
F P
0 g
s
.39683 .54356 m .41123 .53999 L .41639 .52699 L p .245 0 0 r
F P
0 g
s
.42995 .52261 m .41639 .52699 L .41123 .53999 L p .262 0 0 r
F P
0 g
s
.46864 .51526 m .48287 .5071 L .48433 .50026 L p .297 0 .042 r
F P
0 g
s
.48433 .50026 m .47073 .50644 L .46864 .51526 L p .297 0 .042 r
F P
0 g
s
.41123 .53999 m .42563 .53526 L .42995 .52261 L p .262 0 0 r
F P
0 g
s
.44353 .51769 m .42995 .52261 L .42563 .53526 L p .274 0 0 r
F P
0 g
s
.45435 .52277 m .46864 .51526 L .47073 .50644 L p .291 0 .02 r
F P
0 g
s
.47073 .50644 m .45713 .51228 L .45435 .52277 L p .291 0 .02 r
F P
0 g
s
.42563 .53526 m .44001 .52949 L .44353 .51769 L p .274 0 0 r
F P
0 g
s
.45713 .51228 m .44353 .51769 L .44001 .52949 L p .284 0 0 r
F P
0 g
s
.44001 .52949 m .45435 .52277 L .45713 .51228 L p .284 0 0 r
F P
0 g
s
.68847 .42232 m .67469 .42433 L .66359 .43613 L p 0 0 0 r
F P
0 g
s
.65071 .44025 m .66359 .43613 L .67469 .42433 L p .043 0 0 r
F P
0 g
s
.54978 .47257 m .53742 .47653 L .5353 .47958 L p .301 0 .067 r
F P
0 g
s
.70231 .42093 m .68847 .42232 L .67653 .43199 L p 0 0 0 r
F P
0 g
s
.66359 .43613 m .67653 .43199 L .68847 .42232 L p 0 0 0 r
F P
0 g
s
.49806 .50193 m .51166 .49127 L .51112 .48953 L p .305 0 .068 r
F P
0 g
s
.51112 .48953 m .49703 .49846 L .49806 .50193 L p .305 0 .068 r
F P
0 g
s
.20239 .48293 m .18911 .47507 L .19318 .42214 L p .415 .533 .868 r
F P
0 g
s
.71622 .42012 m .70231 .42093 L .68953 .42783 L p .239 .746 .701 r
F P
0 g
s
.67653 .43199 m .68953 .42783 L .70231 .42093 L p 0 0 0 r
F P
0 g
s
.5622 .46859 m .54978 .47257 L .54558 .47859 L p .289 0 .052 r
F P
0 g
s
.5353 .47958 m .54558 .47859 L .54978 .47257 L p .301 0 .067 r
F P
0 g
s
.54558 .47859 m .5353 .47958 L .53247 .48271 L p .299 0 .065 r
F P
0 g
s
.68953 .42783 m .70259 .42365 L .71622 .42012 L p .239 .746 .701 r
F P
0 g
s
.73021 .41987 m .71622 .42012 L .70259 .42365 L p .347 .825 .818 r
F P
0 g
s
.19318 .42214 m .20636 .4356 L .20239 .48293 L p .415 .533 .868 r
F P
0 g
s
.21572 .49099 m .20239 .48293 L .20636 .4356 L p .386 .526 .875 r
F P
0 g
s
.50096 .50394 m .51313 .49227 L .51166 .49127 L p .304 0 .066 r
F P
0 g
s
.51166 .49127 m .49806 .50193 L .50096 .50394 L p .304 0 .066 r
F P
0 g
s
.48432 .5122 m .49806 .50193 L .49703 .49846 L p .303 0 .055 r
F P
0 g
s
.49703 .49846 m .48287 .5071 L .48432 .5122 L p .303 0 .055 r
F P
0 g
s
.57467 .4646 m .5622 .46859 L .55596 .47741 L p .271 0 .03 r
F P
0 g
s
.54558 .47859 m .55596 .47741 L .5622 .46859 L p .289 0 .052 r
F P
0 g
s
.74428 .42014 m .73021 .41987 L .71571 .41944 L p .444 .876 .907 r
F P
0 g
s
.70259 .42365 m .71571 .41944 L .73021 .41987 L p .347 .825 .818 r
F P
0 g
s
.53247 .48271 m .53993 .4848 L .54558 .47859 L p .299 0 .065 r
F P
0 g
s
.53993 .4848 m .53247 .48271 L .52913 .48569 L p .297 0 .063 r
F P
0 g
s
.50556 .50434 m .51543 .49247 L .51313 .49227 L p .303 0 .064 r
F P
0 g
s
.51313 .49227 m .50096 .50394 L .50556 .50434 L p .303 0 .064 r
F P
0 g
s
.20636 .4356 m .21957 .44935 L .21572 .49099 L p .386 .526 .875 r
F P
0 g
s
.22911 .49908 m .21572 .49099 L .21957 .44935 L p .357 .523 .883 r
F P
0 g
s
.52913 .48569 m .53321 .49076 L .53993 .4848 L p .297 0 .063 r
F P
0 g
s
.53321 .49076 m .52913 .48569 L .5255 .48833 L p .296 0 .062 r
F P
0 g
s
.75844 .42088 m .74428 .42014 L .72889 .41522 L p .521 .896 .963 r
F P
0 g
s
.71571 .41944 m .72889 .41522 L .74428 .42014 L p .444 .876 .907 r
F P
0 g
s
.47045 .52183 m .48432 .5122 L .48287 .5071 L p .3 0 .036 r
F P
0 g
s
.48287 .5071 m .46864 .51526 L .47045 .52183 L p .3 0 .036 r
F P
0 g
s
.51155 .50308 m .5184 .49184 L .51543 .49247 L p .3 0 .062 r
F P
0 g
s
.51543 .49247 m .50556 .50434 L .51155 .50308 L p .3 0 .062 r
F P
0 g
s
.5872 .46059 m .57467 .4646 L .56643 .47595 L p .245 0 0 r
F P
0 g
s
.55596 .47741 m .56643 .47595 L .57467 .4646 L p .271 0 .03 r
F P
0 g
s
.55596 .47741 m .54558 .47859 L .53993 .4848 L p .282 0 .046 r
F P
0 g
s
.5255 .48833 m .52589 .49603 L .53321 .49076 L p .296 0 .062 r
F P
0 g
s
.52589 .49603 m .5255 .48833 L .52184 .49043 L p .297 0 .061 r
F P
0 g
s
.21957 .44935 m .23285 .46314 L .22911 .49908 L p .357 .523 .883 r
F P
0 g
s
.24257 .50703 m .22911 .49908 L .23285 .46314 L p .326 .523 .895 r
F P
0 g
s
.51849 .50024 m .52184 .49043 L .5184 .49184 L p .298 0 .061 r
F P
0 g
s
.5184 .49184 m .51155 .50308 L .51849 .50024 L p .298 0 .061 r
F P
0 g
s
.52184 .49043 m .51849 .50024 L .52589 .49603 L p .297 0 .061 r
F P
0 g
s
.77269 .42202 m .75844 .42088 L .74213 .41098 L p .575 .892 .988 r
F P
0 g
s
.72889 .41522 m .74213 .41098 L .75844 .42088 L p .521 .896 .963 r
F P
0 g
s
.48862 .51516 m .50096 .50394 L .49806 .50193 L p .3 0 .049 r
F P
0 g
s
.49806 .50193 m .48432 .5122 L .48862 .51516 L p .3 0 .049 r
F P
0 g
s
.59979 .45656 m .5872 .46059 L .577 .47412 L p .21 0 0 r
F P
0 g
s
.56643 .47595 m .577 .47412 L .5872 .46059 L p .245 0 0 r
F P
0 g
s
.45645 .53057 m .47045 .52183 L .46864 .51526 L p .296 0 .01 r
F P
0 g
s
.46864 .51526 m .45435 .52277 L .45645 .53057 L p .296 0 .01 r
F P
0 g
s
.23285 .46314 m .2462 .47674 L .24257 .50703 L p .326 .523 .895 r
F P
0 g
s
.25613 .51468 m .24257 .50703 L .2462 .47674 L p .293 .527 .907 r
F P
0 g
s
.78702 .4235 m .77269 .42202 L .75544 .40673 L p .61 .873 .991 r
F P
0 g
s
.74213 .41098 m .75544 .40673 L .77269 .42202 L p .575 .892 .988 r
F P
0 g
s
.61243 .45251 m .59979 .45656 L .58765 .47184 L p .163 0 0 r
F P
0 g
s
.577 .47412 m .58765 .47184 L .59979 .45656 L p .21 0 0 r
F P
0 g
s
.53993 .4848 m .54749 .48657 L .55596 .47741 L p .282 0 .046 r
F P
0 g
s
.54749 .48657 m .53993 .4848 L .53321 .49076 L p .275 0 .039 r
F P
0 g
s
.44236 .53818 m .45645 .53057 L .45435 .52277 L p .291 0 0 r
F P
0 g
s
.45435 .52277 m .44001 .52949 L .44236 .53818 L p .291 0 0 r
F P
0 g
s
.56643 .47595 m .55596 .47741 L .54749 .48657 L p .254 0 .016 r
F P
0 g
s
.2462 .47674 m .25964 .48991 L .25613 .51468 L p .293 .527 .907 r
F P
0 g
s
.26978 .52185 m .25613 .51468 L .25964 .48991 L p .255 .535 .92 r
F P
0 g
s
.49553 .51573 m .50556 .50434 L .50096 .50394 L p .294 0 .042 r
F P
0 g
s
.50096 .50394 m .48862 .51516 L .49553 .51573 L p .294 0 .042 r
F P
0 g
s
.80143 .42524 m .78702 .4235 L .76881 .40245 L p .632 .848 .982 r
F P
0 g
s
.75544 .40673 m .76881 .40245 L .78702 .4235 L p .61 .873 .991 r
F P
0 g
s
.62513 .44844 m .61243 .45251 L .59839 .46905 L p .103 0 0 r
F P
0 g
s
.58765 .47184 m .59839 .46905 L .61243 .45251 L p .163 0 0 r
F P
0 g
s
.47612 .52562 m .48862 .51516 L .48432 .5122 L p .294 0 .023 r
F P
0 g
s
.48432 .5122 m .47045 .52183 L .47612 .52562 L p .294 0 .023 r
F P
0 g
s
.42818 .54448 m .44236 .53818 L .44001 .52949 L p .285 0 0 r
F P
0 g
s
.44001 .52949 m .42563 .53526 L .42818 .54448 L p .285 0 0 r
F P
0 g
s
.25964 .48991 m .27319 .50239 L .26978 .52185 L p .255 .535 .92 r
F P
0 g
s
.28353 .52839 m .26978 .52185 L .27319 .50239 L p .212 .546 .929 r
F P
0 g
s
.53321 .49076 m .53736 .4954 L .54749 .48657 L p .275 0 .039 r
F P
0 g
s
.53736 .4954 m .53321 .49076 L .52589 .49603 L p .272 0 .032 r
F P
0 g
s
.81593 .42716 m .80143 .42524 L .78224 .39815 L p .644 .82 .968 r
F P
0 g
s
.76881 .40245 m .78224 .39815 L .80143 .42524 L p .632 .848 .982 r
F P
0 g
s
.50457 .51382 m .51155 .50308 L .50556 .50434 L p .286 0 .035 r
F P
0 g
s
.50556 .50434 m .49553 .51573 L .50457 .51382 L p .286 0 .035 r
F P
0 g
s
.27319 .50239 m .28686 .51395 L .28353 .52839 L p .212 .546 .929 r
F P
0 g
s
.29739 .53414 m .28353 .52839 L .28686 .51395 L p .16 .556 .929 r
F P
0 g
s
.41394 .54926 m .42818 .54448 L .42563 .53526 L p .276 0 0 r
F P
0 g
s
.42563 .53526 m .41123 .53999 L .41394 .54926 L p .276 0 0 r
F P
0 g
s
.63789 .44436 m .62513 .44844 L .60921 .46568 L p .026 0 0 r
F P
0 g
s
.59839 .46905 m .60921 .46568 L .62513 .44844 L p .103 0 0 r
F P
0 g
s
.577 .47412 m .56643 .47595 L .55515 .48783 L p .213 0 0 r
F P
0 g
s
.54749 .48657 m .55515 .48783 L .56643 .47595 L p .254 0 .016 r
F P
0 g
s
.52589 .49603 m .52629 .50326 L .53736 .4954 L p .272 0 .032 r
F P
0 g
s
.52629 .50326 m .52589 .49603 L .51849 .50024 L p .273 0 .029 r
F P
0 g
s
.28686 .51395 m .30065 .52437 L .29739 .53414 L p .16 .556 .929 r
F P
0 g
s
.31135 .53896 m .29739 .53414 L .30065 .52437 L p .098 .56 .911 r
F P
0 g
s
.83051 .42918 m .81593 .42716 L .79573 .39382 L p .651 .794 .951 r
F P
0 g
s
.78224 .39815 m .79573 .39382 L .81593 .42716 L p .644 .82 .968 r
F P
0 g
s
.39966 .5524 m .41394 .54926 L .41123 .53999 L p .263 0 0 r
F P
0 g
s
.41123 .53999 m .39683 .54356 L .39966 .5524 L p .263 0 0 r
F P
0 g
s
.51508 .50956 m .51849 .50024 L .51155 .50308 L p .278 0 .03 r
F P
0 g
s
.51155 .50308 m .50457 .51382 L .51508 .50956 L p .278 0 .03 r
F P
0 g
s
.51849 .50024 m .51508 .50956 L .52629 .50326 L p .273 0 .029 r
F P
0 g
s
.65071 .44025 m .63789 .44436 L .6201 .46168 L p 0 0 0 r
F P
0 g
s
.60921 .46568 m .6201 .46168 L .63789 .44436 L p .026 0 0 r
F P
0 g
s
.55515 .48783 m .54749 .48657 L .53736 .4954 L p .239 0 0 r
F P
0 g
s
.30065 .52437 m .31455 .53344 L .31135 .53896 L p .098 .56 .911 r
F P
0 g
s
.32542 .54275 m .31135 .53896 L .31455 .53344 L p .028 .552 .861 r
F P
0 g
s
.46346 .53499 m .47612 .52562 L .47045 .52183 L p .285 0 0 r
F P
0 g
s
.47045 .52183 m .45645 .53057 L .46346 .53499 L p .285 0 0 r
F P
0 g
s
.38537 .55378 m .39966 .5524 L .39683 .54356 L p .244 0 0 r
F P
0 g
s
.39683 .54356 m .38245 .54592 L .38537 .55378 L p .244 0 0 r
F P
0 g
s
.31455 .53344 m .32856 .541 L .32542 .54275 L p .028 .552 .861 r
F P
0 g
s
.33957 .5454 m .32542 .54275 L .32856 .541 L p 0 .525 .775 r
F P
0 g
s
.37109 .55333 m .38537 .55378 L .38245 .54592 L p .215 0 0 r
F P
0 g
s
.38245 .54592 m .3681 .54701 L .37109 .55333 L p .215 0 0 r
F P
0 g
s
.84515 .43121 m .83051 .42918 L .80929 .38948 L p .654 .771 .935 r
F P
0 g
s
.79573 .39382 m .80929 .38948 L .83051 .42918 L p .651 .794 .951 r
F P
0 g
s
.48533 .52627 m .49553 .51573 L .48862 .51516 L p .28 0 .006 r
F P
0 g
s
.48862 .51516 m .47612 .52562 L .48533 .52627 L p .28 0 .006 r
F P
0 g
s
.32856 .541 m .34266 .5469 L .33957 .5454 L p 0 .525 .775 r
F P
0 g
s
.3538 .54683 m .33957 .5454 L .34266 .5469 L p .116 0 0 r
F P
0 g
s
.35684 .55103 m .37109 .55333 L .3681 .54701 L p .173 0 0 r
F P
0 g
s
.3681 .54701 m .3538 .54683 L .35684 .55103 L p .173 0 0 r
F P
0 g
s
.34266 .5469 m .35684 .55103 L .3538 .54683 L p .116 0 0 r
F P
0 g
s
.66359 .43613 m .65071 .44025 L .63105 .45701 L p 0 0 0 r
F P
0 g
s
.6201 .46168 m .63105 .45701 L .65071 .44025 L p 0 0 0 r
F P
0 g
s
.58765 .47184 m .577 .47412 L .56291 .48841 L p .155 0 0 r
F P
0 g
s
.55515 .48783 m .56291 .48841 L .577 .47412 L p .213 0 0 r
F P
0 g
s
.85986 .43317 m .84515 .43121 L .82291 .38512 L p .656 .751 .92 r
F P
0 g
s
.80929 .38948 m .82291 .38512 L .84515 .43121 L p .654 .771 .935 r
F P
0 g
s
.67653 .43199 m .66359 .43613 L .64207 .45166 L p 0 0 0 r
F P
0 g
s
.63105 .45701 m .64207 .45166 L .66359 .43613 L p 0 0 0 r
F P
0 g
s
.45066 .54301 m .46346 .53499 L .45645 .53057 L p .273 0 0 r
F P
0 g
s
.45645 .53057 m .44236 .53818 L .45066 .54301 L p .273 0 0 r
F P
0 g
s
.53736 .4954 m .54158 .49937 L .55515 .48783 L p .239 0 0 r
F P
0 g
s
.54158 .49937 m .53736 .4954 L .52629 .50326 L p .231 0 0 r
F P
0 g
s
.82291 .38512 m .8366 .38074 L .85986 .43317 L p .656 .751 .92 r
F P
0 g
s
.49745 .52368 m .50457 .51382 L .49553 .51573 L p .262 0 0 r
F P
0 g
s
.49553 .51573 m .48533 .52627 L .49745 .52368 L p .262 0 0 r
F P
0 g
s
.56291 .48841 m .55515 .48783 L .54158 .49937 L p .184 0 0 r
F P
0 g
s
.68953 .42783 m .67653 .43199 L .65314 .44561 L p .455 .868 .718 r
F P
0 g
s
.64207 .45166 m .65314 .44561 L .67653 .43199 L p 0 0 0 r
F P
0 g
s
.59839 .46905 m .58765 .47184 L .57076 .48816 L p .077 0 0 r
F P
0 g
s
.56291 .48841 m .57076 .48816 L .58765 .47184 L p .155 0 0 r
F P
0 g
s
.52629 .50326 m .52669 .5097 L .54158 .49937 L p .231 0 0 r
F P
0 g
s
.52669 .5097 m .52629 .50326 L .51508 .50956 L p .233 0 0 r
F P
0 g
s
.47497 .53562 m .48533 .52627 L .47612 .52562 L p .259 0 0 r
F P
0 g
s
.47612 .52562 m .46346 .53499 L .47497 .53562 L p .259 0 0 r
F P
0 g
s
.5116 .51802 m .51508 .50956 L .50457 .51382 L p .244 0 0 r
F P
0 g
s
.50457 .51382 m .49745 .52368 L .5116 .51802 L p .244 0 0 r
F P
0 g
s
.65314 .44561 m .66426 .43887 L .68953 .42783 L p .455 .868 .718 r
F P
0 g
s
.70259 .42365 m .68953 .42783 L .66426 .43887 L p .576 .939 .818 r
F P
0 g
s
.43774 .54939 m .45066 .54301 L .44236 .53818 L p .256 0 0 r
F P
0 g
s
.44236 .53818 m .42818 .54448 L .43774 .54939 L p .256 0 0 r
F P
0 g
s
.51508 .50956 m .5116 .51802 L .52669 .5097 L p .233 0 0 r
F P
0 g
s
.71571 .41944 m .70259 .42365 L .67542 .43146 L p .669 .974 .885 r
F P
0 g
s
.66426 .43887 m .67542 .43146 L .70259 .42365 L p .576 .939 .818 r
F P
0 g
s
.60921 .46568 m .59839 .46905 L .57869 .48692 L p 0 0 0 r
F P
0 g
s
.57076 .48816 m .57869 .48692 L .59839 .46905 L p .077 0 0 r
F P
0 g
s
.20636 .4356 m .19318 .42214 L .22154 .37026 L p .435 .473 .8 r
F P
0 g
s
.57076 .48816 m .56291 .48841 L .54587 .50241 L p .103 0 0 r
F P
0 g
s
.54158 .49937 m .54587 .50241 L .56291 .48841 L p .184 0 0 r
F P
0 g
s
.54587 .50241 m .54158 .49937 L .52669 .5097 L p .166 0 0 r
F P
0 g
s
.42473 .55391 m .43774 .54939 L .42818 .54448 L p .231 0 0 r
F P
0 g
s
.42818 .54448 m .41394 .54926 L .42473 .55391 L p .231 0 0 r
F P
0 g
s
.72889 .41522 m .71571 .41944 L .68662 .42341 L p .731 .977 .92 r
F P
0 g
s
.67542 .43146 m .68662 .42341 L .71571 .41944 L p .669 .974 .885 r
F P
0 g
s
.22154 .37026 m .2337 .38872 L .20636 .4356 L p .435 .473 .8 r
F P
0 g
s
.21957 .44935 m .20636 .4356 L .2337 .38872 L p .417 .464 .802 r
F P
0 g
s
.49022 .53231 m .49745 .52368 L .48533 .52627 L p .224 0 0 r
F P
0 g
s
.48533 .52627 m .47497 .53562 L .49022 .53231 L p .224 0 0 r
F P
0 g
s
.46447 .54345 m .47497 .53562 L .46346 .53499 L p .229 0 0 r
F P
0 g
s
.46346 .53499 m .45066 .54301 L .46447 .54345 L p .229 0 0 r
F P
0 g
s
.6201 .46168 m .60921 .46568 L .5867 .48457 L p 0 0 0 r
F P
0 g
s
.57869 .48692 m .5867 .48457 L .60921 .46568 L p 0 0 0 r
F P
0 g
s
.74213 .41098 m .72889 .41522 L .69785 .41477 L p .767 .96 .932 r
F P
0 g
s
.68662 .42341 m .69785 .41477 L .72889 .41522 L p .731 .977 .92 r
F P
0 g
s
.2337 .38872 m .24587 .40752 L .21957 .44935 L p .417 .464 .802 r
F P
0 g
s
.23285 .46314 m .21957 .44935 L .24587 .40752 L p .4 .459 .806 r
F P
0 g
s
.41165 .55638 m .42473 .55391 L .41394 .54926 L p .194 0 0 r
F P
0 g
s
.41394 .54926 m .39966 .5524 L .41165 .55638 L p .194 0 0 r
F P
0 g
s
.52669 .5097 m .5271 .51503 L .54587 .50241 L p .166 0 0 r
F P
0 g
s
.5271 .51503 m .52669 .5097 L .5116 .51802 L p .168 0 0 r
F P
0 g
s
.75544 .40673 m .74213 .41098 L .70912 .40559 L p .784 .932 .929 r
F P
0 g
s
.69785 .41477 m .70912 .40559 L .74213 .41098 L p .767 .96 .932 r
F P
0 g
s
.50806 .52527 m .5116 .51802 L .49745 .52368 L p .19 0 0 r
F P
0 g
s
.49745 .52368 m .49022 .53231 L .50806 .52527 L p .19 0 0 r
F P
0 g
s
.24587 .40752 m .25809 .42637 L .23285 .46314 L p .4 .459 .806 r
F P
0 g
s
.2462 .47674 m .23285 .46314 L .25809 .42637 L p .384 .459 .814 r
F P
0 g
s
.5116 .51802 m .50806 .52527 L .5271 .51503 L p .168 0 0 r
F P
0 g
s
.63105 .45701 m .6201 .46168 L .59477 .48101 L p 0 0 0 r
F P
0 g
s
.5867 .48457 m .59477 .48101 L .6201 .46168 L p 0 0 0 r
F P
0 g
s
.57869 .48692 m .57076 .48816 L .55021 .50428 L p 0 0 0 r
F P
0 g
s
.54587 .50241 m .55021 .50428 L .57076 .48816 L p .103 0 0 r
F P
0 g
s
.39853 .55664 m .41165 .55638 L .39966 .5524 L p .139 0 0 r
F P
0 g
s
.39966 .5524 m .38537 .55378 L .39853 .55664 L p .139 0 0 r
F P
0 g
s
.25809 .42637 m .27038 .44498 L .2462 .47674 L p .384 .459 .814 r
F P
0 g
s
.25964 .48991 m .2462 .47674 L .27038 .44498 L p .368 .463 .826 r
F P
0 g
s
.76881 .40245 m .75544 .40673 L .72041 .39594 L p .79 .901 .92 r
F P
0 g
s
.70912 .40559 m .72041 .39594 L .75544 .40673 L p .784 .932 .929 r
F P
0 g
s
.45385 .54945 m .46447 .54345 L .45066 .54301 L p .182 0 0 r
F P
0 g
s
.45066 .54301 m .43774 .54939 L .45385 .54945 L p .182 0 0 r
F P
0 g
s
.55021 .50428 m .54587 .50241 L .5271 .51503 L p .067 0 0 r
F P
0 g
s
.27038 .44498 m .28275 .46303 L .25964 .48991 L p .368 .463 .826 r
F P
0 g
s
.27319 .50239 m .25964 .48991 L .28275 .46303 L p .351 .472 .842 r
F P
0 g
s
.38541 .55462 m .39853 .55664 L .38537 .55378 L p .062 0 0 r
F P
0 g
s
.38537 .55378 m .37109 .55333 L .38541 .55462 L p .062 0 0 r
F P
0 g
s
.48287 .53935 m .49022 .53231 L .47497 .53562 L p .165 0 0 r
F P
0 g
s
.47497 .53562 m .46447 .54345 L .48287 .53935 L p .165 0 0 r
F P
0 g
s
.78224 .39815 m .76881 .40245 L .73175 .3859 L p .789 .871 .908 r
F P
0 g
s
.72041 .39594 m .73175 .3859 L .76881 .40245 L p .79 .901 .92 r
F P
0 g
s
.64207 .45166 m .63105 .45701 L .60291 .47616 L p .498 .879 .685 r
F P
0 g
s
.59477 .48101 m .60291 .47616 L .6236 .46208 L p 0 0 0 r
F P
0 g
s
.59477 .48101 m .6236 .46208 L .62314 .46225 L 0 0 0 r
F
.60291 .47616 m .61109 .46996 L .64207 .45166 L p .498 .879 .685 r
F P
0 g
s
.65314 .44561 m .64207 .45166 L .62574 .46131 L p .648 .963 .795 r
F P
0 g
s
.62574 .46131 m .61109 .46996 L p .62652 .46103 L .648 .963 .795 r
F P
0 g
s
.62652 .46103 m .65314 .44561 L .62574 .46131 L .648 .963 .795 r
F
.6236 .46208 m .63105 .45701 L p .62314 .46225 L 0 0 0 r
F P
0 g
s
.28275 .46303 m .29523 .48023 L .27319 .50239 L p .351 .472 .842 r
F P
0 g
s
.28686 .51395 m .27319 .50239 L .29523 .48023 L p .333 .487 .863 r
F P
0 g
s
.3723 .55027 m .38541 .55462 L .37109 .55333 L p .03 .586 .819 r
F P
0 g
s
.37109 .55333 m .35684 .55103 L .3723 .55027 L p .03 .586 .819 r
F P
0 g
s
.79573 .39382 m .78224 .39815 L .74311 .37554 L p .784 .842 .896 r
F P
0 g
s
.73175 .3859 m .74311 .37554 L .78224 .39815 L p .789 .871 .908 r
F P
0 g
s
.29523 .48023 m .30782 .49626 L .28686 .51395 L p .333 .487 .863 r
F P
0 g
s
.30065 .52437 m .28686 .51395 L .30782 .49626 L p .312 .508 .887 r
F P
0 g
s
.5867 .48457 m .57869 .48692 L .55461 .50478 L p 0 0 0 r
F P
0 g
s
.55021 .50428 m .55461 .50478 L .57869 .48692 L p 0 0 0 r
F P
0 g
s
.35924 .54361 m .3723 .55027 L .35684 .55103 L p .121 .607 .912 r
F P
0 g
s
.35684 .55103 m .34266 .5469 L .35924 .54361 L p .121 .607 .912 r
F P
0 g
s
.30782 .49626 m .32052 .51086 L .30065 .52437 L p .312 .508 .887 r
F P
0 g
s
.31455 .53344 m .30065 .52437 L .32052 .51086 L p .285 .535 .914 r
F P
0 g
s
.34624 .53473 m .35924 .54361 L .34266 .5469 L p .194 .595 .944 r
F P
0 g
s
.34266 .5469 m .32856 .541 L .34624 .53473 L p .194 .595 .944 r
F P
0 g
s
.5271 .51503 m .52752 .51895 L .55021 .50428 L p .067 0 0 r
F P
0 g
s
.52752 .51895 m .5271 .51503 L .50806 .52527 L p .066 0 0 r
F P
0 g
s
.32052 .51086 m .33333 .52375 L .31455 .53344 L p .285 .535 .914 r
F P
0 g
s
.32856 .541 m .31455 .53344 L .33333 .52375 L p .247 .566 .937 r
F P
0 g
s
.33333 .52375 m .34624 .53473 L .32856 .541 L p .247 .566 .937 r
F P
0 g
s
.44312 .55335 m .45385 .54945 L .43774 .54939 L p .112 0 0 r
F P
0 g
s
.43774 .54939 m .42473 .55391 L .44312 .55335 L p .112 0 0 r
F P
0 g
s
.50446 .53097 m .50806 .52527 L .49022 .53231 L p .103 0 0 r
F P
0 g
s
.49022 .53231 m .48287 .53935 L .50446 .53097 L p .103 0 0 r
F P
0 g
s
.80929 .38948 m .79573 .39382 L .75451 .36496 L p .776 .817 .885 r
F P
0 g
s
.74311 .37554 m .75451 .36496 L .79573 .39382 L p .784 .842 .896 r
F P
0 g
s
.50806 .52527 m .50446 .53097 L .52752 .51895 L p .066 0 0 r
F P
0 g
s
.55461 .50478 m .55021 .50428 L .52752 .51895 L p 0 0 0 r
F P
0 g
s
.82291 .38512 m .80929 .38948 L .76596 .35424 L p .766 .794 .876 r
F P
0 g
s
.75451 .36496 m .76596 .35424 L .80929 .38948 L p .776 .817 .885 r
F P
0 g
s
.66426 .43887 m .65314 .44561 L .61931 .4624 L p .753 .994 .86 r
F P
0 g
s
.61109 .46996 m .61931 .4624 L .65314 .44561 L p .648 .963 .795 r
F P
0 g
s
.47542 .54449 m .48287 .53935 L .46447 .54345 L p .073 0 0 r
F P
0 g
s
.46447 .54345 m .45385 .54945 L .47542 .54449 L p .073 0 0 r
F P
0 g
s
.59477 .48101 m .5867 .48457 L .55907 .5037 L p 0 0 0 r
F P
0 g
s
.55461 .50478 m .55907 .5037 L .5867 .48457 L p 0 0 0 r
F P
0 g
s
.8366 .38074 m .82291 .38512 L .77746 .34347 L p .756 .775 .868 r
F P
0 g
s
.76596 .35424 m .77746 .34347 L .82291 .38512 L p .766 .794 .876 r
F P
0 g
s
.43232 .55492 m .44312 .55335 L .42473 .55391 L p .007 0 0 r
F P
0 g
s
.42473 .55391 m .41165 .55638 L .43232 .55492 L p .007 0 0 r
F P
0 g
s
.67542 .43146 m .66426 .43887 L .62757 .45349 L p .815 .985 .885 r
F P
0 g
s
.61931 .4624 m .62757 .45349 L .66426 .43887 L p .753 .994 .86 r
F P
0 g
s
.77746 .34347 m .78901 .33274 L .8366 .38074 L p .756 .775 .868 r
F P
0 g
s
.52752 .51895 m .52795 .5212 L .55461 .50478 L p 0 0 0 r
F P
0 g
s
.52795 .5212 m .52752 .51895 L .50446 .53097 L p 0 0 0 r
F P
0 g
s
.50081 .53482 m .50446 .53097 L .48287 .53935 L p 0 0 0 r
F P
0 g
s
.48287 .53935 m .47542 .54449 L .50081 .53482 L p 0 0 0 r
F P
0 g
s
.68662 .42341 m .67542 .43146 L .63585 .44327 L p .844 .955 .885 r
F P
0 g
s
.62757 .45349 m .63585 .44327 L .67542 .43146 L p .815 .985 .885 r
F P
0 g
s
.55907 .5037 m .55461 .50478 L .52795 .5212 L p 0 0 0 r
F P
0 g
s
.60291 .47616 m .59477 .48101 L .56356 .5009 L p .574 .928 .753 r
F P
0 g
s
.55907 .5037 m .56356 .5009 L .59477 .48101 L p 0 0 0 r
F P
0 g
s
.42146 .554 m .43232 .55492 L .41165 .55638 L p .129 .677 .793 r
F P
0 g
s
.41165 .55638 m .39853 .55664 L .42146 .554 L p .129 .677 .793 r
F P
0 g
s
.47542 .54449 m .45385 .54945 L p .4665 .54763 L 0 0 0 r
F P
0 g
s
.45385 .54945 m .44312 .55335 L .46789 .54743 L p 0 0 0 r
F P
0 g
s
.43232 .55492 m .46029 .54794 L p .4446 .55288 L .255 .766 .793 r
F P
0 g
s
.44312 .55335 m .44194 .55352 L p .4446 .55288 L .255 .766 .793 r
F P
0 g
s
.44194 .55352 m .43232 .55492 L p .4446 .55288 L .255 .766 .793 r
F P
0 g
s
.46789 .54743 m .46878 .54708 L p .4665 .54763 L 0 0 0 r
F P
0 g
s
.46878 .54708 m .47542 .54449 L p .4665 .54763 L 0 0 0 r
F P
0 g
s
.50446 .53097 m .50081 .53482 L .52795 .5212 L p 0 0 0 r
F P
0 g
s
.69785 .41477 m .68662 .42341 L .64414 .43179 L p .854 .919 .874 r
F P
0 g
s
.63585 .44327 m .64414 .43179 L .68662 .42341 L p .844 .955 .885 r
F P
0 g
s
.2337 .38872 m .22154 .37026 L .27399 .32374 L p .501 .467 .752 r
F P
0 g
s
.41058 .55048 m .42146 .554 L .39853 .55664 L p .264 .736 .941 r
F P
0 g
s
.39853 .55664 m .38541 .55462 L .41058 .55048 L p .264 .736 .941 r
F P
0 g
s
.61109 .46996 m .60291 .47616 L .56809 .49626 L p .728 .99 .853 r
F P
0 g
s
.56356 .5009 m .56809 .49626 L .60291 .47616 L p .574 .928 .753 r
F P
0 g
s
.27399 .32374 m .28417 .34614 L .2337 .38872 L p .501 .467 .752 r
F P
0 g
s
.24587 .40752 m .2337 .38872 L .28417 .34614 L p .492 .461 .751 r
F P
0 g
s
.70912 .40559 m .69785 .41477 L .65244 .41916 L p .854 .883 .859 r
F P
0 g
s
.64414 .43179 m .65244 .41916 L .69785 .41477 L p .854 .919 .874 r
F P
0 g
s
.52795 .5212 m .52838 .52153 L .55907 .5037 L p 0 0 0 r
F P
0 g
s
.56356 .5009 m .55907 .5037 L .52838 .52153 L p .517 .905 .757 r
F P
0 g
s
.52838 .52153 m .52795 .5212 L .50081 .53482 L p .313 .776 .644 r
F P
0 g
s
.28417 .34614 m .29435 .36891 L .24587 .40752 L p .492 .461 .751 r
F P
0 g
s
.25809 .42637 m .24587 .40752 L .29435 .36891 L p .485 .458 .753 r
F P
0 g
s
.49712 .53653 m .50081 .53482 L .47542 .54449 L p 0 0 0 r
F P
0 g
s
.47542 .54449 m .46789 .54743 L .49712 .53653 L p 0 0 0 r
F P
0 g
s
.3997 .5443 m .41058 .55048 L .38541 .55462 L p .36 .722 .987 r
F P
0 g
s
.38541 .55462 m .3723 .55027 L .3997 .5443 L p .36 .722 .987 r
F P
0 g
s
.46029 .54794 m .46789 .54743 L .44312 .55335 L p .255 .766 .793 r
F P
0 g
s
.72041 .39594 m .70912 .40559 L .66075 .40549 L p .848 .85 .844 r
F P
0 g
s
.65244 .41916 m .66075 .40549 L .70912 .40559 L p .854 .883 .859 r
F P
0 g
s
.29435 .36891 m .30455 .39172 L .25809 .42637 L p .485 .458 .753 r
F P
0 g
s
.27038 .44498 m .25809 .42637 L .30455 .39172 L p .479 .459 .758 r
F P
0 g
s
.61931 .4624 m .61109 .46996 L .57265 .48969 L p .813 .984 .888 r
F P
0 g
s
.56809 .49626 m .57265 .48969 L .61109 .46996 L p .728 .99 .853 r
F P
0 g
s
.50081 .53482 m .49712 .53653 L .52838 .52153 L p .313 .776 .644 r
F P
0 g
s
.73175 .3859 m .72041 .39594 L .66907 .39091 L p .84 .822 .831 r
F P
0 g
s
.66075 .40549 m .66907 .39091 L .72041 .39594 L p .848 .85 .844 r
F P
0 g
s
.38884 .5355 m .3997 .5443 L .3723 .55027 L p .413 .672 .968 r
F P
0 g
s
.3723 .55027 m .35924 .54361 L .38884 .5355 L p .413 .672 .968 r
F P
0 g
s
.30455 .39172 m .31481 .41424 L .27038 .44498 L p .479 .459 .758 r
F P
0 g
s
.28275 .46303 m .27038 .44498 L .31481 .41424 L p .474 .464 .766 r
F P
0 g
s
.31481 .41424 m .32513 .43612 L .28275 .46303 L p .474 .464 .766 r
F P
0 g
s
.29523 .48023 m .28275 .46303 L .32513 .43612 L p .47 .473 .779 r
F P
0 g
s
.37803 .52414 m .38884 .5355 L .35924 .54361 L p .439 .617 .926 r
F P
0 g
s
.35924 .54361 m .34624 .53473 L .37803 .52414 L p .439 .617 .926 r
F P
0 g
s
.74311 .37554 m .73175 .3859 L .67739 .37559 L p .83 .797 .82 r
F P
0 g
s
.66907 .39091 m .67739 .37559 L .73175 .3859 L p .84 .822 .831 r
F P
0 g
s
.32513 .43612 m .33553 .457 L .29523 .48023 L p .47 .473 .779 r
F P
0 g
s
.30782 .49626 m .29523 .48023 L .33553 .457 L p .467 .487 .796 r
F P
0 g
s
.56809 .49626 m .56356 .5009 L .52881 .51974 L p .7 .982 .883 r
F P
0 g
s
.52838 .52153 m .52881 .51974 L .56356 .5009 L p .517 .905 .757 r
F P
0 g
s
.36728 .51039 m .37803 .52414 L .34624 .53473 L p .452 .571 .884 r
F P
0 g
s
.34624 .53473 m .33333 .52375 L .36728 .51039 L p .452 .571 .884 r
F P
0 g
s
.45264 .54583 m .46029 .54794 L .43232 .55492 L p .431 .848 .96 r
F P
0 g
s
.43232 .55492 m .42146 .554 L .45264 .54583 L p .431 .848 .96 r
F P
0 g
s
.62757 .45349 m .61931 .4624 L .57723 .48116 L p .849 .943 .882 r
F P
0 g
s
.57265 .48969 m .57723 .48116 L .61931 .4624 L p .813 .984 .888 r
F P
0 g
s
.33553 .457 m .34603 .47655 L .30782 .49626 L p .467 .487 .796 r
F P
0 g
s
.32052 .51086 m .30782 .49626 L .34603 .47655 L p .463 .507 .818 r
F P
0 g
s
.35661 .49444 m .36728 .51039 L .33333 .52375 L p .459 .535 .847 r
F P
0 g
s
.33333 .52375 m .32052 .51086 L .35661 .49444 L p .459 .535 .847 r
F P
0 g
s
.34603 .47655 m .35661 .49444 L .32052 .51086 L p .463 .507 .818 r
F P
0 g
s
.52881 .51974 m .52838 .52153 L .49712 .53653 L p .547 .93 .852 r
F P
0 g
s
.75451 .36496 m .74311 .37554 L .68572 .35968 L p .82 .776 .812 r
F P
0 g
s
.67739 .37559 m .68572 .35968 L .74311 .37554 L p .83 .797 .82 r
F P
0 g
s
.49338 .53588 m .49712 .53653 L .46789 .54743 L p .459 .887 .874 r
F P
0 g
s
.46789 .54743 m .46029 .54794 L .49338 .53588 L p .459 .887 .874 r
F P
0 g
s
.76596 .35424 m .75451 .36496 L .69407 .34335 L p .809 .759 .806 r
F P
0 g
s
.68572 .35968 m .69407 .34335 L .75451 .36496 L p .82 .776 .812 r
F P
0 g
s
.49712 .53653 m .49338 .53588 L .52881 .51974 L p .547 .93 .852 r
F P
0 g
s
.63585 .44327 m .62757 .45349 L .58182 .47069 L p .857 .894 .861 r
F P
0 g
s
.57723 .48116 m .58182 .47069 L .62757 .45349 L p .849 .943 .882 r
F P
0 g
s
.44497 .541 m .45264 .54583 L .42146 .554 L p .535 .825 .999 r
F P
0 g
s
.42146 .554 m .41058 .55048 L .44497 .541 L p .535 .825 .999 r
F P
0 g
s
.77746 .34347 m .76596 .35424 L .70243 .32679 L p .798 .744 .803 r
F P
0 g
s
.69407 .34335 m .70243 .32679 L .76596 .35424 L p .809 .759 .806 r
F P
0 g
s
.57265 .48969 m .56809 .49626 L .52925 .51567 L p .793 .966 .916 r
F P
0 g
s
.52881 .51974 m .52925 .51567 L .56809 .49626 L p .7 .982 .883 r
F P
0 g
s
.78901 .33274 m .77746 .34347 L .71083 .31015 L p .787 .732 .801 r
F P
0 g
s
.70243 .32679 m .71083 .31015 L .77746 .34347 L p .798 .744 .803 r
F P
0 g
s
.64414 .43179 m .63585 .44327 L .58642 .45833 L p .853 .848 .837 r
F P
0 g
s
.58182 .47069 m .58642 .45833 L .63585 .44327 L p .857 .894 .861 r
F P
0 g
s
.52925 .51567 m .52881 .51974 L .49338 .53588 L p .702 .961 .945 r
F P
0 g
s
.48962 .53269 m .49338 .53588 L .46029 .54794 L p .617 .919 .977 r
F P
0 g
s
.46029 .54794 m .45264 .54583 L .48962 .53269 L p .617 .919 .977 r
F P
0 g
s
.43728 .53338 m .44497 .541 L .41058 .55048 L p .576 .756 .964 r
F P
0 g
s
.41058 .55048 m .3997 .5443 L .43728 .53338 L p .576 .756 .964 r
F P
0 g
s
.71083 .31015 m .71927 .29362 L .78901 .33274 L p .787 .732 .801 r
F P
0 g
s
.65244 .41916 m .64414 .43179 L .59102 .44417 L p .845 .809 .815 r
F P
0 g
s
.58642 .45833 m .59102 .44417 L .64414 .43179 L p .853 .848 .837 r
F P
0 g
s
.57723 .48116 m .57265 .48969 L .52969 .50923 L p .824 .908 .897 r
F P
0 g
s
.52925 .51567 m .52969 .50923 L .57265 .48969 L p .793 .966 .916 r
F P
0 g
s
.49338 .53588 m .48962 .53269 L .52925 .51567 L p .702 .961 .945 r
F P
0 g
s
.4296 .52299 m .43728 .53338 L .3997 .5443 L p .586 .688 .911 r
F P
0 g
s
.3997 .5443 m .38884 .5355 L .4296 .52299 L p .586 .688 .911 r
F P
0 g
s
.66075 .40549 m .65244 .41916 L .59561 .42835 L p .835 .777 .796 r
F P
0 g
s
.59102 .44417 m .59561 .42835 L .65244 .41916 L p .845 .809 .815 r
F P
0 g
s
.48585 .52685 m .48962 .53269 L .45264 .54583 L p .681 .86 .967 r
F P
0 g
s
.45264 .54583 m .44497 .541 L .48585 .52685 L p .681 .86 .967 r
F P
0 g
s
.28417 .34614 m .27399 .32374 L .34782 .287 L p .57 .489 .724 r
F P
0 g
s
.52969 .50923 m .52925 .51567 L .48962 .53269 L p .763 .907 .939 r
F P
0 g
s
.34782 .287 m .35511 .31188 L .28417 .34614 L p .57 .489 .724 r
F P
0 g
s
.29435 .36891 m .28417 .34614 L .35511 .31188 L p .567 .485 .722 r
F P
0 g
s
.58182 .47069 m .57723 .48116 L .53013 .50036 L p .826 .847 .863 r
F P
0 g
s
.52969 .50923 m .53013 .50036 L .57723 .48116 L p .824 .908 .897 r
F P
0 g
s
.42194 .50992 m .4296 .52299 L .38884 .5355 L p .586 .632 .864 r
F P
0 g
s
.38884 .5355 m .37803 .52414 L .42194 .50992 L p .586 .632 .864 r
F P
0 g
s
.66907 .39091 m .66075 .40549 L .6002 .41106 L p .825 .75 .781 r
F P
0 g
s
.59561 .42835 m .6002 .41106 L .66075 .40549 L p .835 .777 .796 r
F P
0 g
s
.35511 .31188 m .36238 .33711 L .29435 .36891 L p .567 .485 .722 r
F P
0 g
s
.30455 .39172 m .29435 .36891 L .36238 .33711 L p .566 .484 .722 r
F P
0 g
s
.48962 .53269 m .48585 .52685 L .52969 .50923 L p .763 .907 .939 r
F P
0 g
s
.36238 .33711 m .36967 .36237 L .30455 .39172 L p .566 .484 .722 r
F P
0 g
s
.31481 .41424 m .30455 .39172 L .36967 .36237 L p .565 .487 .725 r
F P
0 g
s
.41432 .49432 m .42194 .50992 L .37803 .52414 L p .582 .589 .825 r
F P
0 g
s
.37803 .52414 m .36728 .51039 L .41432 .49432 L p .582 .589 .825 r
F P
0 g
s
.67739 .37559 m .66907 .39091 L .60479 .39248 L p .815 .729 .77 r
F P
0 g
s
.6002 .41106 m .60479 .39248 L .66907 .39091 L p .825 .75 .781 r
F P
0 g
s
.36967 .36237 m .37699 .38729 L .31481 .41424 L p .565 .487 .725 r
F P
0 g
s
.32513 .43612 m .31481 .41424 L .37699 .38729 L p .565 .492 .731 r
F P
0 g
s
.48206 .5183 m .48585 .52685 L .44497 .541 L p .695 .783 .919 r
F P
0 g
s
.44497 .541 m .43728 .53338 L .48206 .5183 L p .695 .783 .919 r
F P
0 g
s
.40674 .4764 m .41432 .49432 L .36728 .51039 L p .577 .557 .795 r
F P
0 g
s
.36728 .51039 m .35661 .49444 L .40674 .4764 L p .577 .557 .795 r
F P
0 g
s
.37699 .38729 m .38435 .41152 L .32513 .43612 L p .565 .492 .731 r
F P
0 g
s
.33553 .457 m .32513 .43612 L .38435 .41152 L p .567 .501 .741 r
F P
0 g
s
.58642 .45833 m .58182 .47069 L .53058 .48908 L p .817 .793 .83 r
F P
0 g
s
.53013 .50036 m .53058 .48908 L .58182 .47069 L p .826 .847 .863 r
F P
0 g
s
.53013 .50036 m .52969 .50923 L .48585 .52685 L p .774 .833 .898 r
F P
0 g
s
.68572 .35968 m .67739 .37559 L .60936 .37285 L p .806 .711 .761 r
F P
0 g
s
.60479 .39248 m .60936 .37285 L .67739 .37559 L p .815 .729 .77 r
F P
0 g
s
.39922 .45641 m .40674 .4764 L .35661 .49444 L p .573 .532 .772 r
F P
0 g
s
.35661 .49444 m .34603 .47655 L .39922 .45641 L p .573 .532 .772 r
F P
0 g
s
.38435 .41152 m .39176 .43467 L .33553 .457 L p .567 .501 .741 r
F P
0 g
s
.34603 .47655 m .33553 .457 L .39176 .43467 L p .569 .514 .754 r
F P
0 g
s
.39176 .43467 m .39922 .45641 L .34603 .47655 L p .569 .514 .754 r
F P
0 g
s
.69407 .34335 m .68572 .35968 L .61393 .3524 L p .797 .697 .755 r
F P
0 g
s
.60936 .37285 m .61393 .3524 L .68572 .35968 L p .806 .711 .761 r
F P
0 g
s
.48585 .52685 m .48206 .5183 L .53013 .50036 L p .774 .833 .898 r
F P
0 g
s
.59102 .44417 m .58642 .45833 L .53102 .47547 L p .806 .751 .801 r
F P
0 g
s
.53058 .48908 m .53102 .47547 L .58642 .45833 L p .817 .793 .83 r
F P
0 g
s
.47827 .50706 m .48206 .5183 L .43728 .53338 L p .691 .717 .869 r
F P
0 g
s
.43728 .53338 m .4296 .52299 L .47827 .50706 L p .691 .717 .869 r
F P
0 g
s
.70243 .32679 m .69407 .34335 L .6185 .33138 L p .788 .686 .752 r
F P
0 g
s
.61393 .3524 m .6185 .33138 L .69407 .34335 L p .797 .697 .755 r
F P
0 g
s
.53058 .48908 m .53013 .50036 L .48206 .5183 L p .767 .769 .854 r
F P
0 g
s
.71083 .31015 m .70243 .32679 L .62308 .31005 L p .78 .678 .751 r
F P
0 g
s
.6185 .33138 m .62308 .31005 L .70243 .32679 L p .788 .686 .752 r
F P
0 g
s
.59561 .42835 m .59102 .44417 L .53146 .45964 L p .794 .717 .778 r
F P
0 g
s
.53102 .47547 m .53146 .45964 L .59102 .44417 L p .806 .751 .801 r
F P
0 g
s
.47448 .4932 m .47827 .50706 L .4296 .52299 L p .681 .664 .827 r
F P
0 g
s
.4296 .52299 m .42194 .50992 L .47448 .4932 L p .681 .664 .827 r
F P
0 g
s
.71927 .29362 m .71083 .31015 L .62766 .28866 L p .772 .672 .753 r
F P
0 g
s
.62308 .31005 m .62766 .28866 L .71083 .31015 L p .78 .678 .751 r
F P
0 g
s
.48206 .5183 m .47827 .50706 L .53058 .48908 L p .767 .769 .854 r
F P
0 g
s
.62766 .28866 m .63227 .26744 L .71927 .29362 L p .772 .672 .753 r
F P
0 g
s
.53102 .47547 m .53058 .48908 L .47827 .50706 L p .755 .717 .817 r
F P
0 g
s
.6002 .41106 m .59561 .42835 L .5319 .44177 L p .784 .69 .76 r
F P
0 g
s
.53146 .45964 m .5319 .44177 L .59561 .42835 L p .794 .717 .778 r
F P
0 g
s
.47071 .47688 m .47448 .4932 L .42194 .50992 L p .671 .625 .794 r
F P
0 g
s
.42194 .50992 m .41432 .49432 L .47071 .47688 L p .671 .625 .794 r
F P
0 g
s
.60479 .39248 m .6002 .41106 L .53234 .42207 L p .775 .669 .746 r
F P
0 g
s
.5319 .44177 m .53234 .42207 L .6002 .41106 L p .784 .69 .76 r
F P
0 g
s
.47827 .50706 m .47448 .4932 L .53102 .47547 L p .755 .717 .817 r
F P
0 g
s
.46696 .45828 m .47071 .47688 L .41432 .49432 L p .662 .595 .769 r
F P
0 g
s
.41432 .49432 m .40674 .4764 L .46696 .45828 L p .662 .595 .769 r
F P
0 g
s
.35511 .31188 m .34782 .287 L .43754 .26392 L p .633 .523 .711 r
F P
0 g
s
.43754 .26392 m .4412 .28949 L .35511 .31188 L p .633 .523 .711 r
F P
0 g
s
.36238 .33711 m .35511 .31188 L .4412 .28949 L p .633 .521 .709 r
F P
0 g
s
.53146 .45964 m .53102 .47547 L .47448 .4932 L p .743 .678 .787 r
F P
0 g
s
.4412 .28949 m .44485 .31538 L .36238 .33711 L p .633 .521 .709 r
F P
0 g
s
.36967 .36237 m .36238 .33711 L .44485 .31538 L p .635 .522 .709 r
F P
0 g
s
.60936 .37285 m .60479 .39248 L .53278 .40082 L p .766 .652 .736 r
F P
0 g
s
.53234 .42207 m .53278 .40082 L .60479 .39248 L p .775 .669 .746 r
F P
0 g
s
.46322 .43767 m .46696 .45828 L .40674 .4764 L p .655 .572 .749 r
F P
0 g
s
.40674 .4764 m .39922 .45641 L .46322 .43767 L p .655 .572 .749 r
F P
0 g
s
.44485 .31538 m .44849 .34125 L .36967 .36237 L p .635 .522 .709 r
F P
0 g
s
.37699 .38729 m .36967 .36237 L .44849 .34125 L p .637 .526 .711 r
F P
0 g
s
.45951 .41533 m .46322 .43767 L .39922 .45641 L p .649 .554 .734 r
F P
0 g
s
.39922 .45641 m .39176 .43467 L .45951 .41533 L p .649 .554 .734 r
F P
0 g
s
.44849 .34125 m .45215 .36677 L .37699 .38729 L p .637 .526 .711 r
F P
0 g
s
.38435 .41152 m .37699 .38729 L .45215 .36677 L p .64 .532 .716 r
F P
0 g
s
.45215 .36677 m .45582 .39158 L .38435 .41152 L p .64 .532 .716 r
F P
0 g
s
.39176 .43467 m .38435 .41152 L .45582 .39158 L p .644 .541 .723 r
F P
0 g
s
.45582 .39158 m .45951 .41533 L .39176 .43467 L p .644 .541 .723 r
F P
0 g
s
.47448 .4932 m .47071 .47688 L .53146 .45964 L p .743 .678 .787 r
F P
0 g
s
.61393 .3524 m .60936 .37285 L .53321 .37828 L p .759 .639 .729 r
F P
0 g
s
.53278 .40082 m .53321 .37828 L .60936 .37285 L p .766 .652 .736 r
F P
0 g
s
.5319 .44177 m .53146 .45964 L .47071 .47688 L p .733 .647 .764 r
F P
0 g
s
.6185 .33138 m .61393 .3524 L .53365 .35476 L p .752 .629 .724 r
F P
0 g
s
.53321 .37828 m .53365 .35476 L .61393 .3524 L p .759 .639 .729 r
F P
0 g
s
.47071 .47688 m .46696 .45828 L .5319 .44177 L p .733 .647 .764 r
F P
0 g
s
.62308 .31005 m .6185 .33138 L .53408 .33058 L p .746 .622 .722 r
F P
0 g
s
.53365 .35476 m .53408 .33058 L .6185 .33138 L p .752 .629 .724 r
F P
0 g
s
.53234 .42207 m .5319 .44177 L .46696 .45828 L p .723 .623 .746 r
F P
0 g
s
.62766 .28866 m .62308 .31005 L .53452 .30604 L p .74 .617 .722 r
F P
0 g
s
.53408 .33058 m .53452 .30604 L .62308 .31005 L p .746 .622 .722 r
F P
0 g
s
.46696 .45828 m .46322 .43767 L .53234 .42207 L p .723 .623 .746 r
F P
0 g
s
.53278 .40082 m .53234 .42207 L .46322 .43767 L p .715 .605 .732 r
F P
0 g
s
.63227 .26744 m .62766 .28866 L .53495 .28147 L p .735 .615 .724 r
F P
0 g
s
.53452 .30604 m .53495 .28147 L .62766 .28866 L p .74 .617 .722 r
F P
0 g
s
.46322 .43767 m .45951 .41533 L .53278 .40082 L p .715 .605 .732 r
F P
0 g
s
.53495 .28147 m .53539 .25714 L .63227 .26744 L p .735 .615 .724 r
F P
0 g
s
.53321 .37828 m .53278 .40082 L .45951 .41533 L p .709 .591 .722 r
F P
0 g
s
.45951 .41533 m .45582 .39158 L .53321 .37828 L p .709 .591 .722 r
F P
0 g
s
.53365 .35476 m .53321 .37828 L .45582 .39158 L p .703 .58 .715 r
F P
0 g
s
.45582 .39158 m .45215 .36677 L .53365 .35476 L p .703 .58 .715 r
F P
0 g
s
.53408 .33058 m .53365 .35476 L .45215 .36677 L p .698 .573 .71 r
F P
0 g
s
.45215 .36677 m .44849 .34125 L .53408 .33058 L p .698 .573 .71 r
F P
0 g
s
.53539 .25714 m .53495 .28147 L .4412 .28949 L p .687 .565 .711 r
F P
0 g
s
.4412 .28949 m .43754 .26392 L .53539 .25714 L p .687 .565 .711 r
F P
0 g
s
.44485 .31538 m .4412 .28949 L .53495 .28147 L p .69 .565 .709 r
F P
0 g
s
.53495 .28147 m .53452 .30604 L .44485 .31538 L p .69 .565 .709 r
F P
0 g
s
.44849 .34125 m .44485 .31538 L .53452 .30604 L p .694 .568 .708 r
F P
0 g
s
.53452 .30604 m .53408 .33058 L .44849 .34125 L p .694 .568 .708 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojn@]P03o`00
0?nlWKWo_9fi00?o_9fi2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?n_T;H00ol0003o_9fi
okbM^@0>okbM^@_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nRQKH00ol0003o[i2fojn@
]P0Mojn@]P03o`000?nlWKWo_9fi01Wo_9fi1ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001_nRQKH00ol0003o[i2fojn@]P0Mojn@]P03o`000?nlWKWo_9fi01go_9fi00?o0000
olF/`?o5[<000ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool0
02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002OnRQKH00ol0
003o[i2fojn@]P0Mojn@]P03o`000?nlWKWo_9fi01go_9fi00?o0000olF/`?o5[<000oo5[<03o`00
00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Ko
oooo00?o0000ooooooooool0IOooool4o`0000goXXFf00?o0000ojn@]_n_T;H07On_T;H00ol0003o
_9fiokbM^@0LokbM^@03o`000?o5[<3oaJc000OoaJc00ol0000:ooooo`03o`000?oooooooooo03;o
oooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo
1?l0000Boj:5]P03o`000?n_T;Ko[i2f01co[i2f00?o0000okbM^OnlWKT07?nlWKT00ol0003oaJc0
olF/`00:olF/`0?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0001Ko
XXFf00?o0000ojn@]_n_T;H05on_T;H6o`0000;o_9fi1_l0000FokbM^@03o`000?o5[<3oaJc000go
aJc00ol00005ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool4o`0001WoXXFf00?o0000ojn@]_n_
T;H03?n_T;H;o`0000Go/92e00?o0000okfM^?nmWKP01_nmWKP?o`0000Ko_9fi00?o0000olF/`?o5
[<004Oo5[<03o`0000;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`00
2Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000;ooooo`03o`000?oooooooooo05?ooooo0ol0000Moj:5]P03o`000?n_T;Ko[i2f00;o
[i2f2_l0000@ok2@]@03o`000?nmWKSo_Ifh01Go_Ifh1ol0000FolF/`0?o0000=_ooool00ol0003o
ooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo0_l000000onAOKWo
0000oj:5]P0Koj:5]POo00006_n`T;D00ol0003o_IfhokfM^00KokfM^003o`000?o7[L3oajg000Co
00004_o5[<04o`0003Cooooo00?o0000ooooooooool0:?ooool0017ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo04gooooo0_l00004oi5m^@03o`000?nRQKKoXXFf01GoXXFf1?l00002oj:5
]@03o`000?n`T;Go/92e01co/92e00?o0000okfM^?nmWKP06onmWKP00ol0003oajg0olN]`004olN]
`0Co00003_o5[<001?l0003oaJc0olF/`?o5[<03o`00037ooooo0_l0000Yooooo`004Oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04[ooooo0_l00006oi5m^@03o`000?nRQKKoXXFf017oXXFf1?l00006
oj:5]@03o`000?n`T;Go/92e01co/92e00?o0000okfM^?nmWKP06onmWKP00ol0003oajg0olN]`008
olN]`0Co00002_o5[<000ol0003oaJc0olF/`002olF/`004o`000?o9^lgo0000o`0002oooooo0_l0
000Yooooo`004Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool2o`00013ooooo00?o0000ooooooooool0Aoooool2o`0000SoTGfi00?o0000oj:5]_nRQKH03OnR
QKH4o`0000[oXXFe00?o0000ok2@]On`T;D07?n`T;D00ol0003o_IfhokfM^00JokfM^003o`000?o7
[L3oajg000goajg01?l00006olF/`005o`000?o5[<3oaJc0olF/`?l000001?o9^ld00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02Kooooo000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool2o`0004Gooooo0_l0000;oi5m^@03o`00
0?nRQKKoXXFf00SoXXFf1?l0000>oj:5]@03o`000?n`T;Go/92e01co/92e00?o0000okfM^?nmWKP0
6_nmWKP00ol0003oajg0olN]`00AolN]`0Co000000?oaJc0o`000?l000000oo5[<000ol0003obK_=
olVkc@03olVkc@;o0000;_ooool00ol0003oooooooooo`0Vooooo`00:_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo043ooooo0_l0000=oi5m^@03o`000?nRQKKoXXFf00CoXXFf1?l0
000Coj:5]@03o`000?n`T;Go/92e01Ko/92e1_l00002okfM^0go00003OnmWKP00ol0003oajg0olN]
`00ColN]`0Ko00000_o5[<000ol0003obK_=olVkc@05olVkc@;o0000;Oooool00ol0003ooooooooo
o`0Uooooo`00:_ooool2o`0001Gooooo00?o0000ooooooooool0?Oooool2o`0000ooTGfi00?o0000
oj:5]_nRQKH01?l0000Goj:5]@03o`000?n`T;Go/92e00co/92e2_l00005ok6A]@03o`000?nnWkSo
_Ynh00go_Ynh3_l0000BolN]`0?o00001Oo7[L03o`0000[obK_=0_l0000/ooooo`03o`000?oooooo
oooo02Cooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool2o`00
017oTGfi0ol0000Koj:5]@03o`000?n`T;Go/92e00;o/92e2_l0000?ok6A]@03o`000?nnWkSo_Ynh
01[o_Ynh00?o0000olV_`?o9[l001Ol00008olN]`0?o00002Oo7[L02o`000003olbncOl0003obK_=
00WobK_=0_l0000Zooooo`;o00009Oooool002[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0gooooo`;o00004OnAOKT2o`000003oi5l^?l0003oXXFe01WoXXFe1ol0000Iok6A]@03
o`000?nnWkSo_Ynh01[o_Ynh00?o0000olV_`?o9[l001Oo9[l04o`000004olN]`?l0003o0000o`00
00coajg00_l00003olbnc@;o00002Oo9^ld00ol0003oooooooooo`0Wooooo`;o00002?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01ooo
ool002[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00004OnAOKT2
o`0000?oTGbh00?o0000oj:5]OnRQKD05?nRQKD4o`0000;oXXFe00?o0000ok6A]OnaTKD06onaTKD0
0ol0003o_YnhokjO^00IokjO^003o`000?o9[l3obJo000SobJo01_l0000<olN]`0;o00001Oo<_/d2
o`0000SobK_=0_l0000Xooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`06ooooo`00:_ooool2o`0001Wooooo00?o0000
ooooooooool0<Oooool2o`00013oTGfi0ol00006oi5l^003o`000?nRQKGoXXFe00ooXXFe1?l00006
oj:5]@03o`000?naTKGo/I6e01[o/I6e00?o0000okjO^?nnWkP06_nnWkP00ol0003obJo0olV_`005
olV_`0?o00001_o9[l05o`0000Koajg000Co0000olbncOo<_/go00001_o<_/d2o`0000SobK_=0_l0
000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Gooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;_oo
ool2o`00013oTGfi0_l00009oi5l^003o`000?nRQKGoXXFe00_oXXFe1?l0000:oj:5]@03o`000?na
TKGo/I6e01[o/I6e00?o0000okjO^?nnWkP06_nnWkP00ol0003obJo0olV_`002olV_`0?o00003_o9
[l04o`0000;oajg000Go0000olbncOo<_/goc;k=o`000007olbnc@;o00002?o9^ld2o`0002Kooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0/ooooo`03o`00
0?n0Ml3o000000koTGfi0_l0000;oi5l^003o`000?nRQKGoXXFe00SoXXFe0ol0000>oj:5]@03o`00
0?naTKGo/I6e01[o/I6e00?o0000okjO^?nnWkP06OnnWkP00ol0003obJo0olV_`003o`0001GobJo0
0_l00005olbnc@03o`000?o<_/goc;k=00Koc;k=00?o0000olVkcOo9^ld01oo9^ld00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01oooool002Wooooo0ol0000Looooo`03o`000?oooooooooo02[o
oooo00Go0000oh1g`?n0Ml3oP7O0o`00000;oi5m^@;o00003OnAO;P00ol0003oXXFeoj:5]@04oj:5
]@Co00004_nRQKD00ol0003o/I6eok6A]@0Fok6A]@Co000000?o_Ynho`000?l000006ol0000IolV_
`003o`000?o?`/ko000000?oc;k=00?o0000olbncOo<_/d01oo<_/d2o`0000SobK_=0_l0000Toooo
o`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Wooooo000Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:?ooool00ol0
003oP7O0oh1g`002oh1g`003o`000?nAOKWoTGfi00OoTGfi0_l0000@oi5l^003o`000?nRQKGo0000
00?o00005_nRQKD00ol0003o/I6eok6A]@0?ok6A]@Oo00000onbT[D00ol0003o`:6iol2Q^@0Fol2Q
^@Co00000oo<//46o`00017obJo000?o0000olo2c_o?`/h00oo?`/h3o`0000[oc;k=0_l00008olVk
c@03o`000?oooooooooo023ooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
02Kooooo00?o0000oh1g`?n0Ml001?n0Ml000ol0003oTGfioi5m^@03oi5m^@?o00004OnAO;P3o`00
01[oXXFe00?o0000ok6A]OnaTKD02?naTKD7o`0000[o/Y:e00?o0000ol2Q^Oo0XKT04oo0XKT3o`00
00?o`:6i00?o0000olbb`Oo<//401oo<//47o`0000WobJo000?o0000olo2c_o?`/h01_o?`/h2o`00
00_oc;k=0_l00004olVkc@04o`000?o1a]ko`LKNo`0002?ooooo00?o0000ooooooooool00_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?n0Ml3oP7O000GoP7O0
00Co0000oi5m^OnAOKWoTGfi0_l0000Boi5l^0;o000000?oT7^ho`000?nRQKD06_nRQKD01?l0003o
/I6eok6A]OnaTKD7o`00017o/Y:e00?o0000ol2Q^Oo0XKT04?o0XKT3o`0000Ko`:6i00?o0000olbb
`Oo<//403_o<//46o`0000?obJo000?o0000olo2c_o?`/h02?o?`/h3o`0000[oc;k=0_l000000oo9
^lgo0000ol76gP03ol76gP03o`000?oooooooooo027ooooo00?o0000ooooooooool07_ooool000Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`00027ooooo00?o0000ooooooooool08_ooool0
0ol0003oP7O0oh1g`006oh1g`004o`000?nAOKWo0000o`0001;oTGbh0_l00003oi1k^003o`000?nR
QKGoXXFe01OoXXFe1_l0000Hok:B]@03o`000?o0XKWo`:6i00ko`:6i0_l00008ol2Q^@03o`000?o<
//7oc;;101Goc;;10ol0000;olo2cP03o`000?o?`/kocl;>00;o00002_o<_/d00ol0003o`LKNol76
gP04ol76gP03o`000?oooooooooo027ooooo00?o0000ooooooooool07Oooool000Co00000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07oooool2o`0000WoP7O00_l0
000Boi5l^0;o00001_n@NkP00ol0003oXXFeoj:5]@0Aoj:5]@Go00000_nSQ[H00ol0003o/Y:eok:B
]@0Iok:B]@03o`000?o0XKWo`:6i00_o`:6i0ol0000:ol2Q^@03o`000?o<//7oc;;101Ooc;;100Co
0000om76col0003o00002Oo?`/h01?l0003ocl;>olo2c_o?`/h2o`0000Soc;k=00?o0000olC;h?o1
a]h01Oo1a]h00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo0006ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?n0Ml3oP7O000So
P7O000?o0000ogef`?l000004?nAO;P2o`0000SoT7^h00?o0000oj:5]OnRQKD03OnRQKD4o`0000Oo
XhJf00?o0000ok:B]OnbT[D06OnbT[D00ol0003o`:6iol2Q^@08ol2Q^@?o00003Oo0XKT00ol0003o
c;;1olbb`@0Folbb`@03o`000?oAa/oodLK?00?odLK?0ol00006olo2cP03o`000?o?`/kocl;>00;o
cl;>0ol00004olbnc@04o`000?o4bn3oa<_PolC;h0Ko`LKN00?o0000ooooooooool08?ooool2o`00
01gooooo0006ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`03oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Tooooo`;o00007?ooool0
0ol0003oP7O0oh1g`008oh1g`005o`000?mmM/3oOGK0ogef`?l000003OnAO;P2o`0000[oT7^h00?o
0000oj:5]OnRQKD02OnRQKD4o`0000coXhJf00?o0000ok:B]OnbT[D06?nbT[D00ol0003o`:6iol2Q
^@05ol2Q^@?o00000oo0XKT>o`0000?oc;;100?o0000olbb`Oo<//404_o<//400ol0003odLK?om76
c`06om76c`?o00001?o?`/h00ol0003ocl;>olo2cP04olo2cP;o000000?oc;k=o`000?o4bn001?o4
bn000ol0003o`LKNol76gP03ol76gP03o`000?oooooooooo01kooooo00?o0000ooooool000007Ooo
ool000Kooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool2o`0002Oooooo00?o0000ooooooooool06?ooool00ol0003oP7O0oh1g
`008oh1g`003o`000?mmM/3oOGK000;oOGK000?o0000oi5l^?nAO;P02OnAO;P2o`0000coT7^h00?o
0000oj:5]OnRQKD01?nRQKD5o`00013oXhJf00?o0000ok:B]OnbT[D05OnbT[D4o`000003ol2Q^Ol0
003o000000[o00003Oo2XkX00ol0003oc[K2oljf`P02oljf`PSo00002oo<//400ol0003odLK?om76
c`0:om76c`?o000000?ocl;>o`000?o?`/h01oo?`/h00ol0003oa<_PolC;h005olC;h003o`000?o1
a]ko`LKN00?o`LKN00?o0000ooooooooool07oooool00ol0003oooooooooo`0Kooooo`001_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Fooooo`03o`00
0?n0Ml3oP7O000SoP7O000?o0000ogef`?mmM/001?mmM/000ol0003oTGbhoi5l^006oi5l^0;o0000
3on@NkP00ol0003oXXFeo`000003o`0001GoXhJf00?o0000ok:B]OnbT[D03_nbT[D7o`0000?o/iBg
00?o0000ol:S^_l000000_l0000Fol:S^P03o`000?o>]/;oc[K200[oc[K21ol00004olbb`@03o`00
0?oAa/oodLK?00godLK?0ol00005olo2cP04o`000?o6dN;oa]7RolKAhPOoa<_P00?o0000ol76g_o1
a]h00oo1a]h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo0006ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool00ol0003oP7O0oh1g`008oh1g
`003o`000?mmM/3oOGK000GoOGK000?o0000oi5l^?nAO;P01?nAO;P2o`00013oT7^h0ol0000Ioj>6
]P03o`000?nbT[Go/Y:e00So/Y:e1_l00009ok>D]`?o00006?o2XkX00ol0003oc[K2oljf`P0Boljf
`PCo00004ooAa/l3o`000003olo2c_l0003oa]7R00Coa]7R00?o0000olC;h?o4bn001?o4bn000ol0
003o`LKNol76gP03ol76gP03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool002Oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Booooo`03o`000?n0Ml3oP7O000So
P7O000?o0000ogef`?mmM/001ommM/001?l0003oTGbhoi5l^?nAO;P2o`00013oT7^h0_l000000on@
O;Wo0000oj>6]P0Joj>6]P03o`000?nbT[Go/Y:e00Oo00003?ncU;L3o`000003ok>D]ol0003o`Z>j
01So`Z>j00?o0000oljf`_o>]/805Oo>]/800ol0003oe<cAomC<d@04o`0000godLK?00Co0000om76
cooAa/oo00001oo6dN800ol0003oa<_PolC;h004olC;h003o`000?o1a]ko`LKN00?o`LKN00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000oooo
ooooool04?ooool00ol0003oP7O0oh1g`007oh1g`0;o00002_mmM/001?l0003oTGbho`000?l0000@
oi1k^0;o00001?n@O;T00ol0003oXhJfoj>6]P0Foj>6]PGo00004?ncU;L3o`0000Co/iBg00?o0000
ol:S^_o2XkX05oo2XkX00ol0003oc[K2oljf`P0Doljf`P03o`000?oDc=7oe<cA00Goe<cA1?l0000:
om76c`;o00000_o8enD7olKAhP;o00001Oo4bn000ol0003o`LKNol76gP03ol76gP03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06?ooool002Oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0>ooooo`03o`000?n0Ml3oP7O000OoP7O000?o0000ogef`?mmM/002_mmM/02o`00
013oT7^h0_l00006oi1l^@03o`000?nSQ[KoXhJf01?oXhJf0ol00002oj>8]`03o`000?ncU;Oo/iBg
00go/iBg0ol00007ok>D]`03o`000?o2Xk[o`Z>j01Ko`Z>j00?o0000oljf`_o>]/805Oo>]/800ol0
003oe<cAomC<d@09omC<d@?o00001ooAa/l2o`0000?ob=OU00?o0000olKAh_o6dN801Oo6dN800ol0
003oa<_PolC;h003olC;h003o`000?o1a]ko`LKN00?o`LKN00?o0000ooooooooool07?ooool2o`00
01[ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003o
P7O0oh1g`006oh1g`003o`000?mmM/3oOGK000[oOGK000?o0000ogae`?l000003_n@NkP2o`0000So
T7bi00?o0000oj>6]_nSQ[H03onSQ[H4o`0000GoXhRg00?o0000ok>D]oncU;L02_ncU;L3o`0000[o
/iBg00?o0000ol:S^_o2XkX04?o2XkX7o`0000;oc[K22_l0000;oljf`P03o`000?oDc=7oe<cA00co
e<cA1?l00002om76c`04o`000?o8enGob=OUo`0000?ob=OU0_l00006olKAhP03o`000?o4bn3oa<_P
00?oa<_P00?o0000ol76g_o1a]h00oo1a]h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Oooooo000Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool00ol0003o
KgW<o`000006oh1g`003o`000?mmM/3oOGK000[oOGK000Go0000ogae`?mlML3oO7G0o`00000:oi1k
^0?o00002on@O;T00ol0003oXhJfoj>6]P0:oj>6]PCo00002OnSR;L00ol0003o/iBgok>D]`07ok>D
]`?o00003OncU;L00ol0003o`Z>jol:S^P03ol:S^Pgo00001_o4Y[`00ol0003od;[5om2ja@0:om2j
a@_o00004ooDc=42o`0000?ob=OU00?o0000olSGiOo8enD00oo8enD00ol0003oa]7RolKAhP04olKA
hP;o00001?o4bn000ol0003o`LKNol76gP03ol76gP03o`000?oooooooooo01gooooo00?o0000oooo
ooooool05_ooool002Oooooo0_l0000`ooooo`03o`000?oooooooooo00[ooooo00Co0000ofmic?m_
NLco00001?n0Ml000ol0003oOGK0ogef`009ogef`0;o00001?mlML000ol0003oT7^hoi1k^006oi1k
^0;o00003_n@O;T00ol0003oXhJfoj>6]P07oj>6]P?o00003OnSR;L00ol0003o/iBgok>D]`04ok>D
]`?o00003OncU;L4o`000003ol:S^_l0003o000000;o00004oo4Y[`00ol0003od;[5om2ja@0Dom2j
a@04o`000?oGd]Coem;DomOBe0Ko00002OoDc=401?l0003obMkXolWNj?o9g^P3olSGi@03o`000?o8
enGob=OU00?ob=OU00?o0000olKAh_o6dN801Oo6dN800ol0003oa<_PolC;h002olC;h003o`000?o1
a]ko`LKN00?o`LKN00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`009_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00Go0000ofmic?m_NLcoKgW<o`00
0003oh1g`003o`000?mmM/3oOGK000WoOGK000?o0000ogae`?mlML001OmlML000ol0003oT7^hoi1k
^003oi1k^0;o00004?n@O;T00ol0003oXhJfoj>6]P03oj>6]PCo00004OnSR;L01?l0003o/iBgok>D
]oncU;L2o`0000[o/iBg1_l00003okFG^003o`000?o4Y[coa:Jl01Koa:Jl00?o0000om2jaOo@^/D0
4oo@^/D00ol0003oem;DomOBe008omOBe0Go00000ooDc=400ol0003obMkXolWNj004olWNj003o`00
0?o8enGo000000Gob=OU00?o0000olKAh_o6dN801Oo6dN800ol0003oa<_PolC;h002olC;h004o`00
0?o1a]ko`LKNol76gP?o00007_ooool00ol0003oooooooooo`0Eooooo`009_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Oooooo00?o0000ofmic?m_NL`00_m_NL`00ol0003oP7O0
o`00000;ogef`003o`000?mlML3oO7G000KoO7G000Co0000oi1k^?n@NkSoT7^h0_l0000Coi1l^@03
o`000?nSQ[Ko000000;o00005OnSR;L4o`0000Go/iBg1ol00009okFG^003o`000?o4Y[coa:Jl01Go
a:Jl00?o0000om2jaOo@^/D04oo@^/D00ol0003oem;DomOBe00>omOBe0?o00002Oo9g^P2o`0000Go
b=OU0_l00006olKAhP03o`000?o4bn3oa<_P00Go00000_nW`>/00ol0003oooooooooo`0Looooo`;o
00005_ooool002Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`03o`00
0?m_NLcoKgW<00CoKgW<00?o0000ogef`?mmM/002?mmM/02o`0000WoO7G000Co0000oi1k^?l0003o
00005?n@O;T3o`0001KoXhRg0ol00002ok>D]`Ko00004?neUkP00ol0003oa:JlolBV_00EolBV_003
o`000?o@^/God;[501?od;[500?o0000omOBe?oGd]@04?oGd]@00ol0003ob^K[o`000008olWNj0;o
00001_o8enD00ol0003oa]7RolKAhP03olKAhP?o00000_nWaNl6ojO0j`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05?ooool002Kooooo0ol0000dooooo`03o`000?oooooooooo00Cooooo
00?o0000ofmic?m_NL`01?m_NL`00ol0003oOGK0ogef`007ogef`003o`000?mlML3oO7G000WoO7G0
0_l0000Coi1l^@?o000000?oT7fko`000?nSR;L04onSR;L8o`0001Ko]INh00?o0000olBV_?o4Y[`0
4Oo4Y[`5o`000003om2jaOl0003o000001;o00004_oGd]@00ol0003ob^K[ol[Vj`02ol[Vj`;o0000
1_o9g^P3o`0000Gob=OU00?o0000olKAh_l000000_l000000onVbo?oYlG_ojO5k`03ojO5k`GoYl3[
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`009_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ofmic?m_NL`01?m_NL`00ol0003oJWK=o`00
0007ogef`003o`000?mlML3oO7G000WoO7G000?o0000ogYe`_l000004On@O;T2o`0000CoT7fk00?o
0000oj>8]onSR;L03onSR;L6o`0000;oY8Zi00?o0000okFG^?neUkP05_neUkP00ol0003oa:JlolBV
_009olBV_0So00001?o6Zkh00ol0003odko7om>oa`0Bom>oa`03o`000?oIfMSofMWH00;ofMWH2Ol0
0004omOBe003o`000?o:i^_ob^K[00Gob^K[0ol00004olWNj004o`000?o9g^So0000o`0000;ob=OU
0ol00005ojK;l`CoYlG_00?o0000ojO0jonW`>/00_nW`>/00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01;ooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0fooooo`04o`000?ooooooooooo`0000OoKgW<00Co0000ofYfcOmZM/go00001?mmM/02o`00
00_oO7G000Go0000ogYe`_mjML;oNWG2o`00000>oi1l^@;o00001on@OK/00ol0003oXhRgoj>8]`0;
oj>8]`Ko00001OnTR[T00ol0003o]INhokFG^00FokFG^004o`000?o4Y[coa:JlolBV_0So00002oo6
Zkh00ol0003odko7om>oa`0Bom>oa`03o`000?oIfMSofMWH00cofMWH1?l0000;ol[Vj`;o00000oo9
g^P00ol0003obMkXolWNj002o`0000;oY=7g00?o0000ojK;lonVbo<00onVbo<00ol0003oYlG_ojO5
k`02ojO5k`03o`000?nW`>_oYl3[00;oYl3[00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Booooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0>?oo
ool3o`0000KoKgW<00Go0000ofYfcOmZM/goJWK=o`000003ogef`003o`000?mlML3oO7G000WoO7G0
0_l00004ogYe`P03o`000?n@O;WoT7bi00WoT7bi0ol00009oi1m^`03o`000?nSR;OoXhRg00SoXhRg
1Ol00009ojB:^@03o`000?neUkSo]INh01Co]INh1_l0000ColJ[_P03o`000?oC_lOodko7017odko7
00?o0000omWIf?oIfMP03_oIfMP00ol0003ob>k]olS^k@02olS^k@;o00002Oo:i^/2o`000005olWN
j?l0003o0000oj7Inol000001?nTdOL00ol0003oY/_cojK;l`03ojK;l`05o`000?nWaNooYlG_ojO5
kol000001?nW`>/00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@
413oooooooooo`03ooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0000ioooo
o`03o`000?m_NLcoKgW<00CoKgW<00?o0000ofYfcOmZM/d00omZM/d00ol0003oOGK0o`00000;ogae
`003o`000?mjML;oNWG200CoNWG200?o0000oi1l^On@O;T01on@O;T2o`0000coT7fk00?o0000oj>8
]onSR;L01OnSR;L5o`0000coY8Zi00?o0000okFG^?neUkP03oneUkP5o`0000;o]iZk00?o0000olJ[
__o6Zkh05?o6Zkh00ol0003odko7om>oa`0Aom>oa`03o`000?oIfMSofMWH00gofMWH00?o0000olS^
kOo8k^d01oo8k^d3o`0000Kob^K[00?o0000oj7Inol000000_nQfO/00ol0003oY=7gojCAm`02ojCA
m`03o`000?nVbo?oY/_c00;oY/_c00?o0000ojO5konWaNl00_nWaNl00ol0003oYl3[ojO0j`02ojO0
j`03o`000?oooooooooo01cooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0iooooo`03o`000?m_NLcoKgW<
00CoKgW<00?o0000ofYfcOmZM/d01?mZM/d00ol0003oO7G0ogae`008ogae`0;o00002?mjML800ol0
003oT7bioi1l^@04oi1l^@;o00003_n@OK/00ol0003oXhRgoj>8]`02oj>8]`Go00004?nTR[T00ol0
003o]INhokFG^009okFG^0Go00001ongV[/00ol0003oaZ^nolJ[_P0ColJ[_P03o`000?oC_lOodko7
00Oodko72ol00002omWIf0ko00003Oo8k^d4o`0000;oW=om00Co0000oj7InonQfO_o00000_nQfO/0
1Ol0003oY=7gojCAmonTdOOo000000GoY/_c00Go0000ojO5konWaNooYlG_o`000004ojO0j`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`006ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0>?ooool00ol0003oKgW<
ofmic004ofmic003o`000?mZM/goJWK=00GoJWK=00?o0000ogae`?mlML001omlML000ol0003oNWG2
ogYe`P08ogYe`P04o`000?n@O;WoT7bioi1l^@?o00004On@OK/5o`0001CoY8Zi00?o0000okFG^?ne
UkP01?neUkP5o`0000co]iZk00?o0000olJ[__o6Zkh04?o6Zkh4o`000003om>oaol0003o000000Ko
00002_oEa//00ol0003of^;Kom[Rf`0;om[Rf`03o`000?o4mNkoa?G^00Koa?G^1_l00004oi?To0Co
W=om00Ko0000oj7InonQfO_o0000oj7Inol00004ojCAm`03o`000?nVbo?oY/_c00?oY/_c00Go0000
ojO5konWaNooYlG_o`000004ojO0j`03o`000?oooooooooo01kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool0>?ooool00ol0003oKgW<ofmic004ofmic003o`000?mZM/goJWK=00CoJWK=00?o
0000ofIec_l000001omlML000ol0003oNWG2ogYe`P09ogYe`P04o`000?n@O;Wo0000o`0001;oT7fk
1?l0000GojB:^@03o`000?neUkSo]INh00Co00004OngV[/00ol0003oaZ^nolJ[_P0;olJ[_PGo0000
0oo8/<800ol0003oeLK;omG6b`0@omG6b`03o`000?oJh]_of^;K00_of^;K00?o0000olCek_o4mNh0
1oo4mNh3o`0000?oQNGf1OnCi?`01ol0003oW=omoicOoOnLgogo0000oj7Inol000000_nQfO/00ol0
003oY=7gojCAm`02ojCAm`03o`000?nVbo?oY/_c00;oY/_c00?o0000ojO5konWaNl00_nWaNl01Ol0
003oYl3[ojO0jonW`>_o0000023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000hooooo`03o`000?m_NLco
KgW<00CoKgW<00?o0000ofYfcOmZM/d01?mZM/d01Ol0003oIWG>ofIec_mVMLko000000CoO7G00_l0
000<ogYe`P;o00004On@OK/4o`000003oi60_Ol0003oY8Zi01GoY8Zi1?l0000FokNJ^`03o`000?o6
ZkkoaZ^n00GoaZ^n1_l00008olR``P03o`000?oEa/_oeLK;00ooeLK;00?o0000om[RfooJh]/01?oJ
h]/8o`0000?oa?G^1ol00007ohGUmP03o`000?nCi?coTnCl00;oTnCl00Oo0000oicOoOnLgogoW=om
o`000?nQfO_o000000;oXMWk00Go0000ojCAmonTdOOoY=7go`000005ojK;l`05o`000?nWaNooYlG_
ojO5kol000000onW`>/00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ofmic?m_NL`01?m_NL`00ol0003oJWK=ofYfc@04ofYfc@05o`000?mVMLko
IWG>ofIec_l000000omlML000ol0003oNWG2ogYe`P0;ogYe`P03o`000?miM/Co000000koT7fk1?l0
0005oi60_@03o`000?nTR[WoY8Zi00ooY8Zi1?l00002ojJ=^`03o`000?ngV[_o]iZk01Go]iZk00Co
0000olJ[__o6ZkkoaZ^n1?l0000>olR``P03o`000?oEa/_oeLK;00_oeLK;1?l000000ooJh]_o0000
o`000004o`0000Kof^_O00?o0000ok_jjonkn^/01_nkn^/6og7Pj0GoQNGf00?o0000oi?To?nCi?`0
0_nCi?`02Ol0003oW=omoicOoOnLgogo0000oj7Inol0003oXMWko`000004ojCAm`03o`000?nVbo?o
Y/_c00;oY/_c00?o0000ojO5konWaNl00_nWaNl01Ol0003oYl3[ojO0jonW`>_o0000023ooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo00?o0000
ofmic?m_NL`01?m_NL`00ol0003oJWK=ofYfc@04ofYfc@03o`000?mVMLkoIWG>00?oIWG>00?o0000
ogae`?l000003?mjML82o`0000?oNGK400?o0000oi1m^on@OK/02?n@OK/5o`0000OoTH2m00?o0000
ojB:^OnTR[T03?nTR[T3o`0000KoYXfk00?o0000okNJ^ongV[/04ongV[/5o`0001;ob;3200?o0000
omG6booEa//01_oEa//6o`0000?of<o@00?o0000om[[gooJjml02_oJjml00ol0003o^o[[ok_jj`02
ok_jj`;o00001?mHdm42obRaf@03o`000?lo^^ko?k[^00;o?k[^0omB_OX00on5iOKo0000o`000006
o`000006oicOoOl0003oXMWko`000?nQfO_o00000onTdOL00ol0003oY/_cojK;l`03ojK;l`05o`00
0?nWaNooYlG_ojO5kol000000onW`>/00ol0003oooooooooo`0Mooooo`03o`000?oooooo000000Go
oooo00?oEEEEofIVI_l000001oooool002Cooooo00?o0000ooooooooool0=oooool00ol0003oKgW<
ofmic004ofmic003o`000?mZM/goJWK=00?oJWK=00?o0000ofIec_mVMLh01OmVMLh00ol0003oNWG2
ogYe`P0:ogYe`P03o`000?miM/CoNGK400?oNGK400?o0000oi1m^on@OK/01_n@OK/5o`0000[oTH2m
00?o0000ojB:^OnTR[T01onTR[T4o`0000WoYXfk00?o0000okNJ^ongV[/03_ngV[/5o`0000;o^Inn
00?o0000olR``_o8/<804_o8/<800ol0003oeLK;omG6b`02omG6b`Co00002?oHcm000ol0003of^_O
om[[g`07om[[g`Co000000?o^o[[oj_ih_n[nN800_l000000omHdm7o>JGdocVUm004ocVUm0Co0000
00?o?k[^o`000?mB_OX00omB_OX5of6ko@CoKKSl2_l00004ojK;l`03o`000?nWaNooYlG_00;oYlG_
00Go0000ojO0jonW`>_oYl3[o`00000Qooooo`03o`000?oooooooooo00cooooo000Tooooo`;o0000
>?ooool00omZR=ko0000ofmic003ofmic003o`000?mZM/goJWK=00CoJWK=00?o0000ofIec_mVMLh0
1OmVMLh00ol0003oNWG2ogYe`P09ogYe`P03o`000?miM/CoNGK400GoNGK400?o0000oi1m^on@OK/0
0_n@OK/5o`0000goTH2m00?o0000ojB:^OnTR[T00onTR[T4o`0000koYXfk00?o0000okNJ^ongV[/0
2?ngV[/5o`0000Oo^Inn00?o0000olR``_o8/<804?o8/<83o`000003omG6bol0003of<o@00gof<o@
00Co0000om[[gooJjmoof^_O1_l00002omSdhP;oZoWR0_l000001?nCl=7oII_^ofFKk_mUVnh3o`00
0003ocVUm?l0003o000000CoBJ;f0ol00003oe:mnP03o`000?mQ^ogoHK_m00;oHK_m00?o0000offh
o?m]^?`00_m]^?`2ogFcn003o`000?me/oSoNjod00?oNjod2ol00003ojO0j`03o`000?oooooooooo
01kooooo0ol0000=ooooo`009?ooool00ol0003oooooooooo`0gooooo`;oJXSN00Co0000ofmic?m_
NLco00001_mZM/d00ol0003oIWG>ofIecP05ofIecP03o`000?mRMM3o000000SoNWG20_l00009ogUf
a0Co000000?oT7fko`000?l000003onAP;d00ol0003oY8ZiojB:^@03o`0001;oYXfk00?o0000okNJ
^ongV[/01?ngV[/4o`0000co^Inn00?o0000olR``_o8/<803?o8/<84o`0000;obkO700?o0000omS?
d?oHcm002ooHcm03o`000003om[[gol0003o000000Kof?CR00?o0000oj_ih_nCl=400_nCl=48ofFK
kP?o00001Om9X_H00ol0003oEIgcoeFMl`02o`000003oe:mn_l0003oHK_m00?oHK_m00?o0000offh
o?m]^?`00_m]^?`00ol0003oMK?hogFcn002o`0000CoNjod1On1Zo04ohFXk0Go00007Oooool3o`00
00;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=oooool01_l0003o
JXSNofZ8g_l0003oKgW<o`0000KoJWK=00?o0000ofIec_mVMLh01?mVMLh01?l0003oHWG@of9ed?l0
0007ogYe`P03o`000?miM/CoNGK400OoNGK40ol000001?n@OK_o0000o`000?l0000Aoi60_@?o0000
5OnVSK/00ol0003o]iZkokNJ^`04o`00013o^Inn00?o0000olR``_o8/<801oo8/<85o`0000GobkO7
00?o0000omS?d?oHcm001ooHcm05o`0000;of]WF00?o0000omSdh_oHm>801?oHm>800ol0003od?cR
oi?`d@02oi?`d@03o`000?mUVnkoII_^00KoII_^0_l00003of^BiP05o`000?m9X_KoBJ;fodVRm_l0
00001_mEWO<2o`0000?oHK_m00?o0000offho?m]^?`00_m]^?`01Ol0003oMK?hogFcn?me/oSo0000
00CoNjod00?o0000oh6[l?n1Zo000_n1Zo05ohFXk0?oRJKX0_l0000Iooooo`?o00001Oooool00ol0
003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0fooooo`03o`000?mZR=koJXSN00;o
JXSN00?o0000ofYfcOmZM/d01?mZM/d00ol0003oIWG>ofIecP05ofIecP05o`000?mRMM3oHWG@of9e
d?l000001?mjML82o`0000OoNGK40ol00002ogUfa0;o00004OnAP;d3o`000003oi63`Ol0003oYXfk
01?oYXfk1?l0000EokVO_P03o`000?o8/<;ob;3200?ob;321?l0000:ol^ga`03o`000?oHcm3of<o@
00?of<o@1?l00006om[IeP03o`000?oHm>;of?CR00;of?CR00Co0000om3lh_o@o>;o00000_nCl=43
ohJEf`03o`000?mUVnkoII_^00;oII_^0ol00006of^BiP03o`000?m9X_Ko000000KoEIgc00?o0000
oejHk_mNV>h00_l000000omQ^ogo0000offho002offho003o`000?me/oSoMK?h00;oMK?h00?o0000
og^_m?mk[o@00_mk[o@00ol0003oPJ_`oh6[l002oh6[l003o`000?n5Z>coQJS/00;oQJS/1?n9Y^P0
0ol0003oooooooooo`0Cooooo`Co00002?ooool00ol0003oooooooooo`0;ooooo`008oooool3o`00
03Oooooo00?o0000ofZ8g_mZR=h00_mZR=h00omRQ]oo0000ofYfc@03ofYfc@03o`000?mVMLkoIWG>
00GoIWG>00?o0000of9ed?mRMM000omRMM001?l0003oNWG2ogYe`_l00006ogUfa0?o00001?miM/@0
0ol0003oN7W7o`00000?oi60_@;o00001?nAPl400ol0003oYXfkojJ=^`0?ojJ=^`?o00000_nWT[l0
0ol0003o^InnokVO_P0DokVO_P03o`000?o8/<;ob;3200?o00003_o;]lL00ol0003of<o@omS?d003
o`0000Wof]WF00Co0000omSdh_oHm>;o00000oo@o>82o`000003ogCN]on6UM_oQYGK00CoQYGK00Co
0000ofFKk_l0003o00002Om[T^H3o`0000GoEIgc00?o0000oejHk_mNV>h01?mNV>h2o`0000;oKKSl
00?o0000ogFcn?me/oP00_me/oP2o`0000?oNjod00?o0000oh6[l?n1Zo000_n1Zo000ol0003oQJS/
ohFXk002ohFXk005o`000?n9Y^SoRJKXohVVj?l000004_ooool3o`0000gooooo00?o0000oooooooo
ool02_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003oJXSNofZ8gP02ofZ8gP;oHXKO
00Go0000ofYfcOmZM/goJWK=o`000007ofIecP03o`000?mRMM3oHWG@00?oHWG@00?o0000ogYe`_l0
00001?miM/@3o`0000GoNGK40_l00003ogQia`03o`000?nAP;goTH2m00[oTH2m0_l00007oi63`@03
o`000?nVSK_oYXfk00[oYXfk1?l00005ojNB_`03o`000?niWkko^Inn01;o^Inn1?l0000?ol^ga`Co
00002ooJfMH4o`0000?od?cR0ol000000omdg[OoQYGKohJEf`06ohJEf`;o00002Om[T^H2o`0000?o
KhcN00Go0000oeFMlomEWO?oEIgco`000007oejHkP;oII?Y00?o0000offho?l000001?me/oP00ol0
003oNjodo`000002og^_m003o`000?n1Zo3oPJ_`00;oPJ_`00?o0000ohFXk?n5Z>`00_n5Z>`01Ol0
003oRJKXohVVj?n9Y^So000000oooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Soooo
o`03o`000?oooooooooo03Oooooo00?o0000ofZ8g_mZR=h00_mZR=h3of:6g`03o`000?mZM/go0000
00OoIWG>00?o0000of9ed?mRMM001OmRMM000ol0003oNGK4ogUfa003o`0000OoNGK400?o0000ogQi
aomhNLL00omhNLL00ol0003oTH2moi60_@07oi60_@?o00002OnAPl400ol0003oYXfkojJ=^`07ojJ=
^`?o00002OnWT[l00ol0003o^InnokVO_P0=okVO_PGo00000_nkYL<00ol0003obkO7ol^ga`0:ol^g
a`Co00000_o>`<d00ol0003of]WFom[IeP07om[IeP?o000000?ofnCLo`000?o@o>800_o@o>82o`00
0003ol3ng?l0003oQYGK00KoQYGK0ol00002ohJ=d`03o`000?m[T^KoJi;V00CoJi;V0_l00006ofn<
gP03o`000?mEWO?o000000OoGYS^00?o0000ofFCjOmUTnT00_mUTnT2o`0000?oMK?h00Ko0000og^_
m?mk[oCo0000og^_m?l00004oh6[l003o`000?n5Z>coQJS/00;oQJS/00Go0000ohVVj?n9Y^SoRJKX
o`00000;ooooo`Co00004oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooooooo
o`0gooooo`03o`000?mZR=koJXSN00;oJXSN00Go0000of:6gomRQ]ooHXKOo`000007ofIecP03o`00
0?mRMM3oHWG@00KoHWG@0ol00008ogUfa0;o00001omhNLL00ol0003oTH2moi60_@04oi60_@;o0000
3?nAPl400ol0003oYXfkojJ=^`03ojJ=^`Co00003OnWT[l00ol0003o^InnokVO_P08okVO_PCo0000
1onkYL<00ol0003obkO7ol^ga`06ol^ga`Co00001_o>`<d00ol0003of]WFom[IeP04om[IeP?o0000
0ooKi=`01?l0003od?cRo`000?l00002ol3ng0;o00001On6UM/3o`0000KoQXgC00?o0000of^Bi_m[
T^H00_m[T^H00ol0003oKhcNofn<gP06ofn<gP;o00001omNV>h00ol0003oII?YofFCj@03ofFCj@;o
Ji3T0_l000001ome/oSo0000og^_m?mk[oCo0000og^_m?l000001?n1Zo000ol0003oQJS/ohFXk002
ohFXk005o`000?n9Y^SoRJKXohVVj?l000002?ooool3o`0001Oooooo00?o0000ooooooooool02_oo
ool002?ooooo0ol0000gooooo`03o`000?mZR=koJXSN00;oJXSN00Ko0000of:6gomRQ]ooHXKOoe^5
h_l00006ofIecP03o`000?mRMM3oHWG@00?oHWG@0ol000000omNM]?o0000ogUfa006ogUfa0;o0000
2OmhNLL00ol0003oTH2moi60_@02oi60_@;o00003onAPl400ol0003oYXfko`000002o`00017oYi:o
00?o0000okVO__niWkh01?niWkh4o`0000_o^jG300?o0000ol^gaoo;]lL00oo;]lL3o`0000Woc/3=
00?o0000om[Ie_oJfMH00_oJfMH3o`0000CofnCL0ol00002ol3ng003o`000?nUm/_oW9O=00;oW9O=
00?o0000ohJEfol000000_l0000:ohJ=d`04o`000?m[T^Ko0000o`0000SoKhcN00Co0000og:6f?mb
Q]So00001OmNV>h00ol0003oII?YofFCj@03ofFCj@03o`000?m[T>CoJi3T00;oJi3T00?oMK?ho`00
0?mk[o@00_mk[o@2o`0000CoPJ_`00?o0000ohFXk?n5Z>`00_n5Z>`01Ol0003oRJKXohVVj?n9Y^So
000000Gooooo0ol0000Jooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo
03Oooooo00?o0000ofZ8g_mZR=h00_mZR=h01?l0003oHXKOof:6gomRQ]l2oe^5hP03o`000?mVMLko
IWG>00;oIWG>00Co0000of9ed?mRMM3oHWG@0ol000000omRMM3o0000oeifd`02oeifd`03o`000?mi
M/CoNGK400?oNGK400?o0000ogQiaomhNLL02OmhNLL00ol0003oTH2mo`000002o`00013oTH?10ol0
000DojNB_`03o`000?niWkko^Inn00Co00003onkYL<00ol0003obkO7ol^ga`03o`0000coc/3=00?o
0000om[Ie_oJfMH00_l00004om_Tg0Co00000_o0o]`00ol0003oYOK;ojGfb`04oibGc@;o00003On6
SM<2o`0000SoKhcN0_l00004og:6f005o`000?mNV>koGYS^oejHk_l000001OmUTnT00ol0003oJi3T
of^@i004of^@i0;o00000omk[o@00ol0003oPJ_`oh6[l002oh6[l005o`000?n5Z>coQJS/ohFXk?l0
00001?n9Y^P00ol0003oooooooooo`03o`0001gooooo00?o0000ooooooooool02_ooool00005onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool00ol0003oooooooooo`0hooooo`03o`000?mZR=koJXSN00;oJXSN00Co0000of:6
gomRQ]ooHXKO0omKQN801?l0003oIWG>ofIec_mVMLh4o`0000?oHWG@00?o0000oeifdomNM]<00_mN
M]<01?l0003oNGK4ogUfa?miM/@2o`0000coN7W70_l0000@oi63`@?o000000?oTXS5o`000?nWT[l0
4_nWT[l4o`0001;o^jG31?l0000>olk0c@Co00001OoKi=`2o`0000;ofO7Q00?o0000ol3ng?l00000
0_nUm//3oibGc@?o000000?oVi37o`000?n6SM<02On6SM<3o`0000;oQhO=00?o0000ofn<g_m_S=h0
1?m_S=h00ol0003oLXKHog:6f005og:6f003o`000?mNV>ko000000KoII?Y00?o0000of^@i?m[T>@0
1?m[T>@2og2>h0;o000000?oNjodo`000?n1Zo000on1Zo001Ol0003oQJS/ohFXk?n5Z>co000000Co
RJKX0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo03Sooooo00Go0000ofZ8g_mZR=koJXSNo`000004of:6g`04o`000?mKQN;o
FhGRoe^5hPCo00001OmRMM000ol0003oGWKCoeifd`04oeifd`03o`000?miM/Co000000coN7W70_l0
00000omgO<_o0000oi63`@0=oi63`@;o00001OnBR<D00ol0003oYi:oojNB_`0=ojNB_`?o00000_nY
V<@00ol0003o^jG3ok^U``0>ok^U``?o00000_nn[LT00ol0003oc/3=olk0c@0:olk0c@?o00000_oA
bm@00ol0003ofnCLom_Tg002om_Tg0;o00000_oIlN42o`0000?oYOK;0_nLUld3o`0000GoVi3700?o
0000ohJ=don6SM<01?n6SM<3o`0000KoQhO=00Co0000ofn<g_m_S=koKhcN0_l00008og:6f0?o0000
1OmUTnT00ol0003oJi3Tof^@i004of^@i003o`000?m`S^3oL8kP00?oL8kP0_l00003oh6[l005o`00
0?n5Z>coQJS/ohFXk?l000001?n9Y^P00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wo
oooo00001Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003o
ooooooooo`02ooooo`;o0000>?ooool00ol0003oJXSNofZ8gP02ofZ8gP03o`000?mRQ]ooHXKO00;o
HXKO00?o0000oe^5h_mKQN800ol00007of9ed003o`000?mNM]?oGWKC00GoGWKC00?o0000ogQiaomh
NLL02OmhNLL2o`0000CoMgc;00?o0000oi63`OnAPl402?nAPl43o`0000OoTXS500?o0000ojNB_onW
T[l02_nWT[l3o`0000KoZIS400?o0000ok^U`onkYL<02_nkYL<3o`0000Go_Zg900?o0000olk0cOo>
`<d01oo>`<d3o`0000CodL_D00Go0000om_Tg?oKi=cofnCLo`000003omWah@;o000000Cod?_So`00
0?nUm/_oW9O=0ol00009oi^@a`03o`000?n6SM?oQXgC00?o00002_n7Qld00ol0003oKhcNo`000008
og:6f0;o00000omePm<2o`0000?oII?Y00?o0000of^@i?m[T>@00om[T>@00ol0003oL8kPog2>h004
og2>h0;oM8gM0_l000000on1Zo3o0000ohFXk002ohFXk003o`000?n9Y^SoRJKX00;oRJKX00?o0000
ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000=
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0g
ooooo`03o`000?mZR=koJXSN00;oJXSN00?o0000of:6gomRQ]l00_mRQ]l3o`0000;oFhGR00?oDhGU
o`000?mRMM001?mRMM000ol0003oGWKCoeifd`05oeifd`;o00002OmhNLL2o`0000OoMgc;00?o0000
oi63`OnAPl401OnAPl42o`0000_oTXS500?o0000ojNB_onWT[l01_nWT[l3o`0000WoZIS400?o0000
ok^U`onkYL<01_nkYL<4o`0000So_Zg900?o0000olk0cOo>`<d01?o>`<d3o`0000OodL_D00?o0000
om_Tg?l000000ooIlN42o`0000;od?_S00Co0000ojGfbol0003o00003?nKT<L3o`0000goQhO=0_l0
0008og:6f003o`000?mePm?oMH?C00GoMH?C00?o0000ofFCjOl000001_m[T>@00ol0003oL8kPog2>
h003og2>h007o`000?mdSMgoM8gMogB=gOl0003oPJ_`o`000003ohFXk003o`000?n9Y^SoRJKX00;o
RJKX00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`0000Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004oooo
o`03o`000?oooooooooo03Oooooo00?o0000ofZ8g_mZR=h00_mZR=h00ol0003oHXKOo`000003o`00
00CoFhGR0_mCQND01Ol0003oHWG@of9ed?mRMM3o000000OoGWKC00Co0000oeUheomIN=Oo00001omh
NLL00ol0003oMgc;ogMlb`07ogMlb`03o`000?nAPl7oTH?100?oTH?10_l0000=oi:8a@03o`000?nW
T[ooYi:o00?oYi:o0ol0000<ojVHa003o`000?nkYL?o^jG300?o^jG30ol0000;okj]b@03o`000?o>
`<goc/3=00;oc/3=0ol00008om7;e0;o00001?oIlN42o`0000;od?_S0ol0000<oi^@a`?o000000?o
VX_2o`000?n7Qld02_n7Qld3o`000003ohN3b?l0003oLXKH00GoLXKH0_l00008ogF3d`;o00001_m[
T>@00ol0003oL8kPog2>h004og2>h006o`000?mdSMgoM8gMogB=gOl0003oM8gM0_l00002ohFXk003
o`000?n9Y^SoRJKX00;oRJKX00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`00
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0gooooo`;o00000_mZR=h3o`0000;oHXKO00?o0000oe^5h_mK
QN800omKQN801_l0003oDhGUoe>5iOl0003oHWG@o`0000OoGWKC00?o0000oeUheomIN=L00_mIN=L0
0ol0003oN7W7ogQia`02ogQia`;o00002omgO</00ol0003oTH?1o`000002o`0000ooTXS500?o0000
ojNB_onWT[l00ol0000@ojVHa003o`000?nkYL?o^jG300;o00003_nn[LT00ol0003oc/3=olk0c@02
o`0000SodL_D0ol000001OoCf=co0000omWahOoIlN7o000000?od?_S0_l00002ojbG`@03o`000?nK
T<OoVi3700OoVi370ol00005oiZ;`P03o`000?n7QlgoQhO=00GoQhO=0ol00005ohN3b004o`000?mb
Q]SoLXKHog:6f0;o00002OmePm<01?l0003oN87?ogR1col00004of^@i003o`000?m`S^3oL8kP00Co
L8kP00?o0000ogB=gOmdSMd00omdSMd00ol0003oNHgJogV=fP03o`0000CoRJKX00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o0000>?ooool01_n0
Yngo0000o`000?l0003oJXSNo`0000?oHXKO00?o0000oe^5h_mKQN800_mKQN800ol0003oDhGUoe>5
i@02oe>5i@03o`000?mNM]?oGWKC00GoGWKC00?o0000oeUheomIN=L01?mIN=L01?l0003oN7W7o`00
0?l0000=ogMlb`;o00004_nBR<D3o`00017oZIS41?l0000?okj]b@Co00002?oAbm@3o`0000?odmSL
00?o0000omWahOoIlN400oo@nn<3o`0000Co[9O100?o0000oi^@aonKT<L00onKT<L3o`0000WoVX_2
00?o0000ohN7cOn7Qld00_n7Qld2o`0000WoQh?800?o0000og:6f?l000002_mePm<00ol0003oN87?
ogR1c`02ogR1c`05o`000?m[T>CoJi3Tof^@i?l000001Om`S^000ol0003oM8gMogB=g@04ogB=g@;o
00000omiSMX2o`0000?oRJKX00?o0000ooooooooool08Oooool00ol0003oooooooooo`09ooooo`00
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Cooooo00?o0000ooooooooool0=_ooool3o`0000?oP:O]0_l00003of:6g`03o`000?mKQN;oFhGR
00;oFhGR00?o0000oe>5iOmCQND00_mCQND00om;Q^So0000oeifd`04oeifd`03o`000?mIN=OoFGSG
00KoFGSG00?o0000ogMlbomgO</02omgO</2o`000003ogJ1dOl0003oTXS500koTXS50ol000000onC
S/_o0000ojVHa00>ojVHa0?o00000_n[Wl/00ol0003o_Zg9okj]b@0;okj]b@?o00000_o1]m400ol0
003odL_Dom7;e004om7;e0?o00001OoCf=`2o`0000?od?_S0_l000000onjoM[o[9O1ojbG`@04ojbG
`@03o`000?nKT<OoVi3700?o00003?nJRl800ol0003oQhO=o`000002o`0000_oQh?80_l00009ogF3
d`;o00001_mhPLl00ol0003oJi3To`000006og2>h003o`000?mdSMgoM8gM00CoM8gM00?o0000ogV=
f_l000000_miSMX2ogf=f@;o000000?oRJKXo`000?ooool08_ooool00ol0003oooooooooo`09oooo
o`008Oooool00ol0003oooooooooo`0cooooo`?o00000oooool4oh2Wk@;o00000_mRQ]l00ol0003o
FhGRoe^5hP02oe^5hP03o`000?mCQNGoDhGU00;oDhGU0_m;Q^P01Ol0003oGWKCoeifdomNM]?o0000
00SoFGSG0_l0000;ogMlb`;o00001?mfPM400ol0003oTXS5oi:8a@09oi:8a@?o00001OnCS//00ol0
003oZIS4ojVHa009ojVHa0?o00001On[Wl/00ol0003o_Zg9okj]b@07okj]b@Co00001Oo1]m400ol0
003odL_Dom7;e002om7;e0;o00001_oCf=`2o`000004om;XiOl0003od?_So`0000;o^_gJ00?oT^g0
ojbG`On/Ul401?n/Ul44o`0000ooVX_20_l0000<ohN3b0;o000000?oR834o`000?mePm<01omePm<0
0ol0003oN87?ogR1c`06ogR1c`;o00001_m`S^000ol0003oM8gMogB=g@04ogB=g@06o`000?miSM[o
NHgJo`000?miSM[o00001?mmSMT2o`0002Cooooo00?o0000ooooooooool02?ooool0027ooooo00?o
0000ooooooooool0<?ooool3o`0000Kooooo00Co0000oh2WkOn0YngoP:O]0_mjZ?400ol0003oHXKO
o`000004oe^5hP03o`000?mCQNGoDhGU00;oDhGU00Ko0000od^6j?m;Q^So0000oeifdol00008oeUh
e`04o`000?mEO=coEGcLo`0000OoMgc;0ol00006ogJ1d@03o`000?nBR<GoTXS500KoTXS50ol00008
oi>>b`03o`000?nYV<CoZIS400KoZIS40ol00009oj^Ob`03o`000?nn[LWo_Zg900;o_Zg91?l00009
ol6gd@04o`000?oAbmCodL_Do`0000KodmSL0ol00002om;Xi@;o00000_njoMX00onBkL3o[9O1ojbG
`@03ojbG`@?o00000_nZT[d00ol0003oVX_2oiZ;`P0;oiZ;`P?o000000?oVHNno`000?n7PlP02On7
PlP2o`0000CoR83400?o0000ogF3domePm<00omePm<2o`0000SoN87?00?o0000ogYocOl000001_m`
S^000ol0003oM8gMogB=g@04ogB=g@04o`000?miSM[oNHgJogV=fP;o00001OmmSMT00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qooooo`;o0000;_ooool3o`0000[ooooo00Co
0000oh2WkOn0YngoP:O]0_mjZ?42o`0000CoFhGR00?o0000oe>5iOmCQND00_mCQND01?l0003oBhKX
od^6j?m;Q^P2o`0000OoFGSG00?o0000oeElg?mEO=`00_mEO=`00ol0003oMgc;ogMlb`02ogMlb`;o
00002_mfPM400ol0003oTXS5oi:8a@02oi:8a@?o00002onCS//00ol0003oZIS4ojVHa003ojVHa0?o
00003?n[Wl/00ol0003o_Zg9okj]b@02o`0000co`KOA0_l00007om?Hg0;o00000ooBj>D2o`0000;o
^_gJ00?o0000ojbG`On/Ul400_n/Ul43o`0000KoZY:m00?o0000oiZ;`_nJRl801onJRl83o`0000Go
VHNn00?o0000ohN3b?n7PlP01On7PlP2o`0000OoR83400Go0000ogF3domePm?oMH?Co`000009ogR1
c`05o`000?mjOlgoNWo=ogYocOl000001?m`S^000ol0003oM8gMogB=g@04ogB=g@03o`000?miSM[o
NHgJ00;oNHgJ0_l00005ogf=f@03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0
027ooooo00?o0000ooooooooool0:_ooool3o`0000gooooo00Go0000oh2WkOn0YngoP:O]o`000002
ogZXl@;o00000_mKQN800ol0003oDhGUoe>5i@03oe>5i@04o`000?m;Q^SoBhKXod^6j0;o@HS[00?o
0000oeUheomIN=L00omIN=L00ol0003oEGcLoeElg004oeElg004o`000?mgO<_o0000o`0000coMX7A
00?o0000oi:8aOnBR<D00_l0000?oi>>b`03o`000?nYV<Co000000;o00003_n[Wl/3o`0000co`KOA
0ol000000oo4a=[o0000om?Hg004om?Hg0;o00000ooBj>D2o`000004ol_gj_l0003o^_gJoi;]`0;o
[9O10ol00009ojZB_@03o`000?nJRl;oVX_200GoVX_20_l00008oiV7_P03o`000?n7PlSoQh?800Co
Qh?800?o0000ohR0a?n8P<@02?n8P<@00ol0003oMH?Co`000009ogR1c`03o`000?mjOlgoNWo=00?o
NWo=00Co0000og2>h?m`S^3o00001_mdSMd00ol0003oNHgJogV=fP03ogV=fP03o`000?mmSMWo0000
00?oOHgI00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003o
ooooooooo`0Wooooo`?o00004?ooool01Ol0003oP:O]oh2WkOn0Yngo000000;oNZSa0_mcZo@3o`00
00CoDhGU00?o0000od^6j?m;Q^P00_m;Q^P01?l0003o@HS[od68jol00003oeUhe`03o`000?mEO=co
EGcL00GoEGcL0_l0000>ogJ1d@;o00004OnCS//3o`0000koZio;0ol000000on^ZM?o0000ol6gd@09
ol6gd@?o00001?o4a=X01?l0003odmSLom?Hg?oCf=`2o`0000?od^SU0_l000001Oo;mn[o0000o`00
0?nBkL3o[9O100?o00003?nZT[d00ol0003oVX_2oiZ;`P02oiZ;`P?o00002onIQkh01?l0003oQh?8
ohN3b?n7PlP2o`0000_oR8340_l00008ogR1c`;o00001omjOld00ol0003oL8kPo`000006ogB=g@03
o`000?miSM[oNHgJ00;oNHgJ00Co0000ogf=fOmmSMWo00000ommSMT00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo02Gooooo0ol0000Dooooo`05
o`000?n0YngoP:O]oh2WkOl000000_mjZ?43og>[m0;o00000omCQND00ol0003oBhKXod^6j002od^6
j007o`000?m1R>_o@HS[od68jol0003oFGSGo`000007oeElg003o`000?m?P^?o000000_oMX7A0ol0
00000omeR=So0000oi>>b`0=oi>>b`?o000000?oU9KCo`000?n[Wl/02on[Wl/3o`0000Co[ZWC00?o
0000ol6gdOo1]m401Oo1]m43o`0000Ooa<CJ00?o0000om?Hg?oCf=`01?oBj>D2o`000003ol_gj_l0
003o000000Co00004?nZT[d4o`0000koVHNn00Co0000ohN3b?l0003o00002on8P<@2o`000003ohUn
`_l0003oN87?00KoN87?00?o0000ogYocOmjOld01omjOld3o`0000GoM8gM00?o0000ogV=f_miSMX0
0omiSMX01ol0003oOHgIogf=fOmmSMWo0000ogf=fOl000009_ooool00ol0003oooooooooo`08oooo
o`008?ooool2o`0002?ooooo0ol0000Gooooo`05o`000?n0YngoP:O]oh2WkOl000000_mjZ?400ol0
003oLj_dog>[m002of^^n0;o000000?oDhGUo`000?m;Q^P00om;Q^P00ol0003o@HS[od68j`02od68
j`03o`000?mEO=coEGcL00GoEGcL00Go0000odn2hom?P^?oCh;So`000008ogJ1d@;o00001OmeR=P0
0ol0003oThk;oi>>b`08oi>>b`?o00001OnDU]<00ol0003oZio;oj^Ob`06oj^Ob`?o00002?n^ZM<0
1?l0003o`KOAol6gdOo1]m43o`0000Woa<CJ0_l00005om;Xi@06o`000?o;mn[oboOZo`000?ncnn;o
00000_nhWKd00ol0003oZY:mojZB_@0=ojZB_@?o00004OnIQkh2o`0000_oR8340_l00004ohUn`P03
o`000?mhPLooN87?00?oN87?00?o0000ogYocOmjOld01omjOld01Ol0003oO7o;ogaobomlOl_o0000
00CoM8gM00?o0000ogV=f_miSMX00_miSMX00ol0003oOHgIogf=f@03ogf=f@;o00009_ooool00ol0
003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool01Ol0003o
P:O]oh2WkOn0Yngo000000?oNZSa00?o0000og>[m?mcZo@00om[[_P2o`0000?oBhKX00?o0000od68
jom1R>/00om1R>/00olfRngo0000oeElg004oeElg003o`000?m?P^?oCh;S00?oCh;S00?o0000ogJ1
dOmfPM400omfPM42o`0000SoMHSH00?o0000oi>>bonCS//01?nCS//3o`0000WoU9KC00?o0000oj^O
bon[Wl/00_n[Wl/3o`0000_o[ZWC00Co0000ol6gdOo1]m7o00002Oo4a=X3o`000003olKEiOl0003o
d^SU00;od^SU00Go0000ol_gj_o;mn[o0000ok?khP02o`0000?o^9fm00?o0000ojZB_OnZT[d02_nZ
T[d3o`0000;oZHnj00?o0000oiV7__nIQkh03?nIQkh3o`000003oiV4_?l0003oR83400SoR8340_l0
0007ohUn`P05o`000?mhPLooN87?ogR1col000002OmjOld00ol0003oO7o;ogaob`03ogaob`04o`00
0?mdSMgoM8gMo`0000GoNHgJ00?o0000ogf=fOmmSMT01?mmSMT00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`05o`00
0?n0YngoP:O]oh2WkOl000000_mjZ?401?l0003oLj_dog>[m?l00003of^^n0;o00000_m;Q^P00ol0
003o@HS[od68j`03od68j`03o`000?lfRngo000000?oEGcL00?o0000odn2hom?P^<01Om?P^<00ol0
003oMX7Ao`000002o`0000_oMHSH00?o0000oi>>bonCS//00ol0000<oiBFd`03o`000?n[Wl_oZio;
00;o00003?n^ZM<3o`0000Woa<CJ0ol00004olKEi@03o`000?oBj>Go000000;oboOZ00Co0000ok?k
h_l0003oQ>O11OnhWKd00ol0003oZY:mojZB_@06ojZB_@Co00001_nYSkX00ol0003oVHNnoiV7_P08
oiV7_P?o00001OnIQ;`00ol0003oR834ohR0a004ohR0a0;o00002_n9O/800ol0003oN87?o`000009
ogYoc@03o`000?mlOl_oO7o;00GoO7o;00?o0000ogB=gOl000001OmiSMX00ol0003oOHgIogf=f@03
ogf=f@;o00009oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Joooo
o`?o00008?ooool01Ol0003oP:O]oh2WkOn0Yngo000000?oNZSa00Co0000og>[m?mcZoCo00000_m[
[_P01Ol0003oHK7ko`000?m;Q^So000000Go@HS[00Ko0000ocJ;kOlfRngo0000oeElg?l00008odn2
h`?o00003OmeR=P3o`0000ooU9KC0_l0000<ojjYd`?o00000_n`]mh00ol0003oa<CJolC4fP05olC4
fP;o00001_o6eND2o`0000?oboOZ00?o0000ok?kh_n4il402?nhWKd00ol0003oZY:mojZB_@02ojZB
_@?o00002_nYSkX00ol0003oVHNnoiV7_P05oiV7_P?o00002OnIQ;`01?l0003oR834ohR0a?n8P<@2
o`0000coRGk20_l00009ogYoc@03o`000?mlOl_oO7o;00KoO7o;0_l00005ogV=fP03o`000?mmSMWo
OHgI00CoOHgI00?o0000ooooool000009_ooool00ol0003oooooooooo`07ooooo`008?ooool3o`00
01Oooooo0ol0000Sooooo`05o`000?n0YngoP:O]oh2WkOl000000omjZ?401?l0003oLj_dog>[m?l0
0003of^^n004o`000?mQ/O_o0000o`0000Co@HS[00?o0000ocJ;kOlfRnd00_lfRnd2o`0000OoCh;S
00Go0000odR8jOm8R>WoB8SYo`000009ogF8f0?o000000?oLi;Ro`000?nDU]<03?nDU]<3o`000003
oiJQgOl0003o[ZWC00So[ZWC0ol00005ok2ggP03o`000?o4a=[oa<CJ00;oa<CJ0ol00005olKEi@?o
000000Go`nS`o`000?o;mn[o0000ok?khP02o`0000Wo^9fm00?o0000ojZB_Ol000000_l0000=ojV?
^P03o`000?nIQkkoVHNn00;oVHNn0ol0000<oiV4_004o`000?n8P<Co0000o`0000coRGk20_l00000
0on9OL3o0000ogYoc@07ogYoc@03o`000?mlOl_oO7o;00KoO7o;00Co0000ogmob_moOl[o00001?mi
SMX00ol0003oOHgIogf=f@03ogf=f@05o`000?ooooooooooooooool000009Oooool00ol0003ooooo
ooooo`07ooooo`007oooool2o`0001Kooooo0ol0000Wooooo`05o`000?n0YngoP:O]oh2WkOl00000
0omjZ?401?l0003oLj_dog>[m?l00002of^^n003o`000?mQ/O_oHK7k00;o00000om1R>/00ol0003o
=X_]ocJ;k@02ocJ;k@;o:8k]00?o0000odn2hom?P^<00om?P^<00ol0003oB8SYodR8j@03odR8j@03
o`000?meR=SoMHSH00?oMHSH0ol00005og>BhP03o`000?nDU]?oU9KC00OoU9KC0ol00005oiJQg@03
o`000?n^ZM?o[ZWC00?o[ZWC0ol00009ok2ggP04o`000?o4a=[o0000o`0000Goa]GU0ol00003ol?X
l0;o000000?o/o_Ro`000?n4il402OnhWKd4o`00017oZHnj1?l0000?oiV4_0;o00003On9O/800ol0
003oRGg0ohUm`002ohUm`003o`000?mjOlgoNWo=00CoNWo=00?o0000ogaobomlOl/01_mlOl/00ol0
003oOgo:ogmobP02ogmobP04o`000?miSM[oNHgJo`0000KoOHgI00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo0004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo01;ooooo0ol0000Zooooo`05o`000?n0YngoP:O]oh2WkOl000000omjZ?401Ol0003oLj_d
og>[m?mcZoCo000000;oJjkh00Co0000of6anol0003oEK?k0_l000000om1R>_o0000ocJ;k@03ocJ;
k@04o`000?lXS^go:8k]o`0000?oCh;S00?o0000odR8jOm8R>T01Om8R>T00ol0003oMHSHogF8f002
o`0000WoLi;R00?o0000oiBFdonDU]<00onDU]<3o`0000SoUZ7M00?o0000ojjYdon^ZM<00ol0000;
ok2ggP;o00001Oo6eND3o`0000?o`nS`1Ol000000on4il7o^9fmokRM_@04okRM_@Go00000_nfVKX0
0ol0003oZHnjojV?^P0>ojV?^P?o00003onIQ;`3o`000003oiV3^_l0003oRGk200[oRGk20_l00006
ohUm`003o`000?mjOlgoNWo=00;oNWo=00?o0000ogaobomlOl/01_mlOl/00ol0003oOgo:ogmobP04
ogmobP03o`000?miSM[o000000GoOHgI00?o0000ooooooooool00oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Oooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0?ooooo`?o0000;Oooool0
1Ol0003oP:O]oh2WkOn0Yngo000000CoNZSa00Co0000og>[m?mcZoCo00000om[[_P00ol0003oHK7k
o`000003oeFcn`;o00000_lfRnd00ol0003o:8k]obR>k@02obR>k@03o`000?m?P^?o000000SoB8SY
0_l0000<og>BhP03o`000?nDU]?oU9KC00?o00002_nFXMd4o`0000_o/;ON0ol00002ok78j`05o`00
0?o6eNGoa]GUolKEiOl000000oo3j?03o`000003ok?flOl0003o000000;o00000onhWKd4o`0000Oo
]YVj00?o0000ojV?^_nYSkX02OnYSkX5o`0000;oZ8bh00?o0000oiV4_?nIQ;`02onIQ;`2o`0000Go
VH>j00?o0000ohUn`_n9O/801_n9O/82o`0000SoRGg000Go0000ogYocOmjOlgoNWo=o`000008ogao
b`03o`000?moOl[oOgo:00KoOgo:0_l00005ogf=f@03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Oooool3o`00
0003oh2WkOl0003oNZSa00;oNZSa00Go0000og>[m?mcZoCoLj_do`000002of^^n004o`000?mQ/O_o
HK7ko`0000;oEK?k00?o0000odJdmol000000_l00005obR>k@;o00001_m8R>T2o`0000;o?i3_00?o
0000og>Bh_mcT^802?mcT^84o`0000[oUZ7M0ol00002oiJ`j@03o`000?n`]mko/;ON00Oo/;ON0ol0
0005ok78j`;o00001Oo3j?001Ol0003o/oKaok?flOl0003oS>kJ00;o000000?o^9fmo`000?l00000
0_l0000<okJI^P03o`000?nYSk[oZHnj00CoZHnj1?l00008ojR<^003o`000?nIQ;coVHBl00OoVHBl
0ol00007oiV3^P03o`000?n9O/;oRGk200GoRGk200?o0000ohUm`?n9OL002On9OL000ol0003oNWo=
o`000007ogaob`;o00002?moOlX01?l0003oPX79oh:1bOl00004ogf=f@03o`000?oooooooooo00Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool2o`0000[ooooo0ol0000dooooo`03
o`000?nW`>_oYl3[00[o00000om[[_P01?l0003oHK7kof6anol00002oeFcn`03o`000?m6]?OoA[Cg
00;o00001?lXS^d2oaV?j@03o`000?m8R>WoB8SY00;oB8SY00?o0000ocn@koloT>l00oloT>l00ol0
003oLi;Rog>BhP04og>BhP?o00001?m`WNd00ol0003oUZ7MoiJQg@04oiJQg@?o00001_nF/>T00ol0
003o/;ONok2ggP03ok2ggP?o00001Onab>/3o`000003ojkLmol0003o`nS`00;o`nS`00Go0000ok?f
lOncm_7o0000ohc^fP04o`00017o]YVj00?o0000ojV?^_l000001?l0000<ojR<^003o`000?nIQ;co
VHBl00CoVHBl0ol0000;oiV3^P03o`000?n9O/;oRGk200;oRGk20_l0000<ohUm`0;o00001omlOl/0
0ol0003oOgo:ogmobP07ogmobP03o`000?n2PLWoPX7900;oPX7900Co0000ogf=fOmmSMWo00002Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
1_ooool3o`0003Sooooo00Go0000ojO0jonW`>_oYl3[o`000004ojO5k`03o`000?nVbo?o000000Co
00000omQ/O/01?l0003oEK?koeFcnol00003odJdm`;o000000?o:8k]o`000?lISnT00_lISnT01?l0
003oB8SYo`000?l00007ocn@k`03o`000?mcT^;oLi;R00?o00002?m`WNd00ol0003oUZ7MoiJQg@03
o`0000[oU[3Y00?o0000ok2gg_n`]mh00_l00005ok78j`?o00001?n^g?L2o`0000?o/oKa00?o0000
ohc^f_n<k]X00oo3Y[d00ol0003o]YVjokJI^P0>okJI^PCo00004OnXS;P00ol0003oVHBloiV4_002
oiV4_0;o00003_nIPkX00ol0003oRGk2ohUn`P02o`0000coRGg00_l000000on;OKoo0000ogaob`05
ogaob`03o`000?moOl[oOgo:00OoOgo:00?o0000oh:1bOn2PLT01?n2PLT00ol0003oOHgIo`000009
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool3
o`0003cooooo00Go0000ojO0jonW`>_oYl3[o`000004ojO5k`05o`000?nVbo?oY/_cojK;lonTdOL0
2Ol00004odJdm`04ocBakOl0003o0000o`0000;o6HoY0_l00008ocn@k`?o00002_m`WNd4o`0000co
U[3Y0ol00005ok78j`?o00001?n^g?L3o`000003oig[n_l0003o000000?oS>kJ1Oo3Y[d00ol0003o
]YVjokJI^P09okJI^PGo00000_neU[P00ol0003oZ8bhojR<^00AojR<^0Co00004?nIPkX00ol0003o
RGk2o`00000=ohUm`003o`000?n;OKooRgfo00;oRgfo00?o0000ogaobomlOl/00_mlOl/00ol0003o
Ogo:ogmobP07ogmobP03o`000?n2PLWoPX7900KoPX7900?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo0004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooooooo`?o0000@?ooool01Ol0
003oYl3[ojO0jonW`>_o000000CoYlG_00Go0000ojK;lonVbo?oY/_co`000002ojCAm`CoXMWk00?o
W=omo`000?l000002_l000001?l7SMco0000o`000?l00002ocn@k`?o00000olaV?400ol0003oL9g]
og2Mk@04og2Mk@?o00000omY[?L00ol0003oU[3YoiJ`j@05oiJ`j@Go00000onC`OH01Ol0003o/LS[
ok78jonab>_o000000Go[]cg0_l000001OnMjo[o0000o`000?l0003oMN?O00;o00001oo3Y[d00ol0
003o]YVjokJI^P04okJI^PGo00001oneU[P00ol0003oZ8bhojR<^00?ojR<^0?o00004_nIPkX3o`00
00coRGg00_l00006oh]m_`04o`000?mlOl_oO7o;o`0000WoOgo:00?o0000oh:1bOn2PLT01_n2PLT0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool0
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool4o`0004Cooooo00Go0000
ojO0jonW`>_oYl3[o`000004ojO5k`05o`000?nVbo?oY/_cojK;lol000000_nTdOL2o`0000?oXMWk
00?o0000oicOoOl000000_l00003oi?To0Go00000_l7SM`2o`0000Oo<ISa00?o0000og2MkOm`WNd0
0ol00007ofV/m`03o`000?nF/>WoU[3Y00Co00001onC`OH4o`0000Go[]cg0_l000001?nMjo[o0000
o`000?mehml3o`0000Wo`jJm00?o0000okJI^_nfVKX01?l0000<okFF^003o`000?nXS;SoZ8bh00_o
Z8bh1?l00002ojN:]`03o`000?nIPk[oVH>j00goVH>j0ol00002oiV2^@03o`000?n9OL3oRGg000So
RGg00_l00008oh]m_`03o`000?mlOl_o000000WoOgo:00?o0000oh:1bOn2PLT01_n2PLT00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool001kooooo
0_l00017ooooo`05o`000?nW`>_oYl3[ojO0jol000001?nWaNl01?l0003oY/_cojK;lonVbo<2o`00
00;oY=7g00Co0000oj7InonQfO_oXMWk0_l00002oicOo@;o00001_nCi?`7o`0000?o<ISa1?l00009
ofV/m`Co00001onC`OH4o`0000CoR=?o00?o0000ojkLmon^g?L00_l000001?nMjo[o0000ogGSgome
hml2o`0000Wo`jJm1Ol0000BokFF^003o`000?nXS;SoZ8bh00KoZ8bh1?l00007ojN:]`03o`000?nI
Pk[oVH>j00WoVH>j0ol00006oiV2^@03o`000?n9OL3oRGg000GoRGg00_l0000:oh]m_`;o00002Omo
OlX00ol0003oPX79oh:1b@06oh:1b@03o`000?oooooooooo00kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`06ooooo`008?ooool00ol0003oooooooooo`15ooooo`05o`000?nW`>_o
Yl3[ojO0jol000001?nWaNl00ol0003oY/_cojK;l`02ojK;l`04o`000?nTdOOoY=7go`0000CoXMWk
0_l00002oicOo@?o000000?oTnClo`000?l000001Oo:in/5o`0000Co7Y_Y0_l00002ofV/m`Go0000
1?mL^?`2o`0000?oTl7f0_l00006ohSCo`[o00001Oo3Y[d7o`0000?o`J>k00?o0000okFF^?neU[P0
4OneU[P00ol0003oZ8bhojR<^003ojR<^0?o00002onWR[L00ol0003oVH>joiV3^P06oiV3^P?o0000
2OnIP[T00ol0003oRGg0ohUm`003ohUm`0;o00002_n;OKl2o`000003ohan__l0003oOgo:00OoOgo:
00?o0000oh:1bOn2PLT01_n2PLT00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0AOooool01Ol0003oYl3[ojO0
jonW`>_o000000CoYlG_00?o0000ojK;lonVbo<00_nVbo<00ol0003oY=7gojCAm`02o`0000CoXMWk
00?o0000oicOoOnLgod00ol0000<ol[Wj`So00002OmL^?`5o`0000?oR=?o1Ol00002ofkIm@Co0000
0oo3Y[d6o`0000[o`J>k00?o0000okFF^?neU[P04OneU[P00ol0003oZ8bho`000003o`0000koYhZg
00?o0000oiV3^_nIPkX00onIPkX3o`0000goVH:i00Go0000ohUm`?n9OL3oRGg0o`00000;oh]m_`03
o`000?n<O[koS7jn00;oS7jn00?o0000ogmob_moOlX01?moOlX00ol0003oPX79oh:1b@06oh:1b@03
o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`00
8_ooool00ol0003oooooooooo`14ooooo`03o`000?nW`>_oYl3[00;oYl3[00?o0000ojO5konWaNl0
0_nWaNl00ol0003oY/_cojK;l`02ojK;l`05o`000?nTdOOoY=7gojCAmol000000_nQfO/4o`0000Ko
b]oW1ol00003ol[Wj`04o`000?oEcmCoeLoDomG?e0Ko00000_mL^?`4o`0000;o@kc`1_l00004ofkI
m@Wo00004Oo1Xk/00ol0003o]IJhokFF^00>okFF^0Go00004onWR[L00ol0003oVH>jo`000002o`00
013oVH:i00Co0000ohUm`?l0003o00002_n;OKl2o`0000KoS7jn00?o0000ogmob_moOlX00_moOlX0
0ol0003oPX79oh:1b@06oh:1b@03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`05ooooo`008oooool2o`0004Gooooo00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYlG_ojO5k`02ojO5k`03o`000?nVbo?oY/_c00;oY/_c00?o0000ojCAmonTdOL00ol00005olWG
i0Go00001oo:gnL3o`000003omG?e?l0003o0000013o000000?o8Jg;o`000?l000001Ol00007olbc
`P03o`000?o1Xk_o`J>k013o`J>k00?o0000okFF^?neU[P02?neU[P7o`0000?o]9Bf00?o0000ojN:
]onWR[L04?nWR[L4o`0001?oVH:i0_l0000:oh]m_`;o00002?n<O[h01Ol0003oOgo:ogmob_moOl[o
000000SoPX7900?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Gooooo000Uooooo`03o`000?oooooooooo04?ooooo00?o0000ojO0jonW`>/00_nW`>/00ol0
003oYlG_ojO5k`02ojO5k`03o`000?nVbo?oY/_c00Co00001?o7d>43o`0000KobMOT1Ol00002ol[O
i`03o`000?oBb=3od/S@013od/S@00?o0000olbc`_o</l803oo</l800ol0003o`J>kol6S^`0@ol6S
^`04o`000?neU[So]IJhokFF^0Oo00002_ndU;H00ol0003oYhZgojN:]`0<ojN:]`Co00000_nVRKH0
0ol0003oVH:ioiV2^@0?oiV2^@?o000000?oVH6ho`000?n;OKl02?n;OKl00ol0003oS7jnohan_P09
ohan_P03o`000?moOl[o000000SoPX7900?o0000ooooooooool05oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Gooooo000Vooooo`03o`000?oooooooooo04?ooooo00?o0000ojO0
jonW`>/00_nW`>/00ol0003oYlG_ojO5k`04o`0000CoaL[N00?o0000olO@hOo7d>401?o7d>43o`00
00SobMOT0_l00004om;8d003o`000?oBb=3od/S@00_od/S@00?o0000olbc`_o</l803oo</l800ol0
003o`J>kol6S^`0<ol6S^`Wo00004OndU;H00ol0003oYhZgojN:]`08ojN:]`Co00001_nVRKH00ol0
003oVH:ioiV2^@0<oiV2^@?o00001OnIPKP00ol0003oRgfooh]m_`04oh]m_`;o00003?n<O[h2o`00
00SoPX7900?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo000Wooooo`03o`000?oooooooooo04?ooooo00Co0000ojO0jonW`>_oYl3[0ol00004ol?5
g003o`000?o5b]koaL[N00?oaL[N0_l00006olO@h@?o00001Oo9en@00ol0003od<?>om33cP04om33
cPWo00001?oBb=000ol0003oc;?2olbc`P0?olbc`P03o`000?o1Xk_o`J>k00;o`J>k2_l00005oknP
^@03o`000?ndU;Ko]9Bf01?o]9Bf00?o0000ojN:]onWR[L00onWR[L4o`0000_oYXVf00?o0000oiV2
^OnIP[T02?nIP[T3o`0000SoVH6h00?o0000oh]m_on;OKl00_n;OKl2o`0000goS7jn00?o0000oheo
_ol000001on2PLT00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool01Oooool002Sooooo0_l00014ooooo`03o`000?nW`>_o000000?o`L7J1_o3aM`00ol0003o
aL[NolG:gP03olG:gP?o00001_o7d>43o`000003olWGi?l0003od<?>00ood<?>1?l000000oo</l;o
0000o`00000Do`0000oo_j2i00?o0000okBD]_ndU;H04ondU;H00ol0003oYhZgo`000003o`0000oo
YXVf00?o0000oiV2^OnIP[T01OnIP[T3o`0000_oVH6h00Go0000oh]m_on;OKooRgfoo`00000=ohan
_P;o00000on=Okl00ol0003oPX79oh:1b@03oh:1b@03o`000?oooooooooo01cooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`12ooooo`03
o`000?o1`M[o`L7J00?o`L7J0_l00004ol?5g0;o00001_o5b]h2o`0000Ooam3Q00?o0000om33c_o@
`lh04_o@`lh00ol0003obK30olV``00@olV``003o`000?noX;Wo_j2i017o_j2i00?o0000okBD]_nd
U;H03ondU;H6o`0001?oYXVf00?o0000oiV2^OnIP[T00_nIP[T3o`0000ooVH6h0ol0000<ohan_P;o
00001_n=Okl01Ol0003oPX79oh:1bOn2PLWo0000023ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`04ooooo`00:oooool00ol0003oooooooooo`13ooooo`Ko`L7J00?o0000ol?5g?o3
aM`00oo3aM`2o`0000KoaL[N0_l00004olO@h@03o`000?o=_/cocKk<00;ocKk<1ol00009om33cP03
o`000?o9/<3obK30017obK3000?o0000oknP^OnoX;T04OnoX;T00ol0003o]9BfokBD]P08okBD]POo
00001?ncT[D00ol0003oYXVfojJ9]P0CojJ9]PCo00004OnIPKP2o`0000goS7jn00?o0000oheo_on=
Okl01on=Okl00ol0003oPX79o`00000Rooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01?ooool002cooooo00?o0000ooooooooool0@oooool00ol0003o`L7Jol71fP03ol71fP;o0000
1Oo3aM`2o`0000KoaL[N0_l000000oo7d>7o0000olfnc00;olfnc0Ko00000oo@`lh00ol0003obK30
olV``00@olV``003o`000?noX;Wo_j2i01;o_j2i00Co0000okBD]_ndU;Ko]9Bf1ol0000;ok>B]@03
o`000?nVRKKoYXVf017oYXVf0ol0000AoiV1^0?o000000?oVH6ho`000?n<O[h02_n<O[h2o`0000[o
SGno0_l0000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002gooooo
0_l00015ooooo`03o`000?o1`M[o`L7J00?o`L7J0_l00005ol?5g0;o00001_o5b]h00ol0003ocKk<
olfnc00Aolfnc0?o00000_o9/<08o`0000WobK3000?o0000oknP^OnoX;T02?noX;T>o`0001;o/i:e
00?o0000ojJ9]_nVRKH03OnVRKH4o`0000;oYXRe00?o0000oiV1^?nIPKP03OnIPKP2o`0000GoVH6h
00?o0000ohan__n<O[h01_n<O[h2o`0000_oSGno00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo000_ooooo`03o`000?oooooooooo04?ooooo00?o
0000ol71f_o1`MX01?o1`MX00ol0003o`lGLol?5g004ol?5g003o`000?o5b]koaL[N00;oaL[N00Co
0000ol^jb_o;^/[obk[:1?l0000?olfnc003o`000?o7[Kooajfo00Soajfo2_l000000onoX;Wo0000
o`000007o`0000[o_Yjh00?o0000ok>B]OncT[D05?ncT[D00ol0003oYXVfojJ9]P07ojJ9]PGo0000
1_nVR;D00ol0003oVH6hoiV1^00:oiV1^0?o00001onIPKP00ol0003oS7jnohan_P05ohan_P03o`00
0?n=OkooSGno00WoSGno0_l0000Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1?ooool0033ooooo00?o0000ooooooooool0@oooool2o`0000Go`L7J0_l00005ol?5g0;o000000?o
aL[No`000?o;^/X01oo;^/X4o`0000[ocKk<00?o0000olN]_oo7[Kl04_o7[Kl00ol0003o_YjhokjN
^00BokjN^003o`000?ncT[Go/i:e01Co/i:e00?o0000ojJ9]_nVRKH00onVRKH4o`0000coYXRe00?o
0000oiV1^?nIPKP01onIPKP2o`0000_oVH6h00?o0000ohan__n<O[h00_n<O[h2o`0000[oSGno0_l0
000[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0037ooooo0_l00015
ooooo`03o`000?o1`M[o`L7J00Co`L7J00?o0000ol?5g?o3aM`01?o3aM`00ol0003obk[:ol^jbP0;
ol^jbP?o00001_o=_/`00ol0003oajfoolN]_`0ColN]_`03o`000?nnW[So_Yjh01;o_Yjh00?o0000
ok>B]OncT[D05?ncT[D00ol0003oYXVfo`000003o`00013oYXRe00?o0000oiV1^?nIPKP01?nIPKP3
o`0000goVH6h00?o0000ohan__n<O[h00_l0000;oheo_`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00<oooool00ol0003oooooooooo`13oooo
o`;o00001Oo1`MX2o`0000?o`lGL00Co0000olRgbOo8]lWob;O90ol0000;ol^jbPCo00000_o=_/`0
0ol0003oajfoolN]_`0ColN]_`03o`000?nnW[So_Yjh01;o_Yjh00?o0000ok>B]OncT[D04?ncT[D6
o`0001CoYXRe00?o0000oiV1^?nIPKP00_nIPKP2o`00013oVH6h00?o0000ohan__l000002on=Okl2
o`0002oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?ooool00ol0
003oooooooooo`14ooooo`03o`000?o1`M[o`L7J00Co`L7J00?o0000ol?5g?l000001oo8]lT3o`00
00cobk[:0_l00002olN]_`Co00003oo7[Kl00ol0003o_YjhokjN^00CokjN^003o`000?ncT[Go/i:e
00So/i:e2?l00004ok:A]@03o`000?nVR;GoYXRe01CoYXRe1?l0000BoiV1^0;o00002on=Okl00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool003Go
oooo00?o0000ooooooooool0A?ooool00ol0003o`L7Jol71fP04ol71fP03o`000?o8]lWob;O900Wo
b;O91?l00009ol^jbP03o`000?o6Z[koaZZn00CoaZZn2ol00004olN]_`03o`000?nnW[So_Yjh01?o
_Yjh00Co0000ok>B]OncT[Go/i:e1ol0000<ok:A]@03o`000?nVR;GoYXRe01;oYXRe0ol0000BoiV1
^0?o000000?oVX:ho`000?n=Okl02?n=Okl2o`0003Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`00=_ooool2o`0004Gooooo0_l00003ol71fP04o`000?o6]LWoa[G9olJe
b@;o00002oo8]lT3o`0000Gobk[:00?o0000olJZ__o6Z[h04?o6Z[h5o`000003okjN^?l0003o0000
01Ko00004onbTKD00ol0003oYXReojJ8]@0=ojJ8]@Go00000_nVR;D00ol0003oVH6hoiV1^00=oiV1
^0?o00001OnJP[P00ol0003oSGnooheo_`05oheo_`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`03
o`000?o1`M[o000000Ooa[G90ol0000:olRgb@?o00000_o;^/X00ol0003oaZZnolJZ_P0DolJZ_P03
o`000?nmW;So_Ibh01?o_Ibh00?o0000ok:A]OnbTKD05OnbTKD00ol0003oYXReojJ8]@08ojJ8]@Co
00001onVR;D00ol0003oVH6hoiV1^00;oiV1^0;o00002?nJP[P00ol0003oSGnooheo_`03oheo_`;o
0000>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`00
0?oooooooooo04Cooooo00?o0000olJebOo6]LT02Oo6]LT3o`0000[ob;O90_l0000GolJZ_P03o`00
0?nmW;So_Ibh01?o_Ibh00?o0000ok:A]OnbTKD05OnbTKD00ol0003oYXReojJ8]@04ojJ8]@Co0000
3?nVR;D00ol0003oVH6hoiV1^007oiV1^0?o00002onJP[P00ol0003oSGnooheo_`02o`0003_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00>_ooool00ol0003ooooooooo
o`15ooooo`;o00002oo6]LT3o`0000Sob;O900?o0000olBX__o4Z;h00_o4Z;h8o`0000[oaZZn00?o
0000okfL^?nmW;P05?nmW;P00ol0003o/Y6eok:A]@0Eok:A]@03o`000?nVR;Go000000Co00004?nV
R;D00ol0003oVH6hoiV1^005oiV1^0;o00003_nJP[P00ol0003oSGnoo`00000nooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool003_ooooo0_l00018ooooo`;o00002oo6]LT3
o`0000Cob;O900?o0000olBX__o4Z;h02oo4Z;h7o`0000?oaZZn00?o0000okfL^?nmW;P05?nmW;P0
0ol0003o/Y6eok:A]@0?ok:A]@So00005OnVR;D00ol0003oVH6hoiV1^002oiV1^0?o00004?nJP[P2
o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00?Oooool00ol0
003oooooooooo`17ooooo`?o00002oo6]LT3o`000003olRgbOl0003oa:Rn01?oa:Rn1?l000000onm
W;So0000o`000009o`0000[o_Ibh00?o0000ok:A]OnbTKD00onbTKD<o`0000Ko/I6e00?o0000ojJ8
]OnVR;D05OnVR;D4o`00013oVX:h0ol00012ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool003kooooo00?o0000ooooooooool0BOooool2o`0000coa[G900?o0000olBX__o4
Z;h05_o4Z;h00ol0003o^ibhok^L^00:ok^L^13o00004_naTKD00ol0003oYXReojJ8]@0CojJ8]@?o
00004?nJP[P3o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
?oooool00ol0003oooooooooo`1:ooooo`;o00002_o6]LT00ol0003o`ZNnol:W_P05o`00013oa:Rn
00?o0000ok^L^?nkW;P05OnkW;P00ol0003o/I6eok6A]@0Eok6A]@03o`000?nVR;GoYXRe00koYXRe
1Ol00002ojJ8]P03o`000?nJP[SoVX:h00_oVX:h0ol0001:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool0043ooooo0_l0001<ooooo`?o00001_o6]LT00ol0003o`ZNnol:W
_P06ol:W_PGo00002oo4Z;h00ol0003o^ibhok^L^00Eok^L^003o`000?naTKGo/I6e01Ko/I6e00?o
0000ojJ8]OnVR;D02?nVR;D5o`0000SoYXRf00?o0000oiZ2^?nJP[P02?nJP[P2o`0004gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@_ooool00ol0003oooooooooo`1<
ooooo`;o00001?o6]LT00ol0003o`ZNnol:W_P0;ol:W_PCo00001oo4Z;h00ol0003o^ibhok^L^00E
ok^L^003o`000?naTKGo/I6e01Ko/I6e00?o0000ojJ8]OnVR;D01?nVR;D4o`0000goYXRf00?o0000
oiZ2^?nJP[P01OnJP[P3o`00053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`00@oooool00ol0003oooooooooo`1=ooooo`?o000000?oa[G9o`000?o2Ykh04?o2Ykh5o`00
0003olBX__l0003o^ibh01Oo^ibh00?o0000ok6A]OnaTKD05_naTKD00ol0003oYXReo`000004o`00
017oYXRf00?o0000oiZ2^?nJP[P00_nJP[P3o`0005Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`1?ooooo`03o`000?o2Ykko`ZNn01Go
`ZNn0_l00002ok^L^0_o00002onkW;P00ol0003o/I6eok6A]@0:ok6A]@ko00005onVR;H4o`0005So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2o`0005;ooooo
1Ol0000Aol:W_P03o`000?njVkSo^Y^h00_o^Y^h6?l0000<ok2A]P03o`000?nVR;KoYXRf01CoYXRf
0ol0001Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Oooooo00?o
0000ooooooooool0E?ooool5o`0000co`ZNn00?o0000okZK^?njVkP05_njVkP00ol0003o/96fok2A
]P0Fok2A]P03o`000?nVR;KoYXRf00ooYXRf1Ol0001Oooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool004Sooooo00?o0000ooooooooool0F?ooool5o`0000Ko`ZNn00?o0000
okZK^?njVkP05onjVkP00ol0003o/96fok2A]P0Fok2A]P03o`000?nVR;KoYXRf00[oYXRf1Ol0001U
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool004Wooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`02ooooo`Go000000?o`ZNno`000?njVkP06?njVkP00ol0
003o/96fok2A]P0Gok2A]P03o`000?nVR;KoYXRf00CoYXRf1Ol0001[ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00Oooool004[ooooo0_l0001Gooooo`03o`000?oooooooooo00Oo
oooo0_l00002okZK^0;o00005OnjVkP00ol0003o/96fok2A]P0Gok2A]P03o`000?nVR;Ko000000Co
0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001<ooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool03Oooool9o`0000co^Y^h00?o0000ok2A]_n`TKH0
4On`TKH8o`0007Kooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool004gooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0Fooooo`Wo00000onjVkP00ol0003o/96fok2A
]P04ok2A]Pgo0000Ooooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00C_ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo01oooooo2_l0002<ooooo`03o`000?oooooo
oooo00Oooooo0Ol00001ooooo`7ooooo001?ooooo`;o0000D_ooool00ol0003oooooooooo`2foooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00
D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool005?ooooo0_l0001>ooooo`03o`000?oooooooooo0;Sooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool005Gooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00E_ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool00oooool1o`00
007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0^oooool00ol0003o
ooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo0;_ooooo
00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0_?ooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool0_Oooool01?l0003oooooooooool00001ooooo`00G?oo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooool000000Ooo
ool005gooooo0_l00014ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool00Ol00000
05oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2oooooo`7o00000Oooool1o`00
0000H?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo0_l00000067ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000?ooo
ool00ol0003oooooooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`2cooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`2`ooooo`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:cooooo
1?l0000Booooo`00JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo1?l0
000Fooooo`00J_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0000J
ooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000Noooo
o`00K?ooool2o`0003Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?ooool0
0ol0003oooooooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`2>ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`2:ooooo`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`26ooooo`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo1?l0
000mooooo`00Moooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l00011
ooooo`00N?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015oooo
o`00NOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019ooooo`00
N_ooool2o`0002Kooooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0003o
ooooooooo`1Sooooo`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1Oooooo`Co0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`1Kooooo`Co0000I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1G
ooooo`Co0000J?ooool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/oooo
o`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`ooooo`00
Qoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00R?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROooool2
o`0001Oooooo00?o0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003ooooooooo
o`0dooooo`Co0000Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0a
ooooo`Co0000Soooool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^oooo
o`?o0000Toooool009;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Fooooo`00
U?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00UOoo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2o`00
00Sooooo00?o0000ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003oooooooooo`0;
ooooo`?o0000]_ooool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002Ooooo
o`03o`000?oooooo000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o000000;o
0000`Oooool00:7ooooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886655, -0.0135833, \
0.0036241, 0.0036241}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51728 .63749 m .51694 .65827 L .43899 .65168 L p .731 .599 .71 r
F P
0 g
s
.51694 .65827 m .51728 .63749 L .59234 .63299 L p .691 .565 .707 r
F P
0 g
s
.59234 .63299 m .59527 .65394 L .51694 .65827 L p .691 .565 .707 r
F P
0 g
s
.43899 .65168 m .44255 .63234 L .51728 .63749 L p .731 .599 .71 r
F P
0 g
s
.51762 .61642 m .51728 .63749 L .44255 .63234 L p .733 .599 .708 r
F P
0 g
s
.51728 .63749 m .51762 .61642 L .58941 .61175 L p .692 .564 .706 r
F P
0 g
s
.58941 .61175 m .59234 .63299 L .51728 .63749 L p .692 .564 .706 r
F P
0 g
s
.44255 .63234 m .44613 .61274 L .51762 .61642 L p .733 .599 .708 r
F P
0 g
s
.51796 .59536 m .51762 .61642 L .44613 .61274 L p .735 .601 .708 r
F P
0 g
s
.51762 .61642 m .51796 .59536 L .58648 .59053 L p .692 .564 .706 r
F P
0 g
s
.58648 .59053 m .58941 .61175 L .51762 .61642 L p .692 .564 .706 r
F P
0 g
s
.44613 .61274 m .4497 .59313 L .51796 .59536 L p .735 .601 .708 r
F P
0 g
s
.5183 .5746 m .51796 .59536 L .4497 .59313 L p .738 .605 .71 r
F P
0 g
s
.51796 .59536 m .5183 .5746 L .58355 .56963 L p .693 .566 .708 r
F P
0 g
s
.58355 .56963 m .58648 .59053 L .51796 .59536 L p .693 .566 .708 r
F P
0 g
s
.4497 .59313 m .45326 .57379 L .5183 .5746 L p .738 .605 .71 r
F P
0 g
s
.51864 .55444 m .5183 .5746 L .45326 .57379 L p .74 .611 .714 r
F P
0 g
s
.5183 .5746 m .51864 .55444 L .58064 .54935 L p .694 .57 .711 r
F P
0 g
s
.58064 .54935 m .58355 .56963 L .5183 .5746 L p .694 .57 .711 r
F P
0 g
s
.45326 .57379 m .45682 .55499 L .51864 .55444 L p .74 .611 .714 r
F P
0 g
s
.51897 .53515 m .51864 .55444 L .45682 .55499 L p .744 .619 .72 r
F P
0 g
s
.51864 .55444 m .51897 .53515 L .57773 .52996 L p .695 .576 .718 r
F P
0 g
s
.57773 .52996 m .58064 .54935 L .51864 .55444 L p .695 .576 .718 r
F P
0 g
s
.45682 .55499 m .46037 .53698 L .51897 .53515 L p .744 .619 .72 r
F P
0 g
s
.51931 .51698 m .51897 .53515 L .46037 .53698 L p .747 .629 .729 r
F P
0 g
s
.51897 .53515 m .51931 .51698 L .57485 .51173 L p .697 .585 .727 r
F P
0 g
s
.57485 .51173 m .57773 .52996 L .51897 .53515 L p .697 .585 .727 r
F P
0 g
s
.46037 .53698 m .4639 .52 L .51931 .51698 L p .747 .629 .729 r
F P
0 g
s
.51964 .50016 m .51931 .51698 L .4639 .52 L p .751 .643 .742 r
F P
0 g
s
.51931 .51698 m .51964 .50016 L .57198 .49488 L p .698 .597 .739 r
F P
0 g
s
.57198 .49488 m .57485 .51173 L .51931 .51698 L p .698 .597 .739 r
F P
0 g
s
.58648 .59053 m .58355 .56963 L .64589 .5591 L p .645 .537 .717 r
F P
0 g
s
.58355 .56963 m .58064 .54935 L .63984 .53995 L p .644 .54 .721 r
F P
0 g
s
.63984 .53995 m .64589 .5591 L .58355 .56963 L p .644 .54 .721 r
F P
0 g
s
.58941 .61175 m .58648 .59053 L .65197 .57884 L p .646 .536 .714 r
F P
0 g
s
.64589 .5591 m .65197 .57884 L .58648 .59053 L p .645 .537 .717 r
F P
0 g
s
.58064 .54935 m .57773 .52996 L .63382 .52166 L p .643 .545 .728 r
F P
0 g
s
.63382 .52166 m .63984 .53995 L .58064 .54935 L p .643 .545 .728 r
F P
0 g
s
.59234 .63299 m .58941 .61175 L .65805 .5989 L p .648 .537 .714 r
F P
0 g
s
.65197 .57884 m .65805 .5989 L .58941 .61175 L p .646 .536 .714 r
F P
0 g
s
.59527 .65394 m .59234 .63299 L .66415 .61899 L p .65 .539 .716 r
F P
0 g
s
.65805 .5989 m .66415 .61899 L .59234 .63299 L p .648 .537 .714 r
F P
0 g
s
.66415 .61899 m .67023 .63881 L .59527 .65394 L p .65 .539 .716 r
F P
0 g
s
.57773 .52996 m .57485 .51173 L .62784 .50449 L p .642 .553 .739 r
F P
0 g
s
.62784 .50449 m .63382 .52166 L .57773 .52996 L p .642 .553 .739 r
F P
0 g
s
.4639 .52 m .46742 .50424 L .51964 .50016 L p .751 .643 .742 r
F P
0 g
s
.51998 .4849 m .51964 .50016 L .46742 .50424 L p .755 .661 .758 r
F P
0 g
s
.51964 .50016 m .51998 .4849 L .56912 .47963 L p .7 .613 .756 r
F P
0 g
s
.56912 .47963 m .57198 .49488 L .51964 .50016 L p .7 .613 .756 r
F P
0 g
s
.57485 .51173 m .57198 .49488 L .62189 .48866 L p .641 .564 .752 r
F P
0 g
s
.62189 .48866 m .62784 .50449 L .57485 .51173 L p .641 .564 .752 r
F P
0 g
s
.44255 .63234 m .43899 .65168 L .36521 .63435 L p .766 .641 .723 r
F P
0 g
s
.36521 .63435 m .3718 .61768 L .44255 .63234 L p .766 .641 .723 r
F P
0 g
s
.44613 .61274 m .44255 .63234 L .3718 .61768 L p .771 .644 .721 r
F P
0 g
s
.57198 .49488 m .56912 .47963 L .61597 .47437 L p .639 .579 .771 r
F P
0 g
s
.61597 .47437 m .62189 .48866 L .57198 .49488 L p .639 .579 .771 r
F P
0 g
s
.3718 .61768 m .3784 .60077 L .44613 .61274 L p .771 .644 .721 r
F P
0 g
s
.4497 .59313 m .44613 .61274 L .3784 .60077 L p .775 .648 .722 r
F P
0 g
s
.3784 .60077 m .38501 .58385 L .4497 .59313 L p .775 .648 .722 r
F P
0 g
s
.45326 .57379 m .4497 .59313 L .38501 .58385 L p .779 .654 .724 r
F P
0 g
s
.38501 .58385 m .39161 .56716 L .45326 .57379 L p .779 .654 .724 r
F P
0 g
s
.45682 .55499 m .45326 .57379 L .39161 .56716 L p .784 .662 .729 r
F P
0 g
s
.46742 .50424 m .47092 .48992 L .51998 .4849 L p .755 .661 .758 r
F P
0 g
s
.52031 .47137 m .51998 .4849 L .47092 .48992 L p .759 .686 .781 r
F P
0 g
s
.51998 .4849 m .52031 .47137 L .56628 .46615 L p .702 .634 .778 r
F P
0 g
s
.56628 .46615 m .56912 .47963 L .51998 .4849 L p .702 .634 .778 r
F P
0 g
s
.39161 .56716 m .3982 .55091 L .45682 .55499 L p .784 .662 .729 r
F P
0 g
s
.46037 .53698 m .45682 .55499 L .3982 .55091 L p .789 .673 .736 r
F P
0 g
s
.56912 .47963 m .56628 .46615 L .61008 .46178 L p .636 .6 .796 r
F P
0 g
s
.61008 .46178 m .61597 .47437 L .56912 .47963 L p .636 .6 .796 r
F P
0 g
s
.3982 .55091 m .40478 .53533 L .46037 .53698 L p .789 .673 .736 r
F P
0 g
s
.4639 .52 m .46037 .53698 L .40478 .53533 L p .794 .687 .747 r
F P
0 g
s
.40478 .53533 m .41134 .5206 L .4639 .52 L p .794 .687 .747 r
F P
0 g
s
.46742 .50424 m .4639 .52 L .41134 .5206 L p .799 .705 .76 r
F P
0 g
s
.47092 .48992 m .47441 .47718 L .52031 .47137 L p .759 .686 .781 r
F P
0 g
s
.52064 .45972 m .52031 .47137 L .47441 .47718 L p .763 .718 .811 r
F P
0 g
s
.52031 .47137 m .52064 .45972 L .56345 .45459 L p .702 .663 .808 r
F P
0 g
s
.56345 .45459 m .56628 .46615 L .52031 .47137 L p .702 .663 .808 r
F P
0 g
s
.56628 .46615 m .56345 .45459 L .60421 .45104 L p .631 .628 .829 r
F P
0 g
s
.60421 .45104 m .61008 .46178 L .56628 .46615 L p .631 .628 .829 r
F P
0 g
s
.41134 .5206 m .41788 .50691 L .46742 .50424 L p .799 .705 .76 r
F P
0 g
s
.47092 .48992 m .46742 .50424 L .41788 .50691 L p .805 .728 .779 r
F P
0 g
s
.47441 .47718 m .47789 .46616 L .52064 .45972 L p .763 .718 .811 r
F P
0 g
s
.52097 .45005 m .52064 .45972 L .47789 .46616 L p .764 .761 .85 r
F P
0 g
s
.52064 .45972 m .52097 .45005 L .56063 .44506 L p .7 .702 .849 r
F P
0 g
s
.56063 .44506 m .56345 .45459 L .52064 .45972 L p .7 .702 .849 r
F P
0 g
s
.41788 .50691 m .42439 .49443 L .47092 .48992 L p .805 .728 .779 r
F P
0 g
s
.47441 .47718 m .47092 .48992 L .42439 .49443 L p .811 .758 .803 r
F P
0 g
s
.64589 .5591 m .63984 .53995 L .69326 .52658 L p .59 .522 .746 r
F P
0 g
s
.63984 .53995 m .63382 .52166 L .6844 .51058 L p .585 .526 .756 r
F P
0 g
s
.6844 .51058 m .69326 .52658 L .63984 .53995 L p .585 .526 .756 r
F P
0 g
s
.65197 .57884 m .64589 .5591 L .70216 .54336 L p .594 .519 .74 r
F P
0 g
s
.69326 .52658 m .70216 .54336 L .64589 .5591 L p .59 .522 .746 r
F P
0 g
s
.63382 .52166 m .62784 .50449 L .67559 .49558 L p .58 .534 .768 r
F P
0 g
s
.67559 .49558 m .6844 .51058 L .63382 .52166 L p .58 .534 .768 r
F P
0 g
s
.65805 .5989 m .65197 .57884 L .7111 .56068 L p .598 .519 .736 r
F P
0 g
s
.70216 .54336 m .7111 .56068 L .65197 .57884 L p .594 .519 .74 r
F P
0 g
s
.56345 .45459 m .56063 .44506 L .59836 .44225 L p .619 .666 .873 r
F P
0 g
s
.59836 .44225 m .60421 .45104 L .56345 .45459 L p .619 .666 .873 r
F P
0 g
s
.62784 .50449 m .62189 .48866 L .66682 .48179 L p .573 .546 .786 r
F P
0 g
s
.66682 .48179 m .67559 .49558 L .62784 .50449 L p .573 .546 .786 r
F P
0 g
s
.66415 .61899 m .65805 .5989 L .72006 .57828 L p .603 .521 .735 r
F P
0 g
s
.7111 .56068 m .72006 .57828 L .65805 .5989 L p .598 .519 .736 r
F P
0 g
s
.67023 .63881 m .66415 .61899 L .72903 .59592 L p .607 .525 .736 r
F P
0 g
s
.72006 .57828 m .72903 .59592 L .66415 .61899 L p .603 .521 .735 r
F P
0 g
s
.72903 .59592 m .73799 .61332 L .67023 .63881 L p .607 .525 .736 r
F P
0 g
s
.62189 .48866 m .61597 .47437 L .65811 .46938 L p .565 .561 .808 r
F P
0 g
s
.65811 .46938 m .66682 .48179 L .62189 .48866 L p .565 .561 .808 r
F P
0 g
s
.42439 .49443 m .4309 .48329 L .47441 .47718 L p .811 .758 .803 r
F P
0 g
s
.47789 .46616 m .47441 .47718 L .4309 .48329 L p .814 .796 .835 r
F P
0 g
s
.61597 .47437 m .61008 .46178 L .64943 .4585 L p .553 .583 .838 r
F P
0 g
s
.64943 .4585 m .65811 .46938 L .61597 .47437 L p .553 .583 .838 r
F P
0 g
s
.47789 .46616 m .48137 .45696 L .52097 .45005 L p .764 .761 .85 r
F P
0 g
s
.52129 .44244 m .52097 .45005 L .48137 .45696 L p .756 .817 .9 r
F P
0 g
s
.52097 .45005 m .52129 .44244 L .55781 .43763 L p .689 .755 .902 r
F P
0 g
s
.55781 .43763 m .56063 .44506 L .52097 .45005 L p .689 .755 .902 r
F P
0 g
s
.56063 .44506 m .55781 .43763 L .59251 .43549 L p .594 .716 .929 r
F P
0 g
s
.59251 .43549 m .59836 .44225 L .56063 .44506 L p .594 .716 .929 r
F P
0 g
s
.3718 .61768 m .36521 .63435 L .29943 .6068 L p .795 .691 .75 r
F P
0 g
s
.29943 .6068 m .30869 .5939 L .3718 .61768 L p .795 .691 .75 r
F P
0 g
s
.3784 .60077 m .3718 .61768 L .30869 .5939 L p .802 .697 .75 r
F P
0 g
s
.61008 .46178 m .60421 .45104 L .64079 .44927 L p .534 .612 .877 r
F P
0 g
s
.64079 .44927 m .64943 .4585 L .61008 .46178 L p .534 .612 .877 r
F P
0 g
s
.30869 .5939 m .31798 .58083 L .3784 .60077 L p .802 .697 .75 r
F P
0 g
s
.38501 .58385 m .3784 .60077 L .31798 .58083 L p .808 .705 .751 r
F P
0 g
s
.4309 .48329 m .43739 .47361 L .47789 .46616 L p .814 .796 .835 r
F P
0 g
s
.48137 .45696 m .47789 .46616 L .43739 .47361 L p .813 .846 .874 r
F P
0 g
s
.31798 .58083 m .32728 .56775 L .38501 .58385 L p .808 .705 .751 r
F P
0 g
s
.39161 .56716 m .38501 .58385 L .32728 .56775 L p .815 .715 .755 r
F P
0 g
s
.32728 .56775 m .33657 .55483 L .39161 .56716 L p .815 .715 .755 r
F P
0 g
s
.3982 .55091 m .39161 .56716 L .33657 .55483 L p .821 .728 .762 r
F P
0 g
s
.33657 .55483 m .34586 .54224 L .3982 .55091 L p .821 .728 .762 r
F P
0 g
s
.40478 .53533 m .3982 .55091 L .34586 .54224 L p .827 .743 .771 r
F P
0 g
s
.34586 .54224 m .35514 .53014 L .40478 .53533 L p .827 .743 .771 r
F P
0 g
s
.41134 .5206 m .40478 .53533 L .35514 .53014 L p .834 .763 .784 r
F P
0 g
s
.60421 .45104 m .59836 .44225 L .63217 .44181 L p .5 .649 .924 r
F P
0 g
s
.63217 .44181 m .64079 .44927 L .60421 .45104 L p .5 .649 .924 r
F P
0 g
s
.48137 .45696 m .48485 .44964 L .52129 .44244 L p .756 .817 .9 r
F P
0 g
s
.52162 .43693 m .52129 .44244 L .48485 .44964 L p .723 .883 .955 r
F P
0 g
s
.52129 .44244 m .52162 .43693 L .55498 .43235 L p .654 .819 .963 r
F P
0 g
s
.55498 .43235 m .55781 .43763 L .52129 .44244 L p .654 .819 .963 r
F P
0 g
s
.55781 .43763 m .55498 .43235 L .58666 .43079 L p .532 .77 .985 r
F P
0 g
s
.58666 .43079 m .59251 .43549 L .55781 .43763 L p .532 .77 .985 r
F P
0 g
s
.35514 .53014 m .36441 .51867 L .41134 .5206 L p .834 .763 .784 r
F P
0 g
s
.41788 .50691 m .41134 .5206 L .36441 .51867 L p .84 .787 .801 r
F P
0 g
s
.43739 .47361 m .44387 .46547 L .48137 .45696 L p .813 .846 .874 r
F P
0 g
s
.48485 .44964 m .48137 .45696 L .44387 .46547 L p .794 .904 .919 r
F P
0 g
s
.36441 .51867 m .37365 .50798 L .41788 .50691 L p .84 .787 .801 r
F P
0 g
s
.42439 .49443 m .41788 .50691 L .37365 .50798 L p .845 .818 .823 r
F P
0 g
s
.59836 .44225 m .59251 .43549 L .62357 .43616 L p .436 .687 .971 r
F P
0 g
s
.62357 .43616 m .63217 .44181 L .59836 .44225 L p .436 .687 .971 r
F P
0 g
s
.37365 .50798 m .38289 .49819 L .42439 .49443 L p .845 .818 .823 r
F P
0 g
s
.4309 .48329 m .42439 .49443 L .38289 .49819 L p .847 .856 .849 r
F P
0 g
s
.48485 .44964 m .48833 .44426 L .52162 .43693 L p .723 .883 .955 r
F P
0 g
s
.52196 .43352 m .52162 .43693 L .48833 .44426 L p .616 .924 .973 r
F P
0 g
s
.52162 .43693 m .52196 .43352 L .55215 .42923 L p .552 .867 .995 r
F P
0 g
s
.55215 .42923 m .55498 .43235 L .52162 .43693 L p .552 .867 .995 r
F P
0 g
s
.44387 .46547 m .45036 .45892 L .48485 .44964 L p .794 .904 .919 r
F P
0 g
s
.48833 .44426 m .48485 .44964 L .45036 .45892 L p .73 .954 .947 r
F P
0 g
s
.55498 .43235 m .55215 .42923 L .5808 .42816 L p .389 .788 .986 r
F P
0 g
s
.5808 .42816 m .58666 .43079 L .55498 .43235 L p .389 .788 .986 r
F P
0 g
s
.38289 .49819 m .39211 .48941 L .4309 .48329 L p .847 .856 .849 r
F P
0 g
s
.43739 .47361 m .4309 .48329 L .39211 .48941 L p .84 .9 .88 r
F P
0 g
s
.59251 .43549 m .58666 .43079 L .61496 .43236 L p .311 .703 .979 r
F P
0 g
s
.61496 .43236 m .62357 .43616 L .59251 .43549 L p .311 .703 .979 r
F P
0 g
s
.69326 .52658 m .6844 .51058 L .72658 .49717 L p .52 .531 .807 r
F P
0 g
s
.6844 .51058 m .67559 .49558 L .71537 .48539 L p .507 .539 .824 r
F P
0 g
s
.71537 .48539 m .72658 .49717 L .6844 .51058 L p .507 .539 .824 r
F P
0 g
s
.70216 .54336 m .69326 .52658 L .73783 .50977 L p .532 .525 .794 r
F P
0 g
s
.72658 .49717 m .73783 .50977 L .69326 .52658 L p .52 .531 .807 r
F P
0 g
s
.67559 .49558 m .66682 .48179 L .70423 .47459 L p .489 .552 .847 r
F P
0 g
s
.70423 .47459 m .71537 .48539 L .67559 .49558 L p .489 .552 .847 r
F P
0 g
s
.7111 .56068 m .70216 .54336 L .74914 .52301 L p .542 .523 .784 r
F P
0 g
s
.73783 .50977 m .74914 .52301 L .70216 .54336 L p .532 .525 .794 r
F P
0 g
s
.72006 .57828 m .7111 .56068 L .76048 .53669 L p .551 .523 .777 r
F P
0 g
s
.74914 .52301 m .76048 .53669 L .7111 .56068 L p .542 .523 .784 r
F P
0 g
s
.66682 .48179 m .65811 .46938 L .69314 .46493 L p .465 .569 .875 r
F P
0 g
s
.69314 .46493 m .70423 .47459 L .66682 .48179 L p .465 .569 .875 r
F P
0 g
s
.72903 .59592 m .72006 .57828 L .77186 .5506 L p .56 .526 .774 r
F P
0 g
s
.76048 .53669 m .77186 .5506 L .72006 .57828 L p .551 .523 .777 r
F P
0 g
s
.73799 .61332 m .72903 .59592 L .78325 .56455 L p .569 .53 .772 r
F P
0 g
s
.77186 .5506 m .78325 .56455 L .72903 .59592 L p .56 .526 .774 r
F P
0 g
s
.65811 .46938 m .64943 .4585 L .68209 .45651 L p .43 .59 .909 r
F P
0 g
s
.68209 .45651 m .69314 .46493 L .65811 .46938 L p .43 .59 .909 r
F P
0 g
s
.39211 .48941 m .40132 .48172 L .43739 .47361 L p .84 .9 .88 r
F P
0 g
s
.44387 .46547 m .43739 .47361 L .40132 .48172 L p .815 .948 .909 r
F P
0 g
s
.78325 .56455 m .79464 .57831 L .73799 .61332 L p .569 .53 .772 r
F P
0 g
s
.45036 .45892 m .45686 .45402 L .48833 .44426 L p .73 .954 .947 r
F P
0 g
s
.49183 .44081 m .48833 .44426 L .45686 .45402 L p .567 .937 .899 r
F P
0 g
s
.48833 .44426 m .49183 .44081 L .52196 .43352 L p .616 .924 .973 r
F P
0 g
s
.64943 .4585 m .64079 .44927 L .67109 .44946 L p .376 .614 .943 r
F P
0 g
s
.67109 .44946 m .68209 .45651 L .64943 .4585 L p .376 .614 .943 r
F P
0 g
s
.52229 .4322 m .52196 .43352 L .49183 .44081 L p .372 .84 .85 r
F P
0 g
s
.52196 .43352 m .52229 .4322 L .5493 .42822 L p .317 .801 .889 r
F P
0 g
s
.5493 .42822 m .55215 .42923 L .52196 .43352 L p .317 .801 .889 r
F P
0 g
s
.55215 .42923 m .5493 .42822 L .5749 .42756 L p .134 .678 .82 r
F P
0 g
s
.5808 .42816 m .55215 .42923 L p .57219 .42776 L .134 .678 .82 r
F P
0 g
s
.54642 .42927 m .56896 .42894 L p .55189 .42832 L .127 0 0 r
F P
0 g
s
.5493 .42822 m .54881 .4284 L p .55189 .42832 L .127 0 0 r
F P
0 g
s
.54881 .4284 m .54642 .42927 L p .55189 .42832 L .127 0 0 r
F P
0 g
s
.5749 .42756 m .57587 .42766 L p .57219 .42776 L .134 .678 .82 r
F P
0 g
s
.57587 .42766 m .5808 .42816 L p .57219 .42776 L .134 .678 .82 r
F P
0 g
s
.58666 .43079 m .5808 .42816 L .60633 .43042 L p .106 .638 .868 r
F P
0 g
s
.60633 .43042 m .61496 .43236 L .58666 .43079 L p .106 .638 .868 r
F P
0 g
s
.40132 .48172 m .41054 .47518 L .44387 .46547 L p .815 .948 .909 r
F P
0 g
s
.45036 .45892 m .44387 .46547 L .41054 .47518 L p .745 .979 .917 r
F P
0 g
s
.64079 .44927 m .63217 .44181 L .66011 .44384 L p .288 .629 .962 r
F P
0 g
s
.66011 .44384 m .67109 .44946 L .64079 .44927 L p .288 .629 .962 r
F P
0 g
s
.30869 .5939 m .29943 .6068 L .24558 .56996 L p .806 .745 .796 r
F P
0 g
s
.24558 .56996 m .25702 .56182 L .30869 .5939 L p .806 .745 .796 r
F P
0 g
s
.31798 .58083 m .30869 .5939 L .25702 .56182 L p .815 .757 .798 r
F P
0 g
s
.25702 .56182 m .26849 .55358 L .31798 .58083 L p .815 .757 .798 r
F P
0 g
s
.32728 .56775 m .31798 .58083 L .26849 .55358 L p .823 .771 .803 r
F P
0 g
s
.63217 .44181 m .62357 .43616 L .64916 .43971 L p .15 .612 .929 r
F P
0 g
s
.64916 .43971 m .66011 .44384 L .63217 .44181 L p .15 .612 .929 r
F P
0 g
s
.26849 .55358 m .27998 .54533 L .32728 .56775 L p .823 .771 .803 r
F P
0 g
s
.33657 .55483 m .32728 .56775 L .27998 .54533 L p .831 .787 .81 r
F P
0 g
s
.45686 .45402 m .46339 .45074 L .49183 .44081 L p .567 .937 .899 r
F P
0 g
s
.49535 .43926 m .49183 .44081 L .46339 .45074 L p .286 .775 .708 r
F P
0 g
s
.49183 .44081 m .49535 .43926 L .52229 .4322 L p .372 .84 .85 r
F P
0 g
s
.27998 .54533 m .29147 .53717 L .33657 .55483 L p .831 .787 .81 r
F P
0 g
s
.34586 .54224 m .33657 .55483 L .29147 .53717 L p .838 .807 .82 r
F P
0 g
s
.41054 .47518 m .41976 .46984 L .45036 .45892 L p .745 .979 .917 r
F P
0 g
s
.45686 .45402 m .45036 .45892 L .41976 .46984 L p .595 .95 .861 r
F P
0 g
s
.5808 .42816 m .5749 .42756 L .59767 .4303 L p .122 0 0 r
F P
0 g
s
.59767 .4303 m .60633 .43042 L .5808 .42816 L p .122 0 0 r
F P
0 g
s
.29147 .53717 m .30297 .52919 L .34586 .54224 L p .838 .807 .82 r
F P
0 g
s
.35514 .53014 m .34586 .54224 L .30297 .52919 L p .844 .83 .834 r
F P
0 g
s
.52262 .43288 m .52229 .4322 L .49535 .43926 L p 0 0 0 r
F P
0 g
s
.52229 .4322 m .52262 .43288 L .54642 .42927 L p 0 0 0 r
F P
0 g
s
.54642 .42927 m .5493 .42822 L .52229 .4322 L p 0 0 0 r
F P
0 g
s
.56896 .42894 m .5749 .42756 L .5493 .42822 L p .127 0 0 r
F P
0 g
s
.30297 .52919 m .31447 .5215 L .35514 .53014 L p .844 .83 .834 r
F P
0 g
s
.36441 .51867 m .35514 .53014 L .31447 .5215 L p .847 .858 .85 r
F P
0 g
s
.62357 .43616 m .61496 .43236 L .6382 .4371 L p 0 .533 .797 r
F P
0 g
s
.6382 .4371 m .64916 .43971 L .62357 .43616 L p 0 .533 .797 r
F P
0 g
s
.31447 .5215 m .32596 .51418 L .36441 .51867 L p .847 .858 .85 r
F P
0 g
s
.37365 .50798 m .36441 .51867 L .32596 .51418 L p .847 .89 .869 r
F P
0 g
s
.32596 .51418 m .33746 .5073 L .37365 .50798 L p .847 .89 .869 r
F P
0 g
s
.38289 .49819 m .37365 .50798 L .33746 .5073 L p .838 .925 .89 r
F P
0 g
s
.46996 .44907 m .46491 .45035 L p .43828 .46284 L 0 0 0 r
F P
0 g
s
.46339 .45074 m .45686 .45402 L .429 .46573 L p .353 .812 .703 r
F P
0 g
s
.46491 .45035 m .46339 .45074 L .45842 .45314 L p 0 0 0 r
F P
0 g
s
.41976 .46984 m .42838 .46601 L p .45686 .45402 L .595 .95 .861 r
F P
0 g
s
.43029 .46519 m .45686 .45402 L p .42838 .46601 L .595 .95 .861 r
F P
0 g
s
.45842 .45314 m .43828 .46284 L p .46491 .45035 L 0 0 0 r
F P
0 g
s
.42838 .46601 m .429 .46573 L .43029 .46519 L p .595 .95 .861 r
F P
0 g
s
.46339 .45074 m .46996 .44907 L .49535 .43926 L p .286 .775 .708 r
F P
0 g
s
.49889 .43955 m .49535 .43926 L .46996 .44907 L p .001 0 0 r
F P
0 g
s
.49535 .43926 m .49889 .43955 L .52262 .43288 L p 0 0 0 r
F P
0 g
s
.33746 .5073 m .34895 .50095 L .38289 .49819 L p .838 .925 .89 r
F P
0 g
s
.39211 .48941 m .38289 .49819 L .34895 .50095 L p .813 .96 .907 r
F P
0 g
s
.61496 .43236 m .60633 .43042 L .62723 .43599 L p .202 0 0 r
F P
0 g
s
.62723 .43599 m .6382 .4371 L .61496 .43236 L p .202 0 0 r
F P
0 g
s
.5749 .42756 m .56896 .42894 L .58896 .43193 L p .285 0 0 r
F P
0 g
s
.58896 .43193 m .59767 .4303 L .5749 .42756 L p .285 0 0 r
F P
0 g
s
.34895 .50095 m .36044 .49519 L .39211 .48941 L p .813 .96 .907 r
F P
0 g
s
.40132 .48172 m .39211 .48941 L .36044 .49519 L p .758 .983 .908 r
F P
0 g
s
.52296 .43546 m .52262 .43288 L .49889 .43955 L p .182 0 0 r
F P
0 g
s
.52262 .43288 m .52296 .43546 L .54352 .43226 L p .216 0 0 r
F P
0 g
s
.54352 .43226 m .54642 .42927 L .52262 .43288 L p .216 0 0 r
F P
0 g
s
.54642 .42927 m .54352 .43226 L .56297 .43217 L p .294 0 0 r
F P
0 g
s
.56297 .43217 m .56896 .42894 L .54642 .42927 L p .294 0 0 r
F P
0 g
s
.429 .46573 m .43828 .46284 L .46339 .45074 L p .353 .812 .703 r
F P
0 g
s
.36044 .49519 m .37194 .49006 L .40132 .48172 L p .758 .983 .908 r
F P
0 g
s
.41054 .47518 m .40132 .48172 L .37194 .49006 L p .651 .97 .871 r
F P
0 g
s
.60633 .43042 m .59767 .4303 L .61623 .43637 L p .324 0 0 r
F P
0 g
s
.61623 .43637 m .62723 .43599 L .60633 .43042 L p .324 0 0 r
F P
0 g
s
.72658 .49717 m .71537 .48539 L .74448 .47441 L p .427 .592 .912 r
F P
0 g
s
.71537 .48539 m .70423 .47459 L .73155 .46746 L p .384 .604 .935 r
F P
0 g
s
.73155 .46746 m .74448 .47441 L .71537 .48539 L p .384 .604 .935 r
F P
0 g
s
.73783 .50977 m .72658 .49717 L .75747 .48204 L p .458 .582 .89 r
F P
0 g
s
.74448 .47441 m .75747 .48204 L .72658 .49717 L p .427 .592 .912 r
F P
0 g
s
.70423 .47459 m .69314 .46493 L .71867 .4613 L p .324 .614 .953 r
F P
0 g
s
.71867 .4613 m .73155 .46746 L .70423 .47459 L p .324 .614 .953 r
F P
0 g
s
.74914 .52301 m .73783 .50977 L .77051 .49025 L p .483 .574 .871 r
F P
0 g
s
.75747 .48204 m .77051 .49025 L .73783 .50977 L p .458 .582 .89 r
F P
0 g
s
.76048 .53669 m .74914 .52301 L .78359 .4989 L p .503 .569 .855 r
F P
0 g
s
.77051 .49025 m .78359 .4989 L .74914 .52301 L p .483 .574 .871 r
F P
0 g
s
.46996 .44907 m .47657 .44895 L .49889 .43955 L p .001 0 0 r
F P
0 g
s
.50247 .44157 m .49889 .43955 L .47657 .44895 L p .203 0 0 r
F P
0 g
s
.49889 .43955 m .50247 .44157 L .52296 .43546 L p .182 0 0 r
F P
0 g
s
.69314 .46493 m .68209 .45651 L .70583 .45602 L p .239 .615 .955 r
F P
0 g
s
.70583 .45602 m .71867 .4613 L .69314 .46493 L p .239 .615 .955 r
F P
0 g
s
.41976 .46984 m .41054 .47518 L .38344 .4856 L p .479 .89 .772 r
F P
0 g
s
.429 .46573 m .41976 .46984 L .40207 .47841 L p 0 0 0 r
F P
0 g
s
.39815 .47995 m .41054 .47518 L p .39674 .48049 L .651 .97 .871 r
F P
0 g
s
.40207 .47841 m .39497 .48185 L p .40299 .47805 L 0 0 0 r
F P
0 g
s
.429 .46573 m .40207 .47841 L .40299 .47805 L 0 0 0 r
F
.37194 .49006 m .38344 .4856 L .39815 .47995 L p .651 .97 .871 r
F P
0 g
s
.39674 .48049 m .37194 .49006 L .39815 .47995 L .651 .97 .871 r
F
.56896 .42894 m .56297 .43217 L .58017 .43523 L p .379 0 0 r
F P
0 g
s
.58017 .43523 m .58896 .43193 L .56896 .42894 L p .379 0 0 r
F P
0 g
s
.77186 .5506 m .76048 .53669 L .79672 .50786 L p .52 .567 .844 r
F P
0 g
s
.78359 .4989 m .79672 .50786 L .76048 .53669 L p .503 .569 .855 r
F P
0 g
s
.68209 .45651 m .67109 .44946 L .69304 .45169 L p .121 .592 .917 r
F P
0 g
s
.69304 .45169 m .70583 .45602 L .68209 .45651 L p .121 .592 .917 r
F P
0 g
s
.78325 .56455 m .77186 .5506 L .80988 .51698 L p .536 .568 .835 r
F P
0 g
s
.79672 .50786 m .80988 .51698 L .77186 .5506 L p .52 .567 .844 r
F P
0 g
s
.79464 .57831 m .78325 .56455 L .82306 .52612 L p .55 .571 .829 r
F P
0 g
s
.80988 .51698 m .82306 .52612 L .78325 .56455 L p .536 .568 .835 r
F P
0 g
s
.43828 .46284 m .4476 .46114 L .46996 .44907 L p 0 0 0 r
F P
0 g
s
.47657 .44895 m .46996 .44907 L .4476 .46114 L p .119 0 0 r
F P
0 g
s
.67109 .44946 m .66011 .44384 L .68027 .44837 L p 0 .53 .816 r
F P
0 g
s
.68027 .44837 m .69304 .45169 L .67109 .44946 L p 0 .53 .816 r
F P
0 g
s
.82306 .52612 m .83625 .53514 L .79464 .57831 L p .55 .571 .829 r
F P
0 g
s
.59767 .4303 m .58896 .43193 L .60518 .43817 L p .397 0 0 r
F P
0 g
s
.60518 .43817 m .61623 .43637 L .59767 .4303 L p .397 0 0 r
F P
0 g
s
.38344 .4856 m .39497 .48185 L .41976 .46984 L p .479 .89 .772 r
F P
0 g
s
.52331 .4398 m .52296 .43546 L .50247 .44157 L p .321 0 0 r
F P
0 g
s
.52296 .43546 m .52331 .4398 L .54058 .43706 L p .344 0 0 r
F P
0 g
s
.54058 .43706 m .54352 .43226 L .52296 .43546 L p .344 0 0 r
F P
0 g
s
.54352 .43226 m .54058 .43706 L .5569 .43713 L p .386 0 0 r
F P
0 g
s
.5569 .43713 m .56297 .43217 L .54352 .43226 L p .386 0 0 r
F P
0 g
s
.66753 .44609 m .68027 .44837 L .66011 .44384 L p .167 0 0 r
F P
0 g
s
.66011 .44384 m .64916 .43971 L .66753 .44609 L p .167 0 0 r
F P
0 g
s
.64916 .43971 m .6382 .4371 L .6548 .44486 L p .284 0 0 r
F P
0 g
s
.6548 .44486 m .66753 .44609 L .64916 .43971 L p .284 0 0 r
F P
0 g
s
.39497 .48185 m .40651 .47881 L .429 .46573 L p 0 0 0 r
F P
0 g
s
.43828 .46284 m .429 .46573 L .40651 .47881 L p 0 0 0 r
F P
0 g
s
.47657 .44895 m .48323 .45028 L .50247 .44157 L p .203 0 0 r
F P
0 g
s
.5061 .4452 m .50247 .44157 L .48323 .45028 L p .326 0 0 r
F P
0 g
s
.50247 .44157 m .5061 .4452 L .52331 .4398 L p .321 0 0 r
F P
0 g
s
.25702 .56182 m .24558 .56996 L .20758 .52532 L p .777 .785 .86 r
F P
0 g
s
.56297 .43217 m .5569 .43713 L .5713 .44005 L p .43 0 0 r
F P
0 g
s
.5713 .44005 m .58017 .43523 L .56297 .43217 L p .43 0 0 r
F P
0 g
s
.4476 .46114 m .45697 .4606 L .47657 .44895 L p .119 0 0 r
F P
0 g
s
.48323 .45028 m .47657 .44895 L .45697 .4606 L p .26 0 0 r
F P
0 g
s
.20758 .52532 m .22056 .52271 L .25702 .56182 L p .777 .785 .86 r
F P
0 g
s
.26849 .55358 m .25702 .56182 L .22056 .52271 L p .784 .804 .869 r
F P
0 g
s
.58896 .43193 m .58017 .43523 L .59407 .44132 L p .438 0 0 r
F P
0 g
s
.59407 .44132 m .60518 .43817 L .58896 .43193 L p .438 0 0 r
F P
0 g
s
.22056 .52271 m .23356 .52008 L .26849 .55358 L p .784 .804 .869 r
F P
0 g
s
.27998 .54533 m .26849 .55358 L .23356 .52008 L p .789 .825 .88 r
F P
0 g
s
.6382 .4371 m .62723 .43599 L .64206 .44469 L p .364 0 0 r
F P
0 g
s
.64206 .44469 m .6548 .44486 L .6382 .4371 L p .364 0 0 r
F P
0 g
s
.23356 .52008 m .24658 .51745 L .27998 .54533 L p .789 .825 .88 r
F P
0 g
s
.29147 .53717 m .27998 .54533 L .24658 .51745 L p .793 .849 .893 r
F P
0 g
s
.24658 .51745 m .25962 .51482 L .29147 .53717 L p .793 .849 .893 r
F P
0 g
s
.30297 .52919 m .29147 .53717 L .25962 .51482 L p .792 .876 .908 r
F P
0 g
s
.40651 .47881 m .41809 .47648 L .43828 .46284 L p 0 0 0 r
F P
0 g
s
.4476 .46114 m .43828 .46284 L .41809 .47648 L p .119 0 0 r
F P
0 g
s
.25962 .51482 m .27268 .51223 L .30297 .52919 L p .792 .876 .908 r
F P
0 g
s
.31447 .5215 m .30297 .52919 L .27268 .51223 L p .785 .904 .924 r
F P
0 g
s
.52366 .44572 m .52331 .4398 L .5061 .4452 L p .401 0 .001 r
F P
0 g
s
.52331 .4398 m .52366 .44572 L .5376 .44347 L p .414 0 0 r
F P
0 g
s
.5376 .44347 m .54058 .43706 L .52331 .4398 L p .414 0 0 r
F P
0 g
s
.54058 .43706 m .5376 .44347 L .55076 .44364 L p .437 0 .01 r
F P
0 g
s
.55076 .44364 m .5569 .43713 L .54058 .43706 L p .437 0 .01 r
F P
0 g
s
.27268 .51223 m .28576 .50969 L .31447 .5215 L p .785 .904 .924 r
F P
0 g
s
.32596 .51418 m .31447 .5215 L .28576 .50969 L p .768 .933 .938 r
F P
0 g
s
.62723 .43599 m .61623 .43637 L .6293 .44555 L p .414 0 0 r
F P
0 g
s
.6293 .44555 m .64206 .44469 L .62723 .43599 L p .414 0 0 r
F P
0 g
s
.28576 .50969 m .29886 .5072 L .32596 .51418 L p .768 .933 .938 r
F P
0 g
s
.33746 .5073 m .32596 .51418 L .29886 .5072 L p .733 .957 .945 r
F P
0 g
s
.45697 .4606 m .46641 .46113 L .48323 .45028 L p .26 0 0 r
F P
0 g
s
.48998 .45296 m .48323 .45028 L .46641 .46113 L p .352 0 0 r
F P
0 g
s
.48323 .45028 m .48998 .45296 L .5061 .4452 L p .326 0 0 r
F P
0 g
s
.29886 .5072 m .31197 .5048 L .33746 .5073 L p .733 .957 .945 r
F P
0 g
s
.34895 .50095 m .33746 .5073 L .31197 .5048 L p .671 .964 .932 r
F P
0 g
s
.58017 .43523 m .5713 .44005 L .58287 .44569 L p .463 0 .005 r
F P
0 g
s
.58287 .44569 m .59407 .44132 L .58017 .43523 L p .463 0 .005 r
F P
0 g
s
.41809 .47648 m .42971 .47485 L .4476 .46114 L p .119 0 0 r
F P
0 g
s
.45697 .4606 m .4476 .46114 L .42971 .47485 L p .242 0 0 r
F P
0 g
s
.50977 .45026 m .5061 .4452 L .48998 .45296 L p .401 0 .019 r
F P
0 g
s
.5061 .4452 m .50977 .45026 L .52366 .44572 L p .401 0 .001 r
F P
0 g
s
.5569 .43713 m .55076 .44364 L .56233 .44625 L p .46 0 .035 r
F P
0 g
s
.56233 .44625 m .5713 .44005 L .5569 .43713 L p .46 0 .035 r
F P
0 g
s
.31197 .5048 m .32511 .50248 L .34895 .50095 L p .671 .964 .932 r
F P
0 g
s
.36044 .49519 m .34895 .50095 L .32511 .50248 L p .569 .939 .885 r
F P
0 g
s
.61623 .43637 m .60518 .43817 L .61652 .44739 L p .445 0 0 r
F P
0 g
s
.61652 .44739 m .6293 .44555 L .61623 .43637 L p .445 0 0 r
F P
0 g
s
.35635 .49612 m .36044 .49519 L p .35679 .49594 L .569 .939 .885 r
F P
0 g
s
.33826 .50026 m .35635 .49612 L p .34455 .49852 L .569 .939 .885 r
F P
0 g
s
.32511 .50248 m .33826 .50026 L p .34455 .49852 L .569 .939 .885 r
F P
0 g
s
.35679 .49594 m .32511 .50248 L .35635 .49612 L .569 .939 .885 r
F
.32511 .50248 m .31197 .5048 L .29971 .50047 L p .317 .803 .877 r
F P
0 g
s
.29971 .50047 m .31371 .50257 L .32511 .50248 L p .317 .803 .877 r
F P
0 g
s
.33826 .50026 m .32511 .50248 L .31371 .50257 L p .177 .712 .758 r
F P
0 g
s
.31371 .50257 m .32501 .50392 L p .33826 .50026 L .177 .712 .758 r
F P
0 g
s
.32501 .50392 m .32774 .50425 L .33826 .50026 L p .177 .712 .758 r
F P
0 g
s
.37194 .49006 m .36044 .49519 L .33826 .50026 L p .423 .865 .791 r
F P
0 g
s
.38344 .4856 m .37194 .49006 L .35211 .49788 L p 0 0 0 r
F P
0 g
s
.35211 .49788 m .35143 .49815 L p .35203 .49792 L 0 0 0 r
F P
0 g
s
.38344 .4856 m .35211 .49788 L .35203 .49792 L 0 0 0 r
F
.33826 .50026 m .35143 .49815 L .37194 .49006 L p .423 .865 .791 r
F P
0 g
s
.42971 .47485 m .44138 .47387 L .45697 .4606 L p .242 0 0 r
F P
0 g
s
.46641 .46113 m .45697 .4606 L .44138 .47387 L p .329 0 0 r
F P
0 g
s
.52401 .45301 m .52366 .44572 L .50977 .45026 L p .448 0 .072 r
F P
0 g
s
.52366 .44572 m .52401 .45301 L .53456 .45128 L p .455 0 .071 r
F P
0 g
s
.53456 .45128 m .5376 .44347 L .52366 .44572 L p .455 0 .071 r
F P
0 g
s
.60518 .43817 m .59407 .44132 L .60369 .45016 L p .465 0 0 r
F P
0 g
s
.60369 .45016 m .61652 .44739 L .60518 .43817 L p .465 0 0 r
F P
0 g
s
.5376 .44347 m .53456 .45128 L .54451 .45148 L p .466 .007 .077 r
F P
0 g
s
.54451 .45148 m .55076 .44364 L .5376 .44347 L p .466 .007 .077 r
F P
0 g
s
.35143 .49815 m .36462 .49616 L .38344 .4856 L p 0 0 0 r
F P
0 g
s
.39497 .48185 m .38344 .4856 L .36462 .49616 L p 0 0 0 r
F P
0 g
s
.46641 .46113 m .47593 .46265 L .48998 .45296 L p .352 0 0 r
F P
0 g
s
.4968 .45683 m .48998 .45296 L .47593 .46265 L p .412 0 .046 r
F P
0 g
s
.48998 .45296 m .4968 .45683 L .50977 .45026 L p .401 0 .019 r
F P
0 g
s
.5713 .44005 m .56233 .44625 L .57157 .45116 L p .478 .009 .063 r
F P
0 g
s
.57157 .45116 m .58287 .44569 L .5713 .44005 L p .478 .009 .063 r
F P
0 g
s
.36462 .49616 m .37784 .49429 L .39497 .48185 L p 0 0 0 r
F P
0 g
s
.40651 .47881 m .39497 .48185 L .37784 .49429 L p .071 0 0 r
F P
0 g
s
.51351 .45656 m .50977 .45026 L .4968 .45683 L p .447 0 .081 r
F P
0 g
s
.50977 .45026 m .51351 .45656 L .52401 .45301 L p .448 0 .072 r
F P
0 g
s
.55076 .44364 m .54451 .45148 L .55323 .45362 L p .478 .021 .089 r
F P
0 g
s
.55323 .45362 m .56233 .44625 L .55076 .44364 L p .478 .021 .089 r
F P
0 g
s
.74448 .47441 m .73155 .46746 L .74638 .46082 L p .309 .71 .978 r
F P
0 g
s
.73155 .46746 m .71867 .4613 L .73246 .45878 L p .201 .681 .933 r
F P
0 g
s
.73246 .45878 m .74638 .46082 L .73155 .46746 L p .201 .681 .933 r
F P
0 g
s
.71867 .4613 m .70583 .45602 L .71858 .45715 L p .072 .618 .84 r
F P
0 g
s
.71858 .45715 m .73246 .45878 L .71867 .4613 L p .072 .618 .84 r
F P
0 g
s
.75747 .48204 m .74448 .47441 L .76034 .46324 L p .39 .715 .987 r
F P
0 g
s
.74638 .46082 m .76034 .46324 L .74448 .47441 L p .309 .71 .978 r
F P
0 g
s
.70583 .45602 m .69304 .45169 L .70473 .45598 L p .062 0 0 r
F P
0 g
s
.70473 .45598 m .71858 .45715 L .70583 .45602 L p .062 0 0 r
F P
0 g
s
.77051 .49025 m .75747 .48204 L .77434 .46598 L p .448 .708 .978 r
F P
0 g
s
.76034 .46324 m .77434 .46598 L .75747 .48204 L p .39 .715 .987 r
F P
0 g
s
.78359 .4989 m .77051 .49025 L .78838 .46899 L p .491 .697 .961 r
F P
0 g
s
.77434 .46598 m .78838 .46899 L .77051 .49025 L p .448 .708 .978 r
F P
0 g
s
.44138 .47387 m .45311 .47352 L .46641 .46113 L p .329 0 0 r
F P
0 g
s
.47593 .46265 m .46641 .46113 L .45311 .47352 L p .389 0 .024 r
F P
0 g
s
.69304 .45169 m .68027 .44837 L .69091 .45527 L p .181 0 0 r
F P
0 g
s
.69091 .45527 m .70473 .45598 L .69304 .45169 L p .181 0 0 r
F P
0 g
s
.79672 .50786 m .78359 .4989 L .80245 .47221 L p .522 .686 .941 r
F P
0 g
s
.78838 .46899 m .80245 .47221 L .78359 .4989 L p .491 .697 .961 r
F P
0 g
s
.59407 .44132 m .58287 .44569 L .5908 .45377 L p .477 .002 .047 r
F P
0 g
s
.5908 .45377 m .60369 .45016 L .59407 .44132 L p .477 .002 .047 r
F P
0 g
s
.37784 .49429 m .39108 .49254 L .40651 .47881 L p .071 0 0 r
F P
0 g
s
.41809 .47648 m .40651 .47881 L .39108 .49254 L p .188 0 0 r
F P
0 g
s
.68027 .44837 m .66753 .44609 L .67711 .45507 L p .275 0 0 r
F P
0 g
s
.67711 .45507 m .69091 .45527 L .68027 .44837 L p .275 0 0 r
F P
0 g
s
.80988 .51698 m .79672 .50786 L .81656 .47556 L p .546 .675 .923 r
F P
0 g
s
.80245 .47221 m .81656 .47556 L .79672 .50786 L p .522 .686 .941 r
F P
0 g
s
.82306 .52612 m .80988 .51698 L .83071 .479 L p .565 .668 .907 r
F P
0 g
s
.81656 .47556 m .83071 .479 L .80988 .51698 L p .546 .675 .923 r
F P
0 g
s
.66753 .44609 m .6548 .44486 L .66333 .45536 L p .343 0 0 r
F P
0 g
s
.66333 .45536 m .67711 .45507 L .66753 .44609 L p .343 0 0 r
F P
0 g
s
.83625 .53514 m .82306 .52612 L .84487 .48244 L p .581 .662 .893 r
F P
0 g
s
.83071 .479 m .84487 .48244 L .82306 .52612 L p .565 .668 .907 r
F P
0 g
s
.39108 .49254 m .40434 .49092 L .41809 .47648 L p .188 0 0 r
F P
0 g
s
.42971 .47485 m .41809 .47648 L .40434 .49092 L p .276 0 0 r
F P
0 g
s
.84487 .48244 m .85906 .48583 L .83625 .53514 L p .581 .662 .893 r
F P
0 g
s
.47593 .46265 m .48555 .46505 L .4968 .45683 L p .412 0 .046 r
F P
0 g
s
.50372 .46172 m .4968 .45683 L .48555 .46505 L p .452 .004 .094 r
F P
0 g
s
.4968 .45683 m .50372 .46172 L .51351 .45656 L p .447 0 .081 r
F P
0 g
s
.6548 .44486 m .64206 .44469 L .64957 .45614 L p .39 0 0 r
F P
0 g
s
.64957 .45614 m .66333 .45536 L .6548 .44486 L p .39 0 0 r
F P
0 g
s
.56233 .44625 m .55323 .45362 L .56016 .45756 L p .487 .035 .102 r
F P
0 g
s
.56016 .45756 m .57157 .45116 L .56233 .44625 L p .487 .035 .102 r
F P
0 g
s
.45311 .47352 m .4649 .47373 L .47593 .46265 L p .389 0 .024 r
F P
0 g
s
.48555 .46505 m .47593 .46265 L .4649 .47373 L p .432 0 .073 r
F P
0 g
s
.52437 .46142 m .52401 .45301 L .51351 .45656 L p .476 .033 .116 r
F P
0 g
s
.52401 .45301 m .52437 .46142 L .53148 .46025 L p .479 .035 .116 r
F P
0 g
s
.53148 .46025 m .53456 .45128 L .52401 .45301 L p .479 .035 .116 r
F P
0 g
s
.53456 .45128 m .53148 .46025 L .53817 .46042 L p .484 .04 .118 r
F P
0 g
s
.53817 .46042 m .54451 .45148 L .53456 .45128 L p .484 .04 .118 r
F P
0 g
s
.58287 .44569 m .57157 .45116 L .57784 .45812 L p .485 .026 .086 r
F P
0 g
s
.57784 .45812 m .5908 .45377 L .58287 .44569 L p .485 .026 .086 r
F P
0 g
s
.64206 .44469 m .6293 .44555 L .6358 .45741 L p .423 0 0 r
F P
0 g
s
.6358 .45741 m .64957 .45614 L .64206 .44469 L p .423 0 0 r
F P
0 g
s
.40434 .49092 m .41763 .48941 L .42971 .47485 L p .276 0 0 r
F P
0 g
s
.44138 .47387 m .42971 .47485 L .41763 .48941 L p .342 0 0 r
F P
0 g
s
.51731 .46387 m .51351 .45656 L .50372 .46172 L p .475 .034 .12 r
F P
0 g
s
.51351 .45656 m .51731 .46387 L .52437 .46142 L p .476 .033 .116 r
F P
0 g
s
.54451 .45148 m .53817 .46042 L .54401 .46194 L p .489 .046 .123 r
F P
0 g
s
.54401 .46194 m .55323 .45362 L .54451 .45148 L p .489 .046 .123 r
F P
0 g
s
.6293 .44555 m .61652 .44739 L .62204 .45914 L p .446 0 0 r
F P
0 g
s
.62204 .45914 m .6358 .45741 L .6293 .44555 L p .446 0 0 r
F P
0 g
s
.22056 .52271 m .20758 .52532 L .18911 .47507 L p .681 .766 .915 r
F P
0 g
s
.41763 .48941 m .43095 .48802 L .44138 .47387 L p .342 0 0 r
F P
0 g
s
.45311 .47352 m .44138 .47387 L .43095 .48802 L p .39 0 .014 r
F P
0 g
s
.18911 .47507 m .20283 .47847 L .22056 .52271 L p .681 .766 .915 r
F P
0 g
s
.23356 .52008 m .22056 .52271 L .20283 .47847 L p .676 .784 .931 r
F P
0 g
s
.61652 .44739 m .60369 .45016 L .60826 .4613 L p .463 0 .034 r
F P
0 g
s
.60826 .4613 m .62204 .45914 L .61652 .44739 L p .463 0 .034 r
F P
0 g
s
.4649 .47373 m .47677 .47444 L .48555 .46505 L p .432 0 .073 r
F P
0 g
s
.49526 .46819 m .48555 .46505 L .47677 .47444 L p .461 .017 .107 r
F P
0 g
s
.48555 .46505 m .49526 .46819 L .50372 .46172 L p .452 .004 .094 r
F P
0 g
s
.20283 .47847 m .21658 .48194 L .23356 .52008 L p .676 .784 .931 r
F P
0 g
s
.24658 .51745 m .23356 .52008 L .21658 .48194 L p .667 .805 .949 r
F P
0 g
s
.51074 .46744 m .50372 .46172 L .49526 .46819 L p .477 .038 .125 r
F P
0 g
s
.50372 .46172 m .51074 .46744 L .51731 .46387 L p .475 .034 .12 r
F P
0 g
s
.57157 .45116 m .56016 .45756 L .5648 .4631 L p .491 .043 .114 r
F P
0 g
s
.5648 .4631 m .57784 .45812 L .57157 .45116 L p .491 .043 .114 r
F P
0 g
s
.55323 .45362 m .54401 .46194 L .54862 .46472 L p .493 .052 .129 r
F P
0 g
s
.54862 .46472 m .56016 .45756 L .55323 .45362 L p .493 .052 .129 r
F P
0 g
s
.21658 .48194 m .23034 .48542 L .24658 .51745 L p .667 .805 .949 r
F P
0 g
s
.25962 .51482 m .24658 .51745 L .23034 .48542 L p .652 .828 .968 r
F P
0 g
s
.23034 .48542 m .24414 .48883 L .25962 .51482 L p .652 .828 .968 r
F P
0 g
s
.27268 .51223 m .25962 .51482 L .24414 .48883 L p .627 .85 .984 r
F P
0 g
s
.43095 .48802 m .4443 .48673 L .45311 .47352 L p .39 0 .014 r
F P
0 g
s
.4649 .47373 m .45311 .47352 L .4443 .48673 L p .426 0 .059 r
F P
0 g
s
.24414 .48883 m .25798 .49211 L .27268 .51223 L p .627 .85 .984 r
F P
0 g
s
.28576 .50969 m .27268 .51223 L .25798 .49211 L p .588 .868 .994 r
F P
0 g
s
.60369 .45016 m .5908 .45377 L .59447 .46385 L p .474 .011 .072 r
F P
0 g
s
.59447 .46385 m .60826 .4613 L .60369 .45016 L p .474 .011 .072 r
F P
0 g
s
.25798 .49211 m .27185 .49518 L .28576 .50969 L p .588 .868 .994 r
F P
0 g
s
.29886 .5072 m .28576 .50969 L .27185 .49518 L p .527 .874 .988 r
F P
0 g
s
.52474 .47068 m .52437 .46142 L .51731 .46387 L p .492 .057 .142 r
F P
0 g
s
.52437 .46142 m .52474 .47068 L .52833 .47008 L p .492 .058 .142 r
F P
0 g
s
.52833 .47008 m .53148 .46025 L .52437 .46142 L p .492 .058 .142 r
F P
0 g
s
.53148 .46025 m .52833 .47008 L .5317 .47018 L p .494 .059 .143 r
F P
0 g
s
.5317 .47018 m .53817 .46042 L .53148 .46025 L p .494 .059 .143 r
F P
0 g
s
.27185 .49518 m .28576 .49799 L .29886 .5072 L p .527 .874 .988 r
F P
0 g
s
.31197 .5048 m .29886 .5072 L .28576 .49799 L p .437 .857 .953 r
F P
0 g
s
.4443 .48673 m .45768 .48553 L .4649 .47373 L p .426 0 .059 r
F P
0 g
s
.47677 .47444 m .4649 .47373 L .45768 .48553 L p .453 .004 .093 r
F P
0 g
s
.28576 .49799 m .29971 .50047 L .31197 .5048 L p .437 .857 .953 r
F P
0 g
s
.52117 .47193 m .51731 .46387 L .51074 .46744 L p .491 .058 .143 r
F P
0 g
s
.51731 .46387 m .52117 .47193 L .52474 .47068 L p .492 .057 .142 r
F P
0 g
s
.53817 .46042 m .5317 .47018 L .53464 .47098 L p .495 .061 .144 r
F P
0 g
s
.53464 .47098 m .54401 .46194 L .53817 .46042 L p .495 .061 .144 r
F P
0 g
s
.47677 .47444 m .48872 .47556 L .49526 .46819 L p .461 .017 .107 r
F P
0 g
s
.50509 .47192 m .49526 .46819 L .48872 .47556 L p .481 .044 .131 r
F P
0 g
s
.49526 .46819 m .50509 .47192 L .51074 .46744 L p .477 .038 .125 r
F P
0 g
s
.5908 .45377 m .57784 .45812 L .58066 .46673 L p .483 .031 .1 r
F P
0 g
s
.58066 .46673 m .59447 .46385 L .5908 .45377 L p .483 .031 .1 r
F P
0 g
s
.56016 .45756 m .54862 .46472 L .55167 .46858 L p .494 .056 .134 r
F P
0 g
s
.55167 .46858 m .5648 .4631 L .56016 .45756 L p .494 .056 .134 r
F P
0 g
s
.35143 .49815 m .33826 .50026 L .32774 .50425 L p 0 0 0 r
F P
0 g
s
.51787 .47377 m .51074 .46744 L .50509 .47192 L p .492 .059 .145 r
F P
0 g
s
.51074 .46744 m .51787 .47377 L .52117 .47193 L p .491 .058 .143 r
F P
0 g
s
.32774 .50425 m .3418 .50546 L .35143 .49815 L p 0 0 0 r
F P
0 g
s
.36462 .49616 m .35143 .49815 L .3418 .50546 L p .092 0 0 r
F P
0 g
s
.54401 .46194 m .53464 .47098 L .53694 .47243 L p .496 .063 .146 r
F P
0 g
s
.53694 .47243 m .54862 .46472 L .54401 .46194 L p .496 .063 .146 r
F P
0 g
s
.45768 .48553 m .47109 .48442 L .47677 .47444 L p .453 .004 .093 r
F P
0 g
s
.48872 .47556 m .47677 .47444 L .47109 .48442 L p .472 .031 .118 r
F P
0 g
s
.3418 .50546 m .3559 .50617 L .36462 .49616 L p .092 0 0 r
F P
0 g
s
.37784 .49429 m .36462 .49616 L .3559 .50617 L p .194 0 0 r
F P
0 g
s
.57784 .45812 m .5648 .4631 L .56682 .4699 L p .489 .046 .122 r
F P
0 g
s
.56682 .4699 m .58066 .46673 L .57784 .45812 L p .489 .046 .122 r
F P
0 g
s
.3559 .50617 m .37002 .50638 L .37784 .49429 L p .194 0 0 r
F P
0 g
s
.39108 .49254 m .37784 .49429 L .37002 .50638 L p .273 0 0 r
F P
0 g
s
.37002 .50638 m .38416 .50607 L .39108 .49254 L p .273 0 0 r
F P
0 g
s
.40434 .49092 m .39108 .49254 L .38416 .50607 L p .333 0 0 r
F P
0 g
s
.48872 .47556 m .50076 .477 L .50509 .47192 L p .481 .044 .131 r
F P
0 g
s
.51504 .47607 m .50509 .47192 L .50076 .477 L p .493 .06 .146 r
F P
0 g
s
.50509 .47192 m .51504 .47607 L .51787 .47377 L p .492 .059 .145 r
F P
0 g
s
.54862 .46472 m .53694 .47243 L .53845 .47442 L p .497 .064 .147 r
F P
0 g
s
.53845 .47442 m .55167 .46858 L .54862 .46472 L p .497 .064 .147 r
F P
0 g
s
.38416 .50607 m .39832 .50524 L .40434 .49092 L p .333 0 0 r
F P
0 g
s
.41763 .48941 m .40434 .49092 L .39832 .50524 L p .378 0 0 r
F P
0 g
s
.47109 .48442 m .48454 .48337 L .48872 .47556 L p .472 .031 .118 r
F P
0 g
s
.50076 .477 m .48872 .47556 L .48454 .48337 L p .486 .05 .136 r
F P
0 g
s
.5648 .4631 m .55167 .46858 L .55296 .47329 L p .493 .057 .138 r
F P
0 g
s
.55296 .47329 m .56682 .4699 L .5648 .4631 L p .493 .057 .138 r
F P
0 g
s
.39832 .50524 m .41247 .50392 L .41763 .48941 L p .378 0 0 r
F P
0 g
s
.43095 .48802 m .41763 .48941 L .41247 .50392 L p .412 0 0 r
F P
0 g
s
.52511 .48046 m .52474 .47068 L .52117 .47193 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .52833 .47008 L .52474 .47068 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .5317 .47018 L .52833 .47008 L closepath p .498 .069 .154 r
F P
0 g
s
.70473 .45598 m .69091 .45527 L .69062 .46428 L p .106 0 0 r
F P
0 g
s
.69091 .45527 m .67711 .45507 L .67665 .46624 L p .204 0 0 r
F P
0 g
s
.67665 .46624 m .69062 .46428 L .69091 .45527 L p .204 0 0 r
F P
0 g
s
.71858 .45715 m .70473 .45598 L .7046 .46218 L p 0 0 0 r
F P
0 g
s
.69062 .46428 m .7046 .46218 L .70473 .45598 L p .106 0 0 r
F P
0 g
s
.67711 .45507 m .66333 .45536 L .66272 .46806 L p .28 0 0 r
F P
0 g
s
.66272 .46806 m .67665 .46624 L .67711 .45507 L p .28 0 0 r
F P
0 g
s
.71861 .45996 m .7046 .46218 L .6917 .47003 L p .319 .791 .695 r
F P
0 g
s
.6917 .47003 m .70485 .46439 L .71861 .45996 L p .319 .791 .695 r
F P
0 g
s
.71861 .45996 m .70485 .46439 L p .71705 .46142 L .473 .892 .811 r
F P
0 g
s
.73246 .45878 m .72128 .45747 L p .71861 .45996 L .154 .694 .736 r
F P
0 g
s
.71861 .45996 m .73264 .45762 L .73246 .45878 L p .154 .694 .736 r
F P
0 g
s
.73264 .45762 m .71861 .45996 L p .71705 .46142 L .473 .892 .811 r
F P
0 g
s
.72128 .45747 m .71858 .45715 L .71861 .45996 L p .154 .694 .736 r
F P
0 g
s
.7046 .46218 m .71861 .45996 L .71858 .45715 L p 0 0 0 r
F P
0 g
s
.66333 .45536 m .64957 .45614 L .64881 .46976 L p .337 0 0 r
F P
0 g
s
.64881 .46976 m .66272 .46806 L .66333 .45536 L p .337 0 0 r
F P
0 g
s
.74638 .46082 m .73246 .45878 L .73264 .45762 L p .294 .79 .859 r
F P
0 g
s
.52511 .48046 m .52117 .47193 L .51787 .47377 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53464 .47098 L .5317 .47018 L closepath p .498 .069 .154 r
F P
0 g
s
.41247 .50392 m .42663 .50213 L .43095 .48802 L p .412 0 0 r
F P
0 g
s
.4443 .48673 m .43095 .48802 L .42663 .50213 L p .437 0 .042 r
F P
0 g
s
.64957 .45614 m .6358 .45741 L .63493 .47132 L p .38 0 0 r
F P
0 g
s
.63493 .47132 m .64881 .46976 L .64957 .45614 L p .38 0 0 r
F P
0 g
s
.76034 .46324 m .74638 .46082 L .74669 .45517 L p .416 .849 .942 r
F P
0 g
s
.73264 .45762 m .74669 .45517 L .74638 .46082 L p .294 .79 .859 r
F P
0 g
s
.6358 .45741 m .62204 .45914 L .62108 .47277 L p .413 0 .001 r
F P
0 g
s
.62108 .47277 m .63493 .47132 L .6358 .45741 L p .413 0 .001 r
F P
0 g
s
.77434 .46598 m .76034 .46324 L .76076 .45262 L p .51 .872 .984 r
F P
0 g
s
.74669 .45517 m .76076 .45262 L .76034 .46324 L p .416 .849 .942 r
F P
0 g
s
.52511 .48046 m .51787 .47377 L .51504 .47607 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53694 .47243 L .53464 .47098 L closepath p .498 .069 .154 r
F P
0 g
s
.42663 .50213 m .44077 .4999 L .4443 .48673 L p .437 0 .042 r
F P
0 g
s
.45768 .48553 m .4443 .48673 L .44077 .4999 L p .457 0 .077 r
F P
0 g
s
.78838 .46899 m .77434 .46598 L .77485 .44997 L p .576 .87 .995 r
F P
0 g
s
.76076 .45262 m .77485 .44997 L .77434 .46598 L p .51 .872 .984 r
F P
0 g
s
.48454 .48337 m .49803 .48237 L .50076 .477 L p .486 .05 .136 r
F P
0 g
s
.51289 .47867 m .50076 .477 L .49803 .48237 L p .494 .062 .148 r
F P
0 g
s
.50076 .477 m .51289 .47867 L .51504 .47607 L p .493 .06 .146 r
F P
0 g
s
.62204 .45914 m .60826 .4613 L .60727 .4741 L p .438 0 .044 r
F P
0 g
s
.60727 .4741 m .62108 .47277 L .62204 .45914 L p .438 0 .044 r
F P
0 g
s
.55167 .46858 m .53845 .47442 L .53905 .47684 L p .496 .064 .148 r
F P
0 g
s
.53905 .47684 m .55296 .47329 L .55167 .46858 L p .496 .064 .148 r
F P
0 g
s
.80245 .47221 m .78838 .46899 L .78897 .44726 L p .619 .854 .988 r
F P
0 g
s
.77485 .44997 m .78897 .44726 L .78838 .46899 L p .576 .87 .995 r
F P
0 g
s
.60826 .4613 m .59447 .46385 L .59348 .47533 L p .457 0 .078 r
F P
0 g
s
.59348 .47533 m .60727 .4741 L .60826 .4613 L p .457 0 .078 r
F P
0 g
s
.44077 .4999 m .4549 .49729 L .45768 .48553 L p .457 0 .077 r
F P
0 g
s
.47109 .48442 m .45768 .48553 L .4549 .49729 L p .471 .023 .103 r
F P
0 g
s
.81656 .47556 m .80245 .47221 L .8031 .44449 L p .646 .833 .972 r
F P
0 g
s
.78897 .44726 m .8031 .44449 L .80245 .47221 L p .619 .854 .988 r
F P
0 g
s
.52511 .48046 m .51504 .47607 L .51289 .47867 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53845 .47442 L .53694 .47243 L closepath p .498 .069 .154 r
F P
0 g
s
.59447 .46385 m .58066 .46673 L .57974 .47647 L p .472 .024 .104 r
F P
0 g
s
.57974 .47647 m .59348 .47533 L .59447 .46385 L p .472 .024 .104 r
F P
0 g
s
.83071 .479 m .81656 .47556 L .81725 .44168 L p .663 .81 .954 r
F P
0 g
s
.8031 .44449 m .81725 .44168 L .81656 .47556 L p .646 .833 .972 r
F P
0 g
s
.4549 .49729 m .469 .49433 L .47109 .48442 L p .471 .023 .103 r
F P
0 g
s
.48454 .48337 m .47109 .48442 L .469 .49433 L p .482 .041 .123 r
F P
0 g
s
.58066 .46673 m .56682 .4699 L .56602 .47753 L p .482 .041 .124 r
F P
0 g
s
.56602 .47753 m .57974 .47647 L .58066 .46673 L p .482 .041 .124 r
F P
0 g
s
.84487 .48244 m .83071 .479 L .83143 .43884 L p .673 .789 .936 r
F P
0 g
s
.81725 .44168 m .83143 .43884 L .83071 .479 L p .663 .81 .954 r
F P
0 g
s
.469 .49433 m .48308 .49111 L .48454 .48337 L p .482 .041 .123 r
F P
0 g
s
.49803 .48237 m .48454 .48337 L .48308 .49111 L p .49 .054 .138 r
F P
0 g
s
.49803 .48237 m .51155 .48141 L .51289 .47867 L p .494 .062 .148 r
F P
0 g
s
.52511 .48046 m .51289 .47867 L .51155 .48141 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53905 .47684 L .53845 .47442 L closepath p .498 .069 .154 r
F P
0 g
s
.85906 .48583 m .84487 .48244 L .84563 .436 L p .679 .77 .92 r
F P
0 g
s
.83143 .43884 m .84563 .436 L .84487 .48244 L p .673 .789 .936 r
F P
0 g
s
.56682 .4699 m .55296 .47329 L .55235 .47854 L p .49 .055 .138 r
F P
0 g
s
.55235 .47854 m .56602 .47753 L .56682 .4699 L p .49 .055 .138 r
F P
0 g
s
.84563 .436 m .85986 .43317 L .85906 .48583 L p .679 .77 .92 r
F P
0 g
s
.48308 .49111 m .49713 .48767 L .49803 .48237 L p .49 .054 .138 r
F P
0 g
s
.51155 .48141 m .49803 .48237 L .49713 .48767 L p .496 .063 .148 r
F P
0 g
s
.55296 .47329 m .53905 .47684 L .53871 .47952 L p .496 .063 .148 r
F P
0 g
s
.53871 .47952 m .55235 .47854 L .55296 .47329 L p .496 .063 .148 r
F P
0 g
s
.49713 .48767 m .51114 .4841 L .51155 .48141 L p .496 .063 .148 r
F P
0 g
s
.52511 .48046 m .51155 .48141 L .51114 .4841 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53871 .47952 L .53905 .47684 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53532 .48492 L .53744 .48227 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53248 .48727 L .53532 .48492 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .52913 .48916 L .53248 .48727 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .5255 .49046 L .52913 .48916 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .52183 .49107 L .5255 .49046 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .5184 .49095 L .52183 .49107 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .51543 .4901 L .5184 .49095 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .51314 .48861 L .51543 .4901 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .51168 .48656 L .51314 .48861 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .51114 .4841 L .51168 .48656 L closepath p .498 .069 .154 r
F P
0 g
s
.52511 .48046 m .53744 .48227 L .53871 .47952 L closepath p .498 .069 .154 r
F P
0 g
s
.49814 .49253 m .51168 .48656 L .51114 .4841 L p .496 .064 .148 r
F P
0 g
s
.51114 .4841 m .49713 .48767 L .49814 .49253 L p .496 .064 .148 r
F P
0 g
s
.55235 .47854 m .53871 .47952 L .53744 .48227 L p .494 .062 .148 r
F P
0 g
s
.48449 .49823 m .49814 .49253 L .49713 .48767 L p .493 .057 .138 r
F P
0 g
s
.49713 .48767 m .48308 .49111 L .48449 .49823 L p .493 .057 .138 r
F P
0 g
s
.56602 .47753 m .55235 .47854 L .54987 .48398 L p .486 .05 .136 r
F P
0 g
s
.53744 .48227 m .54987 .48398 L .55235 .47854 L p .494 .062 .148 r
F P
0 g
s
.20283 .47847 m .18911 .47507 L .19318 .42214 L p .561 .667 .909 r
F P
0 g
s
.47075 .5035 m .48449 .49823 L .48308 .49111 L p .489 .046 .123 r
F P
0 g
s
.48308 .49111 m .469 .49433 L .47075 .5035 L p .489 .046 .123 r
F P
0 g
s
.19318 .42214 m .20675 .43168 L .20283 .47847 L p .561 .667 .909 r
F P
0 g
s
.21658 .48194 m .20283 .47847 L .20675 .43168 L p .54 .672 .923 r
F P
0 g
s
.50102 .49661 m .51314 .48861 L .51168 .48656 L p .497 .064 .147 r
F P
0 g
s
.51168 .48656 m .49814 .49253 L .50102 .49661 L p .497 .064 .147 r
F P
0 g
s
.54987 .48398 m .53744 .48227 L .53532 .48492 L p .493 .06 .146 r
F P
0 g
s
.57974 .47647 m .56602 .47753 L .56239 .48549 L p .473 .032 .119 r
F P
0 g
s
.54987 .48398 m .56239 .48549 L .56602 .47753 L p .486 .05 .136 r
F P
0 g
s
.20675 .43168 m .22033 .44138 L .21658 .48194 L p .54 .672 .923 r
F P
0 g
s
.23034 .48542 m .21658 .48194 L .22033 .44138 L p .514 .679 .94 r
F P
0 g
s
.45692 .50818 m .47075 .5035 L .469 .49433 L p .484 .032 .102 r
F P
0 g
s
.469 .49433 m .4549 .49729 L .45692 .50818 L p .484 .032 .102 r
F P
0 g
s
.59348 .47533 m .57974 .47647 L .57501 .48668 L p .454 .007 .096 r
F P
0 g
s
.56239 .48549 m .57501 .48668 L .57974 .47647 L p .473 .032 .119 r
F P
0 g
s
.22033 .44138 m .23394 .4511 L .23034 .48542 L p .514 .679 .94 r
F P
0 g
s
.24414 .48883 m .23034 .48542 L .23394 .4511 L p .483 .688 .958 r
F P
0 g
s
.44301 .51213 m .45692 .50818 L .4549 .49729 L p .476 .014 .075 r
F P
0 g
s
.4549 .49729 m .44077 .4999 L .44301 .51213 L p .476 .014 .075 r
F P
0 g
s
.50559 .4996 m .51543 .4901 L .51314 .48861 L p .496 .063 .146 r
F P
0 g
s
.51314 .48861 m .50102 .49661 L .50559 .4996 L p .496 .063 .146 r
F P
0 g
s
.53532 .48492 m .54565 .48923 L .54987 .48398 L p .493 .06 .146 r
F P
0 g
s
.54565 .48923 m .53532 .48492 L .53248 .48727 L p .492 .059 .145 r
F P
0 g
s
.23394 .4511 m .24758 .46067 L .24414 .48883 L p .483 .688 .958 r
F P
0 g
s
.25798 .49211 m .24414 .48883 L .24758 .46067 L p .442 .696 .974 r
F P
0 g
s
.60727 .4741 m .59348 .47533 L .58771 .48746 L p .429 0 .064 r
F P
0 g
s
.57501 .48668 m .58771 .48746 L .59348 .47533 L p .454 .007 .096 r
F P
0 g
s
.42904 .51523 m .44301 .51213 L .44077 .4999 L p .466 0 .04 r
F P
0 g
s
.44077 .4999 m .42663 .50213 L .42904 .51523 L p .466 0 .04 r
F P
0 g
s
.24758 .46067 m .26127 .46994 L .25798 .49211 L p .442 .696 .974 r
F P
0 g
s
.27185 .49518 m .25798 .49211 L .26127 .46994 L p .387 .702 .984 r
F P
0 g
s
.48875 .50423 m .50102 .49661 L .49814 .49253 L p .495 .056 .135 r
F P
0 g
s
.49814 .49253 m .48449 .49823 L .48875 .50423 L p .495 .056 .135 r
F P
0 g
s
.41501 .51736 m .42904 .51523 L .42663 .50213 L p .452 0 0 r
F P
0 g
s
.42663 .50213 m .41247 .50392 L .41501 .51736 L p .452 0 0 r
F P
0 g
s
.56239 .48549 m .54987 .48398 L .54565 .48923 L p .481 .044 .132 r
F P
0 g
s
.26127 .46994 m .27501 .47877 L .27185 .49518 L p .387 .702 .984 r
F P
0 g
s
.28576 .49799 m .27185 .49518 L .27501 .47877 L p .314 .698 .979 r
F P
0 g
s
.62108 .47277 m .60727 .4741 L .60051 .48773 L p .396 0 .024 r
F P
0 g
s
.58771 .48746 m .60051 .48773 L .60727 .4741 L p .429 0 .064 r
F P
0 g
s
.51156 .50129 m .5184 .49095 L .51543 .4901 L p .495 .061 .144 r
F P
0 g
s
.51543 .4901 m .50559 .4996 L .51156 .50129 L p .495 .061 .144 r
F P
0 g
s
.53248 .48727 m .53997 .49392 L .54565 .48923 L p .492 .059 .145 r
F P
0 g
s
.53997 .49392 m .53248 .48727 L .52913 .48916 L p .491 .058 .143 r
F P
0 g
s
.27501 .47877 m .28882 .48699 L .28576 .49799 L p .314 .698 .979 r
F P
0 g
s
.29971 .50047 m .28576 .49799 L .28882 .48699 L p .219 .677 .947 r
F P
0 g
s
.40094 .51845 m .41501 .51736 L .41247 .50392 L p .433 0 0 r
F P
0 g
s
.41247 .50392 m .39832 .50524 L .40094 .51845 L p .433 0 0 r
F P
0 g
s
.28882 .48699 m .30268 .49448 L .29971 .50047 L p .219 .677 .947 r
F P
0 g
s
.31371 .50257 m .29971 .50047 L .30268 .49448 L p .104 .63 .876 r
F P
0 g
s
.38685 .51842 m .40094 .51845 L .39832 .50524 L p .406 0 0 r
F P
0 g
s
.39832 .50524 m .38416 .50607 L .38685 .51842 L p .406 0 0 r
F P
0 g
s
.63493 .47132 m .62108 .47277 L .61338 .48741 L p .352 0 0 r
F P
0 g
s
.60051 .48773 m .61338 .48741 L .62108 .47277 L p .396 0 .024 r
F P
0 g
s
.51849 .50153 m .52183 .49107 L .5184 .49095 L p .494 .06 .143 r
F P
0 g
s
.5184 .49095 m .51156 .50129 L .51849 .50153 L p .494 .06 .143 r
F P
0 g
s
.52913 .48916 m .53323 .4977 L .53997 .49392 L p .491 .058 .143 r
F P
0 g
s
.53323 .4977 m .52913 .48916 L .5255 .49046 L p .492 .058 .143 r
F P
0 g
s
.30268 .49448 m .31661 .50111 L .31371 .50257 L p .104 .63 .876 r
F P
0 g
s
.32774 .50425 m .31371 .50257 L .31661 .50111 L p 0 .553 .762 r
F P
0 g
s
.37276 .51724 m .38685 .51842 L .38416 .50607 L p .368 0 0 r
F P
0 g
s
.38416 .50607 m .37002 .50638 L .37276 .51724 L p .368 0 0 r
F P
0 g
s
.31661 .50111 m .33059 .50678 L .32774 .50425 L p 0 .553 .762 r
F P
0 g
s
.3418 .50546 m .32774 .50425 L .33059 .50678 L p .14 0 0 r
F P
0 g
s
.35867 .51489 m .37276 .51724 L .37002 .50638 L p .314 0 0 r
F P
0 g
s
.37002 .50638 m .3559 .50617 L .35867 .51489 L p .314 0 0 r
F P
0 g
s
.33059 .50678 m .34461 .51139 L .3418 .50546 L p .14 0 0 r
F P
0 g
s
.3559 .50617 m .3418 .50546 L .34461 .51139 L p .239 0 0 r
F P
0 g
s
.34461 .51139 m .35867 .51489 L .3559 .50617 L p .239 0 0 r
F P
0 g
s
.52589 .5003 m .5255 .49046 L .52183 .49107 L p .493 .058 .142 r
F P
0 g
s
.52183 .49107 m .51849 .50153 L .52589 .5003 L p .493 .058 .142 r
F P
0 g
s
.5255 .49046 m .52589 .5003 L .53323 .4977 L p .492 .058 .143 r
F P
0 g
s
.64881 .46976 m .63493 .47132 L .62631 .48642 L p .294 0 0 r
F P
0 g
s
.61338 .48741 m .62631 .48642 L .63493 .47132 L p .352 0 0 r
F P
0 g
s
.47633 .51124 m .48875 .50423 L .48449 .49823 L p .492 .045 .116 r
F P
0 g
s
.48449 .49823 m .47075 .5035 L .47633 .51124 L p .492 .045 .116 r
F P
0 g
s
.57501 .48668 m .56239 .48549 L .55611 .49321 L p .462 .019 .109 r
F P
0 g
s
.54565 .48923 m .55611 .49321 L .56239 .48549 L p .481 .044 .132 r
F P
0 g
s
.66272 .46806 m .64881 .46976 L .63931 .48471 L p .218 0 0 r
F P
0 g
s
.62631 .48642 m .63931 .48471 L .64881 .46976 L p .294 0 0 r
F P
0 g
s
.49559 .50865 m .50559 .4996 L .50102 .49661 L p .493 .053 .13 r
F P
0 g
s
.50102 .49661 m .48875 .50423 L .49559 .50865 L p .493 .053 .13 r
F P
0 g
s
.55611 .49321 m .54565 .48923 L .53997 .49392 L p .477 .039 .126 r
F P
0 g
s
.67665 .46624 m .66272 .46806 L .65236 .48224 L p .119 0 0 r
F P
0 g
s
.63931 .48471 m .65236 .48224 L .66272 .46806 L p .218 0 0 r
F P
0 g
s
.69062 .46428 m .67665 .46624 L .66544 .47897 L p 0 0 0 r
F P
0 g
s
.65236 .48224 m .66544 .47897 L .67665 .46624 L p .119 0 0 r
F P
0 g
s
.46378 .51739 m .47633 .51124 L .47075 .5035 L p .487 .029 .09 r
F P
0 g
s
.47075 .5035 m .45692 .50818 L .46378 .51739 L p .487 .029 .09 r
F P
0 g
s
.7046 .46218 m .69062 .46428 L .67856 .4749 L p 0 0 0 r
F P
0 g
s
.66544 .47897 m .67856 .4749 L .69062 .46428 L p 0 0 0 r
F P
0 g
s
.58771 .48746 m .57501 .48668 L .5667 .49667 L p .434 0 .077 r
F P
0 g
s
.55611 .49321 m .5667 .49667 L .57501 .48668 L p .462 .019 .109 r
F P
0 g
s
.50458 .51114 m .51156 .50129 L .50559 .4996 L p .489 .047 .124 r
F P
0 g
s
.50559 .4996 m .49559 .50865 L .50458 .51114 L p .489 .047 .124 r
F P
0 g
s
.67856 .4749 m .6917 .47003 L .7046 .46218 L p 0 0 0 r
F P
0 g
s
.53997 .49392 m .54759 .50015 L .55611 .49321 L p .477 .039 .126 r
F P
0 g
s
.54759 .50015 m .53997 .49392 L .53323 .4977 L p .476 .035 .121 r
F P
0 g
s
.74669 .45517 m .73264 .45762 L .71802 .45803 L p .598 .95 .888 r
F P
0 g
s
.70485 .46439 m .71802 .45803 L .73264 .45762 L p .473 .892 .811 r
F P
0 g
s
.48544 .51694 m .49559 .50865 L .48875 .50423 L p .488 .037 .105 r
F P
0 g
s
.48875 .50423 m .47633 .51124 L .48544 .51694 L p .488 .037 .105 r
F P
0 g
s
.45112 .52248 m .46378 .51739 L .45692 .50818 L p .482 .009 .055 r
F P
0 g
s
.45692 .50818 m .44301 .51213 L .45112 .52248 L p .482 .009 .055 r
F P
0 g
s
.5667 .49667 m .55611 .49321 L .54759 .50015 L p .453 .007 .097 r
F P
0 g
s
.51507 .51148 m .51849 .50153 L .51156 .50129 L p .485 .041 .12 r
F P
0 g
s
.51156 .50129 m .50458 .51114 L .51507 .51148 L p .485 .041 .12 r
F P
0 g
s
.53323 .4977 m .5374 .50577 L .54759 .50015 L p .476 .035 .121 r
F P
0 g
s
.5374 .50577 m .53323 .4977 L .52589 .5003 L p .476 .034 .118 r
F P
0 g
s
.76076 .45262 m .74669 .45517 L .73118 .45099 L p .686 .969 .927 r
F P
0 g
s
.71802 .45803 m .73118 .45099 L .74669 .45517 L p .598 .95 .888 r
F P
0 g
s
.60051 .48773 m .58771 .48746 L .5774 .4994 L p .395 0 .034 r
F P
0 g
s
.5667 .49667 m .5774 .4994 L .58771 .48746 L p .434 0 .077 r
F P
0 g
s
.77485 .44997 m .76076 .45262 L .74434 .44335 L p .741 .961 .939 r
F P
0 g
s
.73118 .45099 m .74434 .44335 L .76076 .45262 L p .686 .969 .927 r
F P
0 g
s
.52629 .50965 m .52589 .5003 L .51849 .50153 L p .48 .036 .117 r
F P
0 g
s
.51849 .50153 m .51507 .51148 L .52629 .50965 L p .48 .036 .117 r
F P
0 g
s
.52589 .5003 m .52629 .50965 L .5374 .50577 L p .476 .034 .118 r
F P
0 g
s
.78897 .44726 m .77485 .44997 L .7575 .43519 L p .772 .94 .936 r
F P
0 g
s
.74434 .44335 m .7575 .43519 L .77485 .44997 L p .741 .961 .939 r
F P
0 g
s
.43835 .5263 m .45112 .52248 L .44301 .51213 L p .473 0 .008 r
F P
0 g
s
.44301 .51213 m .42904 .51523 L .43835 .5263 L p .473 0 .008 r
F P
0 g
s
.8031 .44449 m .78897 .44726 L .77066 .4266 L p .788 .913 .925 r
F P
0 g
s
.7575 .43519 m .77066 .4266 L .78897 .44726 L p .772 .94 .936 r
F P
0 g
s
.61338 .48741 m .60051 .48773 L .58822 .50125 L p .341 0 0 r
F P
0 g
s
.5774 .4994 m .58822 .50125 L .60051 .48773 L p .395 0 .034 r
F P
0 g
s
.81725 .44168 m .8031 .44449 L .78382 .41768 L p .793 .886 .912 r
F P
0 g
s
.77066 .4266 m .78382 .41768 L .8031 .44449 L p .788 .913 .925 r
F P
0 g
s
.83143 .43884 m .81725 .44168 L .79699 .40853 L p .793 .859 .899 r
F P
0 g
s
.78382 .41768 m .79699 .40853 L .81725 .44168 L p .793 .886 .912 r
F P
0 g
s
.49748 .52014 m .50458 .51114 L .49559 .50865 L p .48 .024 .092 r
F P
0 g
s
.49559 .50865 m .48544 .51694 L .49748 .52014 L p .48 .024 .092 r
F P
0 g
s
.47515 .52418 m .48544 .51694 L .47633 .51124 L p .481 .015 .069 r
F P
0 g
s
.47633 .51124 m .46378 .51739 L .47515 .52418 L p .481 .015 .069 r
F P
0 g
s
.54759 .50015 m .55532 .50568 L .5667 .49667 L p .453 .007 .097 r
F P
0 g
s
.55532 .50568 m .54759 .50015 L .5374 .50577 L p .449 0 .085 r
F P
0 g
s
.84563 .436 m .83143 .43884 L .81017 .39925 L p .788 .835 .888 r
F P
0 g
s
.79699 .40853 m .81017 .39925 L .83143 .43884 L p .793 .859 .899 r
F P
0 g
s
.5774 .4994 m .5667 .49667 L .55532 .50568 L p .417 0 .053 r
F P
0 g
s
.42549 .52868 m .43835 .5263 L .42904 .51523 L p .46 0 0 r
F P
0 g
s
.42904 .51523 m .41501 .51736 L .42549 .52868 L p .46 0 0 r
F P
0 g
s
.85986 .43317 m .84563 .436 L .82337 .38995 L p .781 .814 .878 r
F P
0 g
s
.81017 .39925 m .82337 .38995 L .84563 .436 L p .788 .835 .888 r
F P
0 g
s
.62631 .48642 m .61338 .48741 L .59914 .50205 L p .266 0 0 r
F P
0 g
s
.58822 .50125 m .59914 .50205 L .61338 .48741 L p .341 0 0 r
F P
0 g
s
.82337 .38995 m .8366 .38074 L .85986 .43317 L p .781 .814 .878 r
F P
0 g
s
.41257 .52948 m .42549 .52868 L .41501 .51736 L p .439 0 0 r
F P
0 g
s
.41501 .51736 m .40094 .51845 L .41257 .52948 L p .439 0 0 r
F P
0 g
s
.51159 .52055 m .51507 .51148 L .50458 .51114 L p .469 .011 .081 r
F P
0 g
s
.50458 .51114 m .49748 .52014 L .51159 .52055 L p .469 .011 .081 r
F P
0 g
s
.5374 .50577 m .54165 .51302 L .55532 .50568 L p .449 0 .085 r
F P
0 g
s
.54165 .51302 m .5374 .50577 L .52629 .50965 L p .45 0 .076 r
F P
0 g
s
.63931 .48471 m .62631 .48642 L .61014 .50166 L p .163 0 0 r
F P
0 g
s
.59914 .50205 m .61014 .50166 L .62631 .48642 L p .266 0 0 r
F P
0 g
s
.3996 .5286 m .41257 .52948 L .40094 .51845 L p .406 0 0 r
F P
0 g
s
.40094 .51845 m .38685 .51842 L .3996 .5286 L p .406 0 0 r
F P
0 g
s
.46472 .53009 m .47515 .52418 L .46378 .51739 L p .47 0 .018 r
F P
0 g
s
.46378 .51739 m .45112 .52248 L .46472 .53009 L p .47 0 .018 r
F P
0 g
s
.5267 .51812 m .52629 .50965 L .51507 .51148 L p .458 0 .075 r
F P
0 g
s
.51507 .51148 m .51159 .52055 L .5267 .51812 L p .458 0 .075 r
F P
0 g
s
.52629 .50965 m .5267 .51812 L .54165 .51302 L p .45 0 .076 r
F P
0 g
s
.58822 .50125 m .5774 .4994 L .56316 .51025 L p .362 0 0 r
F P
0 g
s
.55532 .50568 m .56316 .51025 L .5774 .4994 L p .417 0 .053 r
F P
0 g
s
.49026 .52797 m .49748 .52014 L .48544 .51694 L p .465 0 .043 r
F P
0 g
s
.48544 .51694 m .47515 .52418 L .49026 .52797 L p .465 0 .043 r
F P
0 g
s
.38661 .52597 m .3996 .5286 L .38685 .51842 L p .355 0 0 r
F P
0 g
s
.38685 .51842 m .37276 .51724 L .38661 .52597 L p .355 0 0 r
F P
0 g
s
.56316 .51025 m .55532 .50568 L .54165 .51302 L p .406 0 .029 r
F P
0 g
s
.20675 .43168 m .19318 .42214 L .22154 .37026 L p .508 .564 .847 r
F P
0 g
s
.65236 .48224 m .63931 .48471 L .62122 .49998 L p .023 0 0 r
F P
0 g
s
.61014 .50166 m .62122 .49998 L .63931 .48471 L p .163 0 0 r
F P
0 g
s
.22154 .37026 m .23398 .38563 L .20675 .43168 L p .508 .564 .847 r
F P
0 g
s
.22033 .44138 m .20675 .43168 L .23398 .38563 L p .487 .558 .854 r
F P
0 g
s
.37362 .52156 m .38661 .52597 L .37276 .51724 L p .278 0 0 r
F P
0 g
s
.37276 .51724 m .35867 .51489 L .37362 .52156 L p .278 0 0 r
F P
0 g
s
.23398 .38563 m .24642 .40124 L .22033 .44138 L p .487 .558 .854 r
F P
0 g
s
.23394 .4511 m .22033 .44138 L .24642 .40124 L p .464 .555 .864 r
F P
0 g
s
.24642 .40124 m .25889 .41687 L .23394 .4511 L p .464 .555 .864 r
F P
0 g
s
.24758 .46067 m .23394 .4511 L .25889 .41687 L p .438 .555 .876 r
F P
0 g
s
.36065 .5154 m .37362 .52156 L .35867 .51489 L p .171 0 0 r
F P
0 g
s
.35867 .51489 m .34461 .51139 L .36065 .5154 L p .171 0 0 r
F P
0 g
s
.66544 .47897 m .65236 .48224 L .63236 .49691 L p 0 0 0 r
F P
0 g
s
.62122 .49998 m .63236 .49691 L .65236 .48224 L p .023 0 0 r
F P
0 g
s
.45417 .53439 m .46472 .53009 L .45112 .52248 L p .453 0 0 r
F P
0 g
s
.45112 .52248 m .43835 .5263 L .45417 .53439 L p .453 0 0 r
F P
0 g
s
.25889 .41687 m .27139 .43228 L .24758 .46067 L p .438 .555 .876 r
F P
0 g
s
.26127 .46994 m .24758 .46067 L .27139 .43228 L p .408 .557 .892 r
F P
0 g
s
.34771 .50753 m .36065 .5154 L .34461 .51139 L p 0 .498 .819 r
F P
0 g
s
.34461 .51139 m .33059 .50678 L .34771 .50753 L p 0 .498 .819 r
F P
0 g
s
.59914 .50205 m .58822 .50125 L .57111 .51362 L p .282 0 0 r
F P
0 g
s
.56316 .51025 m .57111 .51362 L .58822 .50125 L p .362 0 0 r
F P
0 g
s
.27139 .43228 m .28394 .44723 L .26127 .46994 L p .408 .557 .892 r
F P
0 g
s
.27501 .47877 m .26127 .46994 L .28394 .44723 L p .371 .562 .909 r
F P
0 g
s
.28394 .44723 m .29656 .46151 L .27501 .47877 L p .371 .562 .909 r
F P
0 g
s
.28882 .48699 m .27501 .47877 L .29656 .46151 L p .325 .567 .926 r
F P
0 g
s
.33483 .49806 m .34771 .50753 L .33059 .50678 L p .078 .546 .902 r
F P
0 g
s
.33059 .50678 m .31661 .50111 L .33483 .49806 L p .078 .546 .902 r
F P
0 g
s
.29656 .46151 m .30924 .47487 L .28882 .48699 L p .325 .567 .926 r
F P
0 g
s
.30268 .49448 m .28882 .48699 L .30924 .47487 L p .264 .571 .939 r
F P
0 g
s
.322 .48712 m .33483 .49806 L .31661 .50111 L p .182 .567 .936 r
F P
0 g
s
.31661 .50111 m .30268 .49448 L .322 .48712 L p .182 .567 .936 r
F P
0 g
s
.30924 .47487 m .322 .48712 L .30268 .49448 L p .264 .571 .939 r
F P
0 g
s
.50804 .52838 m .51159 .52055 L .49748 .52014 L p .443 0 .021 r
F P
0 g
s
.49748 .52014 m .49026 .52797 L .50804 .52838 L p .443 0 .021 r
F P
0 g
s
.54165 .51302 m .54597 .51915 L .56316 .51025 L p .406 0 .029 r
F P
0 g
s
.54597 .51915 m .54165 .51302 L .5267 .51812 L p .407 0 .012 r
F P
0 g
s
.67856 .4749 m .66544 .47897 L .64355 .49241 L p .356 .803 .657 r
F P
0 g
s
.63236 .49691 m .64355 .49241 L .66544 .47897 L p 0 0 0 r
F P
0 g
s
.48294 .53427 m .49026 .52797 L .47515 .52418 L p .441 0 0 r
F P
0 g
s
.47515 .52418 m .46472 .53009 L .48294 .53427 L p .441 0 0 r
F P
0 g
s
.57111 .51362 m .56316 .51025 L .54597 .51915 L p .34 0 0 r
F P
0 g
s
.64355 .49241 m .65476 .48645 L .67856 .4749 L p .356 .803 .657 r
F P
0 g
s
.6917 .47003 m .67856 .4749 L .65476 .48645 L p .545 .922 .785 r
F P
0 g
s
.52711 .52536 m .5267 .51812 L .51159 .52055 L p .421 0 .008 r
F P
0 g
s
.51159 .52055 m .50804 .52838 L .52711 .52536 L p .421 0 .008 r
F P
0 g
s
.44353 .53687 m .45417 .53439 L .43835 .5263 L p .424 0 0 r
F P
0 g
s
.43835 .5263 m .42549 .52868 L .44353 .53687 L p .424 0 0 r
F P
0 g
s
.5267 .51812 m .52711 .52536 L .54597 .51915 L p .407 0 .012 r
F P
0 g
s
.61014 .50166 m .59914 .50205 L .57916 .51555 L p .162 0 0 r
F P
0 g
s
.57111 .51362 m .57916 .51555 L .59914 .50205 L p .282 0 0 r
F P
0 g
s
.70485 .46439 m .6917 .47003 L .666 .47904 L p .688 .981 .861 r
F P
0 g
s
.65476 .48645 m .666 .47904 L .6917 .47003 L p .545 .922 .785 r
F P
0 g
s
.71802 .45803 m .70485 .46439 L .67724 .47023 L p .778 .99 .89 r
F P
0 g
s
.666 .47904 m .67724 .47023 L .70485 .46439 L p .688 .981 .861 r
F P
0 g
s
.43281 .53734 m .44353 .53687 L .42549 .52868 L p .376 0 0 r
F P
0 g
s
.42549 .52868 m .41257 .52948 L .43281 .53734 L p .376 0 0 r
F P
0 g
s
.73118 .45099 m .71802 .45803 L .68847 .4601 L p .828 .971 .891 r
F P
0 g
s
.67724 .47023 m .68847 .4601 L .71802 .45803 L p .778 .99 .89 r
F P
0 g
s
.50444 .53461 m .50804 .52838 L .49026 .52797 L p .4 0 0 r
F P
0 g
s
.49026 .52797 m .48294 .53427 L .50444 .53461 L p .4 0 0 r
F P
0 g
s
.54597 .51915 m .55036 .52384 L .57111 .51362 L p .34 0 0 r
F P
0 g
s
.55036 .52384 m .54597 .51915 L .52711 .52536 L p .337 0 0 r
F P
0 g
s
.62122 .49998 m .61014 .50166 L .58729 .51585 L p 0 0 0 r
F P
0 g
s
.57916 .51555 m .58729 .51585 L .61014 .50166 L p .162 0 0 r
F P
0 g
s
.47551 .53875 m .48294 .53427 L .46472 .53009 L p .401 0 0 r
F P
0 g
s
.46472 .53009 m .45417 .53439 L .47551 .53875 L p .401 0 0 r
F P
0 g
s
.74434 .44335 m .73118 .45099 L .69969 .44875 L p .852 .941 .88 r
F P
0 g
s
.68847 .4601 m .69969 .44875 L .73118 .45099 L p .828 .971 .891 r
F P
0 g
s
.57916 .51555 m .57111 .51362 L .55036 .52384 L p .234 0 0 r
F P
0 g
s
.7575 .43519 m .74434 .44335 L .7109 .4363 L p .861 .91 .864 r
F P
0 g
s
.69969 .44875 m .7109 .4363 L .74434 .44335 L p .852 .941 .88 r
F P
0 g
s
.42203 .53565 m .43281 .53734 L .41257 .52948 L p .296 0 0 r
F P
0 g
s
.41257 .52948 m .3996 .5286 L .42203 .53565 L p .296 0 0 r
F P
0 g
s
.77066 .4266 m .7575 .43519 L .72208 .42291 L p .862 .88 .849 r
F P
0 g
s
.7109 .4363 m .72208 .42291 L .7575 .43519 L p .861 .91 .864 r
F P
0 g
s
.52753 .53104 m .52711 .52536 L .50804 .52838 L p .36 0 0 r
F P
0 g
s
.50804 .52838 m .50444 .53461 L .52753 .53104 L p .36 0 0 r
F P
0 g
s
.52711 .52536 m .52753 .53104 L .55036 .52384 L p .337 0 0 r
F P
0 g
s
.78382 .41768 m .77066 .4266 L .73324 .40874 L p .858 .854 .836 r
F P
0 g
s
.72208 .42291 m .73324 .40874 L .77066 .4266 L p .862 .88 .849 r
F P
0 g
s
.63236 .49691 m .62122 .49998 L .59549 .51435 L p 0 0 0 r
F P
0 g
s
.58729 .51585 m .59549 .51435 L .62122 .49998 L p 0 0 0 r
F P
0 g
s
.79699 .40853 m .78382 .41768 L .74439 .39398 L p .852 .831 .826 r
F P
0 g
s
.73324 .40874 m .74439 .39398 L .78382 .41768 L p .858 .854 .836 r
F P
0 g
s
.81017 .39925 m .79699 .40853 L .75553 .37881 L p .844 .812 .819 r
F P
0 g
s
.74439 .39398 m .75553 .37881 L .79699 .40853 L p .852 .831 .826 r
F P
0 g
s
.41123 .53171 m .42203 .53565 L .3996 .5286 L p .174 0 0 r
F P
0 g
s
.3996 .5286 m .38661 .52597 L .41123 .53171 L p .174 0 0 r
F P
0 g
s
.82337 .38995 m .81017 .39925 L .76667 .36342 L p .834 .795 .814 r
F P
0 g
s
.75553 .37881 m .76667 .36342 L .81017 .39925 L p .844 .812 .819 r
F P
0 g
s
.468 .54115 m .47551 .53875 L .45417 .53439 L p .333 0 0 r
F P
0 g
s
.45417 .53439 m .44353 .53687 L .468 .54115 L p .333 0 0 r
F P
0 g
s
.8366 .38074 m .82337 .38995 L .77783 .348 L p .824 .78 .811 r
F P
0 g
s
.76667 .36342 m .77783 .348 L .82337 .38995 L p .834 .795 .814 r
F P
0 g
s
.58729 .51585 m .57916 .51555 L .55481 .52681 L p .066 0 0 r
F P
0 g
s
.55036 .52384 m .55481 .52681 L .57916 .51555 L p .234 0 0 r
F P
0 g
s
.50078 .53893 m .50444 .53461 L .48294 .53427 L p .327 0 0 r
F P
0 g
s
.48294 .53427 m .47551 .53875 L .50078 .53893 L p .327 0 0 r
F P
0 g
s
.77783 .348 m .78901 .33274 L .8366 .38074 L p .824 .78 .811 r
F P
0 g
s
.55481 .52681 m .55036 .52384 L .52753 .53104 L p .22 0 0 r
F P
0 g
s
.64355 .49241 m .63236 .49691 L .60374 .51093 L p .486 .893 .771 r
F P
0 g
s
.65476 .48645 m .64725 .49044 L p .61203 .50551 L .678 .978 .874 r
F P
0 g
s
.64725 .49044 m .64355 .49241 L .63874 .49441 L p .678 .978 .874 r
F P
0 g
s
.59549 .51435 m .59952 .51268 L p .63236 .49691 L 0 0 0 r
F P
0 g
s
.61283 .50648 m .63236 .49691 L p .59952 .51268 L 0 0 0 r
F P
0 g
s
.63874 .49441 m .61203 .50551 L p .64725 .49044 L .678 .978 .874 r
F P
0 g
s
.59952 .51268 m .60374 .51093 L .61283 .50648 L p 0 0 0 r
F P
0 g
s
.40041 .52549 m .41123 .53171 L .38661 .52597 L p 0 .521 .833 r
F P
0 g
s
.38661 .52597 m .37362 .52156 L .40041 .52549 L p 0 .521 .833 r
F P
0 g
s
.3896 .517 m .40041 .52549 L .37362 .52156 L p .131 .57 .924 r
F P
0 g
s
.37362 .52156 m .36065 .5154 L .3896 .517 L p .131 .57 .924 r
F P
0 g
s
.52796 .53483 m .52753 .53104 L .50444 .53461 L p .255 0 0 r
F P
0 g
s
.50444 .53461 m .50078 .53893 L .52796 .53483 L p .255 0 0 r
F P
0 g
s
.52753 .53104 m .52796 .53483 L .55481 .52681 L p .22 0 0 r
F P
0 g
s
.60374 .51093 m .61203 .50551 L .64355 .49241 L p .486 .893 .771 r
F P
0 g
s
.468 .54115 m .44353 .53687 L p .45493 .53981 L .216 0 0 r
F P
0 g
s
.44353 .53687 m .43281 .53734 L .46042 .54123 L p .216 0 0 r
F P
0 g
s
.42203 .53565 m .4528 .53883 L p .43833 .53775 L 0 .543 .755 r
F P
0 g
s
.43281 .53734 m .42434 .53601 L p .43833 .53775 L 0 .543 .755 r
F P
0 g
s
.42434 .53601 m .42203 .53565 L p .43833 .53775 L 0 .543 .755 r
F P
0 g
s
.46042 .54123 m .46585 .54117 L p .45493 .53981 L .216 0 0 r
F P
0 g
s
.46585 .54117 m .468 .54115 L p .45493 .53981 L .216 0 0 r
F P
0 g
s
.23398 .38563 m .22154 .37026 L .27399 .32374 L p .528 .514 .784 r
F P
0 g
s
.37882 .50632 m .3896 .517 L .36065 .5154 L p .245 .577 .943 r
F P
0 g
s
.36065 .5154 m .34771 .50753 L .37882 .50632 L p .245 .577 .943 r
F P
0 g
s
.59549 .51435 m .58729 .51585 L .55932 .5278 L p 0 0 0 r
F P
0 g
s
.55481 .52681 m .55932 .5278 L .58729 .51585 L p .066 0 0 r
F P
0 g
s
.27399 .32374 m .28433 .34414 L .23398 .38563 L p .528 .514 .784 r
F P
0 g
s
.24642 .40124 m .23398 .38563 L .28433 .34414 L p .515 .507 .785 r
F P
0 g
s
.28433 .34414 m .29465 .36482 L .24642 .40124 L p .515 .507 .785 r
F P
0 g
s
.25889 .41687 m .24642 .40124 L .29465 .36482 L p .502 .503 .79 r
F P
0 g
s
.36809 .49356 m .37882 .50632 L .34771 .50753 L p .323 .564 .925 r
F P
0 g
s
.34771 .50753 m .33483 .49806 L .36809 .49356 L p .323 .564 .925 r
F P
0 g
s
.29465 .36482 m .30499 .38553 L .25889 .41687 L p .502 .503 .79 r
F P
0 g
s
.27139 .43228 m .25889 .41687 L .30499 .38553 L p .488 .501 .797 r
F P
0 g
s
.49708 .54103 m .50078 .53893 L .47551 .53875 L p .197 0 0 r
F P
0 g
s
.47551 .53875 m .468 .54115 L .49708 .54103 L p .197 0 0 r
F P
0 g
s
.666 .47904 m .65476 .48645 L .62035 .49805 L p .789 .982 .902 r
F P
0 g
s
.61203 .50551 m .62035 .49805 L .65476 .48645 L p .678 .978 .874 r
F P
0 g
s
.35741 .4789 m .36809 .49356 L .33483 .49806 L p .375 .546 .896 r
F P
0 g
s
.33483 .49806 m .322 .48712 L .35741 .4789 L p .375 .546 .896 r
F P
0 g
s
.55932 .5278 m .55481 .52681 L .52796 .53483 L p .023 0 0 r
F P
0 g
s
.30499 .38553 m .31536 .40595 L .27139 .43228 L p .488 .501 .797 r
F P
0 g
s
.28394 .44723 m .27139 .43228 L .31536 .40595 L p .473 .503 .808 r
F P
0 g
s
.31536 .40595 m .32578 .42579 L .28394 .44723 L p .473 .503 .808 r
F P
0 g
s
.29656 .46151 m .28394 .44723 L .32578 .42579 L p .456 .508 .823 r
F P
0 g
s
.3468 .46255 m .35741 .4789 L .322 .48712 L p .41 .53 .867 r
F P
0 g
s
.322 .48712 m .30924 .47487 L .3468 .46255 L p .41 .53 .867 r
F P
0 g
s
.32578 .42579 m .33625 .44475 L .29656 .46151 L p .456 .508 .823 r
F P
0 g
s
.30924 .47487 m .29656 .46151 L .33625 .44475 L p .436 .517 .843 r
F P
0 g
s
.33625 .44475 m .3468 .46255 L .30924 .47487 L p .436 .517 .843 r
F P
0 g
s
.4528 .53883 m .46042 .54123 L .43281 .53734 L p 0 .543 .755 r
F P
0 g
s
.67724 .47023 m .666 .47904 L .62868 .48856 L p .84 .949 .889 r
F P
0 g
s
.62035 .49805 m .62868 .48856 L .666 .47904 L p .789 .982 .902 r
F P
0 g
s
.55932 .5278 m .56386 .52663 L .59549 .51435 L p 0 0 0 r
F P
0 g
s
.60374 .51093 m .59549 .51435 L .56386 .52663 L p .466 .89 .823 r
F P
0 g
s
.52839 .53646 m .52796 .53483 L .50078 .53893 L p .072 0 0 r
F P
0 g
s
.50078 .53893 m .49708 .54103 L .52839 .53646 L p .072 0 0 r
F P
0 g
s
.52796 .53483 m .52839 .53646 L .55932 .5278 L p .023 0 0 r
F P
0 g
s
.68847 .4601 m .67724 .47023 L .63701 .4771 L p .86 .907 .864 r
F P
0 g
s
.62868 .48856 m .63701 .4771 L .67724 .47023 L p .84 .949 .889 r
F P
0 g
s
.49334 .54069 m .49708 .54103 L .468 .54115 L p .016 .59 .712 r
F P
0 g
s
.468 .54115 m .46042 .54123 L .49334 .54069 L p .016 .59 .712 r
F P
0 g
s
.44514 .53383 m .4528 .53883 L .42203 .53565 L p .171 .649 .929 r
F P
0 g
s
.42203 .53565 m .41123 .53171 L .44514 .53383 L p .171 .649 .929 r
F P
0 g
s
.69969 .44875 m .68847 .4601 L .64533 .46379 L p .865 .867 .837 r
F P
0 g
s
.63701 .4771 m .64533 .46379 L .68847 .4601 L p .86 .907 .864 r
F P
0 g
s
.56386 .52663 m .55932 .5278 L .52839 .53646 L p .263 .768 .756 r
F P
0 g
s
.61203 .50551 m .60374 .51093 L .56844 .52311 L p .677 .967 .928 r
F P
0 g
s
.56386 .52663 m .56844 .52311 L .60374 .51093 L p .466 .89 .823 r
F P
0 g
s
.7109 .4363 m .69969 .44875 L .65362 .44877 L p .864 .833 .815 r
F P
0 g
s
.64533 .46379 m .65362 .44877 L .69969 .44875 L p .865 .867 .837 r
F P
0 g
s
.72208 .42291 m .7109 .4363 L .66189 .43221 L p .859 .805 .796 r
F P
0 g
s
.65362 .44877 m .66189 .43221 L .7109 .4363 L p .864 .833 .815 r
F P
0 g
s
.43747 .52619 m .44514 .53383 L .41123 .53171 L p .329 .67 .975 r
F P
0 g
s
.41123 .53171 m .40041 .52549 L .43747 .52619 L p .329 .67 .975 r
F P
0 g
s
.73324 .40874 m .72208 .42291 L .67014 .41435 L p .853 .782 .782 r
F P
0 g
s
.66189 .43221 m .67014 .41435 L .72208 .42291 L p .859 .805 .796 r
F P
0 g
s
.52883 .53568 m .52839 .53646 L .49708 .54103 L p .203 .731 .798 r
F P
0 g
s
.49708 .54103 m .49334 .54069 L .52883 .53568 L p .203 .731 .798 r
F P
0 g
s
.52839 .53646 m .52883 .53568 L .56386 .52663 L p .263 .768 .756 r
F P
0 g
s
.74439 .39398 m .73324 .40874 L .67835 .3954 L p .846 .763 .771 r
F P
0 g
s
.67014 .41435 m .67835 .3954 L .73324 .40874 L p .853 .782 .782 r
F P
0 g
s
.48957 .53772 m .49334 .54069 L .46042 .54123 L p .271 .746 .937 r
F P
0 g
s
.46042 .54123 m .4528 .53883 L .48957 .53772 L p .271 .746 .937 r
F P
0 g
s
.62035 .49805 m .61203 .50551 L .57305 .51715 L p .78 .945 .931 r
F P
0 g
s
.56844 .52311 m .57305 .51715 L .61203 .50551 L p .677 .967 .928 r
F P
0 g
s
.75553 .37881 m .74439 .39398 L .68654 .37564 L p .838 .748 .763 r
F P
0 g
s
.67835 .3954 m .68654 .37564 L .74439 .39398 L p .846 .763 .771 r
F P
0 g
s
.56844 .52311 m .56386 .52663 L .52883 .53568 L p .539 .915 .941 r
F P
0 g
s
.76667 .36342 m .75553 .37881 L .69472 .35531 L p .831 .735 .759 r
F P
0 g
s
.68654 .37564 m .69472 .35531 L .75553 .37881 L p .838 .748 .763 r
F P
0 g
s
.4298 .51592 m .43747 .52619 L .40041 .52549 L p .421 .643 .949 r
F P
0 g
s
.40041 .52549 m .3896 .517 L .4298 .51592 L p .421 .643 .949 r
F P
0 g
s
.77783 .348 m .76667 .36342 L .70289 .3347 L p .823 .726 .757 r
F P
0 g
s
.69472 .35531 m .70289 .3347 L .76667 .36342 L p .831 .735 .759 r
F P
0 g
s
.78901 .33274 m .77783 .348 L .71106 .31405 L p .815 .718 .758 r
F P
0 g
s
.70289 .3347 m .71106 .31405 L .77783 .348 L p .823 .726 .757 r
F P
0 g
s
.71106 .31405 m .71927 .29362 L .78901 .33274 L p .815 .718 .758 r
F P
0 g
s
.42215 .50311 m .4298 .51592 L .3896 .517 L p .473 .608 .904 r
F P
0 g
s
.3896 .517 m .37882 .50632 L .42215 .50311 L p .473 .608 .904 r
F P
0 g
s
.62868 .48856 m .62035 .49805 L .57767 .50871 L p .819 .892 .895 r
F P
0 g
s
.57305 .51715 m .57767 .50871 L .62035 .49805 L p .78 .945 .931 r
F P
0 g
s
.48578 .53199 m .48957 .53772 L .4528 .53883 L p .456 .774 .997 r
F P
0 g
s
.4528 .53883 m .44514 .53383 L .48578 .53199 L p .456 .774 .997 r
F P
0 g
s
.52927 .53232 m .52883 .53568 L .49334 .54069 L p .469 .859 .976 r
F P
0 g
s
.49334 .54069 m .48957 .53772 L .52927 .53232 L p .469 .859 .976 r
F P
0 g
s
.52883 .53568 m .52927 .53232 L .56844 .52311 L p .539 .915 .941 r
F P
0 g
s
.41453 .48788 m .42215 .50311 L .37882 .50632 L p .502 .576 .862 r
F P
0 g
s
.37882 .50632 m .36809 .49356 L .41453 .48788 L p .502 .576 .862 r
F P
0 g
s
.57305 .51715 m .56844 .52311 L .52927 .53232 L p .693 .916 .97 r
F P
0 g
s
.28433 .34414 m .27399 .32374 L .34782 .287 L p .579 .509 .741 r
F P
0 g
s
.63701 .4771 m .62868 .48856 L .58229 .49779 L p .829 .839 .855 r
F P
0 g
s
.57767 .50871 m .58229 .49779 L .62868 .48856 L p .819 .892 .895 r
F P
0 g
s
.40696 .47045 m .41453 .48788 L .36809 .49356 L p .52 .551 .828 r
F P
0 g
s
.36809 .49356 m .35741 .4789 L .40696 .47045 L p .52 .551 .828 r
F P
0 g
s
.34782 .287 m .35515 .31111 L .28433 .34414 L p .579 .509 .741 r
F P
0 g
s
.29465 .36482 m .28433 .34414 L .35515 .31111 L p .572 .504 .74 r
F P
0 g
s
.35515 .31111 m .36247 .33556 L .29465 .36482 L p .572 .504 .74 r
F P
0 g
s
.30499 .38553 m .29465 .36482 L .36247 .33556 L p .566 .501 .741 r
F P
0 g
s
.39943 .45106 m .40696 .47045 L .35741 .4789 L p .532 .532 .801 r
F P
0 g
s
.35741 .4789 m .3468 .46255 L .39943 .45106 L p .532 .532 .801 r
F P
0 g
s
.36247 .33556 m .36979 .36001 L .30499 .38553 L p .566 .501 .741 r
F P
0 g
s
.31536 .40595 m .30499 .38553 L .36979 .36001 L p .56 .501 .746 r
F P
0 g
s
.36979 .36001 m .37714 .38413 L .31536 .40595 L p .56 .501 .746 r
F P
0 g
s
.32578 .42579 m .31536 .40595 L .37714 .38413 L p .554 .503 .753 r
F P
0 g
s
.39195 .43 m .39943 .45106 L .3468 .46255 L p .541 .519 .78 r
F P
0 g
s
.3468 .46255 m .33625 .44475 L .39195 .43 L p .541 .519 .78 r
F P
0 g
s
.37714 .38413 m .38452 .40757 L .32578 .42579 L p .554 .503 .753 r
F P
0 g
s
.33625 .44475 m .32578 .42579 L .38452 .40757 L p .548 .509 .765 r
F P
0 g
s
.38452 .40757 m .39195 .43 L .33625 .44475 L p .548 .509 .765 r
F P
0 g
s
.48199 .52346 m .48578 .53199 L .44514 .53383 L p .548 .731 .96 r
F P
0 g
s
.44514 .53383 m .43747 .52619 L .48199 .52346 L p .548 .731 .96 r
F P
0 g
s
.64533 .46379 m .63701 .4771 L .58692 .48447 L p .829 .796 .82 r
F P
0 g
s
.58229 .49779 m .58692 .48447 L .63701 .4771 L p .829 .839 .855 r
F P
0 g
s
.52971 .52627 m .52927 .53232 L .48957 .53772 L p .616 .845 .987 r
F P
0 g
s
.48957 .53772 m .48578 .53199 L .52971 .52627 L p .616 .845 .987 r
F P
0 g
s
.57767 .50871 m .57305 .51715 L .52971 .52627 L p .752 .857 .927 r
F P
0 g
s
.52927 .53232 m .52971 .52627 L .57305 .51715 L p .693 .916 .97 r
F P
0 g
s
.65362 .44877 m .64533 .46379 L .59153 .46888 L p .825 .761 .792 r
F P
0 g
s
.58692 .48447 m .59153 .46888 L .64533 .46379 L p .829 .796 .82 r
F P
0 g
s
.47819 .51213 m .48199 .52346 L .43747 .52619 L p .589 .68 .904 r
F P
0 g
s
.43747 .52619 m .4298 .51592 L .47819 .51213 L p .589 .68 .904 r
F P
0 g
s
.66189 .43221 m .65362 .44877 L .59612 .4512 L p .819 .734 .77 r
F P
0 g
s
.59153 .46888 m .59612 .4512 L .65362 .44877 L p .825 .761 .792 r
F P
0 g
s
.58229 .49779 m .57767 .50871 L .53016 .51745 L p .769 .797 .875 r
F P
0 g
s
.52971 .52627 m .53016 .51745 L .57767 .50871 L p .752 .857 .927 r
F P
0 g
s
.67014 .41435 m .66189 .43221 L .60069 .43166 L p .813 .712 .754 r
F P
0 g
s
.59612 .4512 m .60069 .43166 L .66189 .43221 L p .819 .734 .77 r
F P
0 g
s
.53016 .51745 m .52971 .52627 L .48578 .53199 L p .673 .785 .933 r
F P
0 g
s
.48578 .53199 m .48199 .52346 L .53016 .51745 L p .673 .785 .933 r
F P
0 g
s
.47441 .49809 m .47819 .51213 L .4298 .51592 L p .607 .636 .854 r
F P
0 g
s
.4298 .51592 m .42215 .50311 L .47441 .49809 L p .607 .636 .854 r
F P
0 g
s
.67835 .3954 m .67014 .41435 L .60524 .41052 L p .807 .696 .742 r
F P
0 g
s
.60069 .43166 m .60524 .41052 L .67014 .41435 L p .813 .712 .754 r
F P
0 g
s
.68654 .37564 m .67835 .3954 L .60977 .38808 L p .802 .683 .733 r
F P
0 g
s
.60524 .41052 m .60977 .38808 L .67835 .3954 L p .807 .696 .742 r
F P
0 g
s
.69472 .35531 m .68654 .37564 L .61428 .36464 L p .797 .673 .727 r
F P
0 g
s
.60977 .38808 m .61428 .36464 L .68654 .37564 L p .802 .683 .733 r
F P
0 g
s
.70289 .3347 m .69472 .35531 L .61878 .34055 L p .791 .665 .724 r
F P
0 g
s
.61428 .36464 m .61878 .34055 L .69472 .35531 L p .797 .673 .727 r
F P
0 g
s
.58692 .48447 m .58229 .49779 L .5306 .5059 L p .772 .747 .831 r
F P
0 g
s
.53016 .51745 m .5306 .5059 L .58229 .49779 L p .769 .797 .875 r
F P
0 g
s
.71106 .31405 m .70289 .3347 L .62327 .3161 L p .786 .66 .724 r
F P
0 g
s
.61878 .34055 m .62327 .3161 L .70289 .3347 L p .791 .665 .724 r
F P
0 g
s
.47063 .4815 m .47441 .49809 L .42215 .50311 L p .616 .603 .815 r
F P
0 g
s
.42215 .50311 m .41453 .48788 L .47063 .4815 L p .616 .603 .815 r
F P
0 g
s
.71927 .29362 m .71106 .31405 L .62776 .29163 L p .781 .657 .726 r
F P
0 g
s
.62327 .3161 m .62776 .29163 L .71106 .31405 L p .786 .66 .724 r
F P
0 g
s
.62776 .29163 m .63227 .26744 L .71927 .29362 L p .781 .657 .726 r
F P
0 g
s
.5306 .5059 m .53016 .51745 L .48199 .52346 L p .693 .727 .876 r
F P
0 g
s
.48199 .52346 m .47819 .51213 L .5306 .5059 L p .693 .727 .876 r
F P
0 g
s
.46688 .46255 m .47063 .4815 L .41453 .48788 L p .62 .578 .785 r
F P
0 g
s
.41453 .48788 m .40696 .47045 L .46688 .46255 L p .62 .578 .785 r
F P
0 g
s
.59153 .46888 m .58692 .48447 L .53105 .49169 L p .769 .709 .796 r
F P
0 g
s
.5306 .5059 m .53105 .49169 L .58692 .48447 L p .772 .747 .831 r
F P
0 g
s
.46315 .44151 m .46688 .46255 L .40696 .47045 L p .623 .559 .762 r
F P
0 g
s
.40696 .47045 m .39943 .45106 L .46315 .44151 L p .623 .559 .762 r
F P
0 g
s
.35515 .31111 m .34782 .287 L .43754 .26392 L p .634 .529 .717 r
F P
0 g
s
.43754 .26392 m .44118 .29004 L .35515 .31111 L p .634 .529 .717 r
F P
0 g
s
.36247 .33556 m .35515 .31111 L .44118 .29004 L p .632 .525 .715 r
F P
0 g
s
.44118 .29004 m .44482 .3165 L .36247 .33556 L p .632 .525 .715 r
F P
0 g
s
.36979 .36001 m .36247 .33556 L .44482 .3165 L p .63 .524 .715 r
F P
0 g
s
.45944 .41869 m .46315 .44151 L .39943 .45106 L p .624 .546 .745 r
F P
0 g
s
.39943 .45106 m .39195 .43 L .45944 .41869 L p .624 .546 .745 r
F P
0 g
s
.53105 .49169 m .5306 .5059 L .47819 .51213 L p .699 .681 .829 r
F P
0 g
s
.47819 .51213 m .47441 .49809 L .53105 .49169 L p .699 .681 .829 r
F P
0 g
s
.44482 .3165 m .44845 .34295 L .36979 .36001 L p .63 .524 .715 r
F P
0 g
s
.37714 .38413 m .36979 .36001 L .44845 .34295 L p .628 .525 .718 r
F P
0 g
s
.45576 .39441 m .45944 .41869 L .39195 .43 L p .625 .536 .733 r
F P
0 g
s
.39195 .43 m .38452 .40757 L .45576 .39441 L p .625 .536 .733 r
F P
0 g
s
.44845 .34295 m .4521 .36905 L .37714 .38413 L p .628 .525 .718 r
F P
0 g
s
.38452 .40757 m .37714 .38413 L .4521 .36905 L p .627 .529 .724 r
F P
0 g
s
.4521 .36905 m .45576 .39441 L .38452 .40757 L p .627 .529 .724 r
F P
0 g
s
.59612 .4512 m .59153 .46888 L .53149 .47496 L p .765 .68 .769 r
F P
0 g
s
.53105 .49169 m .53149 .47496 L .59153 .46888 L p .769 .709 .796 r
F P
0 g
s
.60069 .43166 m .59612 .4512 L .53193 .45592 L p .76 .658 .749 r
F P
0 g
s
.53149 .47496 m .53193 .45592 L .59612 .4512 L p .765 .68 .769 r
F P
0 g
s
.53149 .47496 m .53105 .49169 L .47441 .49809 L p .699 .647 .794 r
F P
0 g
s
.47441 .49809 m .47063 .4815 L .53149 .47496 L p .699 .647 .794 r
F P
0 g
s
.60524 .41052 m .60069 .43166 L .53237 .43483 L p .756 .641 .734 r
F P
0 g
s
.53193 .45592 m .53237 .43483 L .60069 .43166 L p .76 .658 .749 r
F P
0 g
s
.60977 .38808 m .60524 .41052 L .53281 .41198 L p .752 .629 .723 r
F P
0 g
s
.53237 .43483 m .53281 .41198 L .60524 .41052 L p .756 .641 .734 r
F P
0 g
s
.53193 .45592 m .53149 .47496 L .47063 .4815 L p .698 .621 .767 r
F P
0 g
s
.47063 .4815 m .46688 .46255 L .53193 .45592 L p .698 .621 .767 r
F P
0 g
s
.61428 .36464 m .60977 .38808 L .53324 .38769 L p .749 .619 .715 r
F P
0 g
s
.53281 .41198 m .53324 .38769 L .60977 .38808 L p .752 .629 .723 r
F P
0 g
s
.61878 .34055 m .61428 .36464 L .53367 .36232 L p .745 .612 .71 r
F P
0 g
s
.53324 .38769 m .53367 .36232 L .61428 .36464 L p .749 .619 .715 r
F P
0 g
s
.62327 .3161 m .61878 .34055 L .5341 .33623 L p .742 .607 .708 r
F P
0 g
s
.53367 .36232 m .5341 .33623 L .61878 .34055 L p .745 .612 .71 r
F P
0 g
s
.62776 .29163 m .62327 .3161 L .53453 .30977 L p .739 .605 .708 r
F P
0 g
s
.5341 .33623 m .53453 .30977 L .62327 .3161 L p .742 .607 .708 r
F P
0 g
s
.53237 .43483 m .53193 .45592 L .46688 .46255 L p .696 .602 .747 r
F P
0 g
s
.46688 .46255 m .46315 .44151 L .53237 .43483 L p .696 .602 .747 r
F P
0 g
s
.63227 .26744 m .62776 .29163 L .53496 .28329 L p .736 .604 .71 r
F P
0 g
s
.53453 .30977 m .53496 .28329 L .62776 .29163 L p .739 .605 .708 r
F P
0 g
s
.53496 .28329 m .53539 .25714 L .63227 .26744 L p .736 .604 .71 r
F P
0 g
s
.53281 .41198 m .53237 .43483 L .46315 .44151 L p .694 .587 .731 r
F P
0 g
s
.46315 .44151 m .45944 .41869 L .53281 .41198 L p .694 .587 .731 r
F P
0 g
s
.53324 .38769 m .53281 .41198 L .45944 .41869 L p .692 .576 .72 r
F P
0 g
s
.45944 .41869 m .45576 .39441 L .53324 .38769 L p .692 .576 .72 r
F P
0 g
s
.44118 .29004 m .43754 .26392 L .53539 .25714 L p .687 .562 .708 r
F P
0 g
s
.53539 .25714 m .53496 .28329 L .44118 .29004 L p .687 .562 .708 r
F P
0 g
s
.44482 .3165 m .44118 .29004 L .53496 .28329 L p .688 .56 .705 r
F P
0 g
s
.53496 .28329 m .53453 .30977 L .44482 .3165 L p .688 .56 .705 r
F P
0 g
s
.44845 .34295 m .44482 .3165 L .53453 .30977 L p .688 .561 .705 r
F P
0 g
s
.53367 .36232 m .53324 .38769 L .45576 .39441 L p .691 .568 .713 r
F P
0 g
s
.45576 .39441 m .4521 .36905 L .53367 .36232 L p .691 .568 .713 r
F P
0 g
s
.53453 .30977 m .5341 .33623 L .44845 .34295 L p .688 .561 .705 r
F P
0 g
s
.4521 .36905 m .44845 .34295 L .5341 .33623 L p .689 .563 .708 r
F P
0 g
s
.5341 .33623 m .53367 .36232 L .4521 .36905 L p .689 .563 .708 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ojn?]@03o`00
0?nlV[Go_9Ze00?o_9Ze2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?n_SkD00ol0003o_9Ze
okbJ]@0>okbJ]@_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nRQkL00ol0003o[hneojn?
]@0Mojn?]@03o`000?nlV[Go_9Ze01Wo_9Ze1ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001_nRQkL00ol0003o[hneojn?]@0Mojn?]@03o`000?nlV[Go_9Ze01go_9Ze00?o0000
olNX^Oo7Z;T00ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool0
02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002OnRQkL00ol0
003o[hneojn?]@0Mojn?]@03o`000?nlV[Go_9Ze01go_9Ze00?o0000olNX^Oo7Z;T00oo7Z;T3o`00
00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Ko
oooo00?o0000ooooooooool0IOooool4o`0000goXXNg00?o0000ojn?]On_SkD07On_SkD00ol0003o
_9ZeokbJ]@0LokbJ]@03o`000?o7Z;WoajRi00OoajRi0ol0000:ooooo`03o`000?oooooooooo03;o
oooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo
1?l0000Boj:7]`03o`000?n_SkGo[hne01co[hne00?o0000okbJ]OnlV[D07?nlV[D00ol0003oajRi
olNX^@0:olNX^@?o00001oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo
000Aooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool3o`0001Ko
XXNg00?o0000ojn?]On_SkD07?n_SkD00ol0003o_9ZeokbJ]@0LokbJ]@03o`000?o7Z;WoajRi00go
ajRi0ol00005ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0017ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool4o`0001WoXXNg00?o0000ojn?]On_
SkD05?n_SkD9o`0000;o_9Ze1_l0000FokbJ]@03o`000?o7Z;WoajRi013oajRi0ol00002ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002oooool00ol0003o
ooooooooo`1Cooooo`?o00007OnRQkL00ol0003o[hneojn?]@05ojn?]@oo00002?n`Sk@00ol0003o
_IZeokfJ]@06okfJ]@oo00001_nlV[D00ol0003oajRiolNX^@0DolNX^@?o0000=_ooool00ol0003o
ooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo0_l000000onDP[go
0000oj:7]`0Koj:7]`[o00005on`Sk@00ol0003o_IZeokfJ]@0EokfJ]@Oo00006?o7Z;T4o`0003Co
oooo00?o0000ooooooooool0:?ooool0017ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04gooooo0_l00004oiB2_@03o`000?nRQkOoXXNg01GoXXNg1?l00002oj66]`03o`000?n`SkCo/8nd
01co/8nd00?o0000okfJ]OnmV[D06onmV[D00ol0003obJRiolVX^@03o`0001?oajRi00Co0000olNX
^Oo7Z;WoajRi0ol0000aooooo`;o0000:Oooool0017ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1:
ooooo`;o00001_nDP[d00ol0003oXXNgoj:7]`0Aoj:7]`Co00001_nQQ[L00ol0003o/8ndok2?]00L
ok2?]003o`000?nmV[Go_IZe01_o_IZe00?o0000olVX^Oo9Z;T00oo9Z;T4o`0000ooajRi00?o0000
olNX^Oo7Z;T00_o7Z;T01?l0003od;O2o`000?l0000_ooooo`;o0000:Oooool0017ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000@ooooo`03o`000?oo
oooooooo04Oooooo0_l00008oiB2_@03o`000?nRQkOoXXNg00goXXNg1?l0000:oj66]`03o`000?n`
SkCo/8nd01co/8nd00?o0000okfJ]OnmV[D06onmV[D00ol0003obJRiolVX^@07olVX^@?o00003?o7
Z;T00ol0003oajRiolNX^@02olNX^@05o`000?o@]l;od;O2om2g`_l00000<?ooool00ol0003ooooo
ooooo`0Vooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`00
0?oooooooooo013ooooo0_l00015ooooo`;o00002onDP[d00ol0003oXXNgoj:7]`08oj:7]`Co0000
3_nQQ[L00ol0003o/8ndok2?]00Lok2?]003o`000?nmV[Go_IZe01_o_IZe00?o0000olVX^Oo9Z;T0
2_o9Z;T4o`0000OoajRi0_l00003olNX^@03o`000?o@]l;od;O200?od;O20_l0000^ooooo`03o`00
0?oooooooooo02Kooooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@?oo
ool2o`0000goU8:m00?o0000oj:7]onRQkL01?nRQkL4o`0001?oXHJg00?o0000ok2?]?n`Sk@06on`
Sk@00ol0003o_IZeokfJ]@0JokfJ]@03o`000?o9Z;WobJRi00oobJRi0ol000001_o7Z;Wo0000o`00
0?l0003oajRio`0000?oajRi00?o0000om2g`_o@]l801Oo@]l82o`0002gooooo00?o0000oooooooo
ool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l0000?oiB2_@03o`00
0?nRQkOoXXNg00Co00005onQQ[L00ol0003o/8ndok2?]00Dok2?]0So00000_nmV[D5o`0001Go_IZe
00?o0000olVX^Oo9Z;T04?o9Z;T6o`0000;oajRi00Co0000olNX^Oo7Z;Wo00002Oo@]l82o`0002co
oooo00?o0000ooooooooool09?ooool002[ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0jooooo`;o00004OnDP[d3o`0001_oXHJg00?o0000ok2?]?n`Sk@01On`Sk@?o`0000Oo/8nd
00?o0000okfK]OnmVkD01OnmVkD?o`0000Ko_IZe00?o0000olVX^Oo9Z;T03Oo9Z;T3o`0000KobJRi
1Ol0000<om2g`P;o0000:_ooool2o`0002Gooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0=oooool2o`00013oU8:m0ol000000onBPKgo0000oj66]`0Ioj66]`[o00005_n`
Sk@00ol0003o_I^eokfK]@0DokfK]@Oo00003?o9Z;T3o`0000cobJRi0_l0000>om2g`P03o`000?oo
oooooooo02Oooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@07ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo03Cooooo0_l0000@oiB2_@;o00001?nBPKd00ol0003oXHJgoj66]`0Doj66]`Co0000
0_nQQ[L00ol0003o/8ndok2?]00Kok2?]003o`000?nmVkGo_I^e01[o_I^e00?o0000olZZ^Oo:Z[T0
1Ol00002olVX^@?o00004?o9Z;T00ol0003od[W1o`00000=om2g`P;o0000:?ooool00ol0003ooooo
ooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01_ooool002[ooooo0_l0000Iooooo`03o`000?oooooooooo037ooooo0_l0000@oiB2_@;o0000
1onBPKd00ol0003oXHJgoj66]`0?oj66]`Co00001_nQQ[L00ol0003o/8ndok2?]00Kok2?]003o`00
0?nmVkGo_I^e01[o_I^e00?o0000olZZ^Oo:Z[T01?o:Z[T5o`00013obJRi00?o0000om:i`Ol00000
0_oB^L42o`0000cod;O20_l0000Wooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Gooooo000Yooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0;_ooool2o`0000ooU8:m0ol00009oi:1_@03o`000?nQQ[OoXHJg00_oXHJg
1?l0000:oj66]`03o`000?n`SkCo/8nd01[o/8nd00?o0000okfK]OnmVkD06_nmVkD00ol0003obZZi
olZZ^@02olZZ^@?o00001Oo:Z[T4o`0000cobJRi00Co0000om:i`OoB^L7o00000ooB^L42o`0000co
d;O20_l0000Vooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0;?ooool00ol0003oQh?8o`00000=oiB2_@;o00003?nBPKd00ol0003oXHJgoj66]`08oj66]`?o
00003_nQQ[L00ol0003o/8ndok2?]00Jok2?]003o`000?nmVkGo_I^e01[o_I^e00?o0000olZZ^Ol0
00000_l0000<olZZ^@Go00001_o9Z;T00ol0003od[W1om:i`@02om:i`@03o`000?oB^L7od[W100;o
d[W10_l0000<om2g`P03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3o`00
01cooooo00?o0000ooooooooool0:_ooool01Ol0003oQh?8ohN3b?n7PlSo000000WoU8:m0ol0000>
oi:1_@03o`000?nQQ[OoXHJg00CoXHJg1?l0000Boj66]`03o`000?n`SkCo/8nd01Wo/8nd00?o0000
okfK]OnmVkD06OnmVkD3o`0001CobZZi1?l00002olVX^@03o`000?oB^L7od[W100;od[W100?o0000
om:i`OoB^L401?oB^L42o`0000_od;O20_l0000Tooooo`03o`000?oooooooooo00?ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0:?ooool00ol0003oQh?8ohN3b002ohN3b003o`000?nDP[go
U8:m00GoU8:m0_l0000Boi:1_@03o`000?nQQ[Oo000000?o00005_nQQ[L00ol0003o/8ndok2?]00I
ok2?]003o`000?nmVkGo_I^e01Ko_I^e0ol000000onmVkGo0000olZZ^@0HolZZ^@;o00001_oB^L40
0ol0003od[W1om:i`@05om:i`@;o00002oo@]l800ol0003oooooooooo`0Pooooo`?o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?n7PlSoQh?800CoQh?800?o0000
oiB2_OnDP[d00_nDP[d2o`0001?oTX6m0ol0000Joj66]`03o`000?n`SkCo/8nd01;o/8nd2?l00000
0onmVkGo0000o`00000;o`0000Oo_I^e0ol00003okfK]@03o`000?o:Z[WobZZi01WobZZi00Co0000
omBl`_l0003o00001?oB^L400ol0003od[W1om:i`@06om:i`@;o00002Oo@]l82o`0002?ooooo00?o
0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?n7PlSoQh?800GoQh?800?o0000oiB2_Ol000000_l0000Boi:1_@?o000000?oT82mo`000?nQ
Q[L06_nQQ[L00ol0003o/8ndok2?]004ok2?]0ko00001on`T;D00ol0003o_YbeokjL]@0<okjL]@ko
00006_o:Z[T00ol0003oe;c2omBl`P02omBl`P;o00000ooB^L400ol0003od[W1om:i`@07om:i`@;o
00001_o@]l801?l0003od/O?om;7col0000Sooooo`03o`000?oooooooooo01kooooo0006ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0000Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ohN3b?n7PlP01_n7PlP2o`0001?oTX6m0_l00005oi20_@03o`000?nQQ[OoXHJg01KoXHJg2Ol0000E
ok2@]@03o`000?nnW;Go_Ybe00ko_Ybe0_l00009okjL]@04o`000?o<[;[oc:bjolb/^PGo00004_o:
Z[T00ol0003oe;c2omBl`P04omBl`P;o000000?od[W1o`000?oB^L402_oB^L42o`0000?od;O200?o
0000om;7cooBall00_oBall00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01gooooo0004
o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l0
0008ohN3b003o`000?n3PLSo0000013oTX6m0ol00007oi20_@03o`000?nQQ[OoXHJg01;oXHJg1?l0
0002oj26]`03o`000?n`T;Go/92e01Wo/92e00?o0000okjL]OnnW;D02onnW;D3o`0000_o_Ybe00?o
0000olb/^_o<[;X01_o<[;X5o`0000cobZZi00?o0000omBl`_oD_<801ooD_<83o`0000cod[W10_l0
00000oo@]l;o0000om;7c`04om;7c`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01gooooo00?o
0000ohN3b?n7PlP01on7PlP01Ol0003oPh78oh>1b?n3PLSo000000goTX6m0_l0000:oi20_@03o`00
0?nQQ[OoXHJg00koXHJg1?l00006oj26]`03o`000?n`T;Go/92e01Wo/92e00?o0000okjL]OnnW;D0
2?nnW;D3o`0000ko_Ybe00?o0000olb/^_o<[;X02oo<[;X5o`0000OobZZi00?o0000omBl`_oD_<80
2OoD_<83o`0000cod[W100?o0000om;7cooBall01OoBall00ol0003oooooooooo`0Pooooo`;o0000
7Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02Cooooo0_l0000Looooo`03
o`000?n7PlSoQh?800OoQh?800?o0000oh>1b?n3PLP00_n3PLP00ol0003oTX6moi:1_@09oi:1_@;o
00003On@P;d00ol0003oXHJgoj66]`08oj66]`Go00002onPQ[L00ol0003o/92eok2@]@0Hok2@]@03
o`000?nnW;Go_Ybe00Go_Ybe0ol0000AokjL]@03o`000?o<[;[oc:bj013oc:bj1Ol00002olZZ^@03
o`000?oD_<;oe;c200_oe;c20ol0000:om:i`@;o00001ooBall00ol0003oooooooooo`0Nooooo`03
o`000?oooooo000001gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0000Wooooo`03o`000?oooooooooo01So
oooo00?o0000ohN3b?n7PlP01on7PlP00ol0003oPh78oh>1b004oh>1b003o`000?nBPKgoTX6m00Go
TX6m0ol0000?oi20_@03o`000?nQQ[OoXHJg00CoXHJg1?l0000@oj26]`03o`000?n`T;Go/92e01So
/92e00?o0000okjL]OnnW;D00_nnW;D3o`0001?o_Ybe00?o0000olb/^_o<[;X05_o<[;X2o`0000ko
e;c200?o0000omBl`_oD_<800_l00007om:i`@04o`000?oEbm3oeL_@o`0000Ood/O?00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Fooooo`03o`000?n7PlSoQh?800OoQh?800?o0000
oh>1b?n3PLP01_n3PLP00ol0003oTX6moi:1_@02oi:1_@;o00004_n@P;d00ol0003oXHJgoj66]`04
o`0001CoX8Jg00?o0000ok2@]On`T;D06?n`T;D00ol0003o_Ybeo`000002o`0001Ko_Ybe00?o0000
olb/^_o<[;X05oo<[;X00ol0003oe[o3o`000002o`0000_oe;c200Co0000omBl`_oD_<;oe;c20_l0
0004om:i`@03o`000?oEbm3oeL_@00;oeL_@00?o0000om;7cooBall01OoBall00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool05?ooool00ol0003oQh?8ohN3b007ohN3b003o`000?n3PLSoPh7800OoPh78
00?o0000oi:1_Ol000000_l0000Doi20_@?o00006?nPQ[L00ol0003o/92eok2@]@0Dok2@]A?o0000
3?nnW;D00ol0003oc:bjolb/^P0Golb/^P03o`000?oF_l?oe[o300;oe[o30_l0000:omBl`P03o`00
0?oD_<;oe;c200;oe;c20_l000000ooB^L7o0000omG;d005omG;d003o`000?oBalood/O?00God/O?
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Jooooo`009oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo01;ooooo00?o0000ohN3b?n7PlP01_n7PlP2o`0000[oPh780_l0
000Doi20_@?o000000?oSh2no`000?nPQ[L06?nPQ[L00ol0003o/92eok2@]@0;ok2@]@co000000?o
/96fo`000?noW[L03OnoW[L=o`0001Soc:bj00?o0000omJo`ooF_l<01OoF_l<3o`0000Ooe;c200?o
0000omBl`_oD_<801?oD_<800ol0003oeL_@omG;d006omG;d003o`000?oBalood/O?00God/O?00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000
ooooooooool04?ooool00ol0003oQh?8ohN3b006ohN3b003o`000?n3PLSoPh7800WoPh7800?o0000
oh20b_l000004On@P;d3o`0000CoSh2n00?o0000oj26]onPQ[L06?nPQ[L01?l0003o/92eok2@]On`
T;D9o`0000Ko/96f0ol00004ok2A]P03o`000?noW[Oo_ijg01So_ijg00Co0000olf^^oo=[[_ocJjk
1_l0000?olb/^P03o`000?oF_l?oe[o300Soe[o30_l00006omBl`P03o`000?oD_<;oe;c200?oe;c2
00?o0000omS?dOoEbm001ooEbm000ol0003od/O?om;7c`05om;7c`03o`000?oooooooooo01kooooo
00?o0000ooooooooool06?ooool002Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?n7PlSoQh?800KoQh?800?o0000oh>1b?n3PLP02On3PLP01Ol0003oP83:oh20
b_n0P<[o000000goT82m0ol00008ohn0_P03o`000?nPQ[OoX8Jg01GoX8Jg1_l0000<ok2A]P?o0000
1on`TKH00ol0003o_ijgoknN]`0HoknN]`03o`000?o=[[_ocJjk00OocJjk1_l00009olb/^P03o`00
0?oF_l?oe[o300[oe[o30ol00004omBl`P05o`000?oD_<;oe;c2omBl`_l000000ooHcm400ol0003o
eL_@omG;d005omG;d003o`000?oBalood/O?00God/O?00?o0000ooooooooool07?ooool2o`0001[o
oooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool00ol0003oQh?8
ohN3b005ohN3b003o`000?n3PLSoPh7800SoPh780_l00004oh20bP03o`000?n@P;goT82m00WoT82m
0_l0000;ohn0_P03o`000?nPQ[OoX8Jg013oX8Jg1Ol00002oj27^@03o`000?n`TKKo/96f00[o/96f
0ol0000:ok2A]P03o`000?noW[Oo_ijg01Oo_ijg00?o0000olf^^oo=[[/03_o=[[/6o`0000;oc:bj
00?o0000omJo`ooF_l<03_oF_l<2o`0000?oe;c200?o0000omBl`_l000001OoHcm400ol0003oeL_@
omG;d005omG;d003o`000?oBalood/O?00God/O?00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Gooooo`009oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00_ooooo00?o
0000oh:@f?l000001On7PlP00ol0003oPh78oh>1b008oh>1b003o`000?n0P<[oP83:00GoP83:00?o
0000oi20_On@P;d01On@P;d3o`0000goSh2n00?o0000oj26]onPQ[L02onPQ[L5o`0000OoX8Ni00?o
0000ok2A]_n`TKH01on`TKH3o`0000go/96f00?o0000oknN]onoW[L05onoW[L00ol0003ocJjkolf^
^`0Dolf^^`?o00004_oF_l<5o`0000Oof<oA00?o0000omG;d?oEbm001OoEbm000ol0003od/O?om;7
c`05om;7c`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool002Oooooo0_l0000`
ooooo`03o`000?oooooooooo00[ooooo00Co0000oh:@f?n2T=So00000on7PlP00ol0003oPh78oh>1
b008oh>1b003o`000?n0P<[oP83:00KoP83:00?o0000oi20_On@P;d00_n@P;d3o`00013oSh2n00?o
0000oj26]onPQ[L01_nPQ[L5o`0000coX8Ni00?o0000ok2A]_n`TKH01?n`TKH3o`00013o/96f00?o
0000oknN]onoW[L05onoW[L00ol0003ocJjkolf^^`0Folf^^`03o`000?oH`lGof<?500?o00004?oF
_l<2o`0000Sof<oA00?o0000omG;d?oEbm001OoEbm000ol0003od/O?om;7c`05om;7c`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05_ooool002Kooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`08ooooo`03o`000?n2T=SoPY3H00;oPY3H00?o0000ohN3b?l000002On3PLP2
o`0000WoP83:00?o0000oi20_Ol000000_l0000Dohn0_P03o`000?nPQ[OoX8Jg00Go00004OnPQkT0
0ol0003o/96fok2A]P02ok2A]P;o00004on`TKH00ol0003o_ijgoknN]`0GoknN]`03o`000?o=[[_o
cJjk01GocJjk00?o0000omS3aOoH`lD01?oH`lD3o`0000goe[o300?o0000om[Ddol000002?oHcm42
o`0000KoeL_@00?o0000om;7cooBall01?oBall2o`0001kooooo00?o0000ooooooooool05Oooool0
02Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?n2T=SoPY3H
00?oPY3H00?o0000oh>1b?n3PLP01on3PLP00ol0003oP83:oh20bP09oh20bP;o00005_n?P;h4o`00
01OoX8Ni1?l0000Eok2A]P03o`000?noW[Oo_ijg01Ko_ijg00?o0000olf^^oo=[[/05_o=[[/00ol0
003of<?5omS3a@07omS3a@?o00002OoF_l<01?l0003of]CCom[DdooJe=<2o`0000Sof<oA00?o0000
omG;d?oEbm001?oEbm001?l0003od/O?om;7cooBall2o`000003olO@h?l0003ooooo01gooooo0_l0
000Fooooo`009_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00?o0000
oh:@f?n2T=P01?n2T=P00ol0003oPh78oh>1b006oh>1b003o`000?n0P<[oP83:00WoP83:00?o0000
ogb0c?l000004on?P;h3o`000003ohf0`?l0003oX8Ni01KoX8Ni0ol0000Bok2A]POo000000?o_ijg
o`000?l000005_l00002olf^^`Co00004Oo=[[/00ol0003of<?5omS3a@0;omS3a@?o00001OoF_l<0
0ol0003of]CCom[Dd`02om[Dd`03o`000?oJe=?o000000Sof<oA00?o0000omG;d?oEbm001?oEbm00
0ol0003od/O?o`000004olO@h003o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool0
02Kooooo0ol0000dooooo`03o`000?oooooooooo00Cooooo00?o0000oh:@f?n2T=P00on2T=P00ol0
003oO8kJo`000005oh>1b0;o00002_n0P<X2o`0000?oO83<00?o0000ohn0__n?P;h03On?P;h3o`00
00CoSH3000?o0000oj27^OnPQkT04_nPQkT3o`0000;oX8Ni00?o0000ok2A]_n`TKH00on`TKH=o`00
00Ko/I>h00?o0000ol2Q^Oo0XKT05_o0XKT00ol0003oc[:moljb_@04oljb_@_o00001_o=[[/00ol0
003of<?5omS3a@0>omS3a@?o00000_oF_l<00ol0003of]CCom[Dd`03om[Dd`03o`000?oJe=?o0000
00Sof<oA00?o0000omG;d?oEbm000ooEbm02o`0000Goam3P00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Cooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;o
oooo00?o0000oh:@f?n2T=P00on2T=P01Ol0003oO8kJogb>f_mlS][o000000?oPh7800?o0000oh20
b_n0P<X02On0P<X00ol0003oO83<ogb0c003ogb0c003o`000?n?P;koSh2n00[oSh2n0ol00008ohf0
`003o`000?nPQkWoX8Ni00koX8Ni0ol00002oj27^@Wo00004onaTkP00ol0003o`:6iol2Q^@0Fol2Q
^@03o`000?o>/[goc[:m00ooc[:m1_l0000DomS3a@;o00001ooJe=<01?l0003of]CCo`000?l00007
omS?d@06o`000?oEbm3oeL_@omG;d?l0003obMGS1_o7d>000ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01;ooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0fooooo`04o`000?ooooooooooo`0000KoPY3H00?o0000ogb>f_mlS]X00_mlS]X00ol0003o
Ph78o`00000:oh20bP;o00001omlP<`00ol0003oSh2nohn0_P06ohn0_P?o00002on=P<000ol0003o
X8Nioj27^@0;oj27^@So00000onORK/00ol0003o/I>hok6C^00Fok6C^003o`000?o0XKWo`:6i01Ko
`:6i00?o0000oljb_Oo>/[d05?o>/[d00ol0003of/S8om[8b003o`00013of<?500?o0000om_Je_l0
00001_oJe=<01?l0003of]CCom[Ddol00007omS?d@03o`000?oEbm3o000000?obMGS1_o7d>000ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo000Kooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`0hooooo`?o00001On2T=P00ol0003oO8kJogb>fP04ogb>
fP03o`000?n0P<[oP83:00SoP83:00?o0000ogb0c?mlP<`02?mlP<`00ol0003oSh2nohn0_P02ohn0
_P?o00003_n=P<000ol0003oX8Nioj27^@07oj27^@Ko00002OnORK/00ol0003o/I>hok6C^00Fok6C
^003o`000?o0XKWo`:6i01Go`:6i00?o0000oljb_Oo>/[d05?o>/[d00ol0003of/S8om[8b004om[8
b0Co00002ooH`lD01?l0003ofm[Fom_Je_oKf]H2o`0000Cof]CC00Co0000om[DdooJe=?of]CC0_l0
0005omS?d@;o00001?o9eN<00ol0003oam3PolO@h003olO@h003o`000?oooooooooo01kooooo00?o
0000ooooooooool01oooool4o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?oooooo
ooooooooool@41001Oooool3o`0003Wooooo00?o0000oh:@f?n2T=P01?n2T=P00ol0003oO8kJogb>
fP04ogb>fP03o`000?n0P<[oP83:00KoP83:0_l0000;ogb0c003o`000?n?P;ko000000;o00004_n=
P<000ol0003oX8Nioj27^@07o`0000koWhVk00?o0000ok6C^?naTkP05_naTkP00ol0003o`:6iol2Q
^@0Eol2Q^@03o`000?o>/[goc[:m01Coc[:m00?o0000om[8b?oJb<P02?oJb<P4o`0000Kof<?500?o
0000om_Je_oKf]H01?oKf]H2o`0000?of]CC00?o0000om[DdooJe=<00_oJe=<01ol0003of<oAomS?
dOoHcm7o0000ol_Ki_l000001Oo9eN<00ol0003oam3PolO@h003olO@h003o`000?oooooooooo01co
oooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0iooooo`03o`000?n2T=SoPY3H00?oPY3H00?o0000ogb>f_ml
S]X01?mlS]X00ol0003oMXkMo`000006oh20bP03o`000?mlP<coO83<00_oO83<0_l0000Cohf0`0Go
000000CoWhVko`000?l0003o00004OnORK/00ol0003o/I>hok6C^00Fok6C^003o`000?o0XKWo`:6i
01Go`:6i00?o0000oljb_Oo>/[d04oo>/[d00ol0003of/S8om[8b00=om[8b0?o00000_oH`lD00ol0
003ofm[Fom_JeP07om_JeP05o`000?oJe=?of]CCom[Ddol000001?oJe=<00ol0003of<oAo`000003
ol_KiP03o`000?o9eN?obMGS00;obMGS00?o0000olO@h?o7d>000oo7d>000ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo03Sooooo00?o0000oh:@f?n2T=P00on2T=P0
0ol0003oO8kJogb>fP04ogb>fP05o`000?mfS]goMXkMogJ>gOl000000on0P<X2o`0000coO83<0_l0
00000omiP<ko0000ohf0`00?ohf0`0?o00000_n<P/<4o`0001GoWhVk00?o0000ok6C^?naTkP05Ona
TkP00ol0003o`:6iol2Q^@09ol2Q^@go000000?oc[:mo`000?l000000_l0000@oljb_@03o`000?oJ
b<Sof/S8013of/S80_l0000;om_JeP;o00000_oJe=<00ol0003of]CCom[Dd`02om[Dd`03o`000?o;
fnKobm_V00;obm_V00?o0000olWEhoo9eN<00oo9eN<00ol0003oam3PolO@h003olO@h003o`000?oo
oooooooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`006oooool0
1Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool0>?ooool00ol0003oPY3Hoh:@
f003oh:@f003o`000?mlS][oO8kJ00CoO8kJ00?o0000ogJ>gOmfS]d00_mfS]d00ol0003oP83:o`00
000<ogb0c0;o00001?miP<h00ol0003oSH30ohf0`00:ohf0`0?o00000on<P/<4o`0001OoWhVk00?o
0000ok6C^?naTkP03onaTkP7o`000003ol2Q^Ol0003o000000So00003?o1Y;/00ol0003od;K1om2f
`@03om2f`@_o00001Oo>/[d00ol0003of/S8om[8b00@om[8b003o`000?oLhMWog>7I00;o00002_oK
f]H3o`0000;of]CC00?o0000ol_RjOl000001Oo;fnH00ol0003obMGSolWEh`02olWEh`03o`000?o7
d>3oam3P00?oam3P00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0003Sooooo00?o
0000oh:@f?n2T=P00on2T=P00ol0003oO8kJogb>fP04ogb>fP03o`000?mfS]goMXkM00CoMXkM00?o
0000ogb0c?mlP<`02OmlP<`2o`0000KoNH3>00?o0000ohf0`?n=P<001on=P<03o`0000?oS8;30ol0
0003ohb2``03o`000?nORK_oWhVk01GoWhVk00?o0000ok6C^?naTkP00onaTkP<o`0000Ko/IJk00?o
0000ol6T^oo1Y;/05Oo1Y;/00ol0003od;K1om2f`@0>om2f`@Go00004_oJb<P00ol0003og>7IomcQ
f@03omcQf@;o00002_oKf]H3o`0000?obn;Y00?o0000ol_Ki_o;fnH00_o;fnH00ol0003obMGSolWE
h`03olWEh`03o`000?o7d>3oam3P00;oam3P00?o0000ooooooooool07oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0gooooo`03o`000?n2T=SoPY3H00?oPY3H00?o0000ogb>f_mlS]X00oml
S]X00ol0003oMXkMogJ>g@05ogJ>g@03o`000?mlP<coO83<00SoO83<00?o0000ogV0c_miP<h01omi
P<h00ol0003oSH30ohf0`003ohf0`0?o00000on<P/<3o`0000KoS8;300?o0000oin9^onORK/04_nO
RK/9o`0001;o/IJk00?o0000ol6T^oo1Y;/05?o1Y;/00ol0003od;K1om2f`@0Com2f`@03o`000?oK
c/_oflk;00;oflk;2Ol00004om[8b003o`000?oLhMWog>7I00Kog>7I0_l00009om_JeP;o00000oo;
h^T00ol0003obm_Vol_KiP03ol_KiP03o`000?o9eN?obMGS00?obMGS00?o0000olO@h?o7d>000_o7
d>000ol0003oooooooooo`0Nooooo`;o00001oooool00ol0003oooooooooo`05ooooo`009?ooool0
0ol0003oooooooooo`0gooooo`;o00001?n2T=P00ol0003oO8kJogb>fP03ogb>fP03o`000?mfS]go
MXkM00GoMXkM00?o0000og2>h?l000001omlP<`2o`0000[oNH3>00?o0000ohf0`?n=P<000ol00003
ohb2``?o00002_n<P/<00ol0003oWhVkoin9^`0<oin9^`Go00000onORkh00ol0003o/IJkok6F^`0E
ok6F^`03o`000?o1Y;_o`JBk01Co`JBk00?o0000om2f`Oo@]/404_o@]/400ol0003oflk;om_>b`0<
om_>b`Co00002ooLhMT2o`0000Cofm[F0_l000001?o9jNco0000ol_RjOl00003ol_Rj@03o`000?o;
fnKobm_V00?obm_V00?o0000olWEhoo9eN<00_o9eN<00ol0003oam3PolO@h002olO@h003o`000?oo
oooooooo01gooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`000007ooooo`009?ooool0
0ol0003oooooooooo`0gooooo`;oSj[X00Co0000oh:@f?n2T=So00001_mlS]X00ol0003oMXkMogJ>
g@04ogJ>g@05o`000?m`S^3oL8kPog2>h?l000001?mlP<`2o`0000coNH3>0ol00004ohb2``;o0000
3On<P/<00ol0003oWhVkoin9^`06oin9^`Ko00002?nORkh00ol0003o/IJkok6F^`0Eok6F^`03o`00
0?o1Y;_o`JBk01Co`JBk00?o0000om2f`Oo@]/404Oo@]/400ol0003oflk;om_>b`0@om_>b`03o`00
0?oLj=gog>SM00;o00002OoLhMT2o`000003om_Je_l0003obNW/00?obNW/0_l00003ol_Rj@03o`00
0?o;fnKobm_V00?obm_V00?o0000olWEhoo9eN<00oo9eN<00ol0003oam3PolO@h002olO@h003o`00
0?oooooooooo01oooooo00?o0000ooooooooool03?ooool002Cooooo0_l0000hooooo`?oSj[X00?o
0000oh:@f?l000001OmlS]X00ol0003oMXkMogJ>g@05ogJ>g@03o`000?m`S^3oL8kP00;oL8kP00Co
0000ogb0c?l0003o00003?miP<h2o`000004ogB2d_l0003oS8;3ohb2``?o00003on<P/<01?l0003o
WhVkoin9^onORK/5o`0000koWh^n00?o0000ok6F^onaU[/05OnaU[/00ol0003o`JBkol6T^`0Col6T
^`03o`000?o@]/7od;K101;od;K100?o0000om_>booKc//03ooKc//00ol0003og>SMomcXg@04omcX
g@?o00001ooLhMT00ol0003obNW/olWYk004olWYk0;o00000oo;h^T00ol0003obm_Vol_KiP03ol_K
iP03o`000?o9eN?obMGS00;obMGS00?o0000olO@h?o7d>000_o7d>000ol0003oooooooooo`0Noooo
o`?o00003Oooool002Cooooo00?o0000ooooooooool0=oooool4ohnZj0;o00001?mlS]X00ol0003o
MXkMogJ>g@05ogJ>g@03o`000?m`S^3oL8kP00CoL8kP00?o0000ogV0c_miP<h02_miP<h2o`0000?o
M8;B0ol0000Aohb2``Go00005?nORkh00ol0003o/IJkok6F^`0Dok6F^`03o`000?o1Y;_o`JBk00So
`JBk3?l000000oo@]/7o0000o`00000Ao`0000;oflk;0_l0000=om_>b`03o`000?oLj=gog>SM00So
g>SM0ol000000ooLhMWo0000o`000002olG`k`03o`000?o9jNcobNW/00CobNW/0_l00003ol_Rj@03
o`000?o;fnKobm_V00;obm_V00?o0000olWEhoo9eN<00oo9eN<01Ol0003oam3PolO@h?o7d>3o0000
01gooooo0ol00002ooooo`03o`000?oooooooooo00_ooooo000Tooooo`03o`000?oooooooooo03Oo
oooo00Co0000ohnZj?n?Z^SoSj[X0_n:[>`01Ol0003oO8kJogb>f_mlS][o000000KoMXkM00?o0000
og2>h?m`S^001Om`S^000ol0003oNH3>ogV0cP08ogV0cP;o00000_mdP]83o`000003ogB2d_l0003o
S8;300koS8;30ol00002ohZ4a`03o`000?nORkkoWh^n01CoWh^n00?o0000ok6F^onaU[/03_naU[/7
o`000003ol6T^ol0003o000000Oo00002oo2Z;l00ol0003odK_5om6ka@0Aom6ka@03o`000?oMeM3o
gMG@00;ogMG@2Ol00004om_>b`03o`000?oLj=gog>SM00_og>SM00?o0000olG`koo5l>l00oo5l>l0
0ol0003obNW/olWYk003olWYk003o`000?o;h^Wo000000;obn;Y00?o0000ol_Ki_o;fnH00oo;fnH0
0ol0003obMGSolWEh`02olWEh`03o`000?o7d>3oam3P00?o00006Oooool3o`0000Gooooo00?o0000
ooooooooool02oooool002Cooooo00?o0000ooooooooool0=_ooool00ol0003oSj[XohnZj002ohnZ
j0?oRZc/00?o0000ogb>f_l000001omfS]d00ol0003oL8kPog2>h004og2>h003o`000?mXS^Co0000
00OoNH3>0_l000001?mdP];o0000o`000?l00005ogB2dP03o`000?n<P/?oS8;300SoS8;31?l00005
ohZ4a`03o`000?nORkkoWh^n01CoWh^n00?o0000ok6F^onaU[/00onaU[/;o`0000Ko/YZo00?o0000
ol:X_oo2Z;l04oo2Z;l00ol0003odK_5om6ka@0@om6ka@03o`000?oMeM3ogMG@00cogMG@1?l0000<
omcXg@04o`000?nmm_3o_OK`okgfl0GoaO3_00?o0000olWYk?o9jN`00oo9jN`2o`0000?obn;Y00?o
0000ol_Ki_o;fnH00_o;fnH01?l0003obMGSolWEhoo9eN<4o`0000;o[LG[00?o0000ooooooooool0
4oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000gooooo`03o`000?n?
Z^SoSj[X00;oSj[X1?n:[>`2o`0000KoMXkM00?o0000og2>h?m`S^001?m`S^001Ol0003oJ8kTofR>
i?mXS^Co000000CoNH3>1Ol00009ogB2dP03o`000?n<P/?oS8;300?oS8;31?l0000:ohZ4a`03o`00
0?nORkkoWh^n013oWh^n2Ol0000Aok:J_`03o`000?o2Z;oo`ZRo01?o`ZRo00?o0000om6kaOoA^lD0
4?oA^lD00ol0003ogMG@omgEd00>omgEd003o`000?oJl>7of_3Q00;of_3Q1Ol00003omcXg@03o`00
0?nmm_3o_OK`00?o_OK`00?o0000olG`koo5l>l00_o5l>l00ol0003obNW/olWYk003olWYk0;o0000
0_o;h^T01?l0003obm_Vol_Ki_o;fnH5o`0000;o[<W_1?n]aN/00ol0003oooooooooo`0@ooooo`?o
00003Oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`03o`00
0?n?Z^SoSj[X00;oSj[X00Co0000ohZ/k?n:[>coRZc/0_n3[O000ol0003oMXkMogJ>g@02ogJ>g@03
o`000?m`S^3oL8kP00CoL8kP00?o0000ofR>i?mXS^@00omXS^@00ol0003oNH3>o`000003o`0000co
M8;B00?o0000ohb2`on<P/<00ol0000>ohZ4a`03o`000?nORkkoWh^n00_oWh^n1Ol00003oin?``03
o`000?nbV[oo/YZo01Co/YZo00?o0000ol:X_oo2Z;l04_o2Z;l00ol0003odK_5om6ka@0Aom6ka@03
o`000?oMeM3ogMG@00gogMG@00?o0000om[`hOoJl>402?oJl>43o`0000Oo_OK`00?o0000olG`koo5
l>l00_o5l>l01?l0003obNW/olWYk?o9jN`9o`0000;oZLod1On/bNl4ojg5j`03o`000?oooooooooo
00gooooo0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oo
oooo00?o0000ohnZj?n?Z^P00_n?Z^P01?l0003oRZc/ohZ/k?n:[>`3oh>]l005o`000?mfS]goMXkM
ogJ>gOl000001Om`S^000ol0003oJ8kTofR>i004ofR>i0?o00003omdP]83o`00017oRXC700?o0000
oin;__nORkh01_nORkh5o`0000SoWho300?o0000ok:J_onbV[l05?nbV[l00ol0003o`ZRool:X_`0B
ol:X_`03o`000?oA^lGodK_5013odK_500?o0000omgEd?oMeM003OoMeM000ol0003of_3Qom[`h@08
om[`h@;o00000on_n>d2o`0000Go_OK`00?o0000olG`koo5l>l01Ol00002oikJo0;oYMGh00?o0000
ojGEn?nYco@01?nYco@00ol0003o[<W_ojc9k`02ojc9k`05o`000?n]aN_o[LG[ojg5jol000002ooo
ool4o`0001?ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool0
0ol0003oSj[XohnZj002ohnZj005o`000?n:[>coRZc/ohZ/k?l000000on3[O000ol0003oMXkMo`00
0006og2>h004o`000?mXS^CoJ8kTofR>i0?o000000?oJ8kTo`000?mdP]803?mdP]83o`000003ofn4
eol0003oRXC701;oRXC700?o0000oin;__nORkh01Ol0000=oin?``03o`000?nbV[oo/YZo01Co/YZo
00?o0000ol:X_oo2Z;l04_o2Z;l00ol0003odK_5om6ka@07om6ka@[o000000?ogMG@o`000?l00000
3?l00003om[`h@;o00001OoJl>400ol0003o[oS]ojohk@05ojohk@06o`000?nmm_3o_OK`okgfl?l0
003o_OK`0_l00002oi?NoPGoW][l00Go0000ojGEn?l0003oYMGho`000004ojW?m003o`000?n/bNoo
[<W_00;o[<W_00Go0000ojg5jon]aN_o[LG[o`000008ooooo`?o00005oooool00ol0003ooooooooo
o`0:ooooo`008oooool3o`0003Oooooo00?o0000ohnZj?n?Z^P00_n?Z^P01Ol0003oRZc/ohZ/k?n:
[>co000000CoPjg`0_l00005og2>h003o`000?mXS^Co000000;o00000omXS^@00ol0003oGXoXo`00
0009ogB2dP?o00001Om_Q=L00ol0003oRXC7ohZ4a`0=ohZ4a`Ko00004onOSl<00ol0003o/YZook:J
_`0Cok:J_`03o`000?o2Z;oo`ZRo00So`ZRo2ol000000ooA^lGo0000o`000006o`0000Wodl;:00?o
0000omgMe_oMgMH02ooMgMH00ol0003odoSTom?hi004om?hi0Go00002On_n>d3o`0000;oP]ok1?nC
g_h00ol0003oW][loikJo002oikJo003o`000?nUeOSoYMGh00;o00001?nYco@00ol0003o[<W_ojc9
k`02ojc9k`05o`000?n]aN_o[LG[ojg5jol000001Oooool3o`0001[ooooo00?o0000ooooooooool0
2_ooool002?ooooo00?o0000ooooooooool0=oooool00ol0003oSj[XohnZj002ohnZj005o`000?n:
[>coRZc/ohZ/k?l000001?n3[O02og^`m@04o`000?m`S^3oL8kPog2>h0?o00001OmXS^@01Ol0003o
GXoXoej?j?mNSnSo000000GoM8;B0ol00009ofn4e`03o`000?n:Q<OoRXC700KoRXC71_l00003ohR8
c@03o`000?nOSl?oWho301?oWho300?o0000ok:J_onbV[l03_nbV[l@o`0000[o`jk400?o0000om?2
b_oC`/X03ooC`/X00ol0003ogMgFomgMeP0;omgMeP03o`000?oCn>CodoST00OodoST00?o0000oiWc
honIln<00onIln<4o`0000;oJ]Wa1On2go/01Ol0003oTmknoi?No_nCg_ko000000CoW][l00Go0000
ojGEn?nUeOSoYMGho`000004ojW?m003o`000?n/bNoo[<W_00;o[<W_00Go0000ojg5jon]aN_o[LG[
o`000002ooooo`?o00007Oooool00ol0003oooooooooo`0:ooooo`0000Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03
o`000?oooooooooo03Sooooo00Go0000ohnZj?n?Z^SoSj[Xo`000004ohZ/k003o`000?n3[O3oPjg`
00;oPjg`0omk/?D3o`0000OoJ8kT00?o0000oej?j?mNSnP00omNSnP00ol0003oM8;Bo`000002o`00
00coKhCG00Co0000ohZ4aon:Q<OoRXC71Ol0000:ohR8c@03o`000?nOSl?oWho301;oWho300?o0000
ok:J_onbV[l00onbV[l;o`0000Go/Yk400?o0000ol>^a?o3[/@04Oo3[/@00ol0003odl;:om?2bP0?
om?2bP03o`000?oMgMKogMgF00_ogMgF00?o0000om?hi?oCn>@00ooCn>@4o`0000CoVO?S0_l00002
od_:f`03o`000?mZfO7oJ]Wa00;oJ]Wa00?o0000oh;Onon2go/00_n2go/01Ol0003oTmknoi?No_nC
g_ko000000CoW][l00Go0000ojGEn?nUeOSoYMGho`000004ojW?m003o`000?n/bNoo[<W_00;o[<W_
00Co0000ojg5jon]aN_o[LG[0ol0000Pooooo`03o`000?oooooooooo00[ooooo00001OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00Go0000ohnZj?n?Z^SoSj[Xo`000004
ohZ/k003o`000?n3[O3oPjg`00;oPjg`0ol000000omk/?Go0000o`000006ofR>i003o`000?mNSnSo
GXoX00CoGXoX0ol0000>ofn4e`Co00003on8R<d00ol0003oWho3oin?``0?oin?``Wo00004?nbW/@0
0ol0003o`jk4ol>^a00Aol>^a003o`000?oC`/[odl;:00oodl;:00?o0000omgMe_oMgMH00ooMgMH8
o`000004om?hi?l0003o0000o`0000?oaogS00?o0000ogWTcomii<l00_mii<l5oc>^kP03od_:fol0
003o000000;o000000?oJ]Wao`000?n2go/00_n2go/00ol0003oTmknoi?NoP02oi?NoP03o`000?nN
f_coW][l00;oW][l00Co0000ojGEn?nUeOSoYMGh0_l00003ojW?m003o`000?n/bNoo[<W_00;o[<W_
00Go0000ojg5jon]aN_o[LG[o`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`02ooooo`;o
0000>?ooool00ol0003oSj[XohnZj002ohnZj005o`000?n:[>coRZc/ohZ/k?l000000on3[O03o`00
00?oNk3e0_ma/_T2o`0000?oJ8kT00?o0000oej?j?mNSnP01?mNSnP01Ol0003oDi7]oe>AkOmCTNgo
000000[oKhCG0ol000000omXQmgo0000ohR8c@0AohR8c@03o`000?nOSl?oWho300OoWho31ol00003
oijCb003o`000?nbW/Co/Yk401?o/Yk400?o0000ol>^a?o3[/@04Oo3[/@00ol0003odl;:om?2bP05
om?2bP[o000000?ogMgFo`000?l000000ol00005omcXg@03o`000?o7oN?oaogS00CoaogS0_l00000
0omii<ooDLZaoe:Ml`02oe:Ml`;o000000Co<jk^o`000?l0003o00001Om?]OX4o`000003oh;Onol0
003oTmkn00?oTmkn00?o0000oikJo?nNf_`00_nNf_`01ol0003oYMGhojGEn?nUeOSo0000ojW?m?l0
00000_nYco@00ol0003o[<W_ojc9k`02ojc9k`05o`000?n]aN_o[LG[ojg5jol000008oooool00ol0
003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0gooooo`03o`000?n?Z^SoSj[X
00;oSj[X00Co0000ohZ/k?n:[>coRZc/1?l00002oh>]l005o`000?mk/?GoNk3eog^`mOl000000oma
/_T00ol0003oJ8kTo`000006oej?j003o`000?mCTNgoDi7]00?oDi7]00?o0000ofn4eom_Q=L01?m_
Q=L3o`0000GoJ8OM00?o0000ohR8cOn8R<d03on8R<d01?l0003oWho3oin?`onOSl<6o`0000[oWY?8
00?o0000ok:Na?nbW/@04onbW/@00ol0003o`jk4ol>^a00;ol>^a0Ko000000?odl;:o`000?l00000
1Ol00009omC;d@03o`000?oLj=gog>SM00Sog>SM00Co0000olOmhoo7oN?oaogS0ol000000on`nmco
DLZaoe:Ml`05oe:Ml`Co00001Om?]OX2o`0000CoHkOl2?l00003oikJo005o`000?nUeOSoYMGhojGE
n?l000000_nYco@00ol0003oZLodo`000004ojc9k`05o`000?n]aN_o[LG[ojg5jol000008oooool0
0ol0003oooooooooo`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo00?o
0000ohnZj?n?Z^P00_n?Z^P00ol0003oRZc/o`000002o`0000CoPjg`00?o0000og^`mOmk/?D00_mk
/?D00ol0003oLK;iog6bn@02og6bn@;o00001OmNSnP00ol0003oDi7]oe>Ak@05oe>Ak@03o`000?m_
Q=OoKhCG00?o00002?mXQmd00ol0003oR8S=ohR8c@0=ohR8c@Ko00004OnNTlP00ol0003o/Yk4ok:N
a00Bok:Na003o`000?o3[/Co`jk400;o`jk42Ol00005olBeb`03o`000?oDbm7oe<_A00koe<_A00?o
0000omcXgOoLj=d01OoLj=d4o`000003olOmhol0003o/?_L00;o/?_L00?oDLZaogNAgol000000_mB
WO<5o`0000CoHY[_0ol000000om?]O[o0000of>go005of>go003o`000?mb]O[oL[Gj00?oL[Gj0_mm
/_H2o`000003oikJo?l0003oYMGh00;oYMGh00Ko0000ojW?m?nYcoCo0000ojW?m?l00004ojc9k`05
o`000?n]aN_o[LG[ojg5jol000008oooool00ol0003oooooooooo`09ooooo`0000Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0gooooo`;o00000_n?Z^P3o`0000;oRZc/00?o0000oh>]l?n3[O000_n3[O000ol0
003oNk3eog^`m@02og^`m@03o`000?ma/_WoLK;i00;oLK;i0_mS/o/01Ol0003oGXoXoej?j?mNSnSo
000000SoDi7]0ol0000<ofR7g@03o`000?n8R<goR8S=00KoR8S=1_l00003ohF=d`03o`000?nNTlSo
WY?8017oWY?800?o0000ok:Na?nbW/@03onbW/@4o`000004ol>^a?l0003o0000o`0000koa;G;00?o
0000omC;dOoDbm403OoDbm401?l0003og>SMomcXgOoLj=d5o`0000;oeo;S00Go0000ok3kg?n`nmco
/?_Lo`000003ogNAg`Co00002omRV^l3o`0000GoHkOl00?o0000og:en_mb]OX00omb]OX00ol0003o
OK;fogfbmP03ogfbmP?o000000?oYMGho`000?nYco@00_nYco@2o`0000Co[<W_00Go0000ojg5jon]
aN_o[LG[o`00000Sooooo`03o`000?oooooooooo00Wooooo00001OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo0_l0000h
ooooo`03ojk4j_l0003o000000?o00000on:[>`00ol0003oPjg`oh>]l002oh>]l005o`000?mk/?Go
Nk3eog^`mOl000001Oma/_T01_l0003oHk?kof>cnol0003oGXoXo`0000OoDi7]0_l00002od>Bl003
o`000?mXQmgoJ8OM00[oJ8OM00Co0000ohR8cOn8R<goR8S=1Ol0000:ohF=d`03o`000?nNTlSoWY?8
013oWY?800?o0000ok:Na?nbW/@02?nbW/@7o`0000?o/ZG;00?o0000olBeboo4]L/04?o4]L/00ol0
003oe<_AomC;d@09omC;d@Co000000?og>SMo`000?oGl^<01ooGl^<00ol0003o/?_Lok3kg002ogNA
g`Co00000ommSMP00ol0003oHY[_of:Jk`06of:Jk`?o00000om]UnT01Ol0003oHkOlof>go?mS]oco
000000GoL[Gj00?o0000ogfbm_mm/_H01?mm/_H3ohF_l0Go000000?oZLodo`000?n/bNl00on/bNl0
1Ol0003o[LG[ojg5jon]aN_o000002?ooooo00?o0000ooooooooool02Oooool00005onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00004ooooo`03o`00
0?oooooooooo03Kooooo0ol00004ojk4jP?o000000?oRZc/o`000?n3[O000on3[O001Ol0003oNk3e
og^`mOmk/?Go000000GoLK;i00Co0000of>cnomS/o_oHk?k0_l00006oe>Ak@03o`000?m3T_3o@i;`
00?o@i;`00?o0000ofR7gOmXQmd01omXQmd6o`0000ooQHgC00?o0000oijCb?nNTlP04OnNTlP00ol0
003o/Yk4ok:Na007o`0000[o/ZG;00?o0000olBeboo4]L/03oo4]L/00ol0003oe<_AomC;d@05omC;
d@Go00000ooDe]X00ol0003oeo;SomObh`05omObh`?o000000?oRnc8o`000?l000000_l00008ogf=
f003o`000?mRV^ooHY[_00?oHY[_0_l00007offGj@03o`000?mS]oco000000GoL[Gj00?o0000ogfb
m_mm/_H01?mm/_H00ol0003oQJo`ohF_l002ohF_l0CoRjc/1Ol000000on/bNoo0000ojg5j`02ojg5
j`03o`000?oooooooooo027ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool0<oooool3o`0000?ooooo00Co0000ojk4j_n^a>[o[/CZ0on]b>h5o`000003oh>]l?l0003oNk3e
00;oNk3e00?o0000og6bnOma/_T00_ma/_T00ol0003oHk?kof>cn`02of>cn`;oD;;j0ol000000omC
TNgo0000o`000007od>Bl004o`000?mXQmgoJ8OMofR7g@Go00000omORnD00ol0003oQHgCohF=d`0?
ohF=d`03o`000?nNTlSoWY?800coWY?82?l0000Aok:Ub`03o`000?o4]L_oa;G;00ooa;G;00Co0000
omC;dOoDbm7oe<_A1?l00007omCFfP03o`000?oGl^?oeo;S00;oeo;S1?l000001?o9nnKoRnc8o`00
0?l0000=ogf=f003o`000?mRV^oo000000;o00002Om]UnT3o`0000CoL[Gj00?o0000ogfbm_mm/_H0
1?mm/_H00ol0003oQJo`ohF_l002ohF_l003o`000?n;[>coRjc/00?oRjc/00CoT:_Xo`000?n@ZnSo
T:_X1?l000000on]aN_o0000ooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`00
0?oooooooooo033ooooo0ol00006ooooo`03o`000?n^a>[o[/CZ00;o[/CZ0on]b>h4oj[>lPCo0000
00?oNk3eo`000?ma/_T00oma/_T00ol0003oHk?kof>cn`02of>cn`03o`000?m@/_[oD;;j00;oD;;j
0_l00008od>Bl0Co00002OmORnD00ol0003oQHgCohF=d`0?ohF=d`03o`000?nNTlSoWY?800;oWY?8
2Ol00005oifJd003o`000?nbYL_o/ZG;013o/ZG;00?o0000olBeboo4]L/02oo4]L/8o`0000coe=KJ
00?o0000omObhooGl^<00_l00002olWkiP05o`000?nBRlWoTX_9oi:;bOl000003OmmSMP3o`0000[o
KIOY0_l00003ogFDh`;o000000?oL[Gjo`000?mm/_H01Omm/_H00ol0003oQJo`ohF_l002ohF_l003
o`000?n;[>coRjc/00?oRjc/00Co0000oi2[j?n@ZnSo00000_n@ZnP3oiBYi0;o00009?ooool00ol0
003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`05o`000?n^a>[o[/CZojk4
j_l000000on]b>h4oj[>lP?oY]?g1Ol000000oma/_Wo0000of>cn`02of>cn`03o`000?m@/_[oD;;j
00?oD;;j0_lh[O800ol0003o@i;`od>Bl002od>Bl0?o00000_l^TNl00ol0003oGh_Uoen;i@09oen;
i@03o`000?n5SM?oQHgC00[oQHgC2Ol0000>oifJd003o`000?nbYL_o/ZG;013o/ZG;00?o0000olBe
boo4]L/00_o4]L/9o`0000GoaKoD00?o0000omCFf_oDe]X02?oDe]X5o`0000CobO_V0_l00005oi:;
b@03o`000?mmSMSoOHgH00GoOHgH1Ol00003oh69dP03o`000?m]UnWoKIOY00GoKIOY0_l00006ogFD
h`?o00001Omm/_H00ol0003oQJo`ohF_l003ohF_l003o`000?n;[>coRjc/00?oRjc/00Co0000oi2[
j?n@ZnSoT:_X0_l00004oiBYi003o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool0
027ooooo00?o0000ooooooooool0:_ooool3o`0000gooooo00?o0000ojk4j_n^a>X00_n^a>X01?l0
003o[LS^ojg8k_l00004oj[>lP?oY]?g00Co0000oj3InonPfO_oX=Wk1?l000000omS/o_o0000oe2b
nP04oe2bnP05o`000?lh[O;o>:gbo`000?m3T_000_l00006objAk`03o`000?mORnGoGh_U00WoGh_U
00?o0000ohF=don5SM<00_n5SM<7o`0000CoP9?L00?o0000oifJd?nMV]004OnMV]000ol0003o/ZG;
ok:Ub`0;ok:Ub`Wo00003Oo5_m@00ol0003oe=KJomCFfP04omCFfPGo00000_oAi>D01?l0003obO_V
olWki_o9nnH4o`0000OoTX_900?o0000ogf=f?mmSMP01?l00009oh69dP03o`000?m]UnWoKIOY00;o
KIOY0_l00007ogFDh`05o`000?mkT]koNi;Nog^Bg_l000000omm/_H00ol0003oQJo`ohF_l003ohF_
l003o`000?n;[>coRjc/00?oRjc/00?o0000oi2[j?n@ZnP00on@ZnP01Ol0003oU:WToiBYi?nDZNCo
000002Gooooo00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool09oooool3o`00
013ooooo00?o0000ojk4j_n^a>X00_n^a>X01Ol0003o[LS^ojg8k_n]b>ko000000?oZ/kb00Go0000
ojKCmonVdoOoY]?go`000003oj3In`03o`000?nFg_koU]kn00Go000000?oD;;jo`000?lh[O800olh
[O82o`0000So;Y7_00?o0000oen;iOmORnD01?mORnD9o`0000coP9?L00?o0000oifJd?nMV]004?nM
V]000ol0003o/ZG;ok:Ub`02ok:Ub`Wo00001?nb[]@00ol0003oaKoDolFoe00?olFoe003o`000?oD
e][oe=KJ00Co00001_oAi>D01?l0003obO_VolWki_n]n]l2o`000003ojgjgonBRlWoTX_900GoTX_9
1Ol0000>oh69dP04o`000?m]UnWo0000o`0000OoMICS0_l00005og^BgP03o`000?mm/_Ko000000Ko
QJo`00?o0000oh^/k?n;[>`00_n;[>`00ol0003oT:_Xoi2[j003oi2[j0;o00000onDZN@00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oooooooooo02Gooooo
0ol0000Dooooo`05o`000?n^a>[o[/CZojk4j_l000000on]b>h00ol0003oZ/kboj[>lP02oj[>lP04
o`000?nVdoOoY]?go`0000CoX=Wk00Go0000oiKNo_nFg_koU]kno`000002ohKOo0Go000000?o>:gb
o`000?lJXN000ol00003objAk`Wo00001OmBT>`00ol0003oP9?Loh2Cg00>oh2Cg003o`000?nMV]3o
WI[@00_oWI[@2Ol0000=ok:^e003o`000?o5_mCoaKoD00_oaKoD1_l00008om7Ti@?o00000_n]n]l0
0omli<Go0000oi:;b@04oi:;b@Go00000onDR<@00ol0003oPHWBoh69dP0<oh69dP?o00001omeU><2
o`0000OoNi;N0ol00005ohF_l003o`000?n;[>coRjc/00?oRjc/00?o0000oi2[j?n@ZnP00_n@ZnP0
1_l0003oU:WToiBYi?l0003oU:WTo`0002Kooooo00?o0000ooooooooool02?ooool0023ooooo0_l0
000Sooooo`?o00005oooool00ol0003o[/CZojk4jP02ojk4jP05o`000?n]b>ko[LS^ojg8k_l00000
0onZc_801Ol0003oY]?gojKCmonVdoOo000000CoX=Wk00Go0000oiKNo_nFg_koU]kno`000004ohKO
o003o`000?m_fo?o000000?o00000_lJXN03o`0000Go4h_V00?o0000oe:@k?mBT>`01omBT>`00ol0
003oP9?Loh2Cg00=oh2Cg003o`000?nMV]3oWI[@00;oWI[@2Ol00004oi^RfP03o`000?nb[]Co/ZkD
00oo/ZkD00?o0000olFoe?o5_m@01Oo5_m@6o`0000?oa<cO00?o0000om7TiOoAi>D01OoAi>D3o`00
0005olOak_n]n]oo0000ogcTaOl000000_nBRlT5o`0000WoU8S400?o0000oh69d_n1RM802?n1RM83
o`0000;oQHO>00?o0000ogFDhomeU><01?meU><00ol0003oNi;Nog^BgP06og^BgP04o`000?n0TM[o
P97Joh2AfP;o00000_n5[o000ol0003oRjc/oh^/k003oh^/k003o`000?n@ZnSoT:_X00?oT:_X00Co
0000oiBYi?nDZNCoU:WT0_l0000Vooooo`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oo
oooooooo023ooooo0_l0000Jooooo`03o`000?n^a>[o[/CZ00;o[/CZ00Go0000ojg8k_n]b>ko[LS^
o`000004oj[>lP05o`000?nVdoOoY]?gojKCmol000001?nPfO/01Ol0003oU]knoiKNo_nFg_ko0000
00CoQ]ol00Co0000ofoKlom_fo?oKm_c2?l00004oa>;iP03o`000?mBT>coDY3/00OoDY3/00?o0000
oh2Cg?n0Tm`01_n0Tm`;o`0000goVj;J00?o0000ok:^e?nb[]@03onb[]@01?l0003oaKoDolFoe?o5
_m@4o`0000Woa<cO00?o0000om7TiOoAi>D00_oAi>D3o`000004olOak_l0003o0000ogcTa@Ko0000
3onDR<@00ol0003oPHWBoh69dP03oh69dPCo00001_n5Qlh01?l0003oMICSogFDhomeU><2o`0000So
Ni;N00?o0000oh2Af_n0TMX01?n0TMX00ol0003oQJo`o`000005oh^/k003o`000?n@ZnSoT:_X00;o
T:_X00?o0000oiBYi?nDZN@00onDZN@00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oo
oooo000Pooooo`03o`000?oooooooooo01gooooo0ol0000Mooooo`03o`000?n^a>[o[/CZ00;o[/CZ
00Go0000ojg8k_n]b>ko[LS^o`000003oj[>lP05o`000?nVdoOoY]?gojKCmol000001?nPfO/00ol0
003oU]knoiKNoP02oiKNoP03o`000?n6gocoQ]ol00Go00001onkm?4Ho`0000OoNI_W00?o0000oi^R
f_nKX]X03onKX]X00ol0003o/ZkDok:^e00:ok:^e0Oo00003Oo4c=l01Ol0003odNCUom7TiOoAi>Go
000000;oao7^0_l000001?n]mngoO>C5o`000?l00003ojB=_@03o`000?nDR<CoU8S400ooU8S400?o
0000oh69d_n1RM800ol0000;ohF7cP03o`000?meU>?o000000SoNi;N0_l00007oh2AfP?o00001?n;
[>`00ol0003oT:_Xoi2[j003oi2[j003o`000?nDZNCoU:WT00;oU:WT0_l0000Wooooo`03o`000?oo
oooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo0ol0000Pooooo`03o`000?n^a>[o
[/CZ00;o[/CZ00Go0000ojg8k_n]b>ko[LS^o`000004oj[>lP05o`000?nVdoOoY]?gojKCmol00000
1?nPfO/00ol0003oU]knoiKNoP04o`0000Goa>k`1Ol00002ok_dl@;o00000_oHhmh6o`0000So?Y?a
00?o0000ogVKiomiVnL02omiVnL00ol0003oVj;Joi^RfP0>oi^RfP04o`000?nb[]Co/ZkDok:^e0Wo
00001?na^^000ol0003oa<cOolC<g`09olC<g`Ko00000oo7lNh00ol0003o[OO]o`000002o`0000Oo
Y8fm00?o0000oiB8a?nDR<@03OnDR<@4o`0000koQHO>0_l00008og^BgP03o`000?n0TM[oP97J00Ko
P97J00Go0000ohFAf?n5TMSoQI7Ho`000002oh^/k003o`000?n@ZnSoT:_X00?oT:_X00?o0000oiBY
i?nDZN@00onDZN@00ol0003oooooo`00000Vooooo`03o`000?oooooooooo00Oooooo000Pooooo`?o
00005oooool3o`0002?ooooo00?o0000ojk4j_n^a>X00on^a>X01Ol0003o[LS^ojg8k_n]b>ko0000
00?oZ/kb00Go0000ojKCmonVdoOoY]?go`000003oj3In`Co00001?o8in`2o`0000Soa>k`0_l00007
omSSgPCo00002?lnTo400ol0003oNI_WogVKi`0:ogVKi`03o`000?nKX][oVj;J00KoVj;J3?l0000=
ok6jh004o`000?o4c=ooa<cOolC<g`So00000oo0fnd01?l0003oao7^olOak_l00002ojggk@?o0000
2OnTSKd00ol0003oU8S4oiB8a009oiB8a0Co00000_nEQ/400ol0003oQHO>ohF7cP0:ohF7cP?o0000
0_n8Q//00ol0003oNi;Nog^BgP03og^BgP;o00002?n0TMX00ol0003oQI7HohFAf003ohFAf003o`00
0?n;[>co000000GoT:_X00?o0000oiBYi?nDZN@00_nDZN@01Ol0003ooooooooooooooooo000002Go
oooo00?o0000ooooooooool01oooool001oooooo0_l0000Fooooo`?o00009oooool00ol0003o[/CZ
ojk4jP02ojk4jP05o`000?n]b>ko[LS^ojg8k_l000000_nZc_89o`0000Cob^3X00?o0000olSWk?o8
in`00oo8in`3o`0000Coa>k`00?o0000omSKfOoHfmT00ooHfmTVo`0000SoUZkW00?o0000ok6jh?na
^^002_na^^08o`0000So`=_]1?l00003ojggk@;o00003?nTSKd00ol0003oU8S4oiB8a004oiB8a0Go
00001onEQ/400ol0003oQHO>ohF7cP06ohF7cP?o00001_n8Q//01Ol0003oNi;Nog^Bg_mkT]ko0000
00WoP97J00?o0000ohFAf?n5TMP01?n5TMP3o`0000CoT:_X00?o0000oiBYi?nDZN@00onDZN@00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool04_ooool3o`0002[ooooo00?o0000ojk4j_n^a>X00_n^a>X0
0ol0003o[LS^ojg8kP04o`0000CobM?Q1?o;fN@00ol0003ob^3Xol[Pj004ol[Pj0;o00001Oo8in`2
o`000003olC^l?l0003of=_I00cof=_I1Ol00007ob6Ak003o`000?m[Y?;oJjCb00WoJjCb00?o0000
oiJ^ionF[^L03OnF[^L00ol0003o/K[Pok6jh002ok6jh0Oo00001?n/b>h00ol0003o`=_]ol3Kk@05
ol3Kk@Co00000_naj_P01?l0003o[OO]o`000?l0000@ojB=_@03o`000?nDR<Co000000?o00003OnE
Q/400ol0003oQHO>ohF7cP02ohF7cP?o00002_n8Q//00ol0003oNi;No`000009oh2AfP03o`000?n5
TMSoQI7H00CoQI7H00Go0000ohVAeOn9TMGoRI7Eo`000002oi2[j003o`000?nDZNCoU:WT00?oU:WT
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo
0004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0?ooooo`?o0000;Oooool01?l0003o[/CZojk4j_n^a>X4o`0000?o
b<gN00?o0000olWChOo9dn400oo9dn401?l0003obmWTol_Ii?o;fN@2o`0000Kob^3X0_l00005olSW
k003o`000?oHfmWof=_I00kof=_I00?o0000omG3b?oE`lP01_l00002ob6Ak003o`000?m[Y?;oJjCb
00WoJjCb00?o0000oiJ^ionF[^L01OnF[^L8o`000003ok6jh?l0003o000000co[<S^00?o0000ol3K
kOo0fnd00_o0fnd2o`0000Co/N[h0ol000000omghm;o0000ojB=_@0>ojB=_@Go00004OnEQ/400ol0
003oQHO>o`000002o`0000goR8K;0_l00008oh2AfP;o00001_n5TMP00ol0003oRI7EohVAe@03ohVA
e@03o`000?n@ZnSo000000GoU:WT00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Oooooo0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0ol0000aooooo`?o00000_o6b=`00ol0
003ob<gNolS=gP03olS=gP03o`000?o9dn7obM?Q00?obM?Q00?o0000ol_Ii?o;fN@00_o;fN@2o`00
00Kob^3X0_l000000oo8inco0000omSDe@03omSDe@Go00002?oHfmT00ol0003oeL?8omG3b004omG3
b0;o000000?o08GEo`000?l000000_l000000om[Y?;o0000o`000009o`000003oiJ^iol0003o0000
00?o00001on<^oD00ol0003o[<S^ojc8kP0:ojc8kPCo000000?o`=_]ok7Zn?naj_P00onaj_P7o`00
00;o/YFj00?o0000ojB=_OnTSKd01_nTSKd6o`0000?oY8^j00?o0000oiF6`OnEQ/403onEQ/43o`00
00koR8K;0_l000000on:QLSo0000oh2AfP06oh2AfP03o`000?n5TMSoQI7H00GoQI7H00?o0000ohVA
eOn9TMD01On9TMD2o`0000GoU:WT00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003oooool00omg
MgOo<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00?o0000olK8g?o6b=`00oo6b=`00ol0
003ob<gNolS=gP03olS=gP03o`000?o9dn7obM?Q00?obM?Q00?o0000ol_Ii?o;fN@00oo;fN@00ol0
003ob^3Xol[Pj005ol[Pj003o`000?oHe=Gof=CE00Sof=CE1Ol00002omSKf@03o`000?oE`lSoeL?8
00WoeL?81Ol00009oeB[n@03o`000?n<^oGoS;_e00coS;_e00?o0000ojc8k_n/b>h00_n/b>h7o`00
00?oWMSl00Co0000ok7Zn?naj_So/N[h0_l00002ohWZl003o`000?m3a<7o000000Go/YFj00?o0000
ojB=_OnTSKd01_l0000:ojB;^P03o`000?nEQ/7oUHK100_oUHK10ol00002oiN5_P03o`000?n8Q/_o
R8K;00[oR8K;0_l00004ohZ5b003o`000?n0TM[oP97J00?oP97J00?o0000ohFAf?n5TMP01On5TMP0
0ol0003oRI7EohVAe@05ohVAe@03o`000?n<T]CoS9;D00;o00000_nDZN@00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`06ooooo`?o0000>?ooool00ol0003oa/SLolK8g003olK8g003o`000?o8cMkob<gN00?ob<gN00?o
0000olWChOo9dn400oo9dn400ol0003obmWTol_Ii003ol_Ii0;o00000oo:h>P01?l0003oe/kAomK>
dOoFc]43o`0000_of=CE0_l000000ooE`lSo0000o`000005o`0000SoeL?80_l000000omDZoWo0000
o`000003o`0000?oE:_i00?o0000ohbkmOn<^oD01On<^oD;o`0000OoWMSl1Ol00003ohWZl0;o@lC1
3?l0000@ojB;^P03o`000?nEQ/7oUHK100OoUHK11?l00006oiN5_P03o`000?n8Q/_oR8K;00KoR8K;
0ol00007ohZ5b005o`000?n0TM[oP97Joh2Af_l000001on5TMP00ol0003oRI7EohVAe@05ohVAe@03
o`000?n<T]CoS9;D00?oS9;D00?o0000oiBYi?l000002Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000looooo`03o`000?o6b=coa/SL00?o
a/SL00?o0000olS=g_o8cMh00oo8cMh00ol0003obM?QolWCh@03olWCh@03o`000?o;fNCobmWT00Co
bmWT00?o0000ol[Pj?l000001ooFc]43o`0000Wof=CE00?o0000om>naOoC_/D01_oC_/D8o`000003
ol^__ol0003o000000?o00000_l[Y^d5o`000003ohbkmOl0003o000000?o00001omda_l00ol0003o
WMSloigHo003oigHo0Go000000GoN=_io`000?l0003o0000ohWZl002od?4`@?o00002OnaTkL00ol0
003oY8^jojB;^P0@ojB;^P03o`000?nEQ/7oUHK100?oUHK11?l0000:oiN5_P03o`000?n8Q/_oR8K;
00CoR8K;0_l0000;ohZ5b003o`000?n0TM[o000000OoQI7H00?o0000ohVAeOn9TMD01On9TMD00ol0
003oS9;DohbBe005ohbBe003o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo00?o0000olK8g?o6b=`00oo6b=`0
0ol0003ob<gNolS=gP03olS=gP03o`000?o9dn7obM?Q00?obM?Q00?o0000ol_Ii?o;fN@00oo;fN@2
o`0000_oe/kA0ol00005omSDe@03o`000?oC_/Godkk500kodkk500?o0000olV/_?o9[;`00oo9[;`0
0ol0003o08_1o`2;`@08o`0000;oM<Ko2_l000000onMf?co0000ogSKn@03ogSKn@So00003_naTkL0
0ol0003oY8^jojB;^P0AojB;^P03o`000?nEQ/7o000000;o00003onGQKh01?l0003oR8K;ohR6bon8
Q//2o`0000goRXG80_l00007ohFAf003o`000?n9TMGoRI7E00GoRI7E00?o0000ohbBe?n<T]@01On<
T]@00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_oo
ool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool4o`0004Cooooo00?o
0000olK8g?o6b=`00oo6b=`00ol0003ob<gNolS=gP03olS=gP03o`000?o9dn7obM?Q00?obM?Q00Go
0000ol_Ii?o;fNCobmWTo`000003omC9c`?o00002_oFc]43o`000003omSDeOl0003odkk500oodkk5
00?o0000olV/_?o9[;`03Oo9[;`4o`0000CoAKk_1ol000000omhfoWo0000oc>kc003o`0000;o_Yjh
00?o0000ok6C]onaTkL04?naTkL00ol0003oY8^jojB;^P0>ojB;^PGo00004_nGQKh01?l0003oR8K;
o`000?l0000=ohZ5b0;o00000_n=QLH00ol0003oQI7HohFAf003ohFAf003o`000?n9TMGoRI7E00Go
RI7E00?o0000ohbBe?n<T]@01On<T]@00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01_ooool001kooooo0_l00017ooooo`03o`000?o6b=coa/SL00?oa/SL
00?o0000olS=g_o8cMh00oo8cMh00ol0003obM?QolWCh@03olWCh@03o`000?o;fNCo000000Ooe<W?
0_l0000;omK>d@03o`000?oC_/Godkk500;o00003OoC_/D00ol0003obJblolV/_00@olV/_003o`00
0?nnW[So_Yjh017o_Yjh00?o0000ok6C]onaTkL04OnaTkL00ol0003oY8^jojB;^P06ojB;^POo0000
0onTR[P00ol0003oUhFnoiN5_P0@oiN5_P?o00003On:QLP2o`0000GoSHG600Go0000ohFAf?n5TMSo
QI7Ho`000007ohVAe@03o`000?n<T]CoS9;D00GoS9;D00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Pooooo`03o`000?oooooooooo04Gooooo
00?o0000olK8g?o6b=`00_o6b=`00ol0003ob<gNolS=gP04olS=gP03o`000?o9dn7obM?Q00;obM?Q
0_l0000:omC9c`?o00002?oFc]400ol0003od[[3om:j``02om:j``Wo00001?oC_/D00ol0003obJbl
olV/_00@olV/_003o`000?nnW[So_Yjh013o_Yjh00?o0000ok6C]onaTkL04_naTkL00ol0003oY8^j
ojB;^P06o`0000_oY8Zh00?o0000oiN5__nGQKh02onGQKh4o`0000;oV8Bm00?o0000ohZ5b?n:QLP0
2On:QLP2o`0000SoSHG600?o0000ohFAf?l000001on9TMD00ol0003oS9;DohbBe005ohbBe003o`00
0?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`008Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?o6b=coa/SL00;oa/SL00?o0000olS=g_o8cMh01?o8
cMh01?l0003obM?Qo`000?l00003om;5c@;o00002_oDbLl2o`0000Goe/kA00?o0000om:j`ooB^/<0
3?oB^/<4o`0000;obJbl0ol0000=olV/_003o`000?nnW[So_Yjh017o_Yjh00?o0000ok6C]onaTkL0
3OnaTkL8o`00017oY8Zh00?o0000oiN5__nGQKh01onGQKh4o`0000OoV8Bm00?o0000ohZ5b?n:QLP0
1_n:QLP2o`0000[oSHG60_l00007ohVAe@03o`000?n<T]CoS9;D00GoS9;D00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000Rooooo`03o`000?oo
oooooooo04Cooooo00?o0000olK8g?o6b=`00oo6b=`00ol0003ob<gNolS=gP03olS=gP;o00001ooB
aLd3o`0000Woe<W?0ol000000ooFc]7o0000om:j``0Aom:j``03o`000?o8ZK[ob:Vj00?ob:Vj2Ol0
0004olV/_003o`000?nnW[So_Yjh017o_Yjh00?o0000ok6C]onaTkL00_naTkL;o`0000Go/I6f00?o
0000ojB:^?nTR[P04OnTR[P00ol0003oUhFnoiN5_P04oiN5_P?o00002onHQ;d00ol0003oRXG8ohZ5
b004ohZ5b0;o00002_n=QLH2o`000003ohn6a_l0003oRI7E00GoRI7E00?o0000ohbBe?n<T]@01On<
T]@00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool002?ooooo0_l00015ooooo`03o`000?o6b=coa/SL00?oa/SL00Go0000olS=g_o8cMkob<gNo`00
0003om31c003o`000?oBaLgod/G=00Kod/G=0_l0000:omC9c`03o`000?oB^/?od[[3013od[[300?o
0000olRY^_o8ZKX03Oo8ZKX5o`000003okjN^?l0003o000001Go00004?naTKH00ol0003oY8ZhojB:
^00BojB:^003o`000?nGQKko000000?o00003onHQ;d01?l0003oRXG8ohZ5b?n:QLP2o`0000[oSHG6
0_l00004ohn6aP03o`000?n9TMGoRI7E00;oRI7E00?o0000ohbBe?n<T]@01On<T]@00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Oooool002Gooooo00?o
0000ooooooooool0@oooool00ol0003oa/SLolK8g003olK8g003o`000?o8cMko000000Kod<7<0_l0
0007om;5c@;o00002?oDbLl00ol0003od;O1om2g`@05o`0000_od[[300?o0000olRY^_o8ZKX04Oo8
ZKX00ol0003o_IbfokfL]P0AokfL]P03o`000?naTKKo/I6f01;o/I6f00?o0000ojB:^?nTR[P04?nT
R[P4o`0001?oV8Bm00Co0000ohZ5b?l0003o00002_n=QLH2o`0000OoShK600Co0000ohVAeOn9TMGo
00001on<T]@00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool002Kooooo00?o0000ooooooooool0@oooool00ol0003oa/SLolK8g003olK8g003o`00
0?o@`Lcod<7<00Ood<7<0_l00007om;5c@?o00001?oDbLl00ol0003od;O1om2g`@06om2g`@Co0000
1ooB^/<00ol0003ob:VjolRY^P0AolRY^P03o`000?nmW;Ko_Ibf017o_Ibf00?o0000ok6A]_naTKH0
4onaTKH00ol0003oY8ZhojB:^00:ojB:^0Go00000_nURKL00ol0003oV8BmoiR4_@0AoiR4_@?o0000
2_n=QLH2o`0000WoShK600?o0000ohVAeOl000001on<T]@00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0@ooo
ool01Ol0003oa/SLolK8g?o6b=co000000;oc[k;00?o0000om31c?o@`L`01oo@`L`2o`0000Sod/G=
0_l000000ooDbLoo0000om2g`@0<om2g`@Go000000?od[[3o`000?o8ZKX04oo8ZKX00ol0003o_Ibf
okfL]P0AokfL]P03o`000?naTKKo/I6f01?o/I6f00?o0000ojB:^?nTR[P01OnTR[P5o`0000OoYHVg
00?o0000oiR4_OnHQ;d03_nHQ;d3o`0000;oVHBl00?o0000ohf5a_n=QLH01on=QLH00ol0003oShK6
ohn6aP09ohn6aP;o00001on<T]@00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01Oooool002Sooooo0_l00014ooooo`03o`000?o6b=co000000Coc[k;0_l0
0009om31c003o`000?oBaLgod/G=00Ood/G=00?o0000om2g`Oo@]l404Oo@]l42o`0000;ob:Vj0ol0
000>olRY^P03o`000?nmW;Ko_Ibf01;o_Ibf00?o0000ok6A]_naTKH04onaTKH00ol0003oY8ZhojB:
^005o`0000goYHVg00?o0000oiR4_OnHQ;d02_nHQ;d3o`0000KoVHBl00?o0000ohf5a_n=QLH01?n=
QLH2o`0000[oShK60_l00002oi67a@03o`000?n<T]CoS9;D00?oS9;D00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooo
oooo04;ooooo00?o0000oljnboo>_//01Oo>_//00ol0003od<7<om31c007om31c0;o00001ooBaLd0
0ol0003oc[C0oljd`004o`0000kod;O100?o0000olNW^Oo7YkT00oo7YkT:o`0000Cob:Vj00?o0000
okfL]_nmW;H04_nmW;H00ol0003o/I6fok6A]P08ok6A]Pko00004_nURKL00ol0003oV8BmoiR4_@06
oiR4_@Co00002_nIQ;`01?l0003oSHG6ohf5a_n=QLH2o`0000_oShK600?o0000oi67aOnAQlD00onA
QlD01Ol0003oS9;DohbBe?n<T]Co0000023ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`04ooooo`00:oooool00ol0003oooooooooo`13ooooo`Ooc[k;0_l00009om31c0;o00001?oB
aLd00ol0003oc[C0oljd`005oljd`0Co00002Oo@]l400ol0003oajNiolNW^@0>olNW^@Go000000?o
_Ibfo`000?l000007?l0000;ok6@]@03o`000?nURKOoYHVg01;oYHVg00?o0000oiR4_OnHQ;d00onH
Q;d3o`0000koVHBl00Co0000ohf5a_l0003o00002on?Q/H2o`0000OoTHO500?o0000ohbBe?l00000
8_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000/ooooo`03o`000?oo
oooooooo04?ooooo0_l00006oljnb`;o00002Oo@`L`2o`000003om;5cOl0003oc[C000_oc[C00ol0
0006om2g`@03o`000?o7YkWoajNi01;oajNi00?o0000okbJ]OnlV[D04_nlV[D00ol0003o/I2eok6@
]@0Cok6@]@03o`000?nURKOoYHVg01?oYHVg00?o0000oiR4_Ol000000_l0000AoiV4_0;o00002on?
Q/H2o`0000WoTHO50_l0000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?oo
ool002gooooo0_l00015ooooo`03o`000?o>_/_oc[k;00Goc[k;00?o0000om31c?o@`L`02?o@`L`0
0ol0003oc[C0oljd`00>oljd`0Co00000_o@]l400ol0003oajNiolNW^@0BolNW^@03o`000?nlV[Go
_9Ze01;o_9Ze00?o0000ok6@]OnaT;D04onaT;D00ol0003oYHVgojF9]`0@ojF9]`Go00004OnIQ;`3
o`000003oiZ5_?l0003oShK600WoShK600?o0000oi67aOnAQlD02?nAQlD00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002oooooo00?o0000oooo
ooooool0@oooool00ol0003oc[k;oljnb`05oljnb`;o00002?o@`L`00ol0003ocK:oo`000002o`00
013oc[C00_l00003olNW^@03o`000?o7YkWoajNi00ooajNi00?o0000okbJ]OnlV[D04_nlV[D00ol0
003o/I2eok6@]@0Dok6@]@03o`000?nURKOoYHVg00SoYHVg1ol00003ojF9]P03o`000?nIQ;coVHBl
00goVHBl0ol00005oiZ5_003o`000?n?Q/KoShK600GoShK60_l00009oi67a@;o0000:?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?o
oooo0_l00007oljnb`03o`000?o@`Lcod<7<00Cod<7<00?o0000olfb_oo=/[l00oo=/[l3o`0000ko
c[C000?o0000olJU^?o6YKP00_o6YKP7o`0000WoajNi00?o0000okbJ]OnlV[D04onlV[D00ol0003o
/I2eok6@]@0Dok6@]@04o`000?nURKOoYHVgojF9]`Oo00002onURKH00ol0003oVHBloiV4_009oiV4
_0?o00002?nJQK`00ol0003oShK6ohn6aP03ohn6aP;o00002OnAQlD2o`0002_ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`0004Gooooo00?o0000oljnboo>
_//01Oo>_//2o`0000?od<7<00?o0000olfb_oo=/[l01oo=/[l3o`0000[oc[C000?o0000olJU^?o6
YKP02_o6YKP7o`0000;oajNi00?o0000okbJ]OnlV[D04onlV[D00ol0003o/I2eok6@]@0>ok6@]@[o
00004_nURKH00ol0003oVHBloiV4_006oiV4_0?o00003?nJQK`01Ol0003oShK6ohn6a_n?Q/Ko0000
00[oTHO500?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo000cooooo`03o`000?oooooooooo04?ooooo0_l00007oljnb`03o`000?o@`Lco000000go
cK:o0_l00008oljd`003o`000?o6YKSoaZFh017oaZFh0ol000000onlV[Go0000o`000008o`0000[o
_9Ze00?o0000ok6@]OnaT;D00onaT;D;o`0000Ko/I2d00?o0000ojF9]_nURKH04onURKH00ol0003o
VHBloiV4_003oiV4_0?o00003onJQK`01?l0003oShK6o`000?l00009oi67a@;o0000;oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000dooooo`03o`000?oooooooooo04Co
oooo00?o0000oljnboo>_//01Oo>_//00ol0003ocK:oolfb_`0>olfb_`?o00001?o>]<000ol0003o
aZFholJU^00DolJU^003o`000?nlVKGo_9Ve00Wo_9Ve4?l0000Aok6@]003o`000?nURKKoYHVf01Co
YHVf00?o0000oiV4_?l000000_l0000BoiZ5_0;o00002_nAQlD00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool003Gooooo00?o0000ooooooooool0
A?ooool00ol0003oc[k;oljnb`04oljnb`03o`000?o;/;oobk2o00?o00003_o=/[l3o`000003oljd
`?l0003oaZFh01GoaZFh00?o0000okbI]OnlVKD04onlVKD00ol0003o/I2dok6@]00Dok6@]003o`00
0?nURKKoYHVf017oYHVf1Ol0000BoiZ5_0?o000000?oVhJlo`000?nAQlD01onAQlD2o`0003Cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00=_ooool2o`0004Gooooo0_l0
0003oljnb`03o`000?o;/;oobk2o00Cobk2o0ol0000>olfb_`03o`000?o6YKSoaZFh01GoaZFh00?o
0000okbI]OnlVKD04onlVKD00ol0003o/I2dok6@]00Eok6@]003o`000?nURKKoYHVf00_oYHVf1Ol0
0003ojF9]P03o`000?nJQKcoVXFl00koVXFl0ol00005oi^6_003o`000?nAQlGoTHO500CoTHO500?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000h
ooooo`03o`000?oooooooooo04Cooooo00?o0000oljnbol000002_o;/;l3o`0000_ocK:o00Co0000
olFT^?o5Y;SoaJBh1_l0000=olJU^003o`000?nlVKGo_9Ve01Co_9Ve00?o0000ok6@]?naT;@05Ona
T;@00ol0003oYHVfojF9]P05ojF9]PKo00002?nURKH00ol0003oVXFloiZ5_00;oiZ5_0?o00002?nK
Q[`00ol0003oTHO5oi67a@02oi67a@;o0000>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo00?o0000ol^`_oo;/;l03?o;/;l3
o`0000OocK:o00?o0000olFT^?o5Y;P02?o5Y;P5o`0000SoaZFh00?o0000okbI]OnlVKD05?nlVKD0
0ol0003o/I2dok6@]00Eok6@]003o`000?nURKKoYHVf00Go00003onURKH00ol0003oVXFloiZ5_008
oiZ5_0;o00002onKQ[`00ol0003oTHO5oi67a@02o`0003_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`03ooooo`00>_ooool00ol0003oooooooooo`15ooooo`?o00003Oo;/;l3o`00
00CocK:o00?o0000olFT^?o5Y;P03Oo5Y;P6o`0000;oaZFh00?o0000okbI]OnlVKD05?nlVKD00ol0
003o/I2dok6@]00?ok6@]0Wo00005?nURKH00ol0003oVXFloiZ5_005oiZ5_0?o00003_nKQ[`2o`00
03kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00>oooool2o`0004So
oooo0_l0000>ol^`_`?o000000?ocK:oo`000?o5Y;P05?o5Y;P3o`000003okbI]Ol0003o000000Wo
00002_nlVKD00ol0003o/I2dok6@]003ok6@]0co00001_naT;@00ol0003oYHVfojF9]P0DojF9]P03
o`000?nJQKcoVXFl00;oVXFl0ol0000@oi^6_0;o0000?oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00;ooooo000mooooo`03o`000?oooooooooo04Oooooo0ol0000>ol^`_`03o`00
0?o5Y;SoaJBh01KoaJBh00?o0000ok^I]OnkVKD02_nkVKD@o`0001;o/I2d00?o0000ojF9]_nURKH0
5OnURKH4o`00013oVhJl0ol00012ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool003kooooo00?o0000ooooooooool0BOooool2o`0000cobk2o00?o0000olBT^Oo4Y;T01Ol0
000@olFT^003o`000?nkVKGo^iVe01Go^iVe00?o0000ok6@]?naT;@05OnaT;@00ol0003oYHVfojF9
]P0BojF9]PCo00004?nKQ[`3o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`00?oooool00ol0003oooooooooo`1:ooooo`;o00002Oo;/;l00ol0003oa:BiolBT^@06
olBT^@Go00002oo5Y;P00ol0003o^iVeok^I]@0Eok^I]@03o`000?naT;Co/I2d01Ko/I2d00?o0000
ojF9]_nURKH02onURKH6o`0000?oYXVg00?o0000oi^6_?nKQ[`02onKQ[`3o`0004[ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@?ooool2o`0004cooooo0ol00006ol^`
_`03o`000?o4Y;Woa:Bi00_oa:Bi1?l00007olFT^003o`000?nkVKGo^iVe01Go^iVe00?o0000ok6@
]?naT;@05_naT;@00ol0003oYHVfojF9]P06ojF9]PGo00002_nVRKL00ol0003oVhJloi^6_008oi^6
_0;o0000COooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0012ooooo`03
o`000?oooooooooo04cooooo0_l00004ol^`_`03o`000?o4Y;Woa:Bi00ooa:Bi1Ol000000oo5Y;So
0000ok^I]@0Gok^I]@03o`000?naT;Co/I2d01Ko/I2d00?o0000ojF9]_nURKH01_l0000?ojJ9]`03
o`000?nKQ[coVhJl00GoVhJl0ol0001@ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool004?ooooo00?o0000ooooooooool0COooool4o`0001Ooa:Bi0_l00002ok^I]@Co0000
4_nkVKD00ol0003o/I2dok6@]00@ok6@]0Wo00005OnVRKL00ol0003oVhJloi^6_002oi^6_0?o0000
E?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oo
oooooooo04oooooo00?o0000olBT^Oo4Y;T05_o4Y;T00ol0003o^iVeok^I]@04ok^I]@go00001Onk
VKD00ol0003o/I2dok6@]003ok6@]0go00001_n`T;@00ol0003oYXVgojJ9]`0FojJ9]`Co0000F?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0015ooooo`;o0000D_ooool5
o`00017oa:Bi00?o0000ok^I]OnkVKD04OnkVKD;o`0001?o/92d00?o0000ojJ9]onVRKL05?nVRKL3
o`0005_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00Aoooool00ol0
003oooooooooo`1Dooooo`Go00003?o4Y;T00ol0003o^iVeok^I]@0Fok^I]@03o`000?n`T;Co/92d
01Ko/92d00?o0000ojJ9]onVRKL03onVRKL5o`0005oooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`01ooooo`00B?ooool00ol0003oooooooooo`1Hooooo`Go00001_o4Y;T00ol0003o
^iVeok^I]@0Gok^I]@03o`000?n`T;Co/92d01Oo/92d00?o0000ojJ9]onVRKL02OnVRKL5o`0006Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00BOooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo00;ooooo1Ol000000oo4Y;Wo0000ok^I]@0Hok^I]@03o`00
0?n`T;Co/92d01Oo/92d00?o0000ojJ9]onVRKL01?nVRKL5o`0006_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00B_ooool2o`0005Oooooo00?o0000ooooooooool01ooo
ool2o`0000;o^iVe0_l0000Eok^I]@03o`000?n`T;Co/92d01Oo/92d00?o0000ojJ9]ol000001?l0
001`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004cooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`Wo00003?nkVKD00ol0003o/92dok2@]00A
ok2@]0So0000M_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00COooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo01Kooooo2Ol00003ok^I]@03o`000?n`T;Co/92d
00Co/92d3Ol0001oooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001>ooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool07oooool:o`0008cooooo00?o0000oooooooo
ool01oooool1o`00007ooooo0Oooool004oooooo0_l0001Booooo`03o`000?oooooooooo0;Kooooo
00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0057ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001B
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000ooooooooool0^?ooool00ol0
003oooooooooo`04ooooo`7o00000Oooool1ooooo`00EOooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo0;Wooooo00?o0000ooooooooool01?ooool1o`00007ooooo001Fooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool005Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`2kooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00F?ooool2o`0004Wooooo00?o0000ooooooooool0^oooool0
0ol0003oooooooooo`02ooooo`7o00000Oooool005[ooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`2looooo`05o`000?ooooooooooooooool000000Oooool005_ooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`2mooooo`04o`000?ooooooooooo`00007ooooo001Loooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0__ooool00ol0003oooooo`000001oooo
o`00GOooool2o`0004Cooooo00?o0000ooooooooool0__ooool00ol0003oooooooooo`01o`000000
Goooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;oooooo0Ol00001ooooo`7o0000
001Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0`?ooool2o`000000HOooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;oooooo0ol0000006;ooooo0_l0000ooooo
o`03o`000?oooooooooo0;_ooooo1?l00003ooooo`00I?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo0;Oooooo1?l00007ooooo`00IOooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0;?ooooo1?l0000;ooooo`00I_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo0;3ooooo0ol0000?ooooo`00Ioooool2o`0003[ooooo00?o0000ooooooooool0[?ooool4
o`0001;ooooo001Yooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Z?ooool4o`00
01Kooooo001Zooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Y?ooool4o`0001[o
oooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0XOooool4o`0001kooooo
001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Mooooo`Co00008_ooool006kooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`2Iooooo`Co00009_ooool006oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`2Eooooo`Co0000:_ooool0073ooooo0_l0000`ooooo`03
o`000?oooooooooo097ooooo1?l0000^ooooo`00L_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo08kooooo0ol0000booooo`00Loooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo08[ooooo1?l0000eooooo`00M?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo08Kooooo1?l0000iooooo`00MOooool2o`0002_ooooo00?o0000ooooooooool0P_ooool4o`00
03gooooo001gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0O_ooool4o`00047o
oooo001hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0N_ooool4o`0004Gooooo
001iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0M_ooool4o`0004Wooooo001j
ooooo`;o00009_ooool00ol0003oooooooooo`1booooo`Co0000COooool007cooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1_ooooo`?o0000DOooool007gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1[ooooo`Co0000E?ooool007kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Wooooo`Co0000F?ooool007oooooo0_l0000Qooooo`03o`000?oo
oooooooo06?ooooo1?l0001Looooo`00POooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05oooooo1?l0001Pooooo`00P_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
05_ooooo1?l0001Tooooo`00Poooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05Oo
oooo1?l0001Xooooo`00Q?ooool2o`0001cooooo00?o0000ooooooooool0Doooool4o`0006cooooo
0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Coooool4o`00073ooooo0027
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?ooool3o`0007Cooooo0028oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4o`0007Oooooo0029ooooo`;o
00005oooool00ol0003oooooooooo`14ooooo`Co0000Noooool008_ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`10ooooo`Co0000Ooooool008cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0looooo`Co0000Poooool008gooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0hooooo`Co0000Qoooool008kooooo0_l0000Booooo`03o`000?oooooooooo
03Cooooo1?l0002;ooooo`00T?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo037o
oooo1?l0002?ooooo`00TOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo
0ol0002Cooooo`00T_ooool2o`0000gooooo00?o0000ooooooooool0:_ooool4o`0009Kooooo002D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_ooool4o`0009[ooooo002Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4o`0009kooooo002Fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`000:;ooooo002Gooooo`;o0000
2?ooool00ol0003oooooooooo`0Jooooo`Co0000Y_ooool009Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003ooooo`03o`000?oooooooooo00_o
oooo0ol0002fooooo`00W_ooool01?l0003oooooooooool00009ooooo`Co0000^Oooool009oooooo
00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o000000?oooooo`000?l000000_l0
0031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.44619 .60982 m .44979 .58877 L .51796 .59447 L p .731 .597 .706 r
F P
0 g
s
.51796 .59447 m .51762 .61583 L .44619 .60982 L p .731 .597 .706 r
F P
0 g
s
.5183 .57344 m .51796 .59447 L .44979 .58877 L p .731 .598 .708 r
F P
0 g
s
.51762 .61583 m .51796 .59447 L .58652 .59317 L p .688 .566 .712 r
F P
0 g
s
.51796 .59447 m .5183 .57344 L .58361 .57312 L p .686 .566 .714 r
F P
0 g
s
.58361 .57312 m .58652 .59317 L .51796 .59447 L p .686 .566 .714 r
F P
0 g
s
.44259 .63089 m .44619 .60982 L .51762 .61583 L p .731 .596 .706 r
F P
0 g
s
.51762 .61583 m .51728 .6372 L .44259 .63089 L p .731 .596 .706 r
F P
0 g
s
.51728 .6372 m .51762 .61583 L .58944 .61352 L p .69 .567 .712 r
F P
0 g
s
.58652 .59317 m .58944 .61352 L .51762 .61583 L p .688 .566 .712 r
F P
0 g
s
.44979 .58877 m .45339 .56804 L .5183 .57344 L p .731 .598 .708 r
F P
0 g
s
.51864 .55301 m .5183 .57344 L .45339 .56804 L p .731 .601 .712 r
F P
0 g
s
.5183 .57344 m .51864 .55301 L .58071 .55364 L p .684 .568 .718 r
F P
0 g
s
.58071 .55364 m .58361 .57312 L .5183 .57344 L p .684 .568 .718 r
F P
0 g
s
.51728 .6372 m .51694 .65827 L .43899 .65168 L p .731 .598 .708 r
F P
0 g
s
.51694 .65827 m .51728 .6372 L .59236 .63387 L p .692 .57 .713 r
F P
0 g
s
.59236 .63387 m .59527 .65394 L .51694 .65827 L p .692 .57 .713 r
F P
0 g
s
.43899 .65168 m .44259 .63089 L .51728 .6372 L p .731 .598 .708 r
F P
0 g
s
.58944 .61352 m .59236 .63387 L .51728 .6372 L p .69 .567 .712 r
F P
0 g
s
.45339 .56804 m .45697 .54792 L .51864 .55301 L p .731 .601 .712 r
F P
0 g
s
.51898 .53347 m .51864 .55301 L .45697 .54792 L p .731 .606 .719 r
F P
0 g
s
.51864 .55301 m .51898 .53347 L .57781 .53499 L p .681 .572 .725 r
F P
0 g
s
.57781 .53499 m .58071 .55364 L .51864 .55301 L p .681 .572 .725 r
F P
0 g
s
.45697 .54792 m .46053 .5287 L .51898 .53347 L p .731 .606 .719 r
F P
0 g
s
.51931 .51508 m .51898 .53347 L .46053 .5287 L p .73 .614 .728 r
F P
0 g
s
.51898 .53347 m .51931 .51508 L .57493 .51741 L p .678 .577 .735 r
F P
0 g
s
.57493 .51741 m .57781 .53499 L .51898 .53347 L p .678 .577 .735 r
F P
0 g
s
.46053 .5287 m .46408 .51062 L .51931 .51508 L p .73 .614 .728 r
F P
0 g
s
.51965 .49807 m .51931 .51508 L .46408 .51062 L p .729 .623 .74 r
F P
0 g
s
.51931 .51508 m .51965 .49807 L .57207 .50114 L p .674 .585 .748 r
F P
0 g
s
.57207 .50114 m .57493 .51741 L .51931 .51508 L p .674 .585 .748 r
F P
0 g
s
.59527 .65394 m .59236 .63387 L .66423 .621 L p .652 .554 .73 r
F P
0 g
s
.66423 .621 m .67023 .63881 L .59527 .65394 L p .652 .554 .73 r
F P
0 g
s
.46408 .51062 m .4676 .49392 L .51965 .49807 L p .729 .623 .74 r
F P
0 g
s
.51998 .48265 m .51965 .49807 L .4676 .49392 L p .727 .636 .757 r
F P
0 g
s
.51965 .49807 m .51998 .48265 L .56921 .48636 L p .668 .596 .766 r
F P
0 g
s
.56921 .48636 m .57207 .50114 L .51965 .49807 L p .668 .596 .766 r
F P
0 g
s
.59236 .63387 m .58944 .61352 L .65821 .60293 L p .648 .55 .729 r
F P
0 g
s
.65821 .60293 m .66423 .621 L .59236 .63387 L p .648 .55 .729 r
F P
0 g
s
.58944 .61352 m .58652 .59317 L .65219 .58487 L p .644 .547 .73 r
F P
0 g
s
.65219 .58487 m .65821 .60293 L .58944 .61352 L p .644 .547 .73 r
F P
0 g
s
.58652 .59317 m .58361 .57312 L .64618 .56705 L p .639 .546 .734 r
F P
0 g
s
.64618 .56705 m .65219 .58487 L .58652 .59317 L p .639 .546 .734 r
F P
0 g
s
.58361 .57312 m .58071 .55364 L .64018 .54973 L p .634 .547 .739 r
F P
0 g
s
.64018 .54973 m .64618 .56705 L .58361 .57312 L p .634 .547 .739 r
F P
0 g
s
.38532 .57626 m .39201 .55713 L .45339 .56804 L p .775 .641 .714 r
F P
0 g
s
.45339 .56804 m .44979 .58877 L .38532 .57626 L p .775 .641 .714 r
F P
0 g
s
.45697 .54792 m .45339 .56804 L .39201 .55713 L p .776 .646 .718 r
F P
0 g
s
.39201 .55713 m .39868 .53858 L .45697 .54792 L p .776 .646 .718 r
F P
0 g
s
.46053 .5287 m .45697 .54792 L .39868 .53858 L p .778 .653 .725 r
F P
0 g
s
.58071 .55364 m .57781 .53499 L .6342 .53314 L p .628 .55 .747 r
F P
0 g
s
.6342 .53314 m .64018 .54973 L .58071 .55364 L p .628 .55 .747 r
F P
0 g
s
.37862 .59569 m .38532 .57626 L .44979 .58877 L p .773 .637 .711 r
F P
0 g
s
.44979 .58877 m .44619 .60982 L .37862 .59569 L p .773 .637 .711 r
F P
0 g
s
.37191 .61515 m .37862 .59569 L .44619 .60982 L p .771 .635 .711 r
F P
0 g
s
.44619 .60982 m .44259 .63089 L .37191 .61515 L p .771 .635 .711 r
F P
0 g
s
.39868 .53858 m .40531 .52086 L .46053 .5287 L p .778 .653 .725 r
F P
0 g
s
.46408 .51062 m .46053 .5287 L .40531 .52086 L p .779 .663 .735 r
F P
0 g
s
.36521 .63435 m .37191 .61515 L .44259 .63089 L p .769 .635 .713 r
F P
0 g
s
.44259 .63089 m .43899 .65168 L .36521 .63435 L p .769 .635 .713 r
F P
0 g
s
.57781 .53499 m .57493 .51741 L .62825 .51748 L p .62 .555 .759 r
F P
0 g
s
.62825 .51748 m .6342 .53314 L .57781 .53499 L p .62 .555 .759 r
F P
0 g
s
.4676 .49392 m .47111 .47881 L .51998 .48265 L p .727 .636 .757 r
F P
0 g
s
.52031 .469 m .51998 .48265 L .47111 .47881 L p .723 .654 .78 r
F P
0 g
s
.51998 .48265 m .52031 .469 L .56637 .47325 L p .659 .611 .79 r
F P
0 g
s
.56637 .47325 m .56921 .48636 L .51998 .48265 L p .659 .611 .79 r
F P
0 g
s
.40531 .52086 m .41191 .50422 L .46408 .51062 L p .779 .663 .735 r
F P
0 g
s
.4676 .49392 m .46408 .51062 L .41191 .50422 L p .78 .675 .748 r
F P
0 g
s
.57493 .51741 m .57207 .50114 L .62231 .50297 L p .611 .562 .775 r
F P
0 g
s
.62231 .50297 m .62825 .51748 L .57493 .51741 L p .611 .562 .775 r
F P
0 g
s
.41191 .50422 m .41847 .48888 L .4676 .49392 L p .78 .675 .748 r
F P
0 g
s
.47111 .47881 m .4676 .49392 L .41847 .48888 L p .78 .692 .766 r
F P
0 g
s
.57207 .50114 m .56921 .48636 L .6164 .48976 L p .598 .572 .796 r
F P
0 g
s
.6164 .48976 m .62231 .50297 L .57207 .50114 L p .598 .572 .796 r
F P
0 g
s
.47111 .47881 m .4746 .46546 L .52031 .469 L p .723 .654 .78 r
F P
0 g
s
.52064 .45726 m .52031 .469 L .4746 .46546 L p .715 .677 .811 r
F P
0 g
s
.52031 .469 m .52064 .45726 L .56354 .46194 L p .645 .632 .822 r
F P
0 g
s
.56354 .46194 m .56637 .47325 L .52031 .469 L p .645 .632 .822 r
F P
0 g
s
.41847 .48888 m .42499 .47502 L .47111 .47881 L p .78 .692 .766 r
F P
0 g
s
.4746 .46546 m .47111 .47881 L .42499 .47502 L p .779 .713 .791 r
F P
0 g
s
.56921 .48636 m .56637 .47325 L .6105 .47801 L p .58 .586 .823 r
F P
0 g
s
.6105 .47801 m .6164 .48976 L .56921 .48636 L p .58 .586 .823 r
F P
0 g
s
.42499 .47502 m .43149 .46282 L .4746 .46546 L p .779 .713 .791 r
F P
0 g
s
.47807 .45402 m .4746 .46546 L .43149 .46282 L p .774 .742 .824 r
F P
0 g
s
.4746 .46546 m .47807 .45402 L .52064 .45726 L p .715 .677 .811 r
F P
0 g
s
.52097 .44755 m .52064 .45726 L .47807 .45402 L p .701 .708 .853 r
F P
0 g
s
.52064 .45726 m .52097 .44755 L .56071 .45254 L p .622 .658 .864 r
F P
0 g
s
.56071 .45254 m .56354 .46194 L .52064 .45726 L p .622 .658 .864 r
F P
0 g
s
.56637 .47325 m .56354 .46194 L .60462 .46785 L p .552 .603 .858 r
F P
0 g
s
.60462 .46785 m .6105 .47801 L .56637 .47325 L p .552 .603 .858 r
F P
0 g
s
.67023 .63881 m .66423 .621 L .72921 .59893 L p .617 .556 .763 r
F P
0 g
s
.72921 .59893 m .73799 .61332 L .67023 .63881 L p .617 .556 .763 r
F P
0 g
s
.43149 .46282 m .43796 .4524 L .47807 .45402 L p .774 .742 .824 r
F P
0 g
s
.48154 .4446 m .47807 .45402 L .43796 .4524 L p .762 .779 .867 r
F P
0 g
s
.47807 .45402 m .48154 .4446 L .52097 .44755 L p .701 .708 .853 r
F P
0 g
s
.66423 .621 m .65821 .60293 L .72041 .58435 L p .609 .551 .764 r
F P
0 g
s
.72041 .58435 m .72921 .59893 L .66423 .621 L p .609 .551 .764 r
F P
0 g
s
.65821 .60293 m .65219 .58487 L .7116 .56976 L p .601 .548 .767 r
F P
0 g
s
.7116 .56976 m .72041 .58435 L .65821 .60293 L p .601 .548 .767 r
F P
0 g
s
.65219 .58487 m .64618 .56705 L .7028 .55536 L p .592 .546 .772 r
F P
0 g
s
.7028 .55536 m .7116 .56976 L .65219 .58487 L p .592 .546 .772 r
F P
0 g
s
.64618 .56705 m .64018 .54973 L .69401 .54135 L p .581 .546 .781 r
F P
0 g
s
.69401 .54135 m .7028 .55536 L .64618 .56705 L p .581 .546 .781 r
F P
0 g
s
.5213 .43993 m .52097 .44755 L .48154 .4446 L p .672 .747 .907 r
F P
0 g
s
.52097 .44755 m .5213 .43993 L .55788 .44513 L p .578 .69 .918 r
F P
0 g
s
.55788 .44513 m .56071 .45254 L .52097 .44755 L p .578 .69 .918 r
F P
0 g
s
.56354 .46194 m .56071 .45254 L .59875 .45937 L p .507 .624 .901 r
F P
0 g
s
.59875 .45937 m .60462 .46785 L .56354 .46194 L p .507 .624 .901 r
F P
0 g
s
.33735 .54109 m .34678 .52532 L .39868 .53858 L p .819 .704 .738 r
F P
0 g
s
.39868 .53858 m .39201 .55713 L .33735 .54109 L p .819 .704 .738 r
F P
0 g
s
.40531 .52086 m .39868 .53858 L .34678 .52532 L p .822 .715 .746 r
F P
0 g
s
.64018 .54973 m .6342 .53314 L .68524 .52791 L p .568 .549 .792 r
F P
0 g
s
.68524 .52791 m .69401 .54135 L .64018 .54973 L p .568 .549 .792 r
F P
0 g
s
.32789 .55736 m .33735 .54109 L .39201 .55713 L p .816 .696 .732 r
F P
0 g
s
.39201 .55713 m .38532 .57626 L .32789 .55736 L p .816 .696 .732 r
F P
0 g
s
.34678 .52532 m .35617 .51027 L .40531 .52086 L p .822 .715 .746 r
F P
0 g
s
.41191 .50422 m .40531 .52086 L .35617 .51027 L p .825 .728 .758 r
F P
0 g
s
.31841 .57389 m .32789 .55736 L .38532 .57626 L p .812 .689 .729 r
F P
0 g
s
.38532 .57626 m .37862 .59569 L .31841 .57389 L p .812 .689 .729 r
F P
0 g
s
.30892 .59045 m .31841 .57389 L .37862 .59569 L p .808 .685 .728 r
F P
0 g
s
.37862 .59569 m .37191 .61515 L .30892 .59045 L p .808 .685 .728 r
F P
0 g
s
.35617 .51027 m .36551 .49616 L .41191 .50422 L p .825 .728 .758 r
F P
0 g
s
.41847 .48888 m .41191 .50422 L .36551 .49616 L p .827 .746 .774 r
F P
0 g
s
.6342 .53314 m .62825 .51748 L .67649 .51522 L p .553 .553 .808 r
F P
0 g
s
.67649 .51522 m .68524 .52791 L .6342 .53314 L p .553 .553 .808 r
F P
0 g
s
.29943 .6068 m .30892 .59045 L .37191 .61515 L p .804 .681 .729 r
F P
0 g
s
.37191 .61515 m .36521 .63435 L .29943 .6068 L p .804 .681 .729 r
F P
0 g
s
.36551 .49616 m .3748 .48318 L .41847 .48888 L p .827 .746 .774 r
F P
0 g
s
.42499 .47502 m .41847 .48888 L .3748 .48318 L p .828 .768 .795 r
F P
0 g
s
.62825 .51748 m .62231 .50297 L .66777 .50342 L p .533 .56 .828 r
F P
0 g
s
.66777 .50342 m .67649 .51522 L .62825 .51748 L p .533 .56 .828 r
F P
0 g
s
.43796 .4524 m .44441 .44387 L .48154 .4446 L p .762 .779 .867 r
F P
0 g
s
.485 .43727 m .48154 .4446 L .44441 .44387 L p .733 .825 .922 r
F P
0 g
s
.48154 .4446 m .485 .43727 L .5213 .43993 L p .672 .747 .907 r
F P
0 g
s
.3748 .48318 m .38405 .47148 L .42499 .47502 L p .828 .768 .795 r
F P
0 g
s
.43149 .46282 m .42499 .47502 L .38405 .47148 L p .826 .796 .823 r
F P
0 g
s
.62231 .50297 m .6164 .48976 L .65906 .49266 L p .505 .568 .853 r
F P
0 g
s
.65906 .49266 m .66777 .50342 L .62231 .50297 L p .505 .568 .853 r
F P
0 g
s
.56071 .45254 m .55788 .44513 L .59287 .45262 L p .427 .642 .947 r
F P
0 g
s
.59287 .45262 m .59875 .45937 L .56071 .45254 L p .427 .642 .947 r
F P
0 g
s
.52163 .43446 m .5213 .43993 L .485 .43727 L p .605 .789 .969 r
F P
0 g
s
.5213 .43993 m .52163 .43446 L .55505 .43973 L p .489 .719 .973 r
F P
0 g
s
.55505 .43973 m .55788 .44513 L .5213 .43993 L p .489 .719 .973 r
F P
0 g
s
.6164 .48976 m .6105 .47801 L .65038 .48306 L p .465 .579 .884 r
F P
0 g
s
.65038 .48306 m .65906 .49266 L .6164 .48976 L p .465 .579 .884 r
F P
0 g
s
.38405 .47148 m .39326 .46122 L .43149 .46282 L p .826 .796 .823 r
F P
0 g
s
.43796 .4524 m .43149 .46282 L .39326 .46122 L p .819 .832 .86 r
F P
0 g
s
.44441 .44387 m .45086 .43731 L .485 .43727 L p .733 .825 .922 r
F P
0 g
s
.48847 .43208 m .485 .43727 L .45086 .43731 L p .659 .87 .978 r
F P
0 g
s
.485 .43727 m .48847 .43208 L .52163 .43446 L p .605 .789 .969 r
F P
0 g
s
.6105 .47801 m .60462 .46785 L .64171 .47472 L p .405 .588 .917 r
F P
0 g
s
.64171 .47472 m .65038 .48306 L .6105 .47801 L p .405 .588 .917 r
F P
0 g
s
.39326 .46122 m .40243 .45252 L .43796 .4524 L p .819 .832 .86 r
F P
0 g
s
.44441 .44387 m .43796 .4524 L .40243 .45252 L p .797 .876 .904 r
F P
0 g
s
.55788 .44513 m .55505 .43973 L .58699 .44766 L p .282 .635 .964 r
F P
0 g
s
.58699 .44766 m .59287 .45262 L .55788 .44513 L p .282 .635 .964 r
F P
0 g
s
.52196 .43114 m .52163 .43446 L .48847 .43208 L p .452 .799 .998 r
F P
0 g
s
.52163 .43446 m .52196 .43114 L .55221 .43637 L p .308 .704 .978 r
F P
0 g
s
.55221 .43637 m .55505 .43973 L .52163 .43446 L p .308 .704 .978 r
F P
0 g
s
.60462 .46785 m .59875 .45937 L .63304 .46771 L p .308 .589 .942 r
F P
0 g
s
.63304 .46771 m .64171 .47472 L .60462 .46785 L p .308 .589 .942 r
F P
0 g
s
.40243 .45252 m .41158 .44546 L .44441 .44387 L p .797 .876 .904 r
F P
0 g
s
.45086 .43731 m .44441 .44387 L .41158 .44546 L p .744 .92 .951 r
F P
0 g
s
.45086 .43731 m .45732 .43274 L .48847 .43208 L p .659 .87 .978 r
F P
0 g
s
.49195 .42903 m .48847 .43208 L .45732 .43274 L p .484 .863 .981 r
F P
0 g
s
.48847 .43208 m .49195 .42903 L .52196 .43114 L p .452 .799 .998 r
F P
0 g
s
.55505 .43973 m .55221 .43637 L .58108 .44447 L p .048 .554 .88 r
F P
0 g
s
.58108 .44447 m .58699 .44766 L .55505 .43973 L p .048 .554 .88 r
F P
0 g
s
.59875 .45937 m .59287 .45262 L .62436 .46208 L p .157 .56 .93 r
F P
0 g
s
.62436 .46208 m .63304 .46771 L .59875 .45937 L p .157 .56 .93 r
F P
0 g
s
.41158 .44546 m .42073 .44009 L .45086 .43731 L p .744 .92 .951 r
F P
0 g
s
.45732 .43274 m .45086 .43731 L .42073 .44009 L p .616 .931 .965 r
F P
0 g
s
.73799 .61332 m .72921 .59893 L .78355 .5684 L p .597 .592 .817 r
F P
0 g
s
.78355 .5684 m .79464 .57831 L .73799 .61332 L p .597 .592 .817 r
F P
0 g
s
.72921 .59893 m .72041 .58435 L .77243 .55836 L p .583 .588 .822 r
F P
0 g
s
.77243 .55836 m .78355 .5684 L .72921 .59893 L p .583 .588 .822 r
F P
0 g
s
.52229 .42993 m .52196 .43114 L .49195 .42903 L p .157 .682 .875 r
F P
0 g
s
.52196 .43114 m .52229 .42993 L .54935 .43499 L p .012 .566 .821 r
F P
0 g
s
.55221 .43637 m .52196 .43114 L p .54529 .43442 L .012 .566 .821 r
F P
0 g
s
.52263 .43078 m .54646 .43555 L p .5263 .43087 L .272 0 0 r
F P
0 g
s
.52229 .42993 m .52237 .43013 L p .5263 .43087 L .272 0 0 r
F P
0 g
s
.52237 .43013 m .52263 .43078 L p .5263 .43087 L .272 0 0 r
F P
0 g
s
.54935 .43499 m .54999 .4353 L p .54529 .43442 L .012 .566 .821 r
F P
0 g
s
.54999 .4353 m .55221 .43637 L p .54529 .43442 L .012 .566 .821 r
F P
0 g
s
.72041 .58435 m .7116 .56976 L .76131 .54831 L p .569 .585 .83 r
F P
0 g
s
.76131 .54831 m .77243 .55836 L .72041 .58435 L p .569 .585 .83 r
F P
0 g
s
.7116 .56976 m .7028 .55536 L .75018 .53839 L p .552 .584 .84 r
F P
0 g
s
.75018 .53839 m .76131 .54831 L .7116 .56976 L p .552 .584 .84 r
F P
0 g
s
.7028 .55536 m .69401 .54135 L .73906 .52872 L p .532 .586 .854 r
F P
0 g
s
.73906 .52872 m .75018 .53839 L .7028 .55536 L p .532 .586 .854 r
F P
0 g
s
.30435 .50864 m .31601 .49735 L .35617 .51027 L p .857 .794 .788 r
F P
0 g
s
.35617 .51027 m .34678 .52532 L .30435 .50864 L p .857 .794 .788 r
F P
0 g
s
.36551 .49616 m .35617 .51027 L .31601 .49735 L p .86 .814 .803 r
F P
0 g
s
.29265 .5205 m .30435 .50864 L .34678 .52532 L p .853 .777 .777 r
F P
0 g
s
.34678 .52532 m .33735 .54109 L .29265 .5205 L p .853 .777 .777 r
F P
0 g
s
.69401 .54135 m .68524 .52791 L .72795 .51942 L p .506 .588 .871 r
F P
0 g
s
.72795 .51942 m .73906 .52872 L .69401 .54135 L p .506 .588 .871 r
F P
0 g
s
.28091 .53274 m .29265 .5205 L .33735 .54109 L p .848 .764 .769 r
F P
0 g
s
.33735 .54109 m .32789 .55736 L .28091 .53274 L p .848 .764 .769 r
F P
0 g
s
.45732 .43274 m .46379 .43018 L .49195 .42903 L p .484 .863 .981 r
F P
0 g
s
.49545 .42809 m .49195 .42903 L .46379 .43018 L p .166 .704 .814 r
F P
0 g
s
.49195 .42903 m .49545 .42809 L .52229 .42993 L p .157 .682 .875 r
F P
0 g
s
.31601 .49735 m .32762 .48678 L .36551 .49616 L p .86 .814 .803 r
F P
0 g
s
.3748 .48318 m .36551 .49616 L .32762 .48678 L p .86 .838 .823 r
F P
0 g
s
.59287 .45262 m .58699 .44766 L .61568 .45787 L p 0 .474 .831 r
F P
0 g
s
.61568 .45787 m .62436 .46208 L .59287 .45262 L p 0 .474 .831 r
F P
0 g
s
.26914 .54519 m .28091 .53274 L .32789 .55736 L p .843 .753 .763 r
F P
0 g
s
.32789 .55736 m .31841 .57389 L .26914 .54519 L p .843 .753 .763 r
F P
0 g
s
.68524 .52791 m .67649 .51522 L .71685 .51061 L p .473 .592 .892 r
F P
0 g
s
.71685 .51061 m .72795 .51942 L .68524 .52791 L p .473 .592 .892 r
F P
0 g
s
.32762 .48678 m .33919 .47709 L .3748 .48318 L p .86 .838 .823 r
F P
0 g
s
.38405 .47148 m .3748 .48318 L .33919 .47709 L p .856 .868 .848 r
F P
0 g
s
.25736 .55765 m .26914 .54519 L .31841 .57389 L p .837 .744 .761 r
F P
0 g
s
.31841 .57389 m .30892 .59045 L .25736 .55765 L p .837 .744 .761 r
F P
0 g
s
.24558 .56996 m .25736 .55765 L .30892 .59045 L p .83 .736 .761 r
F P
0 g
s
.30892 .59045 m .29943 .6068 L .24558 .56996 L p .83 .736 .761 r
F P
0 g
s
.58108 .44447 m .55221 .43637 L p .56883 .44119 L .217 0 0 r
F P
0 g
s
.57514 .44302 m .57968 .44412 L p .56883 .44119 L .217 0 0 r
F P
0 g
s
.57968 .44412 m .58108 .44447 L p .56883 .44119 L .217 0 0 r
F P
0 g
s
.54646 .43555 m .56916 .44326 L p .55565 .43763 L .406 0 0 r
F P
0 g
s
.55221 .43637 m .54935 .43499 L .57514 .44302 L p .217 0 0 r
F P
0 g
s
.54935 .43499 m .54735 .43538 L p .55565 .43763 L .406 0 0 r
F P
0 g
s
.54735 .43538 m .54646 .43555 L p .55565 .43763 L .406 0 0 r
F P
0 g
s
.67649 .51522 m .66777 .50342 L .70576 .5024 L p .428 .596 .914 r
F P
0 g
s
.70576 .5024 m .71685 .51061 L .67649 .51522 L p .428 .596 .914 r
F P
0 g
s
.33919 .47709 m .3507 .46839 L .38405 .47148 L p .856 .868 .848 r
F P
0 g
s
.39326 .46122 m .38405 .47148 L .3507 .46839 L p .843 .903 .879 r
F P
0 g
s
.42073 .44009 m .42987 .43647 L .45732 .43274 L p .616 .931 .965 r
F P
0 g
s
.46379 .43018 m .45732 .43274 L .42987 .43647 L p .364 .834 .869 r
F P
0 g
s
.66777 .50342 m .65906 .49266 L .69469 .49488 L p .364 .597 .935 r
F P
0 g
s
.69469 .49488 m .70576 .5024 L .66777 .50342 L p .364 .597 .935 r
F P
0 g
s
.3507 .46839 m .36217 .46082 L .39326 .46122 L p .843 .903 .879 r
F P
0 g
s
.40243 .45252 m .39326 .46122 L .36217 .46082 L p .813 .94 .911 r
F P
0 g
s
.65906 .49266 m .65038 .48306 L .68363 .48812 L p .274 .588 .946 r
F P
0 g
s
.68363 .48812 m .69469 .49488 L .65906 .49266 L p .274 .588 .946 r
F P
0 g
s
.52263 .43078 m .52229 .42993 L .49545 .42809 L p .173 0 0 r
F P
0 g
s
.54646 .43555 m .54935 .43499 L .52229 .42993 L p .272 0 0 r
F P
0 g
s
.60696 .45506 m .61568 .45787 L .60395 .45369 L p .263 0 0 r
F P
0 g
s
.60395 .45369 m .58699 .44766 L p .59844 .4519 L .263 0 0 r
F P
0 g
s
.60696 .45506 m .60395 .45369 L .59844 .4519 L .263 0 0 r
F
.58108 .44447 m .57514 .44302 L .58481 .44747 L p .419 0 0 r
F P
0 g
s
.58481 .44747 m .5982 .45364 L p .5896 .44903 L .419 0 0 r
F P
0 g
s
.58699 .44766 m .58108 .44447 L .60696 .45506 L p .263 0 0 r
F P
0 g
s
.5896 .44903 m .58108 .44447 L .58481 .44747 L .419 0 0 r
F
.36217 .46082 m .37361 .45445 L .40243 .45252 L p .813 .94 .911 r
F P
0 g
s
.41158 .44546 m .40243 .45252 L .37361 .45445 L p .744 .967 .933 r
F P
0 g
s
.46379 .43018 m .47029 .42958 L .49545 .42809 L p .166 .704 .814 r
F P
0 g
s
.49898 .42919 m .49545 .42809 L .47029 .42958 L p .161 0 0 r
F P
0 g
s
.49545 .42809 m .49898 .42919 L .52263 .43078 L p .173 0 0 r
F P
0 g
s
.65038 .48306 m .64171 .47472 L .67257 .4822 L p .145 .557 .927 r
F P
0 g
s
.67257 .4822 m .68363 .48812 L .65038 .48306 L p .145 .557 .927 r
F P
0 g
s
.42987 .43647 m .43904 .43457 L .46379 .43018 L p .364 .834 .869 r
F P
0 g
s
.47029 .42958 m .46379 .43018 L .43904 .43457 L p 0 0 0 r
F P
0 g
s
.56916 .44326 m .57514 .44302 L .54935 .43499 L p .406 0 0 r
F P
0 g
s
.37361 .45445 m .38502 .44936 L .41158 .44546 L p .744 .967 .933 r
F P
0 g
s
.42073 .44009 m .41158 .44546 L .38502 .44936 L p .605 .949 .914 r
F P
0 g
s
.64171 .47472 m .63304 .46771 L .66151 .47717 L p 0 .489 .851 r
F P
0 g
s
.66151 .47717 m .67257 .4822 L .64171 .47472 L p 0 .489 .851 r
F P
0 g
s
.5982 .45364 m .60696 .45506 L .58108 .44447 L p .419 0 0 r
F P
0 g
s
.38502 .44936 m .39509 .44603 L p .42073 .44009 L .605 .949 .914 r
F P
0 g
s
.39824 .44518 m .42073 .44009 L p .39509 .44603 L .605 .949 .914 r
F P
0 g
s
.42987 .43647 m .42073 .44009 L .39642 .44559 L p .37 .837 .804 r
F P
0 g
s
.43904 .43457 m .43244 .43594 L p .40781 .44317 L 0 0 0 r
F P
0 g
s
.43244 .43594 m .42987 .43647 L .425 .43795 L p 0 0 0 r
F P
0 g
s
.425 .43795 m .40781 .44317 L p .43244 .43594 L 0 0 0 r
F P
0 g
s
.39509 .44603 m .39642 .44559 L .39824 .44518 L p .605 .949 .914 r
F P
0 g
s
.63304 .46771 m .62436 .46208 L .65044 .47306 L p 0 .381 .707 r
F P
0 g
s
.62436 .46208 m .61568 .45787 L .63398 .46716 L p .349 0 0 r
F P
0 g
s
.64114 .4704 m .63304 .46771 L p .63976 .46977 L 0 .381 .707 r
F P
0 g
s
.63398 .46716 m .63936 .46988 L p .63502 .46762 L .349 0 0 r
F P
0 g
s
.63502 .46762 m .62436 .46208 L .63398 .46716 L .349 0 0 r
F
.65044 .47306 m .66151 .47717 L .64114 .4704 L p 0 .381 .707 r
F P
0 g
s
.65044 .47306 m .64114 .4704 L .63976 .46977 L 0 .381 .707 r
F
.52296 .43356 m .52263 .43078 L .49898 .42919 L p .387 0 0 r
F P
0 g
s
.52263 .43078 m .52296 .43356 L .54355 .43793 L p .442 0 0 r
F P
0 g
s
.54355 .43793 m .54646 .43555 L .52263 .43078 L p .442 0 0 r
F P
0 g
s
.43904 .43457 m .44824 .43438 L .47029 .42958 L p 0 0 0 r
F P
0 g
s
.47684 .43089 m .47029 .42958 L .44824 .43438 L p .23 0 0 r
F P
0 g
s
.47029 .42958 m .47684 .43089 L .49898 .42919 L p .161 0 0 r
F P
0 g
s
.50254 .43222 m .49898 .42919 L .47684 .43089 L p .371 0 0 r
F P
0 g
s
.49898 .42919 m .50254 .43222 L .52296 .43356 L p .387 0 0 r
F P
0 g
s
.39642 .44559 m .40781 .44317 L .42987 .43647 L p .37 .837 .804 r
F P
0 g
s
.54646 .43555 m .54355 .43793 L .56312 .4451 L p .509 0 0 r
F P
0 g
s
.56312 .4451 m .56916 .44326 L .54646 .43555 L p .509 0 0 r
F P
0 g
s
.63936 .46988 m .65044 .47306 L .62436 .46208 L p .349 0 0 r
F P
0 g
s
.57514 .44302 m .56916 .44326 L .58939 .45354 L p .511 0 0 r
F P
0 g
s
.58939 .45354 m .5982 .45364 L .57514 .44302 L p .511 0 0 r
F P
0 g
s
.61568 .45787 m .60696 .45506 L .62824 .46764 L p .456 0 0 r
F P
0 g
s
.62824 .46764 m .63936 .46988 L .61568 .45787 L p .456 0 0 r
F P
0 g
s
.40781 .44317 m .41923 .44209 L .43904 .43457 L p 0 0 0 r
F P
0 g
s
.44824 .43438 m .43904 .43457 L .41923 .44209 L p .162 0 0 r
F P
0 g
s
.44824 .43438 m .45749 .43583 L .47684 .43089 L p .23 0 0 r
F P
0 g
s
.48345 .434 m .47684 .43089 L .45749 .43583 L p .395 0 0 r
F P
0 g
s
.47684 .43089 m .48345 .434 L .50254 .43222 L p .371 0 0 r
F P
0 g
s
.79464 .57831 m .78355 .5684 L .82346 .53057 L p .615 .679 .887 r
F P
0 g
s
.82346 .53057 m .83625 .53514 L .79464 .57831 L p .615 .679 .887 r
F P
0 g
s
.52331 .43814 m .52296 .43356 L .50254 .43222 L p .498 0 0 r
F P
0 g
s
.52296 .43356 m .52331 .43814 L .5406 .442 L p .528 0 0 r
F P
0 g
s
.5406 .442 m .54355 .43793 L .52296 .43356 L p .528 0 0 r
F P
0 g
s
.78355 .5684 m .77243 .55836 L .81066 .52595 L p .598 .682 .9 r
F P
0 g
s
.81066 .52595 m .82346 .53057 L .78355 .5684 L p .598 .682 .9 r
F P
0 g
s
.77243 .55836 m .76131 .54831 L .79783 .52132 L p .577 .686 .916 r
F P
0 g
s
.79783 .52132 m .81066 .52595 L .77243 .55836 L p .577 .686 .916 r
F P
0 g
s
.76131 .54831 m .75018 .53839 L .785 .51674 L p .549 .692 .933 r
F P
0 g
s
.785 .51674 m .79783 .52132 L .76131 .54831 L p .549 .692 .933 r
F P
0 g
s
.50615 .43704 m .50254 .43222 L .48345 .434 L p .485 0 0 r
F P
0 g
s
.50254 .43222 m .50615 .43704 L .52331 .43814 L p .498 0 0 r
F P
0 g
s
.75018 .53839 m .73906 .52872 L .77216 .51226 L p .513 .697 .952 r
F P
0 g
s
.77216 .51226 m .785 .51674 L .75018 .53839 L p .513 .697 .952 r
F P
0 g
s
.56916 .44326 m .56312 .4451 L .58051 .4547 L p .561 .02 0 r
F P
0 g
s
.58051 .4547 m .58939 .45354 L .56916 .44326 L p .561 .02 0 r
F P
0 g
s
.27445 .48928 m .28773 .48268 L .31601 .49735 L p .857 .884 .857 r
F P
0 g
s
.31601 .49735 m .30435 .50864 L .27445 .48928 L p .857 .884 .857 r
F P
0 g
s
.32762 .48678 m .31601 .49735 L .28773 .48268 L p .85 .911 .875 r
F P
0 g
s
.28773 .48268 m .30098 .47653 L .32762 .48678 L p .85 .911 .875 r
F P
0 g
s
.33919 .47709 m .32762 .48678 L .30098 .47653 L p .834 .939 .895 r
F P
0 g
s
.26112 .49623 m .27445 .48928 L .30435 .50864 L p .858 .861 .842 r
F P
0 g
s
.30435 .50864 m .29265 .5205 L .26112 .49623 L p .858 .861 .842 r
F P
0 g
s
.73906 .52872 m .72795 .51942 L .75932 .50793 L p .464 .701 .97 r
F P
0 g
s
.75932 .50793 m .77216 .51226 L .73906 .52872 L p .464 .701 .97 r
F P
0 g
s
.30098 .47653 m .31418 .47093 L .33919 .47709 L p .834 .939 .895 r
F P
0 g
s
.3507 .46839 m .33919 .47709 L .31418 .47093 L p .8 .965 .912 r
F P
0 g
s
.54355 .43793 m .5406 .442 L .55702 .4484 L p .562 .034 0 r
F P
0 g
s
.55702 .4484 m .56312 .4451 L .54355 .43793 L p .562 .034 0 r
F P
0 g
s
.24777 .50343 m .26112 .49623 L .29265 .5205 L p .855 .84 .83 r
F P
0 g
s
.29265 .5205 m .28091 .53274 L .24777 .50343 L p .855 .84 .83 r
F P
0 g
s
.31418 .47093 m .32734 .46596 L .3507 .46839 L p .8 .965 .912 r
F P
0 g
s
.36217 .46082 m .3507 .46839 L .32734 .46596 L p .736 .978 .918 r
F P
0 g
s
.72795 .51942 m .71685 .51061 L .74647 .50379 L p .397 .698 .981 r
F P
0 g
s
.74647 .50379 m .75932 .50793 L .72795 .51942 L p .397 .698 .981 r
F P
0 g
s
.60696 .45506 m .5982 .45364 L .61708 .46631 L p .522 0 0 r
F P
0 g
s
.61708 .46631 m .62824 .46764 L .60696 .45506 L p .522 0 0 r
F P
0 g
s
.23438 .51075 m .24777 .50343 L .28091 .53274 L p .85 .822 .821 r
F P
0 g
s
.28091 .53274 m .26914 .54519 L .23438 .51075 L p .85 .822 .821 r
F P
0 g
s
.22098 .51809 m .23438 .51075 L .26914 .54519 L p .844 .807 .815 r
F P
0 g
s
.26914 .54519 m .25736 .55765 L .22098 .51809 L p .844 .807 .815 r
F P
0 g
s
.41923 .44209 m .43067 .44233 L .44824 .43438 L p .162 0 0 r
F P
0 g
s
.45749 .43583 m .44824 .43438 L .43067 .44233 L p .331 0 0 r
F P
0 g
s
.71685 .51061 m .70576 .5024 L .73362 .49988 L p .304 .681 .976 r
F P
0 g
s
.73362 .49988 m .74647 .50379 L .71685 .51061 L p .304 .681 .976 r
F P
0 g
s
.32734 .46596 m .34046 .46169 L .36217 .46082 L p .736 .978 .918 r
F P
0 g
s
.37361 .45445 m .36217 .46082 L .34046 .46169 L p .623 .959 .894 r
F P
0 g
s
.20758 .52532 m .22098 .51809 L .25736 .55765 L p .836 .793 .811 r
F P
0 g
s
.25736 .55765 m .24558 .56996 L .20758 .52532 L p .836 .793 .811 r
F P
0 g
s
.70576 .5024 m .69469 .49488 L .72076 .49625 L p .18 .64 .938 r
F P
0 g
s
.72076 .49625 m .73362 .49988 L .70576 .5024 L p .18 .64 .938 r
F P
0 g
s
.34046 .46169 m .35356 .45819 L .37361 .45445 L p .623 .959 .894 r
F P
0 g
s
.38502 .44936 m .37361 .45445 L .35356 .45819 L p .446 .879 .814 r
F P
0 g
s
.69469 .49488 m .68363 .48812 L .7079 .49292 L p .031 .565 .853 r
F P
0 g
s
.7079 .49292 m .72076 .49625 L .69469 .49488 L p .031 .565 .853 r
F P
0 g
s
.45749 .43583 m .46682 .43883 L .48345 .434 L p .395 0 0 r
F P
0 g
s
.49013 .43877 m .48345 .434 L .46682 .43883 L p .491 0 0 r
F P
0 g
s
.48345 .434 m .49013 .43877 L .50615 .43704 L p .485 0 0 r
F P
0 g
s
.35356 .45819 m .36662 .45549 L .38502 .44936 L p .446 .879 .814 r
F P
0 g
s
.39642 .44559 m .38502 .44936 L .36662 .45549 L p 0 0 0 r
F P
0 g
s
.5982 .45364 m .58939 .45354 L .60587 .46585 L p .562 .02 0 r
F P
0 g
s
.60587 .46585 m .61708 .46631 L .5982 .45364 L p .562 .02 0 r
F P
0 g
s
.68363 .48812 m .67257 .4822 L .69503 .48992 L p 0 .459 .721 r
F P
0 g
s
.69503 .48992 m .7079 .49292 L .68363 .48812 L p 0 .459 .721 r
F P
0 g
s
.52366 .44434 m .52331 .43814 L .50615 .43704 L p .557 .052 .01 r
F P
0 g
s
.52331 .43814 m .52366 .44434 L .53761 .44758 L p .573 .068 .017 r
F P
0 g
s
.53761 .44758 m .5406 .442 L .52331 .43814 L p .573 .068 .017 r
F P
0 g
s
.56312 .4451 m .55702 .4484 L .57155 .457 L p .588 .076 0 r
F P
0 g
s
.57155 .457 m .58051 .4547 L .56312 .4451 L p .588 .076 0 r
F P
0 g
s
.43067 .44233 m .44215 .44383 L .45749 .43583 L p .331 0 0 r
F P
0 g
s
.46682 .43883 m .45749 .43583 L .44215 .44383 L p .441 0 0 r
F P
0 g
s
.36662 .45549 m .37967 .45362 L .39642 .44559 L p 0 0 0 r
F P
0 g
s
.40781 .44317 m .39642 .44559 L .37967 .45362 L p .006 0 0 r
F P
0 g
s
.67257 .4822 m .66151 .47717 L .68215 .48727 L p .266 0 0 r
F P
0 g
s
.68215 .48727 m .69503 .48992 L .67257 .4822 L p .266 0 0 r
F P
0 g
s
.50981 .44347 m .50615 .43704 L .49013 .43877 L p .548 .048 .02 r
F P
0 g
s
.50615 .43704 m .50981 .44347 L .52366 .44434 L p .557 .052 .01 r
F P
0 g
s
.5406 .442 m .53761 .44758 L .55083 .45301 L p .59 .091 .037 r
F P
0 g
s
.55083 .45301 m .55702 .4484 L .5406 .442 L p .59 .091 .037 r
F P
0 g
s
.66151 .47717 m .65044 .47306 L .66925 .48499 L p .376 0 0 r
F P
0 g
s
.66925 .48499 m .68215 .48727 L .66151 .47717 L p .376 0 0 r
F P
0 g
s
.37967 .45362 m .39272 .4526 L .40781 .44317 L p .006 0 0 r
F P
0 g
s
.41923 .44209 m .40781 .44317 L .39272 .4526 L p .192 0 0 r
F P
0 g
s
.58939 .45354 m .58051 .4547 L .5946 .46621 L p .586 .069 0 r
F P
0 g
s
.5946 .46621 m .60587 .46585 L .58939 .45354 L p .586 .069 0 r
F P
0 g
s
.46682 .43883 m .47623 .44325 L .49013 .43877 L p .491 0 0 r
F P
0 g
s
.4969 .44503 m .49013 .43877 L .47623 .44325 L p .548 .057 .042 r
F P
0 g
s
.49013 .43877 m .4969 .44503 L .50981 .44347 L p .548 .048 .02 r
F P
0 g
s
.65044 .47306 m .63936 .46988 L .65634 .48308 L p .454 0 0 r
F P
0 g
s
.65634 .48308 m .66925 .48499 L .65044 .47306 L p .454 0 0 r
F P
0 g
s
.39272 .4526 m .40577 .45242 L .41923 .44209 L p .192 0 0 r
F P
0 g
s
.43067 .44233 m .41923 .44209 L .40577 .45242 L p .328 0 0 r
F P
0 g
s
.44215 .44383 m .45371 .44651 L .46682 .43883 L p .441 0 0 r
F P
0 g
s
.47623 .44325 m .46682 .43883 L .45371 .44651 L p .511 .013 .009 r
F P
0 g
s
.55702 .4484 m .55083 .45301 L .56249 .46032 L p .604 .114 .063 r
F P
0 g
s
.56249 .46032 m .57155 .457 L .55702 .4484 L p .604 .114 .063 r
F P
0 g
s
.63936 .46988 m .62824 .46764 L .6434 .48154 L p .508 0 0 r
F P
0 g
s
.6434 .48154 m .65634 .48308 L .63936 .46988 L p .508 0 0 r
F P
0 g
s
.52401 .45194 m .52366 .44434 L .50981 .44347 L p .59 .109 .081 r
F P
0 g
s
.52366 .44434 m .52401 .45194 L .53457 .45448 L p .598 .117 .084 r
F P
0 g
s
.53457 .45448 m .53761 .44758 L .52366 .44434 L p .598 .117 .084 r
F P
0 g
s
.58051 .4547 m .57155 .457 L .58326 .46732 L p .601 .104 .046 r
F P
0 g
s
.58326 .46732 m .5946 .46621 L .58051 .4547 L p .601 .104 .046 r
F P
0 g
s
.40577 .45242 m .41883 .45307 L .43067 .44233 L p .328 0 0 r
F P
0 g
s
.44215 .44383 m .43067 .44233 L .41883 .45307 L p .424 0 0 r
F P
0 g
s
.51353 .4513 m .50981 .44347 L .4969 .44503 L p .584 .106 .085 r
F P
0 g
s
.50981 .44347 m .51353 .4513 L .52401 .45194 L p .59 .109 .081 r
F P
0 g
s
.53761 .44758 m .53457 .45448 L .54456 .45875 L p .606 .128 .094 r
F P
0 g
s
.54456 .45875 m .55083 .45301 L .53761 .44758 L p .606 .128 .094 r
F P
0 g
s
.62824 .46764 m .61708 .46631 L .63043 .48036 L p .544 .009 0 r
F P
0 g
s
.63043 .48036 m .6434 .48154 L .62824 .46764 L p .544 .009 0 r
F P
0 g
s
.45371 .44651 m .46533 .45029 L .47623 .44325 L p .511 .013 .009 r
F P
0 g
s
.48574 .44895 m .47623 .44325 L .46533 .45029 L p .557 .075 .068 r
F P
0 g
s
.47623 .44325 m .48574 .44895 L .4969 .44503 L p .548 .057 .042 r
F P
0 g
s
.50378 .45258 m .4969 .44503 L .48574 .44895 L p .583 .11 .096 r
F P
0 g
s
.4969 .44503 m .50378 .45258 L .51353 .4513 L p .584 .106 .085 r
F P
0 g
s
.41883 .45307 m .43192 .4545 L .44215 .44383 L p .424 0 0 r
F P
0 g
s
.45371 .44651 m .44215 .44383 L .43192 .4545 L p .491 0 0 r
F P
0 g
s
.61708 .46631 m .60587 .46585 L .61743 .47952 L p .569 .054 0 r
F P
0 g
s
.61743 .47952 m .63043 .48036 L .61708 .46631 L p .569 .054 0 r
F P
0 g
s
.55083 .45301 m .54456 .45875 L .55333 .46451 L p .613 .14 .106 r
F P
0 g
s
.55333 .46451 m .56249 .46032 L .55083 .45301 L p .613 .14 .106 r
F P
0 g
s
.57155 .457 m .56249 .46032 L .57183 .46909 L p .61 .129 .089 r
F P
0 g
s
.57183 .46909 m .58326 .46732 L .57155 .457 L p .61 .129 .089 r
F P
0 g
s
.83625 .53514 m .82346 .53057 L .84534 .48721 L p .695 .799 .929 r
F P
0 g
s
.84534 .48721 m .85906 .48583 L .83625 .53514 L p .695 .799 .929 r
F P
0 g
s
.82346 .53057 m .81066 .52595 L .83161 .48862 L p .683 .816 .946 r
F P
0 g
s
.83161 .48862 m .84534 .48721 L .82346 .53057 L p .683 .816 .946 r
F P
0 g
s
.43192 .4545 m .44504 .45666 L .45371 .44651 L p .491 0 0 r
F P
0 g
s
.46533 .45029 m .45371 .44651 L .44504 .45666 L p .538 .052 .052 r
F P
0 g
s
.60587 .46585 m .5946 .46621 L .60439 .479 L p .587 .089 .038 r
F P
0 g
s
.60439 .479 m .61743 .47952 L .60587 .46585 L p .587 .089 .038 r
F P
0 g
s
.81066 .52595 m .79783 .52132 L .81786 .49003 L p .664 .833 .965 r
F P
0 g
s
.81786 .49003 m .83161 .48862 L .81066 .52595 L p .664 .833 .965 r
F P
0 g
s
.52437 .46069 m .52401 .45194 L .51353 .4513 L p .608 .144 .125 r
F P
0 g
s
.52401 .45194 m .52437 .46069 L .53148 .46244 L p .612 .147 .126 r
F P
0 g
s
.53148 .46244 m .53457 .45448 L .52401 .45194 L p .612 .147 .126 r
F P
0 g
s
.79783 .52132 m .785 .51674 L .80409 .4914 L p .635 .85 .982 r
F P
0 g
s
.80409 .4914 m .81786 .49003 L .79783 .52132 L p .635 .85 .982 r
F P
0 g
s
.51731 .46026 m .51353 .4513 L .50378 .45258 L p .606 .142 .127 r
F P
0 g
s
.51353 .4513 m .51731 .46026 L .52437 .46069 L p .608 .144 .125 r
F P
0 g
s
.2881 .46597 m .30215 .46508 L .31418 .47093 L p .647 .953 .944 r
F P
0 g
s
.31418 .47093 m .30098 .47653 L .2881 .46597 L p .647 .953 .944 r
F P
0 g
s
.32734 .46596 m .31418 .47093 L .30215 .46508 L p .538 .923 .908 r
F P
0 g
s
.46533 .45029 m .47706 .45502 L .48574 .44895 L p .557 .075 .068 r
F P
0 g
s
.49538 .45574 m .48574 .44895 L .47706 .45502 L p .587 .119 .109 r
F P
0 g
s
.48574 .44895 m .49538 .45574 L .50378 .45258 L p .583 .11 .096 r
F P
0 g
s
.27403 .46703 m .2881 .46597 L .30098 .47653 L p .717 .952 .951 r
F P
0 g
s
.30098 .47653 m .28773 .48268 L .27403 .46703 L p .717 .952 .951 r
F P
0 g
s
.30215 .46508 m .31617 .46438 L .32734 .46596 L p .538 .923 .908 r
F P
0 g
s
.34046 .46169 m .32734 .46596 L .31617 .46438 L p .385 .847 .829 r
F P
0 g
s
.785 .51674 m .77216 .51226 L .7903 .49271 L p .59 .861 .994 r
F P
0 g
s
.7903 .49271 m .80409 .4914 L .785 .51674 L p .59 .861 .994 r
F P
0 g
s
.25993 .46822 m .27403 .46703 L .28773 .48268 L p .759 .936 .943 r
F P
0 g
s
.28773 .48268 m .27445 .48928 L .25993 .46822 L p .759 .936 .943 r
F P
0 g
s
.31617 .46438 m .33017 .46389 L p .33178 .46266 L .385 .847 .829 r
F P
0 g
s
.33017 .46389 m .31617 .46438 L .31899 .46384 L p .04 .61 .722 r
F P
0 g
s
.31899 .46384 m .32745 .46598 L p .33017 .46389 L .04 .61 .722 r
F P
0 g
s
.32745 .46598 m .33293 .46737 L .33017 .46389 L p .04 .61 .722 r
F P
0 g
s
.33017 .46389 m .34046 .46169 L p .33178 .46266 L .385 .847 .829 r
F P
0 g
s
.35356 .45819 m .34046 .46169 L .33017 .46389 L p .202 .723 .703 r
F P
0 g
s
.53457 .45448 m .53148 .46244 L .53819 .4654 L p .615 .152 .13 r
F P
0 g
s
.53819 .4654 m .54456 .45875 L .53457 .45448 L p .615 .152 .13 r
F P
0 g
s
.24581 .46951 m .25993 .46822 L .27445 .48928 L p .783 .914 .928 r
F P
0 g
s
.27445 .48928 m .26112 .49623 L .24581 .46951 L p .783 .914 .928 r
F P
0 g
s
.77216 .51226 m .75932 .50793 L .77649 .49392 L p .523 .86 .994 r
F P
0 g
s
.77649 .49392 m .7903 .49271 L .77216 .51226 L p .523 .86 .994 r
F P
0 g
s
.33017 .46389 m .34415 .46363 L .35356 .45819 L p .202 .723 .703 r
F P
0 g
s
.36662 .45549 m .35356 .45819 L .34415 .46363 L p 0 0 0 r
F P
0 g
s
.23166 .47088 m .24581 .46951 L .26112 .49623 L p .795 .89 .913 r
F P
0 g
s
.26112 .49623 m .24777 .50343 L .23166 .47088 L p .795 .89 .913 r
F P
0 g
s
.75932 .50793 m .74647 .50379 L .76265 .49499 L p .428 .838 .971 r
F P
0 g
s
.76265 .49499 m .77649 .49392 L .75932 .50793 L p .428 .838 .971 r
F P
0 g
s
.21749 .47228 m .23166 .47088 L .24777 .50343 L p .799 .867 .898 r
F P
0 g
s
.24777 .50343 m .23438 .51075 L .21749 .47228 L p .799 .867 .898 r
F P
0 g
s
.34415 .46363 m .3581 .46362 L .36662 .45549 L p 0 0 0 r
F P
0 g
s
.37967 .45362 m .36662 .45549 L .3581 .46362 L p .146 0 0 r
F P
0 g
s
.74647 .50379 m .73362 .49988 L .74878 .4959 L p .301 .784 .911 r
F P
0 g
s
.74878 .4959 m .76265 .49499 L .74647 .50379 L p .301 .784 .911 r
F P
0 g
s
.20331 .47369 m .21749 .47228 L .23438 .51075 L p .799 .845 .886 r
F P
0 g
s
.23438 .51075 m .22098 .51809 L .20331 .47369 L p .799 .845 .886 r
F P
0 g
s
.56249 .46032 m .55333 .46451 L .56031 .4714 L p .616 .147 .119 r
F P
0 g
s
.56031 .4714 m .57183 .46909 L .56249 .46032 L p .616 .147 .119 r
F P
0 g
s
.51076 .46119 m .50378 .45258 L .49538 .45574 L p .605 .144 .131 r
F P
0 g
s
.50378 .45258 m .51076 .46119 L .51731 .46026 L p .606 .142 .127 r
F P
0 g
s
.5946 .46621 m .58326 .46732 L .59131 .47876 L p .599 .115 .077 r
F P
0 g
s
.59131 .47876 m .60439 .479 L .5946 .46621 L p .599 .115 .077 r
F P
0 g
s
.3581 .46362 m .37204 .46385 L .37967 .45362 L p .146 0 0 r
F P
0 g
s
.39272 .4526 m .37967 .45362 L .37204 .46385 L p .274 0 0 r
F P
0 g
s
.73362 .49988 m .72076 .49625 L .73489 .49661 L p .15 .692 .809 r
F P
0 g
s
.73489 .49661 m .74878 .4959 L .73362 .49988 L p .15 .692 .809 r
F P
0 g
s
.18911 .47507 m .20331 .47369 L .22098 .51809 L p .795 .826 .875 r
F P
0 g
s
.22098 .51809 m .20758 .52532 L .18911 .47507 L p .795 .826 .875 r
F P
0 g
s
.44504 .45666 m .45822 .4595 L .46533 .45029 L p .538 .052 .052 r
F P
0 g
s
.47706 .45502 m .46533 .45029 L .45822 .4595 L p .571 .097 .092 r
F P
0 g
s
.72076 .49625 m .7079 .49292 L .72097 .49711 L p .007 0 0 r
F P
0 g
s
.72097 .49711 m .73489 .49661 L .72076 .49625 L p .007 0 0 r
F P
0 g
s
.54456 .45875 m .53819 .4654 L .54405 .46939 L p .618 .157 .135 r
F P
0 g
s
.54405 .46939 m .55333 .46451 L .54456 .45875 L p .618 .157 .135 r
F P
0 g
s
.37204 .46385 m .38596 .46434 L .39272 .4526 L p .274 0 0 r
F P
0 g
s
.40577 .45242 m .39272 .4526 L .38596 .46434 L p .371 0 0 r
F P
0 g
s
.7079 .49292 m .69503 .48992 L .70703 .49738 L p .15 0 0 r
F P
0 g
s
.70703 .49738 m .72097 .49711 L .7079 .49292 L p .15 0 0 r
F P
0 g
s
.38596 .46434 m .39987 .46508 L .40577 .45242 L p .371 0 0 r
F P
0 g
s
.41883 .45307 m .40577 .45242 L .39987 .46508 L p .443 0 0 r
F P
0 g
s
.69503 .48992 m .68215 .48727 L .69308 .49741 L p .268 0 0 r
F P
0 g
s
.69308 .49741 m .70703 .49738 L .69503 .48992 L p .268 0 0 r
F P
0 g
s
.58326 .46732 m .57183 .46909 L .57818 .47878 L p .608 .135 .107 r
F P
0 g
s
.57818 .47878 m .59131 .47876 L .58326 .46732 L p .608 .135 .107 r
F P
0 g
s
.47706 .45502 m .48888 .46058 L .49538 .45574 L p .587 .119 .109 r
F P
0 g
s
.50515 .46341 m .49538 .45574 L .48888 .46058 L p .606 .147 .136 r
F P
0 g
s
.49538 .45574 m .50515 .46341 L .51076 .46119 L p .605 .144 .131 r
F P
0 g
s
.68215 .48727 m .66925 .48499 L .6791 .49718 L p .359 0 0 r
F P
0 g
s
.6791 .49718 m .69308 .49741 L .68215 .48727 L p .359 0 0 r
F P
0 g
s
.39987 .46508 m .41378 .46607 L .41883 .45307 L p .443 0 0 r
F P
0 g
s
.43192 .4545 m .41883 .45307 L .41378 .46607 L p .496 0 0 r
F P
0 g
s
.45822 .4595 m .47145 .46292 L .47706 .45502 L p .571 .097 .092 r
F P
0 g
s
.48888 .46058 m .47706 .45502 L .47145 .46292 L p .594 .13 .121 r
F P
0 g
s
.66925 .48499 m .65634 .48308 L .66511 .49669 L p .428 0 0 r
F P
0 g
s
.66511 .49669 m .6791 .49718 L .66925 .48499 L p .428 0 0 r
F P
0 g
s
.55333 .46451 m .54405 .46939 L .54868 .47416 L p .619 .16 .141 r
F P
0 g
s
.54868 .47416 m .56031 .4714 L .55333 .46451 L p .619 .16 .141 r
F P
0 g
s
.52474 .4703 m .52437 .46069 L .51731 .46026 L p .619 .164 .15 r
F P
0 g
s
.52437 .46069 m .52474 .4703 L .52833 .4712 L p .62 .165 .15 r
F P
0 g
s
.52833 .4712 m .53148 .46244 L .52437 .46069 L p .62 .165 .15 r
F P
0 g
s
.52118 .47009 m .51731 .46026 L .51076 .46119 L p .618 .163 .151 r
F P
0 g
s
.51731 .46026 m .52118 .47009 L .52474 .4703 L p .619 .164 .15 r
F P
0 g
s
.41378 .46607 m .42768 .46729 L .43192 .4545 L p .496 0 0 r
F P
0 g
s
.44504 .45666 m .43192 .4545 L .42768 .46729 L p .535 .046 .041 r
F P
0 g
s
.65634 .48308 m .6434 .48154 L .6511 .49594 L p .48 0 0 r
F P
0 g
s
.6511 .49594 m .66511 .49669 L .65634 .48308 L p .48 0 0 r
F P
0 g
s
.53148 .46244 m .52833 .4712 L .53171 .47272 L p .621 .166 .151 r
F P
0 g
s
.53171 .47272 m .53819 .4654 L .53148 .46244 L p .621 .166 .151 r
F P
0 g
s
.57183 .46909 m .56031 .4714 L .565 .47901 L p .614 .15 .129 r
F P
0 g
s
.565 .47901 m .57818 .47878 L .57183 .46909 L p .614 .15 .129 r
F P
0 g
s
.51787 .47058 m .51076 .46119 L .50515 .46341 L p .618 .164 .152 r
F P
0 g
s
.51076 .46119 m .51787 .47058 L .52118 .47009 L p .618 .163 .151 r
F P
0 g
s
.6434 .48154 m .63043 .48036 L .63709 .49494 L p .518 .003 0 r
F P
0 g
s
.63709 .49494 m .6511 .49594 L .6434 .48154 L p .518 .003 0 r
F P
0 g
s
.42768 .46729 m .44157 .46873 L .44504 .45666 L p .535 .046 .041 r
F P
0 g
s
.45822 .4595 m .44504 .45666 L .44157 .46873 L p .564 .086 .079 r
F P
0 g
s
.53819 .4654 m .53171 .47272 L .53465 .47478 L p .621 .168 .153 r
F P
0 g
s
.53465 .47478 m .54405 .46939 L .53819 .4654 L p .621 .168 .153 r
F P
0 g
s
.47145 .46292 m .48475 .46683 L .48888 .46058 L p .594 .13 .121 r
F P
0 g
s
.50083 .4668 m .48888 .46058 L .48475 .46683 L p .609 .152 .142 r
F P
0 g
s
.48888 .46058 m .50083 .4668 L .50515 .46341 L p .606 .147 .136 r
F P
0 g
s
.63043 .48036 m .61743 .47952 L .62308 .49371 L p .548 .048 .02 r
F P
0 g
s
.62308 .49371 m .63709 .49494 L .63043 .48036 L p .548 .048 .02 r
F P
0 g
s
.51505 .47174 m .50515 .46341 L .50083 .4668 L p .618 .165 .153 r
F P
0 g
s
.50515 .46341 m .51505 .47174 L .51787 .47058 L p .618 .164 .152 r
F P
0 g
s
.44157 .46873 m .45548 .47036 L .45822 .4595 L p .564 .086 .079 r
F P
0 g
s
.47145 .46292 m .45822 .4595 L .45548 .47036 L p .586 .117 .108 r
F P
0 g
s
.61743 .47952 m .60439 .479 L .60906 .49226 L p .57 .083 .059 r
F P
0 g
s
.60906 .49226 m .62308 .49371 L .61743 .47952 L p .57 .083 .059 r
F P
0 g
s
.56031 .4714 m .54868 .47416 L .55176 .4794 L p .619 .161 .145 r
F P
0 g
s
.55176 .4794 m .565 .47901 L .56031 .4714 L p .619 .161 .145 r
F P
0 g
s
.54405 .46939 m .53465 .47478 L .53695 .47723 L p .622 .168 .154 r
F P
0 g
s
.53695 .47723 m .54868 .47416 L .54405 .46939 L p .622 .168 .154 r
F P
0 g
s
.60439 .479 m .59131 .47876 L .59505 .49061 L p .587 .11 .09 r
F P
0 g
s
.59505 .49061 m .60906 .49226 L .60439 .479 L p .587 .11 .09 r
F P
0 g
s
.45548 .47036 m .46938 .47216 L .47145 .46292 L p .586 .117 .108 r
F P
0 g
s
.48475 .46683 m .47145 .46292 L .46938 .47216 L p .602 .14 .13 r
F P
0 g
s
.48475 .46683 m .49812 .47114 L .50083 .4668 L p .609 .152 .142 r
F P
0 g
s
.51291 .47349 m .50083 .4668 L .49812 .47114 L p .619 .166 .155 r
F P
0 g
s
.50083 .4668 m .51291 .47349 L .51505 .47174 L p .618 .165 .153 r
F P
0 g
s
.59131 .47876 m .57818 .47878 L .58104 .4888 L p .6 .132 .114 r
F P
0 g
s
.58104 .4888 m .59505 .49061 L .59131 .47876 L p .6 .132 .114 r
F P
0 g
s
.52511 .48046 m .52474 .4703 L .52118 .47009 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .52833 .4712 L .52474 .4703 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .52118 .47009 L .51787 .47058 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53171 .47272 L .52833 .4712 L closepath p .623 .173 .162 r
F P
0 g
s
.54868 .47416 m .53695 .47723 L .53847 .4799 L p .622 .169 .156 r
F P
0 g
s
.53847 .4799 m .55176 .4794 L .54868 .47416 L p .622 .169 .156 r
F P
0 g
s
.46938 .47216 m .4833 .47411 L .48475 .46683 L p .602 .14 .13 r
F P
0 g
s
.49812 .47114 m .48475 .46683 L .4833 .47411 L p .613 .157 .145 r
F P
0 g
s
.52511 .48046 m .51787 .47058 L .51505 .47174 L closepath p .623 .173 .162 r
F P
0 g
s
.57818 .47878 m .565 .47901 L .56704 .48684 L p .609 .148 .133 r
F P
0 g
s
.56704 .48684 m .58104 .4888 L .57818 .47878 L p .609 .148 .133 r
F P
0 g
s
.52511 .48046 m .53465 .47478 L .53171 .47272 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .51505 .47174 L .51291 .47349 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53695 .47723 L .53465 .47478 L closepath p .623 .173 .162 r
F P
0 g
s
.565 .47901 m .55176 .4794 L .55305 .48477 L p .616 .16 .147 r
F P
0 g
s
.55305 .48477 m .56704 .48684 L .565 .47901 L p .616 .16 .147 r
F P
0 g
s
.4833 .47411 m .49723 .47616 L .49812 .47114 L p .613 .157 .145 r
F P
0 g
s
.51158 .47572 m .49812 .47114 L .49723 .47616 L p .62 .167 .156 r
F P
0 g
s
.49812 .47114 m .51158 .47572 L .51291 .47349 L p .619 .166 .155 r
F P
0 g
s
.52511 .48046 m .51291 .47349 L .51158 .47572 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53847 .4799 L .53695 .47723 L closepath p .623 .173 .162 r
F P
0 g
s
.55176 .4794 m .53847 .4799 L .53908 .48264 L p .621 .168 .156 r
F P
0 g
s
.53908 .48264 m .55305 .48477 L .55176 .4794 L p .621 .168 .156 r
F P
0 g
s
.49723 .47616 m .51116 .47829 L .51158 .47572 L p .62 .167 .156 r
F P
0 g
s
.52511 .48046 m .51158 .47572 L .51116 .47829 L closepath p .623 .173 .162 r
F P
0 g
s
.85906 .48583 m .84534 .48721 L .84611 .44075 L p .8 .865 .897 r
F P
0 g
s
.84611 .44075 m .85986 .43317 L .85906 .48583 L p .8 .865 .897 r
F P
0 g
s
.37468 .47574 m .38856 .47774 L .38596 .46434 L p .417 0 0 r
F P
0 g
s
.38596 .46434 m .37204 .46385 L .37468 .47574 L p .417 0 0 r
F P
0 g
s
.39987 .46508 m .38596 .46434 L .38856 .47774 L p .473 0 0 r
F P
0 g
s
.38856 .47774 m .40242 .47935 L .39987 .46508 L p .473 0 0 r
F P
0 g
s
.41378 .46607 m .39987 .46508 L .40242 .47935 L p .514 0 0 r
F P
0 g
s
.36078 .47334 m .37468 .47574 L .37204 .46385 L p .342 0 0 r
F P
0 g
s
.37204 .46385 m .3581 .46362 L .36078 .47334 L p .342 0 0 r
F P
0 g
s
.40242 .47935 m .41624 .48058 L .41378 .46607 L p .514 0 0 r
F P
0 g
s
.42768 .46729 m .41378 .46607 L .41624 .48058 L p .545 .044 .015 r
F P
0 g
s
.34686 .47055 m .36078 .47334 L .3581 .46362 L p .242 0 0 r
F P
0 g
s
.3581 .46362 m .34415 .46363 L .34686 .47055 L p .242 0 0 r
F P
0 g
s
.41624 .48058 m .43002 .48144 L .42768 .46729 L p .545 .044 .015 r
F P
0 g
s
.44157 .46873 m .42768 .46729 L .43002 .48144 L p .569 .08 .056 r
F P
0 g
s
.33293 .46737 m .34686 .47055 L .34415 .46363 L p .113 0 0 r
F P
0 g
s
.34415 .46363 m .33017 .46389 L .33293 .46737 L p .113 0 0 r
F P
0 g
s
.84534 .48721 m .83161 .48862 L .83235 .44846 L p .802 .889 .907 r
F P
0 g
s
.83235 .44846 m .84611 .44075 L .84534 .48721 L p .802 .889 .907 r
F P
0 g
s
.43002 .48144 m .44377 .48197 L .44157 .46873 L p .569 .08 .056 r
F P
0 g
s
.45548 .47036 m .44157 .46873 L .44377 .48197 L p .586 .109 .089 r
F P
0 g
s
.52511 .48046 m .53908 .48264 L .53847 .4799 L closepath p .623 .173 .162 r
F P
0 g
s
.44377 .48197 m .45746 .4822 L .45548 .47036 L p .586 .109 .089 r
F P
0 g
s
.46938 .47216 m .45548 .47036 L .45746 .4822 L p .599 .131 .114 r
F P
0 g
s
.30504 .45997 m .31899 .46384 L .31617 .46438 L p .202 .726 .851 r
F P
0 g
s
.31617 .46438 m .30215 .46508 L .30504 .45997 L p .202 .726 .851 r
F P
0 g
s
.83161 .48862 m .81786 .49003 L .81857 .45617 L p .797 .913 .918 r
F P
0 g
s
.81857 .45617 m .83235 .44846 L .83161 .48862 L p .797 .913 .918 r
F P
0 g
s
.45746 .4822 m .4711 .48218 L .46938 .47216 L p .599 .131 .114 r
F P
0 g
s
.4833 .47411 m .46938 .47216 L .4711 .48218 L p .609 .148 .133 r
F P
0 g
s
.29108 .45581 m .30504 .45997 L .30215 .46508 L p .35 .806 .94 r
F P
0 g
s
.30215 .46508 m .2881 .46597 L .29108 .45581 L p .35 .806 .94 r
F P
0 g
s
.4711 .48218 m .48469 .48194 L .4833 .47411 L p .609 .148 .133 r
F P
0 g
s
.49723 .47616 m .4833 .47411 L .48469 .48194 L p .616 .16 .147 r
F P
0 g
s
.81786 .49003 m .80409 .4914 L .80477 .46376 L p .785 .936 .929 r
F P
0 g
s
.80477 .46376 m .81857 .45617 L .81786 .49003 L p .785 .936 .929 r
F P
0 g
s
.27712 .45138 m .29108 .45581 L .2881 .46597 L p .468 .848 .985 r
F P
0 g
s
.2881 .46597 m .27403 .46703 L .27712 .45138 L p .468 .848 .985 r
F P
0 g
s
.48469 .48194 m .49823 .48154 L .49723 .47616 L p .616 .16 .147 r
F P
0 g
s
.51116 .47829 m .49723 .47616 L .49823 .48154 L p .621 .168 .156 r
F P
0 g
s
.80409 .4914 m .7903 .49271 L .79092 .47112 L p .759 .955 .937 r
F P
0 g
s
.79092 .47112 m .80477 .46376 L .80409 .4914 L p .759 .955 .937 r
F P
0 g
s
.26316 .44675 m .27712 .45138 L .27403 .46703 L p .553 .86 .997 r
F P
0 g
s
.27403 .46703 m .25993 .46822 L .26316 .44675 L p .553 .86 .997 r
F P
0 g
s
.49823 .48154 m .5117 .48103 L .51116 .47829 L p .621 .168 .156 r
F P
0 g
s
.52511 .48046 m .51116 .47829 L .5117 .48103 L closepath p .623 .173 .162 r
F P
0 g
s
.24919 .44195 m .26316 .44675 L .25993 .46822 L p .611 .854 .99 r
F P
0 g
s
.25993 .46822 m .24581 .46951 L .24919 .44195 L p .611 .854 .99 r
F P
0 g
s
.52511 .48046 m .53533 .48933 L .53746 .48752 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53249 .49054 L .53533 .48933 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .52913 .49105 L .53249 .49054 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .5255 .49084 L .52913 .49105 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .52184 .48992 L .5255 .49084 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .51841 .48834 L .52184 .48992 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .51545 .48623 L .51841 .48834 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .51316 .48373 L .51545 .48623 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .5117 .48103 L .51316 .48373 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53874 .48523 L .53908 .48264 L closepath p .623 .173 .162 r
F P
0 g
s
.52511 .48046 m .53746 .48752 L .53874 .48523 L closepath p .623 .173 .162 r
F P
0 g
s
.7903 .49271 m .77649 .49392 L .77704 .47812 L p .715 .966 .937 r
F P
0 g
s
.77704 .47812 m .79092 .47112 L .7903 .49271 L p .715 .966 .937 r
F P
0 g
s
.55305 .48477 m .53908 .48264 L .53874 .48523 L p .62 .167 .156 r
F P
0 g
s
.77649 .49392 m .76265 .49499 L .7631 .48464 L p .645 .961 .922 r
F P
0 g
s
.7631 .48464 m .77704 .47812 L .77649 .49392 L p .645 .961 .922 r
F P
0 g
s
.23521 .43703 m .24919 .44195 L .24581 .46951 L p .649 .84 .974 r
F P
0 g
s
.24581 .46951 m .23166 .47088 L .23521 .43703 L p .649 .84 .974 r
F P
0 g
s
.56704 .48684 m .55305 .48477 L .55244 .48991 L p .613 .157 .146 r
F P
0 g
s
.53874 .48523 m .55244 .48991 L .55305 .48477 L p .62 .167 .156 r
F P
0 g
s
.76265 .49499 m .74878 .4959 L .74912 .49059 L p .542 .927 .882 r
F P
0 g
s
.74912 .49059 m .7631 .48464 L .76265 .49499 L p .542 .927 .882 r
F P
0 g
s
.22122 .43206 m .23521 .43703 L .23166 .47088 L p .674 .823 .955 r
F P
0 g
s
.23166 .47088 m .21749 .47228 L .22122 .43206 L p .674 .823 .955 r
F P
0 g
s
.58104 .4888 m .56704 .48684 L .56624 .49435 L p .602 .141 .131 r
F P
0 g
s
.55244 .48991 m .56624 .49435 L .56704 .48684 L p .613 .157 .146 r
F P
0 g
s
.74878 .4959 m .73489 .49661 L .7351 .49586 L p .403 .855 .806 r
F P
0 g
s
.7351 .49586 m .74912 .49059 L .74878 .4959 L p .403 .855 .806 r
F P
0 g
s
.59505 .49061 m .58104 .4888 L .58011 .49845 L p .587 .12 .111 r
F P
0 g
s
.56624 .49435 m .58011 .49845 L .58104 .4888 L p .602 .141 .131 r
F P
0 g
s
.20721 .42708 m .22122 .43206 L .21749 .47228 L p .689 .805 .937 r
F P
0 g
s
.21749 .47228 m .20331 .47369 L .20721 .42708 L p .689 .805 .937 r
F P
0 g
s
.73489 .49661 m .72097 .49711 L .72103 .50038 L p .238 .744 .696 r
F P
0 g
s
.72103 .50038 m .7351 .49586 L .73489 .49661 L p .238 .744 .696 r
F P
0 g
s
.60906 .49226 m .59505 .49061 L .59405 .50207 L p .567 .091 .085 r
F P
0 g
s
.58011 .49845 m .59405 .50207 L .59505 .49061 L p .587 .12 .111 r
F P
0 g
s
.50109 .48689 m .51316 .48373 L .5117 .48103 L p .622 .169 .156 r
F P
0 g
s
.5117 .48103 m .49823 .48154 L .50109 .48689 L p .622 .169 .156 r
F P
0 g
s
.72097 .49711 m .70703 .49738 L .70693 .50407 L p 0 0 0 r
F P
0 g
s
.70693 .50407 m .72103 .50038 L .72097 .49711 L p 0 0 0 r
F P
0 g
s
.62308 .49371 m .60906 .49226 L .60805 .50512 L p .54 .054 .052 r
F P
0 g
s
.59405 .50207 m .60805 .50512 L .60906 .49226 L p .567 .091 .085 r
F P
0 g
s
.19318 .42214 m .20721 .42708 L .20331 .47369 L p .699 .789 .92 r
F P
0 g
s
.20331 .47369 m .18911 .47507 L .19318 .42214 L p .699 .789 .92 r
F P
0 g
s
.70703 .49738 m .69308 .49741 L .6928 .50689 L p .087 0 0 r
F P
0 g
s
.6928 .50689 m .70693 .50407 L .70703 .49738 L p .087 0 0 r
F P
0 g
s
.63709 .49494 m .62308 .49371 L .62211 .50749 L p .504 .007 .009 r
F P
0 g
s
.60805 .50512 m .62211 .50749 L .62308 .49371 L p .54 .054 .052 r
F P
0 g
s
.69308 .49741 m .6791 .49718 L .67865 .5088 L p .216 0 0 r
F P
0 g
s
.67865 .5088 m .6928 .50689 L .69308 .49741 L p .216 0 0 r
F P
0 g
s
.6511 .49594 m .63709 .49494 L .63621 .5091 L p .458 0 0 r
F P
0 g
s
.62211 .50749 m .63621 .5091 L .63709 .49494 L p .504 .007 .009 r
F P
0 g
s
.6791 .49718 m .66511 .49669 L .66449 .5098 L p .319 0 0 r
F P
0 g
s
.66449 .5098 m .67865 .5088 L .6791 .49718 L p .319 0 0 r
F P
0 g
s
.66511 .49669 m .6511 .49594 L .65034 .50989 L p .398 0 0 r
F P
0 g
s
.63621 .5091 m .65034 .50989 L .6511 .49594 L p .458 0 0 r
F P
0 g
s
.65034 .50989 m .66449 .5098 L .66511 .49669 L p .398 0 0 r
F P
0 g
s
.55244 .48991 m .53874 .48523 L .53746 .48752 L p .619 .166 .155 r
F P
0 g
s
.48891 .48979 m .50109 .48689 L .49823 .48154 L p .619 .162 .145 r
F P
0 g
s
.49823 .48154 m .48469 .48194 L .48891 .48979 L p .619 .162 .145 r
F P
0 g
s
.50564 .49185 m .51545 .48623 L .51316 .48373 L p .622 .169 .155 r
F P
0 g
s
.51316 .48373 m .50109 .48689 L .50564 .49185 L p .622 .169 .155 r
F P
0 g
s
.53746 .48752 m .54995 .49444 L .55244 .48991 L p .619 .166 .155 r
F P
0 g
s
.54995 .49444 m .53746 .48752 L .53533 .48933 L p .618 .165 .153 r
F P
0 g
s
.56624 .49435 m .55244 .48991 L .54995 .49444 L p .609 .153 .142 r
F P
0 g
s
.47661 .49228 m .48891 .48979 L .48469 .48194 L p .614 .151 .129 r
F P
0 g
s
.48469 .48194 m .4711 .48218 L .47661 .49228 L p .614 .151 .129 r
F P
0 g
s
.51158 .49607 m .51841 .48834 L .51545 .48623 L p .622 .168 .153 r
F P
0 g
s
.51545 .48623 m .50564 .49185 L .51158 .49607 L p .622 .168 .153 r
F P
0 g
s
.53533 .48933 m .5457 .49805 L .54995 .49444 L p .618 .165 .153 r
F P
0 g
s
.5457 .49805 m .53533 .48933 L .53249 .49054 L p .618 .164 .152 r
F P
0 g
s
.51849 .49922 m .52184 .48992 L .51841 .48834 L p .621 .166 .152 r
F P
0 g
s
.51841 .48834 m .51158 .49607 L .51849 .49922 L p .621 .166 .152 r
F P
0 g
s
.46422 .49423 m .47661 .49228 L .4711 .48218 L p .608 .136 .108 r
F P
0 g
s
.4711 .48218 m .45746 .4822 L .46422 .49423 L p .608 .136 .108 r
F P
0 g
s
.53249 .49054 m .54 .50047 L .5457 .49805 L p .618 .164 .152 r
F P
0 g
s
.54 .50047 m .53249 .49054 L .52913 .49105 L p .618 .164 .151 r
F P
0 g
s
.58011 .49845 m .56624 .49435 L .56257 .50102 L p .595 .131 .124 r
F P
0 g
s
.54995 .49444 m .56257 .50102 L .56624 .49435 L p .609 .153 .142 r
F P
0 g
s
.4957 .4971 m .50564 .49185 L .50109 .48689 L p .619 .161 .141 r
F P
0 g
s
.50109 .48689 m .48891 .48979 L .4957 .4971 L p .619 .161 .141 r
F P
0 g
s
.52589 .50108 m .5255 .49084 L .52184 .48992 L p .62 .165 .151 r
F P
0 g
s
.52184 .48992 m .51849 .49922 L .52589 .50108 L p .62 .165 .151 r
F P
0 g
s
.52913 .49105 m .53324 .5015 L .54 .50047 L p .618 .164 .151 r
F P
0 g
s
.53324 .5015 m .52913 .49105 L .5255 .49084 L p .619 .164 .15 r
F P
0 g
s
.5255 .49084 m .52589 .50108 L .53324 .5015 L p .619 .164 .15 r
F P
0 g
s
.45172 .49552 m .46422 .49423 L .45746 .4822 L p .6 .117 .079 r
F P
0 g
s
.45746 .4822 m .44377 .48197 L .45172 .49552 L p .6 .117 .079 r
F P
0 g
s
.56257 .50102 m .54995 .49444 L .5457 .49805 L p .607 .148 .137 r
F P
0 g
s
.59405 .50207 m .58011 .49845 L .57532 .50704 L p .573 .101 .097 r
F P
0 g
s
.56257 .50102 m .57532 .50704 L .58011 .49845 L p .595 .131 .124 r
F P
0 g
s
.43914 .49602 m .45172 .49552 L .44377 .48197 L p .589 .092 .043 r
F P
0 g
s
.44377 .48197 m .43002 .48144 L .43914 .49602 L p .589 .092 .043 r
F P
0 g
s
.50463 .50334 m .51158 .49607 L .50564 .49185 L p .618 .157 .136 r
F P
0 g
s
.50564 .49185 m .4957 .4971 L .50463 .50334 L p .618 .157 .136 r
F P
0 g
s
.48563 .50175 m .4957 .4971 L .48891 .48979 L p .616 .149 .121 r
F P
0 g
s
.48891 .48979 m .47661 .49228 L .48563 .50175 L p .616 .149 .121 r
F P
0 g
s
.42649 .49565 m .43914 .49602 L .43002 .48144 L p .573 .06 0 r
F P
0 g
s
.43002 .48144 m .41624 .48058 L .42649 .49565 L p .573 .06 0 r
F P
0 g
s
.60805 .50512 m .59405 .50207 L .58819 .51231 L p .542 .061 .062 r
F P
0 g
s
.57532 .50704 m .58819 .51231 L .59405 .50207 L p .573 .101 .097 r
F P
0 g
s
.5457 .49805 m .55624 .50634 L .56257 .50102 L p .607 .148 .137 r
F P
0 g
s
.55624 .50634 m .5457 .49805 L .54 .50047 L p .606 .145 .132 r
F P
0 g
s
.41377 .49431 m .42649 .49565 L .41624 .48058 L p .55 .018 0 r
F P
0 g
s
.41624 .48058 m .40242 .47935 L .41377 .49431 L p .55 .018 0 r
F P
0 g
s
.57532 .50704 m .56257 .50102 L .55624 .50634 L p .588 .121 .112 r
F P
0 g
s
.51508 .50803 m .51849 .49922 L .51158 .49607 L p .616 .153 .131 r
F P
0 g
s
.51158 .49607 m .50463 .50334 L .51508 .50803 L p .616 .153 .131 r
F P
0 g
s
.62211 .50749 m .60805 .50512 L .60118 .51663 L p .5 .007 .015 r
F P
0 g
s
.58819 .51231 m .60118 .51663 L .60805 .50512 L p .542 .061 .062 r
F P
0 g
s
.401 .49196 m .41377 .49431 L .40242 .47935 L p .518 0 0 r
F P
0 g
s
.40242 .47935 m .38856 .47774 L .401 .49196 L p .518 0 0 r
F P
0 g
s
.54 .50047 m .54765 .50992 L .55624 .50634 L p .606 .145 .132 r
F P
0 g
s
.54765 .50992 m .54 .50047 L .53324 .5015 L p .606 .143 .128 r
F P
0 g
s
.47543 .50558 m .48563 .50175 L .47661 .49228 L p .611 .132 .092 r
F P
0 g
s
.47661 .49228 m .46422 .49423 L .47543 .50558 L p .611 .132 .092 r
F P
0 g
s
.52629 .5108 m .52589 .50108 L .51849 .49922 L p .612 .148 .127 r
F P
0 g
s
.51849 .49922 m .51508 .50803 L .52629 .5108 L p .612 .148 .127 r
F P
0 g
s
.38819 .48855 m .401 .49196 L .38856 .47774 L p .471 0 0 r
F P
0 g
s
.38856 .47774 m .37468 .47574 L .38819 .48855 L p .471 0 0 r
F P
0 g
s
.63621 .5091 m .62211 .50749 L .61425 .51983 L p .443 0 0 r
F P
0 g
s
.60118 .51663 m .61425 .51983 L .62211 .50749 L p .5 .007 .015 r
F P
0 g
s
.53324 .5015 m .53742 .51145 L .54765 .50992 L p .606 .143 .128 r
F P
0 g
s
.53742 .51145 m .53324 .5015 L .52589 .50108 L p .609 .145 .126 r
F P
0 g
s
.52589 .50108 m .52629 .5108 L .53742 .51145 L p .609 .145 .126 r
F P
0 g
s
.49757 .50987 m .50463 .50334 L .4957 .4971 L p .614 .141 .109 r
F P
0 g
s
.4957 .4971 m .48563 .50175 L .49757 .50987 L p .614 .141 .109 r
F P
0 g
s
.37535 .48408 m .38819 .48855 L .37468 .47574 L p .404 0 0 r
F P
0 g
s
.37468 .47574 m .36078 .47334 L .37535 .48408 L p .404 0 0 r
F P
0 g
s
.58819 .51231 m .57532 .50704 L .56692 .51393 L p .56 .081 .076 r
F P
0 g
s
.55624 .50634 m .56692 .51393 L .57532 .50704 L p .588 .121 .112 r
F P
0 g
s
.65034 .50989 m .63621 .5091 L .62741 .52177 L p .364 0 0 r
F P
0 g
s
.61425 .51983 m .62741 .52177 L .63621 .5091 L p .443 0 0 r
F P
0 g
s
.36249 .47855 m .37535 .48408 L .36078 .47334 L p .31 0 0 r
F P
0 g
s
.36078 .47334 m .34686 .47055 L .36249 .47855 L p .31 0 0 r
F P
0 g
s
.56692 .51393 m .55624 .50634 L .54765 .50992 L p .585 .113 .1 r
F P
0 g
s
.46511 .50838 m .47543 .50558 L .46422 .49423 L p .603 .109 .053 r
F P
0 g
s
.46422 .49423 m .45172 .49552 L .46511 .50838 L p .603 .109 .053 r
F P
0 g
s
.34964 .47199 m .36249 .47855 L .34686 .47055 L p .186 0 0 r
F P
0 g
s
.34686 .47055 m .33293 .46737 L .34964 .47199 L p .186 0 0 r
F P
0 g
s
.66449 .5098 m .65034 .50989 L .64063 .52233 L p .256 0 0 r
F P
0 g
s
.62741 .52177 m .64063 .52233 L .65034 .50989 L p .364 0 0 r
F P
0 g
s
.33678 .46446 m .34964 .47199 L .33293 .46737 L p 0 .52 .801 r
F P
0 g
s
.33293 .46737 m .31899 .46384 L .33678 .46446 L p 0 .52 .801 r
F P
0 g
s
.67865 .5088 m .66449 .5098 L .65389 .52141 L p .111 0 0 r
F P
0 g
s
.64063 .52233 m .65389 .52141 L .66449 .5098 L p .256 0 0 r
F P
0 g
s
.51161 .516 m .51508 .50803 L .50463 .50334 L p .608 .131 .097 r
F P
0 g
s
.50463 .50334 m .49757 .50987 L .51161 .516 L p .608 .131 .097 r
F P
0 g
s
.32394 .45604 m .33678 .46446 L .31899 .46384 L p .11 .606 .904 r
F P
0 g
s
.31899 .46384 m .30504 .45997 L .32394 .45604 L p .11 .606 .904 r
F P
0 g
s
.85986 .43317 m .84611 .44075 L .82379 .39436 L p .859 .843 .827 r
F P
0 g
s
.82379 .39436 m .8366 .38074 L .85986 .43317 L p .859 .843 .827 r
F P
0 g
s
.60118 .51663 m .58819 .51231 L .57774 .52052 L p .518 .025 .024 r
F P
0 g
s
.56692 .51393 m .57774 .52052 L .58819 .51231 L p .56 .081 .076 r
F P
0 g
s
.84611 .44075 m .83235 .44846 L .81097 .40819 L p .868 .861 .831 r
F P
0 g
s
.81097 .40819 m .82379 .39436 L .84611 .44075 L p .868 .861 .831 r
F P
0 g
s
.31111 .44681 m .32394 .45604 L .30504 .45997 L p .241 .66 .961 r
F P
0 g
s
.30504 .45997 m .29108 .45581 L .31111 .44681 L p .241 .66 .961 r
F P
0 g
s
.6928 .50689 m .67865 .5088 L .66717 .51896 L p 0 0 0 r
F P
0 g
s
.65389 .52141 m .66717 .51896 L .67865 .5088 L p .111 0 0 r
F P
0 g
s
.4547 .50996 m .46511 .50838 L .45172 .49552 L p .592 .079 0 r
F P
0 g
s
.45172 .49552 m .43914 .49602 L .4547 .50996 L p .592 .079 0 r
F P
0 g
s
.54765 .50992 m .55544 .51855 L .56692 .51393 L p .585 .113 .1 r
F P
0 g
s
.55544 .51855 m .54765 .50992 L .53742 .51145 L p .586 .109 .09 r
F P
0 g
s
.4904 .51536 m .49757 .50987 L .48563 .50175 L p .606 .118 .069 r
F P
0 g
s
.48563 .50175 m .47543 .50558 L .4904 .51536 L p .606 .118 .069 r
F P
0 g
s
.83235 .44846 m .81857 .45617 L .79814 .42202 L p .874 .88 .836 r
F P
0 g
s
.79814 .42202 m .81097 .40819 L .83235 .44846 L p .874 .88 .836 r
F P
0 g
s
.2983 .4369 m .31111 .44681 L .29108 .45581 L p .346 .688 .981 r
F P
0 g
s
.29108 .45581 m .27712 .45138 L .2983 .4369 L p .346 .688 .981 r
F P
0 g
s
.70693 .50407 m .6928 .50689 L .68046 .51495 L p .277 .759 .658 r
F P
0 g
s
.66717 .51896 m .68046 .51495 L .6928 .50689 L p 0 0 0 r
F P
0 g
s
.81857 .45617 m .80477 .46376 L .78528 .43566 L p .877 .901 .844 r
F P
0 g
s
.78528 .43566 m .79814 .42202 L .81857 .45617 L p .877 .901 .844 r
F P
0 g
s
.2855 .42642 m .2983 .4369 L .27712 .45138 L p .425 .698 .978 r
F P
0 g
s
.27712 .45138 m .26316 .44675 L .2855 .42642 L p .425 .698 .978 r
F P
0 g
s
.80477 .46376 m .79092 .47112 L .77238 .4489 L p .875 .924 .854 r
F P
0 g
s
.77238 .4489 m .78528 .43566 L .80477 .46376 L p .875 .924 .854 r
F P
0 g
s
.68046 .51495 m .69373 .50942 L .70693 .50407 L p .277 .759 .658 r
F P
0 g
s
.72103 .50038 m .70693 .50407 L .69373 .50942 L p .475 .888 .776 r
F P
0 g
s
.27272 .41551 m .2855 .42642 L .26316 .44675 L p .483 .699 .964 r
F P
0 g
s
.26316 .44675 m .24919 .44195 L .27272 .41551 L p .483 .699 .964 r
F P
0 g
s
.79092 .47112 m .77704 .47812 L .75941 .46154 L p .866 .947 .866 r
F P
0 g
s
.75941 .46154 m .77238 .4489 L .79092 .47112 L p .866 .947 .866 r
F P
0 g
s
.5267 .51965 m .52629 .5108 L .51508 .50803 L p .599 .12 .088 r
F P
0 g
s
.51508 .50803 m .51161 .516 L .5267 .51965 L p .599 .12 .088 r
F P
0 g
s
.7351 .49586 m .72103 .50038 L .70697 .50239 L p .632 .963 .848 r
F P
0 g
s
.69373 .50942 m .70697 .50239 L .72103 .50038 L p .475 .888 .776 r
F P
0 g
s
.77704 .47812 m .7631 .48464 L .74639 .47339 L p .846 .97 .877 r
F P
0 g
s
.74639 .47339 m .75941 .46154 L .77704 .47812 L p .846 .97 .877 r
F P
0 g
s
.25994 .40429 m .27272 .41551 L .24919 .44195 L p .526 .696 .947 r
F P
0 g
s
.24919 .44195 m .23521 .43703 L .25994 .40429 L p .526 .696 .947 r
F P
0 g
s
.74912 .49059 m .7351 .49586 L .72016 .49396 L p .741 .99 .879 r
F P
0 g
s
.70697 .50239 m .72016 .49396 L .7351 .49586 L p .632 .963 .848 r
F P
0 g
s
.7631 .48464 m .74912 .49059 L .73331 .48425 L p .807 .987 .885 r
F P
0 g
s
.73331 .48425 m .74639 .47339 L .7631 .48464 L p .807 .987 .885 r
F P
0 g
s
.57774 .52052 m .56692 .51393 L .55544 .51855 L p .552 .064 .051 r
F P
0 g
s
.72016 .49396 m .73331 .48425 L .74912 .49059 L p .741 .99 .879 r
F P
0 g
s
.53742 .51145 m .54169 .52052 L .55544 .51855 L p .586 .109 .09 r
F P
0 g
s
.54169 .52052 m .53742 .51145 L .52629 .5108 L p .591 .112 .085 r
F P
0 g
s
.24715 .39292 m .25994 .40429 L .23521 .43703 L p .558 .691 .929 r
F P
0 g
s
.23521 .43703 m .22122 .43206 L .24715 .39292 L p .558 .691 .929 r
F P
0 g
s
.52629 .5108 m .5267 .51965 L .54169 .52052 L p .591 .112 .085 r
F P
0 g
s
.23436 .38153 m .24715 .39292 L .22122 .43206 L p .583 .687 .913 r
F P
0 g
s
.22122 .43206 m .20721 .42708 L .23436 .38153 L p .583 .687 .913 r
F P
0 g
s
.44419 .51017 m .4547 .50996 L .43914 .49602 L p .573 .038 0 r
F P
0 g
s
.43914 .49602 m .42649 .49565 L .44419 .51017 L p .573 .038 0 r
F P
0 g
s
.61425 .51983 m .60118 .51663 L .5887 .52587 L p .457 0 0 r
F P
0 g
s
.57774 .52052 m .5887 .52587 L .60118 .51663 L p .518 .025 .024 r
F P
0 g
s
.22154 .37026 m .23436 .38153 L .20721 .42708 L p .603 .684 .899 r
F P
0 g
s
.20721 .42708 m .19318 .42214 L .22154 .37026 L p .603 .684 .899 r
F P
0 g
s
.48312 .51954 m .4904 .51536 L .47543 .50558 L p .593 .085 .013 r
F P
0 g
s
.47543 .50558 m .46511 .50838 L .48312 .51954 L p .593 .085 .013 r
F P
0 g
s
.50807 .52279 m .51161 .516 L .49757 .50987 L p .594 .098 .045 r
F P
0 g
s
.49757 .50987 m .4904 .51536 L .50807 .52279 L p .594 .098 .045 r
F P
0 g
s
.4336 .50887 m .44419 .51017 L .42649 .49565 L p .543 0 0 r
F P
0 g
s
.42649 .49565 m .41377 .49431 L .4336 .50887 L p .543 0 0 r
F P
0 g
s
.62741 .52177 m .61425 .51983 L .59976 .52974 L p .366 0 0 r
F P
0 g
s
.5887 .52587 m .59976 .52974 L .61425 .51983 L p .457 0 0 r
F P
0 g
s
.55544 .51855 m .56335 .52603 L .57774 .52052 L p .552 .064 .051 r
F P
0 g
s
.56335 .52603 m .55544 .51855 L .54169 .52052 L p .553 .056 .03 r
F P
0 g
s
.5887 .52587 m .57774 .52052 L .56335 .52603 L p .501 0 0 r
F P
0 g
s
.42296 .50595 m .4336 .50887 L .41377 .49431 L p .494 0 0 r
F P
0 g
s
.41377 .49431 m .401 .49196 L .42296 .50595 L p .494 0 0 r
F P
0 g
s
.52711 .52724 m .5267 .51965 L .51161 .516 L p .577 .076 .027 r
F P
0 g
s
.51161 .516 m .50807 .52279 L .52711 .52724 L p .577 .076 .027 r
F P
0 g
s
.54169 .52052 m .54603 .52835 L .56335 .52603 L p .553 .056 .03 r
F P
0 g
s
.54603 .52835 m .54169 .52052 L .5267 .51965 L p .562 .06 .021 r
F P
0 g
s
.64063 .52233 m .62741 .52177 L .61093 .53191 L p .23 0 0 r
F P
0 g
s
.59976 .52974 m .61093 .53191 L .62741 .52177 L p .366 0 0 r
F P
0 g
s
.47576 .52215 m .48312 .51954 L .46511 .50838 L p .572 .038 0 r
F P
0 g
s
.46511 .50838 m .4547 .50996 L .47576 .52215 L p .572 .038 0 r
F P
0 g
s
.5267 .51965 m .52711 .52724 L .54603 .52835 L p .562 .06 .021 r
F P
0 g
s
.41227 .50136 m .42296 .50595 L .401 .49196 L p .416 0 0 r
F P
0 g
s
.401 .49196 m .38819 .48855 L .41227 .50136 L p .416 0 0 r
F P
0 g
s
.50448 .52807 m .50807 .52279 L .4904 .51536 L p .57 .048 0 r
F P
0 g
s
.4904 .51536 m .48312 .51954 L .50448 .52807 L p .57 .048 0 r
F P
0 g
s
.59976 .52974 m .5887 .52587 L .57137 .53205 L p .419 0 0 r
F P
0 g
s
.56335 .52603 m .57137 .53205 L .5887 .52587 L p .501 0 0 r
F P
0 g
s
.65389 .52141 m .64063 .52233 L .62217 .53221 L p .035 0 0 r
F P
0 g
s
.61093 .53191 m .62217 .53221 L .64063 .52233 L p .23 0 0 r
F P
0 g
s
.40156 .49507 m .41227 .50136 L .38819 .48855 L p .3 0 0 r
F P
0 g
s
.38819 .48855 m .37535 .48408 L .40156 .49507 L p .3 0 0 r
F P
0 g
s
.57137 .53205 m .56335 .52603 L .54603 .52835 L p .497 0 0 r
F P
0 g
s
.46831 .52298 m .47576 .52215 L .4547 .50996 L p .535 0 0 r
F P
0 g
s
.4547 .50996 m .44419 .51017 L .46831 .52298 L p .535 0 0 r
F P
0 g
s
.66717 .51896 m .65389 .52141 L .63347 .53052 L p 0 0 0 r
F P
0 g
s
.62217 .53221 m .63347 .53052 L .65389 .52141 L p .035 0 0 r
F P
0 g
s
.39083 .48709 m .40156 .49507 L .37535 .48408 L p 0 .405 .759 r
F P
0 g
s
.37535 .48408 m .36249 .47855 L .39083 .48709 L p 0 .405 .759 r
F P
0 g
s
.52753 .53324 m .52711 .52724 L .50807 .52279 L p .539 .008 0 r
F P
0 g
s
.50807 .52279 m .50448 .52807 L .52753 .53324 L p .539 .008 0 r
F P
0 g
s
.54603 .52835 m .55044 .5346 L .57137 .53205 L p .497 0 0 r
F P
0 g
s
.55044 .5346 m .54603 .52835 L .52711 .52724 L p .511 0 0 r
F P
0 g
s
.38011 .47746 m .39083 .48709 L .36249 .47855 L p .01 .491 .871 r
F P
0 g
s
.36249 .47855 m .34964 .47199 L .38011 .47746 L p .01 .491 .871 r
F P
0 g
s
.68046 .51495 m .66717 .51896 L .6448 .52675 L p .47 .891 .814 r
F P
0 g
s
.63347 .53052 m .6448 .52675 L .66717 .51896 L p 0 0 0 r
F P
0 g
s
.61093 .53191 m .59976 .52974 L .5795 .53632 L p .285 0 0 r
F P
0 g
s
.57137 .53205 m .5795 .53632 L .59976 .52974 L p .419 0 0 r
F P
0 g
s
.50083 .53154 m .50448 .52807 L .48312 .51954 L p .528 0 0 r
F P
0 g
s
.48312 .51954 m .47576 .52215 L .50083 .53154 L p .528 0 0 r
F P
0 g
s
.52711 .52724 m .52753 .53324 L .55044 .5346 L p .511 0 0 r
F P
0 g
s
.3694 .46629 m .38011 .47746 L .34964 .47199 L p .153 .543 .925 r
F P
0 g
s
.34964 .47199 m .33678 .46446 L .3694 .46629 L p .153 .543 .925 r
F P
0 g
s
.4608 .52183 m .46831 .52298 L .44419 .51017 L p .468 0 0 r
F P
0 g
s
.44419 .51017 m .4336 .50887 L .4608 .52183 L p .468 0 0 r
F P
0 g
s
.69373 .50942 m .68046 .51495 L .65614 .52087 L p .664 .972 .89 r
F P
0 g
s
.6448 .52675 m .65614 .52087 L .68046 .51495 L p .47 .891 .814 r
F P
0 g
s
.5795 .53632 m .57137 .53205 L .55044 .5346 L p .402 0 0 r
F P
0 g
s
.35871 .45369 m .3694 .46629 L .33678 .46446 L p .264 .568 .937 r
F P
0 g
s
.33678 .46446 m .32394 .45604 L .35871 .45369 L p .264 .568 .937 r
F P
0 g
s
.70697 .50239 m .69373 .50942 L .66747 .51289 L p .78 .983 .903 r
F P
0 g
s
.65614 .52087 m .66747 .51289 L .69373 .50942 L p .664 .972 .89 r
F P
0 g
s
.34805 .43982 m .35871 .45369 L .32394 .45604 L p .346 .578 .928 r
F P
0 g
s
.32394 .45604 m .31111 .44681 L .34805 .43982 L p .346 .578 .928 r
F P
0 g
s
.8366 .38074 m .82379 .39436 L .77813 .35174 L p .859 .777 .769 r
F P
0 g
s
.77813 .35174 m .78901 .33274 L .8366 .38074 L p .859 .777 .769 r
F P
0 g
s
.82379 .39436 m .81097 .40819 L .76726 .37102 L p .868 .787 .769 r
F P
0 g
s
.76726 .37102 m .77813 .35174 L .82379 .39436 L p .868 .787 .769 r
F P
0 g
s
.72016 .49396 m .70697 .50239 L .67877 .50288 L p .841 .962 .886 r
F P
0 g
s
.66747 .51289 m .67877 .50288 L .70697 .50239 L p .78 .983 .903 r
F P
0 g
s
.33742 .42485 m .34805 .43982 L .31111 .44681 L p .406 .58 .91 r
F P
0 g
s
.31111 .44681 m .2983 .4369 L .33742 .42485 L p .406 .58 .91 r
F P
0 g
s
.62217 .53221 m .61093 .53191 L .58772 .53857 L p .071 0 0 r
F P
0 g
s
.5795 .53632 m .58772 .53857 L .61093 .53191 L p .285 0 0 r
F P
0 g
s
.81097 .40819 m .79814 .42202 L .75637 .3903 L p .875 .798 .771 r
F P
0 g
s
.75637 .3903 m .76726 .37102 L .81097 .40819 L p .875 .798 .771 r
F P
0 g
s
.79814 .42202 m .78528 .43566 L .74545 .40932 L p .881 .812 .777 r
F P
0 g
s
.74545 .40932 m .75637 .3903 L .79814 .42202 L p .881 .812 .777 r
F P
0 g
s
.42296 .50595 m .41227 .50136 L .42808 .50693 L p 0 .384 .729 r
F P
0 g
s
.44701 .51526 m .4336 .50887 L p .44264 .51333 L .354 0 0 r
F P
0 g
s
.4336 .50887 m .42296 .50595 L .45324 .51858 L p .354 0 0 r
F P
0 g
s
.42808 .50693 m .44564 .51312 L p .43324 .5092 L 0 .384 .729 r
F P
0 g
s
.42296 .50595 m .42808 .50693 L .43324 .5092 L 0 .384 .729 r
F
.45324 .51858 m .4608 .52183 L .44701 .51526 L p .354 0 0 r
F P
0 g
s
.44264 .51333 m .45324 .51858 L .44701 .51526 L .354 0 0 r
F
.32682 .40898 m .33742 .42485 L .2983 .4369 L p .451 .579 .891 r
F P
0 g
s
.2983 .4369 m .2855 .42642 L .32682 .40898 L p .451 .579 .891 r
F P
0 g
s
.73331 .48425 m .72016 .49396 L .69003 .49096 L p .871 .93 .86 r
F P
0 g
s
.67877 .50288 m .69003 .49096 L .72016 .49396 L p .841 .962 .886 r
F P
0 g
s
.78528 .43566 m .77238 .4489 L .73449 .4278 L p .886 .829 .785 r
F P
0 g
s
.73449 .4278 m .74545 .40932 L .78528 .43566 L p .886 .829 .785 r
F P
0 g
s
.52796 .53731 m .52753 .53324 L .50448 .52807 L p .469 0 0 r
F P
0 g
s
.50448 .52807 m .50083 .53154 L .52796 .53731 L p .469 0 0 r
F P
0 g
s
.74639 .47339 m .73331 .48425 L .70124 .47729 L p .884 .899 .836 r
F P
0 g
s
.69003 .49096 m .70124 .47729 L .73331 .48425 L p .871 .93 .86 r
F P
0 g
s
.31625 .39242 m .32682 .40898 L .2855 .42642 L p .485 .579 .874 r
F P
0 g
s
.2855 .42642 m .27272 .41551 L .31625 .39242 L p .485 .579 .874 r
F P
0 g
s
.77238 .4489 m .75941 .46154 L .72347 .44547 L p .889 .848 .798 r
F P
0 g
s
.72347 .44547 m .73449 .4278 L .77238 .4489 L p .889 .848 .798 r
F P
0 g
s
.75941 .46154 m .74639 .47339 L .71239 .46204 L p .889 .872 .815 r
F P
0 g
s
.70124 .47729 m .71239 .46204 L .74639 .47339 L p .884 .899 .836 r
F P
0 g
s
.71239 .46204 m .72347 .44547 L .75941 .46154 L p .889 .872 .815 r
F P
0 g
s
.49715 .53294 m .50083 .53154 L .47576 .52215 L p .45 0 0 r
F P
0 g
s
.47576 .52215 m .46831 .52298 L .49715 .53294 L p .45 0 0 r
F P
0 g
s
.30569 .3754 m .31625 .39242 L .27272 .41551 L p .512 .579 .86 r
F P
0 g
s
.27272 .41551 m .25994 .40429 L .30569 .3754 L p .512 .579 .86 r
F P
0 g
s
.55044 .5346 m .55492 .53894 L .5795 .53632 L p .402 0 0 r
F P
0 g
s
.55492 .53894 m .55044 .5346 L .52753 .53324 L p .419 0 0 r
F P
0 g
s
.29514 .35814 m .30569 .3754 L .25994 .40429 L p .535 .582 .848 r
F P
0 g
s
.25994 .40429 m .24715 .39292 L .29514 .35814 L p .535 .582 .848 r
F P
0 g
s
.28458 .34085 m .29514 .35814 L .24715 .39292 L p .555 .585 .839 r
F P
0 g
s
.24715 .39292 m .23436 .38153 L .28458 .34085 L p .555 .585 .839 r
F P
0 g
s
.27399 .32374 m .28458 .34085 L .23436 .38153 L p .572 .591 .833 r
F P
0 g
s
.23436 .38153 m .22154 .37026 L .27399 .32374 L p .572 .591 .833 r
F P
0 g
s
.52753 .53324 m .52796 .53731 L .55492 .53894 L p .419 0 0 r
F P
0 g
s
.58772 .53857 m .5795 .53632 L .55492 .53894 L p .233 0 0 r
F P
0 g
s
.63347 .53052 m .62217 .53221 L .59601 .5386 L p .224 .743 .751 r
F P
0 g
s
.58772 .53857 m .59601 .5386 L .62217 .53221 L p .071 0 0 r
F P
0 g
s
.44564 .51312 m .45324 .51858 L .42296 .50595 L p 0 .384 .729 r
F P
0 g
s
.4608 .52183 m .45324 .51858 L .45362 .51868 L p 0 .472 .789 r
F P
0 g
s
.49715 .53294 m .46831 .52298 L p .48449 .52882 L .307 0 0 r
F P
0 g
s
.46831 .52298 m .4608 .52183 L .49342 .53205 L p .307 0 0 r
F P
0 g
s
.45362 .51868 m .48967 .52869 L p .4695 .5239 L 0 .472 .789 r
F P
0 g
s
.4608 .52183 m .45362 .51868 L .4695 .5239 L 0 .472 .789 r
F
.49342 .53205 m .49674 .53285 L p .48449 .52882 L .307 0 0 r
F P
0 g
s
.49674 .53285 m .49715 .53294 L p .48449 .52882 L .307 0 0 r
F P
0 g
s
.43802 .50542 m .44564 .51312 L .41227 .50136 L p .014 .491 .873 r
F P
0 g
s
.41227 .50136 m .40156 .49507 L .43802 .50542 L p .014 .491 .873 r
F P
0 g
s
.52796 .53731 m .50083 .53154 L p .52374 .53788 L .337 0 0 r
F P
0 g
s
.52829 .53874 m .52796 .53731 L p .52374 .53788 L .337 0 0 r
F P
0 g
s
.50083 .53154 m .49715 .53294 L .52839 .53917 L p .337 0 0 r
F P
0 g
s
.52796 .53731 m .52839 .53917 L .55945 .54109 L p .249 0 0 r
F P
0 g
s
.49342 .53205 m .52883 .53858 L p .50176 .53376 L 0 .481 .719 r
F P
0 g
s
.49715 .53294 m .49631 .53274 L p .50176 .53376 L 0 .481 .719 r
F P
0 g
s
.49631 .53274 m .49342 .53205 L p .50176 .53376 L 0 .481 .719 r
F P
0 g
s
.52839 .53917 m .52829 .53874 L p .52374 .53788 L .337 0 0 r
F P
0 g
s
.6448 .52675 m .63347 .53052 L .60435 .53624 L p .514 .911 .914 r
F P
0 g
s
.59601 .5386 m .60435 .53624 L .63347 .53052 L p .224 .743 .751 r
F P
0 g
s
.55492 .53894 m .55945 .54109 L .58772 .53857 L p .233 0 0 r
F P
0 g
s
.55945 .54109 m .55492 .53894 L .52796 .53731 L p .249 0 0 r
F P
0 g
s
.59601 .5386 m .58772 .53857 L .55945 .54109 L p 0 0 0 r
F P
0 g
s
.43039 .49549 m .43802 .50542 L .40156 .49507 L p .186 .547 .929 r
F P
0 g
s
.40156 .49507 m .39083 .48709 L .43039 .49549 L p .186 .547 .929 r
F P
0 g
s
.65614 .52087 m .6448 .52675 L .61272 .53138 L p .7 .953 .953 r
F P
0 g
s
.60435 .53624 m .61272 .53138 L .6448 .52675 L p .514 .911 .914 r
F P
0 g
s
.48967 .52869 m .49342 .53205 L .4608 .52183 L p 0 .472 .789 r
F P
0 g
s
.42277 .4834 m .43039 .49549 L .39083 .48709 L p .308 .563 .928 r
F P
0 g
s
.39083 .48709 m .38011 .47746 L .42277 .4834 L p .308 .563 .928 r
F P
0 g
s
.66747 .51289 m .65614 .52087 L .62111 .52399 L p .791 .928 .925 r
F P
0 g
s
.61272 .53138 m .62111 .52399 L .65614 .52087 L p .7 .953 .953 r
F P
0 g
s
.52883 .53858 m .52839 .53917 L .49715 .53294 L p 0 .481 .719 r
F P
0 g
s
.55945 .54109 m .56403 .54082 L .59601 .5386 L p 0 0 0 r
F P
0 g
s
.60435 .53624 m .59601 .5386 L .56403 .54082 L p .373 .827 .928 r
F P
0 g
s
.41517 .46927 m .42277 .4834 L .38011 .47746 L p .39 .562 .903 r
F P
0 g
s
.38011 .47746 m .3694 .46629 L .41517 .46927 L p .39 .562 .903 r
F P
0 g
s
.56403 .54082 m .55945 .54109 L .52839 .53917 L p .034 .601 .777 r
F P
0 g
s
.67877 .50288 m .66747 .51289 L .62949 .51408 L p .83 .886 .882 r
F P
0 g
s
.62111 .52399 m .62949 .51408 L .66747 .51289 L p .791 .928 .925 r
F P
0 g
s
.48589 .52276 m .48967 .52869 L .45324 .51858 L p .157 .589 .934 r
F P
0 g
s
.45324 .51858 m .44564 .51312 L .48589 .52276 L p .157 .589 .934 r
F P
0 g
s
.52839 .53917 m .52883 .53858 L .56403 .54082 L p .034 .601 .777 r
F P
0 g
s
.40759 .45326 m .41517 .46927 L .3694 .46629 L p .444 .555 .874 r
F P
0 g
s
.3694 .46629 m .35871 .45369 L .40759 .45326 L p .444 .555 .874 r
F P
0 g
s
.69003 .49096 m .67877 .50288 L .63786 .50172 L p .847 .847 .843 r
F P
0 g
s
.62949 .51408 m .63786 .50172 L .67877 .50288 L p .83 .886 .882 r
F P
0 g
s
.40003 .43557 m .40759 .45326 L .35871 .45369 L p .481 .547 .847 r
F P
0 g
s
.35871 .45369 m .34805 .43982 L .40003 .43557 L p .481 .547 .847 r
F P
0 g
s
.61272 .53138 m .60435 .53624 L .56864 .53793 L p .606 .893 .989 r
F P
0 g
s
.56403 .54082 m .56864 .53793 L .60435 .53624 L p .373 .827 .928 r
F P
0 g
s
.70124 .47729 m .69003 .49096 L .64619 .48705 L p .853 .814 .811 r
F P
0 g
s
.63786 .50172 m .64619 .48705 L .69003 .49096 L p .847 .847 .843 r
F P
0 g
s
.78901 .33274 m .77813 .35174 L .71123 .31684 L p .828 .708 .733 r
F P
0 g
s
.71123 .31684 m .71927 .29362 L .78901 .33274 L p .828 .708 .733 r
F P
0 g
s
.39252 .41644 m .40003 .43557 L .34805 .43982 L p .509 .541 .825 r
F P
0 g
s
.34805 .43982 m .33742 .42485 L .39252 .41644 L p .509 .541 .825 r
F P
0 g
s
.52927 .53535 m .52883 .53858 L .49342 .53205 L p .187 .658 .936 r
F P
0 g
s
.49342 .53205 m .48967 .52869 L .52927 .53535 L p .187 .658 .936 r
F P
0 g
s
.77813 .35174 m .76726 .37102 L .70321 .34038 L p .833 .712 .731 r
F P
0 g
s
.70321 .34038 m .71123 .31684 L .77813 .35174 L p .833 .712 .731 r
F P
0 g
s
.76726 .37102 m .75637 .3903 L .69518 .36392 L p .838 .718 .732 r
F P
0 g
s
.69518 .36392 m .70321 .34038 L .76726 .37102 L p .838 .718 .732 r
F P
0 g
s
.71239 .46204 m .70124 .47729 L .65448 .47026 L p .854 .787 .786 r
F P
0 g
s
.64619 .48705 m .65448 .47026 L .70124 .47729 L p .853 .814 .811 r
F P
0 g
s
.38503 .39614 m .39252 .41644 L .33742 .42485 L p .529 .537 .807 r
F P
0 g
s
.33742 .42485 m .32682 .40898 L .38503 .39614 L p .529 .537 .807 r
F P
0 g
s
.75637 .3903 m .74545 .40932 L .68713 .38714 L p .843 .726 .735 r
F P
0 g
s
.68713 .38714 m .69518 .36392 L .75637 .3903 L p .843 .726 .735 r
F P
0 g
s
.48211 .51419 m .48589 .52276 L .44564 .51312 L p .336 .625 .957 r
F P
0 g
s
.44564 .51312 m .43802 .50542 L .48211 .51419 L p .336 .625 .957 r
F P
0 g
s
.72347 .44547 m .71239 .46204 L .66272 .45158 L p .852 .766 .766 r
F P
0 g
s
.65448 .47026 m .66272 .45158 L .71239 .46204 L p .854 .787 .786 r
F P
0 g
s
.56864 .53793 m .56403 .54082 L .52883 .53858 L p .35 .776 .973 r
F P
0 g
s
.74545 .40932 m .73449 .4278 L .67904 .40971 L p .847 .737 .742 r
F P
0 g
s
.67904 .40971 m .68713 .38714 L .74545 .40932 L p .847 .737 .742 r
F P
0 g
s
.37757 .37494 m .38503 .39614 L .32682 .40898 L p .546 .535 .794 r
F P
0 g
s
.32682 .40898 m .31625 .39242 L .37757 .37494 L p .546 .535 .794 r
F P
0 g
s
.73449 .4278 m .72347 .44547 L .67091 .4313 L p .85 .75 .752 r
F P
0 g
s
.67091 .4313 m .67904 .40971 L .73449 .4278 L p .85 .75 .752 r
F P
0 g
s
.66272 .45158 m .67091 .4313 L .72347 .44547 L p .852 .766 .766 r
F P
0 g
s
.37013 .35314 m .37757 .37494 L .31625 .39242 L p .56 .536 .785 r
F P
0 g
s
.31625 .39242 m .30569 .3754 L .37013 .35314 L p .56 .536 .785 r
F P
0 g
s
.3627 .33102 m .37013 .35314 L .30569 .3754 L p .573 .538 .778 r
F P
0 g
s
.30569 .3754 m .29514 .35814 L .3627 .33102 L p .573 .538 .778 r
F P
0 g
s
.35527 .30889 m .3627 .33102 L .29514 .35814 L p .584 .543 .775 r
F P
0 g
s
.29514 .35814 m .28458 .34085 L .35527 .30889 L p .584 .543 .775 r
F P
0 g
s
.52883 .53858 m .52927 .53535 L .56864 .53793 L p .35 .776 .973 r
F P
0 g
s
.34782 .287 m .35527 .30889 L .28458 .34085 L p .595 .55 .774 r
F P
0 g
s
.28458 .34085 m .27399 .32374 L .34782 .287 L p .595 .55 .774 r
F P
0 g
s
.62111 .52399 m .61272 .53138 L .57327 .53232 L p .718 .866 .952 r
F P
0 g
s
.56864 .53793 m .57327 .53232 L .61272 .53138 L p .606 .893 .989 r
F P
0 g
s
.47832 .50302 m .48211 .51419 L .43802 .50542 L p .443 .618 .925 r
F P
0 g
s
.43802 .50542 m .43039 .49549 L .47832 .50302 L p .443 .618 .925 r
F P
0 g
s
.52972 .52937 m .52927 .53535 L .48967 .52869 L p .411 .715 .986 r
F P
0 g
s
.48967 .52869 m .48589 .52276 L .52972 .52937 L p .411 .715 .986 r
F P
0 g
s
.57327 .53232 m .56864 .53793 L .52927 .53535 L p .554 .808 .993 r
F P
0 g
s
.62949 .51408 m .62111 .52399 L .57791 .52392 L p .765 .82 .896 r
F P
0 g
s
.57327 .53232 m .57791 .52392 L .62111 .52399 L p .718 .866 .952 r
F P
0 g
s
.47454 .48931 m .47832 .50302 L .43039 .49549 L p .506 .6 .882 r
F P
0 g
s
.43039 .49549 m .42277 .4834 L .47454 .48931 L p .506 .6 .882 r
F P
0 g
s
.52927 .53535 m .52972 .52937 L .57327 .53232 L p .554 .808 .993 r
F P
0 g
s
.53016 .52056 m .52972 .52937 L .48589 .52276 L p .533 .701 .947 r
F P
0 g
s
.48589 .52276 m .48211 .51419 L .53016 .52056 L p .533 .701 .947 r
F P
0 g
s
.63786 .50172 m .62949 .51408 L .58256 .51275 L p .785 .778 .847 r
F P
0 g
s
.57791 .52392 m .58256 .51275 L .62949 .51408 L p .765 .82 .896 r
F P
0 g
s
.47077 .4732 m .47454 .48931 L .42277 .4834 L p .543 .582 .844 r
F P
0 g
s
.42277 .4834 m .41517 .46927 L .47077 .4732 L p .543 .582 .844 r
F P
0 g
s
.57791 .52392 m .57327 .53232 L .52972 .52937 L p .65 .775 .939 r
F P
0 g
s
.64619 .48705 m .63786 .50172 L .58719 .4989 L p .793 .745 .808 r
F P
0 g
s
.58256 .51275 m .58719 .4989 L .63786 .50172 L p .785 .778 .847 r
F P
0 g
s
.46702 .45488 m .47077 .4732 L .41517 .46927 L p .568 .567 .812 r
F P
0 g
s
.41517 .46927 m .40759 .45326 L .46702 .45488 L p .568 .567 .812 r
F P
0 g
s
.52972 .52937 m .53016 .52056 L .57791 .52392 L p .65 .775 .939 r
F P
0 g
s
.53061 .50896 m .53016 .52056 L .48211 .51419 L p .594 .67 .892 r
F P
0 g
s
.48211 .51419 m .47832 .50302 L .53061 .50896 L p .594 .67 .892 r
F P
0 g
s
.46328 .43461 m .46702 .45488 L .40759 .45326 L p .585 .556 .788 r
F P
0 g
s
.40759 .45326 m .40003 .43557 L .46328 .43461 L p .585 .556 .788 r
F P
0 g
s
.65448 .47026 m .64619 .48705 L .5918 .48251 L p .796 .719 .779 r
F P
0 g
s
.58719 .4989 m .5918 .48251 L .64619 .48705 L p .793 .745 .808 r
F P
0 g
s
.58256 .51275 m .57791 .52392 L .53016 .52056 L p .694 .733 .881 r
F P
0 g
s
.45957 .41265 m .46328 .43461 L .40003 .43557 L p .597 .547 .77 r
F P
0 g
s
.40003 .43557 m .39252 .41644 L .45957 .41265 L p .597 .547 .77 r
F P
0 g
s
.66272 .45158 m .65448 .47026 L .5964 .46379 L p .797 .699 .757 r
F P
0 g
s
.5918 .48251 m .5964 .46379 L .65448 .47026 L p .796 .719 .779 r
F P
0 g
s
.71927 .29362 m .71123 .31684 L .62781 .29326 L p .784 .649 .713 r
F P
0 g
s
.62781 .29326 m .63227 .26744 L .71927 .29362 L p .784 .649 .713 r
F P
0 g
s
.71123 .31684 m .70321 .34038 L .62337 .31941 L p .787 .65 .711 r
F P
0 g
s
.62337 .31941 m .62781 .29326 L .71123 .31684 L p .787 .65 .711 r
F P
0 g
s
.45587 .38932 m .45957 .41265 L .39252 .41644 L p .606 .542 .756 r
F P
0 g
s
.39252 .41644 m .38503 .39614 L .45587 .38932 L p .606 .542 .756 r
F P
0 g
s
.67091 .4313 m .66272 .45158 L .60096 .443 L p .796 .684 .74 r
F P
0 g
s
.5964 .46379 m .60096 .443 L .66272 .45158 L p .797 .699 .757 r
F P
0 g
s
.70321 .34038 m .69518 .36392 L .61893 .34556 L p .79 .653 .711 r
F P
0 g
s
.61893 .34556 m .62337 .31941 L .70321 .34038 L p .79 .653 .711 r
F P
0 g
s
.69518 .36392 m .68713 .38714 L .61447 .37136 L p .792 .657 .714 r
F P
0 g
s
.61447 .37136 m .61893 .34556 L .69518 .36392 L p .792 .657 .714 r
F P
0 g
s
.67904 .40971 m .67091 .4313 L .60549 .42044 L p .795 .672 .728 r
F P
0 g
s
.60096 .443 m .60549 .42044 L .67091 .4313 L p .796 .684 .74 r
F P
0 g
s
.68713 .38714 m .67904 .40971 L .60999 .39644 L p .794 .663 .72 r
F P
0 g
s
.60999 .39644 m .61447 .37136 L .68713 .38714 L p .794 .663 .72 r
F P
0 g
s
.45219 .36496 m .45587 .38932 L .38503 .39614 L p .614 .539 .746 r
F P
0 g
s
.38503 .39614 m .37757 .37494 L .45219 .36496 L p .614 .539 .746 r
F P
0 g
s
.60549 .42044 m .60999 .39644 L .67904 .40971 L p .795 .672 .728 r
F P
0 g
s
.53105 .49464 m .53061 .50896 L .47832 .50302 L p .627 .641 .845 r
F P
0 g
s
.47832 .50302 m .47454 .48931 L .53105 .49464 L p .627 .641 .845 r
F P
0 g
s
.53016 .52056 m .53061 .50896 L .58256 .51275 L p .694 .733 .881 r
F P
0 g
s
.44853 .3399 m .45219 .36496 L .37757 .37494 L p .621 .538 .739 r
F P
0 g
s
.37757 .37494 m .37013 .35314 L .44853 .3399 L p .621 .538 .739 r
F P
0 g
s
.44487 .31449 m .44853 .3399 L .37013 .35314 L p .627 .539 .735 r
F P
0 g
s
.37013 .35314 m .3627 .33102 L .44487 .31449 L p .627 .539 .735 r
F P
0 g
s
.44121 .28906 m .44487 .31449 L .3627 .33102 L p .633 .542 .734 r
F P
0 g
s
.3627 .33102 m .35527 .30889 L .44121 .28906 L p .633 .542 .734 r
F P
0 g
s
.43754 .26392 m .44121 .28906 L .35527 .30889 L p .639 .547 .735 r
F P
0 g
s
.35527 .30889 m .34782 .287 L .43754 .26392 L p .639 .547 .735 r
F P
0 g
s
.58719 .4989 m .58256 .51275 L .53061 .50896 L p .714 .698 .833 r
F P
0 g
s
.5315 .47775 m .53105 .49464 L .47454 .48931 L p .646 .618 .807 r
F P
0 g
s
.47454 .48931 m .47077 .4732 L .5315 .47775 L p .646 .618 .807 r
F P
0 g
s
.53061 .50896 m .53105 .49464 L .58719 .4989 L p .714 .698 .833 r
F P
0 g
s
.5918 .48251 m .58719 .4989 L .53105 .49464 L p .725 .671 .797 r
F P
0 g
s
.53194 .4585 m .5315 .47775 L .47077 .4732 L p .657 .6 .779 r
F P
0 g
s
.47077 .4732 m .46702 .45488 L .53194 .4585 L p .657 .6 .779 r
F P
0 g
s
.5964 .46379 m .5918 .48251 L .5315 .47775 L p .731 .65 .769 r
F P
0 g
s
.53105 .49464 m .5315 .47775 L .5918 .48251 L p .725 .671 .797 r
F P
0 g
s
.53237 .43715 m .53194 .4585 L .46702 .45488 L p .665 .587 .758 r
F P
0 g
s
.46702 .45488 m .46328 .43461 L .53237 .43715 L p .665 .587 .758 r
F P
0 g
s
.60096 .443 m .5964 .46379 L .53194 .4585 L p .734 .634 .748 r
F P
0 g
s
.5315 .47775 m .53194 .4585 L .5964 .46379 L p .731 .65 .769 r
F P
0 g
s
.53281 .414 m .53237 .43715 L .46328 .43461 L p .67 .577 .741 r
F P
0 g
s
.46328 .43461 m .45957 .41265 L .53281 .414 L p .67 .577 .741 r
F P
0 g
s
.60549 .42044 m .60096 .443 L .53237 .43715 L p .736 .622 .733 r
F P
0 g
s
.53194 .4585 m .53237 .43715 L .60096 .443 L p .734 .634 .748 r
F P
0 g
s
.53324 .3894 m .53281 .414 L .45957 .41265 L p .675 .57 .73 r
F P
0 g
s
.45957 .41265 m .45587 .38932 L .53324 .3894 L p .675 .57 .73 r
F P
0 g
s
.63227 .26744 m .62781 .29326 L .53496 .28363 L p .737 .603 .708 r
F P
0 g
s
.53496 .28363 m .53539 .25714 L .63227 .26744 L p .737 .603 .708 r
F P
0 g
s
.62781 .29326 m .62337 .31941 L .53453 .31044 L p .737 .601 .706 r
F P
0 g
s
.53453 .31044 m .53496 .28363 L .62781 .29326 L p .737 .601 .706 r
F P
0 g
s
.60999 .39644 m .60549 .42044 L .53281 .414 L p .737 .614 .721 r
F P
0 g
s
.53237 .43715 m .53281 .414 L .60549 .42044 L p .736 .622 .733 r
F P
0 g
s
.62337 .31941 m .61893 .34556 L .5341 .33725 L p .737 .601 .706 r
F P
0 g
s
.5341 .33725 m .53453 .31044 L .62337 .31941 L p .737 .601 .706 r
F P
0 g
s
.61893 .34556 m .61447 .37136 L .53367 .36369 L p .737 .603 .708 r
F P
0 g
s
.53367 .36369 m .5341 .33725 L .61893 .34556 L p .737 .603 .708 r
F P
0 g
s
.53367 .36369 m .53324 .3894 L .45587 .38932 L p .678 .566 .721 r
F P
0 g
s
.45587 .38932 m .45219 .36496 L .53367 .36369 L p .678 .566 .721 r
F P
0 g
s
.61447 .37136 m .60999 .39644 L .53324 .3894 L p .737 .607 .713 r
F P
0 g
s
.53281 .414 m .53324 .3894 L .60999 .39644 L p .737 .614 .721 r
F P
0 g
s
.53324 .3894 m .53367 .36369 L .61447 .37136 L p .737 .607 .713 r
F P
0 g
s
.5341 .33725 m .53367 .36369 L .45219 .36496 L p .681 .563 .716 r
F P
0 g
s
.45219 .36496 m .44853 .3399 L .5341 .33725 L p .681 .563 .716 r
F P
0 g
s
.53453 .31044 m .5341 .33725 L .44853 .3399 L p .683 .563 .713 r
F P
0 g
s
.44853 .3399 m .44487 .31449 L .53453 .31044 L p .683 .563 .713 r
F P
0 g
s
.53496 .28363 m .53453 .31044 L .44487 .31449 L p .685 .564 .713 r
F P
0 g
s
.44487 .31449 m .44121 .28906 L .53496 .28363 L p .685 .564 .713 r
F P
0 g
s
.53539 .25714 m .53496 .28363 L .44121 .28906 L p .688 .568 .715 r
F P
0 g
s
.44121 .28906 m .43754 .26392 L .53539 .25714 L p .688 .568 .715 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ok2A]`03o`00
0?nlV[Go_9Ze00?o_9Ze2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo0_l00002ooooo`03o`000?oooooooooo07Sooooo2_l0000Hok2A]`03o`000?nl
V[Go_9Ze00ko_9Ze2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_oo
ool002cooooo0_l00004ooooo`03o`000?oooooooooo07?ooooo1?l00002oj><_003o`000?n`TKOo
/96g01go/96g00?o0000okbJ]OnlV[D06OnlV[D7o`0001?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06oooooo0ol00006oj><_003o`000?n`TKOo/96g01go/96g00?o0000okbJ]OnlV[D07OnlV[D00ol0
003ob:JfolRV]P03o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]oooo
o`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l00009oj><_003
o`000?n`TKOo/96g01go/96g00?o0000okbJ]OnlV[D07OnlV[D00ol0003ob:JfolRV]P03olRV]P?o
00003Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo000/ooooo`?o0000
1_ooool00ol0003oooooooooo`1Uooooo`Co00003OnSS;`00ol0003o/96gok2A]`0Mok2A]`03o`00
0?nlV[Go_9Ze01co_9Ze00?o0000olRV]_o8Y[H01oo8Y[H3o`0000[ooooo00?o0000ooooooooool0
<_ooool2o`0002gooooo000/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?oo
ool4o`0001;oXhbl00?o0000ok2A]on`TKL07?n`TKL00ol0003o_9ZeokbJ]@0LokbJ]@03o`000?o8
Y[Kob:Jf00[ob:Jf0ol00007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:ooo
ool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`?o0000
5_nSS;`00ol0003o/96gok2A]`0Lok2A]`03o`000?nlV[Go_9Ze01co_9Ze00?o0000olRV]_o8Y[H0
3Oo8Y[H3o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`004Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`Co00006OnSS;`00ol0003o/96g
ok2A]`0=ok2A]aGo00006OnlV[D00ol0003ob:JfolRV]P0@olRV]P?o00000_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02[ooooo0009ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`0000_ooooo00?o0000ooooooooool0
Doooool3o`0001_oXhbl0ol000000on`TKOo0000o`00000<o`0000oo[i2f00?o0000okbI]?nlVK@0
0onlVK@:o`0000oo_9Ze00?o0000olRV]_o8Y[H04oo8Y[H3o`0003Kooooo00?o0000ooooooooool0
:Oooool0017ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`;o000000?oV8c6o`000?nSS;`0
5onSS;`4o`0000;oXXZk00?o0000ojn@]_n_T;H07?n_T;H00ol0003o_9VdokbI]00=okbI]0[o0000
1?nlV[D00ol0003ob:JfolRV]P0FolRV]PCo0000=?ooool00ol0003oooooooooo`0Xooooo`004Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0COooool2o`0000CoV8c600?o0000oj><_?nS
S;`04OnSS;`4o`0000KoXXZk00?o0000ojn@]_n_T;H07?n_T;H00ol0003o_9VdokbI]00GokbI]0Oo
00005_o8Y[H01?l0003ob:JfolRV]_o8Y[H3o`00037ooooo0_l0000Yooooo`004Oooool01Ol@413o
oooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0000oooooo00?o0000oooo
ooooool0B_ooool2o`0000KoV8c600?o0000oj><_?nSS;`03OnSS;`4o`0000[oXXZk00?o0000ojn@
]_n_T;H07?n_T;H00ol0003o_9VdokbI]00KokbI]003o`000?o9Y[KobJJf00?o00004oo8Y[H00ol0
003ob:JfolRV]P02olRV]P04o`000?oC]K_o0000o`0002oooooo0_l0000Yooooo`004Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Oooooo0_l00009oiR<aP03o`000?nSS;coXhbl00SoXhbl1?l0000>
oj::^`03o`000?n_T;Ko[i2f01co[i2f00?o0000okbI]?nlVK@06onlVK@00ol0003obJJfolVV]P03
olVV]PCo00003oo8Y[H00ol0003ob:JfolRV]P02olRV]P05o`000?oC]K_odkFkom>e^ol00000<?oo
ool00ol0003oooooooooo`0Vooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`03o`000?oooooooooo013ooooo0_l00015ooooo`;o00002onHS<H00ol0003oXhbloj><
_004oj><_0Co00004onRR[/00ol0003o[i2fojn@]P0Kojn@]P03o`000?nlVKCo_9Vd01_o_9Vd00?o
0000olVV]_o9Y[H01oo9Y[H3o`0000_ob:Jf0_l00003olRV]P03o`000?oC]K_odkFk00?odkFk0_l0
000^ooooo`03o`000?oooooooooo02Kooooo000Zooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0@?ooool2o`0000goV8c600Co0000oj><_?nSS;coXhbl0ol0000Goj::^`03o`000?n_
T;Ko[i2f01_o[i2f00?o0000okbI]?nlVK@06onlVK@00ol0003obJJfolVV]P0:olVV]PCo00001?o8
Y[H3o`000003olRV]_l0003ob:Jf00;ob:Jf00?o0000om>e^ooC]K/01OoC]K/2o`0002gooooo00?o
0000ooooooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l0000?
oiR<aP?o00006onRR[/00ol0003o[i2fojn@]P0Dojn@]Pgo00005onlVK@00ol0003obJJfolVV]P0?
olVV]PCo00001Oo8Y[H01?l0003ob:JfolRV]_l00009om>e^`;o0000;?ooool00ol0003ooooooooo
o`0Tooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03[ooooo0_l0000?
oiR<aP;o000000?oUH_6o`000?nRR[/06onRR[/00ol0003o[i2fojn@]P05ojn@]Poo00001on^T;H0
0ol0003o_9VdokbI]003okbI]0[o00003OnlVK@00ol0003obJJfolVV]P0=olVV]P?o00000_o9Y[H4
o`0000?ob:Jf00?o0000olRV]_l000002ooC]K/2o`0002[ooooo0_l0000Uooooo`00:_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03Oooooo0_l0000>oiR<aP?o00000onERlH00ol0
003oXXZkoj::^`0Goj::^`Co000000?o[i2fo`000?l000001?l0000Fojj@]P03o`000?nlVKCo_9Vd
00go_9Vd2Ol00004okbI]003o`000?o9Y[KobJJf00[obJJf0ol00009olVV]P?o000000?ob:Jfo`00
0?oC]K/03OoC]K/00ol0003oooooooooo`0Wooooo`;o00002?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool002[ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00003_nHS<H2o`0000OoUH_600?o0000
oj::^onRR[/04OnRR[/5o`0000?oX8Vl00?o0000ojj@]_n^T;H06on^T;H00ol0003o_9VdokbI]00F
okbI]0Oo00001oo9Y[H3o`0000oobJJf0ol0000>om>e^`;o0000:?ooool00ol0003oooooooooo`06
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01_oo
ool002[ooooo0_l0000Iooooo`03o`000?oooooooooo037ooooo0_l0000>oiR<aP;o00002OnERlH0
0ol0003oXXZkoj::^`0;oj::^`Ko00002?nPRK`00ol0003o[Y2fojj@]P0Kojj@]P03o`000?nlVKCo
_9Vd01[o_9Vd00?o0000olZW]_o:YkH01ol0000ColVV]PCo00003_oC]K/2o`0002Oooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01Ooo
ool002Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`;o00003OnHS<H3
o`0000_oUH_600?o0000oj::^onRR[/01_nRR[/5o`0000koX8Vl00?o0000ojj@]_n^T;H06_n^T;H0
0ol0003o_9VdokbI]00KokbI]004o`000?o:YkKobZNfolZW]PKo00004_o9Y[H01Ol0003oeKJkomFf
^ol0003oeKJk00;o00003_oC]K/2o`0002Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool002Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0/ooooo`03o`000?nBUmGo000000_oV8c60_l0000?oiF;aP03o`00
0?nRR[_oXXZk00Go00004onPRK`00ol0003o[Y2fojj@]P0Jojj@]P03o`000?nlVKCo_9Vd01[o_9Vd
00?o0000olZW]_l000000_l00006olZW]PCo00003_o9Y[H01Ol0003oeKJkomFf^ooE][_o000000;o
eKJk0_l0000>om>e^`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3o`00
01cooooo00?o0000ooooooooool0:_ooool01Ol0003oTYOEoi:GeOnBUmGo000000SoV8c60_l0000@
oiF;aPCo00006OnPRK`00ol0003o[Y2fojj@]P0Iojj@]P03o`000?nlVKCo_9Vd01Wo_9Vd0ol0000=
olZW]PCo00002Oo9Y[H00ol0003oeKJkomFf^`02omFf^`03o`000?oE][_oeKJk00;oeKJk0_l0000=
om>e^`;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo02Sooooo00?o0000oi:GeOnBUmD00onBUmD00ol0003oV8c6oiR<aP02oiR<aP?o00003onERlH3
o`000003oi:9aol0003oX8Vl01[oX8Vl00?o0000ojj@]_n^T;H06On^T;H00ol0003o_9VdokbI]00F
okbI]0?o000000?o_9Vdo`000?o:YkH04Oo:YkH3o`0000KobJJf00?o0000omFf^ooE][/00ooE][/0
0ol0003oeKJkomFf^`03omFf^`;o00003OoC]K/00ol0003oooooooooo`0Pooooo`?o00001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02Oooool002Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Vooooo`03o`000?nBUmGoTYOE00GoTYOE00Co0000
oiR<a_nHS<Ko00004?nERlH2o`0000GoTXW700?o0000oj29_?nPRK`06?nPRK`00ol0003o[Y2fojj@
]P0;ojj@]QCo00004?nlVK@3o`0000Co_9Vd00?o0000olZW]_o:YkH04oo:YkH4o`0000;obJJf00?o
0000omFf^ooE][/01?oE][/00ol0003oeKJkomFf^`04omFf^`;o00002ooC]K/2o`0002?ooooo00?o
0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03
o`000?nBUmGoTYOE00KoTYOE0_l0000?oiF;aP?o00001onBRLL00ol0003oX8Vloj29_00Eoj29_17o
00003_n^T;L00ol0003o_9ZeokbJ]@03okbJ]@Wo00001?nlVK@3o`0000Oo_9Vd00?o0000olZW]_o:
YkH05oo:YkH3o`0000OoeKJk00?o0000omFf^ooE][/01OoE][/2o`0000SodkFk00Co0000om_6a?oK
a/Co00008oooool00ol0003oooooooooo`0Nooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03
ooooo`?o00008Oooool00ol0003oooooooooo`0Rooooo`03o`000?nBUmGoTYOE00KoTYOE00?o0000
ohjEe_l000003OnERlH2o`0000_oTXW700?o0000oj29_?nPRK`03_nPRK`6o`0000?oWXVm00?o0000
ojj@]on^T;L06On^T;L00ol0003o_9ZeokbJ]@0<okbJ]@Wo00001?nlVK@00ol0003obZNfolZW]P0I
olZW]P04o`000?oF]k_o0000o`0000GoeKJk00?o0000omFf^ooE][/01ooE][/2o`0000KodkFk00Go
0000om_6a?oKa/CoflK4o`00000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00008oi:Ge@05o`00
0?n>UMKoSYGFohjEe_l000002_nERlH2o`0000goTXW700?o0000oj29_?nPRK`01onPRK`7o`0000Wo
WXVm00?o0000ojj@]on^T;L06On^T;L00ol0003o_9ZeokbJ]@0;okbJ]@?o00001onlV[D7o`0001So
bZNf00?o0000omJg^ooF]k/00_oF]k/2o`0000CoeKJk00?o0000omFf^ooE][/02?oE][/2o`0000?o
dkFk00?o0000om_6a?oKa/@00ooKa/@00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01go
oooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03
ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03
o`000?nBUmGoTYOE00OoTYOE00?o0000ohjEe_n>UMH00_n>UMH00ol0003oUH_6oiF;aP05oiF;aP?o
00003onBRLL01?l0003oX8Vloj29_?nPRK`6o`00017oWXVm00?o0000ojj@]on^T;L06?n^T;L00ol0
003o_9ZeokbJ]@08okbJ]@?o00003_nlV[D00ol0003obZRfolZX]P04o`0001CobZNf00?o0000omJg
^ooF]k/01?oF]k/2o`0000?oeKJk00?o0000omFf^ooE][/02OoE][/2o`000003om>e^ol0003oflK4
00GoflK400?o0000ooooooooool08?ooool2o`0001gooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0Tooooo`;o00007?ooool00ol0003oTYOEoi:Ge@07oi:Ge@03o`000?n>UMKo
SYGF00CoSYGF00?o0000oiF;a_nERlH00_nERlH2o`0001;oTXW71?l0000Goij9_@03o`000?n^T;Oo
[Y2g01So[Y2g00?o0000okbJ]OnlV[D01OnlV[D3o`00017o_9Ze00?o0000olZX]_o:Z;H01?o:Z;H4
o`00013obZNf00?o0000omJg^ooF]k/01_oF]k/2o`0000;oeKJk00?o0000omFf^ooE][/02_oE][/2
o`0000OoflK400?o0000ooooooooool07_ooool00ol0003oooooo`00000Mooooo`001_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`03o`000?nBUmGoTYOE00KoTYOE0_l00007
ohjEeP03o`000?nERlKoUH_600;o00004OnBRLL3o`000003ohn9b?l0003oWXVm01SoWXVm00?o0000
ojj@]on^T;L06?n^T;L00ol0003o_9ZeokbJ]@02okbJ]@?o00005?nlV[D00ol0003obZRfolZX]P08
olZX]PGo00002_o:YkH00ol0003oe[NkomJg^`09omJg^`?o00003?oE][/00ol0003og/W4o`000007
om_6a003o`000?oooooooooo01oooooo00?o0000ooooooooool06oooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool05_ooool00ol0003oTYOEoi:G
e@06oi:Ge@03o`000?n>UMKoSYGF00OoSYGF0_l0000Aoi:9a`?o00001?n?RLP00ol0003oWXVmoij9
_@0Goij9_@03o`000?n^T;Oo[Y2g01So[Y2g00?o0000okbJ]Ol000000_l0000GokbJ]@03o`000?o:
Z;KobZRf00gobZRf1?l00006olZW]P03o`000?oF]k_oe[Nk00coe[Nk0_l00009omFf^`05o`000?oN
bLCog/W4omk9a?l000001ooKa/@00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01[ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05?ooool00ol0003o
TYOEoi:Ge@06oi:Ge@03o`000?n>UMKoSYGF00OoSYGF00?o0000ohRDfOl000003_nBRLL3o`0000So
ShW800?o0000oij9_OnNRKd05onNRKd00ol0003o[Y2gojj@]`0Fojj@]`?o00006OnlV[D00ol0003o
bZRfolZX]P0BolZX]PCo00000_o:YkH00ol0003oe[NkomJg^`0=omJg^`?o00001_oE][/00ol0003o
g/W4omk9a003omk9a003o`000?oKa/CoflK400GoflK400?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Jooooo`009oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01;ooooo
00?o0000oi:GeOnBUmD01_nBUmD00ol0003oSYGFohjEeP07ohjEeP05o`000?n8U=WoR9CIohRDfOl0
00002onBRLL2o`0000_oShW800?o0000oij9_OnNRKd05?nNRKdUo`0001?o_9Ze00?o0000olZX]_o:
Z;H05_o:Z;H3o`0000ooe[Nk00?o0000omJg^ooF]k/00_l00004omFf^`03o`000?oNbLCog/W400Co
g/W400?o0000om_6a?oKa/@01OoKa/@00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Wo
oooo000Wooooo`;o0000;?ooool00ol0003oooooooooo`0@ooooo`03o`000?nBUmGoTYOE00GoTYOE
0_l00008ohjEeP;o00001?n8U=T00ol0003oTXW7oi:9a`06oi:9a`?o00003On?RLP00ol0003oWXVm
oij9_@0>oij9_@Ko00000onMRKh00ol0003o[I2hojf@^00@ojf@^0?o00001?n]T;P00ol0003o_9^f
okbK]P05okbK]Pgo00001_nlV[D00ol0003obZRfolZX]P0GolZX]P04o`000?oG^Kco0000o`0000ko
e[Nk00Co0000omJg^ooF]k_oe[Nk0_l000000ooE][_o0000omk9a007omk9a003o`000?oKa/CoflK4
00GoflK400?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00?o0000oi:GeOnBUmD01OnBUmD00ol0003o
SYGFohjEeP07ohjEeP03o`000?n8U=WoR9CI00GoR9CI00?o0000oi:9aonBRLL00_nBRLL3o`00013o
ShW800?o0000oij9_OnNRKd01onNRKd7o`0000WoWHVn00?o0000ojf@^?n]T;P03On]T;P3o`0000Oo
[I2h00?o0000okbK]_nlVkH04_nlVkH9o`0001OobZRf00Co0000omNi_?oG^KcoekVl0ol0000<omJg
^`03o`000?oF]k_oe[Nk00;oe[Nk0_l00009omk9a003o`000?oKa/CoflK400GoflK400?o0000oooo
ooooool07?ooool2o`0001[ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool03Oooool2o`0000GoTYOE00?o0000ohjEe_n>UMH01on>UMH00ol0003oR9CIohRDf@06ohRDf@03
o`000?nBRLOoTXW700;o00005?n?RLP00ol0003oWXVmoij9_@06o`00013oWHVn00?o0000ojf@^?n]
T;P02_n]T;P3o`0000[o[I2h00?o0000okbK]_nlVkH06?nlVkH00ol0003objVhol^Y^004o`0001;o
bZRf00?o0000omNi_?oG^K`01OoG^K`2o`0000_oe[Nk00Oo0000omJg^ooF]k_oe[Nko`000?oOc<Go
000000Wog/W400?o0000om_6a?oKa/@01OoKa/@00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01Oooooo000Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool01?l0
003oVZoVoiZ_i_l00003oi:Ge@03o`000?n>UMKoSYGF00KoSYGF0_l00009ohRDf@;o00005On?RLP5
o`0001KoWHVn00?o0000ojf@^?n]T;P01on]T;P3o`0000go[I2h00?o0000okbK]_nlVkH06?nlVkH0
0ol0003objVhol^Y^004ol^Y^0Co00003_o:Z;H00ol0003oekVlomNi_007omNi_0;o00002OoF]k/0
1?l0003oe[NkomJg^ol00003omo<a@03o`000?oNbLCog/W400Oog/W400?o0000om_6a?oKa/@01OoK
a/@00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Wooooo`;o0000<?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?nJ[nKoVZoVoiZ_i_l000000_nBUmD8ohjEeP03o`000?n8
U=WoR9CI00OoR9CI0_l000000on3U=co0000ohn9b00@ohn9b0Co00000_n;R</00ol0003oWHVnoif9
_P0Goif9_P03o`000?n]T;So[I2h00?o[I2h0ol0000@ojf@^003o`000?nlVkKo_9^f01Oo_9^f00?o
0000ol^Y^?o;ZKP02Oo;ZKP4o`0000[obZRf00?o0000omNi_?oG^K`02OoG^K`2o`0000Soe[Nk00?o
0000omJg^ol000001?oOc<D00ol0003og/W4omk9a007omk9a003o`000?oKa/CoflK400GoflK400?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`009_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Sooooo00?o0000oiZ_i_nJ[nH00onJ[nH00ol0003oSYGFohjEeP06
ohjEeP03o`000?n8U=WoR9CI00OoR9CI00?o0000oh>Dg?n3U=`00_n3U=`00ol0003oShW8ohn9b00:
ohn9b0Co00001on;R</00ol0003oWHVnoif9_P0Foif9_P04o`000?n]T;So[I2hojf@^0;o00004on]
T;P00ol0003o_9^fokbK]P0GokbK]P03o`000?o;ZKSobjVh00gobjVh1?l00006olZX]P03o`000?oG
^KcoekVl00_oekVl0_l00007omJg^`03o`000?oOc<Goglc500Coglc500?o0000omk9a?oNbL@01ooN
bL@00ol0003oflK4om_6a005om_6a003o`000?oooooooooo01cooooo00?o0000ooooooooool05Ooo
ool002Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`03o`000?nJ[nKo
VZoV00?oVZoV0_l00005ohjEeP;o00002?n8U=T2o`0000KoPiCL00?o0000ohn9b?n?RLP01On?RLP4
o`0000_oRhS;00?o0000oif9__nMRKh05_nMRKh4o`0001Go[I2h00?o0000okbK]_nlVkH05onlVkH0
0ol0003objVhol^Y^00Aol^Y^0Co000000?obZRfo`000?oG^K`03ooG^K`3o`0000?oe[Nk00?o0000
omo<aOl000001_oOc<D00ol0003og/W4omk9a007omk9a003o`000?oKa/CoflK400?oflK40_l0000N
ooooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`03o`000?nJ[nKoVZoV00?oVZoV00Co0000oiF_jOnE[nWo00001?n>UMH8ohRDf@;o00002On3U=`0
0ol0003oShW8ohn9b004o`00013oRhS;00?o0000oif9__nMRKh04OnMRKh5o`000003ojf@^?l0003o
000001Ko000000Co_9^fo`000?l0003o00005OnlVkH00ol0003objVhol^Y^00Eol^Y^0?o00004_oG
^K`2o`000004omJg^ol0003oglc5o`0000Ooglc500?o0000omk9a?oNbL@01ooNbL@01Ol0003oflK4
om_6a?oKa/Co000000;ofmOC00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Dooooo`00
9_ooool3o`0003Cooooo00?o0000ooooooooool01?ooool00ol0003oVZoVoiZ_iP02oiZ_iP03o`00
0?nE[nWoUJoY00;oUJoY00?o0000ohjEe_n>UMH02?n8U=T00ol0003oPiCLoh>Dg009oh>Dg0?o0000
5?n;R</00ol0003oWHVnoif9_P09oif9_P[o00000_nKR/400ol0003o[96jojbA^P0FojbA^P03o`00
0?nlWKSo_9fh00;o_9fh2Ol0000<okbK]P03o`000?o;ZKSobjVh01KobjVh00?o0000omRl_Ol00000
0_l0000AomNi_0;o00000_oOc<D00ol0003oglc5omo<a@05omo<a@03o`000?oNbLCog/W400Oog/W4
00?o0000om_6a?l000000ooKem<00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo
000Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool00_ooool00ol0003oVZoVoiZ_
iP03oiZ_iP03o`000?nE[nWoUJoY00?oUJoY0_l00006ohRDf@;o00002_n3U=`2o`000003ogbDgol0
003oRhS;01CoRhS;00?o0000oif9__nMRKh00_nMRKh7o`0000CoVh[10ol00005oi^:`@03o`000?n/
TK[o[96j01Ko[96j00?o0000okbM^?nlWKP02onlWKP8o`0000?o_9^f00?o0000ol^Y^?o;ZKP05_o;
ZKP00ol0003of;bmomRl_@03omRl_@?o00003_oG^K`00ol0003ohLo6o`000002omo<a@03o`000?oO
c<Goglc500Goglc500?o0000omk9a?oNbL@01ooNbL@00ol0003ofmOCom_Gd`02om_Gd`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool04_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00001OnJ[nH00ol0003oUJoY
oiF_j@04oiF_j@03o`000?n>/>go000000CoR9CI00?o0000oh>Dg?n3U=`02On3U=`00ol0003oO9CO
ogbDg`02ogbDg`03o`000?n;R<_oRhS;017oRhS;1_l00008oi^:`@?o00002?nKR/400ol0003o[96j
ojbA^P0FojbA^P03o`000?nlWKSo_9fh01?o_9fh1ol0000Eol^Y^003o`000?oH_;gof;bm00Kof;bm
0ol0000:omNi_004o`000?oQclKohLo6on7?aP;o000000?oglc5o`000?oOc<D01_oOc<D00ol0003o
g/W4omk9a005omk9a0;o00001OoKem<00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;o
oooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`?o
00001OnJ[nH00ol0003oUJoYoiF_j@03oiF_j@05o`000?n>/>goS[3]ohj`kOl000000_n8U=T;oh>D
g0;o00001OmlU=l00ol0003oRhS;oh^8b`0<oh^8b`Go00000_n7RLh00ol0003oVh[1oi^:`@06oi^:
`@?o00002onKR/400ol0003o[96jojbA^P0FojbA^P03o`000?nlWKSo_9fh01Ko_9fh00Co0000ol^/
^_o;[;[objbj1_l0000>ol^Y^003o`000?oH_;gof;bm00[of;bm0_l00008omNi_003o`000?oQclKo
hLo600?ohLo60_l00008omo<a@03o`000?oNbLCog/W400?og/W400Co0000omkLe?oNg=Co00001?oK
em<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo1?l000000ol@413ooooooooo
o`03ooooo`006oooool01Ol@413ooooooooooooooooo410@00Gooooo0ol0000iooooo`03o`000?nJ
[nKoVZoV00?oVZoV00?o0000oiF_jOnE[nT00onE[nT00ol0003oS[3]ohj`k@03ohj`k@;o00002On3
U=`2o`0000SoO9CO00?o0000oh^8bon;R</01_n;R</5o`0000SoQhW>00?o0000oi^:`OnKR/400_nK
R/43o`0000ooVh[100?o0000ojbA^_n/TKX05On/TKX00ol0003o_9fhokbM^00FokbM^003o`000?o;
[;[objbj00Oobjbj1Ol00009ol^Y^003o`000?oH_;gof;bm00cof;bm0ol00004omNi_003o`000?oQ
clKohLo600GohLo60_l00008omo<a@05o`000?oNbLCog/W4omk9a?l000000ooNg=@00ol0003ofmOC
om_Gd`03om_Gd`03o`000?oooooooooo01cooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo
000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0iooooo`03o`00
0?nJ[nKoVZoV00;oVZoV00?o0000oiF_jOnE[nT01?nE[nT00ol0003oS[3]ohj`k@03ohj`k@03o`00
0?n6/_;o000000KoPiCL0_l0000:ogbDg`04o`000?n;R<_oRhS;oh^8b`Go00003On7RLh00ol0003o
Vh[1o`000002o`0001;oVh[100?o0000ojbA^_n/TKX05On/TKX00ol0003o_9fhokbM^00FokbM^003
o`000?o;[;[objbj00cobjbj1_l00003ol^Y^003o`000?oH_;gof;bm00oof;bm0ol000000ooG^Kco
0000on7?aP07on7?aP;o00002?oOc<D00ol0003og/W4o`000005omkLe003o`000?oKem?ofmOC00;o
fmOC00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo000Kooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0hooooo`03
o`000?nJ[nKoVZoV00?oVZoV00?o0000oiF_jOnE[nT00onE[nT00ol0003oS[3]ohj`k@03ohj`k@05
o`000?n6/_;oQ[;bohJbl_l000001?n3U=`00ol0003oO9COogbDg`0:ogbDg`Co00004On7RLh3o`00
01GoVh[100?o0000ojbA^_n/TKX05On/TKX00ol0003o_9fhokbM^00FokbM^003o`000?o;[;[objbj
01;objbj1Ol0000ComRl_@;o00002_oQclH00ol0003oglc5omo<a@06omo<a@03o`000?oNg=Cog]cD
00Cog]cD00?o0000om_GdooKem<00ooKem<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool001_ooooo00Go410@oooooooooooooooooa0@4005oooo
o`03o`000?oooooooooo03Sooooo00?o0000oiZ_i_nJ[nH00_nJ[nH00ol0003oUJoYoiF_j@03oiF_
j@03o`000?n>/>goS[3]00?oS[3]00?o0000ohJbl_n6/_800on6/_801?l0003oPiCLoh>Dg?l0000;
ogbDg`;o000000?oLiCTo`000?n7RLh03on7RLh3o`0000;oQhW>00?o0000oi^:`OnKR/402?nKR/4<
o`000003ojbA^_l0003o000001Go00000_nlWKP2o`0001?o_9fh00?o0000ol^/^_o;[;X05Oo;[;X0
0ol0003ofKo0omVo`003o`00013of;bm00?o0000on;Db?l000002OoQclH3o`0000Goglc50_l00007
omkLe003o`000?oKem?ofmOC00;ofmOC00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
o`0003Sooooo00?o0000oiZ_i_nJ[nH00onJ[nH00ol0003oUJoYoiF_j@03oiF_j@03o`000?n>/>go
S[3]00;oS[3]00?o0000ohJbl_n6/_801On6/_800ol0003oO9COogbDg`09ogbDg`;o00001?mcU>@0
0ol0003oQhW>ohN9cP0:ohN9cP?o00000_n7RLh>o`0000_oV8c500?o0000oj^C_On[Tkd05On[Tkd0
0ol0003o_9nkokbO^`02okbO^`So00002onlWKP00ol0003objbjol^/^P0Dol^/^P03o`000?oI_l3o
fKo000CofKo00ol0000<omRl_@04o`000?oRe<Soh]C8on;Db0;o00002?oQclH00ol0003ohLo6o`00
0003omo<a@04o`000?oOhMKogn7Fo`0000Kog]cD00?o0000om_GdooKem<00_oKem<00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool001_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo00?o0000oiZ_i_nJ[nH0
0_nJ[nH00ol0003oUJoYoiF_j@03oiF_j@03o`000?n>/>goS[3]00?oS[3]00?o0000ohJbl_n6/_80
1On6/_82o`0000OoO9CO0ol00007og>Di003o`000?n7RLkoQhW>00KoQhW>2?l00003oh::d`03o`00
0?nHS<GoV8c501?oV8c500?o0000oj^C_On[Tkd05On[Tkd00ol0003o_9nkokbO^`0:okbO^`So0000
0onlWKP00ol0003objbjol^/^P0Dol^/^P03o`000?oI_l3ofKo000OofKo00ol00008omRl_@03o`00
0?oRe<Soh]C800Coh]C800?o0000on7?a_oQclH01_oQclH01Ol0003ohLo6o`000?oOc<Go000000?o
gn7F00?o0000omkLe?oNg=@01OoNg=@00ol0003ofmOCom_Gd`02om_Gd`03o`000?oooooooooo01ko
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oooooo
0_l00003oiZ_iP03o`000?nE[nWoUJoY00?oUJoY00?o0000ohj`kOn>/>d00on>/>d00ol0003oQ[;b
ohJblP05ohJblP04o`000?mk/_KoNk;fo`0000CoO9CO0_l0000;og>Di004o`000?n7RLkoQhW>ohN9
cPKo00002On2R]<00ol0003oV8c5oiR<a@0CoiR<a@03o`000?n[TkgoZi>m01GoZi>m00?o0000okbO
^onlWk/04_nlWk/4o`0000;objbj0_l0000Aol^/^P03o`000?oI_l3ofKo000_ofKo00ol00005omRl
_@03o`000?oRe<Soh]C800Goh]C80_l00007on7?aP03o`000?oQclKo000000Gogn7F00?o0000omkL
e?oNg=@01?oNg=@00ol0003ofmOCom_Gd`02om_Gd`03o`000?oooooooooo01gooooo00?o0000oooo
ool000001Oooool00omEEEGoIVIVo`000007ooooo`009?ooool00ol0003oooooooooo`0gooooo`06
o`000?nbbN_o0000o`000?nJ[nKo00001OnE[nT00ol0003oS[3]ohj`k@02ohj`k@03o`000?n6/_;o
Q[;b00GoQ[;b00?o0000og^bm_mk/_H00_mk/_H01?l0003oO9COogbDgol0000<og>Di0Ko00003on2
R]<00ol0003oV8c5oiR<a@0CoiR<a@03o`000?n[TkgoZi>m01CoZi>m00?o0000okbO^onlWk/05Onl
Wk/00ol0003objnmol^__@02ol^__@Oo00002_o;[;X00ol0003ofKo0omVo`00>omVo`0?o000000?o
f;bmo`000?oRe<P02OoRe<P00ol0003ohLo6on7?aP04on7?aP03o`000?oQclKo000000Gogn7F00?o
0000omkLe?oNg=@01?oNg=@00ol0003ofmOCom_Gd`03om_Gd`03o`000?oooooooooo01oooooo00?o
0000ooooooooool03?ooool002Cooooo0_l0000hooooo`04o`000?nbbN_o//W[ok;9j`Co00000_nE
[nT00ol0003oS[3]ohj`k@03ohj`k@03o`000?n6/_;oQ[;b00CoQ[;b00?o0000og^bm_mk/_H00omk
/_H3o`0000[oLiCT0ol000001?mWU>So0000o`000?l0000Aoh::d`03o`000?nHS<GoV8c501?oV8c5
00?o0000oj^C_On[Tkd05?n[Tkd00ol0003o_9nkokbO^`0EokbO^`03o`000?o;[kgobjnm00Wobjnm
1ol00003ol^/^P03o`000?oI_l3ofKo0017ofKo00_l0000;on;Db003o`000?oQclKohLo600CohLo6
00?o0000on3Vf?l000001OoOhMH00ol0003og]cDomkLe004omkLe003o`000?oKem?ofmOC00;ofmOC
00?o0000ooooooooool07_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo03Oooooo00Go
0000ok;9jonbbN_o//W[o`000003ok3>k`?o00001?n>/>d00ol0003oQ[;bohJblP04ohJblP03o`00
0?mk/_KoNk;f00?oNk;f00Go0000ofbbn_m//_[oK;;jo`000006og>Di0?o000000CoIiCXo`000?l0
003o00000_mWU>P00ol0003oPX[Coh::d`0?oh::d`03o`000?nHS<GoV8c501?oV8c500?o0000oj^C
_On[Tkd05?n[Tkd00ol0003o_9nkokbO^`0DokbO^`03o`000?o;[kgobjnm017objnm1Ol0000BomVo
`004o`000?oSfLco0000o`0000[oh]C80_l00003on7?aP05o`000?oPi]So0000on3Vf?l000001OoO
hMH00ol0003og]cDomkLe003omkLe003o`000?oKem?ofmOC00;ofmOC00?o0000ooooooooool06ooo
ool3o`0000;ooooo00?o0000ooooooooool02oooool002Cooooo00?o0000ooooooooool0=oooool0
1Ol0003o//W[ok;9jonbbN_o000000Co/<k_00Ko0000ojcBm?l0003o0000ohj`kOl00006ohJblP03
o`000?mk/_KoNk;f00?oNk;f00?o0000ofbbn_m//_X00om//_X00ol0003oLiCTog>Di003o`000004
ofNDj?l0003o0000o`0000KoIiCX00?o0000oh::don2R]<03on2R]<00ol0003oV8c5oiR<a@08oiR<
a@_o000000?oZi>mo`000?l000002Ol0000:oj^C_@03o`000?nlWk_o_9nk01Co_9nk00?o0000ol^_
_Oo;[kd04oo;[kd00ol0003of/C4om[4a003o`0000kofKo000?o0000on?Ic?oSfL`00_oSfL`2o`00
00[oh]C800?o0000on7?a_l000000ooPi]P2o`0000Gogn7F00?o0000omkLe?oNg=@01?oNg=@01?l0
003ofmOCom_GdooKem<2o`0001Wooooo0ol00005ooooo`03o`000?oooooooooo00_ooooo000Toooo
o`03o`000?oooooooooo03Kooooo00?o0000ok;9jonbbN/00_nbbN/00ol0003o/<k_ok3>k`02ok3>
k`04o`000?n/d_Co[=;dojcBm0;o00001On6/_800ol0003oNk;fog^bmP02og^bmP;o00001_m//_X3
o`000004ofNDj?l0003o0000o`0000WoIiCX00?o0000oh::don2R]<01on2R]<Co`0000[oUHk900?o
0000ojZF`_nZU/802_nZU/8;o`000003okbO^ol0003o000000?o00004?nlWk/00ol0003objnmol^_
_@0Col^__@03o`000?oJa<Cof/C400?of/C41?l0000:omVo`003o`000?oSfLcohmW<00CohmW<0_l0
0009on;Db003o`000?oPi]Soh>KH00;oh>KH00?o0000on3Vf?l000001OoOhMH00ol0003og]cDomkL
e003omkLe006o`000?oKem?o0000o`000?o<gNGo00005Oooool4o`0000Sooooo00?o0000oooooooo
ool02oooool002?ooooo0ol0000gooooo`03o`000?nbbN_o//W[00;o//W[00?o0000ok3>kon`c^l0
0_n`c^l01_l0003o[=;dojcBm?n/d_Co0000ojKGn@?o000000?oQ[;bo`000?mk/_H00omk/_H00ol0
003oK;;jofbbnP05ofbbnP03o`000?mH/?_o000000;o00002_mWU>P<o`0000SoNhcH00?o0000oiF>
bOnES/T04_nES/T00ol0003oZYK2ojZF`P0DojZF`P03o`000?nkX[oo^j:o00Co^j:o2ol00004okbO
^`03o`000?o;[kgobjnm01?objnm00?o0000om[4a?oJa<@02?oJa<@4o`0000GofKo000?o0000on?I
c?oSfL`01ooSfL`00ol0003oh]C8on;Db005on;Db0;o00001OoPi]P00ol0003oh>KHo`000004omoQ
eP03o`000?oNg=Cog]cD00?og]cD0_l00003olcMi@03o`000?oooooooooo013ooooo0ol0000=oooo
o`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o0000ok;9jonb
bN/00_nbbN/01Ol0003o/<k_ok3>kon`c^oo000000Co[=;d00?o0000ojKGnOnVeoT00_nVeoT3o`00
00;oNk;f00?o0000ofbbn_m//_X01?m//_X4o`0000?oF;3k00Co0000ofNDj?mWU>SoIiCX1_l00004
oeRCk@03o`000?mkS=SoNhcH00koNhcH00?o0000oiF>bOnES/T04OnES/T00ol0003oZYK2ojZF`P0D
ojZF`P03o`000?nkX[oo^j:o00oo^j:o1Ol00002ol^__@;o00004Oo;[kd00ol0003of/C4om[4a00<
om[4a0?o00000_oI_l000ol0003ohmW<on?Ic008on?Ic0;o00001?oRe<P01?l0003ogncJomo/f_l0
0005on3Vf0;o00001OoOhMH00ol0003og]cDomkLe002o`000003olgSj?l0003oc=gU00;oc=gU00?o
0000ooooooooool03Oooool3o`00013ooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000
ooooooooool0=oooool00ol0003o//W[ok;9j`02ok;9j`05o`000?n`c^oo/<k_ok3>kol000001?n/
d_@00ol0003oY]OiojKGn@02ojKGn@03o`000?nLf_goW=[m00?o00001?m//_X3o`0000KoF;3k1?l0
000;oeRCk@03o`000?mkS=SoNhcH00koNhcH00?o0000oiF>bOnES/T04OnES/T00ol0003oZYK2ojZF
`P0CojZF`P03o`000?nkX[oo^j:o01?o^j:o00?o0000olbb`Oo<//400_o<//47o`0000[objnm00?o
0000om[4a?oJa<@03ooJa<@3o`0000cohmW<0_l000000ooRe<So0000omo/fP03omo/fP03o`000?oP
i]Soh>KH00?oh>KH0_l00004omoQeP03o`000?oNg=Co000000?ocN?X00Go0000olcMiOo<gNGoc=gU
o`00000;ooooo`Co00004oooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003ooooooooo
o`0gooooo`03o`000?nbbN_o//W[00;o//W[00Go0000ok3>kon`c^oo/<k_o`000004ojcBm003o`00
0?nVeoWoY]Oi00;oY]Oi00Ko0000oicJoOnLf_goW=[mo`000?n=g?l5o`0000KoF;3k0_l00003ocfX
mP03o`000?mHTngoF9?]00[oF9?]00?o0000og^<f?mkS=P03OmkS=P00ol0003oUHk9oiF>b@0AoiF>
b@03o`000?nZU/;oZYK201?oZYK200?o0000ok^R_onkX[l04onkX[l00ol0003oc;;1olbb`@09olbb
`@Oo00000_o;[kd00ol0003of/C4om[4a00Aom[4a004o`000?oSgm3o0000o`0000cohmW<00?o0000
omo/f_oOk=X00ooOk=X00ol0003oh>KHon3Vf003on3Vf0;o00001?oOhMH2o`0000CocN?X00Go0000
olcMiOo<gNGoc=gUo`000008ooooo`?o00005oooool00ol0003oooooooooo`0:ooooo`008oooool3
o`0003Oooooo00Go0000ok;9jonbbN_o//W[o`000004ok3>k`03o`000?n/d_Co[=;d00;o[=;d00?o
0000ojKGnOnVeoT00_nVeoT01?l0003oW=[moicJoOnLf_d3o`0000;oSMco1?l00002oeR`n`;o0000
1_lmZ?H00ol0003oF9?]oeRCk@04oeRCkAOo000000?oUHk9o`000?l000001ol00008oiF>b@03o`00
0?nZU/;oZYK201?oZYK200?o0000ok^R_onkX[l04onkX[l00ol0003oc;;1olbb`@0@olbb`@?o0000
4_oJa<@00ol0003ohmo@on?Od002on?Od0?o00001ooSfL`00ol0003ogO;Mo`000006omo/fP03o`00
0?oPi]Soh>KH00?oh>KH0_l000001OoOhMKo0000o`000?o<jN_o000000CocN?X00Go0000olcMiOo<
gNGoc=gUo`000005ooooo`?o00006_ooool00ol0003oooooooooo`0:ooooo`008oooool00ol0003o
ooooooooo`0gooooo`05o`000?nbbN_o//W[ok;9jol000001?n`c^l01Ol0003o[=;dojcBm?n/d_Co
000000GoY]Oi1Ol00004ohgLo`04o`000?mgfOcoMmWlogOIo0?o00001olmZ?H7o`0000Ko@i7_00?o
0000og6>gomaS]l03OmaS]l00ol0003oTI7?oi6Ac`08oi6Ac`Wo000000?oZYK2o`000?l000002?l0
000:ojZF`P03o`000?nkX[oo^j:o01;o^j:o00?o0000olbb`Oo<//404oo<//401?l0003of/W9om[9
bOoJbLT5o`0000Wof/C400?o0000on?Od?oSgm001_oSgm02o`0000CohmW<00Go0000omgbgOoMl]go
gO;Mo`000006omo/fP03o`000?oPi]Soh>KH00?oh>KH0_l00003olcYj`03o`000?o=hnSocN?X00;o
cN?X00Go0000olcMiOo<gNGoc=gUo`000002ooooo`?o00007Oooool00ol0003oooooooooo`0:oooo
o`0000Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo03Sooooo00Go0000ok;9jonbbN_o//W[o`00
0004ok3>k`05o`000?n/d_Co[=;dojcBm?l000000onVeoT3o`0000;oW=[m00?o0000ohgLoon=g?l0
0on=g?l00ol0003oMmWlogOIo002ogOIo004o`000?mIc_3o0000o`0000;o?JSf0ol00003oabKi`;o
00002Om3TNl00ol0003oLHkOog6>g`0=og6>g`03o`000?nATLooTI7?00ooTI7?00?o0000ojRIaonX
VLL02OnXVLL;o`000003ok^R_ol0003o000000;o00003onkX[l00ol0003oc;;1olbb`@0Bolbb`@03
o`000?oJbLWof/W900Oof/W91Ol00003om[4a003o`000?oSgm3ohmo@00Wohmo@0_l000000ooSfLco
0000omgbg@04omgbg@03o`000?oOk=[ogncJ00?ogncJ00Co0000on3Vf?oPi]Soh>KH1?l00003olcY
j`03o`000?o=hnSocN?X00;ocN?X00Co0000olcMiOo<gNGoc=gU0ol0000Pooooo`03o`000?oooooo
oooo00[ooooo00001OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Sooooo00Go
0000ok;9jonbbN_o//W[o`000004ok3>k`04o`000?n/d_Co[=;dojcBm0Co000000?oY]Oio`000?nL
f_d00_nLf_d00ol0003oSMcoohgLo`02ohgLo`03o`000?mgfOcoMmWl00?oMmWl00Co0000oeW>l?mI
c_3oFLk`1?l00006oabKi`03o`000?m3TNoo@i7_00Oo@i7_00?o0000og6>gomaS]l03?maS]l00ol0
003oTI7?oi6Ac`0@oi6Ac`03o`000?nXVLOoZ9W701;oZ9W700?o0000ok^Va?nkY/@00onkY/@;o`00
00Co^j:o00?o0000olbb`Oo<//404_o<//400ol0003of/W9om[9b@0<om[9b@?o00003_oSgm02o`00
00KogO;M00?o0000omo/f_oOk=X00ooOk=X00ol0003oh>KHo`000003olS_k@05o`000?o<jN_oc>W[
olcYjol000001?o=hnP01Ol0003oc=gUolcMiOo<gNGo000002?ooooo00?o0000ooooooooool02Ooo
ool00005oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oo
oooooooo00;ooooo0_l0000hooooo`03o`000?nbbN_o//W[00;o//W[00Go0000ok3>kon`c^oo/<k_
o`000003ojcBm0;o00001?nVeoT01Ol0003oW=[moicJoOnLf_go000000CoSMco00?o0000ogOIo?mg
fO`00_mgfO`00ol0003oFLk`o`00000Co`0000?o@i7_00?o0000og6>gomaS]l03?maS]l00ol0003o
TI7?oi6Ac`0@oi6Ac`03o`000?nXVLOoZ9W701;oZ9W700?o0000ok^Va?nkY/@03_nkY/@5o`0000;o
c;;10ol0000>olbb`@03o`000?oJbLWof/W900oof/W900?o0000on;Ve_l000000_l00009on?Od004
o`000?oHn>3of?SPo`0000KogO;M00?o0000omo/f_oOk=X00_oOk=X2o`0000Cob>o]0_l00002olcY
j`03o`000?o=hnSocN?X00;ocN?X00Go0000olcMiOo<gNGoc=gUo`00000Sooooo`03o`000?oooooo
oooo00Wooooo00001Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Oooooo00?o0000ok;9jonbbN/00_nbbN/0
1?l0003o/<k_ok3>kon`c^l4o`000003ojcBm?l0003oY]Oi00?oY]Oi00?o0000oicJoOl000003Ol0
0004ojGcl@;o00001?n9k>P8o`0000;o9h_/3Ol00006og6>g`03o`000?nATLooTI7?00ooTI7?00?o
0000ojRIaonXVLL04_nXVLL00ol0003o^jK4ok^Va00Bok^Va003o`000?o;^<OobkS700?obkS72Ol0
0005olbb`@03o`000?oJbLWof/W900kof/W900?o0000on;Ve_oRi]H00ooRi]H3o`0000Gohmo@00?o
0000omShh?oHn>000_oHn>000ol0003ogO;Momgbg@04omgbg@06o`000?oOk=[o0000o`000?o2m>oo
00001?o8knd01Ol0003oc>W[o`000?o<jN_o000000CocN?X00Go0000olcMiOo<gNGoc=gUo`00000S
ooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0=ooo
ool00ol0003o//W[ok;9j`02ok;9j`03o`000?n`c^oo000000;o00000_n/d_@9o`0000;ob>W]00?o
0000ol;_lOo2ko400oo2ko400ol0003o]o?cokOcl`03okOcl`03o`000?nUlo7oYO?a00;oYO?a1?l0
0007olcgj@?o00000_lWRn`00ol0003o9h_/obN;k002obN;k003o`000?mSSnOoHhoW00CoHhoW1ol0
00000onATLoo0000o`000007o`0000SoTI7?00?o0000ojRIaonXVLL04OnXVLL00ol0003o^jK4ok^V
a00Aok^Va003o`000?o;^<OobkS700gobkS71Ol00002om[9b@;o00003?oJbLT00ol0003oh^KFon;V
eP07on;VeP?o000000?ohmo@o`000?oHn>001OoHn>000ol0003ogO;Momgbg@04omgbg@05o`000?o2
m>oo`_C_ol;dkol000001?o8knd01Ol0003oc>W[o`000?o<jN_o000000CocN?X00Go0000olcMiOo<
gNGoc=gUo`00000Sooooo`03o`000?oooooooooo00Wooooo00001Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Oooooo3?l00002olcMi@03o`000?o;hnWobn?Y00;obn?Y00?o0000olSYkOo8jNd00_o8jNd00ol0
003o`^oaol;_l@03ol;_l@03o`000?nglo?o]o?c00?o]o?c00Co0000ojGclOl0003o00001?oEl>D4
o`0000;oc?OY00Co0000om_NfOoKg]WofmkI0_l000000ol2OMko0000o`000004o`0000_oHhoW00?o
0000oh^Df?n;U=P02?n;U=P9o`000003ojRIaol0003o000000Oo00002OnXVLL00ol0003o^jK4ok^V
a00Aok^Va003o`000?o;^<OobkS7017obkS700?o0000om[@cooJd<l00_oJd<l7o`0000Cof/W900?o
0000on;Ve_oRi]H02ooRi]H2o`0000Oof?SP00?o0000omgbgOl000000_l000000ongmnoo0000ol;d
k`02ol;dk`03o`000?o8kngob>o]00;ob>o]00?o0000olcYjoo<jN/00_l00004olgSj005o`000?o<
gNGoc=gUolcMiOl000008oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06ooooo`;o
0000>?ooool4o`000003ol_Cgol0003oc=SR00;oc=SR00?o0000olcMiOo<gND00oo<gND00ol0003o
bn?Yol_Sj@02ol_Sj@03o`000?o8jNgob>W]00;ob>W]00?o0000ol;_lOo2ko400oo2ko400ol0003o
]o?cokOcl`02okOcl`;o00002_oEl>D2o`0000KofmkI00?o0000o`9mg_l2OMh00ol2OMh2o`0000;o
HhoW0_l00007of>?i`03o`000?n;U=SoRiCH00ooRiCH00?o0000ojFNc_nUW/h02?nUW/h:o`0000;o
^jK40ol0000>ok^Va003o`000?o;^<OobkS7013obkS700?o0000om[@cooJd<l02_oJd<l4o`0000go
h^KF00Co0000olklh_o>o>;o00001ooHn>000ol0003o]oO_okOgk`02okOgk`05o`000?o2m>oo`_C_
ol;dkol000001?o8knd01Ol0003oc>W[olcYjoo<jN_o000000CocN?X00Go0000olcMiOo<gNGoc=gU
o`00000Sooooo`03o`000?oooooooooo00Wooooo00001Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001?ooool2o`0003Oooooo1?l00004ol_Cg`05
o`000?o<f>;oc=SRolcHh_l000001?o<gND00ol0003obn?Yol_Sj@03ol_Sj@03o`000?o8jNgob>W]
00;ob>W]00?o0000ol;_lOo2ko400oo2ko401?l0003o]o?co`000?l00004omWYg`?o00001OoEl>D0
0ol0003og=KBomcFdP02omcFdPGo00001_l2OMh01?l0003oCY3]odj@kOm>T>d7o`000003of>?iol0
003oRiCH00ooRiCH00?o0000ojFNc_nUW/h04OnUW/h00ol0003o^J_<okV[c003okV[c0Wo00001?nk
Y/@00ol0003obkS7ol^ha`0@ol^ha`03o`000?oJd<oof]3?00kof]3?00?o0000omk^g?oNk]`01?l0
0006on;VeP03o`000?o>o>;oc_cR00;oc_cR0_l00003omShh003o`000?nUm^co000000Co]oO_00Go
0000ol;dkoo2m>oo`_C_o`000004olS_k@04o`000?o<jN_oc>W[olcYj`;o00000oo=hnP01Ol0003o
c=gUolcMiOo<gNGo000002?ooooo00?o0000ooooooooool02Oooool0027ooooo00?o0000oooooooo
ool0<oooool3o`0000?ooooo00?o0000ol_Cgoo;dml00_o;dml01Ol0003oc=SRolcHh_o<f>;o0000
00Goc=gU00?o0000ol_SjOo;hnT00_o;hnT00ol0003ob>W]olSYk@02olSYk@03o`000?o2ko7o`^oa
00?o`^oa0_l00009omWYg`?o000000?oeO3Uo`000?oLe]802_oLe]87o`0000WoCY3]0ol00002oh^D
f0;o00003?n;U=P00ol0003oYIk>ojFNcP0@ojFNcP03o`000?niZlco^J_<00co^J_<1Ol00002ol^h
a`Oo00002Oo;^<L00ol0003of]3?om[@c`0=om[@c`03o`000?oNk]cog^kL00Gog^kL0ol00002on;V
eP03o`000?o>o>;oc_cR00Goc_cR00?o0000omShh?l000000_nUm^`00ol0003o]oO_okOgk`02okOg
k`05o`000?o2m>oo`_C_ol;dkol000001?o8knd01?l0003oc>W[olcYjoo<jN/2o`0000?ocN?X00Go
0000olcMiOo<gNGoc=gUo`00000Tooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`000?oo
oooooooo033ooooo0ol00006ooooo`03o`000?o;dmoobm?O00;obm?O00?o0000olcHh_o<f>800_o<
f>800ol0003oc=gUolcMi@02olcMi@03o`000?o;hnWobn?Y00?obn?Y00?o0000olSYkOo8jNd00_o8
jNd00ol0003o`^oao`000002o`0000?ofn;K0_l00009omWYg`03o`000?oLe];og=KB00cog=KB00?o
0000om>na_l000000ol0000:odj@k@03o`000?n1VN7oPIWQ00;oPIWQ2Ol00003oh^Df003o`000?nU
W/koYIk>013oYIk>00?o0000okV[c?niZl`04?niZl`00ol0003obkk>ol^ncP07ol^ncPWo00000_oJ
d<l2o`0000_of]3?00?o0000omk^g?oNk]`02OoNk]`3o`0000Soc_cR00Go0000ojGfk?nUm^coYOK/
o`000004okOgk`05o`000?o2m>oo`_C_ol;dkol000001?o8knd01_l0003oc>W[olcYjoo<jN_o0000
olgSj0So00009?ooool00ol0003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0000:oooo
o`03o`000?o;dmoobm?O00;obm?O00Go0000olcHh_o<f>;oc=SRo`000005olcMi@03o`000?o;hnWo
bn?Y00;obn?Y00?o0000olSYkOo8jNd00_o8jNd3o`0000Oofn;K0_l00006omWYg`04o`000?oLd<go
g=3=omc@c@Co00001ooLe]800ol0003odkk6om>naP02om>naPWo00001?m>T>d00ol0003oPIWQoh6I
h@0:oh6Ih@Co000000?oYIk>o`000?l000000_l0000<ojFNcP03o`000?niZlco^J_<017o^J_<00?o
0000ol^nc_o;_/h03oo;_/h00ol0003of=SGomSHe`02omSHe`Oo00001?oJd<l00ol0003og^kLomk^
g008omk^g004o`000?nmoN7o_OgQokgmh@?o000000Koc_cRo`000?l0003o0000oh[]hOl00003ojGf
k003o`000?ngmnoo]oO_00;o]oO_00Go0000ol;dkoo2m>oo`_C_o`000002olS_k@[o000000?o[]3b
o`000?nac>d00_nac>d00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo000Qoooo
o`03o`000?oooooooooo02[ooooo0ol0000=ooooo`03o`000?o;dmoobm?O00;obm?O00?o0000olcH
h_o<f>800_o<f>800ol0003oc=gUolcMi@02olcMi@03o`000?o;hnWobn?Y00?obn?Y00Co0000olSY
kOl0003o00000ooKg=L00ol0003ofn;Kom_Rf`06om_Rf`03o`000?oIjMoofNWO00;ofNWO00?o0000
omc@cOoLd<d01_oLd<d4o`0000;og=KB00?o0000om>na_oC_/H01_oC_/H2o`0000Co;hc]1Ol0000?
oh6Ih@03o`000?nPY=SoX:CH00?oX:CH2Ol00003ojFNcP03o`000?niZlco^J_<013o^J_<00?o0000
ol^nc_o;_/h03oo;_/h00ol0003of=SGomSHe`0:omSHe`Co00000ooNk]`2o`0000Gog^kL00?o0000
okgmhOnmoN401OnmoN400ol0003oR^gQoh[]h@02oh[]h@05o`000?nUm^coYOK/ojGfk?l000000_ng
mnl9o`0000;oX]Wk00Go0000ojWEmonYeOOoZMGgo`000003ojk@lP05o`000?nac>go/Lc]ok7<kOl0
00009Oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?o0000
4?ooool00ol0003obm?Ool_Cg`03ol_Cg`05o`000?o<f>;oc=SRolcHh_l000001?o<gND00ol0003o
bn?Yol_Sj@03ol_Sj@?o00001OoKg=L2o`0000Oofn;K0_l000000ooIjMoo0000omc@c@0<omc@c@;o
00002ooC_/H00ol0003o;hc]obn<k@05obn<k@;o00003_n1VN400ol0003oX:CHoj2Tf00<oj2Tf0Co
00000_niZl`8o`0000So^J_<00?o0000ol^nc_o;_/h03oo;_/h00ol0003of=SGomSHe`0<omSHe`03
o`000?oGm^;oeoKR00CoeoKR1Ol00004okgmh@;o00000_mWf/h4o`000003oh[]hOl0003o000000Go
00000_n5g?h01Ol0003oUmcnoiOLo_nGg?ko000000?oX]Wk00Go0000ojWEmonYeOOoZMGgo`000004
ojk@lP05o`000?nac>go/Lc]ok7<kOl000009Oooool00ol0003oooooooooo`08ooooo`008?ooool0
0ol0003oooooooooo`0Uooooo`?o00005?ooool00ol0003obm?Ool_Cg`02ol_Cg`03o`000?o<f>;o
c=SR00;oc=SR00?o0000olcMiOo<gND00_o<gND00ol0003obn?Yol_Sj@02o`0000?of]OD00?o0000
om_LeooKg=L01?oKg=L00ol0003ofn;Kom_Rf`06om_Rf`03o`000?oLd<gog=3=00gog=3=00Co0000
om>j`_oC^/;odk[21Ol00004om>naPKo00000ol_S>d00ol0003oLIk/og6Nk005o`0000OoPIWQ00?o
0000oj2Tf?nPY=P03_nPY=P00ol0003o][;EokJbe@08okJbe@Wo000000?obkk>o`000?l000001_l0
0008ol^ncP03o`000?oHf=Oof=SG00_of=SG00?o0000omOfh_oGm^801ooGm^801_l0003oXOKIoj7f
fOnQm]Wo0000ocbn/PCo00000om=b>T2o`0000?oKMKh00?o0000ohGLo_n5g?h00on5g?h01Ol0003o
UmcnoiOLo_nGg?ko000000?oX]Wk00?o0000ojWEmonYeOL00_nYeOL02Ol0003o[]3bojk@l_n^d?;o
0000ok7<kOl0003o/Lc]o`00000Vooooo`03o`000?oooooooooo00Sooooo000Pooooo`03o`000?oo
oooooooo02;ooooo0ol0000Gooooo`03o`000?o;dmoobm?O00;obm?O00?o0000olcHh_o<f>800_o<
f>800ol0003oc=gUolcMi@02olcMi@03o`000?o;hnWo000000Kof]OD00?o0000om_LeooKg=L01?oK
g=L00ol0003ofn;Kom_Rf`04om_Rf`04o`000?oKblWofl_9om_;b@?o00002OoLd<d00ol0003odk[2
om>j`P07om>j`PGo000000?odkk6o`000?l3OMl00_l3OMl5o`0000KoLIk/1Ol00002oh6Ih@03o`00
0?nPY=SoX:CH00koX:CH00?o0000okJbeOnf/]D04?nf/]D00ol0003ob<OHolS7f007olS7f0So0000
0_oHf=L5o`0000Kof=SG00?o0000omOfh_oGm^800ooGm^83o`000003oj7ffOl0003o000000;o0000
00?o?;jbo`000?l000000ol00002odg8j@;o00000om]e_P2o`0000GoQMcn00Go0000oiOLo_nGg?ko
Umcno`000004oj;In`05o`000?nYeOOoZMGgojWEmol000001?n^d?800ol0003o/Lc]ok7<k@02o`00
02Kooooo00?o0000ooooooooool02?ooool0023ooooo0_l0000Qooooo`;o00006_ooool00ol0003o
bm?Ool_Cg`03ol_Cg`03o`000?o<f>;oc=SR00;oc=SR00Co0000olcMiOo<gNGoc=gU0ol00007om[G
e003o`000?oKg=OofmcG00CofmcG0_l00003om_Rf`03o`000?oKblWofl_900Gofl_90ol00005omc@
c@03o`000?oC^/;odk[200godk[20_l000001?o7[;oo0000o`000?l00003o`=mg`;o00002_maW^`3
o`0000;oX:CH0_l0000<oj2Tf003o`000?nf/]Go][;E00oo][;E00?o0000olS7f?o8amP03oo8amP0
0ol0003oe>;QomCRh@05omCRh@Ko000000CoeoKRo`000?l0003o00000_o7nnL00ol0003oNN?6ogWS
aP03ogWSaPOoCJki1Ol00002ofgFn003o`000?n5g?koQMcn00CoQMcn00Go0000oiOLo_nGg?koUmcn
o`000004oj;In`05o`000?nYeOOoZMGgojWEmol000001?n^d?800ol0003o/Lc]ok7<k@02ok7<k@03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool0023ooooo00?o0000ooooooooool0
7Oooool3o`0001gooooo00?o0000ol_Cgoo;dml00_o;dml00ol0003oc=SRolcHhP02olcHhP04o`00
0?o<gNGo0000o`0000?ofM;B00?o0000om[Ge?oJem@01OoJem@2o`0000KofmcG00?o0000om_Rfol0
00002ooKblT3o`0000;og=3=00?o0000om>j`_oC^/803_oC^/801?l0003oajVlolNY_?o7ZK`4o`00
0004o`=mgol0003oEYodoeJOm0Go00001OmaW^`00ol0003oV:_ToiR[i002oiR[i0Wo00000onPY=P0
0ol0003o][;EokJbe@0?okJbe@03o`000?o8amSob<OH00kob<OH00?o0000omCRhOoDh^402OoDh^40
0ol0003oao_WolOki`05olOki`04o`000?mihlKoNN?6ogWSaP;oKISY00?o0000odf^nOm=[_T01Ol0
0005ofFbn`?o00001On5g?h00ol0003oUmcnoiOLoP02oiOLoP05o`000?nRfO_oX]Wkoj;Inol00000
1?nYeOL00ol0003o[]3bojk@lP02ojk@lP04o`000?nac>go/Lc]ok7<k@;o00009oooool00ol0003o
ooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0Jooooo`?o00008?ooool00ol0003obm?O
ol_Cg`03ol_Cg`04o`000?o<f>;oc=SRolcHhP;o00001_oId]800ol0003of]ODom[Ge006om[Ge003
o`000?oKg=OofmcG00?ofmcG0ol0000>om_;b@;o00004?oC^/800ol0003oajVlolNY_004olNY_0Go
00001_mFWo@5o`000003og6Nk?l0003oV:_T00_oV:_T1?l000000onf/]Go0000o`000006o`0000So
][;E00?o0000olS7f?o8amP03Oo8amP00ol0003oe>;QomCRh@09omCRh@04o`000?o7nnOoao_WolOk
i`Go000000CoNN?6offHjOm]V>WoKISY1Ol00007ofFbn`?o00000omf/oP3o`000003ohGLo_l0003o
Umcn00?oUmcn00?o0000oj;InonRfO/00_nRfO/01Ol0003oZMGgojWEmonYeOOo000000Co[]3b00?o
0000ok7<kOnac>d00_nac>d00ol0003oooooo`00000Vooooo`03o`000?oooooooooo00Oooooo000P
ooooo`?o00005oooool3o`0002?ooooo00?o0000ol_Cgoo;dml00oo;dml01_l0003oc=SRolcHh_l0
003of<k@o`0000OofM;B00?o0000om[Ge?oJem@01_oJem@01Ol0003ofmcGom_LeooKg=Oo000000?o
f/K60ol0000<om_;b@03o`000?oB]kkod[Nn00Co00002_oC^/800ol0003oajVlolNY_007olNY_0?o
00002_mFWo@2o`0000ooV:_T00?o0000ok6khOna^n401ona^n48o`000003olS7f?l0003o000000go
00000_oDh^4:o`000004olOkiol0003o0000o`0000?oZOSS1_l00004ogVGi003o`000?mU/__oIK;k
00?oIK;k0_l00008ogJcn0Co00000_nGg?h00ol0003oX]Wkoj;In`02oj;In`03o`000?nYeOOoZMGg
00;oZMGg00?o0000ojk@l_n^d?800_n^d?801Ol0003o/Lc]ok7<kOnac>go000000?ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`07ooooo`007oooool2o`0001Kooooo0ol0000Woooo
o`03o`000?o;dmoobm?O00;obm?O00?o0000olcHh_l000000ooHc]000ol0003ofM;BomWBdP05omWB
dP;o00001ooJem@00ol0003ofmcGo`000007om[6aP?o00002?oKblT00ol0003od[Nnom:g_P05om:g
_PCo00001_oC^/800ol0003oajVlolNY_009olNY_0So00001?mFWo@00ol0003oR;?bohRclP02ohRc
lPSo00000onHZn@00ol0003o/K_Qok6kh@0>ok6kh@03o`000?o3dNGo`m7U00go`m7U00?o0000ol[]
k?o:kN`02?o:kN`00ol0003oZOSSojWhh`03ojWhh`;o00003?miUn@00ol0003oIK;ko`000002o`00
00SoM[?h0_l00004oh>bl`?o00001?nRfO/01Ol0003oZMGgojWEmonYeOOo000000Go[]3b00Go0000
ok7<kOnac>go/Lc]o`000004ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01ooo
ool000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool3o`0002[ooooo00?o0000ol_Cgoo;dml0
0_o;dml2o`0000Gof<k@00?o0000omWBd_oId]801_oId]800ol0003of]ODom[Ge005om[Ge0;o0000
2_oJa/H3o`0000Cofl_900?o0000om:g__oB]kh02_oB]kh4o`000003om>j`_l0003oajVl00koajVl
00?o0000obRFkolXU^l00_lXU^l6o`0000_oR;?b1?l00003ok6kh@03o`000?na^n7o/K_Q00[o/K_Q
00?o0000ol?AiOo3dND03?o3dND00ol0003ob^g/ol[]k008ol[]k004o`000?nYn>?oZOSSojWhh`;o
00003_miUn@4o`0000OoM[?h0ol00004oh>bl`;o00000on</Nh2o`000003oj;Inol0003oZMGg00;o
ZMGg00?o0000ojk@l_n^d?800on^d?801Ol0003o/Lc]ok7<kOnac>go000000Gooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool3o`00
02gooooo00?o0000ol_Cgol000000_l000000ooFbloo0000omS>d005omS>d003o`000?oId];ofM;B
00KofM;B00?o0000om[Ge?oJem@00ooJem@00ol0003ofL?4omW3a002o`0000_of/K60ol000000ooK
blWo0000om:g_P0?om:g_P;o000000?oajVlo`000?l000000_l0000<olNY_0Go00000olXU^l2o`00
00goR;?b00?o0000ojK6l?nVa_000_nVa_08o`0000?o/K_Q00?o0000ol?AiOo3dND03?o3dND00ol0
003ob^g/ol[]k002ol[]k0Oo000000?oZOSSohf=c_n=SLh00on=SLh00ol0003oNIOTogVGi006ogVG
i0Go00001?n1U]h00ol0003oM[?hogJcn002ogJcn0;o00001_n3/_<00ol0003oS;7^ohbakP04ohba
kPCo00000_nYeOL00ol0003o[]3bojk@lP03ojk@lP05o`000?nac>go/Lc]ok7<kOl000001_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo0004ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0ol0000a
ooooo`03o`000?oFblooe/_?00?oe/_?00?o0000omS>d?oHc]001?oHc]000ol0003ofM;BomWBdP06
omWBdP05o`000?oJemCof]ODom[Ge?l000001OoI`l@2o`0000cof/K600?o0000om:g__oB]kh04?oB
]kh00ol0003oajNiolNW^@03olNW^@Wo00000oo7ZK`00ol0003o^YfjokZM^P07o`0000CoJKOl1ol0
0002ohRclP03o`000?nVa_3oY/K`00[oY/K`1?l000000oo3dNGo0000o`00000;o`000003ol[]k?l0
003o000000;o00001?nclo<00ol0003oSHg>ohf=cP07ohf=cP03o`000?miUnCoNIOT00Go00002_n1
U]h01?l0003oM[?ho`000?l00006oh>bl`;o00001_n</Nh00ol0003oTjoZoi>_jP02oi>_jP?o0000
1?n^d?800ol0003o/Lc]ok7<k@02ok7<k@03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`06ooooo`001?ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool2o`0000[ooooo0ol0000dooooo`03o`000?oFblooe/_?00Coe/_?
00?o0000omS>d?oHc]001?oHc]000ol0003ofM;BomWBdP06omWBdP03o`000?oJemCo000000SofL?4
0ol00009om[6aP03o`000?oA];codKBl00Co00002ooB]kh00ol0003oajNiolNW^@0=olNW^@Co0000
0_njWKX3o`000003okZM^_l0003o000000;o00002_mY]o`3o`0000koY/K`00?o0000okOMlonggO<0
2_nggO<00ol0003o/o?cok?cl`04ok?cl`03oh?YjOl0003o000000WoSHg>1_l0000>oh6FgP?o0000
1_n3/_<2o`0000OoS;7^00?o0000oi>_j_nC[nX00_nC[nX01?l0003oVJkVoiV^i_nI[^H3o`000003
ojk@l_l0003o/Lc]00;o/Lc]00?o0000ooooooooool01oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Kooooo0004ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_ooool3o`0003Sooooo00?o0000omK;
cooFbll01?oFbll00ol0003of<k@omS>d004omS>d003o`000?oId];ofM;B00KofM;B0_l0000;omW3
a0;o00001_oJa/H00ol0003odKBlom6d_005om6d_0Go00001_oB]kh00ol0003oajNiolNW^@0@olNW
^@03o`000?nkVkSo^i^h00?o^i^h1_l00002obnXk`Oo00000_mY]o`00ol0003oSLknohg>oP05ohg>
oPOo00000onggO<:o`0000;o/o?c0on3jNT2o`0000?oSHg>2Ol00004oi6<bP03o`000?n1U]koPIKN
00WoPIKN1?l00003ohRFfP03o`000?n3/_?oPk;c00;oPk;c00?o0000ohbak_n</Nh01On</Nh2o`00
00CoTjoZ00?o0000oiV^i_nI[^H01?nI[^H4o`0000;o/Lc]00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo0004ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0ol0000loooo
o`03o`000?oFblooe/_?00Coe/_?00?o0000omS>d?oHc]001?oHc]000ol0003ofM;BomWBdP05omWB
dP04o`000?oG`<?o0000o`0000_ofL?40_l00003om[6aP03o`000?oA];codKBl00_odKBl1?l00002
om:g_P03o`000?o7YkWoajNi013oajNi00?o0000ok^K^?nkVkP02onkVkP01?l0NkSo0000o`000?l0
0003obnXk`?o00001_n=c_h00ol0003oSLknohg>oP04ohg>oP03o`000?nKi?goVnCm00WoVnCm00Co
0000oh?YjOn3jNWoPnWY2?l0000>oi6<bP03o`000?n1U]koPIKN00GoPIKN0ol00008ohRFfP04o`00
0?n3/_?o0000o`0000OoS;7^00?o0000oi>_j_nC[nX00onC[nX00ol0003oVJkVoiV^iP04oiV^iP03
o`000?nM[N?oWJgS00;oWJgS0_l0000;ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01_ooool000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooooooo0ol00010ooooo`03o`000?oFblooe/_?00Coe/_?00?o0000omS>
d?oHc]001?oHc]000ol0003ofM;BomWBdP03omWBdP03o`000?oG`<?oel3300;oel3300?o0000omW3
a?oI`l@02_oI`l@2o`000003om[6a_l0003odKBl013odKBl0_l00002olNW^@03o`000?o7YkWoajNi
00koajNi00?o0000ok^K^?nkVkP04?nkVkP5o`0000OoFLKi1_l00003oi_To@Wo000000?oPnWYoj2<
_onPS;l01OnPS;l00ol0003oTHc:oi6<bP0@oi6<bP03o`000?n1U]koPIKN00Co00002on8U]X2o`00
00SoS;7^00?o0000oi>_j_nC[nX00onC[nX00ol0003oVJkVoiV^iP04oiV^iP03o`000?nM[N?oWJgS
00?oWJgS00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Kooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014oooo
o`03o`000?oFblooe/_?00Coe/_?00?o0000omS>d?oHc]001?oHc]001Ol0003ofM;BomWBd_oId];o
000000Koel330_l0000<omW3a0?o00004OoA];`01?l0003oaZFgolJU]oo6YKL7o`0000SoajNi00?o
0000ok^K^?nkVkP04_nkVkP01?l0003o[Y:io`000?l00006o`RIaPGo00001_mOdndAoj2<_`03o`00
0?nAS<[oTHc:00goTHc:1Ol0000<ohRFfP?o00000_n=UML00ol0003oS;7^ohbakP03ohbakP;o0000
1OnC[nX00ol0003oVJkVoiV^iP04oiV^iP03o`000?nM[N?oWJgS00?oWJgS00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Nooooo`;o0000Aooo
ool00ol0003oe/_?omK;c`04omK;c`03o`000?oHc]3of<k@00Cof<k@00?o0000omWBd_l000002OoG
`<<2o`0000[ofL?400?o0000om2b^oo@/[/00ol0000=om6d_003o`000?o6YKOoaZFg00WoaZFg1_l0
0002olNW^@03o`000?nkVkSo^i^h01;o^i^h00?o0000ojjB^On^T[T04?n^T[T00ol0003oX8booj2<
_`0@oj2<_`03o`000?nAS<[oTHc:00OoTHc:1_l00003oiB;a`03o`000?n8U][oR9KJ00WoR9KJ0_l0
0006ohfEe`05o`000?n</NkoS;7^ohbak_l000001_nC[nX00ol0003oVJkVoiV^iP04oiV^iP03o`00
0?nM[N?oWJgS00?oWJgS00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Kooooo000Pooooo`03o`000?oooooooooo04Gooooo00?o0000omK;cooFbll01?oF
bll00ol0003of<k@omS>d004omS>d0;o00002ooG`<<2o`0000OofL?400?o0000om2b^oo@/[/01?o@
/[/4o`0000WodKBl00?o0000olJU]oo6YKL03oo6YKL3o`0000;o^i^h0ol0000>ok^K^003o`000?n^
T[Wo[Y:i01;o[Y:i00?o0000oj2<_onPS;l03onPS;l01?l0003oTHc:oi6<b_nAS<X6o`0000[oU8_7
00?o0000ohRFf_n8U]X01On8U]X3o`0000WoSIGG00?o0000ohbak_l000001_nC[nX00ol0003oVJkV
oiV^iP04oiV^iP03o`000?nM[N?oWJgS00?oWJgS00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o
0000omK;cooFbll01?oFbll00ol0003of<k@omS>d003omS>d004o`000?oF_/;o0000o`0000_oel33
0_l00005omW3a003o`000?o@/[_od;:k00Sod;:k1?l00005om6d_003o`000?o6YKOoaZFg017oaZFg
00?o0000ok^I]_nkVKH00onkVKH:o`0000Co^i^h00?o0000ojjB^On^T[T04_n^T[T00ol0003oX8bo
oj2<_`07oj2<_`co00004OnDRlL00ol0003oR9KJohRFfP02ohRFfP;o00003?n=UML3o`0000GoTjoZ
00?o0000oiV^i_nI[^H00onI[^H2o`0000GoWJgS00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Gooooo000Rooooo`03o`000?oooooooooo04Cooooo00?o
0000omK;cooFbll01OoFbll01Ol0003of<k@omS>d?oHc]3o000000Coe[k20_l0000;omO0``05o`00
0?oI`lCofL?4omW3a?l000003oo@/[/3o`000003om6d_?l0003oaZFg01?oaZFg00?o0000ok^I]_nk
VKH03OnkVKHSo`0000WoXXbm00?o0000oiB;aonDRlL04OnDRlL00ol0003oR9KJo`000002o`0000co
SIGG0_l00003oi6Ee005o`000?nC[n[oTjoZoi>_j_l000001OnI[^H00ol0003oWJgSoif]h`04oif]
h`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05oooo
o`008oooool2o`0004Gooooo00?o0000omK;cooFbll01OoFbll00ol0003of<k@o`000007omJn`P;o
00002_oG`<<2o`000003omW3a?l0003od;:k017od;:k0_l0000DolJU]`03o`000?nkVKKo^iVf017o
^iVf00?o0000ojnA]on_TKL04_n_TKL00ol0003oXXbmoj:<_@0Aoj:<_@03o`000?nDRlOoU8_700oo
U8_70ol0000<ohfEe`?o00001_nAUM@00ol0003oTjoZo`000005oiV^iP03o`000?nM[N?oWJgS00Co
WJgS00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo000Uooooo`03o`000?oooooooooo04?ooooo00?o0000omK;cooFbll01OoFbll2o`0000Woe[k2
0_l0000:omO0``?o00004_o@/[/01?l0003oaZBfolJT]_o6Y;H5o`0000_oaZFg00?o0000ok^I]_nk
VKH04_nkVKH00ol0003o[i6gojnA]`0BojnA]`03o`000?nRS;goXXbm017oXXbm00?o0000oiB;aonD
RlL02_nDRlL5o`0000;oUh_500?o0000ohfEeon=UML02?n=UML2o`0000WoTIGD0_l00005oiV^iP03
o`000?nM[N?oWJgS00CoWJgS00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Gooooo000Vooooo`03o`000?oooooooooo04?ooooo00?o0000omK;cooFbll0
0ooFbll00ol0003oe;c2omBl`P02o`0000Woe[k200?o0000omO0`ooG`<<01ooG`<<00ol0003ock2j
oln`^P03o`0000ood;:k00?o0000olJT]_o6Y;H01_o6Y;H5o`0000KoaZFg00?o0000ok^I]_nkVKH0
4_nkVKH00ol0003o[i6gojnA]`0BojnA]`03o`000?nRS;goXXbm017oXXbm00?o0000oiB;aonDRlL0
1OnDRlL5o`0000SoUh_500?o0000ohfEeon=UML01On=UML2o`0000WoTIGD0_l00002oiFFdP05o`00
0?nI[^KoVJkVoiV^i_l000001_nM[N<00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01Oooool002Oooooo00?o0000ooooooooool0@oooool01Ol0003oe/_?
omK;cooFbloo000000Goe;c200?o0000omJn`_oF_/801ooF_/82o`0000Koel3300?o0000oln`^_o?
/;X01?o?/;X3o`0000_od;:k00?o0000olJT]_o6Y;H03?o6Y;H5o`000003olJU]ol0003o^iVf01?o
^iVf00?o0000ojnA]on_TKL04on_TKL00ol0003oXXbmoj:<_@0Aoj:<_@03o`000?nDRlOo000000Co
00003_nGRlD01?l0003oSIGGohfEeon=UML3o`0000WoTIGD0_l00005oiFFdP03o`000?nI[^Ko0000
00KoWJgS00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Gooooo000Xooooo`;o0000A?ooool00ol0003oe/_?o`000007omBl`P;o00002OoF_/82o`0000?o
el3300?o0000oln`^_o?/;X02?o?/;X3o`0000Sod;:k00?o0000olJT]_o6Y;H04Oo6Y;H2o`000003
ok^I]_l0003o000000;o00003onkVKH00ol0003o[i6gojnA]`0CojnA]`03o`000?nRS;goXXbm00co
XXbm1ol0000CoiN;a@04o`000?n=UMOo0000o`0000[oTIGD0_l00007oiFFdP?o00001OnM[N<00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002[o
oooo00?o0000ooooooooool0@_ooool2o`0000Woe;c20_l00009omJn`P;o000000?oel33o`000?o?
/;X03?o?/;X3o`0000God;:k00?o0000olJT]_o6Y;H04_o6Y;H00ol0003o^iVeok^I]@03ok^I]@_o
00001?nkVKH00ol0003o[i6gojnA]`0CojnA]`03o`000?nRS;goXXbm00;oXXbm2_l00005oj>;^`03
o`000?nGRlGoUh_5017oUh_50ol00009oi6Ee0?o00001onEU]82o`0000?oV9OA00Go0000oif]honM
[N?oWJgSo`00000Pooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool002_o
oooo00?o0000ooooooooool0@oooool00ol0003oe;c2omBl`P08omBl`P03o`000?oF_/;oe[k200So
e[k20_l0000@oln`^P?o000000?od;:ko`000?o6Y;H05?o6Y;H00ol0003o^iVeok^I]@0>ok^I]Aoo
00004?nSRk/00ol0003oUh_5oiN;a@0<oiN;a@Co00000_nIS<@00ol0003oTIGDoi6Ee005oi6Ee0;o
00002OnEU]800ol0003oV9OAoiRGd@04oiRGd@03o`000?nM[N?o000002;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`04ooooo`00;?ooool00ol0003oooooooooo`13ooooo`;o0000
2OoD_<82o`0000Soe[k200?o0000olj_^_l000000_l0000@oln`^PGo00004_o6Y;H00ol0003o^iVe
ok^I]@0Bok^I]@03o`000?n_T;Ko[i2f01?o[i2f00?o0000oj>;^onSRk/04_nSRk/00ol0003oUh_5
oiN;a@08oiN;a@Co00001onIS<@00ol0003oTIGDoi6Ee002oi6Ee0;o00002OnEU]82o`0000OoV9OA
0_l0000Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool002gooooo0_l0
0015ooooo`03o`000?oD_<;oe;c200Soe;c20_l00005omJn`P03o`000?o>[k[ocZnj00?ocZnj0ol0
000>oln`^P04o`000?o5XkKoaJ>folFS]PGo00003?o6Y;H00ol0003o^iVeok^I]@0Cok^I]@03o`00
0?n_T;Ko[i2f01?o[i2f00?o0000oj>;^onSRk/04_nSRk/00ol0003oUh_5oiN;a@04oiN;a@Co0000
3?nIS<@01?l0003oTIGDo`000?l00009oiFFdP;o00002?nHUm400ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool002oooooo00?o0000ooooooooool0
@oooool00ol0003oe;c2omBl`P09omBl`P05o`000?oF_/;oe[k2omJn`_l000002Oo>[kX3o`0000[o
ck2j00?o0000olFS]_o5XkH01oo5XkH5o`0000OoaZBf00?o0000ok^I]OnkVKD04onkVKD00ol0003o
[i2fojn@]P0Cojn@]P03o`000?nSRk_oXh^k01?oXh^k00?o0000oiN;aOl000000ol0000?oiV<a0?o
00002_nEU]800ol0003oV9OAoiRGd@06oiRGd@;o0000:?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0000:omBl`P;o0000
00?oe[k2o`000?o>[kX02oo>[kX2o`0000Sock2j00?o0000olFS]_o5XkH03?o5XkH5o`0000;oaZBf
00?o0000ok^I]OnkVKD04onkVKD00ol0003o[i2fojn@]P0Dojn@]P03o`000?nSRk_oXh^k00goXh^k
1ol0000@oiV<a0?o00000_nKSL<00ol0003oUIKBoiFFdP06oiFFdP;o00001onHUm42o`0002_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`00<Oooool2o`0004Gooooo00?o
0000omBl`_oD_<802OoD_<82o`0000kocZnj0ol00004oln`^P03o`000?o5XkKoaJ>f01;oaJ>f0ol0
00000onkVKGo0000o`000003o`0000oo^iVe00?o0000ojn@]_n_T;H05?n_T;H00ol0003oXh^koj>;
^`02oj>;^`_o00001OnTS;X00ol0003oVHc4oiV<a00;oiV<a0Co00001_nKSL<00ol0003oUIKBoiFF
dP03oiFFdP;o00002?nHUm400ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00oooool003?ooooo00?o0000ooooooooool0@oooool2o`0000Woe;c200Co0000
olf^^_l0003o00003oo>[kX3o`000003oln`^_l0003oaJ>f01GoaJ>f00?o0000ok^H]?nkV;@01?nk
V;@;o`0000Co^iVe00?o0000ojn@]_n_T;H02On_T;H@o`00017oY8bj00?o0000oiV<a?nIS<@01onI
S<@3o`0000_oVhg300Go0000oiFFd_nEU];oUIKBo`000008oiRGd@;o0000;oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo000dooooo`03o`000?oooooooooo04Cooooo00?o
0000omBl`_oD_<801OoD_<800ol0003ocJjjolf^^P02olf^^P?o00003oo>[kX3o`0001GoaJ>f00?o
0000ok^H]?nkV;@03onkV;@@o`0000_o/92f00?o0000ojB<^_nTS;X04onTS;X00ol0003oVHc4oiV<
a003oiV<a0Co00003_nKSL<01?l0003oUIKBo`000?l00008oiRGd@03o`000?oooooooooo033ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`00=Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oD_<;oe;c200?oe;c200?o0000olf^^_o=[[X01_o=[[X2o`0000gocZnj00?o
0000olFR]_o5X[H01Ol0000@olFS]P03o`000?nkV;Co^iRd01?o^iRd00?o0000ok2@]_n`T;H05?n`
T;H00ol0003oY8bjojB<^P0CojB<^P03o`000?nIS<CoVHc400?o00004OnKSL<3o`0000SoV9OA0_l0
000dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool003Kooooo0_l00015
ooooo`;o00000ooD_<800ol0003ocJjjolf^^P08olf^^P;o00002oo>[kX00ol0003oaJ:folFR]P05
olFR]PGo00002_o5XkH00ol0003o^iRdok^H]00Dok^H]003o`000?n`T;Ko/92f01Co/92f00?o0000
ojB<^_nTS;X04OnTS;X5o`00017oVhg30ol00002oif>``03o`000?nHUm7oV9OA00GoV9OA00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000hoooo
o`03o`000?oooooooooo04Cooooo00?o0000omBl`_l000003Oo=[[X2o`0000SocZnj00?o0000olFR
]_o5X[H02oo5X[H4o`0000KoaJ>f00?o0000ok^H]?nkV;@05?nkV;@00ol0003o/92fok2@]P0Eok2@
]P03o`000?nTS;[oY8bj00_oY8bj1Ol00003ojF<^P03o`000?nKSL?oVhg300goVhg30ol00006oif>
``03o`000?nHUm7oV9OA00;oV9OA0_l0000hooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool003Wooooo00?o0000ooooooooool0A?ooool2o`0000oocJjj0_l00006olj_^P03
o`000?o5X[KoaJ:f00ooaJ:f1Ol000000oo5XkKo0000ok^H]00Eok^H]003o`000?n`T;Ko/92f01Go
/92f00?o0000ojB<^_nTS;X01OnTS;X6o`0000WoYHbj00?o0000oi^=`onKSL<02OnKSL<3o`0000Wo
WHk300?o0000oiRGdOnHUm400_l0000kooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00oooool003[ooooo00?o0000ooooooooool0AOooool3o`0000kocJjj0ol00003olj_^P03o`00
0?o5X[KoaJ:f01CoaJ:f2?l0000@ok^H]003o`000?n`T;Ko/92f01Go/92f00?o0000ojB<^_nTS;X0
1Ol0000?ojF<^P03o`000?nKSL?oVhg300KoVhg30ol0000<oif>``03o`000?nHUm7o000003kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00>oooool2o`0004Sooooo0_l0
000?olf^^P?o00006?o5X[H00ol0003o^iRdok^H]004ok^H]0_o00001OnkV;@00ol0003o/92fok2@
]P09ok2@]Poo00005?nUS;X00ol0003oVhg3oi^=``03oi^=``?o00003onMS/<2o`0003oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00?Oooool00ol0003oooooooooo`17
ooooo`?o00003_o=[[X3o`0001KoaJ:f00?o0000ok^H]?nkV;@03onkV;@Ao`0000co/96f00?o0000
ojF<^_nUS;X05OnUS;X00ol0003oVhg3o`000002o`0000ooWHk30ol00012ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool003kooooo00?o0000ooooooooool0BOooool2o`00
00cocJjj00?o0000olBR]_o4X[H01Ol0000@olFR]P03o`000?nkV;Co^iRd01Go^iRd00?o0000ok2A
]_n`TKH05On`TKH00ol0003oYHbjojF<^P0CojF<^PCo00003onMS/<3o`0004Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`00?oooool00ol0003oooooooooo`1:ooooo`;o
00002Oo=[[X00ol0003oa::folBR]P06olBR]PGo00002oo5X[H00ol0003o^iRdok^H]00Eok^H]003
o`000?n`TKKo/96f01Go/96f00?o0000ojF<^_nUS;X03_nUS;X5o`0000;oYXfj00?o0000oif>`onM
S/<02onMS/<3o`0004[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00
@?ooool2o`0004cooooo0ol00006olf^^P03o`000?o4X[Koa::f00_oa::f1?l00007olFR]P03o`00
0?nkV;Co^iRd01Go^iRd00?o0000ok2A]_n`TKH05_n`TKH00ol0003oYHbjojF<^P08ojF<^PGo0000
2?nVSKX00ol0003oWHk3oif>``08oif>``;o0000COooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo0012ooooo`03o`000?oooooooooo04cooooo0_l00004olf^^P03o`000?o4
X[Koa::f00ooa::f1Ol000000oo5X[Ko0000ok^H]00Gok^H]003o`000?n`TKKo/96f01Ko/96f00?o
0000ojF<^_nUS;X01?nUS;X4o`0000goYXfj00?o0000oif>`onMS/<01OnMS/<3o`00053ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`1=
ooooo`Co00005oo4X[H8o`0001;o^iRd00?o0000ok2A]_n`TKH05_n`TKH00ol0003oYHbjo`000004
o`00017oYXfj00?o0000oif>`onMS/<00_nMS/<3o`0005Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`1?ooooo`?o00005_o4X[H00ol0
003o^iVeok^I]@04ok^I]@go00001OnkV;@00ol0003o/96fok2A]P0:ok2A]Pko00005onVSKX4o`00
05Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOooool2o`0005;o
oooo1Ol0000AolBR]P03o`000?nkVKGo^iVe017o^iVe4_l0000<ok6A]P03o`000?nVSK[oYXfj01Co
YXfj0ol0001Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Oooooo
00?o0000ooooooooool0E?ooool5o`0000coa::f00?o0000ok^I]OnkVKD05_nkVKD00ol0003o/I6f
ok6A]P0Fok6A]P03o`000?nVSK[oYXfj00ooYXfj1Ol0001Oooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00Oooool004Sooooo00?o0000ooooooooool0F?ooool5o`0000Koa::f00?o
0000ok^I]OnkVKD05onkVKD00ol0003o/I6fok6A]P0Fok6A]P03o`000?nVSK[oYXfj00[oYXfj1Ol0
001Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool004Wooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`02ooooo`Go000000?oa::fo`000?nkVKD06?nkVKD0
0ol0003o/I6fok6A]P0Gok6A]P03o`000?nVSK[oYXfj00CoYXfj1Ol0001[ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00Oooool004[ooooo0_l0001Gooooo`03o`000?oooooooooo
00Oooooo0_l00002ok^I]@;o00005OnkVKD00ol0003o/I6fok6A]P0Gok6A]P03o`000?nVSK[o0000
00Co0000L?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo001<ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool03Oooool9o`0000co^iVe00?o0000ok6A]_na
TKH04OnaTKH8o`0007Kooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool004gooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Fooooo`Wo00000onkVKD00ol0003o/I6f
ok6A]P04ok6A]Pgo0000Ooooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00C_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo01oooooo2_l0002<ooooo`03o`000?oo
oooooooo00Oooooo0Ol00001ooooo`7ooooo001?ooooo`;o0000D_ooool00ol0003oooooooooo`2f
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001Aooooo`03o`000?oooooooooo
04oooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00D_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooooooo
ool01?ooool1o`00007ooooo0Oooool005?ooooo0_l0001>ooooo`03o`000?oooooooooo0;Sooooo
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool005Gooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00E_ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0;[ooooo00?o0000ooooooooool00oooool1
o`00007ooooo001Gooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0^oooool00ol0
003oooooooooo`02ooooo`7o00000Oooool005Sooooo0_l00019ooooo`03o`000?oooooooooo0;_o
oooo00?o0000ooooooooool00_ooool1o`00007ooooo001Jooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0_?ooool01Ol0003ooooooooooooooooo0000007ooooo001Kooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool0_Oooool01?l0003oooooooooool00001ooooo`00
G?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooool00000
0Oooool005gooooo0_l00014ooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool00Ol0
000005oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2oooooo`7o00000Oooool1
o`000000H?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<3ooooo0_l00000067o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2oooooo`?o0000001Rooooo`;o0000
?oooool00ol0003oooooooooo`2kooooo`Co00000oooool006Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`2gooooo`Co00001oooool006Gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`2cooooo`Co00002oooool006Kooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`2`ooooo`?o00003oooool006Oooooo0_l0000jooooo`03o`000?oooooooooo0:co
oooo1?l0000Booooo`00JOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:Sooooo
1?l0000Fooooo`00J_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Cooooo1?l0
000Jooooo`00Joooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:7ooooo1?l0000N
ooooo`00K?ooool2o`0003Cooooo00?o0000ooooooooool0WOooool4o`0002;ooooo001^ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0VOooool4o`0002Kooooo001_ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0UOooool4o`0002[ooooo001`ooooo`;o0000<?oo
ool00ol0003oooooooooo`2Aooooo`Co0000;_ooool007;ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`2>ooooo`?o0000<_ooool007?ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`2:ooooo`Co0000=Oooool007Cooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`26ooooo`Co0000>Oooool007Gooooo0_l0000[ooooo`03o`000?oooooooooo08;ooooo
1?l0000mooooo`00Moooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07kooooo1?l0
0011ooooo`00N?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1?l00015
ooooo`00NOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Kooooo1?l00019oooo
o`00N_ooool2o`0002Kooooo00?o0000ooooooooool0L_ooool4o`0004gooooo001looooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0Koooool3o`00057ooooo001mooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Joooool4o`0005Cooooo001nooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0Ioooool4o`0005Sooooo001oooooo`;o00008Oooool00ol0
003oooooooooo`1Sooooo`Co0000G?ooool0087ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1Oooooo`Co0000H?ooool008;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Kooooo`Co0000I?ooool008?ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Gooooo`Co0000J?ooool008Cooooo0_l0000Looooo`03o`000?oooooooooo05?ooooo1?l0001/
ooooo`00Q_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001`oooo
o`00Qoooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo0ol0001dooooo`00
R?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo1?l0001gooooo`00ROoo
ool2o`0001Oooooo00?o0000ooooooooool0A?ooool4o`0007_ooooo002;ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@?ooool4o`0007oooooo002<ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0??ooool4o`0008?ooooo002=ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0>?ooool4o`0008Oooooo002>ooooo`;o00004_ooool00ol0003ooooo
ooooo`0dooooo`Co0000Roooool0093ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0aooooo`Co0000Soooool0097ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^
ooooo`?o0000Toooool009;ooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Foooo
o`00U?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Jooooo`00
UOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Nooooo`00U_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Rooooo`00Uoooool2
o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:Kooooo002Iooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool4o`000:[ooooo002Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool4o`000:kooooo002Kooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`000;;ooooo002Looooo`;o00000oooool00ol0003ooooooooo
o`0;ooooo`?o0000]_ooool009kooooo00Co0000oooooooooooo00002Oooool4o`000;Wooooo002O
ooooo`03o`000?oooooo000000Gooooo1?l0002mooooo`00X?ooool2o`000003ooooool0003o0000
00;o0000`Oooool00:7ooooo0_l00035ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.80942e-18 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03013 .282 -24 -2.73513 ]
[.03013 .282 0 6.26487 ]
[.02112 .33842 -30 -2.78326 ]
[.02112 .33842 0 6.21674 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00207 .4578 -24 -2.88566 ]
[.00207 .4578 0 6.11434 ]
[-0.00801 .521 -18 -2.94019 ]
[-0.00801 .521 0 6.05981 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04235 .2772 m
.04846 .27481 L
s
[(-0.5)] .03013 .282 1 -0.39219 Mshowa
.03339 .33375 m
.03952 .33141 L
s
[(-0.25)] .02112 .33842 1 -0.3815 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01443 .45337 m
.02061 .45115 L
s
[(0.25)] .00207 .4578 1 -0.35874 Mshowa
.00439 .5167 m
.0106 .51455 L
s
[(0.5)] -0.00801 .521 1 -0.34662 Mshowa
.125 Mabswid
.04058 .28835 m
.04425 .28692 L
s
.0388 .29957 m
.04247 .29815 L
s
.03701 .31088 m
.04068 .30946 L
s
.03521 .32227 m
.03888 .32086 L
s
.03155 .34531 m
.03524 .34391 L
s
.02971 .35695 m
.03339 .35556 L
s
.02785 .36869 m
.03154 .36731 L
s
.02598 .38051 m
.02967 .37914 L
s
.02219 .40443 m
.02588 .40307 L
s
.02027 .41652 m
.02397 .41517 L
s
.01834 .42871 m
.02204 .42736 L
s
.01639 .44099 m
.0201 .43965 L
s
.01245 .46584 m
.01616 .46452 L
s
.01046 .47841 m
.01417 .47709 L
s
.00846 .49107 m
.01217 .48977 L
s
.00643 .50384 m
.01015 .50254 L
s
.0441 .26614 m
.04776 .2647 L
s
.04584 .25516 m
.0495 .25371 L
s
.00234 .52967 m
.00606 .52839 L
s
.00027 .54274 m
.00399 .54147 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .63837 m .51694 .65827 L .43899 .65168 L p .73 .603 .716 r
F P
0 g
s
.51694 .65827 m .51727 .63837 L .5924 .63613 L p .692 .584 .73 r
F P
0 g
s
.5924 .63613 m .59527 .65394 L .51694 .65827 L p .692 .584 .73 r
F P
0 g
s
.43899 .65168 m .44259 .63089 L .51727 .63837 L p .73 .603 .716 r
F P
0 g
s
.51761 .61817 m .51727 .63837 L .44259 .63089 L p .728 .6 .714 r
F P
0 g
s
.51727 .63837 m .51761 .61817 L .58953 .61806 L p .688 .58 .729 r
F P
0 g
s
.58953 .61806 m .5924 .63613 L .51727 .63837 L p .688 .58 .729 r
F P
0 g
s
.44259 .63089 m .44619 .60982 L .51761 .61817 L p .728 .6 .714 r
F P
0 g
s
.51795 .59798 m .51761 .61817 L .44619 .60982 L p .726 .599 .714 r
F P
0 g
s
.51761 .61817 m .51795 .59798 L .58665 .59998 L p .683 .577 .729 r
F P
0 g
s
.58665 .59998 m .58953 .61806 L .51761 .61817 L p .683 .577 .729 r
F P
0 g
s
.44619 .60982 m .44979 .58877 L .51795 .59798 L p .726 .599 .714 r
F P
0 g
s
.51829 .57807 m .51795 .59798 L .44979 .58877 L p .723 .598 .716 r
F P
0 g
s
.51795 .59798 m .51829 .57807 L .58377 .58211 L p .678 .575 .732 r
F P
0 g
s
.58377 .58211 m .58665 .59998 L .51795 .59798 L p .678 .575 .732 r
F P
0 g
s
.44979 .58877 m .45339 .56804 L .51829 .57807 L p .723 .598 .716 r
F P
0 g
s
.51863 .5587 m .51829 .57807 L .45339 .56804 L p .72 .599 .72 r
F P
0 g
s
.51829 .57807 m .51863 .5587 L .58089 .56469 L p .672 .574 .737 r
F P
0 g
s
.58089 .56469 m .58377 .58211 L .51829 .57807 L p .672 .574 .737 r
F P
0 g
s
.45339 .56804 m .45697 .54792 L .51863 .5587 L p .72 .599 .72 r
F P
0 g
s
.51896 .54014 m .51863 .5587 L .45697 .54792 L p .716 .601 .727 r
F P
0 g
s
.51863 .5587 m .51896 .54014 L .57802 .54795 L p .664 .575 .744 r
F P
0 g
s
.57802 .54795 m .58089 .56469 L .51863 .5587 L p .664 .575 .744 r
F P
0 g
s
.45697 .54792 m .46053 .5287 L .51896 .54014 L p .716 .601 .727 r
F P
0 g
s
.5193 .52263 m .51896 .54014 L .46053 .5287 L p .711 .604 .736 r
F P
0 g
s
.51896 .54014 m .5193 .52263 L .57516 .53209 L p .655 .577 .755 r
F P
0 g
s
.57516 .53209 m .57802 .54795 L .51896 .54014 L p .655 .577 .755 r
F P
0 g
s
.59527 .65394 m .5924 .63613 L .66436 .62421 L p .658 .584 .761 r
F P
0 g
s
.66436 .62421 m .67023 .63881 L .59527 .65394 L p .658 .584 .761 r
F P
0 g
s
.5924 .63613 m .58953 .61806 L .65847 .6094 L p .65 .578 .761 r
F P
0 g
s
.65847 .6094 m .66436 .62421 L .5924 .63613 L p .65 .578 .761 r
F P
0 g
s
.38547 .57273 m .3922 .55247 L .45339 .56804 L p .768 .634 .713 r
F P
0 g
s
.45339 .56804 m .44979 .58877 L .38547 .57273 L p .768 .634 .713 r
F P
0 g
s
.45697 .54792 m .45339 .56804 L .3922 .55247 L p .767 .637 .717 r
F P
0 g
s
.3922 .55247 m .3989 .53286 L .45697 .54792 L p .767 .637 .717 r
F P
0 g
s
.46053 .5287 m .45697 .54792 L .3989 .53286 L p .765 .641 .724 r
F P
0 g
s
.37872 .59333 m .38547 .57273 L .44979 .58877 L p .769 .633 .711 r
F P
0 g
s
.44979 .58877 m .44619 .60982 L .37872 .59333 L p .769 .633 .711 r
F P
0 g
s
.37196 .61398 m .37872 .59333 L .44619 .60982 L p .769 .634 .711 r
F P
0 g
s
.44619 .60982 m .44259 .63089 L .37196 .61398 L p .769 .634 .711 r
F P
0 g
s
.46053 .5287 m .46408 .51062 L .5193 .52263 L p .711 .604 .736 r
F P
0 g
s
.51963 .50638 m .5193 .52263 L .46408 .51062 L p .704 .609 .748 r
F P
0 g
s
.5193 .52263 m .51963 .50638 L .5723 .51731 L p .643 .58 .769 r
F P
0 g
s
.5723 .51731 m .57516 .53209 L .5193 .52263 L p .643 .58 .769 r
F P
0 g
s
.3989 .53286 m .40555 .51416 L .46053 .5287 L p .765 .641 .724 r
F P
0 g
s
.46408 .51062 m .46053 .5287 L .40555 .51416 L p .762 .646 .733 r
F P
0 g
s
.36521 .63435 m .37196 .61398 L .44259 .63089 L p .769 .635 .713 r
F P
0 g
s
.44259 .63089 m .43899 .65168 L .36521 .63435 L p .769 .635 .713 r
F P
0 g
s
.58953 .61806 m .58665 .59998 L .65256 .59457 L p .642 .574 .763 r
F P
0 g
s
.65256 .59457 m .65847 .6094 L .58953 .61806 L p .642 .574 .763 r
F P
0 g
s
.40555 .51416 m .41217 .49664 L .46408 .51062 L p .762 .646 .733 r
F P
0 g
s
.4676 .49392 m .46408 .51062 L .41217 .49664 L p .758 .653 .746 r
F P
0 g
s
.46408 .51062 m .4676 .49392 L .51963 .50638 L p .704 .609 .748 r
F P
0 g
s
.58665 .59998 m .58377 .58211 L .64665 .57988 L p .632 .571 .767 r
F P
0 g
s
.64665 .57988 m .65256 .59457 L .58665 .59998 L p .632 .571 .767 r
F P
0 g
s
.51997 .4916 m .51963 .50638 L .4676 .49392 L p .694 .616 .765 r
F P
0 g
s
.51963 .50638 m .51997 .4916 L .56945 .50377 L p .628 .585 .787 r
F P
0 g
s
.56945 .50377 m .5723 .51731 L .51963 .50638 L p .628 .585 .787 r
F P
0 g
s
.41217 .49664 m .41874 .48053 L .4676 .49392 L p .758 .653 .746 r
F P
0 g
s
.47111 .47881 m .4676 .49392 L .41874 .48053 L p .751 .663 .763 r
F P
0 g
s
.4676 .49392 m .47111 .47881 L .51997 .4916 L p .694 .616 .765 r
F P
0 g
s
.58377 .58211 m .58089 .56469 L .64073 .56553 L p .621 .569 .774 r
F P
0 g
s
.64073 .56553 m .64665 .57988 L .58377 .58211 L p .621 .569 .774 r
F P
0 g
s
.58089 .56469 m .57802 .54795 L .63482 .55168 L p .608 .568 .784 r
F P
0 g
s
.63482 .55168 m .64073 .56553 L .58089 .56469 L p .608 .568 .784 r
F P
0 g
s
.5203 .47843 m .51997 .4916 L .47111 .47881 L p .68 .625 .787 r
F P
0 g
s
.51997 .4916 m .5203 .47843 L .56661 .49162 L p .606 .591 .81 r
F P
0 g
s
.56661 .49162 m .56945 .50377 L .51997 .4916 L p .606 .591 .81 r
F P
0 g
s
.41874 .48053 m .42527 .46604 L .47111 .47881 L p .751 .663 .763 r
F P
0 g
s
.4746 .46546 m .47111 .47881 L .42527 .46604 L p .742 .675 .786 r
F P
0 g
s
.47111 .47881 m .4746 .46546 L .5203 .47843 L p .68 .625 .787 r
F P
0 g
s
.57802 .54795 m .57516 .53209 L .62891 .5385 L p .591 .569 .797 r
F P
0 g
s
.62891 .5385 m .63482 .55168 L .57802 .54795 L p .591 .569 .797 r
F P
0 g
s
.57516 .53209 m .5723 .51731 L .623 .52614 L p .57 .57 .814 r
F P
0 g
s
.623 .52614 m .62891 .5385 L .57516 .53209 L p .57 .57 .814 r
F P
0 g
s
.42527 .46604 m .43176 .45335 L .4746 .46546 L p .742 .675 .786 r
F P
0 g
s
.47807 .45402 m .4746 .46546 L .43176 .45335 L p .727 .691 .816 r
F P
0 g
s
.4746 .46546 m .47807 .45402 L .52063 .46703 L p .66 .637 .816 r
F P
0 g
s
.52063 .46703 m .5203 .47843 L .4746 .46546 L p .66 .637 .816 r
F P
0 g
s
.5203 .47843 m .52063 .46703 L .56377 .48097 L p .573 .598 .84 r
F P
0 g
s
.56377 .48097 m .56661 .49162 L .5203 .47843 L p .573 .598 .84 r
F P
0 g
s
.5723 .51731 m .56945 .50377 L .6171 .51472 L p .541 .572 .835 r
F P
0 g
s
.6171 .51472 m .623 .52614 L .5723 .51731 L p .541 .572 .835 r
F P
0 g
s
.34739 .51414 m .35684 .49717 L .40555 .51416 L p .812 .694 .735 r
F P
0 g
s
.40555 .51416 m .3989 .53286 L .34739 .51414 L p .812 .694 .735 r
F P
0 g
s
.41217 .49664 m .40555 .51416 L .35684 .49717 L p .811 .703 .745 r
F P
0 g
s
.33787 .53199 m .34739 .51414 L .3989 .53286 L p .812 .688 .727 r
F P
0 g
s
.3989 .53286 m .3922 .55247 L .33787 .53199 L p .812 .688 .727 r
F P
0 g
s
.35684 .49717 m .36623 .48134 L .41217 .49664 L p .811 .703 .745 r
F P
0 g
s
.41874 .48053 m .41217 .49664 L .36623 .48134 L p .808 .713 .76 r
F P
0 g
s
.67023 .63881 m .66436 .62421 L .72945 .60291 L p .634 .615 .814 r
F P
0 g
s
.72945 .60291 m .73799 .61332 L .67023 .63881 L p .634 .615 .814 r
F P
0 g
s
.43176 .45335 m .43823 .44259 L .47807 .45402 L p .727 .691 .816 r
F P
0 g
s
.48154 .4446 m .47807 .45402 L .43823 .44259 L p .702 .71 .855 r
F P
0 g
s
.47807 .45402 m .48154 .4446 L .52096 .45749 L p .628 .65 .853 r
F P
0 g
s
.52096 .45749 m .52063 .46703 L .47807 .45402 L p .628 .65 .853 r
F P
0 g
s
.3283 .55047 m .33787 .53199 L .3922 .55247 L p .812 .683 .722 r
F P
0 g
s
.3922 .55247 m .38547 .57273 L .3283 .55047 L p .812 .683 .722 r
F P
0 g
s
.36623 .48134 m .37556 .46686 L .41874 .48053 L p .808 .713 .76 r
F P
0 g
s
.42527 .46604 m .41874 .48053 L .37556 .46686 L p .804 .727 .779 r
F P
0 g
s
.52063 .46703 m .52096 .45749 L .56092 .47192 L p .524 .605 .876 r
F P
0 g
s
.56092 .47192 m .56377 .48097 L .52063 .46703 L p .524 .605 .876 r
F P
0 g
s
.31869 .56929 m .3283 .55047 L .38547 .57273 L p .811 .68 .72 r
F P
0 g
s
.38547 .57273 m .37872 .59333 L .31869 .56929 L p .811 .68 .72 r
F P
0 g
s
.66436 .62421 m .65847 .6094 L .72088 .59236 L p .621 .61 .818 r
F P
0 g
s
.72088 .59236 m .72945 .60291 L .66436 .62421 L p .621 .61 .818 r
F P
0 g
s
.56945 .50377 m .56661 .49162 L .6112 .50436 L p .501 .573 .86 r
F P
0 g
s
.6112 .50436 m .6171 .51472 L .56945 .50377 L p .501 .573 .86 r
F P
0 g
s
.30906 .58816 m .31869 .56929 L .37872 .59333 L p .809 .678 .72 r
F P
0 g
s
.37872 .59333 m .37196 .61398 L .30906 .58816 L p .809 .678 .72 r
F P
0 g
s
.37556 .46686 m .38481 .45393 L .42527 .46604 L p .804 .727 .779 r
F P
0 g
s
.43176 .45335 m .42527 .46604 L .38481 .45393 L p .796 .744 .805 r
F P
0 g
s
.29943 .6068 m .30906 .58816 L .37196 .61398 L p .807 .677 .721 r
F P
0 g
s
.37196 .61398 m .36521 .63435 L .29943 .6068 L p .807 .677 .721 r
F P
0 g
s
.65847 .6094 m .65256 .59457 L .71228 .58179 L p .607 .605 .824 r
F P
0 g
s
.71228 .58179 m .72088 .59236 L .65847 .6094 L p .607 .605 .824 r
F P
0 g
s
.38481 .45393 m .39401 .44271 L .43176 .45335 L p .796 .744 .805 r
F P
0 g
s
.43823 .44259 m .43176 .45335 L .39401 .44271 L p .781 .765 .839 r
F P
0 g
s
.65256 .59457 m .64665 .57988 L .70365 .57129 L p .59 .602 .832 r
F P
0 g
s
.70365 .57129 m .71228 .58179 L .65256 .59457 L p .59 .602 .832 r
F P
0 g
s
.43823 .44259 m .44467 .43389 L .48154 .4446 L p .702 .71 .855 r
F P
0 g
s
.485 .43727 m .48154 .4446 L .44467 .43389 L p .657 .732 .905 r
F P
0 g
s
.48154 .4446 m .485 .43727 L .52129 .44989 L p .574 .664 .899 r
F P
0 g
s
.52129 .44989 m .52096 .45749 L .48154 .4446 L p .574 .664 .899 r
F P
0 g
s
.56661 .49162 m .56377 .48097 L .60529 .49515 L p .442 .572 .889 r
F P
0 g
s
.60529 .49515 m .6112 .50436 L .56661 .49162 L p .442 .572 .889 r
F P
0 g
s
.52096 .45749 m .52129 .44989 L .55808 .46453 L p .444 .606 .915 r
F P
0 g
s
.55808 .46453 m .56092 .47192 L .52096 .45749 L p .444 .606 .915 r
F P
0 g
s
.64665 .57988 m .64073 .56553 L .69501 .561 L p .569 .6 .844 r
F P
0 g
s
.69501 .561 m .70365 .57129 L .64665 .57988 L p .569 .6 .844 r
F P
0 g
s
.39401 .44271 m .40316 .43335 L .43823 .44259 L p .781 .765 .839 r
F P
0 g
s
.44467 .43389 m .43823 .44259 L .40316 .43335 L p .755 .791 .883 r
F P
0 g
s
.64073 .56553 m .63482 .55168 L .68636 .551 L p .544 .598 .858 r
F P
0 g
s
.68636 .551 m .69501 .561 L .64073 .56553 L p .544 .598 .858 r
F P
0 g
s
.56377 .48097 m .56092 .47192 L .59938 .48717 L p .354 .561 .914 r
F P
0 g
s
.59938 .48717 m .60529 .49515 L .56377 .48097 L p .354 .561 .914 r
F P
0 g
s
.44467 .43389 m .45109 .42731 L .485 .43727 L p .657 .732 .905 r
F P
0 g
s
.48847 .43208 m .485 .43727 L .45109 .42731 L p .572 .748 .96 r
F P
0 g
s
.485 .43727 m .48847 .43208 L .52162 .44427 L p .478 .669 .947 r
F P
0 g
s
.52162 .44427 m .52129 .44989 L .485 .43727 L p .478 .669 .947 r
F P
0 g
s
.63482 .55168 m .62891 .5385 L .6777 .54141 L p .511 .596 .875 r
F P
0 g
s
.6777 .54141 m .68636 .551 L .63482 .55168 L p .511 .596 .875 r
F P
0 g
s
.52129 .44989 m .52162 .44427 L .55523 .45884 L p .311 .586 .94 r
F P
0 g
s
.55523 .45884 m .55808 .46453 L .52129 .44989 L p .311 .586 .94 r
F P
0 g
s
.40316 .43335 m .41227 .42595 L .44467 .43389 L p .755 .791 .883 r
F P
0 g
s
.45109 .42731 m .44467 .43389 L .41227 .42595 L p .704 .819 .936 r
F P
0 g
s
.62891 .5385 m .623 .52614 L .66903 .53232 L p .467 .592 .895 r
F P
0 g
s
.66903 .53232 m .6777 .54141 L .62891 .5385 L p .467 .592 .895 r
F P
0 g
s
.56092 .47192 m .55808 .46453 L .59346 .48046 L p .222 .53 .921 r
F P
0 g
s
.59346 .48046 m .59938 .48717 L .56092 .47192 L p .222 .53 .921 r
F P
0 g
s
.623 .52614 m .6171 .51472 L .66034 .52381 L p .407 .585 .914 r
F P
0 g
s
.66034 .52381 m .66903 .53232 L .623 .52614 L p .407 .585 .914 r
F P
0 g
s
.41227 .42595 m .42136 .42057 L .45109 .42731 L p .704 .819 .936 r
F P
0 g
s
.45752 .4229 m .45109 .42731 L .42136 .42057 L p .601 .833 .988 r
F P
0 g
s
.45109 .42731 m .45752 .4229 L .48847 .43208 L p .572 .748 .96 r
F P
0 g
s
.49195 .42903 m .48847 .43208 L .45752 .4229 L p .405 .728 .99 r
F P
0 g
s
.48847 .43208 m .49195 .42903 L .52195 .44063 L p .303 .637 .965 r
F P
0 g
s
.52195 .44063 m .52162 .44427 L .48847 .43208 L p .303 .637 .965 r
F P
0 g
s
.52162 .44427 m .52195 .44063 L .55236 .45483 L p .101 .516 .908 r
F P
0 g
s
.55236 .45483 m .55523 .45884 L .52162 .44427 L p .101 .516 .908 r
F P
0 g
s
.31722 .47852 m .32892 .46546 L .36623 .48134 L p .855 .778 .775 r
F P
0 g
s
.36623 .48134 m .35684 .49717 L .31722 .47852 L p .855 .778 .775 r
F P
0 g
s
.37556 .46686 m .36623 .48134 L .32892 .46546 L p .853 .794 .793 r
F P
0 g
s
.32892 .46546 m .34053 .45361 L .37556 .46686 L p .853 .794 .793 r
F P
0 g
s
.38481 .45393 m .37556 .46686 L .34053 .45361 L p .847 .814 .817 r
F P
0 g
s
.6171 .51472 m .6112 .50436 L .65165 .51595 L p .324 .569 .928 r
F P
0 g
s
.65165 .51595 m .66034 .52381 L .6171 .51472 L p .324 .569 .928 r
F P
0 g
s
.30543 .49259 m .31722 .47852 L .35684 .49717 L p .855 .765 .762 r
F P
0 g
s
.35684 .49717 m .34739 .51414 L .30543 .49259 L p .855 .765 .762 r
F P
0 g
s
.34053 .45361 m .35206 .44313 L .38481 .45393 L p .847 .814 .817 r
F P
0 g
s
.39401 .44271 m .38481 .45393 L .35206 .44313 L p .835 .838 .848 r
F P
0 g
s
.29357 .50744 m .30543 .49259 L .34739 .51414 L p .854 .755 .752 r
F P
0 g
s
.34739 .51414 m .33787 .53199 L .29357 .50744 L p .854 .755 .752 r
F P
0 g
s
.55808 .46453 m .55523 .45884 L .58751 .47504 L p .034 .46 .877 r
F P
0 g
s
.58751 .47504 m .59346 .48046 L .55808 .46453 L p .034 .46 .877 r
F P
0 g
s
.28164 .52286 m .29357 .50744 L .33787 .53199 L p .852 .747 .746 r
F P
0 g
s
.33787 .53199 m .3283 .55047 L .28164 .52286 L p .852 .747 .746 r
F P
0 g
s
.35206 .44313 m .36352 .43418 L .39401 .44271 L p .835 .838 .848 r
F P
0 g
s
.40316 .43335 m .39401 .44271 L .36352 .43418 L p .812 .866 .887 r
F P
0 g
s
.73799 .61332 m .72945 .60291 L .7839 .57289 L p .639 .701 .89 r
F P
0 g
s
.7839 .57289 m .79464 .57831 L .73799 .61332 L p .639 .701 .89 r
F P
0 g
s
.26965 .53858 m .28164 .52286 L .3283 .55047 L p .85 .74 .742 r
F P
0 g
s
.3283 .55047 m .31869 .56929 L .26965 .53858 L p .85 .74 .742 r
F P
0 g
s
.6112 .50436 m .60529 .49515 L .64293 .50881 L p .209 .537 .925 r
F P
0 g
s
.64293 .50881 m .65165 .51595 L .6112 .50436 L p .209 .537 .925 r
F P
0 g
s
.42136 .42057 m .43044 .41726 L .45752 .4229 L p .601 .833 .988 r
F P
0 g
s
.46397 .42066 m .45752 .4229 L .43044 .41726 L p .399 .79 .988 r
F P
0 g
s
.45752 .4229 m .46397 .42066 L .49195 .42903 L p .405 .728 .99 r
F P
0 g
s
.72945 .60291 m .72088 .59236 L .77311 .56743 L p .621 .701 .902 r
F P
0 g
s
.77311 .56743 m .7839 .57289 L .72945 .60291 L p .621 .701 .902 r
F P
0 g
s
.36352 .43418 m .37491 .42687 L .40316 .43335 L p .812 .866 .887 r
F P
0 g
s
.41227 .42595 m .40316 .43335 L .37491 .42687 L p .768 .894 .933 r
F P
0 g
s
.25762 .55437 m .26965 .53858 L .31869 .56929 L p .846 .735 .741 r
F P
0 g
s
.31869 .56929 m .30906 .58816 L .25762 .55437 L p .846 .735 .741 r
F P
0 g
s
.49545 .42809 m .49195 .42903 L .46397 .42066 L p .12 .611 .91 r
F P
0 g
s
.49195 .42903 m .49545 .42809 L .52228 .43893 L p .027 .519 .877 r
F P
0 g
s
.52228 .43893 m .52218 .43943 L p .51697 .4372 L .027 .519 .877 r
F P
0 g
s
.52195 .44063 m .52228 .43893 L .54948 .4525 L p 0 .371 .763 r
F P
0 g
s
.52195 .44063 m .49195 .42903 L p .51697 .4372 L .027 .519 .877 r
F P
0 g
s
.52218 .43943 m .52195 .44063 L p .51697 .4372 L .027 .519 .877 r
F P
0 g
s
.55236 .45483 m .52195 .44063 L p .54127 .44896 L 0 .371 .763 r
F P
0 g
s
.54948 .4525 m .55229 .45477 L p .54127 .44896 L 0 .371 .763 r
F P
0 g
s
.55229 .45477 m .55236 .45483 L p .54127 .44896 L 0 .371 .763 r
F P
0 g
s
.52262 .43912 m .54657 .45178 L p .53073 .4434 L .399 0 0 r
F P
0 g
s
.52228 .43893 m .52257 .43909 L p .53073 .4434 L .399 0 0 r
F P
0 g
s
.52257 .43909 m .52262 .43912 L p .53073 .4434 L .399 0 0 r
F P
0 g
s
.50254 .43222 m .52296 .44109 L p .5032 .43128 L .48 0 0 r
F P
0 g
s
.52228 .43893 m .49584 .42825 L p .51852 .43746 L .272 0 0 r
F P
0 g
s
.52262 .43912 m .49584 .42825 L .49583 .42825 L .272 0 0 r
F
.52262 .43912 m .52254 .43908 L p .51852 .43746 L F P
0 g
s
.49898 .42919 m .52262 .43912 L p .50084 .43028 L .272 0 0 r
F P
0 g
s
.49898 .42919 m .49986 .42994 L p .5032 .43128 L .48 0 0 r
F P
0 g
s
.49986 .42994 m .50254 .43222 L p .5032 .43128 L .48 0 0 r
F P
0 g
s
.52254 .43908 m .52228 .43893 L p .51852 .43746 L .272 0 0 r
F P
0 g
s
.49584 .42825 m .49545 .42809 L p .49583 .42825 L .272 0 0 r
F P
0 g
s
.46397 .42066 m .47044 .42056 L .49545 .42809 L p .12 .611 .91 r
F P
0 g
s
.49545 .42809 m .4965 .42842 L p .50084 .43028 L .272 0 0 r
F P
0 g
s
.4965 .42842 m .49898 .42919 L p .50084 .43028 L .272 0 0 r
F P
0 g
s
.49898 .42919 m .49545 .42809 L .47044 .42056 L p .209 0 0 r
F P
0 g
s
.47044 .42056 m .47696 .42253 L .49518 .42804 L p .209 0 0 r
F P
0 g
s
.49518 .42804 m .49898 .42919 L p .49527 .42807 L .209 0 0 r
F P
0 g
s
.49527 .42807 m .47044 .42056 L .49518 .42804 L .209 0 0 r
F
.24558 .56996 m .25762 .55437 L .30906 .58816 L p .841 .731 .742 r
F P
0 g
s
.30906 .58816 m .29943 .6068 L .24558 .56996 L p .841 .731 .742 r
F P
0 g
s
.72088 .59236 m .71228 .58179 L .76228 .56194 L p .597 .701 .916 r
F P
0 g
s
.76228 .56194 m .77311 .56743 L .72088 .59236 L p .597 .701 .916 r
F P
0 g
s
.60529 .49515 m .59938 .48717 L .6342 .50243 L p .058 .478 .888 r
F P
0 g
s
.6342 .50243 m .64293 .50881 L .60529 .49515 L p .058 .478 .888 r
F P
0 g
s
.37491 .42687 m .38624 .42129 L .41227 .42595 L p .768 .894 .933 r
F P
0 g
s
.42136 .42057 m .41227 .42595 L .38624 .42129 L p .679 .911 .975 r
F P
0 g
s
.55523 .45884 m .55236 .45483 L .58154 .47093 L p 0 .339 .752 r
F P
0 g
s
.58751 .47504 m .55523 .45884 L p .57708 .46888 L 0 .339 .752 r
F P
0 g
s
.57553 .46809 m .58154 .47093 L .57038 .46477 L p .389 0 0 r
F P
0 g
s
.57038 .46477 m .55236 .45483 L p .56603 .46265 L .389 0 0 r
F P
0 g
s
.57553 .46809 m .57038 .46477 L .56603 .46265 L .389 0 0 r
F
.54948 .4525 m .57553 .46809 L p .56603 .46265 L F P
0 g
s
.55236 .45483 m .54948 .4525 L p .56603 .46265 L .389 0 0 r
F P
0 g
s
.54657 .45178 m .55562 .45758 L p .5543 .45587 L .528 0 0 r
F P
0 g
s
.55562 .45758 m .56948 .46648 L p .55935 .4594 L .528 0 0 r
F P
0 g
s
.55935 .4594 m .5543 .45587 L .55562 .45758 L .528 0 0 r
F
.54948 .4525 m .54756 .45202 L p .5543 .45587 L F P
0 g
s
.54756 .45202 m .54657 .45178 L p .5543 .45587 L .528 0 0 r
F P
0 g
s
.58154 .47093 m .58577 .47384 L p .57708 .46888 L 0 .339 .752 r
F P
0 g
s
.58577 .47384 m .58751 .47504 L p .57708 .46888 L 0 .339 .752 r
F P
0 g
s
.71228 .58179 m .70365 .57129 L .75141 .55647 L p .567 .701 .932 r
F P
0 g
s
.75141 .55647 m .76228 .56194 L .71228 .58179 L p .567 .701 .932 r
F P
0 g
s
.43044 .41726 m .43954 .41601 L .46397 .42066 L p .399 .79 .988 r
F P
0 g
s
.47044 .42056 m .46397 .42066 L .43954 .41601 L p .08 .621 .85 r
F P
0 g
s
.70365 .57129 m .69501 .561 L .74051 .55104 L p .528 .7 .948 r
F P
0 g
s
.74051 .55104 m .75141 .55647 L .70365 .57129 L p .528 .7 .948 r
F P
0 g
s
.38624 .42129 m .39754 .41751 L .42136 .42057 L p .679 .911 .975 r
F P
0 g
s
.43044 .41726 m .42136 .42057 L .39754 .41751 L p .506 .878 .977 r
F P
0 g
s
.59938 .48717 m .59346 .48046 L .62543 .49684 L p 0 .385 .798 r
F P
0 g
s
.62543 .49684 m .6342 .50243 L .59938 .48717 L p 0 .385 .798 r
F P
0 g
s
.69501 .561 m .68636 .551 L .72957 .5457 L p .475 .695 .964 r
F P
0 g
s
.72957 .5457 m .74051 .55104 L .69501 .561 L p .475 .695 .964 r
F P
0 g
s
.54657 .45178 m .54948 .4525 L .52228 .43893 L p .399 0 0 r
F P
0 g
s
.68636 .551 m .6777 .54141 L .71859 .54047 L p .405 .682 .974 r
F P
0 g
s
.71859 .54047 m .72957 .5457 L .68636 .551 L p .405 .682 .974 r
F P
0 g
s
.39754 .41751 m .40882 .41556 L .43044 .41726 L p .506 .878 .977 r
F P
0 g
s
.43954 .41601 m .43044 .41726 L .40882 .41556 L p .226 .739 .874 r
F P
0 g
s
.59346 .48046 m .58751 .47504 L .61664 .49205 L p 0 .266 .657 r
F P
0 g
s
.61664 .49205 m .62543 .49684 L .60285 .48527 L p 0 .266 .657 r
F P
0 g
s
.61664 .49205 m .60285 .48527 L .60266 .48506 L 0 .266 .657 r
F
.6078 .48807 m .61664 .49205 L .58751 .47504 L p .443 0 0 r
F P
0 g
s
.58751 .47504 m .58154 .47093 L .60192 .48423 L p .443 0 0 r
F P
0 g
s
.60192 .48423 m .6078 .48807 L p .60205 .48438 L .443 0 0 r
F P
0 g
s
.60205 .48438 m .58751 .47504 L .60192 .48423 L .443 0 0 r
F
.60285 .48527 m .59346 .48046 L p .60266 .48506 L 0 .266 .657 r
F P
0 g
s
.6777 .54141 m .66903 .53232 L .70758 .53537 L p .311 .656 .971 r
F P
0 g
s
.70758 .53537 m .71859 .54047 L .6777 .54141 L p .311 .656 .971 r
F P
0 g
s
.43954 .41601 m .44866 .4168 L .47044 .42056 L p .08 .621 .85 r
F P
0 g
s
.47696 .42253 m .47044 .42056 L .44866 .4168 L p .24 0 0 r
F P
0 g
s
.66903 .53232 m .66034 .52381 L .69654 .53045 L p .191 .61 .945 r
F P
0 g
s
.69654 .53045 m .70758 .53537 L .66903 .53232 L p .191 .61 .945 r
F P
0 g
s
.40882 .41556 m .4201 .41543 L .43954 .41601 L p .226 .739 .874 r
F P
0 g
s
.44866 .4168 m .43954 .41601 L .4201 .41543 L p .091 0 0 r
F P
0 g
s
.56948 .46648 m .57553 .46809 L .54948 .4525 L p .528 0 0 r
F P
0 g
s
.50254 .43222 m .49898 .42919 L .47696 .42253 L p .443 0 0 r
F P
0 g
s
.52296 .44109 m .52262 .43912 L .49898 .42919 L p .48 0 0 r
F P
0 g
s
.66034 .52381 m .65165 .51595 L .68546 .5257 L p .045 .537 .884 r
F P
0 g
s
.68546 .5257 m .69654 .53045 L .66034 .52381 L p .045 .537 .884 r
F P
0 g
s
.52262 .43912 m .52296 .44109 L .54364 .45257 L p .546 0 0 r
F P
0 g
s
.54364 .45257 m .54657 .45178 L .52262 .43912 L p .546 0 0 r
F P
0 g
s
.30282 .44987 m .31609 .44154 L .34053 .45361 L p .869 .896 .85 r
F P
0 g
s
.34053 .45361 m .32892 .46546 L .30282 .44987 L p .869 .896 .85 r
F P
0 g
s
.35206 .44313 m .34053 .45361 L .31609 .44154 L p .851 .92 .877 r
F P
0 g
s
.31609 .44154 m .32927 .43432 L .35206 .44313 L p .851 .92 .877 r
F P
0 g
s
.36352 .43418 m .35206 .44313 L .32927 .43432 L p .817 .945 .908 r
F P
0 g
s
.28945 .45915 m .30282 .44987 L .32892 .46546 L p .878 .874 .828 r
F P
0 g
s
.32892 .46546 m .31722 .47852 L .28945 .45915 L p .878 .874 .828 r
F P
0 g
s
.32927 .43432 m .34237 .42832 L .36352 .43418 L p .817 .945 .908 r
F P
0 g
s
.37491 .42687 m .36352 .43418 L .34237 .42832 L p .754 .961 .936 r
F P
0 g
s
.27599 .46924 m .28945 .45915 L .31722 .47852 L p .882 .855 .811 r
F P
0 g
s
.31722 .47852 m .30543 .49259 L .27599 .46924 L p .882 .855 .811 r
F P
0 g
s
.34237 .42832 m .35539 .42364 L .37491 .42687 L p .754 .961 .936 r
F P
0 g
s
.38624 .42129 m .37491 .42687 L .35539 .42364 L p .639 .951 .945 r
F P
0 g
s
.44866 .4168 m .45784 .41954 L .47696 .42253 L p .24 0 0 r
F P
0 g
s
.48354 .42645 m .47696 .42253 L .45784 .41954 L p .451 0 0 r
F P
0 g
s
.47696 .42253 m .48354 .42645 L .50254 .43222 L p .443 0 0 r
F P
0 g
s
.65165 .51595 m .64293 .50881 L .67434 .52117 L p 0 .438 .783 r
F P
0 g
s
.67434 .52117 m .68546 .5257 L .65165 .51595 L p 0 .438 .783 r
F P
0 g
s
.26244 .47996 m .27599 .46924 L .30543 .49259 L p .882 .838 .798 r
F P
0 g
s
.30543 .49259 m .29357 .50744 L .26244 .47996 L p .882 .838 .798 r
F P
0 g
s
.35539 .42364 m .36835 .42034 L .38624 .42129 L p .639 .951 .945 r
F P
0 g
s
.39754 .41751 m .38624 .42129 L .36835 .42034 L p .449 .88 .902 r
F P
0 g
s
.4201 .41543 m .43141 .41709 L .44866 .4168 L p .091 0 0 r
F P
0 g
s
.45784 .41954 m .44866 .4168 L .43141 .41709 L p .337 0 0 r
F P
0 g
s
.58154 .47093 m .57553 .46809 L .59891 .48487 L p .544 0 0 r
F P
0 g
s
.59891 .48487 m .6078 .48807 L .58154 .47093 L p .544 0 0 r
F P
0 g
s
.24881 .49112 m .26244 .47996 L .29357 .50744 L p .88 .824 .789 r
F P
0 g
s
.29357 .50744 m .28164 .52286 L .24881 .49112 L p .88 .824 .789 r
F P
0 g
s
.79464 .57831 m .7839 .57289 L .82389 .53529 L p .698 .834 .948 r
F P
0 g
s
.82389 .53529 m .83625 .53514 L .79464 .57831 L p .698 .834 .948 r
F P
0 g
s
.66318 .51685 m .67434 .52117 L .64684 .51035 L p .263 0 0 r
F P
0 g
s
.64684 .51035 m .64293 .50881 L p .64726 .51053 L .263 0 0 r
F P
0 g
s
.66318 .51685 m .64684 .51035 L .64726 .51053 L .263 0 0 r
F
.64293 .50881 m .6342 .50243 L .66318 .51685 L p F P
0 g
s
.65198 .51276 m .66318 .51685 L .6342 .50243 L p .389 0 0 r
F P
0 g
s
.6342 .50243 m .62543 .49684 L .6508 .51205 L p .389 0 0 r
F P
0 g
s
.6508 .51205 m .65198 .51276 L p .65065 .51198 L .389 0 0 r
F P
0 g
s
.65065 .51198 m .6342 .50243 L .6508 .51205 L .389 0 0 r
F
.23511 .50254 m .24881 .49112 L .28164 .52286 L p .876 .812 .783 r
F P
0 g
s
.28164 .52286 m .26965 .53858 L .23511 .50254 L p .876 .812 .783 r
F P
0 g
s
.54657 .45178 m .54364 .45257 L .56337 .46602 L p .609 .042 0 r
F P
0 g
s
.56337 .46602 m .56948 .46648 L .54657 .45178 L p .609 .042 0 r
F P
0 g
s
.36835 .42034 m .38126 .41848 L .39754 .41751 L p .449 .88 .902 r
F P
0 g
s
.40882 .41556 m .39754 .41751 L .38126 .41848 L p .19 .722 .777 r
F P
0 g
s
.50615 .43704 m .50254 .43222 L .48354 .42645 L p .571 .001 0 r
F P
0 g
s
.50254 .43222 m .50615 .43704 L .5233 .44472 L p .592 .025 0 r
F P
0 g
s
.5233 .44472 m .52296 .44109 L .50254 .43222 L p .592 .025 0 r
F P
0 g
s
.7839 .57289 m .77311 .56743 L .81148 .53549 L p .678 .848 .964 r
F P
0 g
s
.81148 .53549 m .82389 .53529 L .7839 .57289 L p .678 .848 .964 r
F P
0 g
s
.22136 .51401 m .23511 .50254 L .26965 .53858 L p .871 .802 .779 r
F P
0 g
s
.26965 .53858 m .25762 .55437 L .22136 .51401 L p .871 .802 .779 r
F P
0 g
s
.52296 .44109 m .5233 .44472 L .54067 .45476 L p .625 .066 0 r
F P
0 g
s
.54067 .45476 m .54364 .45257 L .52296 .44109 L p .625 .066 0 r
F P
0 g
s
.38126 .41848 m .39414 .41807 L .40882 .41556 L p .19 .722 .777 r
F P
0 g
s
.4201 .41543 m .40882 .41556 L .39414 .41807 L p .079 0 0 r
F P
0 g
s
.20758 .52532 m .22136 .51401 L .25762 .55437 L p .865 .793 .778 r
F P
0 g
s
.25762 .55437 m .24558 .56996 L .20758 .52532 L p .865 .793 .778 r
F P
0 g
s
.77311 .56743 m .76228 .56194 L .79903 .53569 L p .647 .858 .98 r
F P
0 g
s
.79903 .53569 m .81148 .53549 L .77311 .56743 L p .647 .858 .98 r
F P
0 g
s
.57553 .46809 m .56948 .46648 L .58997 .48242 L p .609 .042 0 r
F P
0 g
s
.58997 .48242 m .59891 .48487 L .57553 .46809 L p .609 .042 0 r
F P
0 g
s
.43141 .41709 m .44276 .42048 L .45784 .41954 L p .337 0 0 r
F P
0 g
s
.46708 .42414 m .45784 .41954 L .44276 .42048 L p .491 0 0 r
F P
0 g
s
.45784 .41954 m .46708 .42414 L .48354 .42645 L p .451 0 0 r
F P
0 g
s
.4902 .43219 m .48354 .42645 L .46708 .42414 L p .569 .006 0 r
F P
0 g
s
.48354 .42645 m .4902 .43219 L .50615 .43704 L p .571 .001 0 r
F P
0 g
s
.76228 .56194 m .75141 .55647 L .78651 .53584 L p .602 .864 .992 r
F P
0 g
s
.78651 .53584 m .79903 .53569 L .76228 .56194 L p .602 .864 .992 r
F P
0 g
s
.62543 .49684 m .61664 .49205 L .64073 .5089 L p .486 0 0 r
F P
0 g
s
.64073 .5089 m .65198 .51276 L .62543 .49684 L p .486 0 0 r
F P
0 g
s
.39414 .41807 m .407 .41912 L .4201 .41543 L p .079 0 0 r
F P
0 g
s
.43141 .41709 m .4201 .41543 L .407 .41912 L p .295 0 0 r
F P
0 g
s
.75141 .55647 m .74051 .55104 L .77394 .53588 L p .537 .858 .997 r
F P
0 g
s
.77394 .53588 m .78651 .53584 L .75141 .55647 L p .537 .858 .997 r
F P
0 g
s
.54364 .45257 m .54067 .45476 L .5572 .46661 L p .655 .111 0 r
F P
0 g
s
.5572 .46661 m .56337 .46602 L .54364 .45257 L p .655 .111 0 r
F P
0 g
s
.74051 .55104 m .72957 .5457 L .76131 .53577 L p .449 .836 .985 r
F P
0 g
s
.76131 .53577 m .77394 .53588 L .74051 .55104 L p .449 .836 .985 r
F P
0 g
s
.56948 .46648 m .56337 .46602 L .58096 .48068 L p .649 .102 0 r
F P
0 g
s
.58096 .48068 m .58997 .48242 L .56948 .46648 L p .649 .102 0 r
F P
0 g
s
.61664 .49205 m .6078 .48807 L .62944 .50527 L p .555 0 0 r
F P
0 g
s
.62944 .50527 m .64073 .5089 L .61664 .49205 L p .555 0 0 r
F P
0 g
s
.50981 .44347 m .50615 .43704 L .4902 .43219 L p .638 .099 0 r
F P
0 g
s
.50615 .43704 m .50981 .44347 L .52365 .44981 L p .65 .112 0 r
F P
0 g
s
.52365 .44981 m .5233 .44472 L .50615 .43704 L p .65 .112 0 r
F P
0 g
s
.44276 .42048 m .45417 .42549 L .46708 .42414 L p .491 0 0 r
F P
0 g
s
.47642 .43046 m .46708 .42414 L .45417 .42549 L p .583 .034 0 r
F P
0 g
s
.46708 .42414 m .47642 .43046 L .4902 .43219 L p .569 .006 0 r
F P
0 g
s
.407 .41912 m .41987 .42158 L .43141 .41709 L p .295 0 0 r
F P
0 g
s
.44276 .42048 m .43141 .41709 L .41987 .42158 L p .444 0 0 r
F P
0 g
s
.5233 .44472 m .52365 .44981 L .53765 .4582 L p .666 .134 0 r
F P
0 g
s
.53765 .4582 m .54067 .45476 L .5233 .44472 L p .666 .134 0 r
F P
0 g
s
.72957 .5457 m .71859 .54047 L .74861 .53546 L p .333 .788 .948 r
F P
0 g
s
.74861 .53546 m .76131 .53577 L .72957 .5457 L p .333 .788 .948 r
F P
0 g
s
.49695 .43955 m .4902 .43219 L .47642 .43046 L p .634 .1 0 r
F P
0 g
s
.4902 .43219 m .49695 .43955 L .50981 .44347 L p .638 .099 0 r
F P
0 g
s
.71859 .54047 m .70758 .53537 L .73585 .5349 L p .194 .711 .88 r
F P
0 g
s
.73585 .5349 m .74861 .53546 L .71859 .54047 L p .194 .711 .88 r
F P
0 g
s
.6078 .48807 m .59891 .48487 L .61809 .50186 L p .604 .041 0 r
F P
0 g
s
.61809 .50186 m .62944 .50527 L .6078 .48807 L p .604 .041 0 r
F P
0 g
s
.54067 .45476 m .53765 .4582 L .55095 .46813 L p .681 .157 0 r
F P
0 g
s
.55095 .46813 m .5572 .46661 L .54067 .45476 L p .681 .157 0 r
F P
0 g
s
.41987 .42158 m .43276 .42541 L .44276 .42048 L p .444 0 0 r
F P
0 g
s
.45417 .42549 m .44276 .42048 L .43276 .42541 L p .542 0 0 r
F P
0 g
s
.70758 .53537 m .69654 .53045 L .72303 .53405 L p .041 .606 .781 r
F P
0 g
s
.72303 .53405 m .71014 .53288 L .71094 .53312 L p 0 0 0 r
F P
0 g
s
.73436 .53493 m .70758 .53537 L p .72303 .53405 L .041 .606 .781 r
F P
0 g
s
.71094 .53312 m .72336 .53683 L p .72303 .53405 L 0 0 0 r
F P
0 g
s
.72303 .53405 m .73585 .5349 L .73436 .53493 L p .041 .606 .781 r
F P
0 g
s
.56337 .46602 m .5572 .46661 L .57187 .47957 L p .674 .145 0 r
F P
0 g
s
.57187 .47957 m .58096 .48068 L .56337 .46602 L p .674 .145 0 r
F P
0 g
s
.71014 .53288 m .72303 .53405 L .69654 .53045 L p .11 0 0 r
F P
0 g
s
.69654 .53045 m .68546 .5257 L .71014 .53288 L p .11 0 0 r
F P
0 g
s
.45417 .42549 m .46567 .432 L .47642 .43046 L p .583 .034 0 r
F P
0 g
s
.48587 .43831 m .47642 .43046 L .46567 .432 L p .638 .113 0 r
F P
0 g
s
.47642 .43046 m .48587 .43831 L .49695 .43955 L p .634 .1 0 r
F P
0 g
s
.59891 .48487 m .58997 .48242 L .60669 .49867 L p .638 .093 0 r
F P
0 g
s
.60669 .49867 m .61809 .50186 L .59891 .48487 L p .638 .093 0 r
F P
0 g
s
.31851 .42818 m .33247 .42569 L .34237 .42832 L p .608 .952 .906 r
F P
0 g
s
.34237 .42832 m .32927 .43432 L .31851 .42818 L p .608 .952 .906 r
F P
0 g
s
.35539 .42364 m .34237 .42832 L .33247 .42569 L p .449 .883 .856 r
F P
0 g
s
.33247 .42569 m .34636 .42408 L .35539 .42364 L p .449 .883 .856 r
F P
0 g
s
.36835 .42034 m .35539 .42364 L .34636 .42408 L p .246 .757 .757 r
F P
0 g
s
.30447 .43148 m .31851 .42818 L .32927 .43432 L p .716 .977 .919 r
F P
0 g
s
.32927 .43432 m .31609 .44154 L .30447 .43148 L p .716 .977 .919 r
F P
0 g
s
.51353 .4513 m .50981 .44347 L .49695 .43955 L p .675 .16 .004 r
F P
0 g
s
.50981 .44347 m .51353 .4513 L .52401 .45619 L p .681 .167 .004 r
F P
0 g
s
.52401 .45619 m .52365 .44981 L .50981 .44347 L p .681 .167 .004 r
F P
0 g
s
.34636 .42408 m .36018 .42338 L .36835 .42034 L p .246 .757 .757 r
F P
0 g
s
.38126 .41848 m .36835 .42034 L .36018 .42338 L p 0 0 0 r
F P
0 g
s
.29034 .43551 m .30447 .43148 L .31609 .44154 L p .784 .975 .913 r
F P
0 g
s
.31609 .44154 m .30282 .44987 L .29034 .43551 L p .784 .975 .913 r
F P
0 g
s
.52365 .44981 m .52401 .45619 L .5346 .46271 L p .689 .177 .014 r
F P
0 g
s
.5346 .46271 m .53765 .4582 L .52365 .44981 L p .689 .177 .014 r
F P
0 g
s
.68546 .5257 m .67434 .52117 L .69719 .53136 L p .243 0 0 r
F P
0 g
s
.69719 .53136 m .71014 .53288 L .68546 .5257 L p .243 0 0 r
F P
0 g
s
.27611 .44018 m .29034 .43551 L .30282 .44987 L p .825 .961 .898 r
F P
0 g
s
.30282 .44987 m .28945 .45915 L .27611 .44018 L p .825 .961 .898 r
F P
0 g
s
.36018 .42338 m .37394 .42364 L .38126 .41848 L p 0 0 0 r
F P
0 g
s
.39414 .41807 m .38126 .41848 L .37394 .42364 L p .172 0 0 r
F P
0 g
s
.43276 .42541 m .44569 .43052 L .45417 .42549 L p .542 0 0 r
F P
0 g
s
.46567 .432 m .45417 .42549 L .44569 .43052 L p .606 .074 0 r
F P
0 g
s
.50381 .44833 m .49695 .43955 L .48587 .43831 L p .672 .16 .013 r
F P
0 g
s
.49695 .43955 m .50381 .44833 L .51353 .4513 L p .675 .16 .004 r
F P
0 g
s
.2618 .44538 m .27611 .44018 L .28945 .45915 L p .849 .942 .882 r
F P
0 g
s
.28945 .45915 m .27599 .46924 L .2618 .44538 L p .849 .942 .882 r
F P
0 g
s
.37394 .42364 m .38766 .42487 L .39414 .41807 L p .172 0 0 r
F P
0 g
s
.407 .41912 m .39414 .41807 L .38766 .42487 L p .329 0 0 r
F P
0 g
s
.67434 .52117 m .66318 .51685 L .68418 .52947 L p .353 0 0 r
F P
0 g
s
.68418 .52947 m .69719 .53136 L .67434 .52117 L p .353 0 0 r
F P
0 g
s
.5572 .46661 m .55095 .46813 L .56271 .47903 L p .69 .176 .007 r
F P
0 g
s
.56271 .47903 m .57187 .47957 L .5572 .46661 L p .69 .176 .007 r
F P
0 g
s
.58997 .48242 m .58096 .48068 L .59523 .49568 L p .662 .132 0 r
F P
0 g
s
.59523 .49568 m .60669 .49867 L .58997 .48242 L p .662 .132 0 r
F P
0 g
s
.24741 .45099 m .2618 .44538 L .27599 .46924 L p .862 .922 .867 r
F P
0 g
s
.27599 .46924 m .26244 .47996 L .24741 .45099 L p .862 .922 .867 r
F P
0 g
s
.53765 .4582 m .5346 .46271 L .54463 .47045 L p .696 .189 .029 r
F P
0 g
s
.54463 .47045 m .55095 .46813 L .53765 .4582 L p .696 .189 .029 r
F P
0 g
s
.38766 .42487 m .40134 .42705 L .407 .41912 L p .329 0 0 r
F P
0 g
s
.41987 .42158 m .407 .41912 L .40134 .42705 L p .445 0 0 r
F P
0 g
s
.66318 .51685 m .65198 .51276 L .67112 .52719 L p .441 0 0 r
F P
0 g
s
.67112 .52719 m .68418 .52947 L .66318 .51685 L p .441 0 0 r
F P
0 g
s
.23293 .4569 m .24741 .45099 L .26244 .47996 L p .867 .903 .855 r
F P
0 g
s
.26244 .47996 m .24881 .49112 L .23293 .4569 L p .867 .903 .855 r
F P
0 g
s
.46567 .432 m .47728 .43985 L .48587 .43831 L p .638 .113 0 r
F P
0 g
s
.49546 .44749 m .48587 .43831 L .47728 .43985 L p .673 .165 .028 r
F P
0 g
s
.48587 .43831 m .49546 .44749 L .50381 .44833 L p .672 .16 .013 r
F P
0 g
s
.44569 .43052 m .45869 .43681 L .46567 .432 L p .606 .074 0 r
F P
0 g
s
.47728 .43985 m .46567 .432 L .45869 .43681 L p .649 .134 .005 r
F P
0 g
s
.83625 .53514 m .82389 .53529 L .8458 .49184 L p .799 .926 .919 r
F P
0 g
s
.8458 .49184 m .85906 .48583 L .83625 .53514 L p .799 .926 .919 r
F P
0 g
s
.40134 .42705 m .41501 .43018 L .41987 .42158 L p .445 0 0 r
F P
0 g
s
.43276 .42541 m .41987 .42158 L .41501 .43018 L p .529 0 0 r
F P
0 g
s
.21838 .46297 m .23293 .4569 L .24881 .49112 L p .868 .885 .846 r
F P
0 g
s
.24881 .49112 m .23511 .50254 L .21838 .46297 L p .868 .885 .846 r
F P
0 g
s
.58096 .48068 m .57187 .47957 L .58371 .49287 L p .679 .163 0 r
F P
0 g
s
.58371 .49287 m .59523 .49568 L .58096 .48068 L p .679 .163 0 r
F P
0 g
s
.65198 .51276 m .64073 .5089 L .65801 .52452 L p .508 0 0 r
F P
0 g
s
.65801 .52452 m .67112 .52719 L .65198 .51276 L p .508 0 0 r
F P
0 g
s
.82389 .53529 m .81148 .53549 L .83249 .498 L p .788 .947 .926 r
F P
0 g
s
.83249 .498 m .8458 .49184 L .82389 .53529 L p .788 .947 .926 r
F P
0 g
s
.20377 .46907 m .21838 .46297 L .23511 .50254 L p .865 .868 .839 r
F P
0 g
s
.23511 .50254 m .22136 .51401 L .20377 .46907 L p .865 .868 .839 r
F P
0 g
s
.51731 .46026 m .51353 .4513 L .50381 .44833 L p .696 .197 .055 r
F P
0 g
s
.51353 .4513 m .51731 .46026 L .52437 .4636 L p .699 .2 .055 r
F P
0 g
s
.52437 .4636 m .52401 .45619 L .51353 .4513 L p .699 .2 .055 r
F P
0 g
s
.52401 .45619 m .52437 .4636 L .53149 .46807 L p .702 .205 .059 r
F P
0 g
s
.53149 .46807 m .5346 .46271 L .52401 .45619 L p .702 .205 .059 r
F P
0 g
s
.55095 .46813 m .54463 .47045 L .55345 .47895 L p .7 .198 .045 r
F P
0 g
s
.55345 .47895 m .56271 .47903 L .55095 .46813 L p .7 .198 .045 r
F P
0 g
s
.41501 .43018 m .42867 .4342 L .43276 .42541 L p .529 0 0 r
F P
0 g
s
.44569 .43052 m .43276 .42541 L .42867 .4342 L p .588 .056 0 r
F P
0 g
s
.64073 .5089 m .62944 .50527 L .64485 .52146 L p .56 .002 0 r
F P
0 g
s
.64485 .52146 m .65801 .52452 L .64073 .5089 L p .56 .002 0 r
F P
0 g
s
.51078 .45827 m .50381 .44833 L .49546 .44749 L p .694 .197 .059 r
F P
0 g
s
.50381 .44833 m .51078 .45827 L .51731 .46026 L p .696 .197 .055 r
F P
0 g
s
.18911 .47507 m .20377 .46907 L .22136 .51401 L p .86 .853 .834 r
F P
0 g
s
.22136 .51401 m .20758 .52532 L .18911 .47507 L p .86 .853 .834 r
F P
0 g
s
.81148 .53549 m .79903 .53569 L .81913 .50418 L p .765 .963 .931 r
F P
0 g
s
.81913 .50418 m .83249 .498 L .81148 .53549 L p .765 .963 .931 r
F P
0 g
s
.5346 .46271 m .53149 .46807 L .53822 .4734 L p .704 .21 .065 r
F P
0 g
s
.53822 .4734 m .54463 .47045 L .5346 .46271 L p .704 .21 .065 r
F P
0 g
s
.45869 .43681 m .47176 .44413 L .47728 .43985 L p .649 .134 .005 r
F P
0 g
s
.48902 .44885 m .47728 .43985 L .47176 .44413 L p .677 .175 .045 r
F P
0 g
s
.47728 .43985 m .48902 .44885 L .49546 .44749 L p .673 .165 .028 r
F P
0 g
s
.57187 .47957 m .56271 .47903 L .57213 .4902 L p .691 .186 .034 r
F P
0 g
s
.57213 .4902 m .58371 .49287 L .57187 .47957 L p .691 .186 .034 r
F P
0 g
s
.62944 .50527 m .61809 .50186 L .63165 .51802 L p .6 .056 0 r
F P
0 g
s
.63165 .51802 m .64485 .52146 L .62944 .50527 L p .6 .056 0 r
F P
0 g
s
.79903 .53569 m .78651 .53584 L .80571 .51024 L p .727 .971 .93 r
F P
0 g
s
.80571 .51024 m .81913 .50418 L .79903 .53569 L p .727 .971 .93 r
F P
0 g
s
.42867 .4342 m .44234 .43905 L .44569 .43052 L p .588 .056 0 r
F P
0 g
s
.45869 .43681 m .44569 .43052 L .44234 .43905 L p .631 .113 0 r
F P
0 g
s
.50518 .45777 m .49546 .44749 L .48902 .44885 L p .694 .199 .065 r
F P
0 g
s
.49546 .44749 m .50518 .45777 L .51078 .45827 L p .694 .197 .059 r
F P
0 g
s
.78651 .53584 m .77394 .53588 L .7922 .51605 L p .669 .967 .921 r
F P
0 g
s
.7922 .51605 m .80571 .51024 L .78651 .53584 L p .669 .967 .921 r
F P
0 g
s
.61809 .50186 m .60669 .49867 L .61842 .51421 L p .63 .1 0 r
F P
0 g
s
.61842 .51421 m .63165 .51802 L .61809 .50186 L p .63 .1 0 r
F P
0 g
s
.54463 .47045 m .53822 .4734 L .54411 .47924 L p .706 .213 .072 r
F P
0 g
s
.54411 .47924 m .55345 .47895 L .54463 .47045 L p .706 .213 .072 r
F P
0 g
s
.44234 .43905 m .45603 .44466 L .45869 .43681 L p .631 .113 0 r
F P
0 g
s
.47176 .44413 m .45869 .43681 L .45603 .44466 L p .662 .156 .032 r
F P
0 g
s
.77394 .53588 m .76131 .53577 L .77861 .52148 L p .586 .945 .898 r
F P
0 g
s
.77861 .52148 m .7922 .51605 L .77394 .53588 L p .586 .945 .898 r
F P
0 g
s
.56271 .47903 m .55345 .47895 L .56048 .48766 L p .7 .203 .059 r
F P
0 g
s
.56048 .48766 m .57213 .4902 L .56271 .47903 L p .7 .203 .059 r
F P
0 g
s
.60669 .49867 m .59523 .49568 L .60515 .51008 L p .654 .135 0 r
F P
0 g
s
.60515 .51008 m .61842 .51421 L .60669 .49867 L p .654 .135 0 r
F P
0 g
s
.47176 .44413 m .48493 .45234 L .48902 .44885 L p .677 .175 .045 r
F P
0 g
s
.50089 .45878 m .48902 .44885 L .48493 .45234 L p .696 .203 .072 r
F P
0 g
s
.48902 .44885 m .50089 .45878 L .50518 .45777 L p .694 .199 .065 r
F P
0 g
s
.52118 .47009 m .51731 .46026 L .51078 .45827 L p .707 .219 .084 r
F P
0 g
s
.51731 .46026 m .52118 .47009 L .52474 .47179 L p .708 .22 .084 r
F P
0 g
s
.52474 .47179 m .52437 .4636 L .51731 .46026 L p .708 .22 .084 r
F P
0 g
s
.76131 .53577 m .74861 .53546 L .76493 .52638 L p .476 .896 .854 r
F P
0 g
s
.76493 .52638 m .77861 .52148 L .76131 .53577 L p .476 .896 .854 r
F P
0 g
s
.52437 .4636 m .52474 .47179 L .52833 .47408 L p .709 .221 .085 r
F P
0 g
s
.52833 .47408 m .53149 .46807 L .52437 .4636 L p .709 .221 .085 r
F P
0 g
s
.51788 .46909 m .51078 .45827 L .50518 .45777 L p .706 .219 .085 r
F P
0 g
s
.51078 .45827 m .51788 .46909 L .52118 .47009 L p .707 .219 .084 r
F P
0 g
s
.45603 .44466 m .46975 .45095 L .47176 .44413 L p .662 .156 .032 r
F P
0 g
s
.48493 .45234 m .47176 .44413 L .46975 .45095 L p .683 .186 .059 r
F P
0 g
s
.59523 .49568 m .58371 .49287 L .59186 .50564 L p .672 .163 .024 r
F P
0 g
s
.59186 .50564 m .60515 .51008 L .59523 .49568 L p .672 .163 .024 r
F P
0 g
s
.53149 .46807 m .52833 .47408 L .53171 .4768 L p .709 .222 .087 r
F P
0 g
s
.53171 .4768 m .53822 .4734 L .53149 .46807 L p .709 .222 .087 r
F P
0 g
s
.74861 .53546 m .73585 .5349 L .75116 .53065 L p .34 .818 .787 r
F P
0 g
s
.75116 .53065 m .76493 .52638 L .74861 .53546 L p .34 .818 .787 r
F P
0 g
s
.51506 .46886 m .50518 .45777 L .50089 .45878 L p .706 .219 .087 r
F P
0 g
s
.50518 .45777 m .51506 .46886 L .51788 .46909 L p .706 .219 .085 r
F P
0 g
s
.55345 .47895 m .54411 .47924 L .54876 .48522 L p .706 .215 .078 r
F P
0 g
s
.54876 .48522 m .56048 .48766 L .55345 .47895 L p .706 .215 .078 r
F P
0 g
s
.73585 .5349 m .72303 .53405 L .7373 .53416 L p .187 .712 .697 r
F P
0 g
s
.7373 .53416 m .75116 .53065 L .73585 .5349 L p .187 .712 .697 r
F P
0 g
s
.36295 .4305 m .37667 .43296 L .37394 .42364 L p .278 0 0 r
F P
0 g
s
.37394 .42364 m .36018 .42338 L .36295 .4305 L p .278 0 0 r
F P
0 g
s
.38766 .42487 m .37394 .42364 L .37667 .43296 L p .389 0 0 r
F P
0 g
s
.34918 .42842 m .36295 .4305 L .36018 .42338 L p .137 0 0 r
F P
0 g
s
.36018 .42338 m .34636 .42408 L .34918 .42842 L p .137 0 0 r
F P
0 g
s
.37667 .43296 m .39033 .43578 L .38766 .42487 L p .389 0 0 r
F P
0 g
s
.40134 .42705 m .38766 .42487 L .39033 .43578 L p .475 0 0 r
F P
0 g
s
.58371 .49287 m .57213 .4902 L .57854 .50093 L p .686 .185 .049 r
F P
0 g
s
.57854 .50093 m .59186 .50564 L .58371 .49287 L p .686 .185 .049 r
F P
0 g
s
.33247 .42569 m .31851 .42818 L .32144 .42531 L p .21 .735 .773 r
F P
0 g
s
.32144 .42531 m .33534 .4267 L .33247 .42569 L p .21 .735 .773 r
F P
0 g
s
.33534 .4267 m .32144 .42531 L .32243 .42536 L p 0 .542 .732 r
F P
0 g
s
.34897 .42811 m .34636 .42408 L p .33534 .4267 L 0 0 0 r
F P
0 g
s
.34636 .42408 m .33247 .42569 L .33534 .4267 L p 0 0 0 r
F P
0 g
s
.32243 .42536 m .33901 .4262 L p .33534 .4267 L 0 .542 .732 r
F P
0 g
s
.33534 .4267 m .34918 .42842 L .34897 .42811 L p 0 0 0 r
F P
0 g
s
.53822 .4734 m .53171 .4768 L .53466 .47979 L p .71 .223 .089 r
F P
0 g
s
.53466 .47979 m .54411 .47924 L .53822 .4734 L p .71 .223 .089 r
F P
0 g
s
.39033 .43578 m .40394 .43898 L .40134 .42705 L p .475 0 0 r
F P
0 g
s
.41501 .43018 m .40134 .42705 L .40394 .43898 L p .54 0 0 r
F P
0 g
s
.72336 .53683 m .7373 .53416 L .72303 .53405 L p 0 0 0 r
F P
0 g
s
.40394 .43898 m .41751 .44254 L .41501 .43018 L p .54 0 0 r
F P
0 g
s
.42867 .4342 m .41501 .43018 L .41751 .44254 L p .589 .055 0 r
F P
0 g
s
.46975 .45095 m .48351 .45779 L .48493 .45234 L p .683 .186 .059 r
F P
0 g
s
.49821 .46127 m .48493 .45234 L .48351 .45779 L p .698 .208 .078 r
F P
0 g
s
.48493 .45234 m .49821 .46127 L .50089 .45878 L p .696 .203 .072 r
F P
0 g
s
.51292 .46941 m .50089 .45878 L .49821 .46127 L p .707 .22 .089 r
F P
0 g
s
.50089 .45878 m .51292 .46941 L .51506 .46886 L p .706 .219 .087 r
F P
0 g
s
.30747 .42424 m .32144 .42531 L .31851 .42818 L p .379 .843 .866 r
F P
0 g
s
.31851 .42818 m .30447 .43148 L .30747 .42424 L p .379 .843 .866 r
F P
0 g
s
.41751 .44254 m .43105 .44644 L .42867 .4342 L p .589 .055 0 r
F P
0 g
s
.44234 .43905 m .42867 .4342 L .43105 .44644 L p .626 .105 0 r
F P
0 g
s
.71014 .53288 m .69719 .53136 L .70933 .53857 L p .117 0 0 r
F P
0 g
s
.70933 .53857 m .72336 .53683 L .71014 .53288 L p .117 0 0 r
F P
0 g
s
.57213 .4902 m .56048 .48766 L .56521 .49602 L p .696 .203 .068 r
F P
0 g
s
.56521 .49602 m .57854 .50093 L .57213 .4902 L p .696 .203 .068 r
F P
0 g
s
.29343 .42345 m .30747 .42424 L .30447 .43148 L p .519 .911 .923 r
F P
0 g
s
.30447 .43148 m .29034 .43551 L .29343 .42345 L p .519 .911 .923 r
F P
0 g
s
.43105 .44644 m .44455 .45066 L .44234 .43905 L p .626 .105 0 r
F P
0 g
s
.45603 .44466 m .44234 .43905 L .44455 .45066 L p .654 .144 .019 r
F P
0 g
s
.69719 .53136 m .68418 .52947 L .69523 .53934 L p .244 0 0 r
F P
0 g
s
.69523 .53934 m .70933 .53857 L .69719 .53136 L p .244 0 0 r
F P
0 g
s
.54411 .47924 m .53466 .47979 L .53698 .48283 L p .71 .224 .091 r
F P
0 g
s
.53698 .48283 m .54876 .48522 L .54411 .47924 L p .71 .224 .091 r
F P
0 g
s
.27931 .42291 m .29343 .42345 L .29034 .43551 L p .624 .945 .948 r
F P
0 g
s
.29034 .43551 m .27611 .44018 L .27931 .42291 L p .624 .945 .948 r
F P
0 g
s
.52511 .48046 m .52118 .47009 L .51788 .46909 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .52474 .47179 L .52118 .47009 L closepath p .712 .229 .098 r
F P
0 g
s
.44455 .45066 m .45802 .45516 L .45603 .44466 L p .654 .144 .019 r
F P
0 g
s
.46975 .45095 m .45603 .44466 L .45802 .45516 L p .675 .174 .046 r
F P
0 g
s
.52511 .48046 m .52833 .47408 L .52474 .47179 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .51788 .46909 L .51506 .46886 L closepath p .712 .229 .098 r
F P
0 g
s
.68418 .52947 m .67112 .52719 L .68107 .53908 L p .35 0 0 r
F P
0 g
s
.68107 .53908 m .69523 .53934 L .68418 .52947 L p .35 0 0 r
F P
0 g
s
.48351 .45779 m .49732 .46508 L .49821 .46127 L p .698 .208 .078 r
F P
0 g
s
.5116 .47071 m .49821 .46127 L .49732 .46508 L p .707 .222 .091 r
F P
0 g
s
.49821 .46127 m .5116 .47071 L .51292 .46941 L p .707 .22 .089 r
F P
0 g
s
.56048 .48766 m .54876 .48522 L .55186 .49093 L p .704 .215 .082 r
F P
0 g
s
.55186 .49093 m .56521 .49602 L .56048 .48766 L p .704 .215 .082 r
F P
0 g
s
.52511 .48046 m .53171 .4768 L .52833 .47408 L closepath p .712 .229 .098 r
F P
0 g
s
.26513 .42256 m .27931 .42291 L .27611 .44018 L p .697 .953 .953 r
F P
0 g
s
.27611 .44018 m .2618 .44538 L .26513 .42256 L p .697 .953 .953 r
F P
0 g
s
.52511 .48046 m .51506 .46886 L .51292 .46941 L closepath p .712 .229 .098 r
F P
0 g
s
.45802 .45516 m .47147 .45991 L .46975 .45095 L p .675 .174 .046 r
F P
0 g
s
.48351 .45779 m .46975 .45095 L .47147 .45991 L p .69 .196 .067 r
F P
0 g
s
.67112 .52719 m .65801 .52452 L .66687 .5378 L p .435 0 0 r
F P
0 g
s
.66687 .5378 m .68107 .53908 L .67112 .52719 L p .435 0 0 r
F P
0 g
s
.52511 .48046 m .53466 .47979 L .53171 .4768 L closepath p .712 .229 .098 r
F P
0 g
s
.25087 .42237 m .26513 .42256 L .2618 .44538 L p .744 .946 .947 r
F P
0 g
s
.2618 .44538 m .24741 .45099 L .25087 .42237 L p .744 .946 .947 r
F P
0 g
s
.65801 .52452 m .64485 .52146 L .65263 .53549 L p .503 0 0 r
F P
0 g
s
.65263 .53549 m .66687 .5378 L .65801 .52452 L p .503 0 0 r
F P
0 g
s
.52511 .48046 m .51292 .46941 L .5116 .47071 L closepath p .712 .229 .098 r
F P
0 g
s
.47147 .45991 m .48491 .46487 L .48351 .45779 L p .69 .196 .067 r
F P
0 g
s
.49732 .46508 m .48351 .45779 L .48491 .46487 L p .701 .212 .082 r
F P
0 g
s
.54876 .48522 m .53698 .48283 L .53849 .48573 L p .709 .224 .092 r
F P
0 g
s
.53849 .48573 m .55186 .49093 L .54876 .48522 L p .709 .224 .092 r
F P
0 g
s
.64485 .52146 m .63165 .51802 L .63837 .53219 L p .556 .018 0 r
F P
0 g
s
.63837 .53219 m .65263 .53549 L .64485 .52146 L p .556 .018 0 r
F P
0 g
s
.52511 .48046 m .53698 .48283 L .53466 .47979 L closepath p .712 .229 .098 r
F P
0 g
s
.23654 .42228 m .25087 .42237 L .24741 .45099 L p .774 .931 .935 r
F P
0 g
s
.24741 .45099 m .23293 .4569 L .23654 .42228 L p .774 .931 .935 r
F P
0 g
s
.63165 .51802 m .61842 .51421 L .62411 .52796 L p .598 .071 0 r
F P
0 g
s
.62411 .52796 m .63837 .53219 L .63165 .51802 L p .598 .071 0 r
F P
0 g
s
.49732 .46508 m .51119 .47268 L .5116 .47071 L p .707 .222 .091 r
F P
0 g
s
.52511 .48046 m .5116 .47071 L .51119 .47268 L closepath p .712 .229 .098 r
F P
0 g
s
.48491 .46487 m .49832 .46998 L .49732 .46508 L p .701 .212 .082 r
F P
0 g
s
.51119 .47268 m .49732 .46508 L .49832 .46998 L p .708 .223 .092 r
F P
0 g
s
.61842 .51421 m .60515 .51008 L .60985 .52286 L p .631 .114 0 r
F P
0 g
s
.60985 .52286 m .62411 .52796 L .61842 .51421 L p .631 .114 0 r
F P
0 g
s
.60515 .51008 m .59186 .50564 L .59561 .517 L p .657 .149 .027 r
F P
0 g
s
.59561 .517 m .60985 .52286 L .60515 .51008 L p .657 .149 .027 r
F P
0 g
s
.22215 .42225 m .23654 .42228 L .23293 .4569 L p .792 .913 .923 r
F P
0 g
s
.23293 .4569 m .21838 .46297 L .22215 .42225 L p .792 .913 .923 r
F P
0 g
s
.85906 .48583 m .8458 .49184 L .84653 .44497 L p .881 .921 .847 r
F P
0 g
s
.84653 .44497 m .85986 .43317 L .85906 .48583 L p .881 .921 .847 r
F P
0 g
s
.52511 .48046 m .53849 .48573 L .53698 .48283 L closepath p .712 .229 .098 r
F P
0 g
s
.59186 .50564 m .57854 .50093 L .58141 .51048 L p .676 .176 .05 r
F P
0 g
s
.58141 .51048 m .59561 .517 L .59186 .50564 L p .676 .176 .05 r
F P
0 g
s
.49832 .46998 m .51172 .4752 L .51119 .47268 L p .708 .223 .092 r
F P
0 g
s
.52511 .48046 m .51119 .47268 L .51172 .4752 L closepath p .712 .229 .098 r
F P
0 g
s
.57854 .50093 m .56521 .49602 L .56726 .50343 L p .691 .197 .068 r
F P
0 g
s
.56726 .50343 m .58141 .51048 L .57854 .50093 L p .691 .197 .068 r
F P
0 g
s
.56521 .49602 m .55186 .49093 L .55315 .49598 L p .701 .213 .082 r
F P
0 g
s
.55315 .49598 m .56726 .50343 L .56521 .49602 L p .701 .213 .082 r
F P
0 g
s
.20769 .42222 m .22215 .42225 L .21838 .46297 L p .8 .894 .91 r
F P
0 g
s
.21838 .46297 m .20377 .46907 L .20769 .42222 L p .8 .894 .91 r
F P
0 g
s
.8458 .49184 m .83249 .498 L .83317 .45701 L p .883 .939 .847 r
F P
0 g
s
.83317 .45701 m .84653 .44497 L .8458 .49184 L p .883 .939 .847 r
F P
0 g
s
.55186 .49093 m .53849 .48573 L .5391 .48828 L p .708 .223 .092 r
F P
0 g
s
.5391 .48828 m .55315 .49598 L .55186 .49093 L p .708 .223 .092 r
F P
0 g
s
.52511 .48046 m .5391 .48828 L .53849 .48573 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .53534 .49228 L .53748 .49168 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .53249 .49206 L .53534 .49228 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .52913 .49105 L .53249 .49206 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .5255 .48931 L .52913 .49105 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .52184 .48697 L .5255 .48931 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .51841 .48418 L .52184 .48697 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .51546 .48115 L .51841 .48418 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .51318 .47808 L .51546 .48115 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .51172 .4752 L .51318 .47808 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .53876 .49031 L .5391 .48828 L closepath p .712 .229 .098 r
F P
0 g
s
.52511 .48046 m .53748 .49168 L .53876 .49031 L closepath p .712 .229 .098 r
F P
0 g
s
.50117 .47565 m .51318 .47808 L .51172 .4752 L p .709 .224 .092 r
F P
0 g
s
.51172 .4752 m .49832 .46998 L .50117 .47565 L p .709 .224 .092 r
F P
0 g
s
.48909 .47313 m .50117 .47565 L .49832 .46998 L p .704 .215 .082 r
F P
0 g
s
.49832 .46998 m .48491 .46487 L .48909 .47313 L p .704 .215 .082 r
F P
0 g
s
.19318 .42214 m .20769 .42222 L .20377 .46907 L p .803 .875 .899 r
F P
0 g
s
.20377 .46907 m .18911 .47507 L .19318 .42214 L p .803 .875 .899 r
F P
0 g
s
.83249 .498 m .81913 .50418 L .81975 .4691 L p .88 .957 .849 r
F P
0 g
s
.81975 .4691 m .83317 .45701 L .83249 .498 L p .88 .957 .849 r
F P
0 g
s
.47694 .47049 m .48909 .47313 L .48491 .46487 L p .696 .202 .067 r
F P
0 g
s
.48491 .46487 m .47147 .45991 L .47694 .47049 L p .696 .202 .067 r
F P
0 g
s
.46471 .46768 m .47694 .47049 L .47147 .45991 L p .686 .184 .047 r
F P
0 g
s
.47147 .45991 m .45802 .45516 L .46471 .46768 L p .686 .184 .047 r
F P
0 g
s
.55315 .49598 m .5391 .48828 L .53876 .49031 L p .707 .222 .091 r
F P
0 g
s
.45242 .46469 m .46471 .46768 L .45802 .45516 L p .671 .161 .021 r
F P
0 g
s
.45802 .45516 m .44455 .45066 L .45242 .46469 L p .671 .161 .021 r
F P
0 g
s
.5057 .48171 m .51546 .48115 L .51318 .47808 L p .71 .224 .091 r
F P
0 g
s
.51318 .47808 m .50117 .47565 L .5057 .48171 L p .71 .224 .091 r
F P
0 g
s
.81913 .50418 m .80571 .51024 L .80626 .48101 L p .869 .974 .852 r
F P
0 g
s
.80626 .48101 m .81975 .4691 L .81913 .50418 L p .869 .974 .852 r
F P
0 g
s
.44005 .46148 m .45242 .46469 L .44455 .45066 L p .652 .132 0 r
F P
0 g
s
.44455 .45066 m .43105 .44644 L .44005 .46148 L p .652 .132 0 r
F P
0 g
s
.42762 .45803 m .44005 .46148 L .43105 .44644 L p .627 .094 0 r
F P
0 g
s
.43105 .44644 m .41751 .44254 L .42762 .45803 L p .627 .094 0 r
F P
0 g
s
.56726 .50343 m .55315 .49598 L .55253 .50002 L p .698 .209 .079 r
F P
0 g
s
.53876 .49031 m .55253 .50002 L .55315 .49598 L p .707 .222 .091 r
F P
0 g
s
.55253 .50002 m .53876 .49031 L .53748 .49168 L p .707 .221 .089 r
F P
0 g
s
.41513 .45432 m .42762 .45803 L .41751 .44254 L p .594 .047 0 r
F P
0 g
s
.41751 .44254 m .40394 .43898 L .41513 .45432 L p .594 .047 0 r
F P
0 g
s
.80571 .51024 m .7922 .51605 L .79268 .49252 L p .848 .988 .855 r
F P
0 g
s
.79268 .49252 m .80626 .48101 L .80571 .51024 L p .848 .988 .855 r
F P
0 g
s
.51161 .48774 m .51841 .48418 L .51546 .48115 L p .71 .223 .089 r
F P
0 g
s
.51546 .48115 m .5057 .48171 L .51161 .48774 L p .71 .223 .089 r
F P
0 g
s
.40258 .45033 m .41513 .45432 L .40394 .43898 L p .55 0 0 r
F P
0 g
s
.40394 .43898 m .39033 .43578 L .40258 .45033 L p .55 0 0 r
F P
0 g
s
.49583 .48203 m .5057 .48171 L .50117 .47565 L p .706 .216 .078 r
F P
0 g
s
.50117 .47565 m .48909 .47313 L .49583 .48203 L p .706 .216 .078 r
F P
0 g
s
.58141 .51048 m .56726 .50343 L .56643 .50937 L p .684 .188 .062 r
F P
0 g
s
.55253 .50002 m .56643 .50937 L .56726 .50343 L p .698 .209 .079 r
F P
0 g
s
.53748 .49168 m .55001 .50275 L .55253 .50002 L p .707 .221 .089 r
F P
0 g
s
.55001 .50275 m .53748 .49168 L .53534 .49228 L p .706 .22 .087 r
F P
0 g
s
.38997 .44607 m .40258 .45033 L .39033 .43578 L p .492 0 0 r
F P
0 g
s
.39033 .43578 m .37667 .43296 L .38997 .44607 L p .492 0 0 r
F P
0 g
s
.7922 .51605 m .77861 .52148 L .779 .50343 L p .812 .996 .857 r
F P
0 g
s
.779 .50343 m .79268 .49252 L .7922 .51605 L p .812 .996 .857 r
F P
0 g
s
.5185 .49331 m .52184 .48697 L .51841 .48418 L p .709 .222 .087 r
F P
0 g
s
.51841 .48418 m .51161 .48774 L .5185 .49331 L p .709 .222 .087 r
F P
0 g
s
.37731 .44151 m .38997 .44607 L .37667 .43296 L p .415 0 0 r
F P
0 g
s
.37667 .43296 m .36295 .4305 L .37731 .44151 L p .415 0 0 r
F P
0 g
s
.59561 .517 m .58141 .51048 L .58044 .51814 L p .664 .16 .038 r
F P
0 g
s
.56643 .50937 m .58044 .51814 L .58141 .51048 L p .684 .188 .062 r
F P
0 g
s
.53534 .49228 m .54574 .50395 L .55001 .50275 L p .706 .22 .087 r
F P
0 g
s
.54574 .50395 m .53534 .49228 L .53249 .49206 L p .707 .219 .086 r
F P
0 g
s
.77861 .52148 m .76493 .52638 L .76522 .51351 L p .758 .995 .854 r
F P
0 g
s
.76522 .51351 m .779 .50343 L .77861 .52148 L p .758 .995 .854 r
F P
0 g
s
.52589 .49801 m .5255 .48931 L .52184 .48697 L p .709 .221 .086 r
F P
0 g
s
.52184 .48697 m .5185 .49331 L .52589 .49801 L p .709 .221 .086 r
F P
0 g
s
.48586 .48196 m .49583 .48203 L .48909 .47313 L p .7 .203 .06 r
F P
0 g
s
.48909 .47313 m .47694 .47049 L .48586 .48196 L p .7 .203 .06 r
F P
0 g
s
.56643 .50937 m .55253 .50002 L .55001 .50275 L p .696 .204 .073 r
F P
0 g
s
.36459 .43668 m .37731 .44151 L .36295 .4305 L p .315 0 0 r
F P
0 g
s
.36295 .4305 m .34918 .42842 L .36459 .43668 L p .315 0 0 r
F P
0 g
s
.53249 .49206 m .54002 .50353 L .54574 .50395 L p .707 .219 .086 r
F P
0 g
s
.54002 .50353 m .53249 .49206 L .52913 .49105 L p .707 .219 .085 r
F P
0 g
s
.53324 .5015 m .52913 .49105 L .5255 .48931 L p .708 .22 .085 r
F P
0 g
s
.5255 .48931 m .52589 .49801 L .53324 .5015 L p .708 .22 .085 r
F P
0 g
s
.60985 .52286 m .59561 .517 L .59455 .5261 L p .636 .122 .007 r
F P
0 g
s
.58044 .51814 m .59455 .5261 L .59561 .517 L p .664 .16 .038 r
F P
0 g
s
.52913 .49105 m .53324 .5015 L .54002 .50353 L p .707 .219 .085 r
F P
0 g
s
.76493 .52638 m .75116 .53065 L .75132 .52258 L p .676 .977 .84 r
F P
0 g
s
.75132 .52258 m .76522 .51351 L .76493 .52638 L p .676 .977 .84 r
F P
0 g
s
.50471 .49093 m .51161 .48774 L .5057 .48171 L p .706 .214 .073 r
F P
0 g
s
.5057 .48171 m .49583 .48203 L .50471 .49093 L p .706 .214 .073 r
F P
0 g
s
.35182 .43157 m .36459 .43668 L .34918 .42842 L p .189 0 0 r
F P
0 g
s
.34918 .42842 m .33534 .4267 L .35182 .43157 L p .189 0 0 r
F P
0 g
s
.62411 .52796 m .60985 .52286 L .60876 .53306 L p .598 .073 0 r
F P
0 g
s
.59455 .5261 m .60876 .53306 L .60985 .52286 L p .636 .122 .007 r
F P
0 g
s
.75116 .53065 m .7373 .53416 L .73732 .53046 L p .562 .932 .808 r
F P
0 g
s
.73732 .53046 m .75132 .52258 L .75116 .53065 L p .562 .932 .808 r
F P
0 g
s
.47579 .48141 m .48586 .48196 L .47694 .47049 L p .692 .186 .035 r
F P
0 g
s
.47694 .47049 m .46471 .46768 L .47579 .48141 L p .692 .186 .035 r
F P
0 g
s
.33901 .4262 m .35182 .43157 L .33534 .4267 L p 0 .542 .732 r
F P
0 g
s
.63837 .53219 m .62411 .52796 L .62304 .53884 L p .547 .01 0 r
F P
0 g
s
.60876 .53306 m .62304 .53884 L .62411 .52796 L p .598 .073 0 r
F P
0 g
s
.7373 .53416 m .72336 .53683 L .72323 .53699 L p .411 .852 .749 r
F P
0 g
s
.72323 .53699 m .73732 .53046 L .7373 .53416 L p .411 .852 .749 r
F P
0 g
s
.55001 .50275 m .56271 .51339 L .56643 .50937 L p .696 .204 .073 r
F P
0 g
s
.56271 .51339 m .55001 .50275 L .54574 .50395 L p .694 .2 .066 r
F P
0 g
s
.58044 .51814 m .56643 .50937 L .56271 .51339 L p .678 .178 .049 r
F P
0 g
s
.65263 .53549 m .63837 .53219 L .63737 .54327 L p .48 0 0 r
F P
0 g
s
.62304 .53884 m .63737 .54327 L .63837 .53219 L p .547 .01 0 r
F P
0 g
s
.72336 .53683 m .70933 .53857 L .70904 .54204 L p 0 0 0 r
F P
0 g
s
.70904 .54204 m .72323 .53699 L .72336 .53683 L p 0 0 0 r
F P
0 g
s
.32615 .42059 m .33901 .4262 L .32144 .42531 L p .121 .66 .847 r
F P
0 g
s
.32144 .42531 m .30747 .42424 L .32615 .42059 L p .121 .66 .847 r
F P
0 g
s
.66687 .5378 m .65263 .53549 L .65173 .54623 L p .39 0 0 r
F P
0 g
s
.63737 .54327 m .65173 .54623 L .65263 .53549 L p .48 0 0 r
F P
0 g
s
.51511 .4992 m .5185 .49331 L .51161 .48774 L p .705 .21 .066 r
F P
0 g
s
.51161 .48774 m .50471 .49093 L .51511 .4992 L p .705 .21 .066 r
F P
0 g
s
.70933 .53857 m .69523 .53934 L .69478 .54553 L p 0 0 0 r
F P
0 g
s
.69478 .54553 m .70904 .54204 L .70933 .53857 L p 0 0 0 r
F P
0 g
s
.46563 .48024 m .47579 .48141 L .46471 .46768 L p .68 .164 .001 r
F P
0 g
s
.46471 .46768 m .45242 .46469 L .46563 .48024 L p .68 .164 .001 r
F P
0 g
s
.68107 .53908 m .66687 .5378 L .6661 .54763 L p .274 0 0 r
F P
0 g
s
.65173 .54623 m .6661 .54763 L .66687 .5378 L p .39 0 0 r
F P
0 g
s
.69523 .53934 m .68107 .53908 L .68046 .5474 L p .127 0 0 r
F P
0 g
s
.68046 .5474 m .69478 .54553 L .69523 .53934 L p .127 0 0 r
F P
0 g
s
.6661 .54763 m .68046 .5474 L .68107 .53908 L p .274 0 0 r
F P
0 g
s
.31324 .41476 m .32615 .42059 L .30747 .42424 L p .274 .753 .931 r
F P
0 g
s
.30747 .42424 m .29343 .42345 L .31324 .41476 L p .274 .753 .931 r
F P
0 g
s
.49771 .49354 m .50471 .49093 L .49583 .48203 L p .7 .199 .047 r
F P
0 g
s
.49583 .48203 m .48586 .48196 L .49771 .49354 L p .7 .199 .047 r
F P
0 g
s
.54574 .50395 m .55632 .51515 L .56271 .51339 L p .694 .2 .066 r
F P
0 g
s
.55632 .51515 m .54574 .50395 L .54002 .50353 L p .695 .198 .06 r
F P
0 g
s
.30029 .40873 m .31324 .41476 L .29343 .42345 L p .404 .812 .979 r
F P
0 g
s
.29343 .42345 m .27931 .42291 L .30029 .40873 L p .404 .812 .979 r
F P
0 g
s
.52629 .50622 m .52589 .49801 L .5185 .49331 L p .702 .205 .06 r
F P
0 g
s
.5185 .49331 m .51511 .4992 L .52629 .50622 L p .702 .205 .06 r
F P
0 g
s
.45537 .47836 m .46563 .48024 L .45242 .46469 L p .664 .135 0 r
F P
0 g
s
.45242 .46469 m .44005 .46148 L .45537 .47836 L p .664 .135 0 r
F P
0 g
s
.59455 .5261 m .58044 .51814 L .57557 .52331 L p .652 .14 .014 r
F P
0 g
s
.56271 .51339 m .57557 .52331 L .58044 .51814 L p .678 .178 .049 r
F P
0 g
s
.54002 .50353 m .54768 .5145 L .55632 .51515 L p .695 .198 .06 r
F P
0 g
s
.54768 .5145 m .54002 .50353 L .53324 .5015 L p .696 .198 .056 r
F P
0 g
s
.53742 .51145 m .53324 .5015 L .52589 .49801 L p .699 .201 .056 r
F P
0 g
s
.52589 .49801 m .52629 .50622 L .53742 .51145 L p .699 .201 .056 r
F P
0 g
s
.28729 .40253 m .30029 .40873 L .27931 .42291 L p .505 .843 .997 r
F P
0 g
s
.27931 .42291 m .26513 .42256 L .28729 .40253 L p .505 .843 .997 r
F P
0 g
s
.53324 .5015 m .53742 .51145 L .54768 .5145 L p .696 .198 .056 r
F P
0 g
s
.57557 .52331 m .56271 .51339 L .55632 .51515 L p .674 .168 .033 r
F P
0 g
s
.44504 .47569 m .45537 .47836 L .44005 .46148 L p .641 .097 0 r
F P
0 g
s
.44005 .46148 m .42762 .45803 L .44504 .47569 L p .641 .097 0 r
F P
0 g
s
.49061 .49537 m .49771 .49354 L .48586 .48196 L p .691 .178 .011 r
F P
0 g
s
.48586 .48196 m .47579 .48141 L .49061 .49537 L p .691 .178 .011 r
F P
0 g
s
.27424 .39621 m .28729 .40253 L .26513 .42256 L p .578 .854 .996 r
F P
0 g
s
.26513 .42256 m .25087 .42237 L .27424 .39621 L p .578 .854 .996 r
F P
0 g
s
.60876 .53306 m .59455 .5261 L .58857 .53221 L p .613 .087 0 r
F P
0 g
s
.57557 .52331 m .58857 .53221 L .59455 .5261 L p .652 .14 .014 r
F P
0 g
s
.51165 .50436 m .51511 .4992 L .50471 .49093 L p .697 .191 .032 r
F P
0 g
s
.50471 .49093 m .49771 .49354 L .51165 .50436 L p .697 .191 .032 r
F P
0 g
s
.43463 .47215 m .44504 .47569 L .42762 .45803 L p .609 .048 0 r
F P
0 g
s
.42762 .45803 m .41513 .45432 L .43463 .47215 L p .609 .048 0 r
F P
0 g
s
.26115 .38978 m .27424 .39621 L .25087 .42237 L p .63 .851 .984 r
F P
0 g
s
.25087 .42237 m .23654 .42228 L .26115 .38978 L p .63 .851 .984 r
F P
0 g
s
.55632 .51515 m .56707 .52553 L .57557 .52331 L p .674 .168 .033 r
F P
0 g
s
.56707 .52553 m .55632 .51515 L .54768 .5145 L p .674 .163 .018 r
F P
0 g
s
.62304 .53884 m .60876 .53306 L .60171 .53982 L p .558 .015 0 r
F P
0 g
s
.58857 .53221 m .60171 .53982 L .60876 .53306 L p .613 .087 0 r
F P
0 g
s
.248 .38329 m .26115 .38978 L .23654 .42228 L p .666 .843 .968 r
F P
0 g
s
.23654 .42228 m .22215 .42225 L .248 .38329 L p .666 .843 .968 r
F P
0 g
s
.85986 .43317 m .84653 .44497 L .82412 .39785 L p .902 .853 .785 r
F P
0 g
s
.82412 .39785 m .8366 .38074 L .85986 .43317 L p .902 .853 .785 r
F P
0 g
s
.42415 .46768 m .43463 .47215 L .41513 .45432 L p .563 0 0 r
F P
0 g
s
.41513 .45432 m .40258 .45033 L .42415 .46768 L p .563 0 0 r
F P
0 g
s
.48342 .49621 m .49061 .49537 L .47579 .48141 L p .677 .15 0 r
F P
0 g
s
.47579 .48141 m .46563 .48024 L .48342 .49621 L p .677 .15 0 r
F P
0 g
s
.58857 .53221 m .57557 .52331 L .56707 .52553 L p .643 .121 0 r
F P
0 g
s
.52669 .51359 m .52629 .50622 L .51511 .4992 L p .69 .18 .017 r
F P
0 g
s
.51511 .4992 m .51165 .50436 L .52669 .51359 L p .69 .18 .017 r
F P
0 g
s
.2348 .37678 m .248 .38329 L .22215 .42225 L p .69 .831 .95 r
F P
0 g
s
.22215 .42225 m .20769 .42222 L .2348 .37678 L p .69 .831 .95 r
F P
0 g
s
.84653 .44497 m .83317 .45701 L .81161 .41528 L p .909 .866 .784 r
F P
0 g
s
.81161 .41528 m .82412 .39785 L .84653 .44497 L p .909 .866 .784 r
F P
0 g
s
.54768 .5145 m .55549 .52459 L .56707 .52553 L p .674 .163 .018 r
F P
0 g
s
.55549 .52459 m .54768 .5145 L .53742 .51145 L p .677 .163 .009 r
F P
0 g
s
.41362 .46227 m .42415 .46768 L .40258 .45033 L p .499 0 0 r
F P
0 g
s
.40258 .45033 m .38997 .44607 L .41362 .46227 L p .499 0 0 r
F P
0 g
s
.63737 .54327 m .62304 .53884 L .61496 .54591 L p .478 0 0 r
F P
0 g
s
.60171 .53982 m .61496 .54591 L .62304 .53884 L p .558 .015 0 r
F P
0 g
s
.50814 .50851 m .51165 .50436 L .49771 .49354 L p .683 .162 0 r
F P
0 g
s
.49771 .49354 m .49061 .49537 L .50814 .50851 L p .683 .162 0 r
F P
0 g
s
.54169 .52052 m .53742 .51145 L .52629 .50622 L p .683 .17 .009 r
F P
0 g
s
.52629 .50622 m .52669 .51359 L .54169 .52052 L p .683 .17 .009 r
F P
0 g
s
.53742 .51145 m .54169 .52052 L .55549 .52459 L p .677 .163 .009 r
F P
0 g
s
.83317 .45701 m .81975 .4691 L .79906 .43277 L p .914 .879 .786 r
F P
0 g
s
.79906 .43277 m .81161 .41528 L .83317 .45701 L p .914 .879 .786 r
F P
0 g
s
.22154 .37026 m .2348 .37678 L .20769 .42222 L p .707 .817 .934 r
F P
0 g
s
.20769 .42222 m .19318 .42214 L .22154 .37026 L p .707 .817 .934 r
F P
0 g
s
.40304 .45588 m .41362 .46227 L .38997 .44607 L p .411 0 0 r
F P
0 g
s
.38997 .44607 m .37731 .44151 L .40304 .45588 L p .411 0 0 r
F P
0 g
s
.47615 .4959 m .48342 .49621 L .46563 .48024 L p .655 .111 0 r
F P
0 g
s
.46563 .48024 m .45537 .47836 L .47615 .4959 L p .655 .111 0 r
F P
0 g
s
.81975 .4691 m .80626 .48101 L .78645 .45002 L p .917 .893 .791 r
F P
0 g
s
.78645 .45002 m .79906 .43277 L .81975 .4691 L p .917 .893 .791 r
F P
0 g
s
.65173 .54623 m .63737 .54327 L .6283 .55025 L p .362 0 0 r
F P
0 g
s
.61496 .54591 m .6283 .55025 L .63737 .54327 L p .478 0 0 r
F P
0 g
s
.60171 .53982 m .58857 .53221 L .57797 .53475 L p .593 .051 0 r
F P
0 g
s
.56707 .52553 m .57797 .53475 L .58857 .53221 L p .643 .121 0 r
F P
0 g
s
.57797 .53475 m .56707 .52553 L .55549 .52459 L p .639 .109 0 r
F P
0 g
s
.80626 .48101 m .79268 .49252 L .77375 .46675 L p .915 .909 .8 r
F P
0 g
s
.77375 .46675 m .78645 .45002 L .80626 .48101 L p .915 .909 .8 r
F P
0 g
s
.39242 .44854 m .40304 .45588 L .37731 .44151 L p .294 0 0 r
F P
0 g
s
.37731 .44151 m .36459 .43668 L .39242 .44854 L p .294 0 0 r
F P
0 g
s
.6661 .54763 m .65173 .54623 L .64169 .55266 L p .198 0 0 r
F P
0 g
s
.6283 .55025 m .64169 .55266 L .65173 .54623 L p .362 0 0 r
F P
0 g
s
.52711 .51981 m .52669 .51359 L .51165 .50436 L p .67 .14 0 r
F P
0 g
s
.51165 .50436 m .50814 .50851 L .52711 .51981 L p .67 .14 0 r
F P
0 g
s
.79268 .49252 m .779 .50343 L .76095 .48267 L p .91 .927 .813 r
F P
0 g
s
.76095 .48267 m .77375 .46675 L .79268 .49252 L p .91 .927 .813 r
F P
0 g
s
.46881 .49428 m .47615 .4959 L .45537 .47836 L p .621 .059 0 r
F P
0 g
s
.45537 .47836 m .44504 .47569 L .46881 .49428 L p .621 .059 0 r
F P
0 g
s
.50458 .51138 m .50814 .50851 L .49061 .49537 L p .661 .12 0 r
F P
0 g
s
.49061 .49537 m .48342 .49621 L .50458 .51138 L p .661 .12 0 r
F P
0 g
s
.38177 .44026 m .39242 .44854 L .36459 .43668 L p 0 .41 .751 r
F P
0 g
s
.36459 .43668 m .35182 .43157 L .38177 .44026 L p 0 .41 .751 r
F P
0 g
s
.68046 .5474 m .6661 .54763 L .65513 .55303 L p 0 0 0 r
F P
0 g
s
.64169 .55266 m .65513 .55303 L .6661 .54763 L p .198 0 0 r
F P
0 g
s
.779 .50343 m .76522 .51351 L .74804 .49751 L p .898 .947 .83 r
F P
0 g
s
.74804 .49751 m .76095 .48267 L .779 .50343 L p .898 .947 .83 r
F P
0 g
s
.55549 .52459 m .56343 .53345 L .57797 .53475 L p .639 .109 0 r
F P
0 g
s
.56343 .53345 m .55549 .52459 L .54169 .52052 L p .644 .108 0 r
F P
0 g
s
.61496 .54591 m .60171 .53982 L .58902 .54249 L p .516 0 0 r
F P
0 g
s
.57797 .53475 m .58902 .54249 L .60171 .53982 L p .593 .051 0 r
F P
0 g
s
.69478 .54553 m .68046 .5474 L .66857 .55125 L p .262 .767 .751 r
F P
0 g
s
.65513 .55303 m .66857 .55125 L .68046 .5474 L p 0 0 0 r
F P
0 g
s
.76522 .51351 m .75132 .52258 L .73502 .51101 L p .875 .967 .85 r
F P
0 g
s
.73502 .51101 m .74804 .49751 L .76522 .51351 L p .875 .967 .85 r
F P
0 g
s
.37109 .4311 m .38177 .44026 L .35182 .43157 L p .001 .512 .859 r
F P
0 g
s
.35182 .43157 m .33901 .4262 L .37109 .4311 L p .001 .512 .859 r
F P
0 g
s
.54603 .52835 m .54169 .52052 L .52669 .51359 L p .655 .12 0 r
F P
0 g
s
.52669 .51359 m .52711 .51981 L .54603 .52835 L p .655 .12 0 r
F P
0 g
s
.75132 .52258 m .73732 .53046 L .72189 .52292 L p .836 .984 .871 r
F P
0 g
s
.72189 .52292 m .73502 .51101 L .75132 .52258 L p .836 .984 .871 r
F P
0 g
s
.70904 .54204 m .69478 .54553 L .68199 .54731 L p .489 .902 .847 r
F P
0 g
s
.66857 .55125 m .68199 .54731 L .69478 .54553 L p .262 .767 .751 r
F P
0 g
s
.54169 .52052 m .54603 .52835 L .56343 .53345 L p .644 .108 0 r
F P
0 g
s
.73732 .53046 m .72323 .53699 L .70867 .53304 L p .769 .991 .888 r
F P
0 g
s
.70867 .53304 m .72189 .52292 L .73732 .53046 L p .769 .991 .888 r
F P
0 g
s
.72323 .53699 m .70904 .54204 L .69536 .54121 L p .659 .971 .887 r
F P
0 g
s
.68199 .54731 m .69536 .54121 L .70904 .54204 L p .489 .902 .847 r
F P
0 g
s
.69536 .54121 m .70867 .53304 L .72323 .53699 L p .659 .971 .887 r
F P
0 g
s
.4614 .49123 m .46881 .49428 L .44504 .47569 L p .568 0 0 r
F P
0 g
s
.44504 .47569 m .43463 .47215 L .4614 .49123 L p .568 0 0 r
F P
0 g
s
.58902 .54249 m .57797 .53475 L .56343 .53345 L p .582 .025 0 r
F P
0 g
s
.36039 .42111 m .37109 .4311 L .33901 .4262 L p .148 .592 .93 r
F P
0 g
s
.33901 .4262 m .32615 .42059 L .36039 .42111 L p .148 .592 .93 r
F P
0 g
s
.50097 .51274 m .50458 .51138 L .48342 .49621 L p .623 .06 0 r
F P
0 g
s
.48342 .49621 m .47615 .4959 L .50097 .51274 L p .623 .06 0 r
F P
0 g
s
.34968 .41039 m .36039 .42111 L .32615 .42059 L p .274 .645 .966 r
F P
0 g
s
.32615 .42059 m .31324 .41476 L .34968 .41039 L p .274 .645 .966 r
F P
0 g
s
.6283 .55025 m .61496 .54591 L .60019 .54845 L p .392 0 0 r
F P
0 g
s
.58902 .54249 m .60019 .54845 L .61496 .54591 L p .516 0 0 r
F P
0 g
s
.52753 .52454 m .52711 .51981 L .50814 .50851 L p .634 .08 0 r
F P
0 g
s
.50814 .50851 m .50458 .51138 L .52753 .52454 L p .634 .08 0 r
F P
0 g
s
.43463 .47215 m .42415 .46768 L .45394 .48665 L p .486 0 0 r
F P
0 g
s
.45394 .48665 m .4614 .49123 L .44048 .47632 L p .486 0 0 r
F P
0 g
s
.43994 .47613 m .45394 .48665 L .44048 .47632 L .486 0 0 r
F
.44643 .48047 m .45394 .48665 L .42415 .46768 L p .367 0 0 r
F P
0 g
s
.42415 .46768 m .41362 .46227 L .43656 .47499 L p .367 0 0 r
F P
0 g
s
.43656 .47499 m .44643 .48047 L p .43736 .47526 L .367 0 0 r
F P
0 g
s
.42415 .46768 m .43656 .47499 L .43736 .47526 L .367 0 0 r
F
.44048 .47632 m .43463 .47215 L p .43994 .47613 L .486 0 0 r
F P
0 g
s
.33894 .39903 m .34968 .41039 L .31324 .41476 L p .375 .677 .976 r
F P
0 g
s
.31324 .41476 m .30029 .40873 L .33894 .39903 L p .375 .677 .976 r
F P
0 g
s
.56343 .53345 m .57149 .54073 L .58902 .54249 L p .582 .025 0 r
F P
0 g
s
.57149 .54073 m .56343 .53345 L .54603 .52835 L p .585 .022 0 r
F P
0 g
s
.32819 .38712 m .33894 .39903 L .30029 .40873 L p .452 .694 .97 r
F P
0 g
s
.30029 .40873 m .28729 .40253 L .32819 .38712 L p .452 .694 .97 r
F P
0 g
s
.55044 .5346 m .54603 .52835 L .52711 .51981 L p .605 .043 0 r
F P
0 g
s
.52711 .51981 m .52753 .52454 L .55044 .5346 L p .605 .043 0 r
F P
0 g
s
.64169 .55266 m .6283 .55025 L .61146 .55237 L p .199 0 0 r
F P
0 g
s
.60019 .54845 m .61146 .55237 L .6283 .55025 L p .392 0 0 r
F P
0 g
s
.60019 .54845 m .58902 .54249 L .57149 .54073 L p .484 0 0 r
F P
0 g
s
.54603 .52835 m .55044 .5346 L .57149 .54073 L p .585 .022 0 r
F P
0 g
s
.50097 .51274 m .47615 .4959 L p .49209 .50829 L .557 0 0 r
F P
0 g
s
.47615 .4959 m .46881 .49428 L .49732 .51236 L p .557 0 0 r
F P
0 g
s
.49363 .51008 m .49732 .51236 L .48334 .50349 L p .447 0 0 r
F P
0 g
s
.48334 .50349 m .46881 .49428 L p .48031 .5016 L .447 0 0 r
F P
0 g
s
.48031 .5016 m .49363 .51008 L .48334 .50349 L .447 0 0 r
F
.46881 .49428 m .4614 .49123 L .49363 .51008 L p F P
0 g
s
.45394 .48665 m .4703 .49533 L p .4661 .49362 L 0 .272 .677 r
F P
0 g
s
.4703 .49533 m .48991 .50575 L p .47395 .49762 L 0 .272 .677 r
F P
0 g
s
.4661 .49362 m .4703 .49533 L .47395 .49762 L 0 .272 .677 r
F
.4614 .49123 m .45614 .488 L p .4661 .49362 L F P
0 g
s
.45614 .488 m .45394 .48665 L p .4661 .49362 L 0 .272 .677 r
F P
0 g
s
.49732 .51236 m .49974 .51261 L p .49209 .50829 L .557 0 0 r
F P
0 g
s
.49974 .51261 m .50097 .51274 L p .49209 .50829 L .557 0 0 r
F P
0 g
s
.31741 .3748 m .32819 .38712 L .28729 .40253 L p .51 .702 .957 r
F P
0 g
s
.28729 .40253 m .27424 .39621 L .31741 .3748 L p .51 .702 .957 r
F P
0 g
s
.52795 .5275 m .52753 .52454 L .50458 .51138 L p .569 0 0 r
F P
0 g
s
.50458 .51138 m .50097 .51274 L .52795 .5275 L p .569 0 0 r
F P
0 g
s
.30662 .36218 m .31741 .3748 L .27424 .39621 L p .553 .705 .941 r
F P
0 g
s
.27424 .39621 m .26115 .38978 L .30662 .36218 L p .553 .705 .941 r
F P
0 g
s
.65513 .55303 m .64169 .55266 L .62281 .55404 L p .073 .635 .745 r
F P
0 g
s
.61146 .55237 m .62281 .55404 L .64169 .55266 L p .199 0 0 r
F P
0 g
s
.43889 .47269 m .44643 .48047 L .41362 .46227 L p 0 .324 .733 r
F P
0 g
s
.41362 .46227 m .40304 .45588 L .43889 .47269 L p 0 .324 .733 r
F P
0 g
s
.29579 .34938 m .30662 .36218 L .26115 .38978 L p .587 .706 .925 r
F P
0 g
s
.26115 .38978 m .248 .38329 L .29579 .34938 L p .587 .706 .925 r
F P
0 g
s
.8366 .38074 m .82412 .39785 L .77833 .35424 L p .876 .773 .745 r
F P
0 g
s
.77833 .35424 m .78901 .33274 L .8366 .38074 L p .876 .773 .745 r
F P
0 g
s
.57149 .54073 m .57966 .5461 L .60019 .54845 L p .484 0 0 r
F P
0 g
s
.57966 .5461 m .57149 .54073 L .55044 .5346 L p .48 0 0 r
F P
0 g
s
.61146 .55237 m .60019 .54845 L .57966 .5461 L p .315 0 0 r
F P
0 g
s
.28492 .33653 m .29579 .34938 L .248 .38329 L p .613 .706 .911 r
F P
0 g
s
.248 .38329 m .2348 .37678 L .28492 .33653 L p .613 .706 .911 r
F P
0 g
s
.82412 .39785 m .81161 .41528 L .76765 .3761 L p .882 .779 .743 r
F P
0 g
s
.76765 .3761 m .77833 .35424 L .82412 .39785 L p .882 .779 .743 r
F P
0 g
s
.66857 .55125 m .65513 .55303 L .63421 .5533 L p .369 .831 .906 r
F P
0 g
s
.62281 .55404 m .63421 .5533 L .65513 .55303 L p .073 .635 .745 r
F P
0 g
s
.43133 .46329 m .43889 .47269 L .40304 .45588 L p 0 .424 .843 r
F P
0 g
s
.40304 .45588 m .39242 .44854 L .43133 .46329 L p 0 .424 .843 r
F P
0 g
s
.55492 .53894 m .55044 .5346 L .52753 .52454 L p .513 0 0 r
F P
0 g
s
.52753 .52454 m .52795 .5275 L .55492 .53894 L p .513 0 0 r
F P
0 g
s
.81161 .41528 m .79906 .43277 L .75693 .39801 L p .887 .786 .744 r
F P
0 g
s
.75693 .39801 m .76765 .3761 L .81161 .41528 L p .887 .786 .744 r
F P
0 g
s
.27399 .32374 m .28492 .33653 L .2348 .37678 L p .633 .706 .898 r
F P
0 g
s
.2348 .37678 m .22154 .37026 L .27399 .32374 L p .633 .706 .898 r
F P
0 g
s
.55044 .5346 m .55492 .53894 L .57966 .5461 L p .48 0 0 r
F P
0 g
s
.68199 .54731 m .66857 .55125 L .64564 .55004 L p .6 .928 .963 r
F P
0 g
s
.63421 .5533 m .64564 .55004 L .66857 .55125 L p .369 .831 .906 r
F P
0 g
s
.52795 .5275 m .50097 .51274 L p .51869 .52288 L .452 0 0 r
F P
0 g
s
.50097 .51274 m .49732 .51236 L .52838 .52843 L p .452 0 0 r
F P
0 g
s
.49363 .51008 m .52882 .5271 L p .50654 .51668 L 0 .304 .686 r
F P
0 g
s
.49732 .51236 m .49373 .51014 L p .50654 .51668 L 0 .304 .686 r
F P
0 g
s
.49373 .51014 m .49363 .51008 L p .50654 .51668 L 0 .304 .686 r
F P
0 g
s
.52838 .52843 m .52802 .52764 L p .51869 .52288 L .452 0 0 r
F P
0 g
s
.52802 .52764 m .52795 .5275 L p .51869 .52288 L .452 0 0 r
F P
0 g
s
.79906 .43277 m .78645 .45002 L .74617 .41963 L p .89 .794 .748 r
F P
0 g
s
.74617 .41963 m .75693 .39801 L .79906 .43277 L p .89 .794 .748 r
F P
0 g
s
.42375 .45233 m .43133 .46329 L .39242 .44854 L p .113 .497 .904 r
F P
0 g
s
.39242 .44854 m .38177 .44026 L .42375 .45233 L p .113 .497 .904 r
F P
0 g
s
.78645 .45002 m .77375 .46675 L .73533 .44064 L p .892 .805 .756 r
F P
0 g
s
.73533 .44064 m .74617 .41963 L .78645 .45002 L p .892 .805 .756 r
F P
0 g
s
.48991 .50575 m .49363 .51008 L .4614 .49123 L p 0 .272 .677 r
F P
0 g
s
.62281 .55404 m .61146 .55237 L .58792 .54928 L p 0 .534 .746 r
F P
0 g
s
.57966 .5461 m .58792 .54928 L .61146 .55237 L p .315 0 0 r
F P
0 g
s
.69536 .54121 m .68199 .54731 L .65707 .54421 L p .738 .945 .949 r
F P
0 g
s
.64564 .55004 m .65707 .54421 L .68199 .54731 L p .6 .928 .963 r
F P
0 g
s
.77375 .46675 m .76095 .48267 L .72441 .46068 L p .892 .817 .768 r
F P
0 g
s
.72441 .46068 m .73533 .44064 L .77375 .46675 L p .892 .817 .768 r
F P
0 g
s
.41616 .43989 m .42375 .45233 L .38177 .44026 L p .242 .542 .926 r
F P
0 g
s
.38177 .44026 m .37109 .4311 L .41616 .43989 L p .242 .542 .926 r
F P
0 g
s
.58792 .54928 m .57966 .5461 L .55492 .53894 L p .29 0 0 r
F P
0 g
s
.70867 .53304 m .69536 .54121 L .66846 .53584 L p .813 .927 .91 r
F P
0 g
s
.65707 .54421 m .66846 .53584 L .69536 .54121 L p .738 .945 .949 r
F P
0 g
s
.76095 .48267 m .74804 .49751 L .7134 .47943 L p .89 .833 .784 r
F P
0 g
s
.7134 .47943 m .72441 .46068 L .76095 .48267 L p .89 .833 .784 r
F P
0 g
s
.72189 .52292 m .70867 .53304 L .67981 .52501 L p .852 .901 .869 r
F P
0 g
s
.66846 .53584 m .67981 .52501 L .70867 .53304 L p .813 .927 .91 r
F P
0 g
s
.74804 .49751 m .73502 .51101 L .70229 .49659 L p .884 .852 .806 r
F P
0 g
s
.70229 .49659 m .7134 .47943 L .74804 .49751 L p .884 .852 .806 r
F P
0 g
s
.73502 .51101 m .72189 .52292 L .69109 .51186 L p .873 .875 .834 r
F P
0 g
s
.67981 .52501 m .69109 .51186 L .72189 .52292 L p .852 .901 .869 r
F P
0 g
s
.69109 .51186 m .70229 .49659 L .73502 .51101 L p .873 .875 .834 r
F P
0 g
s
.55492 .53894 m .52795 .5275 L p .55312 .53836 L .344 0 0 r
F P
0 g
s
.52795 .5275 m .52838 .52843 L .55945 .54109 L p .344 0 0 r
F P
0 g
s
.52882 .5271 m .56403 .54082 L p .53455 .53057 L 0 .453 .809 r
F P
0 g
s
.52838 .52843 m .52851 .52804 L p .53455 .53057 L 0 .453 .809 r
F P
0 g
s
.52851 .52804 m .52882 .5271 L p .53455 .53057 L 0 .453 .809 r
F P
0 g
s
.55945 .54109 m .55809 .54044 L p .55312 .53836 L .344 0 0 r
F P
0 g
s
.55809 .54044 m .55492 .53894 L p .55312 .53836 L .344 0 0 r
F P
0 g
s
.40858 .42609 m .41616 .43989 L .37109 .4311 L p .34 .568 .923 r
F P
0 g
s
.37109 .4311 m .36039 .42111 L .40858 .42609 L p .34 .568 .923 r
F P
0 g
s
.55492 .53894 m .55945 .54109 L .58792 .54928 L p .29 0 0 r
F P
0 g
s
.48617 .49928 m .48991 .50575 L .45394 .48665 L p 0 .398 .824 r
F P
0 g
s
.45394 .48665 m .44643 .48047 L .48617 .49928 L p 0 .398 .824 r
F P
0 g
s
.52882 .5271 m .52838 .52843 L .49732 .51236 L p 0 .304 .686 r
F P
0 g
s
.63421 .5533 m .62281 .55404 L .59625 .55004 L p .277 .748 .941 r
F P
0 g
s
.58792 .54928 m .59625 .55004 L .62281 .55404 L p 0 .534 .746 r
F P
0 g
s
.40099 .41106 m .40858 .42609 L .36039 .42111 L p .413 .582 .909 r
F P
0 g
s
.36039 .42111 m .34968 .41039 L .40099 .41106 L p .413 .582 .909 r
F P
0 g
s
.59625 .55004 m .58792 .54928 L .55945 .54109 L p .002 .544 .837 r
F P
0 g
s
.39341 .39496 m .40099 .41106 L .34968 .41039 L p .467 .59 .893 r
F P
0 g
s
.34968 .41039 m .33894 .39903 L .39341 .39496 L p .467 .59 .893 r
F P
0 g
s
.48242 .49065 m .48617 .49928 L .44643 .48047 L p .117 .487 .901 r
F P
0 g
s
.44643 .48047 m .43889 .47269 L .48242 .49065 L p .117 .487 .901 r
F P
0 g
s
.64564 .55004 m .63421 .5533 L .60463 .54818 L p .532 .848 .998 r
F P
0 g
s
.59625 .55004 m .60463 .54818 L .63421 .5533 L p .277 .748 .941 r
F P
0 g
s
.38583 .37799 m .39341 .39496 L .33894 .39903 L p .508 .595 .876 r
F P
0 g
s
.33894 .39903 m .32819 .38712 L .38583 .37799 L p .508 .595 .876 r
F P
0 g
s
.56403 .54082 m .55945 .54109 L .52838 .52843 L p 0 .453 .809 r
F P
0 g
s
.52926 .52336 m .52882 .5271 L .49363 .51008 L p 0 .459 .861 r
F P
0 g
s
.49363 .51008 m .48991 .50575 L .52926 .52336 L p 0 .459 .861 r
F P
0 g
s
.55945 .54109 m .56403 .54082 L .59625 .55004 L p .002 .544 .837 r
F P
0 g
s
.37826 .36033 m .38583 .37799 L .32819 .38712 L p .54 .599 .861 r
F P
0 g
s
.32819 .38712 m .31741 .3748 L .37826 .36033 L p .54 .599 .861 r
F P
0 g
s
.47866 .47986 m .48242 .49065 L .43889 .47269 L p .269 .534 .917 r
F P
0 g
s
.43889 .47269 m .43133 .46329 L .47866 .47986 L p .269 .534 .917 r
F P
0 g
s
.65707 .54421 m .64564 .55004 L .61305 .5436 L p .678 .858 .968 r
F P
0 g
s
.60463 .54818 m .61305 .5436 L .64564 .55004 L p .532 .848 .998 r
F P
0 g
s
.37068 .3422 m .37826 .36033 L .31741 .3748 L p .566 .603 .849 r
F P
0 g
s
.31741 .3748 m .30662 .36218 L .37068 .3422 L p .566 .603 .849 r
F P
0 g
s
.60463 .54818 m .59625 .55004 L .56403 .54082 L p .308 .707 .978 r
F P
0 g
s
.36308 .32379 m .37068 .3422 L .30662 .36218 L p .587 .607 .84 r
F P
0 g
s
.30662 .36218 m .29579 .34938 L .36308 .32379 L p .587 .607 .84 r
F P
0 g
s
.5297 .5171 m .52926 .52336 L .48991 .50575 L p .216 .554 .933 r
F P
0 g
s
.48991 .50575 m .48617 .49928 L .5297 .5171 L p .216 .554 .933 r
F P
0 g
s
.78901 .33274 m .77833 .35424 L .71131 .31814 L p .833 .704 .722 r
F P
0 g
s
.71131 .31814 m .71927 .29362 L .78901 .33274 L p .833 .704 .722 r
F P
0 g
s
.66846 .53584 m .65707 .54421 L .62147 .53625 L p .753 .836 .915 r
F P
0 g
s
.61305 .5436 m .62147 .53625 L .65707 .54421 L p .678 .858 .968 r
F P
0 g
s
.47489 .46696 m .47866 .47986 L .43133 .46329 L p .376 .555 .902 r
F P
0 g
s
.43133 .46329 m .42375 .45233 L .47489 .46696 L p .376 .555 .902 r
F P
0 g
s
.56864 .53793 m .56403 .54082 L .52882 .5271 L p .202 .603 .947 r
F P
0 g
s
.52882 .5271 m .52926 .52336 L .56864 .53793 L p .202 .603 .947 r
F P
0 g
s
.35547 .30533 m .36308 .32379 L .29579 .34938 L p .605 .613 .833 r
F P
0 g
s
.29579 .34938 m .28492 .33653 L .35547 .30533 L p .605 .613 .833 r
F P
0 g
s
.77833 .35424 m .76765 .3761 L .70336 .34303 L p .836 .705 .72 r
F P
0 g
s
.70336 .34303 m .71131 .31814 L .77833 .35424 L p .836 .705 .72 r
F P
0 g
s
.56403 .54082 m .56864 .53793 L .60463 .54818 L p .308 .707 .978 r
F P
0 g
s
.76765 .3761 m .75693 .39801 L .6954 .36795 L p .838 .708 .72 r
F P
0 g
s
.6954 .36795 m .70336 .34303 L .76765 .3761 L p .838 .708 .72 r
F P
0 g
s
.67981 .52501 m .66846 .53584 L .62988 .52613 L p .792 .809 .865 r
F P
0 g
s
.62147 .53625 m .62988 .52613 L .66846 .53584 L p .753 .836 .915 r
F P
0 g
s
.34782 .287 m .35547 .30533 L .28492 .33653 L p .62 .619 .828 r
F P
0 g
s
.28492 .33653 m .27399 .32374 L .34782 .287 L p .62 .619 .828 r
F P
0 g
s
.61305 .5436 m .60463 .54818 L .56864 .53793 L p .518 .76 .985 r
F P
0 g
s
.47113 .45208 m .47489 .46696 L .42375 .45233 L p .449 .562 .878 r
F P
0 g
s
.42375 .45233 m .41616 .43989 L .47113 .45208 L p .449 .562 .878 r
F P
0 g
s
.75693 .39801 m .74617 .41963 L .68741 .39254 L p .839 .712 .723 r
F P
0 g
s
.68741 .39254 m .6954 .36795 L .75693 .39801 L p .839 .712 .723 r
F P
0 g
s
.69109 .51186 m .67981 .52501 L .63826 .51333 L p .814 .784 .825 r
F P
0 g
s
.62988 .52613 m .63826 .51333 L .67981 .52501 L p .792 .809 .865 r
F P
0 g
s
.74617 .41963 m .73533 .44064 L .67937 .41644 L p .839 .717 .729 r
F P
0 g
s
.67937 .41644 m .68741 .39254 L .74617 .41963 L p .839 .717 .729 r
F P
0 g
s
.53014 .50825 m .5297 .5171 L .48617 .49928 L p .376 .592 .929 r
F P
0 g
s
.48617 .49928 m .48242 .49065 L .53014 .50825 L p .376 .592 .929 r
F P
0 g
s
.73533 .44064 m .72441 .46068 L .67127 .43928 L p .839 .725 .739 r
F P
0 g
s
.67127 .43928 m .67937 .41644 L .73533 .44064 L p .839 .725 .739 r
F P
0 g
s
.70229 .49659 m .69109 .51186 L .6466 .49802 L p .826 .764 .794 r
F P
0 g
s
.63826 .51333 m .6466 .49802 L .69109 .51186 L p .814 .784 .825 r
F P
0 g
s
.72441 .46068 m .7134 .47943 L .66311 .46071 L p .837 .735 .752 r
F P
0 g
s
.66311 .46071 m .67127 .43928 L .72441 .46068 L p .837 .735 .752 r
F P
0 g
s
.46737 .43537 m .47113 .45208 L .41616 .43989 L p .499 .564 .853 r
F P
0 g
s
.41616 .43989 m .40858 .42609 L .46737 .43537 L p .499 .564 .853 r
F P
0 g
s
.7134 .47943 m .70229 .49659 L .65489 .48039 L p .833 .748 .77 r
F P
0 g
s
.6466 .49802 m .65489 .48039 L .70229 .49659 L p .826 .764 .794 r
F P
0 g
s
.65489 .48039 m .66311 .46071 L .7134 .47943 L p .833 .748 .77 r
F P
0 g
s
.57327 .53232 m .56864 .53793 L .52926 .52336 L p .411 .664 .964 r
F P
0 g
s
.52926 .52336 m .5297 .5171 L .57327 .53232 L p .411 .664 .964 r
F P
0 g
s
.56864 .53793 m .57327 .53232 L .61305 .5436 L p .518 .76 .985 r
F P
0 g
s
.62147 .53625 m .61305 .5436 L .57327 .53232 L p .633 .756 .937 r
F P
0 g
s
.46362 .41702 m .46737 .43537 L .40858 .42609 L p .536 .564 .83 r
F P
0 g
s
.40858 .42609 m .40099 .41106 L .46362 .41702 L p .536 .564 .83 r
F P
0 g
s
.53059 .49685 m .53014 .50825 L .48242 .49065 L p .476 .6 .897 r
F P
0 g
s
.48242 .49065 m .47866 .47986 L .53059 .49685 L p .476 .6 .897 r
F P
0 g
s
.45988 .39726 m .46362 .41702 L .40099 .41106 L p .563 .564 .812 r
F P
0 g
s
.40099 .41106 m .39341 .39496 L .45988 .39726 L p .563 .564 .812 r
F P
0 g
s
.62988 .52613 m .62147 .53625 L .57791 .52392 L p .694 .736 .883 r
F P
0 g
s
.57327 .53232 m .57791 .52392 L .62147 .53625 L p .633 .756 .937 r
F P
0 g
s
.57791 .52392 m .57327 .53232 L .5297 .5171 L p .535 .671 .925 r
F P
0 g
s
.5297 .5171 m .53014 .50825 L .57791 .52392 L p .535 .671 .925 r
F P
0 g
s
.45615 .37633 m .45988 .39726 L .39341 .39496 L p .584 .564 .797 r
F P
0 g
s
.39341 .39496 m .38583 .37799 L .45615 .37633 L p .584 .564 .797 r
F P
0 g
s
.53103 .48296 m .53059 .49685 L .47866 .47986 L p .539 .597 .86 r
F P
0 g
s
.47866 .47986 m .47489 .46696 L .53103 .48296 L p .539 .597 .86 r
F P
0 g
s
.45243 .35452 m .45615 .37633 L .38583 .37799 L p .601 .565 .786 r
F P
0 g
s
.38583 .37799 m .37826 .36033 L .45243 .35452 L p .601 .565 .786 r
F P
0 g
s
.63826 .51333 m .62988 .52613 L .58256 .51275 L p .728 .715 .838 r
F P
0 g
s
.57791 .52392 m .58256 .51275 L .62988 .52613 L p .694 .736 .883 r
F P
0 g
s
.44872 .33209 m .45243 .35452 L .37826 .36033 L p .615 .568 .778 r
F P
0 g
s
.37826 .36033 m .37068 .3422 L .44872 .33209 L p .615 .568 .778 r
F P
0 g
s
.58256 .51275 m .57791 .52392 L .53014 .50825 L p .605 .661 .878 r
F P
0 g
s
.53014 .50825 m .53059 .49685 L .58256 .51275 L p .605 .661 .878 r
F P
0 g
s
.53147 .46672 m .53103 .48296 L .47489 .46696 L p .58 .591 .828 r
F P
0 g
s
.47489 .46696 m .47113 .45208 L .53147 .46672 L p .58 .591 .828 r
F P
0 g
s
.445 .30934 m .44872 .33209 L .37068 .3422 L p .627 .572 .773 r
F P
0 g
s
.37068 .3422 m .36308 .32379 L .445 .30934 L p .627 .572 .773 r
F P
0 g
s
.6466 .49802 m .63826 .51333 L .58719 .4989 L p .748 .697 .803 r
F P
0 g
s
.58256 .51275 m .58719 .4989 L .63826 .51333 L p .728 .715 .838 r
F P
0 g
s
.71927 .29362 m .71131 .31814 L .62781 .29326 L p .784 .649 .713 r
F P
0 g
s
.62781 .29326 m .63227 .26744 L .71927 .29362 L p .784 .649 .713 r
F P
0 g
s
.44128 .28653 m .445 .30934 L .36308 .32379 L p .637 .577 .771 r
F P
0 g
s
.36308 .32379 m .35547 .30533 L .44128 .28653 L p .637 .577 .771 r
F P
0 g
s
.71131 .31814 m .70336 .34303 L .62337 .31941 L p .785 .648 .711 r
F P
0 g
s
.62337 .31941 m .62781 .29326 L .71131 .31814 L p .785 .648 .711 r
F P
0 g
s
.65489 .48039 m .6466 .49802 L .5918 .48251 L p .761 .683 .775 r
F P
0 g
s
.58719 .4989 m .5918 .48251 L .6466 .49802 L p .748 .697 .803 r
F P
0 g
s
.70336 .34303 m .6954 .36795 L .61893 .34556 L p .784 .648 .711 r
F P
0 g
s
.61893 .34556 m .62337 .31941 L .70336 .34303 L p .784 .648 .711 r
F P
0 g
s
.53192 .44831 m .53147 .46672 L .47113 .45208 L p .608 .585 .802 r
F P
0 g
s
.47113 .45208 m .46737 .43537 L .53192 .44831 L p .608 .585 .802 r
F P
0 g
s
.43754 .26392 m .44128 .28653 L .35547 .30533 L p .647 .584 .771 r
F P
0 g
s
.35547 .30533 m .34782 .287 L .43754 .26392 L p .647 .584 .771 r
F P
0 g
s
.6954 .36795 m .68741 .39254 L .61447 .37136 L p .783 .649 .714 r
F P
0 g
s
.61447 .37136 m .61893 .34556 L .6954 .36795 L p .783 .649 .714 r
F P
0 g
s
.58719 .4989 m .58256 .51275 L .53059 .49685 L p .647 .647 .837 r
F P
0 g
s
.53059 .49685 m .53103 .48296 L .58719 .4989 L p .647 .647 .837 r
F P
0 g
s
.66311 .46071 m .65489 .48039 L .5964 .46379 L p .769 .671 .755 r
F P
0 g
s
.5918 .48251 m .5964 .46379 L .65489 .48039 L p .761 .683 .775 r
F P
0 g
s
.68741 .39254 m .67937 .41644 L .60999 .39644 L p .782 .652 .719 r
F P
0 g
s
.60999 .39644 m .61447 .37136 L .68741 .39254 L p .782 .652 .719 r
F P
0 g
s
.67127 .43928 m .66311 .46071 L .60096 .443 L p .775 .663 .739 r
F P
0 g
s
.5964 .46379 m .60096 .443 L .66311 .46071 L p .769 .671 .755 r
F P
0 g
s
.67937 .41644 m .67127 .43928 L .60549 .42044 L p .779 .656 .727 r
F P
0 g
s
.60549 .42044 m .60999 .39644 L .67937 .41644 L p .779 .656 .727 r
F P
0 g
s
.60096 .443 m .60549 .42044 L .67127 .43928 L p .775 .663 .739 r
F P
0 g
s
.53235 .42797 m .53192 .44831 L .46737 .43537 L p .628 .58 .781 r
F P
0 g
s
.46737 .43537 m .46362 .41702 L .53235 .42797 L p .628 .58 .781 r
F P
0 g
s
.5918 .48251 m .58719 .4989 L .53103 .48296 L p .673 .635 .803 r
F P
0 g
s
.53103 .48296 m .53147 .46672 L .5918 .48251 L p .673 .635 .803 r
F P
0 g
s
.53279 .40598 m .53235 .42797 L .46362 .41702 L p .643 .576 .764 r
F P
0 g
s
.46362 .41702 m .45988 .39726 L .53279 .40598 L p .643 .576 .764 r
F P
0 g
s
.53323 .38263 m .53279 .40598 L .45988 .39726 L p .654 .574 .752 r
F P
0 g
s
.45988 .39726 m .45615 .37633 L .53323 .38263 L p .654 .574 .752 r
F P
0 g
s
.5964 .46379 m .5918 .48251 L .53147 .46672 L p .69 .624 .777 r
F P
0 g
s
.53147 .46672 m .53192 .44831 L .5964 .46379 L p .69 .624 .777 r
F P
0 g
s
.53366 .35826 m .53323 .38263 L .45615 .37633 L p .663 .573 .743 r
F P
0 g
s
.45615 .37633 m .45243 .35452 L .53366 .35826 L p .663 .573 .743 r
F P
0 g
s
.53409 .33319 m .53366 .35826 L .45243 .35452 L p .671 .574 .738 r
F P
0 g
s
.45243 .35452 m .44872 .33209 L .53409 .33319 L p .671 .574 .738 r
F P
0 g
s
.60096 .443 m .5964 .46379 L .53192 .44831 L p .703 .616 .758 r
F P
0 g
s
.53192 .44831 m .53235 .42797 L .60096 .443 L p .703 .616 .758 r
F P
0 g
s
.53452 .30777 m .53409 .33319 L .44872 .33209 L p .678 .576 .734 r
F P
0 g
s
.44872 .33209 m .445 .30934 L .53452 .30777 L p .678 .576 .734 r
F P
0 g
s
.60549 .42044 m .60096 .443 L .53235 .42797 L p .711 .61 .742 r
F P
0 g
s
.53495 .28231 m .53452 .30777 L .445 .30934 L p .683 .58 .734 r
F P
0 g
s
.445 .30934 m .44128 .28653 L .53495 .28231 L p .683 .58 .734 r
F P
0 g
s
.63227 .26744 m .62781 .29326 L .53495 .28231 L p .736 .61 .718 r
F P
0 g
s
.53495 .28231 m .53539 .25714 L .63227 .26744 L p .736 .61 .718 r
F P
0 g
s
.62781 .29326 m .62337 .31941 L .53452 .30777 L p .733 .606 .715 r
F P
0 g
s
.53452 .30777 m .53495 .28231 L .62781 .29326 L p .733 .606 .715 r
F P
0 g
s
.60999 .39644 m .60549 .42044 L .53279 .40598 L p .718 .606 .731 r
F P
0 g
s
.53235 .42797 m .53279 .40598 L .60549 .42044 L p .711 .61 .742 r
F P
0 g
s
.62337 .31941 m .61893 .34556 L .53409 .33319 L p .731 .604 .715 r
F P
0 g
s
.53409 .33319 m .53452 .30777 L .62337 .31941 L p .731 .604 .715 r
F P
0 g
s
.61893 .34556 m .61447 .37136 L .53366 .35826 L p .727 .603 .718 r
F P
0 g
s
.53366 .35826 m .53409 .33319 L .61893 .34556 L p .727 .603 .718 r
F P
0 g
s
.61447 .37136 m .60999 .39644 L .53323 .38263 L p .723 .604 .723 r
F P
0 g
s
.53279 .40598 m .53323 .38263 L .60999 .39644 L p .718 .606 .731 r
F P
0 g
s
.53323 .38263 m .53366 .35826 L .61447 .37136 L p .723 .604 .723 r
F P
0 g
s
.53539 .25714 m .53495 .28231 L .44128 .28653 L p .689 .586 .735 r
F P
0 g
s
.44128 .28653 m .43754 .26392 L .53539 .25714 L p .689 .586 .735 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ok2F_003o`00
0?nlW;Oo_9bg00?o_9bg2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo0_l00002ooooo`03o`000?oooooooooo07Sooooo2_l0000Hok2F_003o`000?nl
W;Oo_9bg00ko_9bg2ol0000Jooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_oo
ool002cooooo0_l00004ooooo`03o`000?oooooooooo07?ooooo1?l00002ojFEa@03o`000?n`U[co
/9Jl01go/9Jl00?o0000okbL]onlW;L06OnlW;L7o`0001?ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`00;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
06oooooo0ol00006ojFEa@03o`000?n`U[co/9Jl01go/9Jl00?o0000okbL]onlW;L07OnlW;L00ol0
003ob:JfolRV]P03o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]oooo
o`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo1?l00009ojFEa@03
o`000?n`U[co/9Jl01go/9Jl00?o0000okbL]onlW;L07OnlW;L00ol0003ob:JfolRV]P03olRV]P?o
00003Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo000/ooooo`?o0000
1_ooool00ol0003oooooooooo`1Uooooo`Co00003OnUULD00ol0003o/9Jlok2F_00Mok2F_003o`00
0?nlW;Oo_9bg01co_9bg00?o0000olRV]_o8Y[H01oo8Y[H3o`0000[ooooo00?o0000ooooooooool0
<_ooool2o`0002gooooo000/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0H?oo
ool4o`0001;oYIG500?o0000ok2F_?n`U[`07?n`U[`00ol0003o_9bgokbL]`0LokbL]`03o`000?o8
Y[Kob:Jf00[ob:Jf0ol00007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:ooo
ool0017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`?o0000
5_nUULD00ol0003o/9Jlok2F_00Dok2F_0go00006_nlW;L00ol0003ob:JfolRV]P0=olRV]P?o0000
1Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo000Aooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo05Oooooo1?l0000IojFEa@03o`000?n`U[co/9Jl00Go/9Jl
3ol00008ojjD^`03o`000?nkVkOo^i^g00;o^i^g1ol0000CokbL]`03o`000?o8Y[Kob:Jf013ob:Jf
0ol00002ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool000Wooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000
2oooool00ol0003oooooooooo`1Cooooo`?o00006onUULD3o`000003ok2F_?l0003o000000Co0000
5on^U;/00ol0003o^i^gok^K]`09ok^K]`So00002onlW;L00ol0003ob:JfolRV]P0ColRV]P?o0000
=_ooool00ol0003oooooooooo`0Yooooo`004Oooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo
0_l000000onNW]?o0000ojFEa@0FojFEa@Go00000_nSTlD00ol0003o[YBkojjD^`0LojjD^`03o`00
0?nkVkOo^i^g017o^i^g1ol00003okbL]`03o`000?o8Y[Kob:Jf01Kob:Jf1?l0000dooooo`03o`00
0?oooooooooo02Sooooo000Aooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1=ooooo`;o
00001?nNW]<00ol0003oYIG5ojFEa@0?ojFEa@Go00001onSTlD00ol0003o[YBkojjD^`0LojjD^`03
o`000?nkVkOo^i^g01So^i^g1_l0000FolRV]P04o`000?o8Y[Kob:JfolRV]P?o0000<Oooool2o`00
02Wooooo000Aooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06oooo
o`;o00003oooool00ol0003oooooooooo`1:ooooo`;o00001_nNW]<00ol0003oYIG5ojFEa@0;ojFE
a@Co00003?nSTlD00ol0003o[YBkojjD^`0LojjD^`03o`000?nkVkOo^i^g01_o^i^g00?o0000olRU
]_o8YKH00ol0000ColRV]P03o`000?o8Y[Kob:Jf00;ob:Jf00Co0000omFd^?l0003o0000;oooool2
o`0002Wooooo000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Aoooool2o`0000WoWYkC00?o0000
ojFEaOnUULD01OnUULD5o`00017oXi?500?o0000ojjD^on^U;/06on^U;/00ol0003o^i^gok^K]`0K
ok^K]`03o`000?o8YKKob:Ff00?ob:Ff1?l0000?olRV]P03o`000?o8Y[Kob:Jf00;ob:Jf00Go0000
omFd^?oE];SoeKBho`00000`ooooo`03o`000?oooooooooo02Kooooo000Aooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool2o`0004Gooooo0_l0
000;oijNd`04o`000?nUULGoYIG5ojFEa@Co00005_nSTlD00ol0003o[YBkojjD^`0KojjD^`03o`00
0?nkVkOo^i^g01_o^i^g00?o0000olRU]_o8YKH01oo8YKH3o`0000_ob:Jf0_l00003olRV]P03o`00
0?oE];SoeKBh00?oeKBh0_l0000^ooooo`03o`000?oooooooooo02Kooooo000Zooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0@?ooool2o`0000goWYkC0ol0000Koj>Ca@03o`000?n^
U;_o[YBk01_o[YBk00?o0000ok^K]onkVkL06onkVkL00ol0003ob:FfolRU]P0:olRU]PCo00001?o8
Y[H3o`000003olRV]_l0003ob:Jf00;ob:Jf00?o0000omFd^?oE];P01OoE];P2o`0002gooooo00?o
0000ooooooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l0000=
oijNd`;o000000?oVYcEo`000?nSTlD06?nSTlD4o`000003ojjD^ol0003o0000023o00005onkVkL0
0ol0003ob:FfolRU]P0?olRU]PCo00001Oo8Y[H01?l0003ob:JfolRV]_l00009omFd^0;o0000;?oo
ool00ol0003oooooooooo`0Tooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo03[ooooo0_l0000<oijNd`?o00001?nJW=D00ol0003oXi?5oj>Ca@0Aoj>Ca@Go00000onPT/D0
0ol0003o[I>kojfC^`0KojfC^`03o`000?nkV[Oo^iZg00?o^iZg2_l0000=ok^K]`03o`000?o8YKKo
b:Ff00gob:Ff0ol00002olRU]PCo00000oo8Y[H00ol0003ob:Jfo`00000;omFd^0;o0000:_ooool2
o`0002Gooooo000Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=oooool2o`00
00coWYkC0_l00007oiZLe@03o`000?nSTlGoXi?500_oXi?51_l00008oj2Ba@03o`000?n]Tk_o[I>k
01_o[I>k00?o0000ok^J]onkV[L03OnkV[L9o`0000Co^i^g00?o0000olRU]_o8YKH02_o8YKH3o`00
00Wob:Ff0ol000000oo8Y[Ko0000omFd^00=omFd^003o`000?oooooooooo02Oooooo0_l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@07ooooo`00:_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Cooooo0_l0000<
oijNd`;o00002OnJW=D00ol0003oXi?5oj>Ca@06oj>Ca@Go00003_nPT/D00ol0003o[I>kojfC^`0K
ojfC^`03o`000?nkV[Oo^iZg01Ko^iZg1ol00007olRU]P?o00003oo8YKH3o`0000koeKBh0_l0000X
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`06ooooo`00:_ooool2o`0001Wooooo00?o0000ooooooooool0<Oooool2
o`0000_oWYkC0ol0000<oiZLe@03o`000?nSTlGoXi?500Go00004onPT/D00ol0003o[I>kojfC^`0K
ojfC^`03o`000?nkV[Oo^iZg01[o^iZg00?o0000olRU]_o8YKH00ol000001?o8YKKo0000o`000?l0
000ColRU]PCo00003_oE];P2o`0002Oooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooo
oooooooo410@013ooooo00?o0000ooooooooool01Oooool002Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0^ooooo`;o00002onNW]<2o`0000koVYcE1?l0000Ioj2Ba@03o`000?n]
Tk_o[I>k01Wo[I>k00?o0000ok^J]onkV[L06onkV[L01?l0003ob:FfolRU]_o8YKH5o`0001?ob:Ff
00Go0000omJd^?oF];So0000omJd^002o`0000koeKBh0_l0000Vooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo000Yooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0;?ooool01?l0003oX[CUoj:diOl00008oijN
d`;o00003OnJW=D3o`000003oiJKeol0003oX9;501[oX9;500?o0000ojfC^on]Tk/06On]Tk/00ol0
003o^iZgok^J]`0Jok^J]`03o`000?o8YKKo000000;o00001Oo8YKH3o`00013ob:Ff00Go0000omJd
^?oF];Soe[Bho`000002omJd^003o`000?oE];SoeKBh00goeKBh00?o0000ooooooooool08oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Oooooo000Yooooo`?o00007?ooool00ol0003oooooooooo`0Zooooo`03o`000?nR
]>GoX[CU00;oX[CU00?o0000oijNdonNW]<00_nNW]<3o`0000coVYcE0ol00005oiJKe`03o`000?nP
T/GoX9;501SoX9;500?o0000ojfC^on]Tk/06On]Tk/00ol0003o^iZgok^J]`0Iok^J]`?o00002oo8
YKH4o`0000cob:Ff00Go0000omJd^?oF];Soe[Bho`000003omJd^0;o00003_oE];P2o`0002Cooooo
00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool02Oooool002Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?nR]>GoX[CU00CoX[CU00Co0000oijNdonNW]?o00003?nJW=D3o`0000SoUY_G00?o0000oj2BaOnP
T/D05?nPT/D5o`000003ojfC^ol0003o000001go00005?nkV[L3o`000003ok^J]ol0003ob:Ff00oo
b:Ff0ol00008olRU]P03o`000?oF];Soe[Bh00?oe[Bh00?o0000omJd^?oF];P00_oF];P2o`0000ko
eKBh00?o0000ooooooooool08?ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Wooooo000Yooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool09_ooool00ol0003oX[CUoj:di@05oj:di@;o00003?nJW=D2o`0000coUY_G00?o0000oj2BaOnP
T/D02_nPT/D9o`0000CoWI7700?o0000oj^B_?n[T[`06On[T[`00ol0003o^YZgokZJ]`02okZJ]`Oo
00002_nkV[L3o`0000Co^iZg00?o0000olRU]_o8YKH04Oo8YKH3o`0000Gob:Ff00?o0000omJd^?oF
];P01?oF];P00ol0003oe[BhomJd^003omJd^0;o00003?oE];P2o`0002?ooooo00?o0000oooooooo
ool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00008ooooo`001_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?nR]>Go
X[CU00GoX[CU00?o0000oibdjOl000002OnJW=D3o`0000koUY_G00?o0000oj2BaOnPT/D00_nPT/D8
o`0000goWI7700?o0000oj^B_?n[T[`06On[T[`00ol0003o^YZgokZJ]`09okZJ]`[o00001onkV[L0
0ol0003ob:FfolRU]P0DolRU]P?o00000_o8YKH00ol0003oe[BhomJd^005omJd^003o`000?oF];So
e[Bh00Coe[Bh0_l00009omFd^004o`000?oPaKkoh<Fno`0002?ooooo00?o0000ooooooooool07_oo
ool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool3o`00027ooooo00?o0000ooooooooool0
8_ooool00ol0003oX[CUoj:di@05oj:di@05o`000?nL]>WoW;CYoibdjOl000001OnJW=D3o`00013o
UY_G1_l0000FoifAa`03o`000?n[T[coZi:l01SoZi:l00?o0000okZJ]onjV[L03_njV[L9o`0000;o
^iZg00?o0000olRU]_o8YKH06?o8YKH3o`0000Ooe[Bh00?o0000omJd^?oF];P01_oF];P2o`0000Oo
eKBh00Go0000on35__oPaKkoh<Fno`00000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00006oj:d
i@;o00001OnL]>T00ol0003oVYcEoiZLe@02o`00013oUY_G0ol00002oi2Jf@03o`000?nMTLOoWI77
01OoWI7700?o0000oj^B_?n[T[`06?n[T[`00ol0003o^YZgokZJ]`0;okZJ]`?o00002OnjV[L5o`00
01Wob:Ff00Co0000omJe^?l0003o00001_oF];P00ol0003oe[BhomJd^007omJd^003o`000?oE];So
eKBh00?oeKBh00?o0000on35__oPaKh00ooPaKh00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01gooooo0006ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0M
ooooo`03o`000?nR]>GoX[CU00GoX[CU00?o0000oibdjOnL]>T01OnL]>T2o`0000ooUY_G1?l00006
oi2Jf@03o`000?nMTLOoWI7701KoWI7700?o0000oj^B_?n[T[`06?n[T[`00ol0003o^YZgokZJ]`08
okZJ]`?o00003_njV[L00ol0003ob:JfolRV]P03o`0001Gob:Ff00?o0000omJe^?oF]KP00_oF]KP2
o`0000Goe[Bh00?o0000omJd^?oF];P01ooF];P2o`0000?oeKBh00?o0000on35__oPaKh01?oPaKh0
0ol0003oooooooooo`0Pooooo`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02Cooooo0_l0000Looooo`03o`000?nR]>GoX[CU00GoX[CU00?o0000oibdjOnL]>T01OnL
]>T01?l0003oU[C/oiJdk?l0000;oiJKe`?o00002_n@V]T00ol0003oWI77oifAa`0GoifAa`03o`00
0?n[T[coZi:l01OoZi:l00?o0000okZJ]onjV[L01OnjV[L3o`00017o^YZg00?o0000olRV]_o8Y[H0
0oo8Y[H4o`00017ob:Ff00?o0000omJe^?oF]KP01?oF]KP2o`0000Coe[Bh00?o0000omJd^?oF];P0
2?oF];P2o`000003omFd^?l0003oh<Fn00Koh<Fn00?o0000ooooooooool07_ooool00ol0003ooooo
o`00000Mooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`;o00009oooool00ol0003oooooooooo`0Hooooo`03o`00
0?nR]>GoX[CU00CoX[CU0_l00007oibdj@03o`000?nF]>coU[C/00;oU[C/00?o0000oiJKeonFVmL0
1?nFVmL4o`0000goT9[I00?o0000oifAaonMTLL04OnMTLL7o`000003oj^B_?l0003o000000[o0000
3?n[T[`00ol0003o^YZgokZJ]`02okZJ]`?o00005?njV[L00ol0003ob:JfolRV]P07olRV]PCo0000
3Oo8YKH00ol0003oe[FhomJe^006omJe^0;o00000_oF];P00ol0003oe[BhomJd^00:omJd^0;o0000
2?oPaKh00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01_ooooo0006ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Kooooo00?o0000oj:diOnR
]>D01?nR]>D00ol0003oW;CYoibdj@05oibdj@;o00001_nF]>`00ol0003oUY_GoiJKe`03o`0001;o
T9[I00?o0000oifAaonMTLL00onMTLL=o`0000KoVI3900?o0000ojVB__nYT[h02onYT[hAo`0001Oo
^YZg00?o0000olRV]_o8Y[H02oo8Y[H3o`0000Wob:Ff00?o0000omJe^?oF]KP02OoF]KP2o`000003
omJd^?l0003oe[Bh00[oe[Bh00?o0000on77__l000002?oPaKh00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool05?ooool00ol0003oX[CUoj:di@04oj:di@03o`000?nL]>WoW;CY00GoW;CY00?o0000oiJd
k?nF]>`01_nF]>`3o`0001?oT9[I2?l0000CoiV@b@03o`000?nYT[koZI:n01KoZI:n0ol00002okVJ
^@Oo00004?njV[L00ol0003ob:JfolRV]P0?olRV]PCo00001Oo8YKH00ol0003oe[FhomJe^00;omJe
^003o`000?oF];So000000Woe[Bh00Go0000on77__oQakkohLNno`000008on35_P03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Booooo`03o`000?nR]>GoX[CU00CoX[CU00?o0000oibdjOnL]>T01?nL]>T2o`00
00OoU[C/0_l000000on=]?3o0000oi2Jf@0?oi2Jf@Co00000_n:VM`00ol0003oVI39oiV@b@0FoiV@
b@03o`000?nYT[koZI:n01?oZI:n0ol000000onYT[ko0000okVJ^@09okVJ^@Oo00002OnjV[L00ol0
003ob:JfolRV]P0ColRV]P?o00000_o8YKH00ol0003oe[FhomJe^00<omJe^0;o00002OoF];P00ol0
003ohLNnon77_P02on77_P03o`000?oPaKkoh<Fn00Koh<Fn00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0Iooooo`009oooool2o`0002cooooo00?o0000ooooooooool04?ooool00ol0003o
X[CUoj:di@03oj:di@;o00001_nL]>T00ol0003oU[C/oiJdk006oiJdk003o`000?n=]?3oSKC`00;o
SKC`00?o0000oi2JfOn@V]T02On@V]T4o`0000OoRYWL00?o0000oiV@bOnIT<T05_nIT<T00ol0003o
ZI:nojVB_P0?ojVB_P?o00001?nYT[h00ol0003o^IZiokVJ^@0?okVJ^@Oo00000_njV[L00ol0003o
b:JfolRV]P0FolRV]P?o00004?oF]KP2o`0000Koe[Bh00?o0000on77__oQakh01?oQakh00ol0003o
h<Fnon35_P06on35_P03o`000?oooooooooo01kooooo00?o0000ooooooooool06?ooool002Oooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`;o00001OnR]>D7oibdj@03o`00
0?nF]>coU[C/00GoU[C/0_l00006ohfdl003o`000?n@V]WoT9[I00CoT9[I1?l0000;ohZIg003o`00
0?nIT<WoVI3901KoVI3900?o0000ojVB__nYT[h03?nYT[h3o`0000OoZI:n00?o0000okVJ^OniV[T0
5_niV[T5o`0001Oob:Jf00Co0000omJf^Ol0003o00003ooF]KP3o`0000?oe[Bh00?o0000on77__oQ
akh01_oQakh00ol0003oh<Fnon35_P06on35_P03o`000?oooooooooo01cooooo0_l0000Jooooo`00
9oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo00Co0000okCAkol0003o
00000_nR]>D7oibdj@03o`000?nF]>coU[C/00CoU[C/0_l00008ohfdl003o`000?n@V]WoT9[I00Co
00004?n:VM`00ol0003oVI39oiV@b@0EoiV@b@03o`000?nYT[koZI:n00WoZI:n0ol0000:ojVB_P03
o`000?niV[Wo^IZi01So^IZi00?o0000olRV^?o8Y[P00ol0000DolRV]P04o`000?oF][Woe[JiomJf
^@;o00003_oF]KP01_l0003oe[Fho`000?l0003oe[Bho`0000WohLNn00?o0000on35__oPaKh01_oP
aKh00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool02oooool00ol0003o]=7_okCAk`02okCAk`;o00001_nL]>T7
oiJdk003o`000?n=]?3oSKC`00SoSKC`0ol0000DohZIg003o`000?nIT<WoVI3900[oVI393?l00000
0onYT[ko0000o`000003o`0000;oZI:n0ol0000=ojVB_P03o`000?niV[Wo^IZi01So^IZi00?o0000
olRV^?o8Y[P00oo8Y[P4o`0000oob:Jf00?o0000omJf^OoF][T01?oF][T2o`0000coe[Fh00Co0000
omJe^?oF]KSoe[Fh0_l0000:on77_P03o`000?oPaKkoh<Fn00Koh<Fn00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Fooooo`009oooool2o`00033ooooo00?o0000ooooooooool02_ooool0
0ol0003o]=7_okCAk`02okCAk`03o`000?n`e??o000000;o00000_nL]>T6oiJdk0;o00002On=]?02
o`0000;oP[?d00?o0000ohZIg?n:VM`04?n:VM`?o`0000_oUI3<00?o0000ojNB`?nWT/000onWT/0>
o`0000GoZI:n00?o0000okVJ^OniV[T05oniV[T00ol0003ob:JholRV^008olRV^0?o00003?o8Y[H0
0ol0003oe[JiomJf^@06omJf^@;o00002ooF]KP01_l0003oe[FhomJe^?l0003ohlVno`0000[ohLNn
00?o0000on35__oPaKh01_oPaKh00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo
000Vooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003o]=7_okCA
k`02okCAk`03o`000?n`e??o/=Cc00?o/=Cc0_l00005oiJdk003o`000?n=]?3oSKC`00OoSKC`0_l0
0005oh:cm003o`000?n:VMcoRYWL00SoRYWL1ol00003oh:Hh003o`000?nET<coUI3<01CoUI3<00Co
0000ojNB`?nWT/3oYi;00_l0000>ojNB`0Ko00000_niV[T00ol0003o^IZiokVJ^@0DokVJ^@03o`00
0?o8Y[Sob:Jh00_ob:Jh0ol00009olRV]P03o`000?oF][Woe[Ji00Soe[Ji0ol00009omJe^0;o0000
0ooSbKh00ol0003ohLNnon77_P08on77_P03o`000?oPaKkoh<Fn00Koh<Fn00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Eooooo`009_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Oooooo00Go0000okCAkonddNoo]=7_o`000006ok3Dl`04o`000?nZeoOo0000o`0000;o
U[C/2On=]?02o`0000SoP[?d00Co0000ohZIg?n:VMcoRYWL1_l0000;oh:Hh003o`000?nET<coUI3<
01?oUI3<1?l0000EojNB`004o`000?ngVk_o]i^kokNK^`Go00004OniV[T00ol0003ob:JholRV^00>
olRV^0Co00001Oo8Y[H00ol0003oe[JiomJf^@0;omJf^@;o00002?oF]KP00ol0003ohlVnon?9_P02
on?9_P03o`000?oQakkohLNn00SohLNn00?o0000on35__oPaKh01OoPaKh00ol0003oooooooooo`0L
ooooo`;o00005_ooool002Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`03o`000?nddNoo]=7_00;o]=7_00?o0000ok3Dlon`e?<00on`e?<00ol0003oZ]Ogoj[Gm`02oj[G
m`;o00001on=]?02o`0000[oP[?d1?l0000Aoh:Hh003o`000?nET<coUI3<017oUI3<1?l0000GojNB
`003o`000?ngVk_o]i^k00Ko]i^k1Ol0000<okVJ^@03o`000?o8Y[Sob:Jh01;ob:Jh0ol000000oo8
Y[Ko0000omJf^@0?omJf^@;o00001OoF]KP2o`0000GohlVn00?o0000on77__oQakh02?oQakh00ol0
003oh<Fnon35_P03on35_P03o`000?oVf/So000001kooooo00?o0000ooooooooool05?ooool002Ko
oooo0ol0000dooooo`03o`000?oooooooooo00Cooooo00Go0000okCAkonddNoo]=7_o`000005ok3D
l`03o`000?nZeoOoZ]Og00?oZ]Og00?o0000oj7Inol000001?n=]?02o`0000WoP[?d0ol000000omc
/OSo0000oh:Hh00Boh:Hh003o`000?nET<coUI3<00koUI3<0ol00003oiF@c003o`000?nWT/3oYi;0
01GoYi;000?o0000okNK^ongVk/02ongVk/5o`0000Oo^IZi00?o0000olRV^?o8Y[P05Oo8Y[P3o`00
017oe[Ji0_l00003omJe^003o`000?oSbKko000000GohlVn00?o0000on77__oQakh02?oQakh01Ol0
003oh<Fnon35__oPaKko000000;oi][800?o0000ooooooooool07Oooool00ol0003oooooooooo`0C
ooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000okCA
konddNl00_nddNl00ol0003o/=Ccok3Dl`03ok3Dl`03o`000?nZeoOoZ]Og00;oZ]Og00Go0000oj7I
nonQfO_oXMWko`000002ohfdl003o`000?n2/oCoP[?d00KoP[?d0ol00005og>an003o`000?n2V>3o
PYSP00goPYSP1Ol000000onET<co0000o`000008o`000004oiF@c?l0003o0000o`0000KoUI3<00?o
0000ojNB`?nWT/005OnWT/000ol0003o]i^kokNK^`0@okNK^`Go000000?o^IZio`000?o8Y[P06?o8
Y[P01?l0003oe[Njo`000?l0000AomJf^@;o000000Goe[Fho`000?oSbKkohlVno`000005on?9_P;o
00002OoQakh00ol0003oh<Fno`000003onKJb003o`000?oooooooooo01kooooo00?o0000oooooooo
ool04_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Ko
oooo00Co0000oooooooooooo00001?nddNl00ol0003o/=Ccok3Dl`03ok3Dl`03o`000?nZeoOoZ]Og
00;oZ]Og00?o0000oj7InonQfO/00onQfO/2o`0000KoP[?d0ol00009og>an003o`000?n2V>3oPYSP
00?oPYSP2Ol00004ogNGi003o`000?n@T<ooT93?00OoT93?3Ol000001?nWT/3o0000o`000?l0000C
ojNB`003o`000?ngVk_o]i^k01Go]i^k1?l0000FolRV^003o`000?oF]k[oe[Nj00;oe[Nj0_l0000A
omJf^@;o00000ooSbKh00ol0003ohlVnon?9_P04on?9_P03o`000?oQakkohLNn00OohLNn00?o0000
onKJb?oVf/P00ooVf/P00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo000Koooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0hooooo`?o00000onddNl0
0ol0003o/=Ccok3Dl`03ok3Dl`03o`000?nZeoOoZ]Og00;oZ]Og00?o0000oj7InonQfO/00onQfO/0
0ol0003oTm[noi?JoP02o`0000;oP[?d0_l0000;og>an0Oo00003_mgUn@00ol0003oT93?oi2@c`03
oi2@c`?o00003?n@T<l00ol0003oY9?3ojBC``02ojBC``So00002onWT/000ol0003o]i^kokNK^`0F
okNK^`03o`000?o7Yk[oajNj00Co00004_o8Y[P00ol0003oe[NjomJg^P04omJg^P;o00003ooF][T0
0ol0003ohl^oo`000002on?9_P03o`000?oSbKkohlVn00GohlVn00?o0000on77__oQakh01_oQakh0
0ol0003oi][8onKJb003onKJb003o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool4
o`000003oa0@4?oooooooooo00?ooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool3
o`0003Wooooo00?o0000okCAkonddNl00_nddNl00ol0003o/=Ccok3Dl`02ok3Dl`03o`000?nZeoOo
Z]Og00?oZ]Og00?o0000oj7InonQfO/00_nQfO/00ol0003oTm[noi?JoP02oi?JoP?o00002Omc/OP4
o`0000CoGjgi00?o0000ogNGi?mgUn@03omgUn@00ol0003oT93?o`000002o`0000ooT93?00?o0000
ojBC`onTTl<02_nTTl<8o`0000?oYi;000?o0000okNK^ongVk/05_ngVk/00ol0003oajNjolNW^P04
olNW^PCo00003_o8Y[P00ol0003oe[NjomJg^P06omJg^P?o00002ooF][T01Ol0003ohl^oon?;_ooS
bkoo000000;ohlVn00?o0000on?9__oSbKh01OoSbKh00ol0003ohLNnon77_P04on77_P03o`000?oX
gLSo000000Goi][800?o0000ooooooooool07?ooool3o`0000[ooooo00?o0000ooooooooool01Ooo
ool001_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03Wooooo00Go
0000okCAkonddNoo]=7_o`000005ok3Dl`03o`000?nZeoOoZ]Og00;oZ]Og00?o0000oj7InonQfO/0
0_nQfO/00ol0003oTm[noi?JoP02oi?JoP04o`000?n1eoooPMOooh7Go`?o00000_mc/OP4o`0000Wo
Gjgi00?o0000ogNGi?mgUn@03OmgUn@3o`0001;oT93?00?o0000ojBC`onTTl<04_nTTl<4o`0001So
]i^k00?o0000olNW^_o7YkX02?o7YkX3o`0000[ob:Jh00?o0000omJg^_oF]kX02_oF]kX2o`0000Wo
e[Ji00?o0000on?;_ooSbkl00_oSbkl01?l0003ohlVnon?9__l00007on?9_P03o`000?oQakkohLNn
00;ohLNn00Co0000onSMb?oXgLSo00001OoVf/P00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool001_ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo03Sooooo00?o0000okCAkonddNl00_nddNl00ol0003o/=Ccok3Dl`02
ok3Dl`03o`000?nZeoOoZ]Og00;oZ]Og00?o0000oj7InonQfO/00_nQfO/00ol0003oTm[noi?JoP02
oi?JoP03o`000?n1eoooPMOo00CoPMOo0ol0000;oen]nAGo000000?oT93?o`000?l000000_l0000>
oi2@c`03o`000?nTTl?oY9?301CoY9?300?o0000okJL_OnfW;d01Ol0000AokNK^`03o`000?o7Yk[o
ajNj00_oajNj1?l00006olRV^003o`000?oF]k[oe[Nj00coe[Nj0_l00006omJf^@03o`000?oSbkoo
hl^o00Cohl^o00Co0000on?9__oSbKko00001ooSbKh01Ol0003ohLNnon77__oQakko000000?oj=g8
00?o0000onKJb?oVf/P00ooVf/P00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01Oooool001_ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo03Sooooo00Go0000okCAkonddNoo]=7_o`000004ok3Dl`03o`000?nZeoOoZ]Og00?o
Z]Og00Go0000oj7InonQfO_oXMWko`000004oi?JoP03o`000?n1eoooPMOo00?oPMOo0_l00003ofO?
nP;o00000omO[OT6o`0000?oAZGg00?o0000ofVDj?mYU>P01_mYU>P3o`0000GoJICX00?o0000ohV@
e?n9T=@00on9T=@:o`0000CoT93?00?o0000ojBC`onTTl<05?nTTl<00ol0003o]YbmokJL_@05okJL
_@Go00002ongVk/00ol0003oajNjolNW^P0@olNW^PCo00000_o8Y[P00ol0003oe[NjomJg^P0>omJg
^P;o00000ooF][T00ol0003ohl^oon?;_`06on?;_`03o`000?oSbKko000000SohlVn00?o0000on77
__l000001?oXgLP00ol0003oi][8onKJb003onKJb003o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_l0000hooooo`05o`000?nddNoo]=7_okCAkol000001On`e?<00ol0003oZ]Ogoj[Gm`02
oj[Gm`05o`000?nQfO_oXMWkoj7Inol000001?nCf_h00ol0003oPMOooh7Go`03oh7Go`03o`000?mW
co[oIloj00CoIloj1?l0000:odJUm`03o`000?mYU>SoJICX00;oJICX0ol00009ofVDj003o`000?n9
T=CoRI3D00coRI3D1Ol0000FojBC``03o`000?nfW;go]Ybm00[o]Ybm1Ol00006okNK^`03o`000?o7
Yk[oajNj01CoajNj0ol0000BomJg^P;o000000?oe[Jio`000?oSbkl02?oSbkl3o`0000SohlVn00?o
0000onSMb?oXgLP00ooXgLP00ol0003oi][8onKJb003onKJb003o`000?oooooooooo01oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`006oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool0=oooool01Ol0003o]=7_okCAkonddNoo000000Co/=Cc
00?o0000oj[GmonZeoL00_nZeoL01Ol0003oXMWkoj7InonQfO_o000000CoTm[n00?o0000oh7Goon1
eol00_n1eol2o`0000CoIloj0ol00003odK0kP;o00002_m6YOL4o`0000coJICX00?o0000ohV@e?n9
T=@04?n9T=@01?l0003oX9C7oj2DaonPU<L6o`0000goY9?300?o0000okJL_OnfW;d03onfW;d5o`00
0003okNK^ol0003oajNj01KoajNj00?o0000omJi_Ol000000_l0000AomJg^P;o00002ooSbkl2o`00
00OohlVn00?o0000onSMb?oXgLP01?oXgLP00ol0003oi][8onKJb003onKJb003o`000?oooooooooo
01kooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo000Tooooo`03o`000?oooooooooo03Oo
oooo7ol00002ofO?nP;o00001Om6`>h?o`000003ofVDj?l0003o000000Go00001_mYU>P00ol0003o
RI3DohV@e00AohV@e003o`000?nPU<OoX9C700KoX9C71Ol00008ojBC``03o`000?nfW;go]Ybm01Co
]Ybm1?l0000EolNW^P03o`000?oF^Kgoe[Vm00;oe[Vm0_l0000?omJg^P03o`000?oTc/7o000000_o
hl^o0_l00005on?9_P03o`000?oYhLWo000000Goj=g800?o0000onKJb?oVf/P00ooVf/P00ol0003o
ooooooooo`0Mooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001oooool002Cooooo
00?o0000ooooooooool0=oooool01Ol0003ocMoVolgOi_o=gnKo000000Coc>CX00?o0000ol[Yk?o:
jN`00_o:jN`01Ol0003oa^k_olK^koo6k^oo000000Co__;b00?o0000ok;clonblo<00_nblo<00ol0
003oWo7boioalP0Ao`000003obFGk_l0003o000000Go9IO^00?o0000oeNAk?mGTN`01?mGTN`8o`00
00;oRI3D00?o0000ohV@e?n9T=@03On9T=@00ol0003oX9C7oj2Da`0;oj2Da`Ko00000_nTTl<00ol0
003o]YbmokJL_@0EokJL_@03o`000?o6ZKgoaZVm00Co00004?o7YkX00ol0003oe[VmomJi_@05omJi
_@;o00003?oF]kX01Ol0003oi<k1onC>`OoTc/7o000000_ohl^o00?o0000on?9__oSbKh00_oSbKh0
1?l0003ojN79onWQbOl00006onSMb003o`000?oVf/Soi][800?oi][800?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0<ooooo`009?ooool2o`0003Sooooo00Go0000olgOi_o=gnKocMoVo`00
0004olcTj003o`000?o:jNcob^W/00;ob^W/00Go0000olK^koo6k^ooa^k_o`000004okkblP03o`00
0?nblo?o/_?c00;o/_?c00Go0000oioal_nOlO;oWo7bo`000004ohCYk003o`000?mQemgo000000?o
00000_nKlnL00ol0R[_o0000o`000008o`000003obFGk_l0003oEi7/00_oEi7/00Co0000ogn@f_mo
T=[oOi3J1ol00008ohV@e003o`000?nPU<OoX9C7017oX9C70ol0000GokJL_@03o`000?o6ZKgoaZVm
00CoaZVm0ol0000=olNW^P03o`000?oF^Kgoe[Vm00Ooe[Vm0ol00009omJg^P03o`000?oTc/7oi<k1
00;oi<k10_l0000:on?;_`05o`000?oSbKkohlVnon?9__l000000ooYhLT00ol0003oj=g8onSMb003
onSMb003o`000?oVf/Soi][800?oi][800?o0000ooooooooool07_ooool3o`0000gooooo000Toooo
o`03o`000?oooooooooo03Oooooo00Go0000olgOi_o=gnKocMoVo`000004olcTj003o`000?o:jNco
b^W/00;ob^W/00Go0000olK^koo6k^ooa^k_o`000004okkblP03o`000?nblo?o/_?c00;o/_?c00Go
0000oioal_nOlO;oWo7bo`000002ohCYk0Co00001?ngn^/5o`0000;odO7X0ol00003o`23f`?o0000
0_mGTN`00ol0003oEi7/oeNAk007oeNAk003o`000?moT=[oOi3J00OoOi3J1ol00002ohV@e003o`00
0?nPU<OoX9C701;oX9C700?o0000ok>M`_ncWL801Ol0000?okJL_@03o`000?o6ZKgoaZVm00SoaZVm
1?l00009olNW^P03o`000?oF^Kgoe[Vm00[oe[Vm0_l00006omJg^P03o`000?oTc/7oi<k100Goi<k1
00?o0000on?;_ooSbkl02?oSbkl00ol0003ohlVno`000004onWQb@03o`000?oXgLSoj=g800Coj=g8
00?o0000onKJb?oVf/P00_oVf/P00ol0003oooooooooo`0Kooooo`?o00000_ooool00ol0003ooooo
ooooo`0;ooooo`009?ooool00ol0003oooooooooo`0gooooo`05o`000?o=gnKocMoVolgOi_l00000
1?o<i>P00ol0003ob^W/ol[Yk002ol[Yk005o`000?o6k^ooa^k_olK^kol000001?nnl_801Ol0003o
/_?cok;clonblo?o000000?oWo7b1?l00003olSij@03o`000?ngn^_o000000Co00002OoAlNP4o`00
0004o`23fol0003o?H[]ocf:k@Go00001OmGTN`00ol0003oOi3Jogn@fP0=ogn@fP?o00005?nPU<L0
0ol0003o/ig2ok>M`P05ok>M`PCo00002onfW;d00ol0003oaZVmolJY_@0<olJY_@Co00001Oo7YkX0
0ol0003oe[VmomJi_@0<omJi_@;o00001?oF]kX00ol0003oi<k1onC>`@06onC>`@03o`000?oSbkoo
hl^o00Sohl^o00?o0000onWQbOoYhLT01?oYhLT00ol0003oj=g8onSMb003onSMb003o`000?oVf/So
i][800?oi][800?o0000ooooooooool05oooool3o`0000Gooooo00?o0000ooooooooool02oooool0
02Cooooo00?o0000ooooooooool0=_ooool00ol0003ocMoVolgOiP02olgOiP03o`000?o<i>Soc>CX
00;oc>CX00?o0000ol[Yk?o:jN`00_o:jN`01Ol0003oa^k_olK^koo6k^oo000000?o__;b00?o0000
ok;clonblo<00_nblo<00ol0003oWo7bo`000003o`0000Cob?WY0ol000000ongn^_o0000o`000003
omW[h0?o00001OoAlNP01?l0003oeMKIo`000?l0J<03o`0000Ko?H[]1_l0000Aogn@fP03o`000?nK
ULgoViG=00Co00003_nPU<L00ol0003o/ig2ok>M`P09ok>M`PCo00001onfW;d00ol0003oaZVmolJY
_@0@olJY_@?o000000?oajNjo`000?oF^Kd04?oF^Kd3o`000003omJg^_l0003oi<k100Soi<k100?o
0000on?;_ooSbkl01_oSbkl2o`0000KojN7900?o0000onSMb?oXgLP00ooXgLP00ol0003oi][8onKJ
b002onKJb0;o00005Oooool4o`0000Sooooo00?o0000ooooooooool02oooool002?ooooo0ol0000g
ooooo`03o`000?o=gnKocMoV00;ocMoV00?o0000olcTj?o<i>P00_o<i>P00ol0003ob^W/ol[Yk002
ol[Yk004o`000?o6k^ooa^k_o`0000Co__;b00Co0000ok;clonblo?o/_?c0ol00004om?fi@Co0000
0_o8nNT2o`0000SofN_P0ol000000ooAlNSo0000omGFf@03omGFf@;o000000?o06S0o`000?lmR^d0
2OlmR^d2o`00013oOi3J00?o0000oi^EcOnKULd01?nKULd5o`0000WoX9C700?o0000ok>M`_ncWL80
3OncWL85o`000003okJL_Ol0003oaZVm01GoaZVm0ol0000ComJi_@;o00002_oTc/42o`0000Gohl^o
00Co0000on[Tb_oZi<[o00001_oYhLT00ol0003oj=g8onSMb003onSMb006o`000?oVf/Soi][8o`00
0?oQjmSo00004_ooool3o`0000gooooo00?o0000ooooooooool02_ooool002?ooooo00?o0000oooo
ooooool0=oooool00ol0003ocMoVolgOiP02olgOiP03o`000?o<i>Soc>CX00;oc>CX00Go0000ol[Y
k?o:jNcob^W/o`000003olK^k`03o`000?nnl_;o__;b00;o__;b1?l000000ooIlN7o0000om?fi@02
om?fi@Co00000oo8nNT01?l0003og^GIomkUfOoNiMT2o`0000SofN_P00?o0000omGFfOoEe]T01OoE
e]T7o`0000Ko?H[]00?o0000og:?h?mbSn001Ol00009ogn@fP03o`000?nKULgoViG=00WoViG=1?l0
0005oj2Da`03o`000?ncWL;o/ig201;o/ig20_l0000GolJY_@03o`000?oF_<3o000000;o00004?oF
^Kd00ol0003oi=74o`00000;onC>`@05o`000?oSbkoohl^oon?;_ol000000ooZi<X2o`0000GojN79
00?o0000onSMb?oXgLP00ooXgLP00ol0003oi][8o`000002on7[f003o`000?oooooooooo00gooooo
0ol0000@ooooo`03o`000?oooooooooo00[ooooo000Sooooo`03o`000?oooooooooo03Oooooo00?o
0000olgOi_o=gnH00_o=gnH01Ol0003oc>CXolcTj?o<i>So000000Cob^W/00Go0000olK^koo6k^oo
a^k_o`000003okkblP;o00001OoIlN43o`0000CodoKU00?o0000olSijOl000001_oNiMT2o`0000Co
fN_P00Co0000omS@dOoHd=7of=3A0ol00006omGFf@;o00000_lLOnL4o`0000?o?H[]00?o0000og:?
h?mbSn001?mbSn04o`0000KoOi3J00?o0000oi^EcOnKULd03?nKULd4o`000003oj2Daol0003o/ig2
01Co/ig200?o0000olB[`Oo4Zl400ol0000AolJY_@03o`000?oF_<3oe[c000?oe[c00_l0000=omJi
_@05o`000?oTdLCoi=74onCAa?l000002ooTc/400ol0003ohl^oo`000005on[TbP;o00001OoYhLT0
0ol0003oj=g8onSMb003onSMb005o`000?oQjmSohN_Hon7[f?l000002oooool4o`0001?ooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool01Ol0003ocMoVolgOi_o=
gnKo000000Coc>CX00?o0000ol[Yk?o:jN`00_o:jN`01?l0003oa^k_olK^koo6k^l4o`000004omc/
gOl0003ofO7QomWah@?o000000?ofO7Qo`000?oCm^D01?oCm^D3o`0000Sog^GI0_l000000ooIjn3o
0000omS@d@06omS@d@;o00001OoEe]T2o`0000Go77oW1?l0000:og:?h0Go000000?oOi3Jo`000?nK
ULd04OnKULd2o`0001Go/ig200?o0000olB[`Oo4Zl400oo4Zl44o`0000goaZVm00?o0000omJl`?oF
_<001OoF_<03o`0000[oe[Vm00?o0000onCAa?oTdL@00_oTdL@2o`0000[oi<k100?o0000on[Tb_oZ
i<X01?oZi<X2o`0000GojN7900?o0000onSMb?oXgLP00_oXgLP2o`0000?ohN_H00?o0000oooooooo
ool01_ooool3o`0001Oooooo00?o0000ooooooooool02_ooool002?ooooo0ol0000gooooo`05o`00
0?o=gnKocMoVolgOi_l000001?o<i>P00ol0003ob^W/ol[Yk002ol[Yk003o`000?o6k^ooa^k_00;o
00001?oLk=d3o`0000CofO7Q00Co0000om?fiOoCm^GodoKU0_l00003on3Od`03o`000?oNiMWog^GI
00Oog^GI00?o0000omS@dOoHd=402?oHd=43o`000003omGFfOl0003obkk>00;obkk>0ol00004oaao
i`;o00003_mbSn02o`0001?oViG=00?o0000ok2Oa_n`WlH01?l0000?ok>M`P03o`000?o4Zl7oa:_1
00Ooa:_10ol00009olJY_@03o`000?oF_<3oe[c000Woe[c00_l00007omJi_@03o`000?oTdLCoi=74
00Goi=7400?o0000onC>`OoTc/401ooTc/400ol0003oj^C:on[TbP05on[TbP;o00001OoYhLT01_l0
003oj=g8onSMb?l0003oh_3Ho`0000?ohN_H00?o0000ooooooooool00oooool3o`0001[ooooo00?o
0000ooooooooool02_ooool002?ooooo00?o0000ooooooooool0=oooool01Ol0003ocMoVolgOi_o=
gnKo000000Coc>CX00?o0000ol[Yk?o:jN`00_o:jN`3o`000003omgWf_l0003og>cM00?o00000_oL
k=d00ol0003ofO7QomWah@03omWah@03o`000?oCm^Go000000Koh=oC0_l00006omkUf@03o`000?oJ
bl_of/_;00;o00002_oHd=400ol0003obkk>ol^ncP03ol^ncP03o`000?l0K=Oo000000;o00000_lL
OnL00ol0003oH8kVof2>iP03o`0000[oLXoP00?o0000oiBGdonDUm<01?l0000=oi^Ec@03o`000?n`
WlKo/9o600Co/9o61Ol00009ok>M`P03o`000?o4Zl7oa:_100_oa:_11?l00005olJY_@03o`000?oF
_<3oe[c000_oe[c00_l00004omJi_@03o`000?oTdLCoi=7400Ooi=7400?o0000onC>`OoTc/401OoT
c/400ol0003oj^S<o`000006on[TbP03o`000?oYhLWo000000CojN7900?o0000onSMb?l000000_oR
l=P01Ol0003ohN_Hon7[f?oQjmSo000000;ooooo0ol0000Mooooo`03o`000?oooooooooo00[ooooo
00001Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000
o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0>?ooool01Ol0003ocMoVolgOi_o=gnKo0000
00Coc>CX00Co0000ol[Yk?o:jNcob^W/0_l00002omgWfP?o00001OoLk=d00ol0003ofO7QomWah@04
omWah@;o00002?oPgm<2o`0000?og^GI00?o0000om[;booJbl/00ooJbl/3o`0000Oof=3A00?o0000
olfjaoo=^/L00ol00002ol^ncP03o`000?l0K=Oo06cG00;o000000?o77oWo`000?mPS^H00omPS^H4
o`0000KoLXoP00?o0000oiBGdonDUm<01?nDUm<4o`0000WoViG=00?o0000ok2Oa_n`WlH02On`WlH4
o`0000Go/ig200?o0000olB[`Oo4Zl403oo4Zl43o`0000;oaZVm00?o0000omJl`?oF_<003OoF_<03
o`000003omJi_Ol0003oi=7400Woi=740_l00004onC>`@05o`000?oZj<coj^S<on[Xc?l000001_oZ
i<X2o`0000CojN790_l00003on;`f004o`000?oQjmSohN_Hon7[f0?o00008?ooool00ol0003ooooo
ooooo`0:ooooo`0000GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0hooooo`05
o`000?o=gnKocMoVolgOi_l000001?o<i>P4o`000004omkRf?l0003o0000o`0000;ogNOJ00?o0000
omc/gOoLk=d01?oLk=d00ol0003ofO7QomWah@02omWah@04o`000?oQf/oohM[?o`0000Woh=oC00?o
0000omkUfOl000002OoJbl/2o`0000Cof=3A00?o0000olfjaoo=^/L01?o=^/L6o`000004o`1/eol0
003o0000o`0000OoH8kV0ol00004og:?h003o`000?nDUm?oU9OC00OoU9OC1?l00005oi^Ec@03o`00
0?n`WlKo/9o600go/9o61?l000000oncWL;o0000olB[`@0ColB[`@?o00004_oF_<02o`0000coi=74
00Go0000onC>`OoTc/7oi<k1o`000003on[Xc003o`000?oZi<[oj^C:00Coj^C:00?o0000onWQbOl0
00000_oYhLT00ol0003ohOCIo`000003on;`f005o`000?oQjmSohN_Hon7[f?l000008oooool00ol0
003oooooooooo`09ooooo`0000Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Wooooo00?o0000ooooooooool00_ooool2o`0003Sooooo00?o0000olgOi_o=gnH00_o=gnH01?l0
003oc>CXolcTj?o<i>P2o`0000;og^;H0_l000000ooNh]So0000omgWfP03omgWfP03o`000?oLk=go
g>cM00?og>cM00Go0000omWahOoIlN7ofO7Qo`000004on7Jc`03o`000?oPgm?oh=oC00Ooh=oC00?o
0000om[;booJbl/02_oJbl/2o`000003omS@dOl0003ocK[700[ocK[71?l00002o`1/e`03o`000?mP
S^KoH8kV00OoH8kV0ol000000ombSn3o0000oiBGd`0<oiBGd`Co000000?oViG=o`000?n`WlH04_n`
WlH2o`0001Goa:_100?o0000omFoaOl000000_l0000?omJl`004o`000?oSeLSo0000o`0000_oi=74
00?o0000onC>`Ol000001OoZj<`00ol0003oj^C:on[TbP04on[TbP04o`000?oYhLWo0000o`0000;o
hOCI00Go0000on;`f?oRl=Soh_3Ho`000003on7[f003o`000?oooooooooo027ooooo00?o0000oooo
ooooool02Oooool00005o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=oooool00ol0003ocMoVolgOiP02olgO
iPCo000000CogMkFo`000?l0003o00000ooNh]P00ol0003ogNOJomgWfP03omgWfP03o`000?oLk=go
g>cM00?og>cM00?o0000omWahOl000001_oQf/l2o`0000Ooh=oC00Co0000om[7a_l0003o00002ooJ
bl/00ol0003ocK[7olfja`0=olfja`Co00000_m4R>X3o`0000OoH8kV0_l0000AoiBGd`;o00005?n`
WlH00ol0003o`Zk6ol:^aP04o`0000koa:_100?o0000omFoaOoE_lD00ooE_lD3o`0000_oe[c000?o
0000on?Eb?oSeLP00_oSeLP00ol0003oi=74onCAa009onCAa003o`000?oZj<coj^S<00Goj^S<00?o
0000on[Tb_oZi<X00ooZi<X01?l0003ojN79o`000?l00002on7df@05o`000?oRl=Soh_3Hon;`f?l0
00000ooQjmP00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00001Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0=oooool00ol0003ocMoVolgOiP03o`000006omgNe_l0003o0000
o`000?oMg]Ko00001OoNh]P00ol0003ogNOJomgWfP02omgWfP03o`000?oLk=gog>cM00?og>cM0ol0
0008on7Jc`03o`000?oPgm?oh=oC00?oh=oC00?o0000om[7a_oJalH00_oJalH2o`0000Wof/_;00?o
0000oljf`_o>]/801?l0000:olfja`Co00001?m4R>X3o`0000GoH8kV00?o0000ohVHg?n9V=`00ol0
000=oiBGd`03o`000?n/X/go[:;=00Co00003On`WlH00ol0003o`Zk6ol:^aP05ol:^aPCo00002_o4
Zl400ol0003oeKo5omFoa@06omFoa@;o00002?oF_<000ol0003ohmG8on?Eb004on?Eb0;o00002OoT
dL@00ol0003oj^S<on[Xc006on[Xc003o`000?oZi<[oj^C:00;oj^C:0_l000001OoQm=Wo0000on7d
fOoQm=Wo000000?oh_3H00Go0000on7[f?oQjmSohN_Ho`00000Sooooo`03o`000?oooooooooo00Wo
oooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Oooooo0ol000001?oLf]Go0000o`000?l00004omgN
eP03o`000?oNh]Sog^;H00?og^;H00?o0000omgWf_oMimX00ooMimX00ol0003og>cMomc/g@02o`00
00?ohMK<00?o0000on7JcooQf/l01_oQf/l01Ol0003oh=oCon3OdooPgm?o000000Oof/O60_l00006
om[;b`03o`000?o>]/;oc[K200Goc[K20ol00006olfja`04o`000?o0ZL?o`:W3ol2Y``;o00001_m4
R>X3o`0000;oH8kV00?o0000ohVHg?n9V=`00on9V=`4o`0000WoU9OC00?o0000ojbRcOn/X/d01?n/
X/d4o`0000Wo/9o600?o0000ol:^a_o2[/H02Oo2[/H3o`0000Koa:_100?o0000omFoaOoE_lD02OoE
_lD3o`0000Goe[c000?o0000on?Eb?oSeLP01_oSeLP2o`0000Koi=7400?o0000onS]d?l000001ooZ
j<`01ol0003oj^C:on[Tb_oZi<[o0000omkif_l000000_oQm=T00ol0003ohOCIo`000003on;`f005
o`000?oQjmSohN_Hon7[f?l000008oooool00ol0003oooooooooo`09ooooo`0000GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`06
ooooo`;o0000>?ooool4o`0000;og=[E00?o0000omgNe_oMg]H00_oMg]H00ol0003og^;HomkRf004
omkRf003o`000?oMim[ogNOJ00;ogNOJ00?o0000omc/gOl000001_oQe/`00ol0003ohM[?on7Jc`06
on7Jc`03o`000?oPgm?o000000[of/O60_l00003om[;b`03o`000?o>]/;oc[K200Woc[K21?l00002
olfja`03o`000?o0ZL?o`:W300;o`:W300CoG@00o`000?l0003o00001_m4R>X4o`0000SoRISL1?l0
0004oiBGd`03o`000?n/X/go[:;=00Wo[:;=0ol00006ok2OaP03o`000?o2[/Ko`Zk600co`Zk61?l0
0002olB[`@03o`000?oE_lGoeKo500coeKo50ol000000ooF_<3o0000on?Eb00:on?Eb003o`000?oT
dLCoi=7400;oi=7400Go0000onS]d?oXkM3oj>g@o`000007on[Xc003o`000?oZi<[o000000;og_WJ
00Co0000on7dfOoQm=WohOCI0_l00003on;`f005o`000?oQjmSohN_Hon7[f?l000008oooool00ol0
003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Cooooo0_l0000gooooo`Co00001?oLf]D00ol0003ogMkFomgNeP03
omgNeP03o`000?oNh]Sog^;H00?og^;H00?o0000omgWf_oMimX00ooMimX2o`0000OohMK<0_l00007
on7Jc`;o00003?oJalH2o`000003om[;bol0003oc[K200koc[K20_l00007ol2Y``;o000000?o7GcV
o`000?l000001_m4R>X00ol0003oRISLohVHg00:ohVHg0?o000000?oU9OCo`000?n/X/d03On/X/d4
o`000003ok2Oa_l0003o`Zk601;o`Zk60_l0000BomFoa@;o00003?oSeLP2o`000003onCAa?l0003o
j>g@00Coj>g@00?o0000on[Xc?oZj<`01?oZj<`2o`0000?og_WJ00Co0000on7dfOoQm=WohOCI0_l0
0003on;`f005o`000?oQjmSohN_Hon7[f?l000008oooool00ol0003oooooooooo`09ooooo`008Ooo
ool00ol0003oooooooooo`0cooooo`?o00000oooool00ol0003og=[EomcJe@03omcJe@03o`000?oM
g]KogMkF00;ogMkF00?o0000omkRf?oNh]P00ooNh]P00ol0003ogNOJomgWfP02omgWfP04o`000?oQ
d/WohM;9o`0000SohMK<00?o0000on7JcooQf/l00ooQf/l00ol0003of/?3om[3``02o`0000cof/O6
00?o0000oljf`_o>]/803oo>]/800ol0003o`ZNnol:W_P03o`0000Co`:W30_l000001?lMO>Ko0000
o`000?l00003odB8jP03o`000?miVNGo000000;o00002on9V=`2o`0001;o[:;=0_l0000Dol:^aP03
o`000?oC`l_o000000;o00003_oE_lD01?l0003oh][>o`000?l0000<on?Eb003o`000?oXkM3oj>g@
00Coj>g@00?o0000on[Xc?oZj<`00ooZj<`00ol0003ofOcJo`000003omkifP04o`000?oQm=WohOCI
on7df@;o00000ooRl=P01Ol0003ohN_Hon7[f?oQjmSo000002Cooooo00?o0000ooooooooool02?oo
ool0027ooooo00?o0000ooooooooool0<?ooool3o`0000Kooooo00?o0000omcJeOoLf]D00ooLf]D0
0ol0003ogMkFomgNeP03omgNeP03o`000?oNh]Sog^;H00?og^;H00Co0000omgWf_oMim[o00001?oQ
d/T00ol0003ohMK<on7Fc006on7Fc005o`000?oQf/oohM[?on7Jcol000001OoJ`l<2o`0000[of/O6
00?o0000olnc__o?/kh00ol0000;oljf`P03o`000?o2Ykko`ZNn00Co`ZNn0ol00002ol2Y``05o`00
0?l0IM;o0000o`000?lMO>H00_l00002odB8jP04o`000?miVNGoNIWUogVIi@?o00002On9V=`00ol0
003oYJGFojFUeP04o`0000go[:;=00?o0000oknbcOno//d00ol0000>ol:^aP03o`000?oC`l_odl?;
00?odl?;0ol0000:omFoa@03o`000?oRf/koh][>00;oh][>0_l0000:on?Eb003o`000?oXkM3oj>g@
00Goj>g@00Go0000on[Xc?oZj<coj^S<o`000002omWlfP05o`000?oNnM[og_WJomkif_l000000ooQ
m=T00ol0003oh_3Ho`000002on;`f003o`000?oQjmSohN_H00;o00009?ooool00ol0003ooooooooo
o`08ooooo`008Oooool2o`0002kooooo0ol0000:ooooo`03o`000?oLf]Gog=[E00;og=[E00?o0000
omgNe_oMg]H00ooMg]H00ol0003og^;HomkRf003omkRf003o`000?oMim[o000000KohM;900?o0000
on7Fc?oQe/`01_oQe/`00ol0003ohM[?o`000008om[3``?o00001_oJalH00ol0003ock>nolnc_P04
olnc_P?o00002?o>]/800ol0003o`ZNnol:W_P07ol:W_PCo00000_l0IM86o`0000KoNIWU0ol00006
ohVHg003o`000?nUYMKoYJGF00CoYJGF1?l00009ojbRc@03o`000?no//go_k;=00?o_k;=1?l0000:
ol:^aP03o`000?oC`l_odl?;00Kodl?;0_l00008omFoa@03o`000?oRf/koh][>00Coh][>0_l00007
on?Eb003o`000?oUl]Co000000Ooj>g@00?o0000on[Xc?l000000ooIo=X01Ol0003og_WJomkif_oN
nM[o000000?ohOCI00Go0000on;`f?oRl=So0000on;`f003o`000003olc]jol0003ooooo02?ooooo
00?o0000ooooooooool02?ooool0027ooooo00?o0000ooooooooool0:_ooool3o`0000gooooo00?o
0000omcJeOoLf]D00ooLf]D00ol0003ogMkFomgNeP02omgNeP03o`000?oNh]Sog^;H00?og^;H0ol0
0007on7Bb@03o`000?oQe/cohMK<00KohMK<0_l0000;om[3``;o00000ooJalH00ol0003ock>nolnc
_P08olnc_P?o00001?o>]/800ol0003o`ZNnol:W_P0;ol:W_PCo00000_l0IM82o`000003oaeli_l0
003oNIWU00OoNIWU0ol00003ohVHg003o`000?nUYMKoYJGF00SoYJGF0ol00005ojbRc@03o`000?no
//go_k;=00So_k;=1?l00005ol:^aP03o`000?oC`l_odl?;00Wodl?;0ol00004omFoa@03o`000?oR
f/koh][>00Ooh][>0_l00004on?Eb005o`000?oUl]CoiO;DonGbe?l000001ooXkM000ol0003ofOcJ
omWlfP02omWlfP05o`000?oNnM[og_WJomkif_l000000ooQm=T01?l0003oh_3Hon;`f?oRl=P2o`00
00;oc>g[00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`008Oooool00ol0003o
ooooooooo`0Wooooo`?o00004?ooool00ol0003og=[EomcJe@03omcJe@03o`000?oMg]KogMkF00?o
gMkF00Go0000omkRf?oNh]Sog^;Ho`000003on3?b003o`000?oQd/WohM;900GohM;900?o0000on7F
c?oQe/`01OoQe/`01?l0003of/70o`000?l0000;om[3``;o000000?of/O6o`000?o?/kh03?o?/kh3
o`000003oljf`_l0003o`ZNn00oo`ZNn00?o04F]o`000?l000000_l0IM82o`0000;oH9O]0_l00007
ogVIi@Co00003OnUYMH4o`000003ojbRcOl0003o_k;=00go_k;=0ol00002ol:^aP03o`000?oC`l_o
dl?;00codl?;0ol000000ooE_lGo0000on;JcP0:on;JcP;o000000?ohmG8o`000?oUl]@01?oUl]@0
0ol0003oj>g@onS]d003onS]d0;o00001?oIo=X01Ol0003og_WJomkif_oNnM[o000000?ohOCI1_l0
0002olc]j`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool0023ooooo00?o0000
ooooooooool09Oooool3o`0001Cooooo00?o0000omcJeOoLf]D00ooLf]D00ol0003ogMkFomgNeP02
omgNeP04o`000?oNh]Sog^;Ho`0000Goh<o800?o0000on7BbOoQd/T01OoQd/T00ol0003ohMK<on7F
c003on7Fc003o`000?oJ`L3of/7000;of/700_l0000;om[3``03o`000?o?/kkock>n00oock>n00?o
0000ol:W__o2Ykh04?o2Ykh01?l0003o]9^oo`000?l00002o`1UdP03o`000?mPUngoH9O]00;oH9O]
0ol00006ogVIi@03o`000?nUYMKoYJGF00ooYJGF0_l0000Aoknbc@;o00004_oC`l/2o`0000goh][>
00?o0000onGbe?oUl]@01OoUl]@01ol0003oj>g@onS]d?oXkM3o0000olonfol000001?oIo=X01Ol0
003og_WJomkif_oNnM[o000000;ohOCI0_l00003olWbk@;o000000?oc>g[o`000?ooool09Oooool0
0ol0003oooooooooo`08ooooo`008?ooool00ol0003oooooooooo`0Rooooo`?o00005oooool00ol0
003og=[EomcJe@03omcJe@03o`000?oMg]KogMkF00;ogMkF00?o0000omkRf?l000001ooPclP00ol0
003ohM;9on7Bb@05on7Bb@05o`000?oQe/cohMK<on7Fc?l000001ooJ`L02o`0000Wof/?300?o0000
olna_?o?/K`00ol0000<olnc_P03o`000?o3YK_o`jFk00Co00002oo2Ykh01?l0003o]9^ookBK_ond
Vkl2o`000004o`1Ud_l0003o=hg^o`0000GoH9O]0ol00003ogVIi@03o`000?nJZN3oVZWP00?o0000
3OnUYMH00ol0003o^[OFokZgeP03o`0000go_k;=00?o0000om38doo@b=<00ol0000=om?3b`03o`00
0?oOgmGo000000;o00002?oRf/h01?l0003ogoOIomogfOl00007onGbe003o`000?oXkM3o000000;o
cokK00?o0000omWlf_oIo=X00_oIo=X01?l0003og_WJomkif_oNnMX3o`000003ol?fk_l0003obO;]
00;obO;]00Co0000olc]jol0003o00009_ooool00ol0003oooooooooo`08ooooo`008?ooool2o`00
027ooooo0_l0000Jooooo`03o`000?oLf]Gog=[E00Cog=[E00Co0000omgNe_oMg]KogMkF0ol00008
on3?b003o`000?oQd/WohM;900GohM;900?o0000on7Fc?l000002_oJ`L02o`0000Kof/?300?o0000
olna_?o?/K`01?o?/K`3o`0000Sock>n00?o0000ol>U^oo3YK/01Oo3YK/5o`0000Ko`ZNn00?o0000
okBK_ondVkl00ondVkl3o`0000?o=hg^0_l00004of2Gk@Co00001OnJZN04o`0000SoYJGF00?o0000
okZge_nj]mH01?nj]mH4o`0000So_k;=00?o0000om38doo@b=<01?o@b=<3o`0000Wodl?;00?o0000
omoOeOoOgmD00ooOgmD2o`0000Goh][>00?o0000omogfOoOmmT00_oOmmT00ol0003oiO;DonGbe005
onGbe005o`000?o?o]_ocokKolonfol000001?oIo=X00ol0003og_WJomkifP02o`0000;o`oK^00Go
0000olWbkOo9l^gobO;]o`000003olc]j`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1oooool0023ooooo00?o0000ooooooooool07Oooool3o`0001gooooo00?o0000omcJeOoLf]D00ooL
f]D01?l0003ogMkFomgNe_l00003omk=a`03o`000?oPclSoh<o800Koh<o800?o0000on7BbOoQd/T0
1OoQd/T2o`0000cof/700_l00003om[3``03o`000?o?/Kcock6l00Sock6l0ol00005olnc_P03o`00
0?o3YK_o`jFk00[o`jFk1?l00002ol:W_P03o`000?ndVkoo]9^o00Co]9^o0_l00005ocN=kP;o0000
1OmPUnd00ol0003oVZWPoiZYh007oiZYh0?o00001OnUYMH00ol0003o^[OFokZgeP08okZgeP?o0000
1Ono//d00ol0003od<SCom38d`07om38d`?o00001OoC`l/00ol0003ogmoEomoOe@06omoOe@?o0000
00?oh][>o`000?oOmmT01OoOmmT01?l0003oiO;DonGbe?oUl]@2o`000003ol;nf_l0003ocokK00;o
cokK00?o0000omWlf_oIo=X00_oIo=X3o`000005ok[hk_l0003o`oK^ol?fk_l000000oo9l^d00ol0
003oc>g[olc]j`02o`0002Oooooo00?o0000ooooooooool01oooool0023ooooo00?o0000oooooooo
ool06_ooool3o`00023ooooo00?o0000omcJeOoLf]D00ooLf]D00ol0003ogMkFo`000005omk=a`03
o`000?oPclSoh<o800Koh<o800?o0000on7BbOoQd/T01?oQd/T01?l0003of[nno`000?l0000<om[1
`0;o000000?of/?3o`000?o?/K`03?o?/K`3o`0000;ock>n00?o0000ol>U^oo3YK/03_o3YK/2o`00
00Wo]9^o0_l00005ocN=kP?o00000_mPUnd00ol0003oR:_/o`000002o`0000SoVZWP0ol00002ojFU
eP03o`000?nj]mKo^[OF00_o^[OF0ol00002oknbc@03o`000?o@b=?od<SC00[od<SC0ol000000ooC
`l_o0000omoOe@0;omoOe@;o00001ooOmmT00ol0003oiO;Do`000003ol;nfP05o`000?o?o]_ocokK
olonfol000000ooIo=X2o`0000;o^_S^00Co0000ol?fk_o3m^ko00000oo9l^d01ol0003oc>g[olc]
joo<kN_o0000ooooool000009_ooool00ol0003oooooooooo`07ooooo`008?ooool3o`0001Oooooo
0ol0000Sooooo`03o`000?oLf]Gog=[E00?og=[E0_l00007omk=a`03o`000?oPclSoh<o800Koh<o8
00?o0000on7BbOoQd/T00_oQd/T00ol0003of[nnomZo_P02omZo_P;o00003?oJ`L02o`00013ock6l
0_l0000Bol>U^`03o`000?nfV[co]YZl00Go00000ondVkl2o`000004o`1eg?l0003o0000o`0000?o
=hg^0ol00004ohR[k0?o00002?nJZN02o`00017o^[OF0_l0000@om38d`03o`000?oOgmGogmoE00[o
gmoE00Co0000omKkg_oFnmko00001ooOmmT00ol0003o`_kJol;nfP02ol;nfP04o`000?o?o]_ocokK
olonf`Co000000CoZoO[o`000?njn>ko00000oo3m^h01Ol0003obO;]olWbkOo9l^go000000;oc>g[
00Go0000ooooooooooooooooo`00000Uooooo`03o`000?oooooooooo00Oooooo000Oooooo`;o0000
5_ooool3o`0002Oooooo00Oo0000omcJeOoLf]Gog=[Eo`000?oMblOo000000Sog/g700?o0000on3?
b?oPclP01_oPclP01?l0003ohM;9on7BbOl00007omZo_P;o00002_oJ`L000ol0003ock2jo`000002
o`0000kock6l00?o0000ol>T^Oo3Y;T00ol0000=ol>U^`03o`000?nfV[co]YZl00Go]YZl2?l00000
0ol0MMco0000o`000003ocN=kP03o`000?n8ZncoR:_/00GoR:_/0_l00007oiZYh003o`000?na_>;o
/KcR00Co00003?nj]mH00ol0003ob/oMol[?g@03o`0000[od<SC00Co0000om[Vg_oJi]kof^KN0ol0
0006omoOe@03o`000?oFnmkoe__N00;oe__N0_l00003omogf@03o`000?n]n]Oo000000Co`_kJ00?o
0000olonfoo?o]/00_l00003oj_gj`04o`000?njn>ko^_S^o`0000;o`oK^00Go0000olWbkOo9l^go
bO;]o`000003olc]j`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`07ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`?o0000:_ooool01?l0
003og=[EomcJeOl00003omg;a`03o`000?oNcLOog/g700Kog/g700?o0000on3?b?oPclP01_oPclP0
0ol0003ohM;9o`000009omZo_P03o`000?oJ`L3of/7000Kof/7000?o0000oln`^_o?/;X00oo?/;X3
o`0000[ock6l00?o0000ol>T^Oo3Y;T01?o3Y;T4o`0000Wo`jFk00?o0000okJJ_?nfV[`02_nfV[`5
o`000003o`1eg?l0003o000000;o000000?oJJWfo`000?l000001_n8Zn`3o`0000CoVZWP00?o0000
ok6lh_na_>801?na_>84o`0000Oo^[OF00?o0000ol[?gOo:cmd01?o:cmd3o`0000Kod<SC00?o0000
om[Vg_oJi]h01OoJi]h3o`0000;ogmoE00?o0000omKkg_oFnmh01OoFnmh00ol0003ogoOIo`000002
ojgje`03o`000?o2o][o`_kJ00;o`_kJ1?l00003oj_gj`04o`000?njn>ko^_S^o`0000?o`oK^00Go
0000olWbkOo9l^gobO;]o`000002olc]j`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`07ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool3o`0002gooooo
00?o0000omcJeOl000001OoMblL00ol0003og/g7omk=a`06omk=a`03o`000?oPclSoh<o800Koh<o8
0_l0000:omZo_P;o00001_oJ`L000ol0003ock2joln`^P06oln`^P?o00001oo?/K`00ol0003o`jBi
ol>T^@08ol>T^@Co00001?o3YK/00ol0003o]YZlokJJ_00@okJJ_0;o00000_l0MM`00ol0003oJJWf
ofVYmP02ofVYmP?o00001On8Zn`4o`0000_o/KcR1?l00002okZgeP03o`000?o:cmgob/oM00Sob/oM
0ol00002om38d`03o`000?oJi]kof^KN00Wof^KN0ol00008omKkgP05o`000?n]n]Oo[O[Gojgjeol0
00000_o2o]X3o`000003oiKaiOl0003oZoO[00;oZoO[00Co0000ok[hk_njn>ko00000oo3m^h01Ol0
003obO;]olWbkOo9l^go000000?oc>g[00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Oooooo0004ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0ol0000aooooo`03o`000?oMblOo
gL_700GogL_700?o0000omk=aooNcLL01_oNcLL00ol0003oh<o8on3?b005on3?b004o`000?oI_Kgo
0000o`0000[of[nn0_l00003om[1`003o`000?o?/;[ock2j00[ock2j0ol00004olna_003o`000?o3
Y;Wo`jBi00co`jBi0ol000000oo3YK_o0000okJJ_00BokJJ_0Co000000?o<i[bo`000?mYZOH01?mY
ZOH3o`0000GoR:_/00?o0000ok6lh_na_>803Ona_>82o`0000kob/oM0_l0000<om[VgP03o`000?o4
oN?oa?gS00;o00000ooFnmh2o`000003oho^c_l0003o[O[G00;o[O[G1?l00002oiKai@05o`000?n[
mn_oZoO[oj_gjol000000_njn>h00ol0003o`oK^ol?fkP02ol?fkP05o`000?o9l^gobO;]olWbkOl0
00000oo<kN/00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01_ooool000Cooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0_l0000:ooooo`?o0000=?ooool00ol0003ogL_7omg;a`06omg;a`03o`000?oNcLOog/g700Ko
g/g700?o0000on3?b?oPclP00ooPclP00ol0003ofKfmomVm_@02omVm_@03o`000?oJ_kkof[nn00Wo
f[nn0_l000000ooJ`L3o0000oln`^P0>oln`^PCo00004_o3Y;T2o`0001?o]YZl00Co0000ojNC`Ol0
003o00001?lcV_83o`0000?oJJWf0ol000000on8Znco0000oj;1k`02oj;1k`?o00002ona_>800ol0
003o`=KZol3FjP05o`0000Oob/oM00Co0000om3]j?o@kNSod>gX0ol00006om[VgP03o`000?o4oN?o
a?gS00?oa?gS00?o0000omKkg_l000000on?k/h3o`0000;oNNGJ0_l00002oiKai@05o`000?n[mn_o
ZoO[oj_gjol000000onjn>h01Ol0003o`oK^ol?fk_o3m^ko000000?obO;]00Go0000olc]joo<kN_o
c>g[o`000009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool000Cooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`06ooooo`?o0000>?ooool00ol0003ogL_7omg;a`06omg;a`03o`000?oNcLOog/g7
00Kog/g700Go0000on3?b?oPclSoh<o8o`000006omVm_@;o00002ooJ_kh2o`0001;ock2j00?o0000
ol>T^Oo3Y;T04Oo3Y;T01?l0003o]iVjokNI^_ngVKX5o`0000_o]YZl00Ko0000ojNC`OnWTl7oYi?1
oeP00?l00005oc>JlP;o00001?mYZOH00ol0003oX/7_oj;1k`05oj;1k`Co00001_na_>800ol0003o
`=KZol3FjP06ol3FjPCo00000_o:cmd00ol0003od>gXom3]j005om3]j0?o00000_oJi]h00ol0003o
a?gSolCmh`05olCmh`03o`000?n?k/koSnk>00;oSnk>00Go0000ogWUf_miiM[oNNGJo`000003oiKa
i@05o`000?n[mn_oZoO[oj_gjol000000onjn>h00ol0003o`oK^ol?fkP02ol?fkP05o`000?o9l^go
bO;]olWbkOl000000oo<kN/00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01_ooool000Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool3o`0003cooooo00?o0000omg;aooMblL01_oM
blL00ol0003og/g7omk=a`06omk=a`03o`000?oPclSo000000WofKfm0_l00009omZo_P03o`000?o?
[[So000000;o00003oo?/;X00ol0003oa:>golBS]`04o`0000go`jBi00?o0000okNI^_ngVKX01_ng
VKX5o`0000Ko]YZl00?o0000ojNC`OnWTl401?nWTl401?mH003o0000o`000?l00002oc>JlP?o0000
00CoJJWfo`000?n4`_coQ<;l0_l00007oj;1k`?o00000_na_>800ol0003o`=KZol3FjP0;ol3FjP;o
00002oo@kNP5o`0000;oa?gS0_l000000omYf[oo0000o`00000Po`0000_ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo00?o0000omg;
aooMblL01OoMblL00ol0003og/g7omk=a`07omk=a`;o00002ooI_Kd00ol0003of[nnomZo_P05omZo
_P03o`000?o?[[Socjjh00?ocjjh0_l0000=oln`^P03o`000?o4XkOoa:>g00Coa:>g1?l00009ol>T
^@03o`000?ngVK[o]iVj00_o]iVj1Ol000000onfV[co0000ojNC`@08ojNC`@Co000000?o<i[bo`00
0?l000001_n4`_`3o`0000KoX/7_0_l0000=ol3FjP03o`000?nllO;o_?7b00;o_?7b1?l00002om3]
j0?o00001OnXn><2o`000003ofWJ_ol0003o000000;o00000_mEbO83o`0000;oL]Kl0_l00003ohWK
o`05o`000?nJgOgoV]gmoi[MoOl000001?nUfoX00ol0003o[MWfojgImP02ojgImP05o`000?nbeO;o
/]Gbok;El_l000003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo0004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo1?l00014ooooo`03o`000?oM
blOogL_700GogL_700?o0000omk=aooNcLL01_oNcLL00ol0003of;bmo`00000;omVm_@;o00001OoJ
_kh00ol0003ocjjholn^^005oln^^0?o00002Oo?/;X00ol0003oa:>golBS]`09olBS]`?o00001Oo3
Y;T00ol0003o]iVjokNI^P0AokNI^POo00001_nWTl43o`0000CoC[Cj0_l00005ohC2o0?o00000_nR
`Nl00ol0003o[M_gojgKm`03ojgKm`Ko00000oo0e^X00ol0003o_?7bokcalP07okcalP;o00001?nX
n><6o`0000GoELWb0_l00002og;Fo0?o00000on9fol2o`0000?oV]gm00?o0000ojGKn_nUfoX00_nU
foX00ol0003o[MWfojgImP02ojgImP05o`000?nbeO;o/]Gbok;El_l000003oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Kooooo000Nooooo`;o0000Aoooool00ol0003ogL_7omg;
a`05omg;a`03o`000?oNcLOog/g700Cog/g700Co0000omRl_OoH_;gof;bm0_l0000;omVm_@;o0000
0_oJ_kh00ol0003ocjjholn^^009oln^^0?o00001_o?/;X00ol0003oa:>golBS]`0<olBS]`Co0000
00?o`jBio`000?ngVKX04ongVKX00ol0003oZI>nojVC_P03ojVC_PWo000000?oYi?1o`2;e_m>]?X0
1?m>]?X3o`0000CoQ<;l0_l0000<ojgKm`?o00002?nllO82o`0000CoONKH00?o0000ofN^nOmW[_T0
1?mW[_T2o`000004oeG9l_l0003o0000o`0000;oL]Kl0_l00004ohWKo`;o00000onJgOd2o`0000Co
YM_j00?o0000ojgIm_n]fOH00_n]fOH01Ol0003o/]Gbok;El_nbeO;o0000013ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`008?ooool00ol0003oooooooooo`15ooooo`03
o`000?oMblOogL_700GogL_700?o0000omk=aooNcLL00_oNcLL00ol0003of;bmomRl_@04omRl_@;o
00002ooI_Kd00ol0003of[nno`00000>oln^^0;o00001?o?/;X00ol0003oa:>golBS]`0@olBS]`;o
00005?ngVKX00ol0003oZI>nojVC_P0<ojVC_PGo000000?o08_Fo`000?m>]?X00_m>]?X3o`000003
ohC2o?l0003oR=Wo00?oR=Wo1Ol00003ojgKm`;o00001_nIkOH4o`000004oggVf?l0003o0000o`00
00CoIjki2_l000000ombe_co0000o`000005ohWKo`03o`000?nJgOgoV]gm00;oV]gm00?o0000ojGK
n_nUfoX00onUfoX00ol0003o[MWfojgImP02ojgImP05o`000?nbeO;o/]Gbok;El_l000004_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo
04Gooooo00?o0000omg;aooMblL01OoMblL01Ol0003og/g7omk=aooNcLOo000000Sof;bm00?o0000
omVm_OoI_Kd02OoI_Kd2o`00013ocjjh1?l0000DolBS]`04o`000?nhVKSo^9VhokRI^0Go00003?ng
VKX00ol0003oZI>nojVC_P0@ojVC_P03o`000?nKTLSoVi7800Go000000?oC[Cjo`000?n8fOl02On8
fOl3o`0000SoVNgf0_l00003od?4`0Oo00002?mi/OH4o`0000CoRM_o0_l00004oi[Mo@03o`000?nU
fo[oYM_j00;oYM_j0_l00004ojgImP05o`000?nbeO;o/]Gbok;El_l000005?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Gooooo000Rooooo`03o`000?oooooooooo04Cooooo00?o
0000omg;aooMblL01_oMblL00ol0003og/g7o`00000:omRl_@;o00002OoI_Kd00ol0003ocjjho`00
0002o`00013ocjjh00?o0000olBS]oo4XkL04_o4XkL00ol0003o^9VhokRI^006okRI^0Go00001_ng
VKX00ol0003oZI>nojVC_P0AojVC_P03o`000?nKTLSoVi7800GoVi780_l00002o`28_P03o`000?m6
_o3oA[o`00Go00001omNe>L4o`000005od?4`?n;VM_oRiWKoh^Ifol000002omi/OH4o`0000CoQk?b
0_l000000on9fooo0000oi[Mo@03oi[Mo@;o00001?nUfoX00ol0003o[MWfojgImP03ojgImP05o`00
0?nbeO;o/]Gbok;El_l000005_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Go
oooo000Sooooo`;o0000AOooool00ol0003ogL_7omg;a`06omg;a`;o00003?oH_;d00ol0003ofKfm
omVm_@05omVm_@03o`000?o?[[Socjjh00?ocjjh0_l0000>oln^^003o`000?o4X[Koa::f00Co0000
3_o4XkL00ol0003o^9VhokRI^00;okRI^0Go000000?o]iVjo`000?nYTkh04_nYTkh00ol0003oVi78
oi^Ab00@oi^Ab003o`000?n;VM_oRiWK00koRiWK00?o0000ogVam_mi/OH01Omi/OH3o`0000SoQk?b
1?l00003oi[Mo@03o`000?nUfo[oYM_j00?oYM_j00?o0000ojgIm_n]fOH00on]fOH01Ol0003o/]Gb
ok;El_nbeO;o000001Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`00
9Oooool00ol0003oooooooooo`13ooooo`03o`000?oMblOogL_700GogL_700?o0000omNk_Ol00000
3?oH_;d2o`0000GofKfm00?o0000oln^^?o?[[P01Oo?[[P2o`0000cocjjh00?o0000olBR]_o4X[H0
1?o4X[H4o`0000Woa:>g00?o0000okRI^?nhVKP04OnhVKP7o`0000ooZI>n00?o0000oi^Ab?nKTLP0
4?nKTLP00ol0003oRiWKoh^If`0>oh^If`03o`000?mi/OKoNK7f00Co00002?n7/o83o`0000CoTK?^
00?o0000oi[MoOl000001OnUfoX00ol0003o[MWfojgImP03ojgImP05o`000?nbeO;o/]Gbok;El_l0
00006Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo000Vooooo`03o`00
0?oooooooooo04?ooooo00?o0000omg;aooMblL00ooMblL01?l0003oek^momNk_OoG^kd2o`0000co
f;bm0_l00002omVm_@03o`000?o?[[Socjjh00Socjjh0ol00008oln^^003o`000?o4X[Koa::f00Wo
a::f1?l00005olBS]`03o`000?nhVKSo^9Vh01;o^9Vh00?o0000ojbB_?n/T[`00on/T[`;o`0000Co
ZI>n00?o0000oi^Ab?nKTLP04?nKTLP00ol0003oRiWKoh^If`07oh^If`[o00002On7/o83o`0000Oo
TK?^0ol00004ojGKnP03o`000?n]fOKo[MWf00?o[MWf00Go0000ok;El_nbeO;o/]Gbo`00000Koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01Oooool002Oooooo00?o0000oooooooo
ool0@oooool01Ol0003ogL_7omg;aooMblOo000000Koek^m00?o0000omRl_OoH_;d02ooH_;d00ol0
003ofKfmo`00000=oln^^0;o00001_o?[[P00ol0003oa::folBR]P0=olBR]PCo000000?oa:>go`00
0?nhVKP04onhVKP00ol0003o[9:lojbB_00>ojbB_27o00002OnAVMP00ol0003oQk?bohNclP04ohNc
lP?o00002?nA/nh2o`0000?oV;?Z0_l000000onUfo[o0000ojgImP04ojgImP05o`000?nbeO;o/]Gb
ok;El_l000007?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Xoooo
o`;o0000A?ooool00ol0003ogL_7o`000008omNk_@;o00003?oH_;d2o`0000oocjjh0_l00004oln^
^003o`000?o4X[Koa::f017oa::f0_l00003okRI^003o`000?nhVKSo^9Vh00ko^9Vh00?o0000ojbB
_?n/T[`04_n/T[`00ol0003oWY76oijAaP0AoijAaP03o`000?nAVMSoTIWH013oTIWH00?o0000ohNc
l_n7/o800ol00008oi6ckP?o00001_nH/nX3o`0000Co[MWf00Go0000ok;El_nbeO;o/]Gbo`00000N
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000oooo
ooooool0@_ooool2o`0000[oek^m0_l0000:omRl_@03o`000?o?[KSo000000;o00003_o?[[P4o`00
01Goa::f00?o0000okVI]oniVKL00_niVKL7o`0000Wo^9Vh00?o0000ojbB_?n/T[`04_n/T[`00ol0
003oWY76oijAaP0AoijAaP03o`000?nAVMSoTIWH00koTIWH1Ol00009oi6ckP;o00001onH/nX2o`00
00?oW[?V0_l000000on]fOKo0000ok;ElP02ok;ElP03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`04ooooo`00:oooool00ol0003oooooooooo`13ooooo`03
o`000?oG^kgoek^m00Woek^m00?o0000omRl_OoH_;d01_oH_;d00ol0003ocjfholn]^003oln]^0;o
00003oo?[[P3o`0001?oa::f00?o0000okVI]oniVKL02OniVKL7o`0000;o^9Vh00?o0000ojbB_?n/
T[`04_n/T[`00ol0003oWY76oijAaP0BoijAaP03o`000?nAVMSoTIWH00KoTIWH1ol00003oiNJe003
o`000?nA/nkoTK?^00KoTK?^0_l00007oiRcjP;o00001_nN/nH4o`000003ok;El_l0003ooooo027o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`00;?ooool00ol0003ooooo
ooooo`13ooooo`;o00002_oG^kd2o`0000Kof;bm00?o0000oln]^?o?[KP01Oo?[KP2o`0000gocjjh
00?o0000olBR]_o4X[H01?l0000?olBR]P03o`000?niVKOo^IVg013o^IVg2Ol0000?ojbB_003o`00
0?nNTLKoWY76017oWY7600?o0000oi6If?nAVMP01_l0000;oiNJe003o`000?nA/nkoTK?^00;oTK?^
0ol00007oiRcjP;o00001_nN/nH2o`0000?oXk?S0_l0000Sooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01?ooool002gooooo0_l00015ooooo`03o`000?oG^kgoek^m00Woek^m00?o
0000omRl_OoH_;d00_oH_;d00ol0003ocjfholn]^008oln]^0?o00002Oo?[[P00ol0003oa::folBR
]P05olBR]PGo00002Oo4X[H00ol0003o^IVgokVI]`0CokVI]`03o`000?n]Tk_o[I>k00Co[I>k2ol0
0004ojbB_003o`000?nNTLKoWY7600OoWY763Ol0000BoiNJe004o`000?nA/nko0000o`0000OoV;?Z
0ol00006oijciP;o00001?nS/n<00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01?ooool002oooooo00?o0000ooooooooool0@oooool00ol0003oek^momNk
_@09omNk_@;o00000_oH_;d00ol0003ocjfholn]^00;oln]^0;o00001oo?[[P00ol0003oa::folBR
]P0:olBR]PCo00001Oo4X[H00ol0003o^IVgokVI]`0CokVI]`03o`000?n]Tk_o[I>k00oo[I>k3_l0
000:oj6Ba003o`000?nGV]CoUi[D017oUi[D0ol00007oiRcjP;o00001onN/nH2o`0000CoXk?S0_l0
000Xooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0033ooooo00?o0000
ooooooooool0@oooool2o`0000_oek^m00?o0000omRl_Ol000003oo?[KP2o`0000Cocjjh00?o0000
olBR]_o4X[H03oo4X[H4o`000003olBR]_l0003o^IVg01Co^IVg00?o0000ojfC^on]Tk/04on]Tk/0
0ol0003oXI;4oj6Ba00Boj6Ba003o`000?nGV]CoUi[D00_oUi[D1Ol00003oi^JdP03o`000?nH/n[o
V;?Z00;oV;?Z0_l00007oijciP;o00001?nS/n<2o`0002_ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`00<Oooool2o`0004Gooooo00?o0000omNk_OoG^kd02OoG^kd2o`00
017ocjfh0ol000000oo?[[So0000olBR]P0DolBR]P;o00000_niVKL2o`00017o^IVg00?o0000ojfC
^on]Tk/04on]Tk/00ol0003oXI;4oj6Ba00Boj6Ba003o`000?nGV]CoUi[D00KoUi[D1Ol00009oi^J
dP04o`000?nH/n[o0000o`0000OoW[?V0_l00005oj>ch`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`00<oooool00ol0003oooooooooo`13oooo
o`;o00002OoG^kd00ol0003ocZfho`000002o`00017ocjfh0ol0000EolBR]P03o`000?niVKKo^IVf
00;o^IVf1ol0000:okVI]`03o`000?n]Tk_o[I>k01?o[I>k00?o0000oj6Ba?nQT/@04_nQT/@01?l0
003oUi[DoiNJe?nGV]@5o`0000goVi[B0ol00007oijciP;o00001OnS/n<2o`0002oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?ooool00ol0003oooooooooo`14oooo
o`03o`000?oG^kgoek^m00Goek^m00?o0000olj]^?o>[KP00oo>[KP2o`0000oocjfh00?o0000olBR
]_o4X[H01?l0000AolBR]P03o`000?niVKKo^IVf00Wo^IVf1ol00003okVI]`03o`000?n]Tk_o[I>k
01Co[I>k00?o0000oj6Ba?nQT/@03OnQT/@8o`0000ooVi[B0ol00003oijLd@03o`000?nN/nKoW[?V
00;oW[?V0_l00006oj>ch`03o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`03ooooo`00=Oooool00ol0003oooooooooo`14ooooo`03o`000?oG^kgoek^m00?o
ek^m00?o0000olj]^?o>[KP01_o>[KP3o`0000cocjfh00?o0000olBR]_o4X[H01?o4X[H4o`0000go
a::f00?o0000okVI]_niVKH04?niVKH@o`0000[o[I>k00?o0000oj6Ba?nQT/@00_nQT/@;o`0000Go
Y9;300?o0000oi^Jd_nKV]802onKV]84o`0000OoWYcA00Co0000oijci_l0003o00001_nS/n<2o`00
03Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00=_ooool2o`0004Go
oooo0_l00003omNk_@03o`000?o>[KSocZfh00WocZfh0_l00009oln]^003o`000?o4X[Koa::f00Wo
a::f0ol00009olBR]P03o`000?niVKKo^IVf01Co^IVf00?o0000ojjC^_n^TkX02_n^TkX?o`00017o
Y9;300?o0000oi^Jd_nKV]801onKV]83o`0000[oWYcA0ol00007oj>ch`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003ooooo
ooooo`14ooooo`03o`000?oG^kgo000000kocZfh0ol00006oln]^003o`000?o4X[Koa::f00coa::f
1?l00005olBR]P03o`000?niVKKo^IVf01Co^IVf00?o0000ojjC^_n^TkX05?n^TkX00ol0003oY9;3
ojBB``0CojBB``03o`000?nKV];oVi[B00?oVi[B1?l0000:oijLd@?o00000_nRWM000ol0003oXk?S
oj>ch`03oj>ch`;o0000>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
000iooooo`03o`000?oooooooooo04Cooooo0_l0000Aolj]^0;o00001?o?[KP00ol0003oa::folBR
]P0@olBR]PCo000000?oa::fo`000?niVKH05OniVKH00ol0003o[Y>jojjC^P0DojjC^P03o`000?nT
T/?oY9;301?oY9;300?o0000oi^Jd_nKV]800ol0000;oijLd@?o00001_nRWM000ol0003oXk?Soj>c
h`02o`0003_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00>_ooool0
0ol0003oooooooooo`15ooooo`?o00004?o>[KP4o`0001Ooa::f0_l00002okVI]PCo00004?niVKH0
0ol0003o[Y>jojjC^P0EojjC^P03o`000?nTT/?oY9;300koY9;31ol0000;oijLd@?o00002OnRWM00
0ol0003oXk?So`00000nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
03_ooooo0_l00018ooooo`;o00004Oo>[KP3o`0001Koa::f00?o0000okZI]_njVKH01?njVKH;o`00
00Go^IVf00?o0000ojjC^_n^TkX05On^TkX00ol0003oY9;3ojBB``03ojBB``_o00001OnVTl800ol0
003oWYcAoijLd@07oijLd@?o00003?nRWM02o`0003oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`00?Oooool00ol0003oooooooooo`17ooooo`?o00003_o>[KP00ol0003o
a::folBR]P04o`0001;oa::f00?o0000okZI]_njVKH03onjVKHSo`00017oYY?200?o0000oijLdOnN
W=400onNW=43o`0000coXYg@0ol00012ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool003kooooo00?o0000ooooooooool0BOooool2o`0000cocZfh00?o0000olBR]_o4X[H0
1?o4X[H4o`0000goa::f00?o0000okZI]_njVKH05OnjVKH00ol0003o/9Bjok2D^P0Eok2D^P03o`00
0?nVTl;oYY?201CoYY?200?o0000oijLdOnNW=400ol0000<oj:Md0?o0000A_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000oooooo`03o`000?oooooooooo04[ooooo0_l0
0009olj]^003o`000?o4X[Koa::f00Woa::f0ol0000:olBR]P03o`000?njVKKo^YVf01Go^YVf00?o
0000ok2D^_n`U;X05On`U;X00ol0003oYY?2ojJC`P0BojJC`PGo00003?nRWM03o`0004[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@?ooool2o`0004cooooo0ol00006
olj]^003o`000?o4X[Koa::f00coa::f1?l00006olBR]P03o`000?njVKKo^YVf01Go^YVf00?o0000
ok2D^_n`U;X05On`U;X00ol0003oYY?2ojJC`P0<ojJC`PKo00000onXUL800ol0003oXYg@oj:Md009
oj:Md0;o0000COooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0012oooo
o`03o`000?oooooooooo04cooooo0_l00004olj]^003o`000?o4X[Koa::f013oa::f1?l000000oo4
X[Ko0000okZI]P0GokZI]P03o`000?n`U;[o/9Bj01Ko/9Bj00?o0000ojJC`_nVTl801_nVTl85o`00
00[oZ9G200?o0000oj:Md?nRWM001OnRWM03o`00053ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`00@oooool00ol0003oooooooooo`1=ooooo`Co00005oo4X[H2o`0000;o
^YVf1?l0000BokZI]P03o`000?n`U;[o/9Bj01Ko/9Bj00?o0000ojJC`_nVTl801_l0000?ojRE`P03
o`000?nRWM3oXYg@00;oXYg@0ol0001Dooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00Oooool004Cooooo00?o0000ooooooooool0Coooool3o`0001Koa::f00?o0000okZJ]onjV[L0
1?njV[L=o`0000Go^YVf00?o0000ok2D^_n`U;X02_n`U;X?o`0001GoZ9G200?o0000oj:Md?l00000
0_l0001Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool004Gooooo0_l0
001Booooo`Go00004Oo4X[H00ol0003o^YZgokZJ]`0AokZJ]a;o00003?naUKX00ol0003oZ9G2ojRE
`P0DojRE`P?o0000Foooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo0017
ooooo`03o`000?oooooooooo05Cooooo1Ol0000<olBR]P03o`000?njV[Oo^YZg01Ko^YZg00?o0000
ok6E^_naUKX05_naUKX00ol0003oZ9G2ojRE`P0?ojRE`PGo0000Goooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo05Sooooo1Ol00006olBR
]P03o`000?njV[Oo^YZg01Oo^YZg00?o0000ok6E^_naUKX05_naUKX00ol0003oZ9G2ojRE`P0:ojRE
`PGo0000IOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0019ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool00_ooool5o`000003olBR]_l0003o^YZg01So
^YZg00?o0000ok6E^_naUKX05onaUKX00ol0003oZ9G2ojRE`P04ojRE`PGo0000Joooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000Eoooool00ol0003ooooo
ooooo`07ooooo`;o00000_njV[L2o`0001Go^YZg00?o0000ok6E^_naUKX05onaUKX00ol0003oZ9G2
o`000004o`00073ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00C?oo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00gooooo2Ol0000<okZJ]`03o`000?na
UK[o/IFj017o/IFj2?l0001fooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001=
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool05_ooool9o`0000?o^YZg00?o0000
ok6E^_naUKX01?naUKX=o`0007oooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0
04kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Oooooo`[o0000S?ooool00ol0
003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Coooool2o`0005;ooooo00?o0000oooooooo
ool0]_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00DOooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool005;ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2hooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo001Cooooo`;o0000C_ooool00ol0003oooooooooo`2h
ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001Eooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`04ooooo`7o00000Oooool005Ko
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`00Eoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo0;_ooooo
00?o0000ooooooooool00_ooool1o`00007ooooo001Hooooo`;o0000BOooool00ol0003ooooooooo
o`2kooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F_ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo0;cooooo00Go0000ooooooooooooooooo`000001ooooo`00Foooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo00000Ooo
ool005cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooo
0000007ooooo001Mooooo`;o0000A?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo
007o0000001Oooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0_oooool1o`00007o
oooo0Ol00000063ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`30ooooo`;o0000
001Qooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0_oooool3o`000000H_ooool2
o`0003oooooo00?o0000ooooooooool0^oooool4o`0000?ooooo001Tooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0]oooool4o`0000Oooooo001Uooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0/oooool4o`0000_ooooo001Vooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool0/?ooool3o`0000oooooo001Wooooo`;o0000>_ooool00ol0003ooooooooo
o`2/ooooo`Co00004_ooool006Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2X
ooooo`Co00005_ooool006[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2Toooo
o`Co00006_ooool006_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2Qooooo`Co
00007_ooool006cooooo0_l0000dooooo`03o`000?oooooooooo09gooooo1?l0000Rooooo`00K_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Wooooo1?l0000Vooooo`00Koooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo09Gooooo1?l0000Zooooo`00L?ooool2o`00
033ooooo00?o0000ooooooooool0TOooool4o`0002kooooo001booooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0S_ooool3o`0003;ooooo001cooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0R_ooool4o`0003Gooooo001dooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Q_ooool4o`0003Wooooo001eooooo`;o0000:oooool00ol0003oooooooooo`22
ooooo`Co0000?Oooool007Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1noooo
o`Co0000@Oooool007Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1jooooo`Co
0000AOooool007Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1fooooo`Co0000
BOooool007[ooooo0_l0000Vooooo`03o`000?oooooooooo07;ooooo1?l0001=ooooo`00O?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06oooooo0ol0001Aooooo`00OOooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo06_ooooo1?l0001Dooooo`00O_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo06Oooooo1?l0001Hooooo`00Ooooool2o`00027ooooo
00?o0000ooooooooool0Hoooool4o`0005cooooo0021ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool0Goooool4o`00063ooooo0022ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0Foooool4o`0006Cooooo0023ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Eoooool4o`0006Sooooo0024ooooo`;o00007?ooool00ol0003oooooooooo`1Cooooo`Co
0000K?ooool008Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000
L?ooool008Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1<ooooo`?o0000M?oo
ool008Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`18ooooo`Co0000Moooool0
08Wooooo0_l0000Gooooo`03o`000?oooooooooo04Cooooo1?l0001kooooo`00Roooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo043ooooo1?l0001oooooo`00S?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03cooooo1?l00023ooooo`00SOooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo03Sooooo1?l00027ooooo`00S_ooool2o`0001;ooooo00?o0000
ooooooooool0=?ooool4o`0008_ooooo002@ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0<Oooool4o`0008oooooo002Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0;_ooool3o`0009?ooooo002Booooo`;o00003Oooool00ol0003oooooooooo`0Zooooo`Co0000
U_ooool009Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`Co0000V_oo
ool009Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000W_ooool0
09Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000X_ooool009Oo
oooo0_l00008ooooo`03o`000?oooooooooo01[ooooo1?l0002Vooooo`00VOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Kooooo1?l0002Zooooo`00V_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01;ooooo1?l0002^ooooo`00Voooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00kooooo1?l0002booooo`00W?ooool2o`0000?ooooo00?o0000oooo
ooooool02oooool3o`000;Kooooo002Nooooo`04o`000?ooooooooooo`0000Wooooo1?l0002ioooo
o`00Woooool00ol0003oooooo`000005ooooo`Co0000_Oooool00:3ooooo0_l000000ooooooo0000
o`000002o`000<7ooooo002Qooooo`;o0000aOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886123, -0.0135596, \
0.00362392, 0.00362392}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03005 .28245 -24 -2.73552 ]
[.03005 .28245 0 6.26448 ]
[.02108 .33866 -30 -2.78346 ]
[.02108 .33866 0 6.21654 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00211 .45754 -24 -2.88544 ]
[.00211 .45754 0 6.11456 ]
[-0.00793 .52047 -18 -2.93973 ]
[-0.00793 .52047 0 6.06027 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04227 .27766 m
.04839 .27527 L
s
[(-0.5)] .03005 .28245 1 -0.39211 Mshowa
.03335 .33398 m
.03948 .33164 L
s
[(-0.25)] .02108 .33866 1 -0.38145 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.01447 .45311 m
.02065 .45089 L
s
[(0.25)] .00211 .45754 1 -0.35879 Mshowa
.00448 .51617 m
.01068 .51402 L
s
[(0.5)] -0.00793 .52047 1 -0.34673 Mshowa
.125 Mabswid
.04052 .28876 m
.04418 .28733 L
s
.03874 .29994 m
.04242 .29852 L
s
.03696 .31121 m
.04063 .30979 L
s
.03516 .32255 m
.03884 .32114 L
s
.03152 .3455 m
.03521 .3441 L
s
.02969 .3571 m
.03337 .35571 L
s
.02783 .36879 m
.03152 .3674 L
s
.02597 .38056 m
.02966 .37919 L
s
.02219 .40438 m
.02589 .40302 L
s
.02028 .41642 m
.02398 .41507 L
s
.01836 .42856 m
.02206 .42721 L
s
.01642 .44079 m
.02013 .43945 L
s
.0125 .46553 m
.01621 .46421 L
s
.01052 .47804 m
.01423 .47673 L
s
.00852 .49065 m
.01224 .48935 L
s
.00651 .50336 m
.01023 .50206 L
s
.04402 .26664 m
.04768 .2652 L
s
.04575 .2557 m
.04942 .25425 L
s
.00243 .52908 m
.00616 .5278 L
s
.00037 .54209 m
.0041 .54082 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.51727 .64087 m .51694 .65827 L .43899 .65168 L p .728 .618 .735 r
F P
0 g
s
.51694 .65827 m .51727 .64087 L .59247 .63953 L p .692 .614 .764 r
F P
0 g
s
.59247 .63953 m .59527 .65394 L .51694 .65827 L p .692 .614 .764 r
F P
0 g
s
.43899 .65168 m .44255 .63234 L .51727 .64087 L p .728 .618 .735 r
F P
0 g
s
.5176 .62321 m .51727 .64087 L .44255 .63234 L p .724 .613 .733 r
F P
0 g
s
.51727 .64087 m .5176 .62321 L .58966 .6249 L p .685 .607 .763 r
F P
0 g
s
.58966 .6249 m .59247 .63953 L .51727 .64087 L p .685 .607 .763 r
F P
0 g
s
.44255 .63234 m .44613 .61274 L .5176 .62321 L p .724 .613 .733 r
F P
0 g
s
.51794 .60552 m .5176 .62321 L .44613 .61274 L p .719 .609 .733 r
F P
0 g
s
.5176 .62321 m .51794 .60552 L .58684 .61023 L p .676 .602 .764 r
F P
0 g
s
.58684 .61023 m .58966 .6249 L .5176 .62321 L p .676 .602 .764 r
F P
0 g
s
.59527 .65394 m .59247 .63953 L .66453 .62829 L p .664 .641 .818 r
F P
0 g
s
.66453 .62829 m .67023 .63881 L .59527 .65394 L p .664 .641 .818 r
F P
0 g
s
.44613 .61274 m .4497 .59313 L .51794 .60552 L p .719 .609 .733 r
F P
0 g
s
.51827 .58803 m .51794 .60552 L .4497 .59313 L p .713 .606 .736 r
F P
0 g
s
.51794 .60552 m .51827 .58803 L .58401 .59568 L p .666 .597 .768 r
F P
0 g
s
.58401 .59568 m .58684 .61023 L .51794 .60552 L p .666 .597 .768 r
F P
0 g
s
.44255 .63234 m .43899 .65168 L .36521 .63435 L p .766 .641 .723 r
F P
0 g
s
.4497 .59313 m .45326 .57379 L .51827 .58803 L p .713 .606 .736 r
F P
0 g
s
.5186 .57096 m .51827 .58803 L .45326 .57379 L p .706 .603 .74 r
F P
0 g
s
.51827 .58803 m .5186 .57096 L .58117 .58142 L p .655 .593 .773 r
F P
0 g
s
.58117 .58142 m .58401 .59568 L .51827 .58803 L p .655 .593 .773 r
F P
0 g
s
.36521 .63435 m .37195 .61427 L .44255 .63234 L p .766 .641 .723 r
F P
0 g
s
.44613 .61274 m .44255 .63234 L .37195 .61427 L p .765 .638 .721 r
F P
0 g
s
.59247 .63953 m .58966 .6249 L .65879 .61763 L p .651 .634 .82 r
F P
0 g
s
.65879 .61763 m .66453 .62829 L .59247 .63953 L p .651 .634 .82 r
F P
0 g
s
.37195 .61427 m .3787 .59393 L .44613 .61274 L p .765 .638 .721 r
F P
0 g
s
.4497 .59313 m .44613 .61274 L .3787 .59393 L p .762 .635 .721 r
F P
0 g
s
.3787 .59393 m .38543 .57362 L .4497 .59313 L p .762 .635 .721 r
F P
0 g
s
.45326 .57379 m .4497 .59313 L .38543 .57362 L p .759 .634 .722 r
F P
0 g
s
.38543 .57362 m .39215 .55365 L .45326 .57379 L p .759 .634 .722 r
F P
0 g
s
.45682 .55499 m .45326 .57379 L .39215 .55365 L p .754 .633 .726 r
F P
0 g
s
.45326 .57379 m .45682 .55499 L .5186 .57096 L p .706 .603 .74 r
F P
0 g
s
.51894 .55452 m .5186 .57096 L .45682 .55499 L p .697 .602 .746 r
F P
0 g
s
.5186 .57096 m .51894 .55452 L .57833 .5676 L p .641 .589 .781 r
F P
0 g
s
.57833 .5676 m .58117 .58142 L .5186 .57096 L p .641 .589 .781 r
F P
0 g
s
.39215 .55365 m .39884 .5343 L .45682 .55499 L p .754 .633 .726 r
F P
0 g
s
.46037 .53698 m .45682 .55499 L .39884 .5343 L p .749 .633 .732 r
F P
0 g
s
.45682 .55499 m .46037 .53698 L .51894 .55452 L p .697 .602 .746 r
F P
0 g
s
.58966 .6249 m .58684 .61023 L .65303 .60692 L p .637 .628 .824 r
F P
0 g
s
.65303 .60692 m .65879 .61763 L .58966 .6249 L p .637 .628 .824 r
F P
0 g
s
.39884 .5343 m .40549 .51584 L .46037 .53698 L p .749 .633 .732 r
F P
0 g
s
.4639 .52 m .46037 .53698 L .40549 .51584 L p .741 .634 .741 r
F P
0 g
s
.46037 .53698 m .4639 .52 L .51927 .53892 L p .686 .601 .755 r
F P
0 g
s
.51927 .53892 m .51894 .55452 L .46037 .53698 L p .686 .601 .755 r
F P
0 g
s
.51894 .55452 m .51927 .53892 L .57549 .55437 L p .623 .586 .791 r
F P
0 g
s
.57549 .55437 m .57833 .5676 L .51894 .55452 L p .623 .586 .791 r
F P
0 g
s
.40549 .51584 m .4121 .49854 L .4639 .52 L p .741 .634 .741 r
F P
0 g
s
.46742 .50424 m .4639 .52 L .4121 .49854 L p .731 .636 .752 r
F P
0 g
s
.4639 .52 m .46742 .50424 L .5196 .52433 L p .672 .6 .767 r
F P
0 g
s
.5196 .52433 m .51927 .53892 L .4639 .52 L p .672 .6 .767 r
F P
0 g
s
.58684 .61023 m .58401 .59568 L .64724 .59626 L p .62 .622 .831 r
F P
0 g
s
.64724 .59626 m .65303 .60692 L .58684 .61023 L p .62 .622 .831 r
F P
0 g
s
.51927 .53892 m .5196 .52433 L .57265 .54188 L p .601 .582 .804 r
F P
0 g
s
.57265 .54188 m .57549 .55437 L .51927 .53892 L p .601 .582 .804 r
F P
0 g
s
.4121 .49854 m .41867 .48263 L .46742 .50424 L p .731 .636 .752 r
F P
0 g
s
.47092 .48992 m .46742 .50424 L .41867 .48263 L p .718 .638 .767 r
F P
0 g
s
.46742 .50424 m .47092 .48992 L .51993 .51092 L p .654 .6 .782 r
F P
0 g
s
.51993 .51092 m .5196 .52433 L .46742 .50424 L p .654 .6 .782 r
F P
0 g
s
.58401 .59568 m .58117 .58142 L .64143 .58574 L p .599 .615 .839 r
F P
0 g
s
.64143 .58574 m .64724 .59626 L .58401 .59568 L p .599 .615 .839 r
F P
0 g
s
.5196 .52433 m .51993 .51092 L .56981 .53025 L p .573 .578 .821 r
F P
0 g
s
.56981 .53025 m .57265 .54188 L .5196 .52433 L p .573 .578 .821 r
F P
0 g
s
.41867 .48263 m .4252 .4683 L .47092 .48992 L p .718 .638 .767 r
F P
0 g
s
.47441 .47718 m .47092 .48992 L .4252 .4683 L p .7 .641 .787 r
F P
0 g
s
.47092 .48992 m .47441 .47718 L .52027 .49882 L p .63 .6 .801 r
F P
0 g
s
.52027 .49882 m .51993 .51092 L .47092 .48992 L p .63 .6 .801 r
F P
0 g
s
.58117 .58142 m .57833 .5676 L .6356 .57546 L p .573 .609 .85 r
F P
0 g
s
.6356 .57546 m .64143 .58574 L .58117 .58142 L p .573 .609 .85 r
F P
0 g
s
.67023 .63881 m .66453 .62829 L .72972 .60742 L p .654 .726 .902 r
F P
0 g
s
.72972 .60742 m .73799 .61332 L .67023 .63881 L p .654 .726 .902 r
F P
0 g
s
.34762 .5098 m .3571 .49209 L .40549 .51584 L p .798 .68 .734 r
F P
0 g
s
.40549 .51584 m .39884 .5343 L .34762 .5098 L p .798 .68 .734 r
F P
0 g
s
.4121 .49854 m .40549 .51584 L .3571 .49209 L p .793 .683 .743 r
F P
0 g
s
.33807 .52846 m .34762 .5098 L .39884 .5343 L p .802 .678 .727 r
F P
0 g
s
.39884 .5343 m .39215 .55365 L .33807 .52846 L p .802 .678 .727 r
F P
0 g
s
.3571 .49209 m .36651 .4756 L .4121 .49854 L p .793 .683 .743 r
F P
0 g
s
.41867 .48263 m .4121 .49854 L .36651 .4756 L p .785 .687 .756 r
F P
0 g
s
.32846 .54779 m .33807 .52846 L .39215 .55365 L p .804 .676 .723 r
F P
0 g
s
.39215 .55365 m .38543 .57362 L .32846 .54779 L p .804 .676 .723 r
F P
0 g
s
.51993 .51092 m .52027 .49882 L .56696 .51957 L p .535 .572 .84 r
F P
0 g
s
.56696 .51957 m .56981 .53025 L .51993 .51092 L p .535 .572 .84 r
F P
0 g
s
.4252 .4683 m .43169 .45573 L .47441 .47718 L p .7 .641 .787 r
F P
0 g
s
.47789 .46616 m .47441 .47718 L .43169 .45573 L p .675 .644 .811 r
F P
0 g
s
.47441 .47718 m .47789 .46616 L .5206 .48816 L p .596 .598 .824 r
F P
0 g
s
.5206 .48816 m .52027 .49882 L .47441 .47718 L p .596 .598 .824 r
F P
0 g
s
.3188 .56749 m .32846 .54779 L .38543 .57362 L p .806 .676 .721 r
F P
0 g
s
.38543 .57362 m .3787 .59393 L .3188 .56749 L p .806 .676 .721 r
F P
0 g
s
.36651 .4756 m .37585 .46054 L .41867 .48263 L p .785 .687 .756 r
F P
0 g
s
.4252 .4683 m .41867 .48263 L .37585 .46054 L p .775 .692 .772 r
F P
0 g
s
.30912 .58727 m .3188 .56749 L .3787 .59393 L p .806 .677 .721 r
F P
0 g
s
.3787 .59393 m .37195 .61427 L .30912 .58727 L p .806 .677 .721 r
F P
0 g
s
.57833 .5676 m .57549 .55437 L .62975 .5655 L p .541 .601 .863 r
F P
0 g
s
.62975 .5655 m .6356 .57546 L .57833 .5676 L p .541 .601 .863 r
F P
0 g
s
.29943 .6068 m .30912 .58727 L .37195 .61427 L p .806 .678 .723 r
F P
0 g
s
.37195 .61427 m .36521 .63435 L .29943 .6068 L p .806 .678 .723 r
F P
0 g
s
.66453 .62829 m .65879 .61763 L .72141 .60147 L p .633 .723 .912 r
F P
0 g
s
.72141 .60147 m .72972 .60742 L .66453 .62829 L p .633 .723 .912 r
F P
0 g
s
.37585 .46054 m .38511 .44714 L .4252 .4683 L p .775 .692 .772 r
F P
0 g
s
.43169 .45573 m .4252 .4683 L .38511 .44714 L p .759 .698 .794 r
F P
0 g
s
.52027 .49882 m .5206 .48816 L .56411 .50995 L p .483 .563 .861 r
F P
0 g
s
.56411 .50995 m .56696 .51957 L .52027 .49882 L p .483 .563 .861 r
F P
0 g
s
.43169 .45573 m .43816 .44506 L .47789 .46616 L p .675 .644 .811 r
F P
0 g
s
.48137 .45696 m .47789 .46616 L .43816 .44506 L p .638 .645 .841 r
F P
0 g
s
.47789 .46616 m .48137 .45696 L .52093 .47901 L p .548 .593 .851 r
F P
0 g
s
.52093 .47901 m .5206 .48816 L .47789 .46616 L p .548 .593 .851 r
F P
0 g
s
.57549 .55437 m .57265 .54188 L .62388 .55594 L p .501 .591 .877 r
F P
0 g
s
.62388 .55594 m .62975 .5655 L .57549 .55437 L p .501 .591 .877 r
F P
0 g
s
.38511 .44714 m .3943 .43556 L .43169 .45573 L p .759 .698 .794 r
F P
0 g
s
.43816 .44506 m .43169 .45573 L .3943 .43556 L p .737 .705 .821 r
F P
0 g
s
.65879 .61763 m .65303 .60692 L .71304 .59549 L p .607 .718 .923 r
F P
0 g
s
.71304 .59549 m .72141 .60147 L .65879 .61763 L p .607 .718 .923 r
F P
0 g
s
.57265 .54188 m .56981 .53025 L .618 .54686 L p .448 .578 .891 r
F P
0 g
s
.618 .54686 m .62388 .55594 L .57265 .54188 L p .448 .578 .891 r
F P
0 g
s
.3943 .43556 m .40344 .42595 L .43816 .44506 L p .737 .705 .821 r
F P
0 g
s
.4446 .4364 m .43816 .44506 L .40344 .42595 L p .703 .711 .855 r
F P
0 g
s
.43816 .44506 m .4446 .4364 L .48137 .45696 L p .638 .645 .841 r
F P
0 g
s
.5206 .48816 m .52093 .47901 L .56125 .50144 L p .411 .546 .881 r
F P
0 g
s
.56125 .50144 m .56411 .50995 L .5206 .48816 L p .411 .546 .881 r
F P
0 g
s
.65303 .60692 m .64724 .59626 L .70463 .58948 L p .574 .712 .936 r
F P
0 g
s
.70463 .58948 m .71304 .59549 L .65303 .60692 L p .574 .712 .936 r
F P
0 g
s
.48485 .44964 m .48137 .45696 L .4446 .4364 L p .582 .643 .876 r
F P
0 g
s
.48137 .45696 m .48485 .44964 L .52126 .47144 L p .478 .582 .88 r
F P
0 g
s
.52126 .47144 m .52093 .47901 L .48137 .45696 L p .478 .582 .88 r
F P
0 g
s
.56981 .53025 m .56696 .51957 L .61209 .53832 L p .38 .558 .903 r
F P
0 g
s
.61209 .53832 m .618 .54686 L .56981 .53025 L p .38 .558 .903 r
F P
0 g
s
.40344 .42595 m .41254 .41841 L .4446 .4364 L p .703 .711 .855 r
F P
0 g
s
.45104 .42983 m .4446 .4364 L .41254 .41841 L p .649 .714 .896 r
F P
0 g
s
.4446 .4364 m .45104 .42983 L .48485 .44964 L p .582 .643 .876 r
F P
0 g
s
.64724 .59626 m .64143 .58574 L .69616 .58348 L p .533 .702 .948 r
F P
0 g
s
.69616 .58348 m .70463 .58948 L .64724 .59626 L p .533 .702 .948 r
F P
0 g
s
.52093 .47901 m .52126 .47144 L .55838 .49409 L p .311 .516 .894 r
F P
0 g
s
.55838 .49409 m .56125 .50144 L .52093 .47901 L p .311 .516 .894 r
F P
0 g
s
.48833 .44426 m .48485 .44964 L .45104 .42983 L p .494 .63 .912 r
F P
0 g
s
.48485 .44964 m .48833 .44426 L .52159 .46548 L p .373 .556 .904 r
F P
0 g
s
.52159 .46548 m .52126 .47144 L .48485 .44964 L p .373 .556 .904 r
F P
0 g
s
.32972 .45229 m .34136 .43912 L .37585 .46054 L p .835 .757 .777 r
F P
0 g
s
.37585 .46054 m .36651 .4756 L .32972 .45229 L p .835 .757 .777 r
F P
0 g
s
.38511 .44714 m .37585 .46054 L .34136 .43912 L p .825 .766 .797 r
F P
0 g
s
.31796 .46687 m .32972 .45229 L .36651 .4756 L p .842 .749 .762 r
F P
0 g
s
.36651 .4756 m .3571 .49209 L .31796 .46687 L p .842 .749 .762 r
F P
0 g
s
.64143 .58574 m .6356 .57546 L .68765 .57749 L p .48 .688 .959 r
F P
0 g
s
.68765 .57749 m .69616 .58348 L .64143 .58574 L p .48 .688 .959 r
F P
0 g
s
.34136 .43912 m .3529 .42755 L .38511 .44714 L p .825 .766 .797 r
F P
0 g
s
.3943 .43556 m .38511 .44714 L .3529 .42755 L p .809 .777 .823 r
F P
0 g
s
.3061 .48264 m .31796 .46687 L .3571 .49209 L p .846 .743 .75 r
F P
0 g
s
.3571 .49209 m .34762 .5098 L .3061 .48264 L p .846 .743 .75 r
F P
0 g
s
.56696 .51957 m .56411 .50995 L .60616 .53037 L p .291 .527 .907 r
F P
0 g
s
.60616 .53037 m .61209 .53832 L .56696 .51957 L p .291 .527 .907 r
F P
0 g
s
.29414 .49935 m .3061 .48264 L .34762 .5098 L p .848 .738 .742 r
F P
0 g
s
.34762 .5098 m .33807 .52846 L .29414 .49935 L p .848 .738 .742 r
F P
0 g
s
.41254 .41841 m .42161 .41303 L .45104 .42983 L p .649 .714 .896 r
F P
0 g
s
.45747 .42538 m .45104 .42983 L .42161 .41303 L p .561 .706 .938 r
F P
0 g
s
.45104 .42983 m .45747 .42538 L .48833 .44426 L p .494 .63 .912 r
F P
0 g
s
.3529 .42755 m .36435 .41776 L .3943 .43556 L p .809 .777 .823 r
F P
0 g
s
.40344 .42595 m .3943 .43556 L .36435 .41776 L p .784 .788 .856 r
F P
0 g
s
.28209 .51672 m .29414 .49935 L .33807 .52846 L p .849 .734 .737 r
F P
0 g
s
.33807 .52846 m .32846 .54779 L .28209 .51672 L p .849 .734 .737 r
F P
0 g
s
.6356 .57546 m .62975 .5655 L .67909 .57153 L p .413 .667 .965 r
F P
0 g
s
.67909 .57153 m .68765 .57749 L .6356 .57546 L p .413 .667 .965 r
F P
0 g
s
.36435 .41776 m .37571 .40988 L .40344 .42595 L p .784 .788 .856 r
F P
0 g
s
.41254 .41841 m .40344 .42595 L .37571 .40988 L p .745 .798 .896 r
F P
0 g
s
.52126 .47144 m .52159 .46548 L .5555 .48793 L p .173 .464 .887 r
F P
0 g
s
.5555 .48793 m .55838 .49409 L .52126 .47144 L p .173 .464 .887 r
F P
0 g
s
.26997 .53448 m .28209 .51672 L .32846 .54779 L p .849 .732 .734 r
F P
0 g
s
.32846 .54779 m .3188 .56749 L .26997 .53448 L p .849 .732 .734 r
F P
0 g
s
.73799 .61332 m .72972 .60742 L .78426 .57754 L p .678 .869 .971 r
F P
0 g
s
.78426 .57754 m .79464 .57831 L .73799 .61332 L p .678 .869 .971 r
F P
0 g
s
.56411 .50995 m .56125 .50144 L .6002 .52305 L p .176 .481 .897 r
F P
0 g
s
.6002 .52305 m .60616 .53037 L .56411 .50995 L p .176 .481 .897 r
F P
0 g
s
.49183 .44081 m .48833 .44426 L .45747 .42538 L p .355 .592 .935 r
F P
0 g
s
.48833 .44426 m .49183 .44081 L .52193 .46114 L p .219 .502 .905 r
F P
0 g
s
.52193 .46114 m .52159 .46548 L .48833 .44426 L p .219 .502 .905 r
F P
0 g
s
.25779 .55232 m .26997 .53448 L .3188 .56749 L p .847 .73 .734 r
F P
0 g
s
.3188 .56749 m .30912 .58727 L .25779 .55232 L p .847 .73 .734 r
F P
0 g
s
.37571 .40988 m .387 .40401 L .41254 .41841 L p .745 .798 .896 r
F P
0 g
s
.42161 .41303 m .41254 .41841 L .387 .40401 L p .678 .802 .941 r
F P
0 g
s
.62975 .5655 m .62388 .55594 L .67048 .56561 L p .33 .635 .963 r
F P
0 g
s
.67048 .56561 m .67909 .57153 L .62975 .5655 L p .33 .635 .963 r
F P
0 g
s
.42161 .41303 m .43066 .40984 L .45747 .42538 L p .561 .706 .938 r
F P
0 g
s
.46392 .42306 m .45747 .42538 L .43066 .40984 L p .416 .669 .966 r
F P
0 g
s
.45747 .42538 m .46392 .42306 L .49183 .44081 L p .355 .592 .935 r
F P
0 g
s
.24558 .56996 m .25779 .55232 L .30912 .58727 L p .845 .729 .735 r
F P
0 g
s
.30912 .58727 m .29943 .6068 L .24558 .56996 L p .845 .729 .735 r
F P
0 g
s
.72972 .60742 m .72141 .60147 L .77381 .57683 L p .644 .875 .984 r
F P
0 g
s
.77381 .57683 m .78426 .57754 L .72972 .60742 L p .644 .875 .984 r
F P
0 g
s
.56125 .50144 m .55838 .49409 L .59421 .51638 L p .036 .414 .862 r
F P
0 g
s
.59421 .51638 m .6002 .52305 L .56125 .50144 L p .036 .414 .862 r
F P
0 g
s
.52159 .46548 m .52193 .46114 L .5526 .48295 L p 0 .383 .843 r
F P
0 g
s
.5526 .48295 m .5555 .48793 L .52159 .46548 L p 0 .383 .843 r
F P
0 g
s
.387 .40401 m .39823 .40023 L .42161 .41303 L p .678 .802 .941 r
F P
0 g
s
.43066 .40984 m .42161 .41303 L .39823 .40023 L p .566 .787 .982 r
F P
0 g
s
.62388 .55594 m .618 .54686 L .66182 .55974 L p .227 .589 .947 r
F P
0 g
s
.66182 .55974 m .67048 .56561 L .62388 .55594 L p .227 .589 .947 r
F P
0 g
s
.72141 .60147 m .71304 .59549 L .76329 .57611 L p .597 .874 .993 r
F P
0 g
s
.76329 .57611 m .77381 .57683 L .72141 .60147 L p .597 .874 .993 r
F P
0 g
s
.49535 .43926 m .49183 .44081 L .46392 .42306 L p .148 .507 .911 r
F P
0 g
s
.49183 .44081 m .49535 .43926 L .52227 .45838 L p .012 .406 .855 r
F P
0 g
s
.52227 .45838 m .52193 .46114 L .49183 .44081 L p .012 .406 .855 r
F P
0 g
s
.43066 .40984 m .43973 .40884 L .46392 .42306 L p .416 .669 .966 r
F P
0 g
s
.4704 .42283 m .46392 .42306 L .43973 .40884 L p .194 .576 .94 r
F P
0 g
s
.46392 .42306 m .4704 .42283 L .49535 .43926 L p .148 .507 .911 r
F P
0 g
s
.618 .54686 m .61209 .53832 L .65311 .55395 L p .108 .527 .912 r
F P
0 g
s
.65311 .55395 m .66182 .55974 L .618 .54686 L p .108 .527 .912 r
F P
0 g
s
.39823 .40023 m .40944 .39856 L .43066 .40984 L p .566 .787 .982 r
F P
0 g
s
.43973 .40884 m .43066 .40984 L .40944 .39856 L p .383 .726 .99 r
F P
0 g
s
.55838 .49409 m .5555 .48793 L .58819 .51039 L p 0 .327 .793 r
F P
0 g
s
.58819 .51039 m .59421 .51638 L .55838 .49409 L p 0 .327 .793 r
F P
0 g
s
.71304 .59549 m .70463 .58948 L .75269 .57532 L p .534 .862 .995 r
F P
0 g
s
.75269 .57532 m .76329 .57611 L .71304 .59549 L p .534 .862 .995 r
F P
0 g
s
.52193 .46114 m .52227 .45838 L .54968 .47914 L p 0 .272 .748 r
F P
0 g
s
.54968 .47914 m .5526 .48295 L .52193 .46114 L p 0 .272 .748 r
F P
0 g
s
.61209 .53832 m .60616 .53037 L .64435 .54823 L p 0 .448 .854 r
F P
0 g
s
.64435 .54823 m .65311 .55395 L .61209 .53832 L p 0 .448 .854 r
F P
0 g
s
.70463 .58948 m .69616 .58348 L .74202 .57438 L p .454 .835 .987 r
F P
0 g
s
.74202 .57438 m .75269 .57532 L .70463 .58948 L p .454 .835 .987 r
F P
0 g
s
.31752 .41957 m .33072 .4107 L .3529 .42755 L p .857 .864 .845 r
F P
0 g
s
.3529 .42755 m .34136 .43912 L .31752 .41957 L p .857 .864 .845 r
F P
0 g
s
.36435 .41776 m .3529 .42755 L .33072 .4107 L p .833 .879 .877 r
F P
0 g
s
.49889 .43955 m .49535 .43926 L .4704 .42283 L p 0 .364 .806 r
F P
0 g
s
.49535 .43926 m .49889 .43955 L .52261 .45714 L p 0 .27 .736 r
F P
0 g
s
.52261 .45714 m .52227 .45838 L .49535 .43926 L p 0 .27 .736 r
F P
0 g
s
.33072 .4107 m .34379 .40342 L .36435 .41776 L p .833 .879 .877 r
F P
0 g
s
.37571 .40988 m .36435 .41776 L .34379 .40342 L p .793 .892 .915 r
F P
0 g
s
.3042 .42989 m .31752 .41957 L .34136 .43912 L p .872 .85 .819 r
F P
0 g
s
.34136 .43912 m .32972 .45229 L .3042 .42989 L p .872 .85 .819 r
F P
0 g
s
.40944 .39856 m .42065 .39901 L .43973 .40884 L p .383 .726 .99 r
F P
0 g
s
.44882 .41 m .43973 .40884 L .42065 .39901 L p .123 .59 .919 r
F P
0 g
s
.43973 .40884 m .44882 .41 L .4704 .42283 L p .194 .576 .94 r
F P
0 g
s
.47693 .42463 m .4704 .42283 L .44882 .41 L p 0 .414 .821 r
F P
0 g
s
.4704 .42283 m .47693 .42463 L .49889 .43955 L p 0 .364 .806 r
F P
0 g
s
.5555 .48793 m .5526 .48295 L .58214 .50507 L p 0 .225 .694 r
F P
0 g
s
.58214 .50507 m .58819 .51039 L .5555 .48793 L p 0 .225 .694 r
F P
0 g
s
.34379 .40342 m .35676 .39787 L .37571 .40988 L p .793 .892 .915 r
F P
0 g
s
.387 .40401 m .37571 .40988 L .35676 .39787 L p .727 .898 .956 r
F P
0 g
s
.29074 .4415 m .3042 .42989 L .32972 .45229 L p .88 .838 .799 r
F P
0 g
s
.32972 .45229 m .31796 .46687 L .29074 .4415 L p .88 .838 .799 r
F P
0 g
s
.27715 .45417 m .29074 .4415 L .31796 .46687 L p .885 .827 .784 r
F P
0 g
s
.31796 .46687 m .3061 .48264 L .27715 .45417 L p .885 .827 .784 r
F P
0 g
s
.60616 .53037 m .6002 .52305 L .63553 .54259 L p 0 .356 .773 r
F P
0 g
s
.63553 .54259 m .64435 .54823 L .60616 .53037 L p 0 .356 .773 r
F P
0 g
s
.35676 .39787 m .36964 .39414 L .387 .40401 L p .727 .898 .956 r
F P
0 g
s
.39823 .40023 m .387 .40401 L .36964 .39414 L p .616 .882 .99 r
F P
0 g
s
.69616 .58348 m .68765 .57749 L .73127 .57324 L p .354 .791 .964 r
F P
0 g
s
.73127 .57324 m .74202 .57438 L .69616 .58348 L p .354 .791 .964 r
F P
0 g
s
.52227 .45838 m .52261 .45714 L .54674 .47644 L p 0 .149 .614 r
F P
0 g
s
.54674 .47644 m .54968 .47914 L .54009 .47188 L p 0 .149 .614 r
F P
0 g
s
.54674 .47644 m .54009 .47188 L .53717 .46938 L 0 .149 .614 r
F
.54376 .47479 m .54674 .47644 L .54093 .4718 L p .513 0 0 r
F P
0 g
s
.54093 .4718 m .52261 .45714 L p .53643 .46867 L .513 0 0 r
F P
0 g
s
.54376 .47479 m .54093 .4718 L .53643 .46867 L .513 0 0 r
F
.52261 .45714 m .52295 .45735 L .53047 .46365 L p F P
0 g
s
.53294 .46576 m .52261 .45714 L .53047 .46365 L .513 0 0 r
F
.54009 .47188 m .52227 .45838 L p .53717 .46938 L 0 .149 .614 r
F P
0 g
s
.52295 .45735 m .5233 .45888 L .52711 .46221 L p .606 .054 0 r
F P
0 g
s
.52711 .46221 m .54076 .4741 L p .53093 .46486 L .606 .054 0 r
F P
0 g
s
.53093 .46486 m .52295 .45735 L .52711 .46221 L .606 .054 0 r
F
.53047 .46365 m .54376 .47479 L p .53294 .46576 L .513 0 0 r
F P
0 g
s
.26343 .4677 m .27715 .45417 L .3061 .48264 L p .887 .818 .774 r
F P
0 g
s
.3061 .48264 m .29414 .49935 L .26343 .4677 L p .887 .818 .774 r
F P
0 g
s
.36964 .39414 m .38244 .39228 L .39823 .40023 L p .616 .882 .99 r
F P
0 g
s
.40944 .39856 m .39823 .40023 L .38244 .39228 L p .44 .819 .99 r
F P
0 g
s
.68765 .57749 m .67909 .57153 L .72043 .57182 L p .237 .726 .922 r
F P
0 g
s
.72043 .57182 m .73127 .57324 L .68765 .57749 L p .237 .726 .922 r
F P
0 g
s
.2496 .48183 m .26343 .4677 L .29414 .49935 L p .887 .81 .766 r
F P
0 g
s
.29414 .49935 m .28209 .51672 L .2496 .48183 L p .887 .81 .766 r
F P
0 g
s
.42065 .39901 m .43187 .40154 L .44882 .41 L p .123 .59 .919 r
F P
0 g
s
.45797 .41324 m .44882 .41 L .43187 .40154 L p 0 .393 .758 r
F P
0 g
s
.44882 .41 m .45797 .41324 L .47693 .42463 L p 0 .414 .821 r
F P
0 g
s
.5526 .48295 m .54968 .47914 L .57604 .5004 L p 0 .123 .576 r
F P
0 g
s
.57604 .5004 m .58214 .50507 L .56283 .49061 L p 0 .123 .576 r
F P
0 g
s
.57604 .5004 m .56283 .49061 L .56308 .49075 L 0 .123 .576 r
F
.56989 .49635 m .57604 .5004 L .54968 .47914 L p .521 0 0 r
F P
0 g
s
.54968 .47914 m .54674 .47644 L .56394 .49124 L p .521 0 0 r
F P
0 g
s
.56394 .49124 m .56989 .49635 L p .56378 .49114 L .521 0 0 r
F P
0 g
s
.56378 .49114 m .54968 .47914 L .56394 .49124 L .521 0 0 r
F
.56283 .49061 m .5526 .48295 L p .56308 .49075 L 0 .123 .576 r
F P
0 g
s
.6002 .52305 m .59421 .51638 L .62667 .53704 L p 0 .26 .678 r
F P
0 g
s
.62667 .53704 m .63553 .54259 L .6002 .52305 L p 0 .26 .678 r
F P
0 g
s
.50247 .44157 m .49889 .43955 L .47693 .42463 L p 0 .193 .633 r
F P
0 g
s
.49889 .43955 m .50247 .44157 L .52295 .45735 L p 0 .124 .573 r
F P
0 g
s
.52261 .45714 m .49889 .43955 L p .517 .45294 L 0 .124 .573 r
F P
0 g
s
.5061 .4452 m .5233 .45888 L p .50888 .4469 L .555 0 0 r
F P
0 g
s
.50247 .44157 m .50464 .44373 L p .50888 .4469 L .555 0 0 r
F P
0 g
s
.50464 .44373 m .5061 .4452 L p .50888 .4469 L .555 0 0 r
F P
0 g
s
.52295 .45735 m .52273 .45722 L p .517 .45294 L 0 .124 .573 r
F P
0 g
s
.52273 .45722 m .52261 .45714 L p .517 .45294 L 0 .124 .573 r
F P
0 g
s
.48352 .42835 m .47693 .42463 L .45797 .41324 L p 0 .222 .633 r
F P
0 g
s
.47693 .42463 m .48352 .42835 L .50247 .44157 L p 0 .193 .633 r
F P
0 g
s
.38244 .39228 m .3952 .39232 L .40944 .39856 L p .44 .819 .99 r
F P
0 g
s
.42065 .39901 m .40944 .39856 L .3952 .39232 L p .194 .685 .923 r
F P
0 g
s
.23566 .49633 m .2496 .48183 L .28209 .51672 L p .886 .803 .762 r
F P
0 g
s
.28209 .51672 m .26997 .53448 L .23566 .49633 L p .886 .803 .762 r
F P
0 g
s
.67909 .57153 m .67048 .56561 L .7095 .57007 L p .108 .643 .861 r
F P
0 g
s
.7095 .57007 m .72043 .57182 L .67909 .57153 L p .108 .643 .861 r
F P
0 g
s
.79464 .57831 m .78426 .57754 L .82429 .53976 L p .743 .973 .926 r
F P
0 g
s
.82429 .53976 m .83625 .53514 L .79464 .57831 L p .743 .973 .926 r
F P
0 g
s
.61774 .53157 m .62667 .53704 L .59868 .51922 L p .397 0 0 r
F P
0 g
s
.59868 .51922 m .59421 .51638 L p .59977 .51997 L .397 0 0 r
F P
0 g
s
.61774 .53157 m .59868 .51922 L .59977 .51997 L .397 0 0 r
F
.59421 .51638 m .58819 .51039 L .61774 .53157 L p F P
0 g
s
.60876 .5262 m .61774 .53157 L .58819 .51039 L p .487 0 0 r
F P
0 g
s
.58819 .51039 m .58214 .50507 L .60798 .52558 L p .487 0 0 r
F P
0 g
s
.60798 .52558 m .60876 .5262 L p .60775 .52542 L .487 0 0 r
F P
0 g
s
.60775 .52542 m .58819 .51039 L .60798 .52558 L .487 0 0 r
F
.22165 .51091 m .23566 .49633 L .26997 .53448 L p .883 .797 .76 r
F P
0 g
s
.26997 .53448 m .25779 .55232 L .22165 .51091 L p .883 .797 .76 r
F P
0 g
s
.3952 .39232 m .40792 .39426 L .42065 .39901 L p .194 .685 .923 r
F P
0 g
s
.43187 .40154 m .42065 .39901 L .40792 .39426 L p 0 .49 .778 r
F P
0 g
s
.43187 .40154 m .44313 .40607 L .45797 .41324 L p 0 .393 .758 r
F P
0 g
s
.45797 .41324 m .46719 .41845 L .48352 .42835 L p 0 .222 .633 r
F P
0 g
s
.46719 .41845 m .45797 .41324 L .44313 .40607 L p .387 0 0 r
F P
0 g
s
.67048 .56561 m .66182 .55974 L .69849 .56794 L p 0 .545 .785 r
F P
0 g
s
.68739 .56537 m .69849 .56794 L .69517 .5672 L p 0 .441 .698 r
F P
0 g
s
.69517 .5672 m .66182 .55974 L p .68739 .56537 L 0 .441 .698 r
F P
0 g
s
.66182 .55974 m .65311 .55395 L .68739 .56537 L p 0 .441 .698 r
F P
0 g
s
.68739 .56537 m .67621 .56233 L .67875 .56334 L p .23 0 0 r
F P
0 g
s
.70629 .56971 m .67048 .56561 L p .69849 .56794 L 0 .545 .785 r
F P
0 g
s
.67875 .56334 m .69928 .57152 L p .68739 .56537 L .23 0 0 r
F P
0 g
s
.69849 .56794 m .68739 .56537 L .68984 .56598 L p .12 0 0 r
F P
0 g
s
.68984 .56598 m .71231 .57157 L p .69849 .56794 L .12 0 0 r
F P
0 g
s
.69849 .56794 m .7095 .57007 L .70629 .56971 L p 0 .545 .785 r
F P
0 g
s
.20758 .52532 m .22165 .51091 L .25779 .55232 L p .878 .792 .761 r
F P
0 g
s
.25779 .55232 m .24558 .56996 L .20758 .52532 L p .878 .792 .761 r
F P
0 g
s
.78426 .57754 m .77381 .57683 L .81227 .54456 L p .703 .976 .916 r
F P
0 g
s
.81227 .54456 m .82429 .53976 L .78426 .57754 L p .703 .976 .916 r
F P
0 g
s
.5061 .4452 m .50247 .44157 L .48352 .42835 L p .518 0 0 r
F P
0 g
s
.5233 .45888 m .52295 .45735 L .50247 .44157 L p .555 0 0 r
F P
0 g
s
.49018 .43384 m .48352 .42835 L .46719 .41845 L p .512 0 0 r
F P
0 g
s
.48352 .42835 m .49018 .43384 L .5061 .4452 L p .518 0 0 r
F P
0 g
s
.40792 .39426 m .42064 .39806 L .43187 .40154 L p 0 .49 .778 r
F P
0 g
s
.44313 .40607 m .43187 .40154 L .42064 .39806 L p .307 0 0 r
F P
0 g
s
.77381 .57683 m .76329 .57611 L .80016 .54939 L p .646 .966 .898 r
F P
0 g
s
.80016 .54939 m .81227 .54456 L .77381 .57683 L p .646 .966 .898 r
F P
0 g
s
.54076 .4741 m .54376 .47479 L .52295 .45735 L p .606 .054 0 r
F P
0 g
s
.54674 .47644 m .54376 .47479 L .56369 .49289 L p .599 .045 0 r
F P
0 g
s
.56369 .49289 m .56989 .49635 L .54674 .47644 L p .599 .045 0 r
F P
0 g
s
.67621 .56233 m .68739 .56537 L .65311 .55395 L p .262 0 0 r
F P
0 g
s
.65311 .55395 m .64435 .54823 L .67621 .56233 L p .262 0 0 r
F P
0 g
s
.44313 .40607 m .45446 .4125 L .46719 .41845 L p .387 0 0 r
F P
0 g
s
.4765 .4255 m .46719 .41845 L .45446 .4125 L p .537 0 0 r
F P
0 g
s
.46719 .41845 m .4765 .4255 L .49018 .43384 L p .512 0 0 r
F P
0 g
s
.58214 .50507 m .57604 .5004 L .59973 .5209 L p .558 0 0 r
F P
0 g
s
.59973 .5209 m .60876 .5262 L .58214 .50507 L p .558 0 0 r
F P
0 g
s
.76329 .57611 m .75269 .57532 L .78796 .55409 L p .571 .94 .872 r
F P
0 g
s
.78796 .55409 m .80016 .54939 L .76329 .57611 L p .571 .94 .872 r
F P
0 g
s
.33441 .39359 m .34822 .39086 L .35676 .39787 L p .664 .953 .95 r
F P
0 g
s
.35676 .39787 m .34379 .40342 L .33441 .39359 L p .664 .953 .95 r
F P
0 g
s
.36964 .39414 m .35676 .39787 L .34822 .39086 L p .525 .906 .949 r
F P
0 g
s
.32048 .39772 m .33441 .39359 L .34379 .40342 L p .757 .967 .93 r
F P
0 g
s
.34379 .40342 m .33072 .4107 L .32048 .39772 L p .757 .967 .93 r
F P
0 g
s
.42064 .39806 m .43339 .40366 L .44313 .40607 L p .307 0 0 r
F P
0 g
s
.45446 .4125 m .44313 .40607 L .43339 .40366 L p .471 0 0 r
F P
0 g
s
.34822 .39086 m .36192 .38961 L .36964 .39414 L p .525 .906 .949 r
F P
0 g
s
.38244 .39228 m .36964 .39414 L .36192 .38961 L p .333 .807 .908 r
F P
0 g
s
.30642 .40317 m .32048 .39772 L .33072 .4107 L p .815 .964 .904 r
F P
0 g
s
.33072 .4107 m .31752 .41957 L .30642 .40317 L p .815 .964 .904 r
F P
0 g
s
.36192 .38961 m .37554 .38989 L .38244 .39228 L p .333 .807 .908 r
F P
0 g
s
.3952 .39232 m .38244 .39228 L .37554 .38989 L p .105 .655 .814 r
F P
0 g
s
.66494 .55878 m .67621 .56233 L .64435 .54823 L p .36 0 0 r
F P
0 g
s
.64435 .54823 m .63553 .54259 L .66494 .55878 L p .36 0 0 r
F P
0 g
s
.29222 .4098 m .30642 .40317 L .31752 .41957 L p .853 .953 .878 r
F P
0 g
s
.31752 .41957 m .3042 .42989 L .29222 .4098 L p .853 .953 .878 r
F P
0 g
s
.50977 .45026 m .5061 .4452 L .49018 .43384 L p .623 .066 0 r
F P
0 g
s
.5061 .4452 m .50977 .45026 L .52365 .4616 L p .641 .089 0 r
F P
0 g
s
.52365 .4616 m .5233 .45888 L .5061 .4452 L p .641 .089 0 r
F P
0 g
s
.49694 .44093 m .49018 .43384 L .4765 .4255 L p .619 .058 0 r
F P
0 g
s
.49018 .43384 m .49694 .44093 L .50977 .45026 L p .623 .066 0 r
F P
0 g
s
.75269 .57532 m .74202 .57438 L .77565 .55852 L p .479 .897 .835 r
F P
0 g
s
.77565 .55852 m .78796 .55409 L .75269 .57532 L p .479 .897 .835 r
F P
0 g
s
.37554 .38989 m .38909 .39172 L .3952 .39232 L p .105 .655 .814 r
F P
0 g
s
.40792 .39426 m .3952 .39232 L .38909 .39172 L p .122 0 0 r
F P
0 g
s
.27788 .41747 m .29222 .4098 L .3042 .42989 L p .876 .939 .856 r
F P
0 g
s
.3042 .42989 m .29074 .4415 L .27788 .41747 L p .876 .939 .856 r
F P
0 g
s
.57604 .5004 m .56989 .49635 L .59063 .51569 L p .612 .05 0 r
F P
0 g
s
.59063 .51569 m .59973 .5209 L .57604 .5004 L p .612 .05 0 r
F P
0 g
s
.54376 .47479 m .54076 .4741 L .55743 .48996 L p .653 .104 0 r
F P
0 g
s
.55743 .48996 m .56369 .49289 L .54376 .47479 L p .653 .104 0 r
F P
0 g
s
.63553 .54259 m .62667 .53704 L .6536 .55471 L p .442 0 0 r
F P
0 g
s
.6536 .55471 m .66494 .55878 L .63553 .54259 L p .442 0 0 r
F P
0 g
s
.5233 .45888 m .52365 .4616 L .53772 .47426 L p .666 .119 0 r
F P
0 g
s
.53772 .47426 m .54076 .4741 L .5233 .45888 L p .666 .119 0 r
F P
0 g
s
.26339 .42601 m .27788 .41747 L .29074 .4415 L p .89 .924 .838 r
F P
0 g
s
.29074 .4415 m .27715 .45417 L .26339 .42601 L p .89 .924 .838 r
F P
0 g
s
.38909 .39172 m .40258 .39509 L .40792 .39426 L p .122 0 0 r
F P
0 g
s
.42064 .39806 m .40792 .39426 L .40258 .39509 L p .311 0 0 r
F P
0 g
s
.45446 .4125 m .46588 .42069 L .4765 .4255 L p .537 0 0 r
F P
0 g
s
.48593 .43418 m .4765 .4255 L .46588 .42069 L p .629 .067 0 r
F P
0 g
s
.4765 .4255 m .48593 .43418 L .49694 .44093 L p .619 .058 0 r
F P
0 g
s
.43339 .40366 m .44618 .41094 L .45446 .4125 L p .471 0 0 r
F P
0 g
s
.46588 .42069 m .45446 .4125 L .44618 .41094 L p .579 .004 0 r
F P
0 g
s
.74202 .57438 m .73127 .57324 L .76322 .56253 L p .371 .836 .789 r
F P
0 g
s
.76322 .56253 m .77565 .55852 L .74202 .57438 L p .371 .836 .789 r
F P
0 g
s
.24876 .43525 m .26339 .42601 L .27715 .45417 L p .898 .91 .824 r
F P
0 g
s
.27715 .45417 m .26343 .4677 L .24876 .43525 L p .898 .91 .824 r
F P
0 g
s
.62667 .53704 m .61774 .53157 L .64219 .55012 L p .509 0 0 r
F P
0 g
s
.64219 .55012 m .6536 .55471 L .62667 .53704 L p .509 0 0 r
F P
0 g
s
.40258 .39509 m .41605 .39997 L .42064 .39806 L p .311 0 0 r
F P
0 g
s
.43339 .40366 m .42064 .39806 L .41605 .39997 L p .453 0 0 r
F P
0 g
s
.56989 .49635 m .56369 .49289 L .58147 .51055 L p .653 .099 0 r
F P
0 g
s
.58147 .51055 m .59063 .51569 L .56989 .49635 L p .653 .099 0 r
F P
0 g
s
.73127 .57324 m .72043 .57182 L .74485 .56709 L p .252 .758 .734 r
F P
0 g
s
.74485 .56709 m .75067 .56596 L p .74851 .56677 L .252 .758 .734 r
F P
0 g
s
.74851 .56677 m .73127 .57324 L .74485 .56709 L .252 .758 .734 r
F
.73801 .5687 m .75067 .56596 L .72043 .57182 L p 0 0 0 r
F P
0 g
s
.72043 .57182 m .7095 .57007 L .7316 .56901 L p 0 0 0 r
F P
0 g
s
.7316 .56901 m .73801 .5687 L p .73566 .56911 L 0 0 0 r
F P
0 g
s
.73566 .56911 m .72043 .57182 L .7316 .56901 L 0 0 0 r
F
.72522 .5706 m .73801 .5687 L .7117 .56997 L p F P
0 g
s
.7117 .56997 m .7095 .57007 L p .7102 .5701 L 0 0 0 r
F P
0 g
s
.72522 .5706 m .7117 .56997 L .7102 .5701 L 0 0 0 r
F
.7095 .57007 m .69849 .56794 L .72522 .5706 L p F P
0 g
s
.71231 .57157 m .72522 .5706 L .701 .56819 L p .12 0 0 r
F P
0 g
s
.701 .56819 m .69849 .56794 L p .69926 .56814 L .12 0 0 r
F P
0 g
s
.71231 .57157 m .701 .56819 L .69926 .56814 L .12 0 0 r
F
.75067 .56596 m .76322 .56253 L .73127 .57324 L p .252 .758 .734 r
F P
0 g
s
.23401 .44499 m .24876 .43525 L .26343 .4677 L p .901 .897 .814 r
F P
0 g
s
.26343 .4677 m .2496 .48183 L .23401 .44499 L p .901 .897 .814 r
F P
0 g
s
.51351 .45656 m .50977 .45026 L .49694 .44093 L p .683 .138 0 r
F P
0 g
s
.50977 .45026 m .51351 .45656 L .52401 .46532 L p .692 .15 0 r
F P
0 g
s
.52401 .46532 m .52365 .4616 L .50977 .45026 L p .692 .15 0 r
F P
0 g
s
.5038 .4494 m .49694 .44093 L .48593 .43418 L p .681 .134 0 r
F P
0 g
s
.49694 .44093 m .5038 .4494 L .51351 .45656 L p .683 .138 0 r
F P
0 g
s
.54076 .4741 m .53772 .47426 L .55111 .48748 L p .69 .147 0 r
F P
0 g
s
.55111 .48748 m .55743 .48996 L .54076 .4741 L p .69 .147 0 r
F P
0 g
s
.61774 .53157 m .60876 .5262 L .6307 .54499 L p .563 0 0 r
F P
0 g
s
.6307 .54499 m .64219 .55012 L .61774 .53157 L p .563 0 0 r
F P
0 g
s
.44618 .41094 m .45904 .41978 L .46588 .42069 L p .579 .004 0 r
F P
0 g
s
.47742 .43045 m .46588 .42069 L .45904 .41978 L p .648 .09 0 r
F P
0 g
s
.46588 .42069 m .47742 .43045 L .48593 .43418 L p .629 .067 0 r
F P
0 g
s
.41605 .39997 m .42951 .4063 L .43339 .40366 L p .453 0 0 r
F P
0 g
s
.44618 .41094 m .43339 .40366 L .42951 .4063 L p .553 0 0 r
F P
0 g
s
.52365 .4616 m .52401 .46532 L .53463 .47513 L p .703 .165 0 r
F P
0 g
s
.53463 .47513 m .53772 .47426 L .52365 .4616 L p .703 .165 0 r
F P
0 g
s
.21913 .45501 m .23401 .44499 L .2496 .48183 L p .901 .885 .808 r
F P
0 g
s
.2496 .48183 m .23566 .49633 L .21913 .45501 L p .901 .885 .808 r
F P
0 g
s
.49548 .44429 m .48593 .43418 L .47742 .43045 L p .684 .138 0 r
F P
0 g
s
.48593 .43418 m .49548 .44429 L .5038 .4494 L p .681 .134 0 r
F P
0 g
s
.56369 .49289 m .55743 .48996 L .57224 .50547 L p .683 .137 0 r
F P
0 g
s
.57224 .50547 m .58147 .51055 L .56369 .49289 L p .683 .137 0 r
F P
0 g
s
.60876 .5262 m .59973 .5209 L .61916 .53935 L p .607 .037 0 r
F P
0 g
s
.61916 .53935 m .6307 .54499 L .60876 .5262 L p .607 .037 0 r
F P
0 g
s
.83625 .53514 m .82429 .53976 L .84619 .49583 L p .85 .991 .845 r
F P
0 g
s
.84619 .49583 m .85906 .48583 L .83625 .53514 L p .85 .991 .845 r
F P
0 g
s
.42951 .4063 m .44299 .41398 L .44618 .41094 L p .553 0 0 r
F P
0 g
s
.45904 .41978 m .44618 .41094 L .44299 .41398 L p .622 .056 0 r
F P
0 g
s
.20416 .46511 m .21913 .45501 L .23566 .49633 L p .898 .874 .804 r
F P
0 g
s
.23566 .49633 m .22165 .51091 L .20416 .46511 L p .898 .874 .804 r
F P
0 g
s
.53772 .47426 m .53463 .47513 L .54472 .48539 L p .714 .179 0 r
F P
0 g
s
.54472 .48539 m .55111 .48748 L .53772 .47426 L p .714 .179 0 r
F P
0 g
s
.45904 .41978 m .472 .43 L .47742 .43045 L p .648 .09 0 r
F P
0 g
s
.4891 .44157 m .47742 .43045 L .472 .43 L p .693 .149 0 r
F P
0 g
s
.47742 .43045 m .4891 .44157 L .49548 .44429 L p .684 .138 0 r
F P
0 g
s
.59973 .5209 m .59063 .51569 L .60755 .53322 L p .642 .082 0 r
F P
0 g
s
.60755 .53322 m .61916 .53935 L .59973 .5209 L p .642 .082 0 r
F P
0 g
s
.18911 .47507 m .20416 .46511 L .22165 .51091 L p .893 .863 .803 r
F P
0 g
s
.22165 .51091 m .20758 .52532 L .18911 .47507 L p .893 .863 .803 r
F P
0 g
s
.55743 .48996 m .55111 .48748 L .56296 .50044 L p .705 .167 0 r
F P
0 g
s
.56296 .50044 m .57224 .50547 L .55743 .48996 L p .705 .167 0 r
F P
0 g
s
.82429 .53976 m .81227 .54456 L .83325 .5061 L p .83 .999 .831 r
F P
0 g
s
.83325 .5061 m .84619 .49583 L .82429 .53976 L p .83 .999 .831 r
F P
0 g
s
.51731 .46387 m .51351 .45656 L .5038 .4494 L p .718 .184 0 r
F P
0 g
s
.51351 .45656 m .51731 .46387 L .52437 .46985 L p .721 .189 0 r
F P
0 g
s
.52437 .46985 m .52401 .46532 L .51351 .45656 L p .721 .189 0 r
F P
0 g
s
.51077 .45901 m .5038 .4494 L .49548 .44429 L p .717 .182 0 r
F P
0 g
s
.5038 .4494 m .51077 .45901 L .51731 .46387 L p .718 .184 0 r
F P
0 g
s
.44299 .41398 m .4565 .42291 L .45904 .41978 L p .622 .056 0 r
F P
0 g
s
.472 .43 m .45904 .41978 L .4565 .42291 L p .67 .119 0 r
F P
0 g
s
.52401 .46532 m .52437 .46985 L .53151 .47657 L p .726 .195 0 r
F P
0 g
s
.53151 .47657 m .53463 .47513 L .52401 .46532 L p .726 .195 0 r
F P
0 g
s
.69928 .57152 m .71231 .57157 L .68739 .56537 L p .23 0 0 r
F P
0 g
s
.36495 .39105 m .37849 .39354 L .37554 .38989 L p .075 0 0 r
F P
0 g
s
.37554 .38989 m .36192 .38961 L .36495 .39105 L p .075 0 0 r
F P
0 g
s
.38909 .39172 m .37554 .38989 L .37849 .39354 L p .237 0 0 r
F P
0 g
s
.50519 .45557 m .49548 .44429 L .4891 .44157 L p .718 .184 0 r
F P
0 g
s
.49548 .44429 m .50519 .45557 L .51077 .45901 L p .717 .182 0 r
F P
0 g
s
.36192 .38961 m .34822 .39086 L .35131 .38961 L p .105 .66 .743 r
F P
0 g
s
.35131 .38961 m .36495 .39105 L .36192 .38961 L p .105 .66 .743 r
F P
0 g
s
.37849 .39354 m .39195 .39711 L .38909 .39172 L p .237 0 0 r
F P
0 g
s
.40258 .39509 m .38909 .39172 L .39195 .39711 L p .37 0 0 r
F P
0 g
s
.59063 .51569 m .58147 .51055 L .5959 .52663 L p .67 .119 0 r
F P
0 g
s
.5959 .52663 m .60755 .53322 L .59063 .51569 L p .67 .119 0 r
F P
0 g
s
.33757 .38919 m .35131 .38961 L .34822 .39086 L p .286 .787 .822 r
F P
0 g
s
.34822 .39086 m .33441 .39359 L .33757 .38919 L p .286 .787 .822 r
F P
0 g
s
.81227 .54456 m .80016 .54939 L .82023 .51643 L p .799 .999 .816 r
F P
0 g
s
.82023 .51643 m .83325 .5061 L .81227 .54456 L p .799 .999 .816 r
F P
0 g
s
.39195 .39711 m .40535 .40174 L .40258 .39509 L p .37 0 0 r
F P
0 g
s
.41605 .39997 m .40258 .39509 L .40535 .40174 L p .475 0 0 r
F P
0 g
s
.32371 .38974 m .33757 .38919 L .33441 .39359 L p .447 .881 .873 r
F P
0 g
s
.33441 .39359 m .32048 .39772 L .32371 .38974 L p .447 .881 .873 r
F P
0 g
s
.40535 .40174 m .41869 .4074 L .41605 .39997 L p .475 0 0 r
F P
0 g
s
.42951 .4063 m .41605 .39997 L .41869 .4074 L p .554 0 0 r
F P
0 g
s
.67621 .56233 m .66494 .55878 L .68615 .57037 L p .327 0 0 r
F P
0 g
s
.68615 .57037 m .69928 .57152 L .67621 .56233 L p .327 0 0 r
F P
0 g
s
.55111 .48748 m .54472 .48539 L .5536 .49543 L p .722 .189 0 r
F P
0 g
s
.5536 .49543 m .56296 .50044 L .55111 .48748 L p .722 .189 0 r
F P
0 g
s
.30972 .3912 m .32371 .38974 L .32048 .39772 L p .577 .941 .899 r
F P
0 g
s
.32048 .39772 m .30642 .40317 L .30972 .3912 L p .577 .941 .899 r
F P
0 g
s
.53463 .47513 m .53151 .47657 L .53826 .48359 L p .73 .202 0 r
F P
0 g
s
.53826 .48359 m .54472 .48539 L .53463 .47513 L p .73 .202 0 r
F P
0 g
s
.4565 .42291 m .47006 .43294 L .472 .43 L p .67 .119 0 r
F P
0 g
s
.48507 .44142 m .472 .43 L .47006 .43294 L p .703 .164 0 r
F P
0 g
s
.472 .43 m .48507 .44142 L .4891 .44157 L p .693 .149 0 r
F P
0 g
s
.50093 .4538 m .4891 .44157 L .48507 .44142 L p .721 .188 0 r
F P
0 g
s
.4891 .44157 m .50093 .4538 L .50519 .45557 L p .718 .184 0 r
F P
0 g
s
.58147 .51055 m .57224 .50547 L .5842 .51963 L p .693 .149 0 r
F P
0 g
s
.5842 .51963 m .5959 .52663 L .58147 .51055 L p .693 .149 0 r
F P
0 g
s
.41869 .4074 m .43199 .41405 L .42951 .4063 L p .554 0 0 r
F P
0 g
s
.44299 .41398 m .42951 .4063 L .43199 .41405 L p .613 .046 0 r
F P
0 g
s
.80016 .54939 m .78796 .55409 L .80711 .5266 L p .757 .993 .8 r
F P
0 g
s
.80711 .5266 m .82023 .51643 L .80016 .54939 L p .757 .993 .8 r
F P
0 g
s
.2956 .39347 m .30972 .3912 L .30642 .40317 L p .675 .973 .907 r
F P
0 g
s
.30642 .40317 m .29222 .4098 L .2956 .39347 L p .675 .973 .907 r
F P
0 g
s
.66494 .55878 m .6536 .55471 L .67293 .56809 L p .411 0 0 r
F P
0 g
s
.67293 .56809 m .68615 .57037 L .66494 .55878 L p .411 0 0 r
F P
0 g
s
.43199 .41405 m .44528 .42161 L .44299 .41398 L p .613 .046 0 r
F P
0 g
s
.4565 .42291 m .44299 .41398 L .44528 .42161 L p .657 .102 0 r
F P
0 g
s
.52117 .47193 m .51731 .46387 L .51077 .45901 L p .737 .211 0 r
F P
0 g
s
.51731 .46387 m .52117 .47193 L .52474 .47498 L p .738 .213 0 r
F P
0 g
s
.52474 .47498 m .52437 .46985 L .51731 .46387 L p .738 .213 0 r
F P
0 g
s
.51788 .46946 m .51077 .45901 L .50519 .45557 L p .736 .211 0 r
F P
0 g
s
.51077 .45901 m .51788 .46946 L .52117 .47193 L p .737 .211 0 r
F P
0 g
s
.28135 .39645 m .2956 .39347 L .29222 .4098 L p .745 .985 .904 r
F P
0 g
s
.29222 .4098 m .27788 .41747 L .28135 .39645 L p .745 .985 .904 r
F P
0 g
s
.6536 .55471 m .64219 .55012 L .65963 .56467 L p .482 0 0 r
F P
0 g
s
.65963 .56467 m .67293 .56809 L .6536 .55471 L p .482 0 0 r
F P
0 g
s
.57224 .50547 m .56296 .50044 L .57245 .51227 L p .71 .174 0 r
F P
0 g
s
.57245 .51227 m .5842 .51963 L .57224 .50547 L p .71 .174 0 r
F P
0 g
s
.78796 .55409 m .77565 .55852 L .79385 .53638 L p .701 .977 .783 r
F P
0 g
s
.79385 .53638 m .80711 .5266 L .78796 .55409 L p .701 .977 .783 r
F P
0 g
s
.52437 .46985 m .52474 .47498 L .52834 .47841 L p .739 .214 0 r
F P
0 g
s
.52834 .47841 m .53151 .47657 L .52437 .46985 L p .739 .214 0 r
F P
0 g
s
.51507 .46773 m .50519 .45557 L .50093 .4538 L p .736 .211 0 r
F P
0 g
s
.50519 .45557 m .51507 .46773 L .51788 .46946 L p .736 .211 0 r
F P
0 g
s
.54472 .48539 m .53826 .48359 L .54417 .49045 L p .733 .206 0 r
F P
0 g
s
.54417 .49045 m .5536 .49543 L .54472 .48539 L p .733 .206 0 r
F P
0 g
s
.47006 .43294 m .48369 .4439 L .48507 .44142 L p .703 .164 0 r
F P
0 g
s
.49827 .4538 m .48507 .44142 L .48369 .4439 L p .725 .195 0 r
F P
0 g
s
.48507 .44142 m .49827 .4538 L .50093 .4538 L p .721 .188 0 r
F P
0 g
s
.44528 .42161 m .45855 .43002 L .4565 .42291 L p .657 .102 0 r
F P
0 g
s
.47006 .43294 m .4565 .42291 L .45855 .43002 L p .689 .146 0 r
F P
0 g
s
.64219 .55012 m .6307 .54499 L .64626 .5601 L p .54 0 0 r
F P
0 g
s
.64626 .5601 m .65963 .56467 L .64219 .55012 L p .54 0 0 r
F P
0 g
s
.26696 .40003 m .28135 .39645 L .27788 .41747 L p .793 .985 .896 r
F P
0 g
s
.27788 .41747 m .26339 .42601 L .26696 .40003 L p .793 .985 .896 r
F P
0 g
s
.53151 .47657 m .52834 .47841 L .53173 .48198 L p .74 .216 0 r
F P
0 g
s
.53173 .48198 m .53826 .48359 L .53151 .47657 L p .74 .216 0 r
F P
0 g
s
.51293 .46686 m .50093 .4538 L .49827 .4538 L p .737 .212 0 r
F P
0 g
s
.50093 .4538 m .51293 .46686 L .51507 .46773 L p .736 .211 0 r
F P
0 g
s
.77565 .55852 m .76322 .56253 L .78047 .54553 L p .63 .952 .764 r
F P
0 g
s
.78047 .54553 m .79385 .53638 L .77565 .55852 L p .63 .952 .764 r
F P
0 g
s
.56296 .50044 m .5536 .49543 L .56067 .5046 L p .724 .193 0 r
F P
0 g
s
.56067 .5046 m .57245 .51227 L .56296 .50044 L p .724 .193 0 r
F P
0 g
s
.6307 .54499 m .61916 .53935 L .63283 .55442 L p .589 .018 0 r
F P
0 g
s
.63283 .55442 m .64626 .5601 L .6307 .54499 L p .589 .018 0 r
F P
0 g
s
.45855 .43002 m .47182 .43915 L .47006 .43294 L p .689 .146 0 r
F P
0 g
s
.48369 .4439 m .47006 .43294 L .47182 .43915 L p .713 .178 0 r
F P
0 g
s
.25244 .40408 m .26696 .40003 L .26339 .42601 L p .826 .977 .887 r
F P
0 g
s
.26339 .42601 m .24876 .43525 L .25244 .40408 L p .826 .977 .887 r
F P
0 g
s
.61916 .53935 m .60755 .53322 L .61937 .54769 L p .628 .066 0 r
F P
0 g
s
.61937 .54769 m .63283 .55442 L .61916 .53935 L p .628 .066 0 r
F P
0 g
s
.53826 .48359 m .53173 .48198 L .53468 .48547 L p .741 .217 0 r
F P
0 g
s
.53468 .48547 m .54417 .49045 L .53826 .48359 L p .741 .217 0 r
F P
0 g
s
.76322 .56253 m .75067 .56596 L .76693 .55384 L p .543 .913 .741 r
F P
0 g
s
.76693 .55384 m .78047 .54553 L .76322 .56253 L p .543 .913 .741 r
F P
0 g
s
.48369 .4439 m .4974 .45562 L .49827 .4538 L p .725 .195 0 r
F P
0 g
s
.51161 .46691 m .49827 .4538 L .4974 .45562 L p .738 .214 0 r
F P
0 g
s
.49827 .4538 m .51161 .46691 L .51293 .46686 L p .737 .212 0 r
F P
0 g
s
.5536 .49543 m .54417 .49045 L .54885 .4967 L p .734 .207 0 r
F P
0 g
s
.54885 .4967 m .56067 .5046 L .5536 .49543 L p .734 .207 0 r
F P
0 g
s
.47182 .43915 m .48511 .4489 L .48369 .4439 L p .713 .178 0 r
F P
0 g
s
.4974 .45562 m .48369 .4439 L .48511 .4489 L p .729 .201 0 r
F P
0 g
s
.60755 .53322 m .5959 .52663 L .60588 .54 L p .66 .107 0 r
F P
0 g
s
.60588 .54 m .61937 .54769 L .60755 .53322 L p .66 .107 0 r
F P
0 g
s
.23779 .40847 m .25244 .40408 L .24876 .43525 L p .847 .966 .879 r
F P
0 g
s
.24876 .43525 m .23401 .44499 L .23779 .40847 L p .847 .966 .879 r
F P
0 g
s
.52511 .48046 m .52117 .47193 L .51788 .46946 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .52474 .47498 L .52117 .47193 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51788 .46946 L .51507 .46773 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .52834 .47841 L .52474 .47498 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51507 .46773 L .51293 .46686 L closepath p .745 .224 0 r
F P
0 g
s
.75067 .56596 m .73801 .5687 L .75325 .5611 L p .437 .858 .713 r
F P
0 g
s
.75325 .5611 m .76693 .55384 L .75067 .56596 L p .437 .858 .713 r
F P
0 g
s
.5959 .52663 m .5842 .51963 L .59238 .53144 L p .686 .141 0 r
F P
0 g
s
.59238 .53144 m .60588 .54 L .5959 .52663 L p .686 .141 0 r
F P
0 g
s
.52511 .48046 m .53173 .48198 L .52834 .47841 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51293 .46686 L .51161 .46691 L closepath p .745 .224 0 r
F P
0 g
s
.54417 .49045 m .53468 .48547 L .537 .48863 L p .741 .218 0 r
F P
0 g
s
.537 .48863 m .54885 .4967 L .54417 .49045 L p .741 .218 0 r
F P
0 g
s
.48511 .4489 m .49841 .45914 L .4974 .45562 L p .729 .201 0 r
F P
0 g
s
.51121 .46788 m .4974 .45562 L .49841 .45914 L p .739 .216 0 r
F P
0 g
s
.4974 .45562 m .51121 .46788 L .51161 .46691 L p .738 .214 0 r
F P
0 g
s
.5842 .51963 m .57245 .51227 L .57889 .52215 L p .706 .168 0 r
F P
0 g
s
.57889 .52215 m .59238 .53144 L .5842 .51963 L p .706 .168 0 r
F P
0 g
s
.22302 .41303 m .23779 .40847 L .23401 .44499 L p .86 .952 .872 r
F P
0 g
s
.23401 .44499 m .21913 .45501 L .22302 .41303 L p .86 .952 .872 r
F P
0 g
s
.42877 .42014 m .44097 .42662 L .43199 .41405 L p .613 .045 0 r
F P
0 g
s
.43199 .41405 m .41869 .4074 L .42877 .42014 L p .613 .045 0 r
F P
0 g
s
.44528 .42161 m .43199 .41405 L .44097 .42662 L p .651 .094 0 r
F P
0 g
s
.4165 .41409 m .42877 .42014 L .41869 .4074 L p .564 0 0 r
F P
0 g
s
.41869 .4074 m .40535 .40174 L .4165 .41409 L p .564 0 0 r
F P
0 g
s
.52511 .48046 m .53468 .48547 L .53173 .48198 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51161 .46691 L .51121 .46788 L closepath p .745 .224 0 r
F P
0 g
s
.73801 .5687 m .72522 .5706 L .73942 .56712 L p .314 .785 .677 r
F P
0 g
s
.73942 .56712 m .75325 .5611 L .73801 .5687 L p .314 .785 .677 r
F P
0 g
s
.44097 .42662 m .45312 .43351 L .44528 .42161 L p .651 .094 0 r
F P
0 g
s
.45855 .43002 m .44528 .42161 L .45312 .43351 L p .681 .133 0 r
F P
0 g
s
.40417 .40851 m .4165 .41409 L .40535 .40174 L p .501 0 0 r
F P
0 g
s
.40535 .40174 m .39195 .39711 L .40417 .40851 L p .501 0 0 r
F P
0 g
s
.57245 .51227 m .56067 .5046 L .56541 .51225 L p .721 .19 0 r
F P
0 g
s
.56541 .51225 m .57889 .52215 L .57245 .51227 L p .721 .19 0 r
F P
0 g
s
.45312 .43351 m .46521 .44076 L .45855 .43002 L p .681 .133 0 r
F P
0 g
s
.47182 .43915 m .45855 .43002 L .46521 .44076 L p .703 .164 0 r
F P
0 g
s
.39176 .4034 m .40417 .40851 L .39195 .39711 L p .423 0 0 r
F P
0 g
s
.39195 .39711 m .37849 .39354 L .39176 .4034 L p .423 0 0 r
F P
0 g
s
.46521 .44076 m .47727 .44832 L .47182 .43915 L p .703 .164 0 r
F P
0 g
s
.48511 .4489 m .47182 .43915 L .47727 .44832 L p .72 .188 0 r
F P
0 g
s
.37927 .39878 m .39176 .4034 L .37849 .39354 L p .325 0 0 r
F P
0 g
s
.37849 .39354 m .36495 .39105 L .37927 .39878 L p .325 0 0 r
F P
0 g
s
.56067 .5046 m .54885 .4967 L .55195 .5019 L p .733 .206 0 r
F P
0 g
s
.55195 .5019 m .56541 .51225 L .56067 .5046 L p .733 .206 0 r
F P
0 g
s
.52511 .48046 m .537 .48863 L .53468 .48547 L closepath p .745 .224 0 r
F P
0 g
s
.49841 .45914 m .51175 .46971 L .51121 .46788 L p .739 .216 0 r
F P
0 g
s
.52511 .48046 m .51121 .46788 L .51175 .46971 L closepath p .745 .224 0 r
F P
0 g
s
.47727 .44832 m .48928 .45614 L .48511 .4489 L p .72 .188 0 r
F P
0 g
s
.49841 .45914 m .48511 .4489 L .48928 .45614 L p .732 .205 0 r
F P
0 g
s
.20815 .41764 m .22302 .41303 L .21913 .45501 L p .865 .937 .866 r
F P
0 g
s
.21913 .45501 m .20416 .46511 L .20815 .41764 L p .865 .937 .866 r
F P
0 g
s
.72522 .5706 m .71231 .57157 L .72545 .57173 L p 0 0 0 r
F P
0 g
s
.72545 .57173 m .73942 .56712 L .72522 .5706 L p 0 0 0 r
F P
0 g
s
.85906 .48583 m .84619 .49583 L .84685 .44818 L p .922 .943 .795 r
F P
0 g
s
.84685 .44818 m .85986 .43317 L .85906 .48583 L p .922 .943 .795 r
F P
0 g
s
.35402 .39095 m .3667 .39463 L .36493 .39406 L p .07 0 0 r
F P
0 g
s
.36493 .39406 m .35131 .38961 L p .35402 .39095 L .07 0 0 r
F P
0 g
s
.35131 .38961 m .33757 .38919 L .35402 .39095 L p .07 0 0 r
F P
0 g
s
.35402 .39095 m .34125 .3877 L .344 .38809 L p 0 .512 .783 r
F P
0 g
s
.37745 .3978 m .36495 .39105 L p .3667 .39463 L .207 0 0 r
F P
0 g
s
.36495 .39105 m .35131 .38961 L .3667 .39463 L p .207 0 0 r
F P
0 g
s
.344 .38809 m .37297 .39223 L p .35402 .39095 L 0 .512 .783 r
F P
0 g
s
.3667 .39463 m .35402 .39095 L .35683 .39173 L p 0 .403 .689 r
F P
0 g
s
.35683 .39173 m .38361 .39922 L p .3667 .39463 L 0 .403 .689 r
F P
0 g
s
.3667 .39463 m .37927 .39878 L .37745 .3978 L p .207 0 0 r
F P
0 g
s
.54885 .4967 m .537 .48863 L .53851 .49125 L p .74 .217 0 r
F P
0 g
s
.53851 .49125 m .55195 .5019 L .54885 .4967 L p .74 .217 0 r
F P
0 g
s
.48928 .45614 m .50126 .46415 L .49841 .45914 L p .732 .205 0 r
F P
0 g
s
.51175 .46971 m .49841 .45914 L .50126 .46415 L p .74 .217 0 r
F P
0 g
s
.52511 .48046 m .53851 .49125 L .537 .48863 L closepath p .745 .224 0 r
F P
0 g
s
.50126 .46415 m .5132 .47228 L .51175 .46971 L p .74 .217 0 r
F P
0 g
s
.52511 .48046 m .51175 .46971 L .5132 .47228 L closepath p .745 .224 0 r
F P
0 g
s
.71231 .57157 m .69928 .57152 L .71135 .5748 L p 0 0 0 r
F P
0 g
s
.71135 .5748 m .72545 .57173 L .71231 .57157 L p 0 0 0 r
F P
0 g
s
.19318 .42214 m .20815 .41764 L .20416 .46511 L p .866 .922 .863 r
F P
0 g
s
.20416 .46511 m .18911 .47507 L .19318 .42214 L p .866 .922 .863 r
F P
0 g
s
.52511 .48046 m .53534 .49342 L .53749 .49428 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .53249 .49168 L .53534 .49342 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .52913 .48916 L .53249 .49168 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .5255 .48605 L .52913 .48916 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .52184 .48255 L .5255 .48605 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51842 .47893 L .52184 .48255 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .51548 .47542 L .51842 .47893 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .5132 .47228 L .51548 .47542 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .53912 .49314 L .53851 .49125 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .53877 .49418 L .53912 .49314 L closepath p .745 .224 0 r
F P
0 g
s
.52511 .48046 m .53749 .49428 L .53877 .49418 L closepath p .745 .224 0 r
F P
0 g
s
.84619 .49583 m .83325 .5061 L .83379 .46355 L p .923 .954 .789 r
F P
0 g
s
.83379 .46355 m .84685 .44818 L .84619 .49583 L p .923 .954 .789 r
F P
0 g
s
.34125 .3877 m .35402 .39095 L .33757 .38919 L p .078 .64 .75 r
F P
0 g
s
.33757 .38919 m .32371 .38974 L .34125 .3877 L p .078 .64 .75 r
F P
0 g
s
.69928 .57152 m .68615 .57037 L .69713 .57623 L p .106 0 0 r
F P
0 g
s
.69713 .57623 m .71135 .5748 L .69928 .57152 L p .106 0 0 r
F P
0 g
s
.55195 .5019 m .53851 .49125 L .53912 .49314 L p .74 .216 0 r
F P
0 g
s
.50577 .47033 m .51548 .47542 L .5132 .47228 L p .741 .218 0 r
F P
0 g
s
.5132 .47228 m .50126 .46415 L .50577 .47033 L p .741 .218 0 r
F P
0 g
s
.56541 .51225 m .55195 .5019 L .55323 .50568 L p .73 .202 0 r
F P
0 g
s
.53912 .49314 m .55323 .50568 L .55195 .5019 L p .74 .216 0 r
F P
0 g
s
.49599 .46516 m .50577 .47033 L .50126 .46415 L p .734 .207 0 r
F P
0 g
s
.50126 .46415 m .48928 .45614 L .49599 .46516 L p .734 .207 0 r
F P
0 g
s
.68615 .57037 m .67293 .56809 L .68281 .57596 L p .235 0 0 r
F P
0 g
s
.68281 .57596 m .69713 .57623 L .68615 .57037 L p .235 0 0 r
F P
0 g
s
.32838 .38485 m .34125 .3877 L .32371 .38974 L p .228 .748 .826 r
F P
0 g
s
.32371 .38974 m .30972 .3912 L .32838 .38485 L p .228 .748 .826 r
F P
0 g
s
.83325 .5061 m .82023 .51643 L .82065 .47899 L p .92 .965 .786 r
F P
0 g
s
.82065 .47899 m .83379 .46355 L .83325 .5061 L p .92 .965 .786 r
F P
0 g
s
.57889 .52215 m .56541 .51225 L .56744 .51782 L p .715 .18 0 r
F P
0 g
s
.55323 .50568 m .56744 .51782 L .56541 .51225 L p .73 .202 0 r
F P
0 g
s
.55323 .50568 m .53912 .49314 L .53877 .49418 L p .738 .214 0 r
F P
0 g
s
.51166 .47727 m .51842 .47893 L .51548 .47542 L p .741 .217 0 r
F P
0 g
s
.51548 .47542 m .50577 .47033 L .51166 .47727 L p .741 .217 0 r
F P
0 g
s
.48613 .45989 m .49599 .46516 L .48928 .45614 L p .723 .192 0 r
F P
0 g
s
.48928 .45614 m .47727 .44832 L .48613 .45989 L p .723 .192 0 r
F P
0 g
s
.67293 .56809 m .65963 .56467 L .66842 .57396 L p .349 0 0 r
F P
0 g
s
.66842 .57396 m .68281 .57596 L .67293 .56809 L p .349 0 0 r
F P
0 g
s
.59238 .53144 m .57889 .52215 L .58174 .52934 L p .694 .151 0 r
F P
0 g
s
.56744 .51782 m .58174 .52934 L .57889 .52215 L p .715 .18 0 r
F P
0 g
s
.65963 .56467 m .64626 .5601 L .65397 .57024 L p .443 0 0 r
F P
0 g
s
.65397 .57024 m .66842 .57396 L .65963 .56467 L p .443 0 0 r
F P
0 g
s
.60588 .54 m .59238 .53144 L .59611 .54001 L p .665 .114 0 r
F P
0 g
s
.58174 .52934 m .59611 .54001 L .59238 .53144 L p .694 .151 0 r
F P
0 g
s
.4762 .45451 m .48613 .45989 L .47727 .44832 L p .709 .172 0 r
F P
0 g
s
.47727 .44832 m .46521 .44076 L .4762 .45451 L p .709 .172 0 r
F P
0 g
s
.64626 .5601 m .63283 .55442 L .63949 .56488 L p .52 0 0 r
F P
0 g
s
.63949 .56488 m .65397 .57024 L .64626 .5601 L p .52 0 0 r
F P
0 g
s
.61937 .54769 m .60588 .54 L .61054 .54961 L p .629 .067 0 r
F P
0 g
s
.59611 .54001 m .61054 .54961 L .60588 .54 L p .665 .114 0 r
F P
0 g
s
.3154 .38237 m .32838 .38485 L .30972 .3912 L p .367 .834 .884 r
F P
0 g
s
.30972 .3912 m .2956 .39347 L .3154 .38237 L p .367 .834 .884 r
F P
0 g
s
.53877 .49418 m .55259 .50775 L .55323 .50568 L p .738 .214 0 r
F P
0 g
s
.55259 .50775 m .53877 .49418 L .53749 .49428 L p .737 .213 0 r
F P
0 g
s
.51852 .48448 m .52184 .48255 L .51842 .47893 L p .74 .216 0 r
F P
0 g
s
.51842 .47893 m .51166 .47727 L .51852 .48448 L p .74 .216 0 r
F P
0 g
s
.63283 .55442 m .61937 .54769 L .62501 .55796 L p .581 .008 0 r
F P
0 g
s
.62501 .55796 m .63949 .56488 L .63283 .55442 L p .581 .008 0 r
F P
0 g
s
.61054 .54961 m .62501 .55796 L .61937 .54769 L p .629 .067 0 r
F P
0 g
s
.82023 .51643 m .80711 .5266 L .8074 .49424 L p .911 .975 .787 r
F P
0 g
s
.8074 .49424 m .82065 .47899 L .82023 .51643 L p .911 .975 .787 r
F P
0 g
s
.4662 .44901 m .4762 .45451 L .46521 .44076 L p .69 .146 0 r
F P
0 g
s
.46521 .44076 m .45312 .43351 L .4662 .44901 L p .69 .146 0 r
F P
0 g
s
.56744 .51782 m .55323 .50568 L .55259 .50775 L p .726 .196 0 r
F P
0 g
s
.50481 .47536 m .51166 .47727 L .50577 .47033 L p .733 .206 0 r
F P
0 g
s
.50577 .47033 m .49599 .46516 L .50481 .47536 L p .733 .206 0 r
F P
0 g
s
.53749 .49428 m .55005 .50796 L .55259 .50775 L p .737 .213 0 r
F P
0 g
s
.55005 .50796 m .53749 .49428 L .53534 .49342 L p .737 .211 0 r
F P
0 g
s
.52589 .49146 m .5255 .48605 L .52184 .48255 L p .739 .214 0 r
F P
0 g
s
.52184 .48255 m .51852 .48448 L .52589 .49146 L p .739 .214 0 r
F P
0 g
s
.45613 .44337 m .4662 .44901 L .45312 .43351 L p .666 .113 0 r
F P
0 g
s
.45312 .43351 m .44097 .42662 L .45613 .44337 L p .666 .113 0 r
F P
0 g
s
.30231 .38019 m .3154 .38237 L .2956 .39347 L p .487 .896 .921 r
F P
0 g
s
.2956 .39347 m .28135 .39645 L .30231 .38019 L p .487 .896 .921 r
F P
0 g
s
.53534 .49342 m .54576 .50626 L .55005 .50796 L p .737 .211 0 r
F P
0 g
s
.54576 .50626 m .53534 .49342 L .53249 .49168 L p .736 .211 0 r
F P
0 g
s
.53323 .4977 m .52913 .48916 L .5255 .48605 L p .738 .213 0 r
F P
0 g
s
.5255 .48605 m .52589 .49146 L .53323 .4977 L p .738 .213 0 r
F P
0 g
s
.53249 .49168 m .54001 .50276 L .54576 .50626 L p .736 .211 0 r
F P
0 g
s
.54001 .50276 m .53249 .49168 L .52913 .48916 L p .737 .211 0 r
F P
0 g
s
.52913 .48916 m .53323 .4977 L .54001 .50276 L p .737 .211 0 r
F P
0 g
s
.80711 .5266 m .79385 .53638 L .79403 .50898 L p .896 .985 .792 r
F P
0 g
s
.79403 .50898 m .8074 .49424 L .80711 .5266 L p .896 .985 .792 r
F P
0 g
s
.44598 .43757 m .45613 .44337 L .44097 .42662 L p .635 .072 0 r
F P
0 g
s
.44097 .42662 m .42877 .42014 L .44598 .43757 L p .635 .072 0 r
F P
0 g
s
.58174 .52934 m .56744 .51782 L .56657 .52088 L p .705 .167 0 r
F P
0 g
s
.55259 .50775 m .56657 .52088 L .56744 .51782 L p .726 .196 0 r
F P
0 g
s
.49788 .47311 m .50481 .47536 L .49599 .46516 L p .722 .19 0 r
F P
0 g
s
.49599 .46516 m .48613 .45989 L .49788 .47311 L p .722 .19 0 r
F P
0 g
s
.56657 .52088 m .55259 .50775 L .55005 .50796 L p .722 .19 0 r
F P
0 g
s
.28911 .37828 m .30231 .38019 L .28135 .39645 L p .583 .933 .942 r
F P
0 g
s
.28135 .39645 m .26696 .40003 L .28911 .37828 L p .583 .933 .942 r
F P
0 g
s
.51515 .48605 m .51852 .48448 L .51166 .47727 L p .73 .202 0 r
F P
0 g
s
.51166 .47727 m .50481 .47536 L .51515 .48605 L p .73 .202 0 r
F P
0 g
s
.43576 .43162 m .44598 .43757 L .42877 .42014 L p .595 .022 0 r
F P
0 g
s
.42877 .42014 m .4165 .41409 L .43576 .43162 L p .595 .022 0 r
F P
0 g
s
.79385 .53638 m .78047 .54553 L .78051 .52293 L p .874 .993 .801 r
F P
0 g
s
.78051 .52293 m .79403 .50898 L .79385 .53638 L p .874 .993 .801 r
F P
0 g
s
.59611 .54001 m .58174 .52934 L .58069 .53327 L p .676 .127 0 r
F P
0 g
s
.56657 .52088 m .58069 .53327 L .58174 .52934 L p .705 .167 0 r
F P
0 g
s
.42547 .42549 m .43576 .43162 L .4165 .41409 L p .544 0 0 r
F P
0 g
s
.4165 .41409 m .40417 .40851 L .42547 .42549 L p .544 0 0 r
F P
0 g
s
.49087 .47041 m .49788 .47311 L .48613 .45989 L p .706 .167 0 r
F P
0 g
s
.48613 .45989 m .4762 .45451 L .49087 .47041 L p .706 .167 0 r
F P
0 g
s
.2758 .37655 m .28911 .37828 L .26696 .40003 L p .656 .952 .949 r
F P
0 g
s
.26696 .40003 m .25244 .40408 L .2758 .37655 L p .656 .952 .949 r
F P
0 g
s
.55005 .50796 m .5628 .52116 L .56657 .52088 L p .722 .19 0 r
F P
0 g
s
.5628 .52116 m .55005 .50796 L .54576 .50626 L p .719 .185 0 r
F P
0 g
s
.52628 .49644 m .52589 .49146 L .51852 .48448 L p .726 .196 0 r
F P
0 g
s
.51852 .48448 m .51515 .48605 L .52628 .49644 L p .726 .196 0 r
F P
0 g
s
.78047 .54553 m .76693 .55384 L .76685 .5358 L p .841 .999 .813 r
F P
0 g
s
.76685 .5358 m .78051 .52293 L .78047 .54553 L p .841 .999 .813 r
F P
0 g
s
.41511 .41919 m .42547 .42549 L .40417 .40851 L p .48 0 0 r
F P
0 g
s
.40417 .40851 m .39176 .4034 L .41511 .41919 L p .48 0 0 r
F P
0 g
s
.61054 .54961 m .59611 .54001 L .59494 .5446 L p .635 .072 0 r
F P
0 g
s
.58069 .53327 m .59494 .5446 L .59611 .54001 L p .676 .127 0 r
F P
0 g
s
.58069 .53327 m .56657 .52088 L .5628 .52116 L p .696 .153 0 r
F P
0 g
s
.51173 .48706 m .51515 .48605 L .50481 .47536 L p .715 .181 0 r
F P
0 g
s
.50481 .47536 m .49788 .47311 L .51173 .48706 L p .715 .181 0 r
F P
0 g
s
.54576 .50626 m .55635 .5186 L .5628 .52116 L p .719 .185 0 r
F P
0 g
s
.55635 .5186 m .54576 .50626 L .54001 .50276 L p .718 .184 0 r
F P
0 g
s
.5374 .50577 m .53323 .4977 L .52589 .49146 L p .722 .19 0 r
F P
0 g
s
.52589 .49146 m .52628 .49644 L .5374 .50577 L p .722 .19 0 r
F P
0 g
s
.26239 .37496 m .2758 .37655 L .25244 .40408 L p .709 .957 .949 r
F P
0 g
s
.25244 .40408 m .23779 .40847 L .26239 .37496 L p .709 .957 .949 r
F P
0 g
s
.48379 .46715 m .49087 .47041 L .4762 .45451 L p .684 .138 0 r
F P
0 g
s
.4762 .45451 m .4662 .44901 L .48379 .46715 L p .684 .138 0 r
F P
0 g
s
.40468 .41271 m .41511 .41919 L .39176 .4034 L p .4 0 0 r
F P
0 g
s
.39176 .4034 m .37927 .39878 L .40468 .41271 L p .4 0 0 r
F P
0 g
s
.76693 .55384 m .75325 .5611 L .75302 .54732 L p .793 .999 .828 r
F P
0 g
s
.75302 .54732 m .76685 .5358 L .76693 .55384 L p .793 .999 .828 r
F P
0 g
s
.54001 .50276 m .54768 .51334 L .55635 .5186 L p .718 .184 0 r
F P
0 g
s
.54768 .51334 m .54001 .50276 L .53323 .4977 L p .719 .186 0 r
F P
0 g
s
.53323 .4977 m .5374 .50577 L .54768 .51334 L p .719 .186 0 r
F P
0 g
s
.62501 .55796 m .61054 .54961 L .60931 .55462 L p .577 .001 0 r
F P
0 g
s
.59494 .5446 m .60931 .55462 L .61054 .54961 L p .635 .072 0 r
F P
0 g
s
.39418 .40605 m .40468 .41271 L .37927 .39878 L p .302 0 0 r
F P
0 g
s
.37927 .39878 m .3667 .39463 L .39418 .40605 L p .302 0 0 r
F P
0 g
s
.75325 .5611 m .73942 .56712 L .73905 .55725 L p .724 .989 .842 r
F P
0 g
s
.73905 .55725 m .75302 .54732 L .75325 .5611 L p .724 .989 .842 r
F P
0 g
s
.24887 .37343 m .26239 .37496 L .23779 .40847 L p .747 .952 .944 r
F P
0 g
s
.23779 .40847 m .22302 .41303 L .24887 .37343 L p .747 .952 .944 r
F P
0 g
s
.63949 .56488 m .62501 .55796 L .62376 .56306 L p .499 0 0 r
F P
0 g
s
.60931 .55462 m .62376 .56306 L .62501 .55796 L p .577 .001 0 r
F P
0 g
s
.47664 .46327 m .48379 .46715 L .4662 .44901 L p .654 .1 0 r
F P
0 g
s
.4662 .44901 m .45613 .44337 L .47664 .46327 L p .654 .1 0 r
F P
0 g
s
.5628 .52116 m .57572 .53354 L .58069 .53327 L p .696 .153 0 r
F P
0 g
s
.57572 .53354 m .5628 .52116 L .55635 .5186 L p .688 .143 0 r
F P
0 g
s
.59494 .5446 m .58069 .53327 L .57572 .53354 L p .656 .1 0 r
F P
0 g
s
.52669 .5007 m .52628 .49644 L .51515 .48605 L p .705 .167 0 r
F P
0 g
s
.51515 .48605 m .51173 .48706 L .52669 .5007 L p .705 .167 0 r
F P
0 g
s
.73942 .56712 m .72545 .57173 L .72493 .56536 L p .625 .961 .849 r
F P
0 g
s
.72493 .56536 m .73905 .55725 L .73942 .56712 L p .625 .961 .849 r
F P
0 g
s
.50825 .48732 m .51173 .48706 L .49788 .47311 L p .692 .15 0 r
F P
0 g
s
.49788 .47311 m .49087 .47041 L .50825 .48732 L p .692 .15 0 r
F P
0 g
s
.38361 .39922 m .39418 .40605 L .3667 .39463 L p 0 .403 .689 r
F P
0 g
s
.65397 .57024 m .63949 .56488 L .63827 .56971 L p .392 0 0 r
F P
0 g
s
.62376 .56306 m .63827 .56971 L .63949 .56488 L p .499 0 0 r
F P
0 g
s
.72545 .57173 m .71135 .5748 L .71067 .5715 L p .49 .903 .84 r
F P
0 g
s
.71067 .5715 m .72493 .56536 L .72545 .57173 L p .49 .903 .84 r
F P
0 g
s
.66842 .57396 m .65397 .57024 L .65281 .57439 L p .251 0 0 r
F P
0 g
s
.63827 .56971 m .65281 .57439 L .65397 .57024 L p .392 0 0 r
F P
0 g
s
.23525 .37188 m .24887 .37343 L .22302 .41303 L p .771 .94 .936 r
F P
0 g
s
.22302 .41303 m .20815 .41764 L .23525 .37188 L p .771 .94 .936 r
F P
0 g
s
.71135 .5748 m .69713 .57623 L .69631 .57552 L p .318 .806 .804 r
F P
0 g
s
.69631 .57552 m .71067 .5715 L .71135 .5748 L p .318 .806 .804 r
F P
0 g
s
.46942 .45867 m .47664 .46327 L .45613 .44337 L p .614 .053 0 r
F P
0 g
s
.45613 .44337 m .44598 .43757 L .46942 .45867 L p .614 .053 0 r
F P
0 g
s
.68281 .57596 m .66842 .57396 L .66735 .57696 L p .076 0 0 r
F P
0 g
s
.65281 .57439 m .66735 .57696 L .66842 .57396 L p .251 0 0 r
F P
0 g
s
.69713 .57623 m .68281 .57596 L .68186 .57735 L p .121 .671 .735 r
F P
0 g
s
.68186 .57735 m .69631 .57552 L .69713 .57623 L p .121 .671 .735 r
F P
0 g
s
.85986 .43317 m .84685 .44818 L .82432 .40004 L p .922 .856 .76 r
F P
0 g
s
.82432 .40004 m .8366 .38074 L .85986 .43317 L p .922 .856 .76 r
F P
0 g
s
.55635 .5186 m .56712 .53008 L .57572 .53354 L p .688 .143 0 r
F P
0 g
s
.56712 .53008 m .55635 .5186 L .54768 .51334 L p .684 .138 0 r
F P
0 g
s
.66735 .57696 m .68186 .57735 L .68281 .57596 L p .076 0 0 r
F P
0 g
s
.37297 .39223 m .38361 .39922 L .35402 .39095 L p 0 .512 .783 r
F P
0 g
s
.54165 .51302 m .5374 .50577 L .52628 .49644 L p .694 .153 0 r
F P
0 g
s
.52628 .49644 m .52669 .5007 L .54165 .51302 L p .694 .153 0 r
F P
0 g
s
.60931 .55462 m .59494 .5446 L .58882 .54475 L p .597 .024 0 r
F P
0 g
s
.57572 .53354 m .58882 .54475 L .59494 .5446 L p .656 .1 0 r
F P
0 g
s
.54768 .51334 m .55548 .52307 L .56712 .53008 L p .684 .138 0 r
F P
0 g
s
.55548 .52307 m .54768 .51334 L .5374 .50577 L p .687 .142 0 r
F P
0 g
s
.5374 .50577 m .54165 .51302 L .55548 .52307 L p .687 .142 0 r
F P
0 g
s
.22154 .37026 m .23525 .37188 L .20815 .41764 L p .786 .925 .928 r
F P
0 g
s
.20815 .41764 m .19318 .42214 L .22154 .37026 L p .786 .925 .928 r
F P
0 g
s
.50474 .48666 m .50825 .48732 L .49087 .47041 L p .658 .109 0 r
F P
0 g
s
.49087 .47041 m .48379 .46715 L .50474 .48666 L p .658 .109 0 r
F P
0 g
s
.84685 .44818 m .83379 .46355 L .81201 .41973 L p .927 .863 .757 r
F P
0 g
s
.81201 .41973 m .82432 .40004 L .84685 .44818 L p .927 .863 .757 r
F P
0 g
s
.36226 .38507 m .37297 .39223 L .34125 .3877 L p .083 .615 .866 r
F P
0 g
s
.34125 .3877 m .32838 .38485 L .36226 .38507 L p .083 .615 .866 r
F P
0 g
s
.46214 .4533 m .46942 .45867 L .44598 .43757 L p .562 0 0 r
F P
0 g
s
.44598 .43757 m .43576 .43162 L .46214 .4533 L p .562 0 0 r
F P
0 g
s
.58882 .54475 m .57572 .53354 L .56712 .53008 L p .638 .078 0 r
F P
0 g
s
.5271 .504 m .52669 .5007 L .51173 .48706 L p .671 .125 0 r
F P
0 g
s
.51173 .48706 m .50825 .48732 L .5271 .504 L p .671 .125 0 r
F P
0 g
s
.83379 .46355 m .82065 .47899 L .79964 .43951 L p .93 .871 .757 r
F P
0 g
s
.79964 .43951 m .81201 .41973 L .83379 .46355 L p .93 .871 .757 r
F P
0 g
s
.62376 .56306 m .60931 .55462 L .60205 .55447 L p .508 0 0 r
F P
0 g
s
.58882 .54475 m .60205 .55447 L .60931 .55462 L p .597 .024 0 r
F P
0 g
s
.35148 .37777 m .36226 .38507 L .32838 .38485 L p .218 .702 .93 r
F P
0 g
s
.32838 .38485 m .3154 .38237 L .35148 .37777 L p .218 .702 .93 r
F P
0 g
s
.4548 .44711 m .46214 .4533 L .43651 .43223 L p .493 0 0 r
F P
0 g
s
.43666 .43235 m .4548 .44711 L .43651 .43223 L .493 0 0 r
F
.43651 .43223 m .43576 .43162 L p .43666 .43235 L F P
0 g
s
.43576 .43162 m .42547 .42549 L .4548 .44711 L p .493 0 0 r
F P
0 g
s
.44741 .44007 m .4548 .44711 L .42547 .42549 L p .406 0 0 r
F P
0 g
s
.42547 .42549 m .41511 .41919 L .44282 .43711 L p .406 0 0 r
F P
0 g
s
.44282 .43711 m .44741 .44007 L p .44205 .43651 L .406 0 0 r
F P
0 g
s
.42547 .42549 m .44282 .43711 L .44205 .43651 L .406 0 0 r
F
.46214 .4533 m .4548 .44711 L .45753 .44901 L p 0 .193 .658 r
F P
0 g
s
.50282 .48488 m .48379 .46715 L p .49534 .47895 L .609 .055 0 r
F P
0 g
s
.48379 .46715 m .47664 .46327 L .50118 .48492 L p .609 .055 0 r
F P
0 g
s
.45753 .44901 m .49028 .47191 L p .46697 .45649 L 0 .193 .658 r
F P
0 g
s
.46214 .4533 m .45753 .44901 L .46697 .45649 L 0 .193 .658 r
F
.50118 .48492 m .50474 .48666 L .50282 .48488 L p .609 .055 0 r
F P
0 g
s
.49534 .47895 m .50118 .48492 L .50282 .48488 L .609 .055 0 r
F
.56712 .53008 m .57806 .54033 L .58882 .54475 L p .638 .078 0 r
F P
0 g
s
.57806 .54033 m .56712 .53008 L .55548 .52307 L p .628 .069 0 r
F P
0 g
s
.82065 .47899 m .8074 .49424 L .78718 .45904 L p .931 .879 .762 r
F P
0 g
s
.78718 .45904 m .79964 .43951 L .82065 .47899 L p .931 .879 .762 r
F P
0 g
s
.54597 .51915 m .54165 .51302 L .52669 .5007 L p .648 .097 0 r
F P
0 g
s
.52669 .5007 m .5271 .504 L .54597 .51915 L p .648 .097 0 r
F P
0 g
s
.34063 .37034 m .35148 .37777 L .3154 .38237 L p .341 .769 .972 r
F P
0 g
s
.3154 .38237 m .30231 .38019 L .34063 .37034 L p .341 .769 .972 r
F P
0 g
s
.63827 .56971 m .62376 .56306 L .61541 .5624 L p .378 0 0 r
F P
0 g
s
.60205 .55447 m .61541 .5624 L .62376 .56306 L p .508 0 0 r
F P
0 g
s
.60205 .55447 m .58882 .54475 L .57806 .54033 L p .559 0 0 r
F P
0 g
s
.5271 .504 m .50825 .48732 L p .52431 .50295 L .617 .065 0 r
F P
0 g
s
.52737 .50534 m .5271 .504 L p .52431 .50295 L .617 .065 0 r
F P
0 g
s
.50825 .48732 m .50474 .48666 L .52751 .50607 L p .617 .065 0 r
F P
0 g
s
.49758 .48195 m .50118 .48492 L .48284 .46873 L p .54 0 0 r
F P
0 g
s
.48284 .46873 m .47664 .46327 L p .48282 .46878 L .54 0 0 r
F P
0 g
s
.48282 .46878 m .49758 .48195 L .48284 .46873 L .54 0 0 r
F
.47664 .46327 m .46942 .45867 L .49758 .48195 L p F P
0 g
s
.49394 .47764 m .49758 .48195 L .46942 .45867 L p .445 0 0 r
F P
0 g
s
.46942 .45867 m .46214 .4533 L .48274 .46906 L p .445 0 0 r
F P
0 g
s
.48274 .46906 m .49394 .47764 L p .48276 .46899 L .445 0 0 r
F P
0 g
s
.46942 .45867 m .48274 .46906 L .48276 .46899 L .445 0 0 r
F
.5271 .504 m .52751 .50607 L .55036 .52384 L p .572 .016 0 r
F P
0 g
s
.52793 .50668 m .52751 .50607 L .51921 .499 L p .535 0 0 r
F P
0 g
s
.51921 .499 m .50474 .48666 L p .51644 .49677 L .535 0 0 r
F P
0 g
s
.51644 .49677 m .52793 .50668 L .51921 .499 L .535 0 0 r
F
.50474 .48666 m .50118 .48492 L .52793 .50668 L p F P
0 g
s
.49758 .48195 m .50822 .49015 L p .50364 .4868 L 0 .117 .578 r
F P
0 g
s
.50822 .49015 m .52836 .50564 L p .51162 .49288 L 0 .117 .578 r
F P
0 g
s
.50364 .4868 m .50822 .49015 L .51162 .49288 L 0 .117 .578 r
F
.50118 .48492 m .50008 .48401 L p .50364 .4868 L F P
0 g
s
.50008 .48401 m .49758 .48195 L p .50364 .4868 L 0 .117 .578 r
F P
0 g
s
.52751 .50607 m .52737 .50534 L p .52431 .50295 L .617 .065 0 r
F P
0 g
s
.55548 .52307 m .56341 .53158 L .57806 .54033 L p .628 .069 0 r
F P
0 g
s
.56341 .53158 m .55548 .52307 L .54165 .51302 L p .632 .076 0 r
F P
0 g
s
.54165 .51302 m .54597 .51915 L .56341 .53158 L p .632 .076 0 r
F P
0 g
s
.8074 .49424 m .79403 .50898 L .77461 .47799 L p .929 .888 .77 r
F P
0 g
s
.77461 .47799 m .78718 .45904 L .8074 .49424 L p .929 .888 .77 r
F P
0 g
s
.32971 .36278 m .34063 .37034 L .30231 .38019 L p .444 .815 .993 r
F P
0 g
s
.30231 .38019 m .28911 .37828 L .32971 .36278 L p .444 .815 .993 r
F P
0 g
s
.65281 .57439 m .63827 .56971 L .62886 .56827 L p .193 0 0 r
F P
0 g
s
.61541 .5624 m .62886 .56827 L .63827 .56971 L p .378 0 0 r
F P
0 g
s
.43997 .43218 m .44741 .44007 L .41511 .41919 L p 0 .25 .667 r
F P
0 g
s
.41511 .41919 m .40468 .41271 L .43997 .43218 L p 0 .25 .667 r
F P
0 g
s
.79403 .50898 m .78051 .52293 L .76191 .496 L p .924 .899 .784 r
F P
0 g
s
.76191 .496 m .77461 .47799 L .79403 .50898 L p .924 .899 .784 r
F P
0 g
s
.31871 .35512 m .32971 .36278 L .28911 .37828 L p .526 .842 .999 r
F P
0 g
s
.28911 .37828 m .2758 .37655 L .31871 .35512 L p .526 .842 .999 r
F P
0 g
s
.61541 .5624 m .60205 .55447 L .58914 .54901 L p .433 0 0 r
F P
0 g
s
.57806 .54033 m .58914 .54901 L .60205 .55447 L p .559 0 0 r
F P
0 g
s
.58914 .54901 m .57806 .54033 L .56341 .53158 L p .535 0 0 r
F P
0 g
s
.62886 .56827 m .64237 .57189 L .65281 .57439 L p .193 0 0 r
F P
0 g
s
.66735 .57696 m .65281 .57439 L .64237 .57189 L p .042 .597 .82 r
F P
0 g
s
.78051 .52293 m .76685 .5358 L .74908 .51276 L p .915 .912 .802 r
F P
0 g
s
.74908 .51276 m .76191 .496 L .78051 .52293 L p .915 .912 .802 r
F P
0 g
s
.55036 .52384 m .54772 .52102 L p .54309 .51764 L .572 .016 0 r
F P
0 g
s
.54597 .51915 m .55036 .52384 L .57146 .53854 L p .54 0 0 r
F P
0 g
s
.55036 .52384 m .52751 .50607 L p .54531 .51959 L .451 0 0 r
F P
0 g
s
.55481 .52681 m .55131 .52447 L p .54531 .51959 L .451 0 0 r
F P
0 g
s
.55131 .52447 m .55036 .52384 L p .54531 .51959 L .451 0 0 r
F P
0 g
s
.54597 .51915 m .5271 .504 L p .54309 .51764 L .572 .016 0 r
F P
0 g
s
.52836 .50564 m .55932 .5278 L p .53672 .5126 L 0 .229 .694 r
F P
0 g
s
.52751 .50607 m .52778 .50646 L p .53416 .51111 L .451 0 0 r
F P
0 g
s
.52778 .50646 m .52793 .50668 L p .53416 .51111 L .451 0 0 r
F P
0 g
s
.52793 .50668 m .52832 .50576 L p .53672 .5126 L 0 .229 .694 r
F P
0 g
s
.52832 .50576 m .52836 .50564 L p .53672 .5126 L 0 .229 .694 r
F P
0 g
s
.52793 .50668 m .55481 .52681 L p .53416 .51111 L .451 0 0 r
F P
0 g
s
.54772 .52102 m .54597 .51915 L p .54309 .51764 L .572 .016 0 r
F P
0 g
s
.43248 .42343 m .43997 .43218 L .40468 .41271 L p 0 .346 .762 r
F P
0 g
s
.40468 .41271 m .39418 .40605 L .43248 .42343 L p 0 .346 .762 r
F P
0 g
s
.76685 .5358 m .75302 .54732 L .7361 .52794 L p .899 .925 .827 r
F P
0 g
s
.7361 .52794 m .74908 .51276 L .76685 .5358 L p .899 .925 .827 r
F P
0 g
s
.68186 .57735 m .66735 .57696 L .65591 .57308 L p .294 .77 .929 r
F P
0 g
s
.64237 .57189 m .65591 .57308 L .66735 .57696 L p .042 .597 .82 r
F P
0 g
s
.30765 .34736 m .31871 .35512 L .2758 .37655 L p .59 .855 .994 r
F P
0 g
s
.2758 .37655 m .26239 .37496 L .30765 .34736 L p .59 .855 .994 r
F P
0 g
s
.56341 .53158 m .57146 .53854 L .58914 .54901 L p .535 0 0 r
F P
0 g
s
.57146 .53854 m .56341 .53158 L .54597 .51915 L p .54 0 0 r
F P
0 g
s
.75302 .54732 m .73905 .55725 L .72299 .54126 L p .874 .939 .857 r
F P
0 g
s
.72299 .54126 m .7361 .52794 L .75302 .54732 L p .874 .939 .857 r
F P
0 g
s
.42496 .41384 m .43248 .42343 L .39418 .40605 L p 0 .437 .844 r
F P
0 g
s
.39418 .40605 m .38361 .39922 L .42496 .41384 L p 0 .437 .844 r
F P
0 g
s
.69631 .57552 m .68186 .57735 L .66945 .57174 L p .512 .885 .973 r
F P
0 g
s
.65591 .57308 m .66945 .57174 L .68186 .57735 L p .294 .77 .929 r
F P
0 g
s
.73905 .55725 m .72493 .56536 L .70975 .55248 L p .835 .951 .894 r
F P
0 g
s
.70975 .55248 m .72299 .54126 L .73905 .55725 L p .835 .951 .894 r
F P
0 g
s
.71067 .5715 m .69631 .57552 L .68296 .56783 L p .669 .939 .965 r
F P
0 g
s
.66945 .57174 m .68296 .56783 L .69631 .57552 L p .512 .885 .973 r
F P
0 g
s
.58914 .54901 m .60035 .5558 L .61541 .5624 L p .433 0 0 r
F P
0 g
s
.62886 .56827 m .61541 .5624 L .60035 .5558 L p 0 .33 .684 r
F P
0 g
s
.72493 .56536 m .71067 .5715 L .6964 .56138 L p .771 .955 .932 r
F P
0 g
s
.6964 .56138 m .70975 .55248 L .72493 .56536 L p .771 .955 .932 r
F P
0 g
s
.68296 .56783 m .6964 .56138 L .71067 .5715 L p .669 .939 .965 r
F P
0 g
s
.29651 .33954 m .30765 .34736 L .26239 .37496 L p .637 .858 .983 r
F P
0 g
s
.26239 .37496 m .24887 .37343 L .29651 .33954 L p .637 .858 .983 r
F P
0 g
s
.49028 .47191 m .49394 .47764 L .46214 .4533 L p 0 .193 .658 r
F P
0 g
s
.60035 .5558 m .58914 .54901 L .57596 .5412 L p .386 0 0 r
F P
0 g
s
.57637 .54147 m .60035 .5558 L .57596 .5412 L .386 0 0 r
F
.57146 .53854 m .57962 .54363 L .60035 .5558 L p F P
0 g
s
.55036 .52384 m .55481 .52681 L .57832 .54275 L p 0 .158 .59 r
F P
0 g
s
.57832 .54275 m .57962 .54363 L p .57821 .54268 L 0 .158 .59 r
F P
0 g
s
.55036 .52384 m .57832 .54275 L .57821 .54268 L 0 .158 .59 r
F
.57596 .5412 m .57146 .53854 L p .57637 .54147 L .386 0 0 r
F P
0 g
s
.4174 .40347 m .42496 .41384 L .38361 .39922 L p .088 .518 .905 r
F P
0 g
s
.38361 .39922 m .37297 .39223 L .4174 .40347 L p .088 .518 .905 r
F P
0 g
s
.52836 .50564 m .52793 .50668 L .50118 .48492 L p 0 .117 .578 r
F P
0 g
s
.28529 .33166 m .29651 .33954 L .24887 .37343 L p .672 .854 .969 r
F P
0 g
s
.24887 .37343 m .23525 .37188 L .28529 .33166 L p .672 .854 .969 r
F P
0 g
s
.64237 .57189 m .62886 .56827 L .61167 .56041 L p .008 .529 .857 r
F P
0 g
s
.60035 .5558 m .61167 .56041 L .62886 .56827 L p 0 .33 .684 r
F P
0 g
s
.40981 .39235 m .4174 .40347 L .37297 .39223 L p .209 .582 .943 r
F P
0 g
s
.37297 .39223 m .36226 .38507 L .40981 .39235 L p .209 .582 .943 r
F P
0 g
s
.8366 .38074 m .82432 .40004 L .77841 .35522 L p .882 .772 .736 r
F P
0 g
s
.77841 .35522 m .78901 .33274 L .8366 .38074 L p .882 .772 .736 r
F P
0 g
s
.57962 .54363 m .57146 .53854 L .55036 .52384 L p 0 .158 .59 r
F P
0 g
s
.48659 .46468 m .49028 .47191 L .4548 .44711 L p 0 .29 .76 r
F P
0 g
s
.4548 .44711 m .44741 .44007 L .48659 .46468 L p 0 .29 .76 r
F P
0 g
s
.27399 .32374 m .28529 .33166 L .23525 .37188 L p .697 .847 .955 r
F P
0 g
s
.23525 .37188 m .22154 .37026 L .27399 .32374 L p .697 .847 .955 r
F P
0 g
s
.82432 .40004 m .81201 .41973 L .7678 .37809 L p .885 .773 .733 r
F P
0 g
s
.7678 .37809 m .77841 .35522 L .82432 .40004 L p .885 .773 .733 r
F P
0 g
s
.40218 .38056 m .40981 .39235 L .36226 .38507 L p .314 .631 .962 r
F P
0 g
s
.36226 .38507 m .35148 .37777 L .40218 .38056 L p .314 .631 .962 r
F P
0 g
s
.61167 .56041 m .60035 .5558 L .57962 .54363 L p 0 .361 .767 r
F P
0 g
s
.52879 .50278 m .52836 .50564 L .49758 .48195 L p 0 .232 .709 r
F P
0 g
s
.49758 .48195 m .49394 .47764 L .52879 .50278 L p 0 .232 .709 r
F P
0 g
s
.65591 .57308 m .64237 .57189 L .62306 .56263 L p .277 .698 .969 r
F P
0 g
s
.61167 .56041 m .62306 .56263 L .64237 .57189 L p .008 .529 .857 r
F P
0 g
s
.55932 .5278 m .55481 .52681 L .52793 .50668 L p 0 .229 .694 r
F P
0 g
s
.81201 .41973 m .79964 .43951 L .75715 .40102 L p .887 .776 .734 r
F P
0 g
s
.75715 .40102 m .7678 .37809 L .81201 .41973 L p .887 .776 .734 r
F P
0 g
s
.48287 .45595 m .48659 .46468 L .44741 .44007 L p 0 .379 .837 r
F P
0 g
s
.44741 .44007 m .43997 .43218 L .48287 .45595 L p 0 .379 .837 r
F P
0 g
s
.39452 .36819 m .40218 .38056 L .35148 .37777 L p .4 .665 .967 r
F P
0 g
s
.35148 .37777 m .34063 .37034 L .39452 .36819 L p .4 .665 .967 r
F P
0 g
s
.79964 .43951 m .78718 .45904 L .74645 .42367 L p .887 .779 .737 r
F P
0 g
s
.74645 .42367 m .75715 .40102 L .79964 .43951 L p .887 .779 .737 r
F P
0 g
s
.66945 .57174 m .65591 .57308 L .63451 .56226 L p .497 .797 .999 r
F P
0 g
s
.62306 .56263 m .63451 .56226 L .65591 .57308 L p .277 .698 .969 r
F P
0 g
s
.57962 .54363 m .58787 .54658 L .61167 .56041 L p 0 .361 .767 r
F P
0 g
s
.58787 .54658 m .57962 .54363 L .55481 .52681 L p 0 .319 .762 r
F P
0 g
s
.55481 .52681 m .55932 .5278 L .58787 .54658 L p 0 .319 .762 r
F P
0 g
s
.47914 .44571 m .48287 .45595 L .43997 .43218 L p .11 .452 .884 r
F P
0 g
s
.43997 .43218 m .43248 .42343 L .47914 .44571 L p .11 .452 .884 r
F P
0 g
s
.52923 .49797 m .52879 .50278 L .49394 .47764 L p 0 .342 .812 r
F P
0 g
s
.49394 .47764 m .49028 .47191 L .52923 .49797 L p 0 .342 .812 r
F P
0 g
s
.62306 .56263 m .61167 .56041 L .58787 .54658 L p .099 .536 .911 r
F P
0 g
s
.78718 .45904 m .77461 .47799 L .73566 .44566 L p .885 .784 .744 r
F P
0 g
s
.73566 .44566 m .74645 .42367 L .78718 .45904 L p .885 .784 .744 r
F P
0 g
s
.38684 .35531 m .39452 .36819 L .34063 .37034 L p .469 .688 .962 r
F P
0 g
s
.34063 .37034 m .32971 .36278 L .38684 .35531 L p .469 .688 .962 r
F P
0 g
s
.68296 .56783 m .66945 .57174 L .64597 .5592 L p .646 .838 .974 r
F P
0 g
s
.63451 .56226 m .64597 .5592 L .66945 .57174 L p .497 .797 .999 r
F P
0 g
s
.77461 .47799 m .76191 .496 L .72478 .46664 L p .882 .79 .755 r
F P
0 g
s
.72478 .46664 m .73566 .44566 L .77461 .47799 L p .882 .79 .755 r
F P
0 g
s
.56386 .52663 m .55932 .5278 L .52836 .50564 L p 0 .364 .823 r
F P
0 g
s
.52836 .50564 m .52879 .50278 L .56386 .52663 L p 0 .364 .823 r
F P
0 g
s
.37912 .34203 m .38684 .35531 L .32971 .36278 L p .524 .704 .952 r
F P
0 g
s
.32971 .36278 m .31871 .35512 L .37912 .34203 L p .524 .704 .952 r
F P
0 g
s
.6964 .56138 m .68296 .56783 L .65743 .5534 L p .738 .845 .93 r
F P
0 g
s
.64597 .5592 m .65743 .5534 L .68296 .56783 L p .646 .838 .974 r
F P
0 g
s
.4754 .434 m .47914 .44571 L .43248 .42343 L p .231 .505 .905 r
F P
0 g
s
.43248 .42343 m .42496 .41384 L .4754 .434 L p .231 .505 .905 r
F P
0 g
s
.76191 .496 m .74908 .51276 L .71379 .48626 L p .875 .797 .77 r
F P
0 g
s
.71379 .48626 m .72478 .46664 L .76191 .496 L p .875 .797 .77 r
F P
0 g
s
.74908 .51276 m .7361 .52794 L .7027 .50417 L p .866 .806 .789 r
F P
0 g
s
.7027 .50417 m .71379 .48626 L .74908 .51276 L p .866 .806 .789 r
F P
0 g
s
.70975 .55248 m .6964 .56138 L .66885 .54487 L p .794 .839 .886 r
F P
0 g
s
.65743 .5534 m .66885 .54487 L .6964 .56138 L p .738 .845 .93 r
F P
0 g
s
.52966 .49112 m .52923 .49797 L .49028 .47191 L p .099 .43 .872 r
F P
0 g
s
.49028 .47191 m .48659 .46468 L .52966 .49112 L p .099 .43 .872 r
F P
0 g
s
.58787 .54658 m .59619 .54715 L .62306 .56263 L p .099 .536 .911 r
F P
0 g
s
.59619 .54715 m .58787 .54658 L .55932 .5278 L p .065 .469 .887 r
F P
0 g
s
.63451 .56226 m .62306 .56263 L .59619 .54715 L p .34 .656 .971 r
F P
0 g
s
.7361 .52794 m .72299 .54126 L .69151 .52007 L p .851 .816 .815 r
F P
0 g
s
.69151 .52007 m .7027 .50417 L .7361 .52794 L p .851 .816 .815 r
F P
0 g
s
.72299 .54126 m .70975 .55248 L .68022 .53371 L p .829 .828 .847 r
F P
0 g
s
.66885 .54487 m .68022 .53371 L .70975 .55248 L p .794 .839 .886 r
F P
0 g
s
.55932 .5278 m .56386 .52663 L .59619 .54715 L p .065 .469 .887 r
F P
0 g
s
.68022 .53371 m .69151 .52007 L .72299 .54126 L p .829 .828 .847 r
F P
0 g
s
.37136 .32846 m .37912 .34203 L .31871 .35512 L p .568 .714 .94 r
F P
0 g
s
.31871 .35512 m .30765 .34736 L .37136 .32846 L p .568 .714 .94 r
F P
0 g
s
.47165 .42091 m .4754 .434 L .42496 .41384 L p .329 .543 .908 r
F P
0 g
s
.42496 .41384 m .4174 .40347 L .47165 .42091 L p .329 .543 .908 r
F P
0 g
s
.56844 .52311 m .56386 .52663 L .52879 .50278 L p .144 .47 .893 r
F P
0 g
s
.52879 .50278 m .52923 .49797 L .56844 .52311 L p .144 .47 .893 r
F P
0 g
s
.36356 .31469 m .37136 .32846 L .30765 .34736 L p .602 .721 .928 r
F P
0 g
s
.30765 .34736 m .29651 .33954 L .36356 .31469 L p .602 .721 .928 r
F P
0 g
s
.5301 .4822 m .52966 .49112 L .48659 .46468 L p .245 .491 .893 r
F P
0 g
s
.48659 .46468 m .48287 .45595 L .5301 .4822 L p .245 .491 .893 r
F P
0 g
s
.64597 .5592 m .63451 .56226 L .60456 .54517 L p .515 .715 .963 r
F P
0 g
s
.59619 .54715 m .60456 .54517 L .63451 .56226 L p .34 .656 .971 r
F P
0 g
s
.46789 .40653 m .47165 .42091 L .4174 .40347 L p .406 .568 .901 r
F P
0 g
s
.4174 .40347 m .40981 .39235 L .46789 .40653 L p .406 .568 .901 r
F P
0 g
s
.60456 .54517 m .59619 .54715 L .56386 .52663 L p .285 .572 .937 r
F P
0 g
s
.56386 .52663 m .56844 .52311 L .60456 .54517 L p .285 .572 .937 r
F P
0 g
s
.35571 .30084 m .36356 .31469 L .29651 .33954 L p .63 .726 .917 r
F P
0 g
s
.29651 .33954 m .28529 .33166 L .35571 .30084 L p .63 .726 .917 r
F P
0 g
s
.46412 .39099 m .46789 .40653 L .40981 .39235 L p .466 .586 .89 r
F P
0 g
s
.40981 .39235 m .40218 .38056 L .46412 .39099 L p .466 .586 .89 r
F P
0 g
s
.65743 .5534 m .64597 .5592 L .61296 .54052 L p .626 .735 .925 r
F P
0 g
s
.60456 .54517 m .61296 .54052 L .64597 .5592 L p .515 .715 .963 r
F P
0 g
s
.57305 .51715 m .56844 .52311 L .52923 .49797 L p .311 .537 .909 r
F P
0 g
s
.52923 .49797 m .52966 .49112 L .57305 .51715 L p .311 .537 .909 r
F P
0 g
s
.53055 .47121 m .5301 .4822 L .48287 .45595 L p .356 .529 .889 r
F P
0 g
s
.48287 .45595 m .47914 .44571 L .53055 .47121 L p .356 .529 .889 r
F P
0 g
s
.78901 .33274 m .77841 .35522 L .71129 .31782 L p .831 .705 .725 r
F P
0 g
s
.71129 .31782 m .71927 .29362 L .78901 .33274 L p .831 .705 .725 r
F P
0 g
s
.34782 .287 m .35571 .30084 L .28529 .33166 L p .651 .729 .906 r
F P
0 g
s
.28529 .33166 m .27399 .32374 L .34782 .287 L p .651 .729 .906 r
F P
0 g
s
.77841 .35522 m .7678 .37809 L .70333 .34236 L p .832 .703 .722 r
F P
0 g
s
.70333 .34236 m .71129 .31782 L .77841 .35522 L p .832 .703 .722 r
F P
0 g
s
.61296 .54052 m .60456 .54517 L .56844 .52311 L p .445 .625 .93 r
F P
0 g
s
.46035 .37444 m .46412 .39099 L .40218 .38056 L p .513 .599 .877 r
F P
0 g
s
.40218 .38056 m .39452 .36819 L .46035 .37444 L p .513 .599 .877 r
F P
0 g
s
.66885 .54487 m .65743 .5534 L .62138 .53315 L p .696 .737 .883 r
F P
0 g
s
.61296 .54052 m .62138 .53315 L .65743 .5534 L p .626 .735 .925 r
F P
0 g
s
.7678 .37809 m .75715 .40102 L .69535 .36693 L p .831 .702 .722 r
F P
0 g
s
.69535 .36693 m .70333 .34236 L .7678 .37809 L p .831 .702 .722 r
F P
0 g
s
.56844 .52311 m .57305 .51715 L .61296 .54052 L p .445 .625 .93 r
F P
0 g
s
.53099 .45823 m .53055 .47121 L .47914 .44571 L p .439 .552 .873 r
F P
0 g
s
.47914 .44571 m .4754 .434 L .53099 .45823 L p .439 .552 .873 r
F P
0 g
s
.75715 .40102 m .74645 .42367 L .68734 .39118 L p .829 .703 .725 r
F P
0 g
s
.68734 .39118 m .69535 .36693 L .75715 .40102 L p .829 .703 .725 r
F P
0 g
s
.57767 .50871 m .57305 .51715 L .52966 .49112 L p .431 .573 .894 r
F P
0 g
s
.52966 .49112 m .5301 .4822 L .57767 .50871 L p .431 .573 .894 r
F P
0 g
s
.68022 .53371 m .66885 .54487 L .62978 .52308 L p .74 .733 .844 r
F P
0 g
s
.62138 .53315 m .62978 .52308 L .66885 .54487 L p .696 .737 .883 r
F P
0 g
s
.45658 .35704 m .46035 .37444 L .39452 .36819 L p .55 .609 .865 r
F P
0 g
s
.39452 .36819 m .38684 .35531 L .45658 .35704 L p .55 .609 .865 r
F P
0 g
s
.74645 .42367 m .73566 .44566 L .67929 .41474 L p .826 .704 .73 r
F P
0 g
s
.67929 .41474 m .68734 .39118 L .74645 .42367 L p .826 .704 .73 r
F P
0 g
s
.69151 .52007 m .68022 .53371 L .63816 .5104 L p .77 .726 .812 r
F P
0 g
s
.62978 .52308 m .63816 .5104 L .68022 .53371 L p .74 .733 .844 r
F P
0 g
s
.62138 .53315 m .61296 .54052 L .57305 .51715 L p .551 .648 .899 r
F P
0 g
s
.73566 .44566 m .72478 .46664 L .67118 .43726 L p .821 .706 .738 r
F P
0 g
s
.67118 .43726 m .67929 .41474 L .73566 .44566 L p .821 .706 .738 r
F P
0 g
s
.53143 .44334 m .53099 .45823 L .4754 .434 L p .5 .566 .854 r
F P
0 g
s
.4754 .434 m .47165 .42091 L .53143 .44334 L p .5 .566 .854 r
F P
0 g
s
.72478 .46664 m .71379 .48626 L .66301 .4584 L p .813 .709 .75 r
F P
0 g
s
.66301 .4584 m .67118 .43726 L .72478 .46664 L p .813 .709 .75 r
F P
0 g
s
.7027 .50417 m .69151 .52007 L .6465 .49525 L p .79 .72 .787 r
F P
0 g
s
.63816 .5104 m .6465 .49525 L .69151 .52007 L p .77 .726 .812 r
F P
0 g
s
.4528 .33898 m .45658 .35704 L .38684 .35531 L p .58 .618 .854 r
F P
0 g
s
.38684 .35531 m .37912 .34203 L .4528 .33898 L p .58 .618 .854 r
F P
0 g
s
.71379 .48626 m .7027 .50417 L .65479 .47783 L p .804 .714 .766 r
F P
0 g
s
.65479 .47783 m .66301 .4584 L .71379 .48626 L p .804 .714 .766 r
F P
0 g
s
.6465 .49525 m .65479 .47783 L .7027 .50417 L p .79 .72 .787 r
F P
0 g
s
.57305 .51715 m .57767 .50871 L .62138 .53315 L p .551 .648 .899 r
F P
0 g
s
.58229 .49779 m .57767 .50871 L .5301 .4822 L p .514 .59 .868 r
F P
0 g
s
.5301 .4822 m .53055 .47121 L .58229 .49779 L p .514 .59 .868 r
F P
0 g
s
.44901 .32045 m .4528 .33898 L .37912 .34203 L p .604 .625 .845 r
F P
0 g
s
.37912 .34203 m .37136 .32846 L .44901 .32045 L p .604 .625 .845 r
F P
0 g
s
.62978 .52308 m .62138 .53315 L .57767 .50871 L p .62 .655 .863 r
F P
0 g
s
.53187 .4267 m .53143 .44334 L .47165 .42091 L p .545 .575 .835 r
F P
0 g
s
.47165 .42091 m .46789 .40653 L .53187 .4267 L p .545 .575 .835 r
F P
0 g
s
.57767 .50871 m .58229 .49779 L .62978 .52308 L p .62 .655 .863 r
F P
0 g
s
.4452 .30164 m .44901 .32045 L .37136 .32846 L p .625 .633 .839 r
F P
0 g
s
.37136 .32846 m .36356 .31469 L .4452 .30164 L p .625 .633 .839 r
F P
0 g
s
.58692 .48447 m .58229 .49779 L .53055 .47121 L p .572 .598 .841 r
F P
0 g
s
.53055 .47121 m .53099 .45823 L .58692 .48447 L p .572 .598 .841 r
F P
0 g
s
.63816 .5104 m .62978 .52308 L .58229 .49779 L p .666 .656 .83 r
F P
0 g
s
.53231 .40849 m .53187 .4267 L .46789 .40653 L p .579 .581 .819 r
F P
0 g
s
.46789 .40653 m .46412 .39099 L .53231 .40849 L p .579 .581 .819 r
F P
0 g
s
.44139 .28274 m .4452 .30164 L .36356 .31469 L p .642 .641 .834 r
F P
0 g
s
.36356 .31469 m .35571 .30084 L .44139 .28274 L p .642 .641 .834 r
F P
0 g
s
.6465 .49525 m .63816 .5104 L .58692 .48447 L p .698 .654 .802 r
F P
0 g
s
.58229 .49779 m .58692 .48447 L .63816 .5104 L p .666 .656 .83 r
F P
0 g
s
.53275 .38892 m .53231 .40849 L .46412 .39099 L p .606 .586 .804 r
F P
0 g
s
.46412 .39099 m .46035 .37444 L .53275 .38892 L p .606 .586 .804 r
F P
0 g
s
.59153 .46888 m .58692 .48447 L .53099 .45823 L p .613 .602 .816 r
F P
0 g
s
.53099 .45823 m .53143 .44334 L .59153 .46888 L p .613 .602 .816 r
F P
0 g
s
.71927 .29362 m .71129 .31782 L .62776 .29163 L p .781 .657 .726 r
F P
0 g
s
.62776 .29163 m .63227 .26744 L .71927 .29362 L p .781 .657 .726 r
F P
0 g
s
.65479 .47783 m .6465 .49525 L .59153 .46888 L p .72 .651 .78 r
F P
0 g
s
.58692 .48447 m .59153 .46888 L .6465 .49525 L p .698 .654 .802 r
F P
0 g
s
.43754 .26392 m .44139 .28274 L .35571 .30084 L p .656 .649 .831 r
F P
0 g
s
.35571 .30084 m .34782 .287 L .43754 .26392 L p .656 .649 .831 r
F P
0 g
s
.71129 .31782 m .70333 .34236 L .62327 .3161 L p .778 .652 .723 r
F P
0 g
s
.62327 .3161 m .62776 .29163 L .71129 .31782 L p .778 .652 .723 r
F P
0 g
s
.53319 .36823 m .53275 .38892 L .46035 .37444 L p .627 .59 .793 r
F P
0 g
s
.46035 .37444 m .45658 .35704 L .53319 .36823 L p .627 .59 .793 r
F P
0 g
s
.70333 .34236 m .69535 .36693 L .61878 .34055 L p .775 .649 .723 r
F P
0 g
s
.61878 .34055 m .62327 .3161 L .70333 .34236 L p .775 .649 .723 r
F P
0 g
s
.66301 .4584 m .65479 .47783 L .59612 .4512 L p .736 .649 .762 r
F P
0 g
s
.59153 .46888 m .59612 .4512 L .65479 .47783 L p .72 .651 .78 r
F P
0 g
s
.69535 .36693 m .68734 .39118 L .61428 .36464 L p .771 .647 .726 r
F P
0 g
s
.61428 .36464 m .61878 .34055 L .69535 .36693 L p .771 .647 .726 r
F P
0 g
s
.59612 .4512 m .59153 .46888 L .53143 .44334 L p .642 .603 .795 r
F P
0 g
s
.53143 .44334 m .53187 .4267 L .59612 .4512 L p .642 .603 .795 r
F P
0 g
s
.68734 .39118 m .67929 .41474 L .60977 .38808 L p .765 .646 .73 r
F P
0 g
s
.60977 .38808 m .61428 .36464 L .68734 .39118 L p .765 .646 .73 r
F P
0 g
s
.67118 .43726 m .66301 .4584 L .60069 .43166 L p .749 .647 .748 r
F P
0 g
s
.59612 .4512 m .60069 .43166 L .66301 .4584 L p .736 .649 .762 r
F P
0 g
s
.67929 .41474 m .67118 .43726 L .60524 .41052 L p .758 .646 .738 r
F P
0 g
s
.60524 .41052 m .60977 .38808 L .67929 .41474 L p .758 .646 .738 r
F P
0 g
s
.60069 .43166 m .60524 .41052 L .67118 .43726 L p .749 .647 .748 r
F P
0 g
s
.53363 .34668 m .53319 .36823 L .45658 .35704 L p .644 .595 .785 r
F P
0 g
s
.45658 .35704 m .4528 .33898 L .53363 .34668 L p .644 .595 .785 r
F P
0 g
s
.60069 .43166 m .59612 .4512 L .53187 .4267 L p .664 .604 .778 r
F P
0 g
s
.53187 .4267 m .53231 .40849 L .60069 .43166 L p .664 .604 .778 r
F P
0 g
s
.53407 .32453 m .53363 .34668 L .4528 .33898 L p .658 .6 .779 r
F P
0 g
s
.4528 .33898 m .44901 .32045 L .53407 .32453 L p .658 .6 .779 r
F P
0 g
s
.60524 .41052 m .60069 .43166 L .53231 .40849 L p .681 .605 .764 r
F P
0 g
s
.53231 .40849 m .53275 .38892 L .60524 .41052 L p .681 .605 .764 r
F P
0 g
s
.5345 .30205 m .53407 .32453 L .44901 .32045 L p .67 .606 .775 r
F P
0 g
s
.44901 .32045 m .4452 .30164 L .5345 .30205 L p .67 .606 .775 r
F P
0 g
s
.60977 .38808 m .60524 .41052 L .53275 .38892 L p .695 .607 .754 r
F P
0 g
s
.53275 .38892 m .53319 .36823 L .60977 .38808 L p .695 .607 .754 r
F P
0 g
s
.53494 .2795 m .5345 .30205 L .4452 .30164 L p .68 .612 .773 r
F P
0 g
s
.4452 .30164 m .44139 .28274 L .53494 .2795 L p .68 .612 .773 r
F P
0 g
s
.61428 .36464 m .60977 .38808 L .53319 .36823 L p .705 .609 .747 r
F P
0 g
s
.53319 .36823 m .53363 .34668 L .61428 .36464 L p .705 .609 .747 r
F P
0 g
s
.61878 .34055 m .61428 .36464 L .53363 .34668 L p .714 .612 .742 r
F P
0 g
s
.62327 .3161 m .61878 .34055 L .53407 .32453 L p .721 .616 .739 r
F P
0 g
s
.53363 .34668 m .53407 .32453 L .61878 .34055 L p .714 .612 .742 r
F P
0 g
s
.62776 .29163 m .62327 .3161 L .5345 .30205 L p .727 .621 .739 r
F P
0 g
s
.53407 .32453 m .5345 .30205 L .62327 .3161 L p .721 .616 .739 r
F P
0 g
s
.53539 .25714 m .53494 .2795 L .44139 .28274 L p .689 .62 .774 r
F P
0 g
s
.44139 .28274 m .43754 .26392 L .53539 .25714 L p .689 .62 .774 r
F P
0 g
s
.63227 .26744 m .62776 .29163 L .53494 .2795 L p .732 .627 .741 r
F P
0 g
s
.5345 .30205 m .53494 .2795 L .62776 .29163 L p .727 .621 .739 r
F P
0 g
s
.53494 .2795 m .53539 .25714 L .63227 .26744 L p .732 .627 .741 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00loooool4o`000003oa0@4?oo
oooooooo06kooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo
073ooooo003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo
003eooooo`03o`000?oooooooooo073ooooo003eooooo`03o`000?oooooooooo073ooooo003coooo
o`03oeEEEOmVIVKo000007;ooooo003ooooooa7ooooo1?l000000ol@413oooooooooo`1Aooooo`00
oooooolCooooo`03o`000?oooooooooo05?ooooo003nooooo`;o00001oooool6o`0000Gooooo00?o
0000ooooooooool0Doooool00?_ooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooo
oooo05?ooooo003iooooo`;o00001?ooool2o`00017ooooo00?o0000ooooooooool0Doooool00?Ko
oooo0ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo0000013ooooo00?o0000oooooooo
ool0Doooool00?Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1Cooooo`00lOooool3o`0000Oooooo00Co0000oooooooooooooooo
1?l0000=ooooo`03oeEEEOmVIVKo000005Gooooo003_ooooo`;o00003_ooool01Ol0003ooooooooo
oooooooo000006Cooooo003/ooooo`Co00003oooool01Ol0003ooooooooooooooooo000006Cooooo
003Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0HOooool00>Oooooo0ol0000Fooooo`05o`000?ooooooooooooooool00000Hooo
ool00>Gooooo0_l0000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H?ooool0
0>;ooooo0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Goooool00:go
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01gooooo0_l00002ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Oooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00004ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool2o`00063ooooo002]ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05gooooo002]ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05gooooo002]oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01?ooooo0_l0
00000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0G?oo
ool00:gooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01;ooooo0ol0
0003ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Kooooo`00[Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?oo
ool2o`0002gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Kooooo`00[Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000<ooooo`?o0000;oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05[ooooo003<ooooo`?o0000<Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Wooooo0039ooooo`?o00000oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo00Sooooo0_l0001Kooooo`00aoooool2o`0003Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Hooooo`00a?ooool3o`0003Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Gooooo`00`_ooool2o`0003cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Gooooo`00_oooool3o`0000;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Kooooo002mooooo`;o00001_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0E_ooool00;[o
oooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0EOooool00;Sooooo
0_l00017ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0E?ooool00;Gooooo0ol0
0002ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool2o`0005Kooooo002c
ooooo`;o0000C?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05?ooooo002`oooo
o`?o0000C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0027ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool2o`00057ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1Booooo`00Qoooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo1?l0001Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0DOooool008Oooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D?ooool008Oooooo00Go0000ooooooooooooooooo`00000Joooo
o`?o0000F?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo0027ooooo`05
o`000?ooooooooooooooool000006?ooool2o`0005_ooooo00?o0000ooooooooool04Oooool2o`00
057ooooo0027ooooo`05oa0@4?ooooooooooooooool@41005Oooool4o`0005cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Zooooo`00Qoooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo0_l00004ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool0:Oooool008Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`?o0000
H_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Xooooo`00V_ooool2o`0006Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`0Yooooo`00Uoooool4o`0006Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<02[ooooo002Eooooo`;o00001?ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool0;?ooool009;ooooo0ol0001]ooooo`03o`000?oooooooooo01Go
oooo0_l0000<ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0/oooo
o`00T?ooool2o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00000<ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0002_ooooo002=ooooo`Co0000LOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo002;ooooo`;o00001?ooool00ol0003ooooo
ooooo`1^ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool008Sooooo0ol0
001gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool008Kooooo0_l0001j
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool008?ooooo1?l0001koooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Aoooool0087ooooo0_l00004ooooo`03
o`000?oooooooooo07Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`00
O_ooool3o`00087ooooo00?o0000ooooooooool06Oooool3o`0004Oooooo0016ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o
0000Q?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Gooooo0016ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool07?ooool3o`000003
ooooool0003ooooo08?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`14ooooo`00
?_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Wo
oooo0_l00029ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo0ol0002;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@oooool004Kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05_ooool2o`0008kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool05Oooool3o`000003ooooool0003ooooo08gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`12ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool04oooool2o`0009?ooooo00?o0000ooooooooool07_ooool2o`00
04?ooooo0016ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo0ol0002Foooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Sooooo0_l0002Iooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0@?ooool006Gooooo0ol00002ooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0oooooo`00Hooo
ool2o`0009kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00H?ooool3
o`000:3ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0nooooo`00G_ooool3o`00
0:;ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0mooooo`00Foooool3o`0000?o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0Rooooo`;o0000?_ooool005Wooooo
0_l0002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0??ooool005Kooooo0ol0
002Zooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>oooool005Cooooo0ol0002/
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>_ooool0057ooooo0ol00003oooo
o`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0joooo
o`00:Oooool4o`000003oa0@4?oooooooooo01oooooo0_l0002booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>Oooool002_ooooo00?o0000ooooooooool07_ooool3o`000;Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0hooooo`008?ooool6o`0000Gooooo00?o
0000ooooooooool07?ooool2o`0000;ooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0Vooooo`;o00002Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000[ooooo`03o`000?oo
oooooooo01Wooooo0ol0002iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000[ooooo`03o`000?oooooooooo01Oooooo0_l0
002looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooo
oooooooo410@02cooooo000[ooooo`03o`000?oooooooooo01Cooooo0ol0002nooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo
000[ooooo`03o`000?oooooooooo01;ooooo0_l00003ooooo`03o`000?oooooooooo0;cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool002Wooooo00?oEEEEofIVI_l000004Oooool3o`000<Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003_ooooo0_l0
0037ooooo`03o`000?oooooooooo02Wooooo0_l00005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool003Sooooo0ol000000ooooooo0000ooooo`36ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000fooooo`;o0000
c?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo000cooooo`?o0000c_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo000aooooo`;o0000dOooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000^ooooo`?o000000?oooooo`00
0?ooool0d?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo000]ooooo`;o
00001?ooool00ol0003oooooooooo`3>ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0<?ooool002gooooo00?o0000ooooool00000U_ooool>o`00033ooooo00?o0000ooooooooool0
;Oooool3o`00037ooooo000]ooooo`04o`000?ooooooooooo`0008Gooooo4?l00008ok2NaP03o`00
0?nkX;go^j2m00?o^j2m2ol0000Uooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;oooool002gooooo00Go0000ooooooooooooooooo`00001jooooo`[o00006?n`W/H00ol0003o^j2m
ok^P_@0>ok^P_@_o00006_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02kooooo
000/ooooo`?o00000oooool00ol0003oooooooooo`1cooooo`Co00000_nWY]@00ol0003o/9k6ok2N
aP0Mok2NaP03o`000?nkX;go^j2m01Wo^j2m1ol0000Cooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool002cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_
ooooo`?o00001_nWY]@00ol0003o/9k6ok2NaP0Mok2NaP03o`000?nkX;go^j2m01go^j2m00?o0000
olNX^Oo7Z;T00ol0000@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool0
02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Zooooo`Co00002OnWY]@00ol0
003o/9k6ok2NaP0Mok2NaP03o`000?nkX;go^j2m01go^j2m00?o0000olNX^Oo7Z;T00oo7Z;T3o`00
00gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`00;?ooool3o`0000Ko
oooo00?o0000ooooooooool0IOooool4o`0000koYjKD00?o0000ok2Na_n`W/H07?n`W/H00ol0003o
^j2mok^P_@0Lok^P_@03o`000?o7Z;WoajRi00OoajRi0ol0000:ooooo`03o`000?oooooooooo03;o
oooo0_l0000]ooooo`00;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo063ooooo
1?l0000BojNVe003o`000?n`W/Ko/9k600go/9k64?l00003ok^P_@03o`000?nkX;go^j2m01So^j2m
00?o0000olNX^Oo7Z;T02_o7Z;T3o`0000Oooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0[ooooo`004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05co
oooo0ol0000DojNVe0?o000000?o/9k6o`000?l000003?l0000?ojjLa@03o`000?njW[go^Yjm00;o
^Yjm1ol0000Cok^P_@03o`000?o7Z;WoajRi00goajRi0ol00005ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool0017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Eoooool4o`0001;oYjKD1Ol00002ojBTe@03o`000?n^W<Go[Yc501co[Yc500?o0000okZN_Onj
W[d02OnjW[d8o`0000_o^j2m00?o0000olNX^Oo7Z;T04?o7Z;T3o`0000;ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Zooooo`002Oooool6o`0000;ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000;ooooo`03o`000?oooooooooo05?o
oooo0ol0000AojNVe0Go00001onTY=D00ol0003o[Yc5ojjLa@0LojjLa@03o`000?njW[go^Yjm017o
^Yjm1ol00003ok^P_@03o`000?o7Z;WoajRi01CoajRi0ol0000fooooo`03o`000?oooooooooo02Wo
oooo000Aooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool2o`000003ojJjiol0003oYjKD00go
YjKD1?l0000<ojBTe@03o`000?n^W<Go[Yc501co[Yc500?o0000okZN_OnjW[d06?njW[d6o`0001Ko
ajRi1?l0000dooooo`03o`000?oooooooooo02Sooooo000Aooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1=ooooo`;o00001?nV^^L00ol0003oYjKDojNVe006ojNVe0Go00004OnTY=D00ol0
003o[Yc5ojjLa@0KojjLa@03o`000?njW[go^Yjm01_o^Yjm00?o0000olNV^Oo7Y[T00ol0000ColNX
^@04o`000?o7Z;WoajRiolNX^@?o0000<Oooool2o`0002Wooooo000Aooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0B_ooool2o`0000OoY[[W00Co0000ojNVe?nWY]CoYjKD1?l0000FojBTe@03o`000?n^
W<Go[Yc501_o[Yc500?o0000okZN_OnjW[d06onjW[d00ol0003oajJiolNV^@03olNV^@?o00004?o7
Z;T00ol0003oajRiolNX^@02olNX^@04o`000?oD];Wo0000o`0002oooooo0_l0000Yooooo`004Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool2o`00013ooooo
00?o0000ooooooooool0Aoooool2o`0000WoY[[W0ol0000KojBTe@03o`000?n^W<Go[Yc501_o[Yc5
00?o0000okZN_OnjW[d06onjW[d00ol0003oajJiolNV^@06olNV^@?o00003Oo7Z;T00ol0003oajRi
olNX^@02olNX^@05o`000?oD];Woe;BiomBd^Ol00000<?ooool00ol0003oooooooooo`0Vooooo`00
4Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo013o
oooo0_l00015ooooo`;o00002OnV^^L2o`000003oj6ij_l0003oY:CE01SoY:CE1?l000000on^W<Go
0000o`00000Ko`0000?o^Yjm00?o0000okZN_OnjW[d05onjW[d00ol0003oajJiolNV^@09olNV^@?o
00002Oo7Z;T2o`0000?oajRi00?o0000omBd^OoD];T00ooD];T2o`0002kooooo00?o0000oooooooo
ool09_ooool002[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`10ooooo`;o0000
2?nV^^L3o`0000CoXKWZ00?o0000ojBTeOnTY=D03onTY=D7o`0000?oWj;F00?o0000oj^Ka_n[VlH0
6on[VlH00ol0003o^9fmokRM_@02okRM_@Oo00004OnjW[d00ol0003oajJiolNV^@0=olNV^@?o0000
0oo7Z;T3o`000003olNX^Ol0003oajRi00;oajRi00?o0000omBd^OoD];T01OoD];T2o`0002gooooo
00?o0000ooooooooool09Oooool002[ooooo0_l0000Eooooo`03o`000?oooooooooo03gooooo0_l0
0008ojJji`;o00001onQ^NX00ol0003oY:CEojBTe@08ojBTe@Oo00002onOX]H00ol0003oZi_6oj^K
aP0Joj^KaP03o`000?nhWKgo^9fm00Wo^9fm1ol0000:okZN_@03o`000?o7Y[WoajJi013oajJi0ol0
0005olNX^@04o`000?o7Z;WoajRio`0000Woe;Bi0_l0000/ooooo`03o`000?oooooooooo02Cooooo
000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0>_ooool2o`0000SoY[[W0_l0
0009oj6ijP03o`000?nTY=GoY:CE00;oY:CE1_l0000BoinReP03o`000?n[VlKoZi_601[oZi_600?o
0000okRM_OnhWKd04?nhWKd7o`0000?o^Yjm00?o0000olNV^Oo7Y[T03Oo7Y[T3o`0000?oajJi0ol0
0003olNX^@03o`000?o7Z;Wo000000_oe;Bi0_l0000Zooooo`;o00009Oooool002[ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0gooooo`;o00001onV^^L3o`0000_oXKWZ1?l0000I
oinReP03o`000?n[VlKoZi_601WoZi_600?o0000okRM_OnhWKd06?nhWKd5o`0000_oajJi0ol00009
olNV^@?o000000?oajRio`000?oD];T03OoD];T00ol0003oooooooooo`0Wooooo`;o00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1oooool002[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0dooooo`;o00001onV
^^L2o`0000_oXKWZ0ol000000onJ^>go0000oinReP0KoinReP03o`000?n[VlKoZi_601SoZi_600?o
0000okRM_OnhWKd06onhWKd00ol0003oaZJio`000002o`0000GoajJi0ol0000?olNV^@?o00003_oD
];T2o`0002Sooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Kooooo000Zooooo`;o00006Oooool00ol0003ooooooooo
o`0aooooo`;o00001onV^^L2o`0000[oXKWZ0ol00005oiZhk@03o`000?nOX]KoWj;F01?oWj;F1ol0
00000on[VlKo0000o`00000;o`0000coZi_600?o0000okRM_OnhWKd06onhWKd00ol0003oaZJiolJV
^@02olJV^@Go00004oo7Y[T4o`0000koe;Bi0_l0000Wooooo`03o`000?oooooooooo00Gooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Gooooo000Yooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0;_ooool3o`0000KoY[[W0_l00009oj6ijP?o00002OnJ
^>d00ol0003oWj;FoinReP05oinRePgo00001_nJWmP00ol0003oZ9W7ojRIa`0<ojRIa`go00007?nh
WKd00ol0003oaZJiolJV^@02olJV^@?o000000CoaZJio`000?l0003o00004Oo7Y[T01Ol0003oe;>h
omBc^?l0003oe;>h00;o00003_oD];T2o`0002Kooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool002Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0/ooooo`04o`000?nbf?Co/]Sdok;Hm0;o00000_nV^^L00ol0
003oXKWZoj6ijP08oj6ijP;o00003?nJ^>d2o`000003oinRe_l0003o000000?o00004onJWmP00ol0
003oZ9W7ojRIa`0HojRIa`04o`000?nfW;go]YbmokJL_@Go00005?nhWKd00ol0003oaZJio`000002
o`0000OoaZJi0ol0000>olNV^@05o`000?oD/kSoe;>homBc^?l000000_oD/kP00ol0003oe;BiomBd
^@0=omBd^@03o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c007ooooo`00:Oooool3o`0001cooooo
00?o0000ooooooooool0:_ooool00ol0003o/]Sdok;Hm003ok;Hm0;o00002OnQ^NX3o`0000_oV[S]
0ol000000onA]_3o0000oiZOf00HoiZOf003o`000?nXVLOoZ9W701SoZ9W700?o0000okJL_OnfW;d0
1_nfW;d6o`0000go^9fm0ol0000=olJV^@?o00002oo7Y[T01Ol0003oe;>homBc^?oD/kSo000000?o
e;>h0_l0000>omBd^@;o00009?ooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`09ooooo`00:Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo02Sooooo00?o0000ok;Hm?nbf?@00onbf?@01?l0003o[=[hojcJn?l00005oj6i
jP?o00002onJ^>d3o`0000GoTKK`00?o0000oiZOf?nJWmP05onJWmP00ol0003oZ9W7ojRIa`0GojRI
a`03o`000?nfW;go]Ybm00co]Ybm1_l00004okRM_@?o000000?o^9fmo`000?o6Y[T04?o6Y[T3o`00
00OoajJi00?o0000omBc^?oD/kP00ooD/kP00ol0003oe;>homBc^002omBc^0;o00003_oD];T00ol0
003oooooooooo`0Pooooo`?o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool02Oooool002Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Voooo
o`03o`000?nbf?Co/]Sd00?o/]Sd00?o0000ojcJn?n/f_P00_n/f_P00ol0003oXKWZoj6ijP02o`00
00_oV[S]0ol00009oi6fl003o`000?nJWmSoVYoH01KoVYoH00?o0000ojRIaonXVLL05onXVLL00ol0
003o]YbmokJL_@0BokJL_@Go00000_nhWKd00ol0003oaZJiolJV^@0ColJV^@?o00001?o7Y[T00ol0
003oe;>homBc^004omBc^003o`000?oD/kSoe;>h00?oe;>h0_l0000<omBd^@;o00008oooool00ol0
003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Sooooo0006oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Cooooo00?o
0000ok;Hm?nbf?@00onbf?@00ol0003o[=[hojcJn003ojcJn0?o00002_nJ^>d3o`0000coTKK`00?o
0000oiZOf?nJWmP02_nJWmP=o`0000;oZ9W71Ol0000BojRIa`03o`000?nfW;go]Ybm013o]Ybm0ol0
0004okJL_@Co00005oo6Y[T3o`000003olNV^Ol0003oe;>h00Koe;>h00?o0000omBc^?oD/kP01?oD
/kP2o`0000Woe;Bi00Co0000on75_?oQaKco00008oooool00ol0003oooooooooo`0Nooooo`001_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`03ooooo`?o00008Oooool00ol0003oooooooooo`0Rooooo`03
o`000?nbf?Co/]Sd00?o/]Sd00?o0000ojcJn?n/f_P00on/f_P01Ol0003oXm_koj?KnonSfo_o0000
00KoV[S]0ol0000>oi6fl0?o000000?oVYoHo`000?l000002?l0000<oiBNfP03o`000?nTV<SoY9S8
00GoY9S83Ol00005ojRIa`03o`000?nfW;go]Ybm00ko]Ybm0_l00009okJL_@03o`000?o5YKWo0000
00;o00005oo6Y[T2o`0000Ooe;>h00?o0000omBc^?oD/kP01_oD/kP2o`0000Ooe;Bi00Go0000on75
_?oQaKcohLFlo`00000Sooooo`03o`000?oooooooooo01gooooo0004o`0000;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01oooooo0_l00004ok;Hm0;o00001On/f_P0
0ol0003oXm_koj?Kn`03oj?Kn`03o`000?nJ^>goV[S]00?o00003?nA]_05o`0000;oQ[Cc00?o0000
oiBNf_nDW]X05OnDW]X00ol0003oY9S8ojBHb00BojBHb0Ko00003OnfW;d3o`0000_o]Ybm00?o0000
olFU^Oo5YKT00_o5YKT3o`0001CoaZJi00Co0000omBc^?l0003o00001_oD/kP00ol0003oe;>homBc
^007omBc^003o`000?oD];Woe;Bi00?oe;Bi00?o0000on75_?oQaK`00ooQaK`00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01gooooo0006ooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?nbf?Co/]Sd00?o/]Sd00?o0000ojcJn?n/f_P00on/
f_P2o`0000KoXm_k0ol0000:oi6fl0Go00002?n6]?<00ol0003oU9kJoiBNfP0DoiBNfP03o`000?nT
V<SoY9S801OoY9S800?o0000okBK_ondVkl01Ol00003okJL_@?o00003_nfW;d00ol0003oaJFiolFU
^@05olFU^@?o00004?o6Y[T00ol0003oe;>homBc^002omBc^003o`000?oD/kSoe;>h00Coe;>h00?o
0000omBc^?oD/kP01ooD/kP2o`0000?oe;Bi00?o0000on75_?oQaK`01?oQaK`00ol0003ooooooooo
o`0Pooooo`;o00007Oooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo02Cooooo
0_l0000Looooo`03o`000?nbf?Co/]Sd00?o/]Sd00?o0000ojcJn?n/f_P00on/f_P00ol0003oXm_k
oj?Kn`04oj?Kn`;o00000onGf_h2o`0000?oTKK`1Ol0000=ohJdl`03o`000?nDW][oU9kJ01GoU9kJ
00?o0000ojBHb?nTV<P05_nTV<P00ol0003o]9^ookBK_`05okBK_`Co00004?nfW;d00ol0003oaJFi
olFU^@08olFU^@?o00003Oo6Y[T00ol0003oe;>homBc^003omBc^0;o00001OoD/kP00ol0003oe;>h
omBc^008omBc^0;o000000?oe;Bio`000?oQaK`01_oQaK`00ol0003oooooooooo`0Nooooo`03o`00
0?oooooo000001gooooo0006ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0000Wooooo`03o`000?oooooooooo01Sooooo
00?o0000ok;Hm?nbf?@00onbf?@00ol0003o[=[hojcJn002ojcJn0;o00001_nSfo/00ol0003oUm[n
oiOJoP04oiOJoPCo00004?n6]?<4o`000003oiBNf_l0003o000000Wo00002_nDW]X00ol0003oY9S8
ojBHb00FojBHb003o`000?ndVkoo]9^o00;o]9^o0ol00004okBK_`Go00002_nfW;d00ol0003oaJFi
olFU^@0<olFU^@;o00002oo6Y[T00ol0003oe;>homBc^005omBc^0;o00000ooD/kP00ol0003oe;>h
omBc^00:omBc^003o`000?oQaKcohLFl00OohLFl00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Kooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Fooooo`03o`000?nbf?Co/]Sd00;o/]Sd0_l00004ojcJn003o`000?nSfo_oXm_k00Co
Xm_k0_l00005oiOJoP;o00000_n6eol00ol0003oQ[CcohJdl`08ohJdl`Oo00000omh/?H00ol0003o
S9_MohbKg@0:ohbKg@_o00000_nTV<P2o`0001CoY9S800?o0000okBK_ol000000_l0000<okBK_`Co
00001_nfW;d00ol0003oaJFiolFU^@0>olFU^@?o00001oo6Y[T00ol0003oe;>homBc^008omBc^0;o
00000_oD/kP00ol0003oe;>homBc^009omBc^0;o00002OoQaK`00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01[ooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool05?ooool00ol0003o/]Sdok;Hm002ok;Hm003o`000?n/f_So[=[h00?o[=[h00?o0000oj?K
nonSfo/00onSfo/2o`0000GoUm[n0_l00005ohKGo`03o`000?n6]??oQ[Cc00;oQ[Cc1Ol0000;ogR`
mP03o`000?n<VmgoS9_M01?oS9_M00?o0000oj2GbonPUl/00_nPUl/9o`0000[oY9S80ol0000CokBK
_`Go000000?o]Ybmo`000?o5YKT04_o5YKT3o`0000CoaZJi00?o0000omBc^?oD/kP02_oD/kP01?l0
003oe;>homBc^?l00009omBc^004o`000?oRaK_oh/Fko`0000WohLFl00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Jooooo`009oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01;ooooo00?o0000ok;Hm?nbf?@00onbf?@5ojcJn003o`000?nSfo_oXm_k00?oXm_k00?o0000
oiOJo_nGf_h00onGf_h2o`0000OoQ]Oo1?l0000BogR`mP03o`000?n<VmgoS9_M01;oS9_M00?o0000
oj2GbonPUl/02onPUl/:o`000003ojBHb?l0003o]9^o01So]9^o0ol0000EolFU^@?o000000?oaZJi
o`000?oD/kP03?oD/kP3o`0000Woe;>h00Go0000on;5^ooRaK_oh/Fko`000009on75_003o`000?oo
oooooooo01kooooo00?o0000ooooooooool06Oooool002Oooooo0_l0000/ooooo`03o`000?oooooo
oooo013ooooo00?o0000ok;Hm?nbf?@00onbf?@5ojcJn0GoXm_k0_l00004oiOJoP;o00001_n6eol3
o`0000?oLM3n0_l00009ogR`mP[o00000_n<Vmd3o`0000ooS9_M00?o0000oj2GbonPUl/03_nPUl/3
o`000003oj2Gbol0003o000000;o00006_ndVkl00ol0003o`jFjo`000002o`0001GoaJFi0_l0000?
omBc^0;o00001ooD/kP00ol0003oh/Fkon;5^`03on;5^`03o`000?oQaKcohLFl00OohLFl00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`009oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00kooooo0ol00003ok;Hm0Go[=[h1OnSfo/00ol0003oUm[noiOJoP02oiOJ
oP;o00001On6eol3o`0000KoLM3n0ol000000omh/?Ko0000o`000005o`0000WoIZ[g00?o0000oh>I
h?n3VN000on3VN0;o`0000CoS9_M00?o0000oj2GbonPUl/02onPUl/3o`0000OoX9O;00?o0000ok6K
`OnaVl400ol0000EokBK_`03o`000?o3YK[o`jFj00;o`jFj0ol0000BolFU^@04o`000?oD/kWo0000
o`0000ooe;>h0_l00005omBc^003o`000?oRaK_oh/Fk00Coh/Fk00?o0000on75_?oQaK`01ooQaK`0
0ol0003oooooooooo`0Looooo`;o00006_ooool002Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0=ooooo`03o`000?o9k>gobNc]00Wo00000onSfo/5oiOJoP03o`000?n6eoooQ]Oo
00?oQ]Oo0_l00004og7@oPGo00001?mGa?P00ol0003oIZ[gofJZm`0>ofJZm`03o`000?n3VN3oPiWP
00goPiWP1Ol0000:oj2Gb`?o00002_nPUl/00ol0003o/I_1ok6K`@03ok6K`@Co00004?ndVkl00ol0
003o`jFjol>U^P06ol>U^P;o00004?o5YKT01?l0003oe;>iomBc^OoD/kT2o`0000koe;>h0_l00003
omBc^003o`000?oRaK_oh/Fk00Koh/Fk00?o0000on75_?oQaK`01ooQaK`00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Oooooo000Wooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02oooool00ol0003obNc]olW/k@02olW/k@03o`000?o5l>ooaO3_00;oaO3_00?o0000okoc
lOnolo402Ol00003ohKGo`;o00000omad?h3o`0000[oElCh00?o0000ofJZmomVZ_L03OmVZ_L00ol0
003oPiWPoh>Ih00Aoh>Ih003o`000?nKU/goViK=00So00003OnPUl/00ol0003o/I_1ok6K`@07ok6K
`@Co00003?ndVkl00ol0003o`jFjol>U^P08ol>U^P?o00003?o5YKT00ol0003oe;>iomBc^@04omBc
^@;o00003?oD/kP01_l0003oe;>ho`000?l0003oe;>ho`0000Woh/Fk00?o0000on75_?oQaK`01ooQ
aK`00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo000Wooooo`;o0000<?ooool0
0ol0003oooooooooo`0:ooooo`05o`000?o9k>gobNc]olW/kOl000001?o5l>l00ol0003o_o?aokoc
l@02okocl@03o`000?nem?;o]OCb00;o]OCb00?o0000ojOcl_nWlo802Ol00007oeO4n0Oo000000?o
IZ[go`000?l000003Ol0000Coh>Ih004o`000?nKU/goViK=oi^Fc@So00002onPUl/00ol0003o/I_1
ok6K`@0;ok6K`@?o00002OndVkl00ol0003o`jFjol>U^P0;ol>U^P?o00002Oo5YKT00ol0003oe;>i
omBc^@06omBc^@;o00002ooD/kP00ol0003oe;>homBc^002o`0000[oh/Fk00?o0000on75_?oQaK`0
1ooQaK`00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo000Vooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02?ooool01Ol0003obNc]olW/kOo9k>go000000CoaO3_
00?o0000okoclOnolo400_nolo400ol0003o]OCbokGdlP02okGdlP05o`000?nWlo;oYo?bojOcl_l0
00000_nEk_400ol0003oO>G[ogcUj`03ogcUj`Oo00002?lg/nh00ol0003oD:7foe2QmP0;oe2QmP04
o`000?mgU^?oMiKSogNFh`Go00002on3VN001?l0003oViK=o`000?l00008oi^Fc@Go00001_nPUl/0
0ol0003o/I_1ok6K`@0>ok6K`@Co00001OndVkl00ol0003o`jFjol>U^P0>ol>U^P;o00001oo5YKT0
0ol0003oe;>iomBc^@08omBc^@;o00002_oD/kP01Ol0003oe;>ho`000?oSa[_o000000[oh/Fk00?o
0000on75_?oQaK`01ooQaK`00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo000V
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Ol0003obNc]olW/kOo9
k>go000000CoaO3_00Go0000okoclOnolo7o_o?ao`000004okGdlP05o`000?nWlo;oYo?bojOcl_l0
00000_nEk_400ol0003oO>G[ogcUj`02ogcUj`;o00001?mMeN82o`000003ocNck_l0003o000000So
00000_m@XOH2o`0000WoD:7f00?o0000ogNFhomgU^<01OmgU^<5o`0000GoPiWP0ol0000?oi^Fc@Go
000000?oX9O;o`000?naVl404onaVl43o`000003okBK_ol0003o`jFj01;o`jFj0ol00004olFU^@03
o`000?oD/kWoe;>i00[oe;>i00?o0000omBc^?oD/kP02?oD/kP01Ol0003ohlJkon?6^ooSa[_o0000
00[oh/Fk00?o0000on75_?oQaK`01_oQaK`00ol0003oooooooooo`0Looooo`;o00005_ooool002Ko
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?o9k>gobNc]olW/
kOl000001?o5l>l01Ol0003o_o?aokoclOnolo7o000000Co]OCb00Go0000ojOcl_nWlo;oYo?bo`00
0002oiG^l@03o`000?mliN_oO>G[00;oO>G[00Co0000oegEh_mMeN;oGMGR2Ol00003oaFMg@?o0000
0_lEWMd2o`000003ocFDlOl0003o000000Ko00000_m@XOH00ol0003oMiKSogNFh`09ogNFh`Go0000
0_n3VN000ol0003oViK=oi^Fc@0Boi^Fc@;o00005onaVl43o`0001Go`jFj1?l0000>omBc^@;o0000
2?oD/kP00ol0003ohlJkon?6^`02on?6^`03o`000?oRaK_oh/Fk00Soh/Fk00?o0000on75_?oQaK`0
1?oQaK`00ol0003ok=_2o`00000Nooooo`03o`000?oooooooooo01Cooooo000Vooooo`?o0000=?oo
ool00ol0003oooooooooo`04ooooo`05o`000?o9k>gobNc]olW/kOl000000oo5l>l00ol0003o_o?a
okocl@02okocl@05o`000?nem?;o]OCbokGdl_l000000onWlo801?l0003oUNkaoiG^lOl00003ogcU
j`Ko00000_nCl>H00ol0003oL^7Oog;Qg`02og;Qg`go00002?leU?44o`0000WoMiKS0ol00003ogNF
h`?o00005OnKU/d00ol0003o[Y[3ojjJ``03o`0001?o/I_100?o0000ol:U_?l000000_l0000Eol>U
^P;o00003ooD/kT2o`0000Goe;>h00?o0000on?6^ol000001?oSa[/00ol0003oh/Fkon;5^`08on;5
^`03o`000?oQaKcohLFl00;ohLFl00Co0000oncK`_o/fl;o00007oooool00ol0003oooooooooo`0C
ooooo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00Go0000olW/
kOo9k>gobNc]o`000003olG`k`03o`000?nolo7o_o?a00;o_o?a00Go0000okGdl_nem?;o]OCbo`00
0003ojOclP05o`000?nEk_7oUNkao`000?mliN/01Ol00002ojcij004o`000?nCl>KoTo3Vo`0000;o
L^7O1?l00004ojWcl`03o`000?n6io;oQ^Ob00?o00000_l0PlP00ol0003o5XCWo`000002o`0000Ko
=ICa00?o0000ofNAi_mWTNH01ol00008ogNFh`03o`000?nDU=7oU9CA00Co00003onKU/d00ol0003o
[Y[3ojjJ``03ojjJ``Co00003onaVl400ol0003o`ZFlol:U_002ol:U_0;o00004oo3YKX01?l0003o
dkBjo`000?l0000?omBc^@;o00000ooD/kP01?l0003ohlJkon?6^ol00004on?6^`03o`000?oRaK_o
h/Fk00Soh/Fk00Go0000on75_?oQaKcohLFlo`000002oncK`P03o`000?oooooooooo01kooooo00?o
0000ooooooooool04_ooool001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo03Kooooo00Co0000oooooooooooo00000oo9k>d00ol0003oaO3_olG`k`02olG`k`05o`00
0?nolo7o_o?aokoclOl000000onem?801?l0003oYo?bojOcl_nWlo86o`0000;o__cW00?o0000ojci
j?n/nNP00_n/nNP00ol0003oTo3Vo`000003o`0000?o`OO^00?o0000ojWclonYlo<00_nYlo<3o`00
00?o^^Gd1?l00003oaJ4i`Co00000oleU?400ol0003oIi7VofNAiP07o`0000OoMiKS00?o0000oiBD
dOnDU=401?nDU=43o`0000coViK=00?o0000ojjJ`on^V/<01on^V/<3o`0000co/I_100?o0000ol:U
_?o2YK`01?o2YK`3o`0000oo`jFj00?o0000om>d^_oC];X00_oC];X00ol0003oe;>iomBc^@0>omBc
^@;o000000?oe;>ho`000?oSa[/00_oSa[/00ol0003ohlJkon?6^`02on?6^`;o00002OoRaK/00ol0
003ohLFlo`000004oncK`P03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool001_o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Sooooo0ol00003olW/
k@05o`000?o5l>ooaO3_olG`kol000001?nolo401Ol0003o]OCbokGdl_l0003oYo?b00Co00000_o;
o>D00ol0003o__cWokkli`02okkli`04o`000?n/nNSo[?WXojcij0?o00000_o@m^L00ol0003o`OO^
ol7gkP03ol7gkP04o`000?nYlo?o0000o`0000?obnCZ00?o0000ok[Um?njiO@00onjiO@2o`0000Ko
5XCW1_l00007ofNAiP?o00001OmgU^<00ol0003oU9CAoiBDd@06oiBDd@Co00002?nKU/d00ol0003o
[Y[3ojjJ``0:ojjJ``?o00002?naVl400ol0003o`ZFlol:U_008ol:U_0?o00003?o3YKX00ol0003o
dkBjom>d^P03om>d^P;o00004?oD/kT2o`0000?ohlJk00?o0000on?6^ooSa[/01?oSa[/00ol0003o
h/Fkon;5^`07on;5^`03o`000?o/fl;ok=_200?ok=_200?o0000ooooooooool07_ooool00ol0003o
ooooooooo`07ooooo`Co000000?o410@ooooooooool00oooool001_ooooo00Go410@oooooooooooo
oooooa0@4005ooooo`?o0000>Oooool01Ol0003obNc]olW/kOo9k>go000000?oaO3_00?o0000okoc
lOnolo400_nolo400ol0003o]OCbo`000003o`0000;odo[S00Go0000ol_liOo;o>GobocUo`000003
okkli`04o`000?n/nNSo[?WXojcij0;o00001Oo@m^L00ol0003o`OO^ol7gkP02ol7gkP;o00001_o;
i>X2o`0000Go^^Gd1Ol000000olFQ>Oo0000o`000003o`0000_oIi7V1?l000000omgU^?o0000oiBD
d@0;oiBDd@Co00001?nKU/d00ol0003o[Y[3ojjJ``0=ojjJ``Co00001?naVl400ol0003o`ZFlol:U
_00;ol:U_0;o00002_o3YKX00ol0003odkBjom>d^P05om>d^P;o00003_oD/kT00ol0003ohlNlo`00
0003on?6^`03o`000?oSa[_ohlJk00CohlJk00?o0000on;5^ooRaK/01_oRaK/00ol0003ok=_2oncK
`P04oncK`P03o`000?oooooooooo01cooooo0ol0000:ooooo`03o`000?oooooooooo00Gooooo000K
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0iooooo`05o`000?o9
k>gobNc]olW/kOl000000oo5l>l01?l0003o_o?aokoclOnolo43o`000003omSghOl0003odo[S00?o
do[S00Go0000ol_liOo;o>GobocUo`000003okkli`Co000000?of_?Po`000?o@m^L01Oo@m^L01?l0
003o`OO^o`000?l00003omGQh003o`000?o;i>[obnCZ00CobnCZ00Co0000ok[Um?l0003o00000onn
c>D7o`0000;o5XCW00?o0000oeB;j?l000000_l0000:ofNAiP;o00004?nDU=43o`000003oi^FcOl0
003o[Y[301;o[Y[30ol000000onaVl7o0000ol:U_00>ol:U_0?o00001_o3YKX00ol0003odkBjom>d
^P08om>d^P;o00002ooD/kT01Ol0003ohlNlon?7_?oSakco000000?ohlJk00?o0000on?6^ooSa[/0
1?oSa[/00ol0003oh/Fkon;5^`04on;5^`03o`000?o]g<7o000000Gok=_200?o0000ooooooooool0
7_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000Kooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`0hooooo`05o`000?o9k>gobNc]olW/kOl0
00000oo5l>l00ol0003o_o?ao`000002o`0000Cof?OQ00?o0000om?jhooCn^<00_oCn^<01?l0003o
bocUol_liOl00003okkli`;o00001OoJln000ol0003od?KWom3fi`03om3fi`;o00001_oEhN02o`00
00GobnCZ00Co0000okk<iOnnc>Go_/cU0ol000001?nnc>Go0000o`000?l00002o`1_f0Co00000omD
RnP3o`0000SoIi7V00?o0000oh^CeOn;TmD00ol0000>oiBDd@;o00005_n^V/<3o`00017o`ZFl0_l0
0004ol>U^P03o`000?oC];[odkBj00[odkBj00?o0000omBc^OoD/kT02?oD/kT00ol0003ohlNlon?7
_002on?7_005o`000?oSa[_ohlJkon?6^ol000001_oSa[/00ol0003oh/Fkon;5^`02on;5^`04o`00
0?o]g<7okMc1o`0000Kok=_200?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo000Kooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0hooooo`04o`000?o9k>gobNc]o`0000;oaO3_1?l00002omccg`03o`000?oHmn7of?OQ
00;of?OQ00?o0000om?jhooCn^<00_oCn^<01Ol0003obocUol_liOl0003o__cW00;o000000?oh?3K
o`000?oJln001OoJln000ol0003od?KWom3fi`02o`0000?ofmgH00?o0000omGQh?oEhN001?oEhN00
1_l0003obnCZol_Tj_o;i>[o0000olS9f`?o00001_nnc>D3o`0000?o06oH0_l00005oeB;j0?o0000
1OmWTNH00ol0003oRi?Eoh^Ce@03oh^Ce@?o00003?nDU=400ol0003oZI[7ojVJa`03o`0001;o[Y[3
00?o0000oknU_ol000000_l0000@ol:U_0?o000000?o`jFjo`000?oC];X03?oC];X2o`0000Ooe;>i
00?o0000on?7_?oSak`01?oSak`01?l0003ohlJkon?6^ol00007on?6^`05o`000?oRaK_oh/Fkon;5
^ol000000oo]g<400ol0003ok=_2oncK`P03oncK`P03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`006oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_l0000hooooo`04o`000?o9k>gobNc]olW/k@?o000000?ogNoMo`000?oLlml00ooLlml0
0ol0003of?OQomSgh@02omSgh@05o`000?oCn^?odo[Som?jhol000000oo;o>D2o`0000Coh?3K00?o
0000om[ch?oJln000ooJln000ol0003od?KWo`000006om_Mf003o`000?oEhN3oeN7P00CoeN7P00?o
0000ol_Tj_l000000_l00003olS9f`;o00001Onnc>D01?l0003o05S3o`000?l00002o`1_f004o`00
0?lkPNOo0000o`0000GoE8_X0ol00003ofNAiP03o`000?n;TmGoRi?E00GoRi?E0ol00009oiBDd@03
o`000?nYV/OoZI[700?oZI[70ol0000?ojjJ``03o`000?noYKoo_jFo00;o_jFo0_l0000Aol:U_0;o
00003ooC];X2o`0000Goe;>i00?o0000on?7_?oSak`01OoSak`01?l0003ohlJkon?6^ol00007on?6
^`03o`000?oRaK_o000000CokMc100?o0000oncK`_o/fl800oo/fl800ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool001_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo03Oooooo1?l00004omg_g@03o`000?oLlmoog??O
00;og??O00?o0000omSghOoHmn400_oHmn401Ol0003odo[Som?jhooCn^?o000000;obocU0_l00005
on3`f`03o`000?oJln3of_?P00Cof_?P0_l00007om_Mf003o`000?oEhN3oeN7P00;oeN7P0ol00008
olS9f`;o00001Onnc>D01_l0003o05S3o`000?l0003o06oHo`0000;o>h7W0ol00005oeB;j0Co0000
2_n;TmD3o`0000KoU9CA00?o0000ojVJaonYV/L01_nYV/L3o`0000_o[Y[300?o0000oknU_onoYKl0
1OnoYKl3o`0000ko`ZFl00Co0000om:d_?l0003o00003ooC];X01Ol0003oe;>iomBc^OoD/kWo0000
00WohlNl00Co0000on?6^ooSa[_o00001ooSa[/00ol0003okMc1ongL`@03ongL`@03o`000?o/fl;o
k=_200Cok=_200?o0000ooooooooool07_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool0
02Cooooo00?o0000ooooooooool0=oooool2o`0000;ogNcL00?o0000omg_gOoMkmd00_oMkmd00ol0
003og??Oomccg`02omccg`05o`000?oHmn7of?OQomSghOl000001?oCn^<3o`000003on?/e_l0003o
h?3K00Goh?3K00?o0000om[ch?oJln000_oJln001?l0003ogmWAomoIdOl00007om_Mf0Go00000oo?
a]82o`0000Oob<WK0_l000000onnc>Go0000ok>ffP02ok>ffP04o`0oZ_l0003o0000o`0000Go>h7W
0_l00006oeB;j003o`000?n;TmGoRi?E00_oRi?E0ol00003oiBDd@03o`000?nYV/OoZI[700WoZI[7
0ol00008ojjJ``03o`000?noYKoo_jFo00So_jFo0_l0000<ol:U_004o`000?oB];cod[Blom:d_0;o
00003_oC];X2o`000003omBc^Ol0003ohlNl00WohlNl00Co0000on?6^ooSa[_o00001_oSa[/00ol0
003okMc1ongL`@04ongL`@03o`000?o/fl;ok=_200?ok=_200?o0000ooooooooool07Oooool00ol0
003oooooo`000005ooooo`03oeEEEOmVIVKo000000Oooooo000Tooooo`03o`000?oooooooooo03Oo
oooo00Go0000omg/g?oMk=cogNcLo`000004omg_g@03o`000?oLlmoog??O00;og??O00Go0000omSg
hOoHmn7of?OQo`000003om?jh`;o00001?oSk=H00ol0003oh?3Kon3`f`04on3`f`04o`000?oJln3o
f_?Po`0000CogmWA00?o0000om_Mf?oKgMP00ooKgMP3o`000003omGQh?l0003oclKB00GoclKB00?o
0000olS9foo8bM/01_o8bM/00ol0003o/kKJok>ffP03ok>ffP04o`000?l0?j[o0000o`0000Ko>h7W
0_l00004oeB;j003o`000?moT=[o000000;o00003?n;TmD4o`0000koZI[70ol00005ojjJ``03o`00
0?noYKoo_jFo00[o_jFo0_l00009ol:U_003o`000?oB];cod[Bl00Cod[Bl0_l0000>om>d^P;o0000
2ooSak`00ol0003ohlJko`000005on?6^`03o`000?o^g/7o000000GokMc100?o0000oncK`_o/fl80
1?o/fl800ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo000Tooooo`;o0000>?oo
ool01Ol0003ogNcLomg/g?oMk=co000000CogNoM00?o0000omccgooLlml00_oLlml01_l0003of?OQ
omSghOoHmn7o0000om?jh`;o000000?oiNSBo`000?oSk=H01?oSk=H00ol0003oh?3Kon3`f`03on3`
f`03o`000?oJln3o000000KogmWA00?o0000om_Mf?l000000_l00003om_Mf003o`000?o?a];oclKB
00KoclKB0_l00006olS9f`03o`000?nl]=;o000000Go/kKJ1?l00006oc^1i`?o000000?oE8_Xo`00
0?moT=X00omoT=X3o`0000coRi?E00?o0000ojVJaonYV/L03onYV/L3o`000003ojjJ`ol0003o_jFo
00ko_jFo0ol00006ol:U_003o`000?oB];cod[Bl00Kod[Bl0_l0000<om>d^P03o`000?oRb;ko0000
00_ohlNl00?o0000on?6^ol000001?oSa[/00ol0003ok]k1o`000006ongL`@03o`000?o/fl;ok=_2
00?ok=_200?o0000ooooooooool07_ooool3o`0000gooooo000Tooooo`03o`000?oooooooooo03Oo
oooo00Go0000omg/g?oMk=cogNcLo`000004omg_g@05o`000?oLlmoog??Oomccgol000001?oHmn42
o`0000CoiNSB00?o0000on?/e_oSk=H00ooSk=H00ol0003oh?3Kon3`f`02on3`f`?o00001OoOfM43
o`0000GofmgH00Co0000om?4c?oCa<co00002?o?a]82o`0000?ob<WK00Co0000okbdd_nl]=;o_;CB
0_l00005ok>ffP03o`000?l0?j[o000000;o00001_lkPNL3o`0000KoOi3J0ol00009oh^Ce@03o`00
0?nTV/_o000000;o00004?nYV/L2o`0001;o_jFo0_l00004ol:U_003o`000?oB];cod[Bl00Sod[Bl
00?o0000om>d^_oC];X02?oC];X01Ol0003oh/Rnon;8__oRb;ko000000_ohlNl00?o0000on?6^ol0
00000_oSa[/01Ol0003ok]k1onkN`Oo^g/7o000000GokMc100?o0000oncK`_o/fl800oo/fl800ol0
003oooooooooo`0Kooooo`?o00000_ooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003o
ooooooooo`0gooooo`05o`000?oMk=cogNcLomg/g?l000001?oMkmd01Ol0003og??OomccgooLlmoo
000000?of?OQ0_l00005onGXdP03o`000?oSk=KohncF00?ohncF00Go0000on3`fooPl=_oh?3Ko`00
0003on7Fc003o`000?oOfM7o000000;o00000ooOfM401Ol0003ofmgHom_Mf?oKgMSo000000GodlC<
0_l00007olo6dP03o`000?o8bM_o000000Ko_;CB0_l00004ok>ffP;o000000?o067Foaach_l00000
0_l00005oc^1i`03o`000?moT=[oOi3J00OoOi3J0ol00006oh^Ce@03o`000?nTV/_oY9[;00;oY9[;
0ol0000>ojVJa`03o`000?nlY/?o000000;o00004?noYKl4o`0000cod[Bl0_l00008om>d^P03o`00
0?oRb;koh/Rn00;oh/Rn00?o0000on?7_?oSak`02OoSak`01?l0003ohlJko`000?l00004onkN`@03
o`000?o]g<7okMc100CokMc100?o0000oncK`_o/fl800oo/fl800ol0003oooooooooo`0Gooooo`?o
00001Oooool00ol0003oooooooooo`0;ooooo`009?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oMk=cogNcL00;ogNcL00Go0000omg_gOoMkmgogNoMo`000004omccg`06o`000?oHmn7of?OQo`00
0?oViM3o00001OoUj=800ol0003ohncFon?/eP04on?/eP03o`000?oPl=_o000000?ohMK<0ol00007
omoId@03o`000?oKgMSo000000SodlC<00?o0000olo6d_o?a]801Oo?a]800ol0003o_;CBokbddP07
okbddP03o`000?nc]][o/kKJ00;o/kKJ00KoI`00o`000?l0HMKo067Fo`000?lLLn82o`0000?o>h7W
00Co0000og2=gol0003o00002OmoT=X3o`0000?oRi?E00?o0000ojBJbonTV//01OnTV//2o`0000co
ZI[700?o0000okbV`onlY/<00_nlY/<2o`00017o_jFo0_l0000=om:d_0;o00001OoC];X00ol0003o
h/Rnon;8_P04on;8_P;o00002_oSak`3o`0000Gok]k100?o0000ongL`Oo]g<400oo]g<400ol0003o
k=_2oncK`P03oncK`P03o`000?oooooooooo01?ooooo1?l00008ooooo`03o`000?oooooooooo00_o
oooo000Sooooo`?o0000=oooool00ol0003ogNcLomg/g002omg/g005o`000?oMkmgogNoMomg_gOl0
00001?oLlml00ol0003of?OQo`000003onKUd003o`000?oUj=;oiNSB00?oiNSB00?o0000on?/e_oS
k=H01?oSk=H00ol0003ohMK<o`000002o`0000?ohMK<00?o0000omoIdOoOfM401OoOfM400ol0003o
dlC<om?4c008om?4c0;o00001?o?a]801?l0003o`[;;ol:bbol00008okbddP;o00000onc]]X2o`00
00;o067F0_l000001OlLLn;o0000o`000?lkPNOo000000?oL8gO0ol00009ogn@fPCo00002OnTV//3
o`0000WoZI[700?o0000okbV`onlY/<01?nlY/<2o`0000oo_jFo00Co0000om2e_ol0003o00003OoB
];`2o`0000?odkBj00?o0000on;8__oRb;h01_oRb;h00ol0003ohlNlon?7_008on?7_0;o00001Oo^
g/400ol0003okMc1ongL`@03ongL`@03o`000?o/fl;ok=_200;ok=_20_l0000Booooo`?o00003Ooo
ool00ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`05o`000?oMk=co
gNcLomg/g?l000001?oMkmd00ol0003og??Oomccg`02omccg`;o00001?oViM000ol0003oiNSBonGX
dP03onGXdP03o`000?oSk=KohncF00?ohncF0ol00007on7Fc003o`000?oOfM7ogmWA00?ogmWA00?o
0000omG1a_oE`LH00_l00009om?4c0;o000000?oclKBo`000?o2///01?o2///2o`0000Oo_;CB00?o
0000ok>ff_l000000_nSYML01?l0003o067Fo`1Qe_l0HMH2o`000004oaach_l0003o0000o`0000Go
L8gO0_l0000:ogn@fP03o`000?nTV/_oY9[;00[oY9[;0_l00006ojVJa`03o`000?nlY/?o_:K300Oo
_:K30ol0000;oknU_`03o`000?o@]Kood;Fo00;od;Fo00?o0000om:d_?oB];`03?oB];`2o`000003
om>d^_l0003oh/Rn00Soh/Rn00?o0000on?7_?oSak`01ooSak`00ol0003ok]k1o`000005onkN`@03
o`000?o]g<7okMc100?okMc100Ko0000oncK`_o/fl;o0000oncabol0000?ooooo`?o00004?ooool0
0ol0003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`05o`000?oMk=cogNcL
omg/g?l000001?oMkmd01?l0003og??OomccgooLlml2o`0000Koi^G@00?o0000onGXd_oUj=800ooU
j=800ol0003ohncFo`000002o`0000?oh]?800?o0000on7Fc?oQe/`01OoQe/`01Ol0003ogmWAomoI
dOoOfM7o000000GoeL7600?o0000om?4c?oCa<`02?oCa<`00ol0003o`[;;ol:bb`06ol:bb`;o0000
1_nl]=800ol0003oXjGGoj>Ue`02oj>Ue`?o00000_l0HMH2o`000003oaach_l0003oL8gO00KoL8gO
0_l00008ogn@fP03o`000?nLV]3o000000;o00002_nTV//3o`0000?oZI[700?o0000okbV`onlY/<0
2_nlY/<2o`0000Wo_jFo00?o0000om2e_oo@]Kl00oo@]Kl2o`0000kod[Bl0_l0000:on;8_P;o0000
1_oSak`01Ol0003ok^73o`000?o^g/7o000000Cok]k100?o0000ongL`Oo]g<400oo]g<400ol0003o
k=_2o`000002oncab`03o`000?oooooooooo00Wooooo1?l0000Cooooo`03o`000?oooooooooo00[o
oooo000Sooooo`03o`000?oooooooooo03Oooooo00Go0000omg/g?oMk=cogNcLo`000004omg_g@06
o`000?oLlmoo0000o`000?oVh/ko00001_oViM000ol0003oiNSBonGXdP02onGXdP?o000000?ohncF
o`000?oRdlP01?oRdlP00ol0003ohMK<on7Fc005on7Fc003o`000?oOfM7o000000OoeL760_l00008
om?4c004o`000?o6/LGo0000o`0000Oo`[;;0_l00004okbddP03o`000?n/Y<oo000000?oXjGG00Co
0000o`1:`_l0003o00000_l0HMH2o`000003oe^7hol0003oL8gO00KoL8gO0_l00006ogn@fP03o`00
0?nLV]3oW9[@00;oW9[@0_l0000;ojBJb`Co00003_nlY/<2o`0000Ko_jFo00?o0000om2e_oo@]Kl0
1_o@]Kl2o`0000cod[Bl00?o0000on7:`Ol000002ooRb;h00ol0003ohlNlon?7_002on?7_006o`00
0?o^hL?ok^73o`000?o^g/7o00001?o^g/400ol0003okMc1ongL`@04ongL`@05o`000?o/lL_ok?7;
oncabol000002?ooool3o`0001Oooooo00?o0000ooooooooool02_ooool002?ooooo0ol0000goooo
o`05o`000?oMk=cogNcLomg/g?l000001?oMkmd2o`0000Coi^;>00?o0000onKUd?oViM001?oViM04
o`000004onGXd_l0003ohncFo`0000Ooh]?800?o0000on7Fc?oQe/`01OoQe/`2o`0000WoeL760_l0
0005om?4c003o`000?o6/LGoa[7500;oa[750_l00007ol:bb`;o000000?o_;CBo`000?n/Y<l00on/
Y<l2o`0000;oXjGG00?o0000o`1:`_l000000_l0HMH2o`0000;oFhOS0_l00006og2=g`?o00000_mo
T=X00ol0003oW9[@oibJd005oibJd0;o00003?nTV//00ol0003o_:K3okbV``0>okbV``?o00000ono
YKl00ol0003od;Foom2e_`08om2e_`03o`000?oB];cod[Bl00Sod[Bl00Go0000on7:`OoQb/7ohL[1
o`00000;on;8_P05o`000?oSakcohlNlon?7_?l000000oo^hL<00ol0003ok]k1o`000004onkN`@03
o`000?o]g<7okMc100?okMc100Go0000oncaboo/lL_ok?7;o`000005ooooo`?o00006_ooool00ol0
003oooooooooo`0:ooooo`008oooool00ol0003oooooooooo`0gooooo`05o`000?oMk=cogNcLomg/
g?l000000ooMkmd2o`0000Goi^;>00?o0000onKUd?oViM000_oViM03o`0000GoiNSB0_l00008on;C
b003o`000?oQe/cohMK<00CohMK<00?o0000omNo`ol000002_oE`LH01Ol0003odlC<om?4c?oCa<co
000000Ooa[750_l00007ol:bb`03o`000?n/Y<oo[:C?00Go[:C?0_l000000onSYMOo0000o`000002
o`0000;o067F00Co0000oe^7homKQn?oFhOS0_l00007og2=g`?o00002OnLV]03o`0000WoY9[;00?o
0000okRVaol000000_l0000?okbV``;o000000?o_jFoo`000?o@]Kl02_o@]Kl2o`0000Sod[Bl00?o
0000on7:`OoQb/400_oQb/400ol0003oh/Rnon;8_P09on;8_P03o`000?oSakco000000Cok^7300Co
0000onkN`Oo^g/7o00000oo^g/400ol0003okMc1ongL`@02ongL`@;o00000oo/lL/00ol0003ooooo
ooooo`03o`0001gooooo00?o0000ooooooooool02_ooool00005onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003o
ooooooooo`0hooooo`06o`000?oMk=cogNcLomg/g?l0003ogNoM0_l000000ooUglgo0000onKRcP04
onKRcP03o`000?oViM3o000000;o00000_oViM000ol0003oiNSBonGXdP02onGXdP04o`000?oSdLKo
hm76o`0000Soh]?800?o0000on7Fc?oQe/`00_oQe/`01?l0003oeko3omNo`ooG_l<2o`0000WoeL76
0_l000000ooCa<co0000olJaa@08olJaa@03o`000?o2//_o`[;;00Co`[;;00?o0000ok>TbOl00000
1on/Y<l01Ol0003oXjGGo`000?l0003o04[200?o000000?o?WgTo`000?mKQn<00_mKQn<3o`0000Ko
L8gO00?o0000oibJd?nLV]002_nLV]02o`0000KoY9[;00?o0000okRVaonhY/L00onhY/L2o`0000oo
_:K30_l0000=om2e_`;o00001OoB];`00ol0003ohL[1on7:`@04on7:`@03o`000?oRb;koh/Rn00Wo
h/Rn00?o0000onkQ`oo^hL<01?o^hL<00ol0003ok]k1o`000004onkN`@06o`000?o]g<7okMc1o`00
0?o/m<Wo00000oo/lL/3o`00023ooooo00?o0000ooooooooool02_ooool00005ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb
<S;ooooo00?ooooo00?o0000ooooooooool0>?ooool01?l0003ogNcLomg/g?oMk=`2o`0000CoiMo=
00Co0000onKRc_oVh/koi^;>0ol00006onKUd004o`000?oUj=;oiNSBo`0000Cohm7600?o0000on;C
b?oRdlP01_oRdlP01?l0003ohMK<on7Fc?l00006omNo``03o`000?oE`LKoeL7600SoeL7600?o0000
olJaaOo6/LD02Oo6/LD2o`0000?o`[;;00?o0000ok>TbOncY<T00_ncY<T2o`0000Go[:C?0_l00000
1?nSYMOo0000o`000?l0B/82o`0000;o?WgT00?o0000oe^7homKQn<00_mKQn<2o`0000CoL8gO00Co
0000oi:Ieol0003o00002onLV]02o`0000CoY9[;00?o0000okRVaonhY/L01OnhY/L2o`0000go_:K3
00Co0000olffa?l0003o00003Oo@]Kl01Ol0003od[Blom:d_?oB];co000000SohL[10_l00009on;8
_P03o`000?o^hL?ok^7300Gok^7300?o0000onkN`Ol000000oo^g/400ol0003okMc1o`000002oncd
b@05o`000?o/lL_ok?7;oncabol000008oooool00ol0003oooooooooo`09ooooo`0000Go410@oooo
oooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00_ooool2
o`0003Sooooo00Co0000omg/g?oMk=cogNcL0_l00005onGOc@04o`000?oVh/ko0000o`0000;oi^;>
00?o0000onKUd?oViM001?oViM000ol0003oiNSBo`000006on?AaP03o`000?oRdlSoh]?800Koh]?8
00?o0000on7Fc?l000001ooG_l<2o`0000SoeL7600Co0000olR_`Ol0003o00002_o6/LD2o`000003
ol:bbol0003o/jC900Go/jC90_l00005ojbTc`Ko00000olnON@2o`0000CoFhOS0_l00002og2=g`04
o`000?nBVMOoTYWGoi:Ie`;o00002onLV]03o`000003ojBJbol0003o^:K700So^:K70ol00009okbV
``03o`000?o=]/CocKK400;ocKK40_l0000<om2e_`;o000000?od[Blo`000?oQb/402OoQb/400ol0
003oh/Rnon;8_P05on;8_P03o`000?o]hlGo000000Kok^7300Co0000onkN`Oo^g/7o00000oo^g/40
1Ol0003ok?C9oncdbOo/m<Wo000000?ok?7;00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`09ooooo`0000Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`0gooooo`06o`000?oMk=co0000o`000?oTg<go
00001?oUgld3o`0000Goi^;>00?o0000onKUd?oViM001?oViM000ol0003ohm76on?AaP06on?AaP03
o`000?oRdlSoh]?800Koh]?80_l00009omNo``03o`000?oE`LKoeL7600CoeL7600?o0000olR_`Oo8
[l400_o8[l42o`0000[oa[7500?o0000ok>TbOncY<T01oncY<T2o`0000Go[:C?00Go0000og400?l0
003o0000oaU^g`04ocimi0;o00001?mKQn<3o`0000GoTYWG0_l0000<oibJd003o`000?nhY/Oo^:K7
00_o^:K70_l00007okbV``03o`000?o=]/CocKK400CocKK40_l0000<om2e_`;o00002ooQb/400ol0
003oh/Rnon;8_P03on;8_P04o`000?o]hlGokN?5o`0000Ook^7300Co0000onkN`Oo^g/7o00000_o^
g/401Ol0003ok?C9oncdbOo/m<Wo000000?ok?7;00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`09ooooo`0000Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Oooooo0_l00004onCLc@Co
00000_oUgld00ol0003oi^;>onKRcP03onKRcP03o`000?oViM3oi^G@00?oi^G@00?o0000on??a?l0
00002?oSdLH00ol0003oh]?8on;Cb005on;Cb003o`000?oH_[oo000000Woeko30_l00003omG1aP03
o`000?o8[l7ob:o100Gob:o10_l00008olJaa@04o`000?ngXlCo0000o`0000So/jC90_l00003ojbT
c`03o`000?nHVM;o000000;o000000?o6FkOo`000?l000000olnON@00ol0003oFhOSoe^7h`03oe^7
h`03o`000?nBVMOoTYWG00GoTYWG0ol00009oibJd004o`000?nbYlgo0000o`0000co^:K70_l00004
okbV``03o`000?o=]/CocKK400OocKK40_l0000:om2e_`03o`000?oOc<Go000000_ohL[100Go0000
on;8__oRb;koh/Rno`000004ongSa@03o`000?o^hL?ok^7300Cok^7300Go0000onkN`Oo^g/7o0000
onkN`@02o`0000?ok?C900Go0000oncaboo/lL_ok?7;o`00000Sooooo`03o`000?oooooooooo00Wo
oooo00001Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00Co0000onCLcOoTg<goi=c=0ol00005onGO
c@03o`000?oVh/koi^;>00Coi^;>00Go0000onKUd?oViM3oi^G@o`000003on??a003o`000?oSdLKo
hm7600Kohm7600?o0000on;Cb?oRdlP00ooRdlP01?l0003of;joomRn_ooH_[l2o`0000Woeko300?o
0000omG1a_l000002_o8[l42o`0000Goa[7500?o0000okNSa?ngXl@00_ngXl@2o`0000So/jC90ol0
0003oiRIdP;o000000Co05O?oaU^golIK]oo00000olnON@2o`0000?oFhOS00?o0000oh>Gg_l00000
2?nBVML2o`0000OoW9[@00Co0000ok:WcOnbYlgo/ZO=0_l0000<okRVa`?o000000?o_:K3o`000?o=
]/@02_o=]/@00ol0003od;Foom2e_`06om2e_`05o`000?oOc<Goglc5omo<aOl000002ooQb/400ol0
003oh/Rno`000005ongSa@03o`000?o^hL?ok^7300Gok^7300Ko0000onkN`Oo^g/7o0000on_gbOl0
0003oncdb@05o`000?o/lL_ok?7;oncabol000008oooool00ol0003oooooooooo`09ooooo`0000Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`06ooooo`;o0000>?ooool4o`0000;oi=c=00?o0000onGOcOoUgld01?oUgld00ol0003o
i^;>onKRcP03onKRcP04o`000?oViM3oi^G@o`0000Gohlo400?o0000on?Aa_oSdLH01_oSdLH01Ol0
003oh]?8on;Cb?oRdlSo000000Kof;jo00?o0000omNo`ooG_l<01ooG_l<00ol0003ob:o1olR_`@0;
olR_`@;o00000oo6/LD00ol0003o]j?4okNSa004okNSa0?o00001oncY<T2o`0000?oV9WB0_l00000
0ol0Eloo0000oaU^g`02o`0000?o?WgT0_l000000omKQn?o0000oh>GgP02oh>GgP;o00001onBVML2
o`0000GoW9[@00?o0000ok:WcOnbYld00onbYld2o`0000go^:K70_l0000<olffa0;o00001_o@]Kl0
0ol0003oglc5omo<a@02omo<a@;o00002_oQb/400ol0003okN?5ongSa@05ongSa@03o`000?o^hL?o
k^7300Cok^7300Co0000onkN`Ol0003ojoO90_l00003oncdb@05o`000?o/lL_ok?7;oncabol00000
8oooool00ol0003oooooooooo`09ooooo`0000Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Cooooo00?o0000ooooooooool0=_ooool4o`0000Go
i=c=00?o0000onGOcOoUgld00ooUgld00ol0003oi^;>onKRcP03onKRcP03o`000?oViM3o000000Oo
hlo400?o0000on?Aa_oSdLH01_oSdLH00ol0003oh]?8o`000008omRn_`;o00001ooG_l<01?l0003o
bjjno`000?l0000<olR_`@;o000000?oa[75o`000?ngXl@02?ngXl@2o`0000Go/jC900Co0000oj6I
cOl0003o00000_nHVM801_l0003o03^eo`1Gcol0Eloo0000oaU^g`;o00000olnON@2o`0000GoPiON
0_l00007oi:Ie`;o00000_nLV]000ol0003o/ZO=ok:Wc@06ok:Wc@;o00002onhY/L01?l0003ob[S9
o`000?l0000<olffa0;o00000oo@]Kl00ol0003oglc5omo<a@05omo<a@03o`000?oQb/7ohL[100Oo
hL[100?o0000ongSaOo]hlD01Oo]hlD00ol0003ok^73onkQ``05onkQ``05o`000?o[mlWojoO9on_g
bOl000000oo/m<T01Ol0003ok?7;oncaboo/lL_o000002?ooooo00?o0000ooooooooool02Oooool0
027ooooo00?o0000ooooooooool0<oooool3o`0000?ooooo00?o0000onCLcOoTg<d00ooTg<d00ol0
003oiMo=onGOc@03onGOc@03o`000?oVh/koi^;>00?oi^;>0_l00009on??a003o`000?oSdLKohm76
00Kohm760_l0000:omRn_`03o`000?oG_l?oeko300?oeko300?o0000ol^^__o;[[h00_o;[[h2o`00
00cob:o100?o0000okNSa?ngXl@02_ngXl@2o`0000?o/jC900Co0000oj6IcOnQVLgoXIW=0_l00000
1OnHVM;o0000o`0k]Ol0003o05O?00;o000000?o6FkOo`000?lnON@00_lnON@00ol0003oPiONoh>G
gP05oh>GgP;o00001onBVML3o`0000[o/ZO=0_l00008okRVa`03o`000?o:^<Wob[S900;ob[S900?o
0000olffa?o=]/@02oo=]/@2o`000003om2e_ol0003oglc500Ooglc500?o0000on7:`OoQb/401OoQ
b/400ol0003ok>K8o`000007ongSa@03o`000?o^hL?ok^7300?ok^730_l00003on_gb@05o`000?o/
m<Wok?C9oncdbOl000000oo/lL/00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo
000Qooooo`03o`000?oooooooooo033ooooo0ol00006ooooo`03o`000?oTg<goi=c=00Coi=c=00?o
0000onGOcOoUgld00ooUgld01Ol0003oi^;>onKRc_oVh/ko000000;oh/g300?o0000on??a?oScl@0
1ooScl@00ol0003ohm76on?AaP05on?AaP03o`000?oI_;go000000[of;jo0_l00002omNo``03o`00
0?o;[[kobjjn00Gobjjn0ol00009olR_`@04o`000?nkX/3o0000o`0000_o]j?40ol00006oj6Ic@?o
000000Ko03^eo`000?l0Eloo05O?o`000?lIK]l2o`000004ocimi?l0003oKY;To`0000OoPiON00?o
0000oi:IeonBVML01_nBVML00ol0003o/ZO=ok:Wc@0:ok:Wc@;o00001_nhY/L00ol0003ob[S9olZh
b@03olZhb@;o00003Oo=]/@2o`0000Woglc50_l00004on7:`@05o`000?o/i/Sok>K8oncVb?l00000
1_o]hlD00ol0003ok^73onkQ``02onkQ``03o`000?oYnLWo000000?ojoO90_l00002oncdb@03o`00
0?o/lL_ok?7;00;o00009?ooool00ol0003oooooooooo`08ooooo`008Oooool2o`0002kooooo0ol0
000:ooooo`03o`000?oTg<goi=c=00?oi=c=00?o0000onGOcOoUgld00ooUgld01?l0003oi^;>onKR
c_l00004on;=``03o`000?oSclCohlo400Oohlo400?o0000on?Aa_oSdLH00ooSdLH01?l0003ofKbm
omVl_OoI_;d2o`0000[of;jo00?o0000omNo`ol000002_o;[[h2o`0000Kob:o100?o0000ok^R`?nk
X/000_nkX/03o`0000[o]j?40_l00008oj6Ic@06o`000?l0>kGo03^eo`000?l0Eloo00000_lIK]l2
o`0000?oKY;T00?o0000oh>Gg_n3Umh01?n3Umh2o`0000KoTYWG00Co0000ojZWe?l0003o00002onb
Yld2o`0000?o^:K700?o0000olZhbOo:^<T01_o:^<T2o`0000_ocKK400?o0000omg>bOl000002_oO
c<D01Ol0003ohL[1on7:`OoQb/7o000000?ok>K800?o0000ongSaOo]hlD01Oo]hlD01?l0003ok^73
onkQ`ol00002onWib@0=o`000?o[mlWojoO9on_gbOl0003ok?C9o`000?o/m<Wo0000oncabol0003o
fOgHo`00000Tooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo02[ooooo
0ol0000=ooooo`03o`000?oTg<goi=c=00?oi=c=00?o0000onGOcOoUgld00ooUgld00ol0003oi^;>
o`000006on;=``03o`000?oSclCohlo400Oohlo400Go0000on?Aa_oSdLKohm76o`000006omVl_@03
o`000?oH_[oof;jo00Sof;jo00?o0000ol^^__o;[[h02oo;[[h2o`0000?ob:o100?o0000ok^R`?nk
X/001_nkX/02o`0000So]j?400Co0000ojNIb?l0003o00002?nQVLd01?l0003o03^eo`000?l0Ell2
o`000003oaU^gol0003oKY;T00?oKY;T0_l00006oh>GgP;o00000onBVML00ol0003oZZODojZWe002
ojZWe0;o00002onbYld2o`000003okRVaol0003ob[S900Wob[S90_l00008olffa005o`000?oMc/Wo
gLk9omg>bOl000002_oOc<D00ol0003ohL[1o`000005oncVb003o`000?o]hlGokN?500CokN?500?o
0000onkQ`ol000000ooYnLT01Ol0003ojoO9on_gbOo[mlWo000000;ok?C90ol000000ooIoMSo0000
ooooo`0Tooooo`03o`000?oooooooooo00Sooooo000Qooooo`03o`000?oooooooooo02Oooooo0ol0
000@ooooo`03o`000?oTg<goi=c=00Coi=c=00?o0000onGOcOoUgld00ooUgld00ol0003oh/g3on;=
``06on;=``03o`000?oSclCohlo400Oohlo400?o0000on?Aa_l000002?oI_;d2o`0000Sof;jo00Co
0000olb^^ol0003o00003?o;[[h2o`000003olR_`Ol0003o^j;000Wo^j;00_l00006okNSa004o`00
0?nWVLSoYiW8ojNIb0?o00001onQVLd3o`000004o`1Gcol0003o0000odn9j0GoKY;T0_l00006oh>G
gP;o000000?oTYWGo`000?nZYm@01OnZYm@2o`0000_o/ZO=00?o0000olZhbOo:^<T02oo:^<T2o`00
00GocKK400?o0000omg>bOoMc/T00ooMc/T00ol0003oglc5omo<a@08omo<a@03o`000?o/i/Sok>K8
00Gok>K800?o0000ongSaOo]hlD01?o]hlD00ol0003ojOW9onWib@02onWib@05o`000?o[mlWojoO9
on_gbOl000000_o/m<T2o`0000;ofOgH00?o0000ooooooooool08oooool00ol0003oooooooooo`08
ooooo`008?ooool00ol0003oooooooooo`0Uooooo`?o00005?ooool00ol0003oi=c=onCLc@03onCL
c@03o`000?oUglgoiMo=00?oiMo=00?o0000on;=`ooRcL<01ooRcL<00ol0003ohlo4on??a007on??
a0;o00002_oI_;d00ol0003of;joomRn_`04omRn_`03o`000?o<[[_oc:jk00;oc:jk0_l0000<ol^^
_P03o`000?nkX/3o^j;000_o^j;00ol00002okNSa003o`000?nWVLSoYiW800GoYiW80_l00006oj6I
c@05o`000?l0>kGo0000o`1Gcol000000om?RNP00ol0003oKY;TofjBi002ofjBi0;o00001_n3Umh0
0ol0003oZZODojZWe007ojZWe0?o00002?nbYld01?l0003oaKW?o`000?l0000<olZhb@03o`000?o=
]/CocKK400;ocKK400?o0000omg>bOoMc/T01?oMc/T2o`0000Soglc500?o0000oncVb?o/i/P01Oo/
i/P00ol0003okN?5ongSa@04ongSa@03o`000?oYnLWojOW900;ojOW900Go0000on_gbOo[mlWojoO9
o`000002oncdb@;o000000?ofOgHo`000?ooool09Oooool00ol0003oooooooooo`08ooooo`008?oo
ool2o`0002?ooooo0ol0000Gooooo`03o`000?oTg<goi=c=00Coi=c=00Oo0000onGOcOoUglgoiMo=
o`000?oRc<;o000000Woh/g300?o0000on??a?oScl@01_oScl@00ol0003ofK^lo`00000:omVl_@03
o`000?oH_[oof;jo00?of;jo00?o0000olb^^oo<[[/01?o<[[/2o`0000[objjn00?o0000okfR_Ol0
00000_l0000<ok^R`0?o00002OnWVLP2o`0000GoXIW=1?l000001?lTN>CoChWXodn9j?m?RNP2o`00
00CoKY;T0_l00004oh>GgP03o`000?nNYmco000000[oZZOD0_l00005ok:Wc@03o`000?o5^LooaKW?
00;oaKW?0_l0000;olZhb@;o000000?ocKK4o`000?oMc/T02?oMc/T00ol0003oglc5omo<a@04omo<
a@03o`000?oZjLgo000000Ook>K800?o0000ongSaOo]hlD00_o]hlD2o`0000?ojOW900?o0000on_g
bOo[mlT00_o[mlT01Ol0003ok?C9o`000?l0003ofOgH00;o00009_ooool00ol0003oooooooooo`08
ooooo`008?ooool00ol0003oooooooooo`0Pooooo`;o00006_ooool00ol0003oi=c=onCLc@04onCL
c@04o`000?oUglgoiMo=o`0000?oh/c200?o0000on;=`ooRcL<01ooRcL<00ol0003ohlo4on??a004
on??a004o`000?oI^kcofK^lomVk_0;o00002OoI_;d2o`0000;of;jo00?o0000olb^^oo<[[/01oo<
[[/2o`0000Oobjjn00?o0000okfR_OnmX[d00onmX[d2o`0000co^j;00_l0000:ojNIb0?o00000_nQ
VLd4o`0000;o97ST0_l00002odn9j0;o00001?m^T^@01Ol0003oPiONoh>Gg_n3Umko000000?oWZOL
0_l00009ojZWe0;o00000onbYld00ol0003oaKW?olFic`04olFic`;o00002oo:^<T2o`0000[ogLk9
00?o0000omo<aOoOc<D00_oOc<D01Ol0003oj^W=on[YcOoZjLgo000000Kok>K800Oo0000ongSaOo]
hlGokN?5o`000?oUo<[o000000?ojOW900?o0000on_gbOo[mlT00_o[mlT2o`000005omCoe?l0003o
fOgHomWmf?l000009oooool00ol0003oooooooooo`07ooooo`008?ooool00ol0003oooooooooo`0M
ooooo`?o00007Oooool00ol0003oi=c=onCLc@03onCLc@03o`000?oUglgo000000Goh/c200?o0000
on;=`ooRcL<01ooRcL<00ol0003ohlo4on??a002on??a003o`000?oI^kcofK^l00CofK^l00?o0000
omVl_OoI_;d02?oI_;d00ol0003of;joo`00000;olb^^`;o00001Oo;[[h00ol0003o_J:mokfR_@05
okfR_@?o00002OnkX/000ol0003o[9W4o`000002o`0000[oYiW80ol000001?n8T]Oo0000o`000?l0
GM83obAhi0;o00000_m?RNP2o`0000?oKY;T0ol00006oijWg0;o00002OnZYm@2o`000003ok:WcOl0
003oaKW?00OoaKW?00?o0000olZhbOo:^<T02?o:^<T00ol0003ofM3@o`00000:omg>b@05o`000?oO
c<Goglc5omo<aOl000000ooZjLd00ol0003ok>K8oncVb005oncVb003o`000?o]hlGo000000;oiOc:
00Go0000onWibOoYnLWojOW9o`000003on_gb@;o000000Coe?oDo`000?oIoMSofOgH0_l0000Woooo
o`03o`000?oooooooooo00Oooooo000Pooooo`03o`000?oooooooooo01[ooooo0ol0000Pooooo`03
o`000?oTg<goi=c=00Coi=c=00?o0000on;<`_oRc<801OoRc<800ol0003oh/g3on;=``07on;=``05
o`000?oSclCohlo4on??a?l000001ooI^k`00ol0003ofKbmomVl_@08omVl_@;o00003Oo<[[/2o`00
00?objjn00?o0000okfR_OnmX[d02?nmX[d2o`0000Ko^j;000?o0000ojbIa?n/VL@00on/VL@2o`00
00[oYiW80_l00002ohRBe`03o`000?l0GM;o000000?o97ST00Go0000odn9j?m?RNSoChWXo`000004
ofjBi003o`000?nNYmcoWZOL00KoWZOL0_l00009ojZWe003o`000?o5^LooaKW?00SoaKW?0_l00007
olZhb@05o`000?oId=3ofM3@omW@d?l000002_oMc/T00ol0003oglc5o`000005on[Yc@03o`000?o/
i/Sok>K800Cok>K80_l00003onGlbP06o`000?oYnLWojOW9onWibOl0003ojoO90_l000001?o<om3o
0000omCoe?l00002omWmf003o`000?oooooo000002Kooooo00?o0000ooooooooool01oooool0023o
oooo0ol0000Gooooo`?o00008oooool00ol0003oi=c=onCLc@03onCLc@;o00002?oRc<800ol0003o
h/g3on;=``07on;=``03o`000?oSclCo000000WofK^l0_l00008omVl_@04o`000?o=[K[o0000o`00
00goc:jk0ol0000=okfR_@;o00001?nkX/000ol0003o[9W4ojbIa005ojbIa0?o00001onWVLP01Ol0
003oTY?Bo`000?l0003oR9;G00;o000000Co05gBo`000?lTN>Co97ST0_l00002odn9j0;o000000Go
KY;To`000?n=YNKoSJGVo`000008oijWg0;o00001onZYm@00ol0003o_K_Ho`00000:olFic`;o0000
1?o:^<T00ol0003ofM3@omW@d003omW@d0;o00002OoMc/T00ol0003oj^W=on[Yc@05on[Yc@03o`00
0?o/i/Sok>K800;ok>K800?o0000omoncOl000000ooUo<X01?l0003ojOW9onWibOoYnLT2o`0000;o
c?o@00?o0000omCoe?l000000_oIoMP01Ol0003ooooooooooooooooo000002Gooooo00?o0000oooo
ooooool01oooool001oooooo0_l0000Fooooo`?o00009oooool01Ol0003oi=c=onCLcOoTg<go0000
00;oh<[200?o0000on;<`_oRc<801_oRc<800ol0003oh/g3on;=``07on;=``;o00002ooI^k`00ol0
003ofKbmomVl_@04omVl_@03o`000?o=[K[ocJfj00;ocJfj0_l0000=olb^^`03o`000?nmX[go_J:m
00go_J:m0ol000000onkX/3o0000ojbIa009ojbIa0;o00001OnWVLP01?l0003oTY?Boi:Cd_nBTm85
o`000004o`1Md_l0003o97STobAhi0;o00000_m?RNP00ol0003oSJGVohfUiP03ohfUiP03o`000?nN
YmcoWZOL00KoWZOL0_l00004ojZWe004o`000?nm^mSo_K_Hokfkf0;o00002_o5^Ll2o`000003olZh
bOl0003ofM3@00OofM3@00?o0000omg>bOoMc/T01_oMc/T00ol0003oj^W=on[Yc@05on[Yc@05o`00
0?o/i/Sok>K8oncVb?l000000_oOo/d01Ol0003oiOc:onGlb_oUo<[o000000;ojOW90_l00003olco
d003o`000?oDomCo000000;ofOgH00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Oooooo0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo0ol0000Z
ooooo`04o`000?oTg<goi=c=o`0000Coh<[200?o0000on;<`_oRc<801_oRc<800ol0003oh/g3on;=
``06on;=``03o`000?oI^k_o000000_ofK^l0_l00004omVl_@03o`000?o=[K[ocJfj00CocJfj0_l0
000;olb^^`03o`000?noX[_o000000;o00003_nmX[d3o`0000_o[9W40_l00003ojNIb003o`000?nB
Tm;oTY?B00CoTY?B0ol000000ol0GM;o0000o`000002obAhi004o`000?m?RNSo0000og6OkPGoSJGV
0_l00008oijWg0;o000000?oZZODo`000?nm^mP01Onm^mP2o`0000[oaKW?0_l00009omW@d0;o0000
1OoMc/T00ol0003oi^cCo`000007on[Yc@03o`000?o/i/So000000?ogok=00Wo0000onGlb_oUo<[o
iOc:o`000?oYnLWo0000ol7nc?l000000_o<om000ol0003oe?oDo`000002omWmf003o`000?oooooo
oooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool03oooool3o`0002gooooo00?o0000onCLcOl000001_oPb/800ol0003oh/c2on;<`P06
on;<`P03o`000?oRcL?oh/g300Coh/g300Co0000omVk^ooI^k_ofK^k0_l0000;omVk_004o`000?oI
_;gofKbmo`0000WocJfj0ol00007olb^^`03o`000?noX[_o_j:k00?o_j:k0_l0000<okfR_@03o`00
0?n_VL7o[iW100?o00002_n/VL@4o`0000SoTY?B0ol000000ol0GM;o0000obAhi002o`0000?oLIo^
0_l00004ohfUiP;o00002?nNYm`00ol0003o_K_Hokfkf007okfkf003o`000?o5^LooaKW?00OoaKW?
00?o0000omCCf?l000002_oId=001Ol0003ogLk9omg>bOoMc/Wo000000?oi^cC00?o0000on[YcOoZ
jLd01OoZjLd00ol0003ogok=omonc@02omonc@04o`000?oUo<[oiOc:onGlbP;o000000Go`Ok<o`00
0?o<om3oc?o@o`000002omCoe004o`000?oIoMSofOgHo`0000Kooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`07ooooo`001?ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`?o0000<Oooool00ol0003oh<[2on3:
`P06on3:`P03o`000?oRc<;oh/c200Koh/c200?o0000on;=`ooRcL<00_oRcL<00ol0003ofK^komVk
^`04omVk^`03o`000?oI^kcofK^l00WofK^l00?o0000omVl_Ol000003?o=[KX2o`0000Goc:jk00?o
0000oknR^onoX[/01OnoX[/3o`0000Wo_J:m00?o0000ojnI`On_VL400on_VL43o`0000[o[9W40ol0
0007oi:CdP?o000000?o05gBo`000?m8T^l00_m8T^l4og6OkP;o00001?n=YNH2o`0000KoWZOL00?o
0000ok:lh_l000002?nm^mP2o`0000KoaKW?00Co0000omCCf?oDdmSoe=?H0_l00009omW@d003o`00
0?oMc/Wo000000Goi^cC00?o0000on[YcOoZjLd00ooZjLd2o`0000Cogok=00Go0000onGlb_oUo<[o
iOc:o`000002ol7nc004o`000?o<om3oc?o@o`0000;oe?oD00Co0000omWmf?oIoMSo00001oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo0004ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`04ooooo`;o00002_ooool3o`0003Cooooo00?o0000
on3:`_oPb/801ooPb/800ol0003oh/c2on;<`P06on;<`P05o`000?oRcL?oh/g3on;=`ol000001ooI
^k/2o`0000[ofK^l0_l0000>olf]^P;o00000oo<[[/00ol0003o_j:koknR^`08oknR^`?o00001_nm
X[d00ol0003o[iW1ojnI`@06ojnI`@?o00001on/VL@00ol0003oVIC=oiVDc@03o`0000KoTY?B0_l0
0002oa1hh`?oB9;_0_l00003og6OkP03o`000?n=YNKoSJGV00?oSJGV00?o0000oijWg?nNYm`00_nN
Ym`00ol0003o/[cRok:lhP02ok:lhP;o00001onm^mP2o`0000?oaKW?00?o0000omCCf?oDdmP01?oD
dmP2o`0000SofM3@00?o0000onK/dooVk=<01OoVk=<01ol0003oj^W=on[YcOoZjLgo0000omOod?l0
00001?oOo/d00ol0003oiOc:onGlbP02o`000005ol7nc?l0003oc?o@olcod?l000000_oDom@01?l0
003ofOgHomWmf?l00009ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool0
00Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`06ooooo`?o0000>?ooool00ol0003oh<[2on3:`P07on3:`P03o`000?oR
c<;oh/c200Koh/c200?o0000on;=`ol000002_oI^k/00ol0003ofK^lomVk_007omVk_004o`000?o=
[KWo0000o`0000kocJfj0ol0000>oknR^`;o00000onmX[d00ol0003o[iW1ojnI`@0:ojnI`@?o0000
1?n/VL@00ol0003oVIC=oiVDc@03oiVDc@Co00000onBTm801Ol0:9Oo0573oa1hhol@N>?o000000?o
B9;_00Co0000og6Ok_maWnkoLIo^0_l00004ohfUiP;o000000?oWZOLo`000?nb_>801_nb_>82o`00
00Oo_K_H00?o0000olFicol000002OoDdmP00ol0003ofM3@omW@d004omW@d0;o00002?oVk=<00ol0
003oj^W=o`000002omOod003o`000?oOo/gogok=00;ogok=00Co0000onGlb_l0003o00000_o1o/`0
1?l0003oc?o@olcod?l00002omCoe004o`000?oIoMSofOgHo`0000Wooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`06ooooo`001?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`?o0000??ooool00ol0003oh<[2
on3:`P06on3:`P03o`000?oRc<;oh/c200Ooh/c20_l0000;omVk^`;o00001_oI^k`00ol0003ocJfi
olf]^@02olf]^@?o00003Oo=[KX00ol0003o_j:koknR^`0>oknR^`Co00003on_VL43o`000003ojbI
a?l0003oVIC=00SoVIC=0ol00002oi:CdP;o00000_l@N><00ol0003oB9;_odRBk`02o`0000?oLIo^
0_l00003ohfUiP;o00002_nb_>800ol0003o_K_Hokfkf005okfkf003o`000?oDdmSoe=?H00Woe=?H
0_l00003omW@d004o`000?oOl=_ogo3Ko`0000Soi^cC00Go0000omOod?oGom3oeoo@o`000004omon
c@?o00000_o1o/`01?l0003oc?o@olcod?l00002omCoe004o`000?oIoMSo0000o`0000_ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`06ooooo`001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool3o`00043ooooo
00?o0000on3:`_oPb/801_oPb/800ol0003oh/c2on;<`P06on;<`P03o`000?oH^[_o000000cofK^k
00?o0000omVk_?oI^k`00ooI^k`00ol0003ocJfiolf]^@05olf]^@;o00002oo=[KX00ol0003o`J:i
o`000002o`0000oo_j:k0ol0000@ojnI`@Co00002_nIU<d3o`000003o`0XUol0003o000000;o47SS
00Co0000odRBkom8T^oo00001?maWnh00ol0003oSJGVo`000003oj2lk0;o00002?nb_>82o`0000Co
_K_H00?o0000ol_Fh_o;e^800_l0000:omCCf003o`000?oId=3o000000Cogo3K00?o0000onK/dooV
k=<00ooVk=<00ol0003obooCo`000003omOod004o`000?oOo/gogok=omonc@;o000000Co/o[8o`00
0?o1o/co00000_o<om001?l0003oe?oDomCoe?oDom@3o`0000gooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`06ooooo`001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0005ooooo`Co0000A?ooool00ol0003oh<[2on3:`P06on3:`P03o`000?oRc<;oh/c200Coh/c200Co
0000omRj^ooH^[_of;Zk0_l0000;omVk^`;o00000_oI^k`00ol0003ocJfiolf]^@08olf]^@;o0000
2?o=[KX00ol0003o`J:iol6R^@03ol6R^@?o00003?noX[/00ol0003o/YZnok:J_P03o`0000ko[iW1
00?o0000oinFb_nOU/X00ol0000:oiVDc@Go000000Co47SSo`000?l0003oB9;_0_l00003og6OkP03
o`000?nP_>coX;c/00CoX;c/0_l00008ok:lhP;o000000?o_K_Ho`000?o;e^801?o;e^800ol0003o
e=?HomCCf008omCCf003o`000?oOl=_ogo3K00Cogo3K00Go0000onK/dooVk=?oi^cCo`000002ol_o
d`06o`000?oGom3oeoo@omOod?l0003ogok=0_l000000onQll?o0000o`000002ol7nc003o`000?o<
om3oc?o@00Co000000?o__W]o`000?ooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Kooooo000Nooooo`;o0000Aoooool00ol0003oh<[2on3:`P06on3:`P03o`000?oRc<;o
h/c200;oh/c200?o0000omRj^ooH^[/01?oH^[/00ol0003ofK^komVk^`0:omVk^`03o`000?oI^kco
000000cocJfi0_l00006olf]^P03o`000?o1X[Wo`J:i00Ko`J:i0ol00009oknR^`03o`000?nbV[ko
/YZn00?o/YZn0ol0000;ojnI`@03o`000?nOU/[oWiK:00?oWiK:0ol00008oiVDc@03o`000?n0Un3o
000000;o00000_l@N><01_l0003oB9;_odRBkol0003oLIo^o`0000;oPkOf00?o0000oj2lk?nP_>`0
1?nP_>`2o`0000So/[cR00?o0000ol_Fh_o;e^801Oo;e^82o`0000Koe=?H00Co0000omGci?oElnCo
00001_oOl=/00ol0003oi^cCo`000003ol_od`04o`000?oGom3oeoo@omOod0;o00000_nQll<2o`00
00;o`Ok<00?o0000olcod?l000000ol00002okkik@03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`06ooooo`008?ooool00ol0003oooooooooo`15ooooo`03
o`000?oPb/;oh<[200Koh<[200Go0000on;<`_oRc<;oh/c2o`000007omRj^`;o00002ooI^k/2o`00
00kocJfi0ol00003olf]^P03o`000?o1X[Wo`J:i00Wo`J:i0_l00007oknR^`03o`000?nbV[ko/YZn
00Ko/YZn1?l00007ojnI`@03o`000?nOU/[oWiK:00KoWiK:0ol00005oiVDc@05o`000?n0Un3oP9OP
oh2Gh?l0G<@01ol00005oh>gmP;o00001OnP_>`2o`0000Co/[cR00Go0000okcHk_nlf>ko_=S^o`00
0007ol_FhP;o00000ooDdmP00ol0003oeO?TomGci002omGci003o`000?oOl=_ogo3K00Cogo3K00?o
0000ol_odoo;om<00_o;om<00ol0003oeoo@omOod002o`0000;oXO?300?o0000ok?jb?l000000_o1
o/`2o`0000;o/oWZ00Co0000okkikOnnnNgo00004_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000on3:`_oPb/801_oP
b/800ol0003oh/c2o`00000:omRj^`03o`000?oI^k_ofK^k00SofK^k00Co0000olj]^?l0003o0000
3oo=[KT3o`0000ko`J:i0ol00003oknR^`03o`000?nbV[ko/YZn00_o/YZn0ol00004ojnI`@03o`00
0?nOU/[oWiK:00WoWiK:0ol00003oiVDc@03o`000?n0Un3oP9OP00;oP9OP00Co05c4oaV9jOlIRNWo
6HWY0omGYoP00ol0003oPkOfoh>gmP03oh>gmP03o`000?nP_>coX;c/00CoX;c/0_l000000onb_>;o
0000okcHkP04okcHkP;o00001oo;e^800ol0003oe=?Ho`000006omGci007o`000?oOl=_ogo3Komo`
fol0003o^OgGo`000004ol_od`Co00000_nQll<00ol0003o/o[8o`000004o`0000;o/oWZ00Co0000
okkikOnnnNgo00005?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo000R
ooooo`03o`000?oooooooooo04Cooooo00?o0000on3:`_oPb/801ooPb/82o`0000_of;Zk00?o0000
omVk^ooI^k/01_oI^k/00ol0003ocZfholj]^002olj]^0;o00003oo=[KT00ol0003o`J:iol6R^@0?
ol6R^@Co00004?nbV[h3o`000003ojnI`Ol0003oWiK:00goWiK:1?l00005oh2Gh0?o00000_lIRNT0
0ol0003oEjOhoeNWn002o`0000?oPkOf0_l00006oj2lk003o`000?nlf>ko_=S^00Ko_=S^00?o0000
ol_Fh_o;e^801Oo;e^82o`0000OoeO?T00?o0000omo`fol000000_nioML01?l0003obooCol_odoo;
om<2o`000004oh_Y_Ol0003oXO?3oj7c``Go000000GoYOOUo`000?ncnN[o/oWZo`000002okkik@03
o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`00
8oooool2o`0004Gooooo00?o0000on3:`_oPb/801_oPb/800ol0003of;Zlo`00000;omRj^`;o0000
1_oI^k/00ol0003ocZfholj]^004olj]^0;o00003Oo=[KT00ol0003o`Z:ho`000002o`00013o`J:i
00?o0000ok:J__nbV[h04OnbV[h4o`0000ooWiK:1?l00004oh2Gh003o`1La?l0003o000000;o6HWY
00Co0000oeNWn?mGYoSo00001?n3]oH2o`000003oj2lk?l0003o000000?oYMKi00?o0000okcHk_nl
f>h01Onlf>h2o`0000?obmKR00Go0000olGdk_o5m>koaOC^o`000007omGci006o`000?nioMOo^OgG
okWmeol0003obooC0_l00002oh_Y_@03o`000?nQll?oXO?300;o00000_nBl=l00ol0003oYOOUo`00
0002ok?ijP04o`000?nnnNgo__W]o`0001Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`05ooooo`009Oooool00ol0003oooooooooo`13ooooo`03o`000?oPb/;oh<[200Coh<[200Co
0000omRj_?oH^[cof;Zl0_l0000;omRj^`03o`000?oI^k_ofK^k00;ofK^k00?o0000olj]^?o>[KP0
1oo>[KP3o`0000[ocJfi00?o0000ol:R^?o2X[P00_o2X[P3o`0000go`J:i00?o0000okBJ_OndV[d0
1?l0000>ok:J_P03o`000?nTU/OoY9K700Go00002_nOU/X01?l0003oRYWLohZIg?n:VM`6o`000004
o`1La?l0003o6HWYoaV9j@;o000000?oEjOho`000?l000000_n3]oH00ol0003oPkOfo`000006ojGF
n@;o00001onlf>h00ol0003obmKRo`000005olGdkP04o`000?oElnCoeO?TomGci0;o000000?oWoKI
o`000?nioML00_nioML3o`0000;oRnVm1?l00002oi;`g`Co00000_ncnNX01?l0003o__W]okkikOl0
000Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool002Kooooo00?o0000
ooooooooool0@oooool00ol0003oh<[2on3:`P02on3:`P03o`000?oH^[cof;Zl00Cof;Zl00?o0000
omRj^ooH^[/02OoH^[/2o`0000;ofK^k00?o0000olj]^?o>[KP02_o>[KP2o`0000OocJfi00?o0000
ol:R^?o2X[P01_o2X[P3o`0000[o`J:i00?o0000okBJ_OndV[d01?ndV[d4o`0000[o/YZn00?o0000
ojBFaonTU/L01OnTU/L5o`0000GoWiK:00?o0000ohZIg?n:VM`01on:VM`;o`0000CoOlco00?o0000
ojGFnOnUe_T01?nUe_T2o`0000Ko_=S^0_l00006olGdkP03o`000?oElnCo000000?oWoKI00?o0000
okWmeonioML02Ol00002oi;`g`03o`000?nUmnGo000000?o/oWZ00Co0000okkikOnnnNgo00006ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo000Wooooo`03o`000?oooooo
oooo04?ooooo00Go0000on3:`_oPb/;oh<[2o`000007omRj_0;o00002ooH^[/00ol0003ofK^ko`00
000>olj]^0;o00001Oo=[KT00ol0003o`Z:hol:R^009ol:R^0?o00001oo1X[T00ol0003o]9ZmokBJ
_@08okBJ_@Co00001OnbV[h00ol0003oY9K7ojBFa`0;ojBFa`Go000000?oWiK:o`000?n:VM`03?n:
VM`3o`:7f`?oA[;h00?o0000ogo<oomoc?l00omoc?l2o`0000GoYMKi00?o0000okcHk_l000000_l0
0003oj_`m`03o`000?o5m>koaOC^00CoaOC^00?o0000oioffOnOm]T00_nOm]T:o`0000?oT_3O00?o
0000ojGgiOl000000oncnNX01?l0003o__W]okkikOl0000Looooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01Oooool002Sooooo0_l00014ooooo`03o`000?oPb/;o000000[of;Zl0_l0
000:omRj^`;o00004?o>[KP2o`0000?ocJfi00?o0000ol:R^?o2X[P03?o2X[P3o`0000?o`J:i00?o
0000okBJ_OndV[d03OndV[d4o`000003ok:J__l0003oY9K7017oY9K71ol0000;ohZIg0;o0XOK00Co
0000odJbn?m6/_So00001Omoc?l2o`0000;oYMKi00?o0000ojGFnOl000001on[l?L00ol0003oaOC^
o`000002o`000006oggWeol0003oWoKIoioffOl0003oWoKI1_l000000omjiMGo0000oi;`g`02oi;`
g`;o000000?oYOOUo`000?ncnNX00_ncnNX01?l0003o__W]okkikOl0000Nooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0@_ooool2o`00
00cof;Zl00?o0000omRj^ooH^[/01ooH^[/01?l0003ocZfho`000?l0000@olj]^0?o00004_o2X[P4
o`0001?o]9Zm1_l0000?ojBFa`03o`000?nBVmWoTY_I00?oTY_I2Ol00003ohZIg005o`000?mYZ_Oo
0XOKo`000?m6/_P00_l00003ogo<o`04o`000?moc?oo0000o`0000CoPn;i0ol00004oj_`m`03o`00
0?mmimOoONOG00;oONOG1_l000001?m0`[_o0000o`000?mjiMD2o`0000?oT_3O00Co0000ojGgiOnU
mnGo00000oncnNX01?l0003o__W]okkikOl0000Pooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01?ooool002_ooooo00?o0000ooooooooool0@oooool00ol0003of;ZlomRj_00:omRj
_0;o00001_oH^[/00ol0003ocZfholj]^002olj]^0;o00004?o>[KP00ol0003o`Z:hol:R^00Col:R
^003o`000?ndV[go]9Zm01;o]9Zm00?o0000ojNGaOnWUlD00_nWUlD7o`0000SoY9K700?o0000oi:K
fOnBVmT03?nBVmT8o`000003oc400?l0003o000000;o00001?m;aNd2o`0000GoPn;i0_l00003oe7>
c@Oo000000?o@<:ko`000?l000001_l00002oi;`g`04o`000?nUmnGoYOOUo`0000?o/oWZ00Co0000
okkikOnnnNgo00008_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000/
ooooo`03o`000?oooooooooo04?ooooo0_l0000<omRj_003o`000?oH^[_of;Zk00?of;Zk00?o0000
olj]^?o>[KP01?o>[KP2o`0000kocZfh00?o0000ol>R^?o3X[P00ol0000@ol:R^003o`000?nfVkco
]Y^l00Co00003_ndV[d00ol0003oYiO5ojNGa@09ojNGa@Oo00000_nTU/L00ol0003oTY_Ioi:Kf@0?
oi:Kf@03o`000?mj/?GoN[3e00KoN[3e0ol00003od_5k@?o00000_lNZk`4o`0000CoF/[f2?l00005
ohSLoPco00008oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo000]oooo
o`;o0000AOooool00ol0003of;ZlomRj_00:omRj_0;o00000_oH^[/00ol0003ocZfholj]^007olj]
^0?o00002_o>[KP00ol0003o`j:hol>R^004ol>R^0Co00003?o2X[P00ol0003o]Y^lokJK_004okJK
_0Go00002OndV[d00ol0003oYiO5ojNGa@0@ojNGa@So00003OnBVmT00ol0003oN[3eogZ`m@0?ogZ`
m@04o`000?mJb_KoF/[foe[:mPGo00000_mdeO`3o`0000GoR=cn0ol000000onHgoko0000o`000002
ojCOn`;o00000_n]g_P00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01?ooool002oooooo00?o0000ooooooooool0@oooool00ol0003of;ZlomRj_00;omRj
_003o`000?oH^[_o000000cocZfh0_l00008olj]^003o`000?o3X[So`j:h00So`j:h0ol00009ol:R
^003o`000?nfVkco]Y^l00Wo]Y^l1?l00005okBJ_@03o`000?nWUlGoYiO501;oYiO500?o0000oiVM
e_nIWMH00onIWMH:o`0000?oTY_I00?o0000ogZ`mOmj/?D01omj/?D<o`0000CoM=Gl0ol00005ohSL
oP?o00000_nHgoh2o`0000;oY=ok0_l00002ojgNn0;o0000:?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Cooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0000<omRj_0;o
00003_o>[KP2o`0000GocZfh00?o0000ol>R^?o3X[P03?o3X[P4o`0000Co`Z:h00?o0000okJK_?nf
Vk`03_nfVk`4o`000003okBJ_Ol0003oYiO501?oYiO500?o0000oiVMe_nIWMH03OnIWMH=o`0000[o
R;?b00?o0000ogCEo?mdeO`00ol00005ohSLoP?o00000onHgoh2o`0000?oY=ok00?o0000ojgNn?n]
g_P00_l0000[ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0037ooooo
0_l00015ooooo`03o`000?oH^[cof;Zl00Wof;Zl00Co0000olj]^Ol0003o00003_o>[KP2o`0000?o
cZfh00?o0000ol>R^?o3X[P04?o3X[P3o`000003ol:R^?l0003o]Y^l01?o]Y^l2?l0000?ojNGa@03
o`000?nIWMKoVIgF013oVIgF00?o0000ohRcl_n8/o803On8/o86o`0000GoR=cn0ol00003oiSOoP?o
00000onTgo/2o`0000;o[Mkh00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00?ooooo000cooooo`03o`000?oooooooooo04?ooooo0_l00008omRj_003o`00
0?o>[KWocZfi00;ocZfi0ol0000=olj]^0;o000000?ocZfho`000?o3X[P05?o3X[P2o`0001Go]Y^l
00?o0000ojZHa?nZV<@01?nZV<@;o`0000CoYiO500?o0000oiVMe_nIWMH04OnIWMH00ol0003oR;?b
ohRclP03ohRclPWo00001_nB]^l00ol0003oR=cno`000002o`0000CoV=on0_l00004ojCOn`;o0000
0_n]g_P2o`0002oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00=?oo
ool00ol0003oooooooooo`14ooooo`03o`000?oH^[cof;Zl00Gof;Zl00?o0000olj]^Oo>[KT01Oo>
[KT2o`0000gocZfh00?o0000ol>R^?o3X[P05Oo3X[P01?l0003o^9^kokRK^onhVk/5o`0000go]Y^l
00?o0000ojZHa?nZV<@03onZV<@No`0000koT[K_1?l00004oiSOoP;o00001?nTgo/2o`0000?o[Mkh
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo
000eooooo`03o`000?oooooooooo04Cooooo00?o0000omRj_?oH^[`00ooH^[`00ol0003ocZfiolj]
^@08olj]^@;o00002oo>[KP00ol0003o`j>hol>S^004o`00017o`j:h00?o0000okRK^onhVk/01_nh
Vk/6o`0000Oo]Y^l00?o0000ojZHa?nZV<@04onZV<@00ol0003oWYoDoijOe00BoijOe003o`000?nB
]^ooT[K_00_oT[K_1Ol00004oi^gk004o`000?nHgoko0000o`0000CoY=ok0_l00003ojgNn0;o0000
=?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo000fooooo`;o0000AOoo
ool2o`0000;of;Zl00?o0000olj]^Oo>[KT02oo>[KT2o`0000SocZfh00?o0000ol>S^?o3XkP01Oo3
XkP4o`0000go`j:h00?o0000okRK^onhVk/03?nhVk/5o`0000;o]Y^l00?o0000ojZHa?nZV<@04onZ
V<@00ol0003oWYoDoijOe00CoijOe003o`000?nB]^ooT[K_00GoT[K_1Ol00008oi^gk0Co00001?nT
go/00ol0003o[MkhojgNn002ojgNn003o`000?oooooooooo03Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`03ooooo`00>?ooool00ol0003oooooooooo`14ooooo`03o`000?oH^[co
000000oocZfi0_l00006olj]^003o`000?o3XkSo`j>h00Wo`j>h0ol00009ol>R^003o`000?nhVk_o
^9^k01;o^9^k2Ol0000@ojZHa003o`000?nNWmCoWYoD01;oWYoD00?o0000oi:fkonB]^l01Ol00009
oi^gk0Co00001?nR^NT01?l0003oY=oko`000?l00003ojgNn0;o0000>?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo000iooooo`03o`000?oooooooooo04Cooooo0_l0000A
olj]^@?o00000oo>[KP00ol0003o`j>hol>S^00<ol>S^0Co00001Oo3X[P00ol0003o^9^kokRK^`0D
okRK^`03o`000?n]V/?o[I[300Co[I[32ol00005ojZHa003o`000?nNWmCoWYoD00SoWYoD3Ol00009
oi^gk0Go00001onR^NT3o`0000?o[Mkh0_l0000kooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00oooool003[ooooo00?o0000ooooooooool0AOooool3o`00017ocZfi0ol0000Col>S
^0Co000000?o`j:ho`000?nhVk/05OnhVk/00ol0003o[I[3ojfJ``0?ojfJ`a3o00002onSX=800ol0
003oVkO/oi^gk004oi^gk0Co00002OnR^NT3o`0000?oYkWV00?o0000ojgNn?l00000?_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo000kooooo`;o0000B?ooool2o`00017o
cZfi00?o0000ol>S^?o3XkP05Oo3XkP2o`0000?o^9^k00?o0000okRK^onhVk/04?nhVk/00ol0003o
[I[3ojfJ``0DojfJ``03o`000?nSX=;oXj3B01CoXj3B00?o0000oi^gk?l000000ol0000:oj:ij@?o
00001_nW^NH2o`0003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00
?Oooool00ol0003oooooooooo`17ooooo`?o00003_o>[KT00ol0003oa:BiolBT^@04o`0001;o`j>h
00?o0000okVL^oniW;/00_niW;/8o`0000[o^9^k00?o0000ojfJ`on]V/<05?n]V/<00ol0003oXj3B
oj>PdP0@oj>PdPKo00002onR^NT3o`0000KoYkWV0ol00012ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool003kooooo00?o0000ooooooooool0BOooool2o`0000cocZfi00?o
0000olBT^Oo4Y;T01?o4Y;T4o`0000go`j>h00?o0000okVL^oniW;/02oniW;/7o`0000?o^9^k00?o
0000ojfJ`on]V/<05On]V/<00ol0003oXj3Boj>PdP08oj>PdPOo00001?nVX]400ol0003oX[WYoj:i
j@07oj:ij@?o00001_nW^NH3o`0004Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`00?oooool00ol0003oooooooooo`1:ooooo`;o00002Oo>[KT00ol0003oa:BiolBT^@09
olBT^@?o00002_o3XkP00ol0003o^IbkokVL^`0BokVL^a3o00002on]V/<01?l0003oXj3Boj>Pd_nS
X=87o`0000coYZ;A00?o0000oj:ijOnR^NT00onR^NT3o`0000KoYkWV0ol0001:ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool0043ooooo0_l0001<ooooo`?o00001_o>[KT0
0ol0003oa:BiolBT^@0<olBT^@Co00001_o3XkP00ol0003o^IbkokVL^`0EokVL^`03o`000?n_Vl?o
[i_300[o[i_33ol0000CojJRd@03o`000?nR^NWoX[WY00?o00001onW^NH2o`0004gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00@_ooool00ol0003oooooooooo`1<oooo
o`;o00001?o>[KT00ol0003oa:BiolBT^@0@olBT^@Co000000?o`j>ho`000?niW;/05oniW;/00ol0
003o[i_3ojnK``0EojnK``03o`000?nVX]7oYZ;A01;oYZ;A1Ol00007ojNiiP?o0000D?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo0013ooooo`03o`000?oooooooooo04go
oooo1?l0000GolBT^@;o00000oniW;/00ol0003o^IbkokVL^`0BokVL^`03o`000?n_Vl?o[i_301Go
[i_300?o0000ojJRdOnVX]403?nVX]46o`0000?oZJCA00?o0000ojNii_nW^NH00onW^NH3o`0005Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?o4Y;Woa:Bi01Koa:Bi00?o0000okZN_?njW[`00_njW[`9o`0000_o^Ibk
00?o0000ojnK`on_Vl<05_n_Vl<00ol0003oYZ;AojJRd@06ojJRd@Go00002_nYY=400ol0003oYkWV
o`000002o`0005Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00AOoo
ool2o`0005;ooooo1Ol0000AolBT^@03o`000?njW[co^Yjl00_o^Yjl2?l00003okVL^`03o`000?n_
Vl?o[i_301Ko[i_300?o0000ojJRdOnVX]401_l0000>ojVTd@?o0000Foooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo007ooooo0017ooooo`03o`000?oooooooooo05Cooooo1Ol0000<
olBT^@03o`000?njW[co^Yjl01?o^Yjl7ol0000?ojVTd@Go0000Goooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo007ooooo0018ooooo`03o`000?oooooooooo05Sooooo1Ol00006olBT
^@03o`000?njW[co^Yjl01Oo^Yjl00?o0000ok6M`onaWL<05_naWL<00ol0003oZJCAojVTd@0:ojVT
d@Go0000IOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0019ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool00_ooool5o`000003olBT^Ol0003o^Yjl01So
^Yjl00?o0000ok6M`onaWL<05_naWL<00ol0003oZJCAojVTd@05ojVTd@Go0000Joooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo001:ooooo`;o0000Eoooool00ol0003ooooo
ooooo`07ooooo`;o00000onjW[`00ol0003o^YjlokZN_00CokZN_003o`000?naWL?o/Ig301Oo/Ig3
00?o0000ojVTdOl000001?l0001`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0Oooool004cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`Wo00003?nj
W[`00ol0003o/Ig3ok6M``0Aok6M``So0000M_ooool00ol0003oooooooooo`08ooooo`7o00000Ooo
ool1ooooo`00COooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Kooooo2Ol00003
okZN_003o`000?naWL?o/Ig300Co/Ig33Ol0001oooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`7ooooo001>ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool07oooool:o`00
08cooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004oooooo0_l0001Booooo`03
o`000?oooooooooo0;Kooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0057ooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`7ooooo001Booooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0^?oo
ool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00Doooool2o`0004kooooo00?o0000
ooooooooool0^?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00EOooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool01?ooool1o`00
007ooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0^_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool005Oooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00F?ooool2o`0004Wooooo00?o
0000ooooooooool0^oooool00ol0003oooooooooo`02ooooo`7o00000Oooool005[ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`2looooo`05o`000?ooooooooooooooool000000Ooo
ool005_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2mooooo`04o`000?oooooo
ooooo`00007ooooo001Looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0__ooool0
0ol0003oooooo`000001ooooo`00GOooool2o`0004Cooooo00?o0000ooooooooool0__ooool00ol0
003oooooooooo`01o`000000Goooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;oo
oooo0Ol00001ooooo`7o0000001Pooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
`?ooool2o`000000HOooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0;oooooo0ol0
000006;ooooo0_l0000oooooo`03o`000?oooooooooo0;_ooooo1?l00003ooooo`00I?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo0;Oooooo1?l00007ooooo`00IOooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0;?ooooo1?l0000;ooooo`00I_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo0;3ooooo0ol0000?ooooo`00Ioooool2o`0003[ooooo00?o
0000ooooooooool0[?ooool4o`0001;ooooo001Yooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0Z?ooool4o`0001Kooooo001Zooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0Y?ooool4o`0001[ooooo001[ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0XOooool4o`0001kooooo001/ooooo`;o0000=?ooool00ol0003oooooooooo`2Mooooo`Co0000
8_ooool006kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Iooooo`Co00009_oo
ool006oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Eooooo`Co0000:_ooool0
073ooooo0_l0000`ooooo`03o`000?oooooooooo097ooooo1?l0000^ooooo`00L_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo08kooooo0ol0000booooo`00Loooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo08[ooooo1?l0000eooooo`00M?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000iooooo`00MOooool2o`0002_ooooo00?o0000
ooooooooool0P_ooool4o`0003gooooo001gooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0O_ooool4o`00047ooooo001hooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0N_ooool4o`0004Gooooo001iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
M_ooool4o`0004Wooooo001jooooo`;o00009_ooool00ol0003oooooooooo`1booooo`Co0000COoo
ool007cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1_ooooo`?o0000DOooool0
07gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1[ooooo`Co0000E?ooool007ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Wooooo`Co0000F?ooool007oooooo
0_l0000Qooooo`03o`000?oooooooooo06?ooooo1?l0001Looooo`00POooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo05oooooo1?l0001Pooooo`00P_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo05_ooooo1?l0001Tooooo`00Poooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo05Oooooo1?l0001Xooooo`00Q?ooool2o`0001cooooo00?o0000oooooooo
ool0Doooool4o`0006cooooo0026ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
Coooool4o`00073ooooo0027ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0C?oo
ool3o`0007Cooooo0028ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0B?ooool4
o`0007Oooooo0029ooooo`;o00005oooool00ol0003oooooooooo`14ooooo`Co0000Noooool008_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000Ooooool008cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0looooo`Co0000Poooool008gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0hooooo`Co0000Qoooool008kooooo0_l0000B
ooooo`03o`000?oooooooooo03Cooooo1?l0002;ooooo`00T?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo037ooooo1?l0002?ooooo`00TOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02kooooo0ol0002Cooooo`00T_ooool2o`0000gooooo00?o0000ooooooooool0
:_ooool4o`0009Kooooo002Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09_oo
ool4o`0009[ooooo002Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool4
o`0009kooooo002Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool4o`00
0:;ooooo002Gooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`Co0000Y_ooool009Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`Co0000Z_ooool009[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000[_ooool009_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000/_ooool009cooooo0_l00003oooo
o`03o`000?oooooooooo00_ooooo0ol0002fooooo`00W_ooool01?l0003oooooooooool00009oooo
o`Co0000^Oooool009oooooo00?o0000ooooool000001Oooool4o`000;gooooo002Pooooo`;o0000
00?oooooo`000?l000000_l00031ooooo`00XOooool2o`000<Gooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0886549, -0.0135786, \
0.00362407, 0.00362407}}]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Sources and Inhomogeneous Boundary Conditions", \
"Subsubsection"]], "Section",
  CellTags->"c:39"],

Cell[TextData[{
  "Traveling waves such as that shown above are often created by moving \
disturbances (time-dependent sources). For example, a boat traveling across \
the surface of a lake creates a wake of traveling waves.  Mathematically, \
these sources enter as a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", "t"}], ")"}], TraditionalForm]]],
  " on the ",
  "right-hand",
  " side of the wave equation, Eq. ",
  ButtonBox["(4.4.1)",
    ButtonData:>"(4.4.1)",
    ButtonStyle->"Hyperlink"],
  " The response to time-dependent sources is found using an eigenmode \
expansion, in a manner that is completely identical to that used for the \
one-dimensional wave equation. Problems such as this will be left to the \
exercises. "
}], "Text"],

Cell[TextData[{
  "\tInhomogeneous boundary conditions on the wave equation can also be \
handled in an analogous manner to the methods used for the one-dimensional \
wave equation. For example, on a circular drumhead the rim might be warped, \
with a height that is given by some function ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\_o\)(\[Theta])\)]],
  ". This implies a Dirichlet boundary condition "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(a, \[Theta]) = \(z\_o\)(\[Theta])\)]],
  "."
}], "NE5",
  CellTags->"(4.4.21)"],

Cell[TextData[{
  "The wave equation is then solved by breaking the solution into a two \
pieces, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r, \[Theta], t)\), "=", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["z",
                    FontSlant->"Italic"]}]], "(", \(r, \[Theta], t\), ")"}], 
            " ", "+", \(u(r, \[Theta])\)}]}], TraditionalForm]]],
  ". One can now use two approaches to finding the solution. In the eigenmode \
approach, one chooses the function ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta])\)]],
  " to be any function that matches the boundary condition, ",
  Cell[BoxData[
      \(TraditionalForm\`u(a, \[Theta]) = \(z\_o\)(\[Theta])\)]],
  ", and the remainder ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["z",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " then satisfies homogeneous boundary conditions, and also satisfies the \
wave equation with a source created by ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\^2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["z",
                    FontSlant->"Italic"]}]]}], "/", \(\[PartialD]t\^2\)}], 
          "=", 
          RowBox[{
            RowBox[{\(c\^2\), 
              RowBox[{\(\[Del]\^2\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["z",
                      FontSlant->"Italic"]}]]}]}], " ", "-", 
            " ", \(\[PartialD]\^2 u/\[PartialD]t\^2\), 
            "+", \(\(c\^2\) \[Del]\^2 u\)}]}], TraditionalForm]]],
  "."
}], "NE5",
  CellTags->"(4.4.22)"],

Cell[TextData[{
  "However, for this  time-independent boundary condition it is easier to use \
a second approach, by choosing a form for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " which satisfies the Laplace equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = 0\)]],
  ".  The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is the equilibrium shape of the drumhead: ",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ u(r, \[Theta])\)]],
  " is a time-independent solution to the wave equation ",
  ButtonBox["(4.4.1)",
    ButtonData:>"(4.4.1)",
    ButtonStyle->"Hyperlink"],
  ". The remainder term ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["z",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " then satisfies the wave equation without sources, subject to whatever \
initial conditions are given in the problem. "
}], "Text"],

Cell[TextData[{
  " \tThe equilibrium solution for the shape of the drumhead can be found \
using the Laplace solution methods discussed in Sec. ",
  ButtonBox["3.2.3",
    ButtonData:>{"Chapter3.nb", "c:31"},
    ButtonStyle->"Hyperlink"],
  ".  For instance, if the warp follows the equation ",
  Cell[BoxData[
      \(TraditionalForm\`z(a, \[Theta]) = \ a\ sin2\[Theta]\)]],
  ", the solution to Laplace's equation that matches this boundary condition \
is simply ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, \[Theta]) = \((\ r\^2/a)\)\ sin2\[Theta]\)]],
  ". [This follows from Eq. ",
  ButtonBox["(3.1.24)",
    ButtonData:>{"Chapter3.nb", "(3.1.24)"},
    ButtonStyle->"Hyperlink"],
  ", and can be verified by direct substitution into ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = 0\)]],
  ".] This equilibrium shape is displayed in Cell ",
  ButtonBox["4.44",
    ButtonData:>"Cell 4.44",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(u[r_, \[Theta]_]\  = \ \(r\^\(\(2\)\(\ \)\)\) 
          Sin[2\ \[Theta]];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ParametricPlot3D[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], 
          u[r, \[Theta]]}, {r, 0, 1}, {\[Theta], 0, 2\ Pi}, 
        PlotPoints \[Rule] 25, BoxRatios \[Rule] {1, 1, 1/2}, 
        PlotLabel \[Rule] "\<equilibrium of a warped circular drumhead\>"];\)\
\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.44"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85958 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.22226e-17 1.05023 -0.0446497 1.05023 [
[.5 .87208 -125.125 0 ]
[.5 .87208 125.125 12 ]
[.05011 .23931 -12 -8.80895 ]
[.05011 .23931 0 .19105 ]
[.19006 .18353 -23.3672 -9 ]
[.19006 .18353 .63284 0 ]
[.33812 .12455 -5.55056 -9 ]
[.33812 .12455 .44944 0 ]
[.495 .06208 -15.778 -9 ]
[.495 .06208 2.22199 0 ]
[.66152 -0.00418 -4.96811 -9 ]
[.66152 -0.00418 1.03189 0 ]
[.70617 .00771 0 -6.27218 ]
[.70617 .00771 12 2.72782 ]
[.78245 .12584 0 -6.15535 ]
[.78245 .12584 24 2.84465 ]
[.85101 .23203 0 -6.05297 ]
[.85101 .23203 6 2.94703 ]
[.91296 .32799 0 -5.96251 ]
[.91296 .32799 18 3.03749 ]
[.96922 .41514 0 -5.88202 ]
[.96922 .41514 6 3.11798 ]
[.03285 .26491 -12 -2.72059 ]
[.03285 .26491 0 6.27941 ]
[.02254 .32954 -24 -2.77567 ]
[.02254 .32954 0 6.22433 ]
[.01178 .39698 -6 -2.83339 ]
[.01178 .39698 0 6.16661 ]
[.00054 .46744 -18 -2.89396 ]
[.00054 .46744 0 6.10604 ]
[-0.01122 .54111 -6 -2.95759 ]
[-0.01122 .54111 0 6.04241 ]
[ 0 0 0 0 ]
[ 1 .85958 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .87208 -186.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(equilibrium) show
135.125 13.000 moveto
(of) show
153.125 13.000 moveto
(a) show
165.250 13.000 moveto
(warped) show
207.250 13.000 moveto
(circular) show
261.250 13.000 moveto
(drumhead) show
309.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.69396 .01252 m
.68785 .01492 L
s
[(-1)] .70617 .00771 -1 .39382 Mshowa
.77013 .13037 m
.76397 .13264 L
s
[(-0.5)] .78245 .12584 -1 .36785 Mshowa
.8386 .23631 m
.8324 .23845 L
s
[(0)] .85101 .23203 -1 .3451 Mshowa
.90048 .33205 m
.89424 .33408 L
s
[(0.5)] .91296 .32799 -1 .325 Mshowa
.95667 .41899 m
.9504 .42092 L
s
[(1)] .96922 .41514 -1 .30711 Mshowa
.125 Mabswid
.70987 .03714 m
.7062 .03856 L
s
.72543 .06122 m
.72175 .06263 L
s
.74066 .08477 m
.73697 .08616 L
s
.75555 .10782 m
.75186 .10919 L
s
.7844 .15245 m
.7807 .1538 L
s
.79838 .17407 m
.79467 .1754 L
s
.81206 .19525 m
.80835 .19656 L
s
.82547 .21599 m
.82175 .21729 L
s
.85147 .25622 m
.84774 .2575 L
s
.86409 .27574 m
.86035 .277 L
s
.87646 .29488 m
.87272 .29612 L
s
.88858 .31364 m
.88484 .31487 L
s
.91215 .3501 m
.9084 .3513 L
s
.92359 .36781 m
.91984 .369 L
s
.93483 .38519 m
.93107 .38637 L
s
.94585 .40225 m
.94209 .40342 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
.04506 .26008 m
.05116 .25767 L
s
[(-1)] .03285 .26491 1 -0.39542 Mshowa
.0348 .32484 m
.04093 .32249 L
s
[(-0.5)] .02254 .32954 1 -0.38318 Mshowa
.02409 .39242 m
.03024 .39015 L
s
[(0)] .01178 .39698 1 -0.37036 Mshowa
.0129 .46303 m
.01908 .46082 L
s
[(0.5)] .00054 .46744 1 -0.3569 Mshowa
.0012 .53686 m
.00741 .53473 L
s
[(1)] -0.01122 .54111 1 -0.34276 Mshowa
.125 Mabswid
.04304 .27282 m
.04671 .27138 L
s
.04101 .28566 m
.04468 .28423 L
s
.03896 .29861 m
.04263 .29718 L
s
.03689 .31167 m
.04056 .31025 L
s
.03269 .33812 m
.03637 .33672 L
s
.03057 .35152 m
.03425 .35013 L
s
.02843 .36504 m
.03211 .36365 L
s
.02627 .37867 m
.02996 .3773 L
s
.02189 .4063 m
.02559 .40494 L
s
.01967 .42029 m
.02337 .41894 L
s
.01743 .43441 m
.02114 .43307 L
s
.01518 .44866 m
.01888 .44732 L
s
.0106 .47753 m
.01431 .47621 L
s
.00828 .49216 m
.012 .49086 L
s
.00594 .50692 m
.00966 .50563 L
s
.00358 .52182 m
.0073 .52054 L
s
.25 Mabswid
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
.40746 .59663 m
.04606 .25376 L
s
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.40746 .59663 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.39827 .85958 L
s
.39827 .85958 m
.40746 .59663 L
s
0 0 m
1 0 L
1 .85958 L
0 .85958 L
closepath
clip
newpath
.5 Mabswid
.44501 .53107 m .44211 .52801 L .37029 .52613 L p .447 0 0 r
F P
0 g
s
.44211 .52801 m .44501 .53107 L .51747 .55249 L p .43 0 0 r
F P
0 g
s
.51747 .55249 m .51719 .55088 L .44211 .52801 L p .43 0 0 r
F P
0 g
s
.59148 .5894 m .59398 .59102 L .53965 .56262 L p 0 .278 .673 r
F P
0 g
s
.53965 .56262 m .53214 .55869 L p .54074 .56315 L 0 .278 .673 r
F P
0 g
s
.59148 .5894 m .53965 .56262 L .54074 .56315 L 0 .278 .673 r
F
.59148 .5894 m .53214 .55869 L .53429 .55978 L F
.59148 .5894 m .52465 .55478 L .52964 .55734 L F
.53214 .55869 m .52465 .55478 L p .53429 .55978 L F P
0 g
s
.52465 .55478 m .51719 .55088 L p .52964 .55734 L 0 .278 .673 r
F P
0 g
s
.51719 .55088 m .51747 .55249 L .59148 .5894 L p 0 .278 .673 r
F P
0 g
s
.58895 .58755 m .59148 .5894 L .54008 .56377 L p 0 .323 .718 r
F P
0 g
s
.54008 .56377 m .51747 .55249 L p .54244 .56474 L 0 .323 .718 r
F P
0 g
s
.58895 .58755 m .54008 .56377 L .54244 .56474 L 0 .323 .718 r
F
.51747 .55249 m .51776 .55376 L .5329 .56095 L p F P
0 g
s
.5329 .56095 m .58447 .58543 L p .54216 .56463 L 0 .323 .718 r
F P
0 g
s
.54216 .56463 m .51747 .55249 L .5329 .56095 L 0 .323 .718 r
F
.51776 .55376 m .51804 .55468 L .52566 .55811 L p 0 .367 .761 r
F P
0 g
s
.58122 .58376 m .51747 .55249 L .58447 .58543 L 0 .323 .718 r
F
.58447 .58543 m .58895 .58755 L p .58122 .58376 L F P
0 g
s
.58638 .58547 m .58895 .58755 L .51776 .55376 L p 0 .367 .761 r
F P
0 g
s
.52566 .55811 m .57739 .58142 L p .53594 .56219 L 0 .367 .761 r
F P
0 g
s
.53594 .56219 m .51776 .55376 L .52566 .55811 L 0 .367 .761 r
F
.57483 .58013 m .51776 .55376 L .57739 .58142 L F
.57739 .58142 m .58638 .58547 L p .57483 .58013 L F P
0 g
s
.58379 .58314 m .58638 .58547 L .53329 .56155 L p 0 .41 .801 r
F P
0 g
s
.53329 .56155 m .51804 .55468 L p .53667 .56274 L 0 .41 .801 r
F P
0 g
s
.58379 .58314 m .53329 .56155 L .53667 .56274 L 0 .41 .801 r
F
.51804 .55468 m .51834 .55523 L .526 .5585 L p F P
0 g
s
.526 .5585 m .57025 .57737 L p .53582 .5624 L 0 .41 .801 r
F P
0 g
s
.53582 .5624 m .51804 .55468 L .526 .5585 L 0 .41 .801 r
F
.56844 .57649 m .51804 .55468 L .57025 .57737 L F
.57025 .57737 m .58379 .58314 L p .56844 .57649 L F P
0 g
s
.58116 .58056 m .58379 .58314 L .51834 .55523 L p 0 .452 .837 r
F P
0 g
s
.51863 .55542 m .56756 .57509 L p .52075 .55621 L 0 .452 .837 r
F P
0 g
s
.51834 .55523 m .51863 .55542 L p .52075 .55621 L 0 .452 .837 r
F P
0 g
s
.45098 .53605 m .45404 .53794 L .51834 .55523 L p .267 0 0 r
F P
0 g
s
.51834 .55523 m .51804 .55468 L .45098 .53605 L p .267 0 0 r
F P
0 g
s
.51863 .55542 m .51834 .55523 L .45404 .53794 L p .202 0 0 r
F P
0 g
s
.45404 .53794 m .45714 .53944 L .51863 .55542 L p .202 0 0 r
F P
0 g
s
.51863 .55542 m .45714 .53944 L p .51636 .55458 L 0 .449 .727 r
F P
0 g
s
.56586 .57439 m .51834 .55523 L .56756 .57509 L 0 .452 .837 r
F
.51894 .55524 m .51863 .55542 L p .51636 .55458 L 0 .449 .727 r
F P
0 g
s
.51863 .55542 m .51894 .55524 L .56938 .57429 L p .008 .49 .869 r
F P
0 g
s
.56938 .57429 m .5785 .57774 L p .56706 .57347 L .008 .49 .869 r
F P
0 g
s
.56706 .57347 m .51863 .55542 L .56938 .57429 L .008 .49 .869 r
F
.56756 .57509 m .58116 .58056 L p .56586 .57439 L 0 .452 .837 r
F P
0 g
s
.37029 .52613 m .37583 .52865 L .44501 .53107 L p .447 0 0 r
F P
0 g
s
.44797 .53375 m .44501 .53107 L .37583 .52865 L p .41 0 0 r
F P
0 g
s
.44501 .53107 m .44797 .53375 L .51776 .55376 L p .381 0 0 r
F P
0 g
s
.51776 .55376 m .51747 .55249 L .44501 .53107 L p .381 0 0 r
F P
0 g
s
.37583 .52865 m .38144 .53083 L .44797 .53375 L p .41 0 0 r
F P
0 g
s
.45098 .53605 m .44797 .53375 L .38144 .53083 L p .367 0 0 r
F P
0 g
s
.44797 .53375 m .45098 .53605 L .51804 .55468 L p .327 0 0 r
F P
0 g
s
.51804 .55468 m .51776 .55376 L .44797 .53375 L p .327 0 0 r
F P
0 g
s
.37583 .52865 m .37029 .52613 L .3037 .54291 L p .387 0 0 r
F P
0 g
s
.59398 .59102 m .59148 .5894 L .66471 .63279 L p 0 .36 .825 r
F P
0 g
s
.66471 .63279 m .67023 .63881 L .59398 .59102 L p 0 .36 .825 r
F P
0 g
s
.38144 .53083 m .38715 .53267 L .45098 .53605 L p .367 0 0 r
F P
0 g
s
.45404 .53794 m .45098 .53605 L .38715 .53267 L p .317 0 0 r
F P
0 g
s
.3037 .54291 m .31197 .54304 L .37583 .52865 L p .387 0 0 r
F P
0 g
s
.38144 .53083 m .37583 .52865 L .31197 .54304 L p .353 0 0 r
F P
0 g
s
.59148 .5894 m .58895 .58755 L .65915 .62672 L p 0 .388 .844 r
F P
0 g
s
.65915 .62672 m .66471 .63279 L .59148 .5894 L p 0 .388 .844 r
F P
0 g
s
.38715 .53267 m .39293 .53416 L .45404 .53794 L p .317 0 0 r
F P
0 g
s
.45714 .53944 m .45404 .53794 L .39293 .53416 L p .261 0 0 r
F P
0 g
s
.31197 .54304 m .32032 .54296 L .38144 .53083 L p .353 0 0 r
F P
0 g
s
.38715 .53267 m .38144 .53083 L .32032 .54296 L p .313 0 0 r
F P
0 g
s
.58895 .58755 m .58638 .58547 L .65355 .62061 L p .032 .416 .862 r
F P
0 g
s
.65355 .62061 m .65915 .62672 L .58895 .58755 L p .032 .416 .862 r
F P
0 g
s
.58638 .58547 m .58379 .58314 L .6479 .61445 L p .071 .443 .878 r
F P
0 g
s
.6479 .61445 m .65355 .62061 L .58638 .58547 L p .071 .443 .878 r
F P
0 g
s
.5785 .57774 m .58116 .58056 L .51863 .55542 L p .008 .49 .869 r
F P
0 g
s
.32032 .54296 m .32876 .54266 L .38715 .53267 L p .313 0 0 r
F P
0 g
s
.39293 .53416 m .38715 .53267 L .32876 .54266 L p .268 0 0 r
F P
0 g
s
.39293 .53416 m .3988 .53528 L .45714 .53944 L p .261 0 0 r
F P
0 g
s
.4603 .54052 m .45714 .53944 L .3988 .53528 L p .197 0 0 r
F P
0 g
s
.4603 .54052 m .40476 .53605 L p .46081 .54095 L .127 0 0 r
F P
0 g
s
.4603 .54052 m .51894 .55524 L p .45982 .54012 L 0 .449 .727 r
F P
0 g
s
.51924 .55467 m .51894 .55524 L .4603 .54052 L p 0 .503 .786 r
F P
0 g
s
.46351 .54118 m .51924 .55467 L p .46315 .54121 L 0 .503 .786 r
F P
0 g
s
.4603 .54052 m .46351 .54118 L p .46315 .54121 L 0 .503 .786 r
F P
0 g
s
.46351 .54118 m .4603 .54052 L p .46081 .54095 L .127 0 0 r
F P
0 g
s
.3988 .53528 m .40289 .53581 L p .4603 .54052 L .197 0 0 r
F P
0 g
s
.40476 .53605 m .3988 .53528 L .34591 .54137 L p .157 0 0 r
F P
0 g
s
.35462 .54039 m .39178 .53717 L p .34861 .54113 L .157 0 0 r
F P
0 g
s
.39513 .53692 m .38546 .53779 L .39178 .53717 L .157 0 0 r
F
.38546 .53779 m .34591 .54137 L .38533 .53776 L F
.38546 .53779 m .38533 .53776 L .39178 .53717 L F
.39178 .53717 m .40476 .53605 L p .39513 .53692 L F P
0 g
s
.40476 .53605 m .35462 .54039 L p .40824 .53662 L .092 0 0 r
F P
0 g
s
.40476 .53605 m .41432 .53682 L p .40377 .53589 L .197 0 0 r
F P
0 g
s
.41432 .53682 m .4603 .54052 L p .40289 .53581 L .197 0 0 r
F P
0 g
s
.41079 .53644 m .46351 .54118 L p .40762 .5363 L .127 0 0 r
F P
0 g
s
.40476 .53605 m .41079 .53644 L p .40762 .5363 L .127 0 0 r
F P
0 g
s
.41079 .53644 m .40476 .53605 L p .40784 .53655 L .092 0 0 r
F P
0 g
s
.41079 .53644 m .40784 .53655 L .40824 .53662 L .092 0 0 r
F
.4639 .54116 m .46365 .54118 L .41079 .53644 L 0 .532 .714 r
F
.45098 .54006 m .41079 .53644 L p .46365 .54118 L F P
0 g
s
.41691 .53645 m .46676 .54142 L p .41385 .53671 L 0 .532 .714 r
F P
0 g
s
.41079 .53644 m .41691 .53645 L p .41385 .53671 L 0 .532 .714 r
F P
0 g
s
.3988 .53528 m .39293 .53416 L .33729 .54213 L p .216 0 0 r
F P
0 g
s
.33729 .54213 m .34591 .54137 L .3988 .53528 L p .216 0 0 r
F P
0 g
s
.36341 .53917 m .41079 .53644 L p .35738 .54019 L .092 0 0 r
F P
0 g
s
.35462 .54039 m .36341 .53917 L p .35738 .54019 L .092 0 0 r
F P
0 g
s
.33729 .54213 m .32876 .54266 L .27894 .55928 L p .11 0 0 r
F P
0 g
s
.27894 .55928 m .29016 .55569 L .33729 .54213 L p .11 0 0 r
F P
0 g
s
.34591 .54137 m .33729 .54213 L .29016 .55569 L p .057 0 0 r
F P
0 g
s
.29016 .55569 m .30143 .55208 L .34591 .54137 L p .057 0 0 r
F P
0 g
s
.34591 .54137 m .35462 .54039 L p .34861 .54113 L .157 0 0 r
F P
0 g
s
.35462 .54039 m .34591 .54137 L .30143 .55208 L p 0 0 0 r
F P
0 g
s
.30143 .55208 m .31274 .54846 L .35462 .54039 L p 0 0 0 r
F P
0 g
s
.35462 .54039 m .31274 .54846 L p .36112 .53959 L 0 0 0 r
F P
0 g
s
.36341 .53917 m .35462 .54039 L p .36112 .53959 L 0 0 0 r
F P
0 g
s
.36341 .53917 m .3241 .54482 L p .36985 .53808 L .127 .674 .717 r
F P
0 g
s
.37228 .53772 m .36341 .53917 L p .36985 .53808 L .127 .674 .717 r
F P
0 g
s
.41079 .53644 m .37115 .53872 L p .41416 .53659 L .021 0 0 r
F P
0 g
s
.41691 .53645 m .41079 .53644 L p .41416 .53659 L .021 0 0 r
F P
0 g
s
.41691 .53645 m .38386 .53739 L p .42014 .53618 L .053 .62 .732 r
F P
0 g
s
.42311 .53608 m .41691 .53645 L p .42014 .53618 L .053 .62 .732 r
F P
0 g
s
.38386 .53739 m .37228 .53772 L p .38371 .53735 L .053 .62 .732 r
F P
0 g
s
.42311 .53608 m .38386 .53739 L .38371 .53735 L .053 .62 .732 r
F
.37115 .53872 m .36341 .53917 L p .36898 .53889 L .021 0 0 r
F P
0 g
s
.41691 .53645 m .37115 .53872 L .36898 .53889 L .021 0 0 r
F
.40289 .53581 m .40476 .53605 L p .40377 .53589 L .197 0 0 r
F P
0 g
s
.46351 .54118 m .45098 .54006 L p .46365 .54118 L 0 .532 .714 r
F P
0 g
s
.46676 .54142 m .46351 .54118 L p .4639 .54116 L 0 .532 .714 r
F P
0 g
s
.45714 .53944 m .4603 .54052 L p .45982 .54012 L 0 .449 .727 r
F P
0 g
s
.58379 .58314 m .58116 .58056 L .64221 .60824 L p .11 .469 .892 r
F P
0 g
s
.64221 .60824 m .6479 .61445 L .58379 .58314 L p .11 .469 .892 r
F P
0 g
s
.32876 .54266 m .33729 .54213 L .39293 .53416 L p .268 0 0 r
F P
0 g
s
.51894 .55524 m .51924 .55467 L .5758 .57466 L p .066 .526 .897 r
F P
0 g
s
.5758 .57466 m .5785 .57774 L .51894 .55524 L p .066 .526 .897 r
F P
0 g
s
.58116 .58056 m .5785 .57774 L .63648 .60198 L p .149 .494 .905 r
F P
0 g
s
.63648 .60198 m .64221 .60824 L .58116 .58056 L p .149 .494 .905 r
F P
0 g
s
.67023 .63881 m .66471 .63279 L .73346 .66904 L p .145 .401 .849 r
F P
0 g
s
.73346 .66904 m .74216 .67957 L .67023 .63881 L p .145 .401 .849 r
F P
0 g
s
.31197 .54304 m .3037 .54291 L .24558 .56996 L p .24 0 0 r
F P
0 g
s
.51955 .55372 m .51924 .55467 L .46351 .54118 L p .011 .554 .839 r
F P
0 g
s
.51924 .55467 m .51955 .55372 L .57308 .57133 L p .122 .559 .92 r
F P
0 g
s
.57308 .57133 m .5758 .57466 L .51924 .55467 L p .122 .559 .92 r
F P
0 g
s
.46351 .54118 m .46676 .54142 L .51955 .55372 L p .011 .554 .839 r
F P
0 g
s
.66471 .63279 m .65915 .62672 L .72474 .65871 L p .167 .42 .858 r
F P
0 g
s
.72474 .65871 m .73346 .66904 L .66471 .63279 L p .167 .42 .858 r
F P
0 g
s
.5785 .57774 m .5758 .57466 L .6307 .59568 L p .187 .518 .917 r
F P
0 g
s
.6307 .59568 m .63648 .60198 L .5785 .57774 L p .187 .518 .917 r
F P
0 g
s
.24558 .56996 m .25665 .56641 L .31197 .54304 L p .24 0 0 r
F P
0 g
s
.32032 .54296 m .31197 .54304 L .25665 .56641 L p .201 0 0 r
F P
0 g
s
.51987 .55237 m .51955 .55372 L .46676 .54142 L p .083 .599 .884 r
F P
0 g
s
.51955 .55372 m .51987 .55237 L .57032 .56773 L p .176 .589 .939 r
F P
0 g
s
.57032 .56773 m .57308 .57133 L .51955 .55372 L p .176 .589 .939 r
F P
0 g
s
.65915 .62672 m .65355 .62061 L .71601 .64858 L p .191 .438 .867 r
F P
0 g
s
.71601 .64858 m .72474 .65871 L .65915 .62672 L p .191 .438 .867 r
F P
0 g
s
.47007 .54121 m .46676 .54142 L .41691 .53645 L p .025 .592 .784 r
F P
0 g
s
.46676 .54142 m .47007 .54121 L .51987 .55237 L p .083 .599 .884 r
F P
0 g
s
.25665 .56641 m .26777 .56285 L .32032 .54296 L p .201 0 0 r
F P
0 g
s
.32876 .54266 m .32032 .54296 L .26777 .56285 L p .158 0 0 r
F P
0 g
s
.5758 .57466 m .57308 .57133 L .62488 .58932 L p .223 .541 .926 r
F P
0 g
s
.62488 .58932 m .6307 .59568 L .5758 .57466 L p .223 .541 .926 r
F P
0 g
s
.65355 .62061 m .6479 .61445 L .70725 .63865 L p .214 .456 .875 r
F P
0 g
s
.70725 .63865 m .71601 .64858 L .65355 .62061 L p .214 .456 .875 r
F P
0 g
s
.52019 .55063 m .51987 .55237 L .47007 .54121 L p .153 .638 .92 r
F P
0 g
s
.51987 .55237 m .52019 .55063 L .56753 .56388 L p .227 .615 .954 r
F P
0 g
s
.56753 .56388 m .57032 .56773 L .51987 .55237 L p .227 .615 .954 r
F P
0 g
s
.41691 .53645 m .42311 .53608 L .47007 .54121 L p .025 .592 .784 r
F P
0 g
s
.47342 .54056 m .47007 .54121 L .42311 .53608 L p .103 .645 .846 r
F P
0 g
s
.47007 .54121 m .47342 .54056 L .52019 .55063 L p .153 .638 .92 r
F P
0 g
s
.26777 .56285 m .27894 .55928 L .32876 .54266 L p .158 0 0 r
F P
0 g
s
.6479 .61445 m .64221 .60824 L .69848 .62891 L p .237 .474 .883 r
F P
0 g
s
.69848 .62891 m .70725 .63865 L .6479 .61445 L p .237 .474 .883 r
F P
0 g
s
.57308 .57133 m .57032 .56773 L .61901 .58292 L p .259 .562 .934 r
F P
0 g
s
.61901 .58292 m .62488 .58932 L .57308 .57133 L p .259 .562 .934 r
F P
0 g
s
.36341 .53917 m .37228 .53772 L .41691 .53645 L p .021 0 0 r
F P
0 g
s
.64221 .60824 m .63648 .60198 L .68968 .61937 L p .261 .492 .89 r
F P
0 g
s
.68968 .61937 m .69848 .62891 L .64221 .60824 L p .261 .492 .89 r
F P
0 g
s
.52051 .54847 m .52019 .55063 L .47342 .54056 L p .218 .672 .949 r
F P
0 g
s
.52019 .55063 m .52051 .54847 L .5647 .55976 L p .275 .638 .965 r
F P
0 g
s
.5647 .55976 m .56753 .56388 L .52019 .55063 L p .275 .638 .965 r
F P
0 g
s
.42311 .53608 m .42939 .53532 L .47342 .54056 L p .103 .645 .846 r
F P
0 g
s
.47682 .53945 m .47342 .54056 L .42939 .53532 L p .18 .691 .897 r
F P
0 g
s
.47342 .54056 m .47682 .53945 L .52051 .54847 L p .218 .672 .949 r
F P
0 g
s
.57032 .56773 m .56753 .56388 L .61309 .57646 L p .294 .582 .941 r
F P
0 g
s
.61309 .57646 m .61901 .58292 L .57032 .56773 L p .294 .582 .941 r
F P
0 g
s
.63648 .60198 m .6307 .59568 L .68086 .61002 L p .284 .51 .897 r
F P
0 g
s
.68086 .61002 m .68968 .61937 L .63648 .60198 L p .284 .51 .897 r
F P
0 g
s
.37228 .53772 m .38124 .53603 L .42311 .53608 L p .053 .62 .732 r
F P
0 g
s
.42939 .53532 m .42311 .53608 L .38124 .53603 L p .129 .676 .802 r
F P
0 g
s
.52084 .5459 m .52051 .54847 L .47682 .53945 L p .278 .698 .97 r
F P
0 g
s
.52051 .54847 m .52084 .5459 L .56185 .55536 L p .32 .658 .972 r
F P
0 g
s
.56185 .55536 m .5647 .55976 L .52051 .54847 L p .32 .658 .972 r
F P
0 g
s
.56753 .56388 m .5647 .55976 L .60713 .56996 L p .327 .601 .946 r
F P
0 g
s
.60713 .56996 m .61309 .57646 L .56753 .56388 L p .327 .601 .946 r
F P
0 g
s
.42939 .53532 m .43575 .53416 L .47682 .53945 L p .18 .691 .897 r
F P
0 g
s
.48027 .53788 m .47682 .53945 L .43575 .53416 L p .251 .728 .937 r
F P
0 g
s
.47682 .53945 m .48027 .53788 L .52084 .5459 L p .278 .698 .97 r
F P
0 g
s
.6307 .59568 m .62488 .58932 L .67202 .60086 L p .308 .527 .903 r
F P
0 g
s
.67202 .60086 m .68086 .61002 L .6307 .59568 L p .308 .527 .903 r
F P
0 g
s
.38124 .53603 m .39028 .53409 L .42939 .53532 L p .129 .676 .802 r
F P
0 g
s
.43575 .53416 m .42939 .53532 L .39028 .53409 L p .204 .725 .863 r
F P
0 g
s
.62488 .58932 m .61901 .58292 L .66314 .5919 L p .331 .544 .909 r
F P
0 g
s
.66314 .5919 m .67202 .60086 L .62488 .58932 L p .331 .544 .909 r
F P
0 g
s
.5647 .55976 m .56185 .55536 L .60112 .5634 L p .359 .619 .95 r
F P
0 g
s
.60112 .5634 m .60713 .56996 L .5647 .55976 L p .359 .619 .95 r
F P
0 g
s
.52118 .5429 m .52084 .5459 L .48027 .53788 L p .334 .72 .983 r
F P
0 g
s
.52084 .5459 m .52118 .5429 L .55896 .5507 L p .361 .676 .977 r
F P
0 g
s
.55896 .5507 m .56185 .55536 L .52084 .5459 L p .361 .676 .977 r
F P
0 g
s
.31274 .54846 m .3241 .54482 L .36341 .53917 L p 0 0 0 r
F P
0 g
s
.43575 .53416 m .44219 .5326 L .48027 .53788 L p .251 .728 .937 r
F P
0 g
s
.48377 .53584 m .48027 .53788 L .44219 .5326 L p .317 .756 .966 r
F P
0 g
s
.48027 .53788 m .48377 .53584 L .52118 .5429 L p .334 .72 .983 r
F P
0 g
s
.39028 .53409 m .39941 .53192 L .43575 .53416 L p .204 .725 .863 r
F P
0 g
s
.44219 .5326 m .43575 .53416 L .39941 .53192 L p .275 .764 .912 r
F P
0 g
s
.61901 .58292 m .61309 .57646 L .65423 .58313 L p .355 .561 .914 r
F P
0 g
s
.65423 .58313 m .66314 .5919 L .61901 .58292 L p .355 .561 .914 r
F P
0 g
s
.74216 .67957 m .73346 .66904 L .79238 .68247 L p .289 .437 .836 r
F P
0 g
s
.79238 .68247 m .80413 .69612 L .74216 .67957 L p .289 .437 .836 r
F P
0 g
s
.3241 .54482 m .33552 .54116 L .37228 .53772 L p .127 .674 .717 r
F P
0 g
s
.38124 .53603 m .37228 .53772 L .33552 .54116 L p .192 .724 .782 r
F P
0 g
s
.56185 .55536 m .55896 .5507 L .59506 .55679 L p .39 .635 .953 r
F P
0 g
s
.59506 .55679 m .60112 .5634 L .56185 .55536 L p .39 .635 .953 r
F P
0 g
s
.73346 .66904 m .72474 .65871 L .78068 .66926 L p .302 .449 .843 r
F P
0 g
s
.78068 .66926 m .79238 .68247 L .73346 .66904 L p .302 .449 .843 r
F P
0 g
s
.52151 .53948 m .52118 .5429 L .48377 .53584 L p .383 .736 .991 r
F P
0 g
s
.52118 .5429 m .52151 .53948 L .55604 .54576 L p .4 .69 .978 r
F P
0 g
s
.55604 .54576 m .55896 .5507 L .52118 .5429 L p .4 .69 .978 r
F P
0 g
s
.44219 .5326 m .4487 .53063 L .48377 .53584 L p .317 .756 .966 r
F P
0 g
s
.48731 .53333 m .48377 .53584 L .4487 .53063 L p .375 .775 .985 r
F P
0 g
s
.48377 .53584 m .48731 .53333 L .52151 .53948 L p .383 .736 .991 r
F P
0 g
s
.61309 .57646 m .60713 .56996 L .64529 .57456 L p .378 .578 .919 r
F P
0 g
s
.64529 .57456 m .65423 .58313 L .61309 .57646 L p .378 .578 .919 r
F P
0 g
s
.72474 .65871 m .71601 .64858 L .76901 .65648 L p .315 .462 .849 r
F P
0 g
s
.76901 .65648 m .78068 .66926 L .72474 .65871 L p .315 .462 .849 r
F P
0 g
s
.39941 .53192 m .40862 .5295 L .44219 .5326 L p .275 .764 .912 r
F P
0 g
s
.4487 .53063 m .44219 .5326 L .40862 .5295 L p .34 .793 .95 r
F P
0 g
s
.33552 .54116 m .34698 .5375 L .38124 .53603 L p .192 .724 .782 r
F P
0 g
s
.39028 .53409 m .38124 .53603 L .34698 .5375 L p .257 .766 .841 r
F P
0 g
s
.71601 .64858 m .70725 .63865 L .75738 .64411 L p .329 .476 .855 r
F P
0 g
s
.75738 .64411 m .76901 .65648 L .71601 .64858 L p .329 .476 .855 r
F P
0 g
s
.55896 .5507 m .55604 .54576 L .58896 .55013 L p .419 .65 .954 r
F P
0 g
s
.58896 .55013 m .59506 .55679 L .55896 .5507 L p .419 .65 .954 r
F P
0 g
s
.70725 .63865 m .69848 .62891 L .74577 .63217 L p .343 .489 .861 r
F P
0 g
s
.74577 .63217 m .75738 .64411 L .70725 .63865 L p .343 .489 .861 r
F P
0 g
s
.60713 .56996 m .60112 .5634 L .63632 .56617 L p .401 .594 .923 r
F P
0 g
s
.63632 .56617 m .64529 .57456 L .60713 .56996 L p .401 .594 .923 r
F P
0 g
s
.25665 .56641 m .24558 .56996 L .20101 .59345 L p 0 0 0 r
F P
0 g
s
.52185 .53562 m .52151 .53948 L .48731 .53333 L p .427 .747 .994 r
F P
0 g
s
.52151 .53948 m .52185 .53562 L .55309 .54054 L p .435 .703 .978 r
F P
0 g
s
.55309 .54054 m .55604 .54576 L .52151 .53948 L p .435 .703 .978 r
F P
0 g
s
.34698 .5375 m .35849 .53381 L .39028 .53409 L p .257 .766 .841 r
F P
0 g
s
.39941 .53192 m .39028 .53409 L .35849 .53381 L p .318 .801 .89 r
F P
0 g
s
.4487 .53063 m .45529 .52824 L .48731 .53333 L p .375 .775 .985 r
F P
0 g
s
.4909 .53033 m .48731 .53333 L .45529 .52824 L p .427 .788 .996 r
F P
0 g
s
.48731 .53333 m .4909 .53033 L .52185 .53562 L p .427 .747 .994 r
F P
0 g
s
.69848 .62891 m .68968 .61937 L .73419 .62064 L p .358 .503 .867 r
F P
0 g
s
.73419 .62064 m .74577 .63217 L .69848 .62891 L p .358 .503 .867 r
F P
0 g
s
.40862 .5295 m .41791 .52683 L .4487 .53063 L p .34 .793 .95 r
F P
0 g
s
.45529 .52824 m .4487 .53063 L .41791 .52683 L p .399 .813 .976 r
F P
0 g
s
.20101 .59345 m .2147 .586 L .25665 .56641 L p 0 0 0 r
F P
0 g
s
.26777 .56285 m .25665 .56641 L .2147 .586 L p 0 0 0 r
F P
0 g
s
.68968 .61937 m .68086 .61002 L .72263 .60951 L p .373 .516 .872 r
F P
0 g
s
.72263 .60951 m .73419 .62064 L .68968 .61937 L p .373 .516 .872 r
F P
0 g
s
.60112 .5634 m .59506 .55679 L .62731 .55798 L p .423 .61 .926 r
F P
0 g
s
.62731 .55798 m .63632 .56617 L .60112 .5634 L p .423 .61 .926 r
F P
0 g
s
.55604 .54576 m .55309 .54054 L .5828 .54342 L p .447 .664 .955 r
F P
0 g
s
.5828 .54342 m .58896 .55013 L .55604 .54576 L p .447 .664 .955 r
F P
0 g
s
.2147 .586 m .22835 .57879 L .26777 .56285 L p 0 0 0 r
F P
0 g
s
.27894 .55928 m .26777 .56285 L .22835 .57879 L p 0 0 0 r
F P
0 g
s
.35849 .53381 m .37005 .53011 L .39941 .53192 L p .318 .801 .89 r
F P
0 g
s
.40862 .5295 m .39941 .53192 L .37005 .53011 L p .374 .828 .93 r
F P
0 g
s
.68086 .61002 m .67202 .60086 L .71109 .59879 L p .388 .53 .878 r
F P
0 g
s
.71109 .59879 m .72263 .60951 L .68086 .61002 L p .388 .53 .878 r
F P
0 g
s
.5222 .53133 m .52185 .53562 L .4909 .53033 L p .466 .755 .993 r
F P
0 g
s
.52185 .53562 m .5222 .53133 L .5501 .53503 L p .468 .713 .976 r
F P
0 g
s
.5501 .53503 m .55309 .54054 L .52185 .53562 L p .468 .713 .976 r
F P
0 g
s
.22835 .57879 m .24197 .57183 L .27894 .55928 L p 0 0 0 r
F P
0 g
s
.29016 .55569 m .27894 .55928 L .24197 .57183 L p 0 0 0 r
F P
0 g
s
.45529 .52824 m .46196 .52544 L .4909 .53033 L p .427 .788 .996 r
F P
0 g
s
.49453 .52683 m .4909 .53033 L .46196 .52544 L p .471 .795 .999 r
F P
0 g
s
.4909 .53033 m .49453 .52683 L .5222 .53133 L p .466 .755 .993 r
F P
0 g
s
.41791 .52683 m .42727 .52391 L .45529 .52824 L p .399 .813 .976 r
F P
0 g
s
.46196 .52544 m .45529 .52824 L .42727 .52391 L p .449 .824 .991 r
F P
0 g
s
.59506 .55679 m .58896 .55013 L .61826 .54998 L p .446 .625 .929 r
F P
0 g
s
.61826 .54998 m .62731 .55798 L .59506 .55679 L p .446 .625 .929 r
F P
0 g
s
.67202 .60086 m .66314 .5919 L .69955 .58848 L p .403 .544 .883 r
F P
0 g
s
.69955 .58848 m .71109 .59879 L .67202 .60086 L p .403 .544 .883 r
F P
0 g
s
.24197 .57183 m .25555 .56512 L .29016 .55569 L p 0 0 0 r
F P
0 g
s
.30143 .55208 m .29016 .55569 L .25555 .56512 L p .248 .753 .711 r
F P
0 g
s
.55309 .54054 m .5501 .53503 L .5766 .53665 L p .474 .677 .954 r
F P
0 g
s
.5766 .53665 m .5828 .54342 L .55309 .54054 L p .474 .677 .954 r
F P
0 g
s
.37005 .53011 m .38167 .52639 L .40862 .5295 L p .374 .828 .93 r
F P
0 g
s
.41791 .52683 m .40862 .5295 L .38167 .52639 L p .425 .845 .959 r
F P
0 g
s
.66314 .5919 m .65423 .58313 L .68803 .57856 L p .419 .558 .888 r
F P
0 g
s
.68803 .57856 m .69955 .58848 L .66314 .5919 L p .419 .558 .888 r
F P
0 g
s
.25555 .56512 m .26911 .55865 L .30143 .55208 L p .248 .753 .711 r
F P
0 g
s
.31274 .54846 m .30143 .55208 L .26911 .55865 L p .295 .789 .763 r
F P
0 g
s
.52255 .52659 m .5222 .53133 L .49453 .52683 L p .5 .76 .988 r
F P
0 g
s
.5222 .53133 m .52255 .52659 L .54709 .52924 L p .497 .722 .972 r
F P
0 g
s
.54709 .52924 m .5501 .53503 L .5222 .53133 L p .497 .722 .972 r
F P
0 g
s
.58896 .55013 m .5828 .54342 L .60917 .54217 L p .467 .639 .931 r
F P
0 g
s
.60917 .54217 m .61826 .54998 L .58896 .55013 L p .467 .639 .931 r
F P
0 g
s
.42727 .52391 m .43672 .52074 L .46196 .52544 L p .449 .824 .991 r
F P
0 g
s
.4687 .5222 m .46196 .52544 L .43672 .52074 L p .492 .828 .999 r
F P
0 g
s
.46196 .52544 m .4687 .5222 L .49453 .52683 L p .471 .795 .999 r
F P
0 g
s
.65423 .58313 m .64529 .57456 L .67651 .56904 L p .434 .573 .893 r
F P
0 g
s
.67651 .56904 m .68803 .57856 L .65423 .58313 L p .434 .573 .893 r
F P
0 g
s
.49821 .52284 m .49453 .52683 L .4687 .5222 L p .509 .797 .998 r
F P
0 g
s
.49453 .52683 m .49821 .52284 L .52255 .52659 L p .5 .76 .988 r
F P
0 g
s
.26911 .55865 m .28264 .55243 L .31274 .54846 L p .295 .789 .763 r
F P
0 g
s
.3241 .54482 m .31274 .54846 L .28264 .55243 L p .34 .82 .811 r
F P
0 g
s
.38167 .52639 m .39333 .52265 L .41791 .52683 L p .425 .845 .959 r
F P
0 g
s
.42727 .52391 m .41791 .52683 L .39333 .52265 L p .47 .855 .98 r
F P
0 g
s
.5501 .53503 m .54709 .52924 L .57035 .52982 L p .499 .689 .952 r
F P
0 g
s
.57035 .52982 m .5766 .53665 L .5501 .53503 L p .499 .689 .952 r
F P
0 g
s
.64529 .57456 m .63632 .56617 L .66499 .55991 L p .45 .587 .898 r
F P
0 g
s
.66499 .55991 m .67651 .56904 L .64529 .57456 L p .45 .587 .898 r
F P
0 g
s
.28264 .55243 m .29615 .54644 L .3241 .54482 L p .34 .82 .811 r
F P
0 g
s
.33552 .54116 m .3241 .54482 L .29615 .54644 L p .384 .847 .854 r
F P
0 g
s
.5828 .54342 m .5766 .53665 L .60004 .53455 L p .489 .654 .933 r
F P
0 g
s
.60004 .53455 m .60917 .54217 L .5828 .54342 L p .489 .654 .933 r
F P
0 g
s
.43672 .52074 m .44625 .51731 L .4687 .5222 L p .492 .828 .999 r
F P
0 g
s
.47552 .51854 m .4687 .5222 L .44625 .51731 L p .528 .827 .999 r
F P
0 g
s
.4687 .5222 m .47552 .51854 L .49821 .52284 L p .509 .797 .998 r
F P
0 g
s
.52291 .52139 m .52255 .52659 L .49821 .52284 L p .53 .763 .982 r
F P
0 g
s
.52255 .52659 m .52291 .52139 L .54404 .52317 L p .524 .728 .967 r
F P
0 g
s
.54404 .52317 m .54709 .52924 L .52255 .52659 L p .524 .728 .967 r
F P
0 g
s
.39333 .52265 m .40505 .5189 L .42727 .52391 L p .47 .855 .98 r
F P
0 g
s
.43672 .52074 m .42727 .52391 L .40505 .5189 L p .508 .859 .992 r
F P
0 g
s
.29615 .54644 m .30964 .54069 L .33552 .54116 L p .384 .847 .854 r
F P
0 g
s
.34698 .5375 m .33552 .54116 L .30964 .54069 L p .425 .868 .891 r
F P
0 g
s
.63632 .56617 m .62731 .55798 L .65346 .55117 L p .467 .601 .902 r
F P
0 g
s
.65346 .55117 m .66499 .55991 L .63632 .56617 L p .467 .601 .902 r
F P
0 g
s
.50193 .51835 m .49821 .52284 L .47552 .51854 L p .54 .796 .992 r
F P
0 g
s
.49821 .52284 m .50193 .51835 L .52291 .52139 L p .53 .763 .982 r
F P
0 g
s
.54709 .52924 m .54404 .52317 L .56404 .52294 L p .523 .7 .95 r
F P
0 g
s
.56404 .52294 m .57035 .52982 L .54709 .52924 L p .523 .7 .95 r
F P
0 g
s
.30964 .54069 m .32311 .53518 L .34698 .5375 L p .425 .868 .891 r
F P
0 g
s
.35849 .53381 m .34698 .5375 L .32311 .53518 L p .463 .883 .922 r
F P
0 g
s
.62731 .55798 m .61826 .54998 L .64193 .54282 L p .483 .615 .906 r
F P
0 g
s
.64193 .54282 m .65346 .55117 L .62731 .55798 L p .483 .615 .906 r
F P
0 g
s
.5766 .53665 m .57035 .52982 L .59086 .52712 L p .51 .667 .933 r
F P
0 g
s
.59086 .52712 m .60004 .53455 L .5766 .53665 L p .51 .667 .933 r
F P
0 g
s
.40505 .5189 m .41682 .51514 L .43672 .52074 L p .508 .859 .992 r
F P
0 g
s
.44625 .51731 m .43672 .52074 L .41682 .51514 L p .54 .857 .997 r
F P
0 g
s
.32311 .53518 m .33657 .52991 L .35849 .53381 L p .463 .883 .922 r
F P
0 g
s
.37005 .53011 m .35849 .53381 L .33657 .52991 L p .497 .892 .947 r
F P
0 g
s
.44625 .51731 m .45585 .51362 L .47552 .51854 L p .528 .827 .999 r
F P
0 g
s
.4824 .51444 m .47552 .51854 L .45585 .51362 L p .558 .823 .995 r
F P
0 g
s
.47552 .51854 m .4824 .51444 L .50193 .51835 L p .54 .796 .992 r
F P
0 g
s
.61826 .54998 m .60917 .54217 L .63038 .53486 L p .499 .629 .909 r
F P
0 g
s
.63038 .53486 m .64193 .54282 L .61826 .54998 L p .499 .629 .909 r
F P
0 g
s
.52326 .51574 m .52291 .52139 L .50193 .51835 L p .557 .763 .974 r
F P
0 g
s
.52291 .52139 m .52326 .51574 L .54096 .51679 L p .549 .734 .961 r
F P
0 g
s
.54096 .51679 m .54404 .52317 L .52291 .52139 L p .549 .734 .961 r
F P
0 g
s
.5057 .51335 m .50193 .51835 L .4824 .51444 L p .568 .792 .984 r
F P
0 g
s
.50193 .51835 m .5057 .51335 L .52326 .51574 L p .557 .763 .974 r
F P
0 g
s
.33657 .52991 m .35001 .52487 L .37005 .53011 L p .497 .892 .947 r
F P
0 g
s
.38167 .52639 m .37005 .53011 L .35001 .52487 L p .527 .897 .966 r
F P
0 g
s
.57035 .52982 m .56404 .52294 L .58163 .51988 L p .53 .68 .934 r
F P
0 g
s
.58163 .51988 m .59086 .52712 L .57035 .52982 L p .53 .68 .934 r
F P
0 g
s
.54404 .52317 m .54096 .51679 L .55769 .51601 L p .545 .709 .947 r
F P
0 g
s
.55769 .51601 m .56404 .52294 L .54404 .52317 L p .545 .709 .947 r
F P
0 g
s
.41682 .51514 m .42864 .51135 L .44625 .51731 L p .54 .857 .997 r
F P
0 g
s
.45585 .51362 m .44625 .51731 L .42864 .51135 L p .566 .85 .997 r
F P
0 g
s
.60917 .54217 m .60004 .53455 L .61881 .52728 L p .515 .643 .913 r
F P
0 g
s
.61881 .52728 m .63038 .53486 L .60917 .54217 L p .515 .643 .913 r
F P
0 g
s
.35001 .52487 m .36345 .52006 L .38167 .52639 L p .527 .897 .966 r
F P
0 g
s
.39333 .52265 m .38167 .52639 L .36345 .52006 L p .552 .897 .979 r
F P
0 g
s
.45585 .51362 m .46553 .50968 L .4824 .51444 L p .558 .823 .995 r
F P
0 g
s
.48935 .50991 m .4824 .51444 L .46553 .50968 L p .583 .815 .988 r
F P
0 g
s
.4824 .51444 m .48935 .50991 L .5057 .51335 L p .568 .792 .984 r
F P
0 g
s
.52363 .50963 m .52326 .51574 L .5057 .51335 L p .58 .763 .965 r
F P
0 g
s
.52326 .51574 m .52363 .50963 L .53786 .51013 L p .571 .738 .955 r
F P
0 g
s
.53786 .51013 m .54096 .51679 L .52326 .51574 L p .571 .738 .955 r
F P
0 g
s
.60004 .53455 m .59086 .52712 L .60723 .52009 L p .532 .657 .916 r
F P
0 g
s
.60723 .52009 m .61881 .52728 L .60004 .53455 L p .532 .657 .916 r
F P
0 g
s
.56404 .52294 m .55769 .51601 L .57235 .51283 L p .55 .693 .934 r
F P
0 g
s
.57235 .51283 m .58163 .51988 L .56404 .52294 L p .55 .693 .934 r
F P
0 g
s
.36345 .52006 m .37688 .51549 L .39333 .52265 L p .552 .897 .979 r
F P
0 g
s
.40505 .5189 m .39333 .52265 L .37688 .51549 L p .574 .892 .988 r
F P
0 g
s
.42864 .51135 m .44051 .50755 L .45585 .51362 L p .566 .85 .997 r
F P
0 g
s
.46553 .50968 m .45585 .51362 L .44051 .50755 L p .588 .841 .993 r
F P
0 g
s
.76901 .65648 m .75738 .64411 L .7933 .62162 L p .43 .503 .832 r
F P
0 g
s
.75738 .64411 m .74577 .63217 L .77951 .60991 L p .439 .513 .838 r
F P
0 g
s
.77951 .60991 m .7933 .62162 L .75738 .64411 L p .439 .513 .838 r
F P
0 g
s
.5095 .50782 m .5057 .51335 L .48935 .50991 L p .59 .787 .974 r
F P
0 g
s
.5057 .51335 m .5095 .50782 L .52363 .50963 L p .58 .763 .965 r
F P
0 g
s
.74577 .63217 m .73419 .62064 L .76581 .59871 L p .447 .523 .843 r
F P
0 g
s
.76581 .59871 m .77951 .60991 L .74577 .63217 L p .447 .523 .843 r
F P
0 g
s
.78068 .66926 m .76901 .65648 L .80716 .63387 L p .422 .493 .827 r
F P
0 g
s
.7933 .62162 m .80716 .63387 L .76901 .65648 L p .43 .503 .832 r
F P
0 g
s
.73419 .62064 m .72263 .60951 L .75217 .58803 L p .457 .534 .848 r
F P
0 g
s
.75217 .58803 m .76581 .59871 L .73419 .62064 L p .457 .534 .848 r
F P
0 g
s
.79238 .68247 m .78068 .66926 L .82112 .64664 L p .414 .483 .822 r
F P
0 g
s
.80716 .63387 m .82112 .64664 L .78068 .66926 L p .422 .493 .827 r
F P
0 g
s
.72263 .60951 m .71109 .59879 L .73859 .57786 L p .466 .545 .853 r
F P
0 g
s
.73859 .57786 m .75217 .58803 L .72263 .60951 L p .466 .545 .853 r
F P
0 g
s
.54096 .51679 m .53786 .51013 L .55128 .50901 L p .567 .718 .944 r
F P
0 g
s
.55128 .50901 m .55769 .51601 L .54096 .51679 L p .567 .718 .944 r
F P
0 g
s
.80413 .69612 m .79238 .68247 L .83516 .65997 L p .406 .474 .817 r
F P
0 g
s
.82112 .64664 m .83516 .65997 L .79238 .68247 L p .414 .483 .822 r
F P
0 g
s
.71109 .59879 m .69955 .58848 L .72507 .56818 L p .476 .556 .859 r
F P
0 g
s
.72507 .56818 m .73859 .57786 L .71109 .59879 L p .476 .556 .859 r
F P
0 g
s
.83516 .65997 m .84931 .67384 L .80413 .69612 L p .406 .474 .817 r
F P
0 g
s
.69955 .58848 m .68803 .57856 L .7116 .55901 L p .486 .568 .864 r
F P
0 g
s
.7116 .55901 m .72507 .56818 L .69955 .58848 L p .486 .568 .864 r
F P
0 g
s
.37688 .51549 m .39031 .51115 L .40505 .5189 L p .574 .892 .988 r
F P
0 g
s
.41682 .51514 m .40505 .5189 L .39031 .51115 L p .593 .885 .991 r
F P
0 g
s
.68803 .57856 m .67651 .56904 L .69818 .55032 L p .496 .58 .869 r
F P
0 g
s
.69818 .55032 m .7116 .55901 L .68803 .57856 L p .496 .58 .869 r
F P
0 g
s
.59086 .52712 m .58163 .51988 L .59561 .51328 L p .548 .671 .918 r
F P
0 g
s
.59561 .51328 m .60723 .52009 L .59086 .52712 L p .548 .671 .918 r
F P
0 g
s
.46553 .50968 m .47528 .50548 L .48935 .50991 L p .583 .815 .988 r
F P
0 g
s
.49638 .50492 m .48935 .50991 L .47528 .50548 L p .603 .806 .978 r
F P
0 g
s
.48935 .50991 m .49638 .50492 L .5095 .50782 L p .59 .787 .974 r
F P
0 g
s
.67651 .56904 m .66499 .55991 L .68479 .54212 L p .506 .592 .874 r
F P
0 g
s
.68479 .54212 m .69818 .55032 L .67651 .56904 L p .506 .592 .874 r
F P
0 g
s
.44051 .50755 m .45243 .50373 L .46553 .50968 L p .588 .841 .993 r
F P
0 g
s
.47528 .50548 m .46553 .50968 L .45243 .50373 L p .606 .83 .985 r
F P
0 g
s
.55769 .51601 m .55128 .50901 L .56302 .50597 L p .569 .705 .933 r
F P
0 g
s
.56302 .50597 m .57235 .51283 L .55769 .51601 L p .569 .705 .933 r
F P
0 g
s
.66499 .55991 m .65346 .55117 L .67144 .5344 L p .517 .604 .879 r
F P
0 g
s
.67144 .5344 m .68479 .54212 L .66499 .55991 L p .517 .604 .879 r
F P
0 g
s
.39031 .51115 m .40374 .50705 L .41682 .51514 L p .593 .885 .991 r
F P
0 g
s
.42864 .51135 m .41682 .51514 L .40374 .50705 L p .608 .875 .991 r
F P
0 g
s
.52399 .50305 m .52363 .50963 L .5095 .50782 L p .6 .761 .956 r
F P
0 g
s
.52363 .50963 m .52399 .50305 L .53472 .50317 L p .592 .742 .948 r
F P
0 g
s
.53472 .50317 m .53786 .51013 L .52363 .50963 L p .592 .742 .948 r
F P
0 g
s
.65346 .55117 m .64193 .54282 L .65812 .52715 L p .528 .616 .884 r
F P
0 g
s
.65812 .52715 m .67144 .5344 L .65346 .55117 L p .528 .616 .884 r
F P
0 g
s
.58163 .51988 m .57235 .51283 L .58397 .50685 L p .564 .684 .92 r
F P
0 g
s
.58397 .50685 m .59561 .51328 L .58163 .51988 L p .564 .684 .92 r
F P
0 g
s
.51335 .50178 m .5095 .50782 L .49638 .50492 L p .61 .78 .962 r
F P
0 g
s
.5095 .50782 m .51335 .50178 L .52399 .50305 L p .6 .761 .956 r
F P
0 g
s
.53786 .51013 m .53472 .50317 L .54482 .50197 L p .587 .726 .94 r
F P
0 g
s
.54482 .50197 m .55128 .50901 L .53786 .51013 L p .587 .726 .94 r
F P
0 g
s
.64193 .54282 m .63038 .53486 L .64481 .52038 L p .54 .629 .889 r
F P
0 g
s
.64481 .52038 m .65812 .52715 L .64193 .54282 L p .54 .629 .889 r
F P
0 g
s
.40374 .50705 m .41718 .50317 L .42864 .51135 L p .608 .875 .991 r
F P
0 g
s
.44051 .50755 m .42864 .51135 L .41718 .50317 L p .62 .864 .989 r
F P
0 g
s
.63038 .53486 m .61881 .52728 L .63153 .51409 L p .551 .642 .893 r
F P
0 g
s
.63153 .51409 m .64481 .52038 L .63038 .53486 L p .551 .642 .893 r
F P
0 g
s
.45243 .50373 m .46441 .4999 L .47528 .50548 L p .606 .83 .985 r
F P
0 g
s
.48511 .50101 m .47528 .50548 L .46441 .4999 L p .621 .818 .976 r
F P
0 g
s
.47528 .50548 m .48511 .50101 L .49638 .50492 L p .603 .806 .978 r
F P
0 g
s
.50347 .49949 m .49638 .50492 L .48511 .50101 L p .62 .795 .966 r
F P
0 g
s
.49638 .50492 m .50347 .49949 L .51335 .50178 L p .61 .78 .962 r
F P
0 g
s
.55128 .50901 m .54482 .50197 L .55363 .49931 L p .588 .716 .932 r
F P
0 g
s
.55363 .49931 m .56302 .50597 L .55128 .50901 L p .588 .716 .932 r
F P
0 g
s
.57235 .51283 m .56302 .50597 L .57228 .50081 L p .581 .697 .922 r
F P
0 g
s
.57228 .50081 m .58397 .50685 L .57235 .51283 L p .581 .697 .922 r
F P
0 g
s
.61881 .52728 m .60723 .52009 L .61825 .50826 L p .563 .655 .898 r
F P
0 g
s
.61825 .50826 m .63153 .51409 L .61881 .52728 L p .563 .655 .898 r
F P
0 g
s
.41718 .50317 m .43062 .49953 L .44051 .50755 L p .62 .864 .989 r
F P
0 g
s
.45243 .50373 m .44051 .50755 L .43062 .49953 L p .63 .85 .984 r
F P
0 g
s
.52436 .496 m .52399 .50305 L .51335 .50178 L p .618 .758 .946 r
F P
0 g
s
.52399 .50305 m .52436 .496 L .53155 .4959 L p .61 .745 .941 r
F P
0 g
s
.53155 .4959 m .53472 .50317 L .52399 .50305 L p .61 .745 .941 r
F P
0 g
s
.60723 .52009 m .59561 .51328 L .60498 .5029 L p .575 .668 .902 r
F P
0 g
s
.60498 .5029 m .61825 .50826 L .60723 .52009 L p .575 .668 .902 r
F P
0 g
s
.51723 .49521 m .51335 .50178 L .50347 .49949 L p .626 .773 .951 r
F P
0 g
s
.51335 .50178 m .51723 .49521 L .52436 .496 L p .618 .758 .946 r
F P
0 g
s
.53472 .50317 m .53155 .4959 L .5383 .49486 L p .605 .734 .935 r
F P
0 g
s
.5383 .49486 m .54482 .50197 L .53472 .50317 L p .605 .734 .935 r
F P
0 g
s
.46441 .4999 m .47644 .49605 L .48511 .50101 L p .621 .818 .976 r
F P
0 g
s
.49501 .49627 m .48511 .50101 L .47644 .49605 L p .632 .805 .966 r
F P
0 g
s
.48511 .50101 m .49501 .49627 L .50347 .49949 L p .62 .795 .966 r
F P
0 g
s
.43062 .49953 m .44406 .49612 L .45243 .50373 L p .63 .85 .984 r
F P
0 g
s
.46441 .4999 m .45243 .50373 L .44406 .49612 L p .638 .837 .977 r
F P
0 g
s
.56302 .50597 m .55363 .49931 L .56056 .49515 L p .597 .71 .923 r
F P
0 g
s
.56056 .49515 m .57228 .50081 L .56302 .50597 L p .597 .71 .923 r
F P
0 g
s
.51062 .49361 m .50347 .49949 L .49501 .49627 L p .634 .784 .954 r
F P
0 g
s
.50347 .49949 m .51062 .49361 L .51723 .49521 L p .626 .773 .951 r
F P
0 g
s
.59561 .51328 m .58397 .50685 L .5917 .498 L p .587 .681 .906 r
F P
0 g
s
.5917 .498 m .60498 .5029 L .59561 .51328 L p .587 .681 .906 r
F P
0 g
s
.54482 .50197 m .5383 .49486 L .54419 .49283 L p .606 .726 .93 r
F P
0 g
s
.54419 .49283 m .55363 .49931 L .54482 .50197 L p .606 .726 .93 r
F P
0 g
s
.44406 .49612 m .45753 .49293 L .46441 .4999 L p .638 .837 .977 r
F P
0 g
s
.47644 .49605 m .46441 .4999 L .45753 .49293 L p .644 .822 .969 r
F P
0 g
s
.58397 .50685 m .57228 .50081 L .57842 .49357 L p .599 .694 .909 r
F P
0 g
s
.57842 .49357 m .5917 .498 L .58397 .50685 L p .599 .694 .909 r
F P
0 g
s
.47644 .49605 m .48853 .49218 L .49501 .49627 L p .632 .805 .966 r
F P
0 g
s
.50497 .49127 m .49501 .49627 L .48853 .49218 L p .642 .791 .954 r
F P
0 g
s
.49501 .49627 m .50497 .49127 L .51062 .49361 L p .634 .784 .954 r
F P
0 g
s
.55363 .49931 m .54419 .49283 L .5488 .48987 L p .612 .722 .924 r
F P
0 g
s
.5488 .48987 m .56056 .49515 L .55363 .49931 L p .612 .722 .924 r
F P
0 g
s
.52474 .48847 m .52436 .496 L .51723 .49521 L p .634 .755 .936 r
F P
0 g
s
.52436 .496 m .52474 .48847 L .52835 .48834 L p .627 .747 .933 r
F P
0 g
s
.52835 .48834 m .53155 .4959 L .52436 .496 L p .627 .747 .933 r
F P
0 g
s
.52115 .4881 m .51723 .49521 L .51062 .49361 L p .64 .765 .939 r
F P
0 g
s
.51723 .49521 m .52115 .4881 L .52474 .48847 L p .634 .755 .936 r
F P
0 g
s
.53155 .4959 m .52835 .48834 L .53174 .48769 L p .623 .74 .931 r
F P
0 g
s
.53174 .48769 m .5383 .49486 L .53155 .4959 L p .623 .74 .931 r
F P
0 g
s
.45753 .49293 m .471 .48998 L .47644 .49605 L p .644 .822 .969 r
F P
0 g
s
.48853 .49218 m .47644 .49605 L .471 .48998 L p .648 .808 .96 r
F P
0 g
s
.57228 .50081 m .56056 .49515 L .56513 .4896 L p .611 .707 .913 r
F P
0 g
s
.56513 .4896 m .57842 .49357 L .57228 .50081 L p .611 .707 .913 r
F P
0 g
s
.29769 .52979 m .31235 .52351 L .32311 .53518 L p .646 .949 .951 r
F P
0 g
s
.32311 .53518 m .30964 .54069 L .29769 .52979 L p .646 .949 .951 r
F P
0 g
s
.33657 .52991 m .32311 .53518 L .31235 .52351 L p .655 .943 .96 r
F P
0 g
s
.28294 .53651 m .29769 .52979 L .30964 .54069 L p .636 .953 .939 r
F P
0 g
s
.30964 .54069 m .29615 .54644 L .28294 .53651 L p .636 .953 .939 r
F P
0 g
s
.31235 .52351 m .32693 .51768 L .33657 .52991 L p .655 .943 .96 r
F P
0 g
s
.35001 .52487 m .33657 .52991 L .32693 .51768 L p .661 .936 .968 r
F P
0 g
s
.5383 .49486 m .53174 .48769 L .53468 .48655 L p .623 .737 .928 r
F P
0 g
s
.53468 .48655 m .54419 .49283 L .5383 .49486 L p .623 .737 .928 r
F P
0 g
s
.51784 .48727 m .51062 .49361 L .50497 .49127 L p .645 .773 .941 r
F P
0 g
s
.51062 .49361 m .51784 .48727 L .52115 .4881 L p .64 .765 .939 r
F P
0 g
s
.26808 .54369 m .28294 .53651 L .29615 .54644 L p .624 .954 .924 r
F P
0 g
s
.29615 .54644 m .28264 .55243 L .26808 .54369 L p .624 .954 .924 r
F P
0 g
s
.32693 .51768 m .34142 .51228 L .35001 .52487 L p .661 .936 .968 r
F P
0 g
s
.36345 .52006 m .35001 .52487 L .34142 .51228 L p .667 .927 .973 r
F P
0 g
s
.25312 .55133 m .26808 .54369 L .28264 .55243 L p .61 .953 .906 r
F P
0 g
s
.28264 .55243 m .26911 .55865 L .25312 .55133 L p .61 .953 .906 r
F P
0 g
s
.34142 .51228 m .35584 .50732 L .36345 .52006 L p .667 .927 .973 r
F P
0 g
s
.37688 .51549 m .36345 .52006 L .35584 .50732 L p .671 .916 .976 r
F P
0 g
s
.23805 .55944 m .25312 .55133 L .26911 .55865 L p .595 .949 .887 r
F P
0 g
s
.26911 .55865 m .25555 .56512 L .23805 .55944 L p .595 .949 .887 r
F P
0 g
s
.35584 .50732 m .37019 .50279 L .37688 .51549 L p .671 .916 .976 r
F P
0 g
s
.39031 .51115 m .37688 .51549 L .37019 .50279 L p .673 .904 .977 r
F P
0 g
s
.22286 .56802 m .23805 .55944 L .25555 .56512 L p .578 .943 .864 r
F P
0 g
s
.25555 .56512 m .24197 .57183 L .22286 .56802 L p .578 .943 .864 r
F P
0 g
s
.37019 .50279 m .38448 .49868 L .39031 .51115 L p .673 .904 .977 r
F P
0 g
s
.40374 .50705 m .39031 .51115 L .38448 .49868 L p .675 .891 .976 r
F P
0 g
s
.20755 .57708 m .22286 .56802 L .24197 .57183 L p .56 .935 .84 r
F P
0 g
s
.24197 .57183 m .22835 .57879 L .20755 .57708 L p .56 .935 .84 r
F P
0 g
s
.38448 .49868 m .39871 .495 L .40374 .50705 L p .675 .891 .976 r
F P
0 g
s
.41718 .50317 m .40374 .50705 L .39871 .495 L p .675 .878 .974 r
F P
0 g
s
.56056 .49515 m .5488 .48987 L .55182 .48609 L p .623 .72 .916 r
F P
0 g
s
.55182 .48609 m .56513 .4896 L .56056 .49515 L p .623 .72 .916 r
F P
0 g
s
.471 .48998 m .4845 .48726 L .48853 .49218 L p .648 .808 .96 r
F P
0 g
s
.50067 .48829 m .48853 .49218 L .4845 .48726 L p .651 .793 .95 r
F P
0 g
s
.48853 .49218 m .50067 .48829 L .50497 .49127 L p .642 .791 .954 r
F P
0 g
s
.54419 .49283 m .53468 .48655 L .53698 .48498 L p .628 .735 .924 r
F P
0 g
s
.53698 .48498 m .5488 .48987 L .54419 .49283 L p .628 .735 .924 r
F P
0 g
s
.1921 .58662 m .20755 .57708 L .22835 .57879 L p .54 .924 .814 r
F P
0 g
s
.22835 .57879 m .2147 .586 L .1921 .58662 L p .54 .924 .814 r
F P
0 g
s
.51501 .486 m .50497 .49127 L .50067 .48829 L p .649 .778 .942 r
F P
0 g
s
.50497 .49127 m .51501 .486 L .51784 .48727 L p .645 .773 .941 r
F P
0 g
s
.39871 .495 m .41289 .49173 L .41718 .50317 L p .675 .878 .974 r
F P
0 g
s
.43062 .49953 m .41718 .50317 L .41289 .49173 L p .675 .864 .971 r
F P
0 g
s
.65812 .52715 m .64481 .52038 L .65122 .49901 L p .582 .633 .867 r
F P
0 g
s
.64481 .52038 m .63153 .51409 L .6371 .49531 L p .589 .644 .873 r
F P
0 g
s
.6371 .49531 m .65122 .49901 L .64481 .52038 L p .589 .644 .873 r
F P
0 g
s
.67144 .5344 m .65812 .52715 L .66538 .50314 L p .575 .622 .862 r
F P
0 g
s
.65122 .49901 m .66538 .50314 L .65812 .52715 L p .582 .633 .867 r
F P
0 g
s
.17651 .59667 m .1921 .58662 L .2147 .586 L p .52 .911 .785 r
F P
0 g
s
.2147 .586 m .20101 .59345 L .17651 .59667 L p .52 .911 .785 r
F P
0 g
s
.63153 .51409 m .61825 .50826 L .62303 .49202 L p .596 .656 .879 r
F P
0 g
s
.62303 .49202 m .6371 .49531 L .63153 .51409 L p .596 .656 .879 r
F P
0 g
s
.68479 .54212 m .67144 .5344 L .67959 .50769 L p .568 .611 .856 r
F P
0 g
s
.66538 .50314 m .67959 .50769 L .67144 .5344 L p .575 .622 .862 r
F P
0 g
s
.41289 .49173 m .42703 .48888 L .43062 .49953 L p .675 .864 .971 r
F P
0 g
s
.44406 .49612 m .43062 .49953 L .42703 .48888 L p .674 .849 .967 r
F P
0 g
s
.61825 .50826 m .60498 .5029 L .60898 .48914 L p .604 .668 .884 r
F P
0 g
s
.60898 .48914 m .62303 .49202 L .61825 .50826 L p .604 .668 .884 r
F P
0 g
s
.69818 .55032 m .68479 .54212 L .69386 .51266 L p .561 .601 .85 r
F P
0 g
s
.67959 .50769 m .69386 .51266 L .68479 .54212 L p .568 .611 .856 r
F P
0 g
s
.60498 .5029 m .5917 .498 L .59496 .48667 L p .612 .68 .89 r
F P
0 g
s
.59496 .48667 m .60898 .48914 L .60498 .5029 L p .612 .68 .89 r
F P
0 g
s
.7116 .55901 m .69818 .55032 L .70819 .51805 L p .555 .591 .845 r
F P
0 g
s
.69386 .51266 m .70819 .51805 L .69818 .55032 L p .561 .601 .85 r
F P
0 g
s
.42703 .48888 m .44112 .48645 L .44406 .49612 L p .674 .849 .967 r
F P
0 g
s
.45753 .49293 m .44406 .49612 L .44112 .48645 L p .672 .835 .962 r
F P
0 g
s
.5917 .498 m .57842 .49357 L .58097 .48461 L p .62 .692 .896 r
F P
0 g
s
.58097 .48461 m .59496 .48667 L .5917 .498 L p .62 .692 .896 r
F P
0 g
s
.52511 .48046 m .52474 .48847 L .52115 .4881 L closepath p .648 .752 .925 r
F P
0 g
s
.52511 .48046 m .52835 .48834 L .52474 .48847 L closepath p .643 .748 .925 r
F P
0 g
s
.72507 .56818 m .7116 .55901 L .72258 .52388 L p .549 .581 .839 r
F P
0 g
s
.70819 .51805 m .72258 .52388 L .7116 .55901 L p .555 .591 .845 r
F P
0 g
s
.5488 .48987 m .53698 .48498 L .53848 .48305 L p .636 .733 .918 r
F P
0 g
s
.53848 .48305 m .55182 .48609 L .5488 .48987 L p .636 .733 .918 r
F P
0 g
s
.52511 .48046 m .53174 .48769 L .52835 .48834 L closepath p .64 .746 .926 r
F P
0 g
s
.52511 .48046 m .52115 .4881 L .51784 .48727 L closepath p .652 .757 .927 r
F P
0 g
s
.44112 .48645 m .45517 .48443 L .45753 .49293 L p .672 .835 .962 r
F P
0 g
s
.471 .48998 m .45753 .49293 L .45517 .48443 L p .669 .82 .956 r
F P
0 g
s
.4845 .48726 m .49801 .48476 L .50067 .48829 L p .651 .793 .95 r
F P
0 g
s
.51286 .48439 m .50067 .48829 L .49801 .48476 L p .654 .779 .94 r
F P
0 g
s
.50067 .48829 m .51286 .48439 L .51501 .486 L p .649 .778 .942 r
F P
0 g
s
.57842 .49357 m .56513 .4896 L .56699 .48297 L p .628 .705 .901 r
F P
0 g
s
.56699 .48297 m .58097 .48461 L .57842 .49357 L p .628 .705 .901 r
F P
0 g
s
.52511 .48046 m .53468 .48655 L .53174 .48769 L closepath p .64 .746 .926 r
F P
0 g
s
.52511 .48046 m .51784 .48727 L .51501 .486 L closepath p .654 .762 .929 r
F P
0 g
s
.73859 .57786 m .72507 .56818 L .73704 .53015 L p .543 .572 .834 r
F P
0 g
s
.72258 .52388 m .73704 .53015 L .72507 .56818 L p .549 .581 .839 r
F P
0 g
s
.45517 .48443 m .4692 .48282 L .471 .48998 L p .669 .82 .956 r
F P
0 g
s
.4845 .48726 m .471 .48998 L .4692 .48282 L p .666 .805 .95 r
F P
0 g
s
.52511 .48046 m .53698 .48498 L .53468 .48655 L closepath p .643 .746 .924 r
F P
0 g
s
.56513 .4896 m .55182 .48609 L .55303 .48173 L p .636 .717 .906 r
F P
0 g
s
.55303 .48173 m .56699 .48297 L .56513 .4896 L p .636 .717 .906 r
F P
0 g
s
.52511 .48046 m .51501 .486 L .51286 .48439 L closepath p .655 .765 .93 r
F P
0 g
s
.75217 .58803 m .73859 .57786 L .75159 .53686 L p .537 .563 .829 r
F P
0 g
s
.73704 .53015 m .75159 .53686 L .73859 .57786 L p .543 .572 .834 r
F P
0 g
s
.4692 .48282 m .4832 .48162 L .4845 .48726 L p .666 .805 .95 r
F P
0 g
s
.49801 .48476 m .4845 .48726 L .4832 .48162 L p .663 .791 .943 r
F P
0 g
s
.52511 .48046 m .53848 .48305 L .53698 .48498 L closepath p .648 .746 .921 r
F P
0 g
s
.55182 .48609 m .53848 .48305 L .53907 .48089 L p .644 .73 .911 r
F P
0 g
s
.53907 .48089 m .55303 .48173 L .55182 .48609 L p .644 .73 .911 r
F P
0 g
s
.49801 .48476 m .51155 .4825 L .51286 .48439 L p .654 .779 .94 r
F P
0 g
s
.52511 .48046 m .51286 .48439 L .51155 .4825 L closepath p .655 .765 .93 r
F P
0 g
s
.4832 .48162 m .49719 .48083 L .49801 .48476 L p .663 .791 .943 r
F P
0 g
s
.51155 .4825 m .49801 .48476 L .49719 .48083 L p .66 .777 .936 r
F P
0 g
s
.76581 .59871 m .75217 .58803 L .76622 .54401 L p .532 .554 .823 r
F P
0 g
s
.75159 .53686 m .76622 .54401 L .75217 .58803 L p .537 .563 .829 r
F P
0 g
s
.52511 .48046 m .53907 .48089 L .53848 .48305 L closepath p .653 .744 .916 r
F P
0 g
s
.49719 .48083 m .51115 .48044 L .51155 .4825 L p .66 .777 .936 r
F P
0 g
s
.52511 .48046 m .51155 .4825 L .51115 .48044 L closepath p .656 .763 .928 r
F P
0 g
s
.77951 .60991 m .76581 .59871 L .78093 .55161 L p .526 .545 .818 r
F P
0 g
s
.76622 .54401 m .78093 .55161 L .76581 .59871 L p .532 .554 .823 r
F P
0 g
s
.55303 .48173 m .53907 .48089 L .53871 .47866 L p .651 .727 .905 r
F P
0 g
s
.52511 .48046 m .53871 .47866 L .53907 .48089 L closepath p .655 .741 .912 r
F P
0 g
s
.56699 .48297 m .55303 .48173 L .55234 .47709 L p .647 .715 .897 r
F P
0 g
s
.53871 .47866 m .55234 .47709 L .55303 .48173 L p .651 .727 .905 r
F P
0 g
s
.52511 .48046 m .53528 .47465 L .53742 .47653 L closepath p .656 .738 .91 r
F P
0 g
s
.52511 .48046 m .53245 .4732 L .53528 .47465 L closepath p .657 .741 .912 r
F P
0 g
s
.52511 .48046 m .52911 .47228 L .53245 .4732 L closepath p .659 .746 .914 r
F P
0 g
s
.52511 .48046 m .5255 .47197 L .52911 .47228 L closepath p .663 .751 .915 r
F P
0 g
s
.52511 .48046 m .52185 .47228 L .5255 .47197 L closepath p .668 .755 .915 r
F P
0 g
s
.52511 .48046 m .51844 .47318 L .52185 .47228 L closepath p .671 .756 .915 r
F P
0 g
s
.52511 .48046 m .51548 .47457 L .51844 .47318 L closepath p .671 .756 .915 r
F P
0 g
s
.52511 .48046 m .51319 .47634 L .51548 .47457 L closepath p .668 .756 .916 r
F P
0 g
s
.52511 .48046 m .51171 .47834 L .51319 .47634 L closepath p .663 .757 .92 r
F P
0 g
s
.52511 .48046 m .51115 .48044 L .51171 .47834 L closepath p .659 .759 .924 r
F P
0 g
s
.52511 .48046 m .53742 .47653 L .53871 .47866 L closepath p .656 .738 .91 r
F P
0 g
s
.58097 .48461 m .56699 .48297 L .566 .47575 L p .643 .703 .89 r
F P
0 g
s
.55234 .47709 m .566 .47575 L .56699 .48297 L p .647 .715 .897 r
F P
0 g
s
.49827 .47669 m .51171 .47834 L .51115 .48044 L p .667 .773 .929 r
F P
0 g
s
.51115 .48044 m .49719 .48083 L .49827 .47669 L p .667 .773 .929 r
F P
0 g
s
.7933 .62162 m .77951 .60991 L .79575 .55967 L p .521 .537 .813 r
F P
0 g
s
.78093 .55161 m .79575 .55967 L .77951 .60991 L p .526 .545 .818 r
F P
0 g
s
.59496 .48667 m .58097 .48461 L .5797 .47464 L p .638 .691 .882 r
F P
0 g
s
.566 .47575 m .5797 .47464 L .58097 .48461 L p .643 .703 .89 r
F P
0 g
s
.48477 .4755 m .49827 .47669 L .49719 .48083 L p .676 .786 .933 r
F P
0 g
s
.49719 .48083 m .4832 .48162 L .48477 .4755 L p .676 .786 .933 r
F P
0 g
s
.60898 .48914 m .59496 .48667 L .59345 .47376 L p .634 .679 .875 r
F P
0 g
s
.5797 .47464 m .59345 .47376 L .59496 .48667 L p .638 .691 .882 r
F P
0 g
s
.47123 .47477 m .48477 .4755 L .4832 .48162 L p .685 .8 .936 r
F P
0 g
s
.4832 .48162 m .4692 .48282 L .47123 .47477 L p .685 .8 .936 r
F P
0 g
s
.55234 .47709 m .53871 .47866 L .53742 .47653 L p .656 .726 .9 r
F P
0 g
s
.50119 .4726 m .51319 .47634 L .51171 .47834 L p .676 .769 .921 r
F P
0 g
s
.51171 .47834 m .49827 .47669 L .50119 .4726 L p .676 .769 .921 r
F P
0 g
s
.62303 .49202 m .60898 .48914 L .60724 .47312 L p .63 .668 .868 r
F P
0 g
s
.59345 .47376 m .60724 .47312 L .60898 .48914 L p .634 .679 .875 r
F P
0 g
s
.45762 .47452 m .47123 .47477 L .4692 .48282 L p .693 .814 .94 r
F P
0 g
s
.4692 .48282 m .45517 .48443 L .45762 .47452 L p .693 .814 .94 r
F P
0 g
s
.80716 .63387 m .7933 .62162 L .81067 .5682 L p .516 .529 .808 r
F P
0 g
s
.79575 .55967 m .81067 .5682 L .7933 .62162 L p .521 .537 .813 r
F P
0 g
s
.6371 .49531 m .62303 .49202 L .62108 .47271 L p .626 .657 .861 r
F P
0 g
s
.60724 .47312 m .62108 .47271 L .62303 .49202 L p .63 .668 .868 r
F P
0 g
s
.44395 .47474 m .45762 .47452 L .45517 .48443 L p .702 .827 .942 r
F P
0 g
s
.45517 .48443 m .44112 .48645 L .44395 .47474 L p .702 .827 .942 r
F P
0 g
s
.53742 .47653 m .54978 .47257 L .55234 .47709 L p .656 .726 .9 r
F P
0 g
s
.54978 .47257 m .53742 .47653 L .53528 .47465 L p .659 .726 .899 r
F P
0 g
s
.566 .47575 m .55234 .47709 L .54978 .47257 L p .655 .713 .891 r
F P
0 g
s
.50578 .46887 m .51548 .47457 L .51319 .47634 L p .682 .767 .915 r
F P
0 g
s
.51319 .47634 m .50119 .4726 L .50578 .46887 L p .682 .767 .915 r
F P
0 g
s
.65122 .49901 m .6371 .49531 L .63497 .47254 L p .622 .647 .854 r
F P
0 g
s
.62108 .47271 m .63497 .47254 L .6371 .49531 L p .626 .657 .861 r
F P
0 g
s
.48913 .46925 m .50119 .4726 L .49827 .47669 L p .688 .782 .922 r
F P
0 g
s
.49827 .47669 m .48477 .4755 L .48913 .46925 L p .688 .782 .922 r
F P
0 g
s
.4302 .47543 m .44395 .47474 L .44112 .48645 L p .71 .841 .945 r
F P
0 g
s
.44112 .48645 m .42703 .48888 L .4302 .47543 L p .71 .841 .945 r
F P
0 g
s
.53528 .47465 m .54552 .46857 L .54978 .47257 L p .659 .726 .899 r
F P
0 g
s
.54552 .46857 m .53528 .47465 L .53245 .4732 L p .663 .731 .9 r
F P
0 g
s
.5117 .46583 m .51844 .47318 L .51548 .47457 L p .685 .764 .911 r
F P
0 g
s
.51548 .47457 m .50578 .46887 L .5117 .46583 L p .685 .764 .911 r
F P
0 g
s
.82112 .64664 m .80716 .63387 L .82569 .57719 L p .511 .522 .803 r
F P
0 g
s
.81067 .5682 m .82569 .57719 L .80716 .63387 L p .516 .529 .808 r
F P
0 g
s
.5797 .47464 m .566 .47575 L .5622 .46859 L p .655 .702 .881 r
F P
0 g
s
.54978 .47257 m .5622 .46859 L .566 .47575 L p .655 .713 .891 r
F P
0 g
s
.66538 .50314 m .65122 .49901 L .64892 .4726 L p .618 .637 .847 r
F P
0 g
s
.63497 .47254 m .64892 .4726 L .65122 .49901 L p .622 .647 .854 r
F P
0 g
s
.41637 .47661 m .4302 .47543 L .42703 .48888 L p .718 .854 .946 r
F P
0 g
s
.42703 .48888 m .41289 .49173 L .41637 .47661 L p .718 .854 .946 r
F P
0 g
s
.53245 .4732 m .53984 .46547 L .54552 .46857 L p .663 .731 .9 r
F P
0 g
s
.53984 .46547 m .53245 .4732 L .52911 .47228 L p .668 .738 .902 r
F P
0 g
s
.51856 .46379 m .52185 .47228 L .51844 .47318 L p .685 .76 .909 r
F P
0 g
s
.51844 .47318 m .5117 .46583 L .51856 .46379 L p .685 .76 .909 r
F P
0 g
s
.52911 .47228 m .53314 .46356 L .53984 .46547 L p .668 .738 .902 r
F P
0 g
s
.53314 .46356 m .52911 .47228 L .5255 .47197 L p .674 .747 .905 r
F P
0 g
s
.5622 .46859 m .54978 .47257 L .54552 .46857 L p .662 .715 .888 r
F P
0 g
s
.52588 .46299 m .5255 .47197 L .52185 .47228 L p .68 .755 .907 r
F P
0 g
s
.52185 .47228 m .51856 .46379 L .52588 .46299 L p .68 .755 .907 r
F P
0 g
s
.5255 .47197 m .52588 .46299 L .53314 .46356 L p .674 .747 .905 r
F P
0 g
s
.477 .46629 m .48913 .46925 L .48477 .4755 L p .7 .794 .923 r
F P
0 g
s
.48477 .4755 m .47123 .47477 L .477 .46629 L p .7 .794 .923 r
F P
0 g
s
.67959 .50769 m .66538 .50314 L .66292 .4729 L p .615 .628 .841 r
F P
0 g
s
.64892 .4726 m .66292 .4729 L .66538 .50314 L p .618 .637 .847 r
F P
0 g
s
.59345 .47376 m .5797 .47464 L .57467 .4646 L p .654 .691 .872 r
F P
0 g
s
.5622 .46859 m .57467 .4646 L .5797 .47464 L p .655 .702 .881 r
F P
0 g
s
.40246 .47826 m .41637 .47661 L .41289 .49173 L p .726 .867 .947 r
F P
0 g
s
.41289 .49173 m .39871 .495 L .40246 .47826 L p .726 .867 .947 r
F P
0 g
s
.496 .46336 m .50578 .46887 L .50119 .4726 L p .696 .777 .914 r
F P
0 g
s
.50119 .4726 m .48913 .46925 L .496 .46336 L p .696 .777 .914 r
F P
0 g
s
.83516 .65997 m .82112 .64664 L .84083 .58666 L p .507 .514 .798 r
F P
0 g
s
.82569 .57719 m .84083 .58666 L .82112 .64664 L p .511 .522 .803 r
F P
0 g
s
.69386 .51266 m .67959 .50769 L .67699 .47344 L p .611 .619 .834 r
F P
0 g
s
.66292 .4729 m .67699 .47344 L .67959 .50769 L p .615 .628 .841 r
F P
0 g
s
.38845 .48041 m .40246 .47826 L .39871 .495 L p .733 .879 .948 r
F P
0 g
s
.39871 .495 m .38448 .49868 L .38845 .48041 L p .733 .879 .948 r
F P
0 g
s
.54552 .46857 m .55582 .46221 L .5622 .46859 L p .662 .715 .888 r
F P
0 g
s
.55582 .46221 m .54552 .46857 L .53984 .46547 L p .669 .721 .888 r
F P
0 g
s
.60724 .47312 m .59345 .47376 L .5872 .46059 L p .653 .68 .863 r
F P
0 g
s
.57467 .4646 m .5872 .46059 L .59345 .47376 L p .654 .691 .872 r
F P
0 g
s
.46479 .46372 m .477 .46629 L .47123 .47477 L p .711 .805 .923 r
F P
0 g
s
.47123 .47477 m .45762 .47452 L .46479 .46372 L p .711 .805 .923 r
F P
0 g
s
.57467 .4646 m .5622 .46859 L .55582 .46221 L p .664 .704 .877 r
F P
0 g
s
.50491 .45842 m .5117 .46583 L .50578 .46887 L p .699 .771 .908 r
F P
0 g
s
.50578 .46887 m .496 .46336 L .50491 .45842 L p .699 .771 .908 r
F P
0 g
s
.84931 .67384 m .83516 .65997 L .8561 .59661 L p .502 .507 .794 r
F P
0 g
s
.84083 .58666 m .8561 .59661 L .83516 .65997 L p .507 .514 .798 r
F P
0 g
s
.70819 .51805 m .69386 .51266 L .69112 .47422 L p .607 .61 .828 r
F P
0 g
s
.67699 .47344 m .69112 .47422 L .69386 .51266 L p .611 .619 .834 r
F P
0 g
s
.37434 .48305 m .38845 .48041 L .38448 .49868 L p .741 .891 .948 r
F P
0 g
s
.38448 .49868 m .37019 .50279 L .37434 .48305 L p .741 .891 .948 r
F P
0 g
s
.53984 .46547 m .54729 .45727 L .55582 .46221 L p .669 .721 .888 r
F P
0 g
s
.54729 .45727 m .53984 .46547 L .53314 .46356 L p .676 .731 .891 r
F P
0 g
s
.62108 .47271 m .60724 .47312 L .59979 .45656 L p .651 .67 .855 r
F P
0 g
s
.5872 .46059 m .59979 .45656 L .60724 .47312 L p .653 .68 .863 r
F P
0 g
s
.48615 .45805 m .496 .46336 L .48913 .46925 L p .709 .786 .912 r
F P
0 g
s
.48913 .46925 m .477 .46629 L .48615 .45805 L p .709 .786 .912 r
F P
0 g
s
.51524 .45499 m .51856 .46379 L .5117 .46583 L p .698 .764 .903 r
F P
0 g
s
.5117 .46583 m .50491 .45842 L .51524 .45499 L p .698 .764 .903 r
F P
0 g
s
.45249 .46154 m .46479 .46372 L .45762 .47452 L p .723 .817 .923 r
F P
0 g
s
.45762 .47452 m .44395 .47474 L .45249 .46154 L p .723 .817 .923 r
F P
0 g
s
.53314 .46356 m .53721 .45428 L .54729 .45727 L p .676 .731 .891 r
F P
0 g
s
.53721 .45428 m .53314 .46356 L .52588 .46299 L p .684 .743 .896 r
F P
0 g
s
.72258 .52388 m .70819 .51805 L .70533 .47524 L p .604 .601 .822 r
F P
0 g
s
.69112 .47422 m .70533 .47524 L .70819 .51805 L p .607 .61 .828 r
F P
0 g
s
.36013 .48618 m .37434 .48305 L .37019 .50279 L p .748 .903 .947 r
F P
0 g
s
.37019 .50279 m .35584 .50732 L .36013 .48618 L p .748 .903 .947 r
F P
0 g
s
.5872 .46059 m .57467 .4646 L .56617 .45558 L p .666 .694 .867 r
F P
0 g
s
.55582 .46221 m .56617 .45558 L .57467 .4646 L p .664 .704 .877 r
F P
0 g
s
.52627 .45352 m .52588 .46299 L .51856 .46379 L p .692 .754 .899 r
F P
0 g
s
.51856 .46379 m .51524 .45499 L .52627 .45352 L p .692 .754 .899 r
F P
0 g
s
.52588 .46299 m .52627 .45352 L .53721 .45428 L p .684 .743 .896 r
F P
0 g
s
.8561 .59661 m .87149 .60706 L .84931 .67384 L p .502 .507 .794 r
F P
0 g
s
.56617 .45558 m .55582 .46221 L .54729 .45727 L p .673 .712 .877 r
F P
0 g
s
.63497 .47254 m .62108 .47271 L .61243 .45251 L p .65 .66 .847 r
F P
0 g
s
.59979 .45656 m .61243 .45251 L .62108 .47271 L p .651 .67 .855 r
F P
0 g
s
.73704 .53015 m .72258 .52388 L .7196 .47651 L p .601 .593 .816 r
F P
0 g
s
.70533 .47524 m .7196 .47651 L .72258 .52388 L p .604 .601 .822 r
F P
0 g
s
.3458 .48982 m .36013 .48618 L .35584 .50732 L p .754 .914 .945 r
F P
0 g
s
.35584 .50732 m .34142 .51228 L .3458 .48982 L p .754 .914 .945 r
F P
0 g
s
.49806 .45095 m .50491 .45842 L .496 .46336 L p .713 .778 .904 r
F P
0 g
s
.496 .46336 m .48615 .45805 L .49806 .45095 L p .713 .778 .904 r
F P
0 g
s
.4401 .45977 m .45249 .46154 L .44395 .47474 L p .734 .828 .922 r
F P
0 g
s
.44395 .47474 m .4302 .47543 L .4401 .45977 L p .734 .828 .922 r
F P
0 g
s
.47623 .45294 m .48615 .45805 L .477 .46629 L p .722 .796 .91 r
F P
0 g
s
.477 .46629 m .46479 .46372 L .47623 .45294 L p .722 .796 .91 r
F P
0 g
s
.64892 .4726 m .63497 .47254 L .62513 .44844 L p .649 .651 .839 r
F P
0 g
s
.61243 .45251 m .62513 .44844 L .63497 .47254 L p .65 .66 .847 r
F P
0 g
s
.59979 .45656 m .5872 .46059 L .57659 .44867 L p .667 .684 .857 r
F P
0 g
s
.56617 .45558 m .57659 .44867 L .5872 .46059 L p .666 .694 .867 r
F P
0 g
s
.54729 .45727 m .55479 .4486 L .56617 .45558 L p .673 .712 .877 r
F P
0 g
s
.55479 .4486 m .54729 .45727 L .53721 .45428 L p .682 .723 .881 r
F P
0 g
s
.75159 .53686 m .73704 .53015 L .73395 .47802 L p .597 .585 .81 r
F P
0 g
s
.7196 .47651 m .73395 .47802 L .73704 .53015 L p .601 .593 .816 r
F P
0 g
s
.33135 .49397 m .3458 .48982 L .34142 .51228 L p .76 .925 .943 r
F P
0 g
s
.34142 .51228 m .32693 .51768 L .33135 .49397 L p .76 .925 .943 r
F P
0 g
s
.57659 .44867 m .56617 .45558 L .55479 .4486 L p .677 .703 .866 r
F P
0 g
s
.51189 .44587 m .51524 .45499 L .50491 .45842 L p .71 .768 .897 r
F P
0 g
s
.50491 .45842 m .49806 .45095 L .51189 .44587 L p .71 .768 .897 r
F P
0 g
s
.66292 .4729 m .64892 .4726 L .63789 .44436 L p .647 .642 .831 r
F P
0 g
s
.62513 .44844 m .63789 .44436 L .64892 .4726 L p .649 .651 .839 r
F P
0 g
s
.53721 .45428 m .5413 .44446 L .55479 .4486 L p .682 .723 .881 r
F P
0 g
s
.5413 .44446 m .53721 .45428 L .52627 .45352 L p .693 .738 .886 r
F P
0 g
s
.42761 .45839 m .4401 .45977 L .4302 .47543 L p .746 .838 .921 r
F P
0 g
s
.4302 .47543 m .41637 .47661 L .42761 .45839 L p .746 .838 .921 r
F P
0 g
s
.52666 .44355 m .52627 .45352 L .51524 .45499 L p .703 .754 .892 r
F P
0 g
s
.51524 .45499 m .51189 .44587 L .52666 .44355 L p .703 .754 .892 r
F P
0 g
s
.61243 .45251 m .59979 .45656 L .58707 .44148 L p .668 .675 .848 r
F P
0 g
s
.57659 .44867 m .58707 .44148 L .59979 .45656 L p .667 .684 .857 r
F P
0 g
s
.52627 .45352 m .52666 .44355 L .5413 .44446 L p .693 .738 .886 r
F P
0 g
s
.46622 .44803 m .47623 .45294 L .46479 .46372 L p .735 .805 .907 r
F P
0 g
s
.46479 .46372 m .45249 .46154 L .46622 .44803 L p .735 .805 .907 r
F P
0 g
s
.76622 .54401 m .75159 .53686 L .74838 .47978 L p .594 .578 .805 r
F P
0 g
s
.73395 .47802 m .74838 .47978 L .75159 .53686 L p .597 .585 .81 r
F P
0 g
s
.31677 .49864 m .33135 .49397 L .32693 .51768 L p .766 .935 .939 r
F P
0 g
s
.32693 .51768 m .31235 .52351 L .31677 .49864 L p .766 .935 .939 r
F P
0 g
s
.49116 .44341 m .49806 .45095 L .48615 .45805 L p .726 .785 .899 r
F P
0 g
s
.48615 .45805 m .47623 .45294 L .49116 .44341 L p .726 .785 .899 r
F P
0 g
s
.67699 .47344 m .66292 .4729 L .65071 .44025 L p .646 .634 .824 r
F P
0 g
s
.63789 .44436 m .65071 .44025 L .66292 .4729 L p .647 .642 .831 r
F P
0 g
s
.55479 .4486 m .56234 .43946 L .57659 .44867 L p .677 .703 .866 r
F P
0 g
s
.56234 .43946 m .55479 .4486 L .5413 .44446 L p .688 .716 .87 r
F P
0 g
s
.58707 .44148 m .57659 .44867 L .56234 .43946 L p .68 .694 .856 r
F P
0 g
s
.41503 .45742 m .42761 .45839 L .41637 .47661 L p .756 .849 .92 r
F P
0 g
s
.41637 .47661 m .40246 .47826 L .41503 .45742 L p .756 .849 .92 r
F P
0 g
s
.62513 .44844 m .61243 .45251 L .5976 .43402 L p .669 .666 .839 r
F P
0 g
s
.58707 .44148 m .5976 .43402 L .61243 .45251 L p .668 .675 .848 r
F P
0 g
s
.78093 .55161 m .76622 .54401 L .7629 .48179 L p .591 .571 .799 r
F P
0 g
s
.74838 .47978 m .7629 .48179 L .76622 .54401 L p .594 .578 .805 r
F P
0 g
s
.30205 .50384 m .31677 .49864 L .31235 .52351 L p .772 .944 .935 r
F P
0 g
s
.31235 .52351 m .29769 .52979 L .30205 .50384 L p .772 .944 .935 r
F P
0 g
s
.69112 .47422 m .67699 .47344 L .66359 .43613 L p .644 .626 .817 r
F P
0 g
s
.65071 .44025 m .66359 .43613 L .67699 .47344 L p .646 .634 .824 r
F P
0 g
s
.50852 .43643 m .51189 .44587 L .49806 .45095 L p .722 .77 .891 r
F P
0 g
s
.49806 .45095 m .49116 .44341 L .50852 .43643 L p .722 .77 .891 r
F P
0 g
s
.5413 .44446 m .54543 .43408 L .56234 .43946 L p .688 .716 .87 r
F P
0 g
s
.54543 .43408 m .5413 .44446 L .52666 .44355 L p .7 .734 .877 r
F P
0 g
s
.45613 .44331 m .46622 .44803 L .45249 .46154 L p .747 .813 .904 r
F P
0 g
s
.45249 .46154 m .4401 .45977 L .45613 .44331 L p .747 .813 .904 r
F P
0 g
s
.52705 .43309 m .52666 .44355 L .51189 .44587 L p .712 .753 .884 r
F P
0 g
s
.51189 .44587 m .50852 .43643 L .52705 .43309 L p .712 .753 .884 r
F P
0 g
s
.52666 .44355 m .52705 .43309 L .54543 .43408 L p .7 .734 .877 r
F P
0 g
s
.79575 .55967 m .78093 .55161 L .7775 .48406 L p .588 .564 .794 r
F P
0 g
s
.7629 .48179 m .7775 .48406 L .78093 .55161 L p .591 .571 .799 r
F P
0 g
s
.40233 .45686 m .41503 .45742 L .40246 .47826 L p .767 .858 .918 r
F P
0 g
s
.40246 .47826 m .38845 .48041 L .40233 .45686 L p .767 .858 .918 r
F P
0 g
s
.63789 .44436 m .62513 .44844 L .60818 .42627 L p .669 .658 .83 r
F P
0 g
s
.5976 .43402 m .60818 .42627 L .62513 .44844 L p .669 .666 .839 r
F P
0 g
s
.28718 .50957 m .30205 .50384 L .29769 .52979 L p .776 .953 .93 r
F P
0 g
s
.29769 .52979 m .28294 .53651 L .28718 .50957 L p .776 .953 .93 r
F P
0 g
s
.48419 .43581 m .49116 .44341 L .47623 .45294 L p .738 .79 .895 r
F P
0 g
s
.47623 .45294 m .46622 .44803 L .48419 .43581 L p .738 .79 .895 r
F P
0 g
s
.5976 .43402 m .58707 .44148 L .56994 .42985 L p .683 .686 .847 r
F P
0 g
s
.56234 .43946 m .56994 .42985 L .58707 .44148 L p .68 .694 .856 r
F P
0 g
s
.70533 .47524 m .69112 .47422 L .67653 .43199 L p .643 .618 .81 r
F P
0 g
s
.66359 .43613 m .67653 .43199 L .69112 .47422 L p .644 .626 .817 r
F P
0 g
s
.56994 .42985 m .56234 .43946 L .54543 .43408 L p .693 .71 .861 r
F P
0 g
s
.81067 .5682 m .79575 .55967 L .79219 .48657 L p .585 .557 .789 r
F P
0 g
s
.7775 .48406 m .79219 .48657 L .79575 .55967 L p .588 .564 .794 r
F P
0 g
s
.27216 .51584 m .28718 .50957 L .28294 .53651 L p .781 .961 .925 r
F P
0 g
s
.28294 .53651 m .26808 .54369 L .27216 .51584 L p .781 .961 .925 r
F P
0 g
s
.65071 .44025 m .63789 .44436 L .61882 .41825 L p .669 .65 .822 r
F P
0 g
s
.60818 .42627 m .61882 .41825 L .63789 .44436 L p .669 .658 .83 r
F P
0 g
s
.44595 .4388 m .45613 .44331 L .4401 .45977 L p .759 .821 .901 r
F P
0 g
s
.4401 .45977 m .42761 .45839 L .44595 .4388 L p .759 .821 .901 r
F P
0 g
s
.7196 .47651 m .70533 .47524 L .68953 .42783 L p .641 .611 .804 r
F P
0 g
s
.67653 .43199 m .68953 .42783 L .70533 .47524 L p .643 .618 .81 r
F P
0 g
s
.38952 .45672 m .40233 .45686 L .38845 .48041 L p .777 .868 .915 r
F P
0 g
s
.38845 .48041 m .37434 .48305 L .38952 .45672 L p .777 .868 .915 r
F P
0 g
s
.50511 .42667 m .50852 .43643 L .49116 .44341 L p .733 .773 .885 r
F P
0 g
s
.49116 .44341 m .48419 .43581 L .50511 .42667 L p .733 .773 .885 r
F P
0 g
s
.54543 .43408 m .54959 .42315 L .56994 .42985 L p .693 .71 .861 r
F P
0 g
s
.54959 .42315 m .54543 .43408 L .52705 .43309 L p .708 .73 .868 r
F P
0 g
s
.60818 .42627 m .5976 .43402 L .57758 .41976 L p .685 .678 .837 r
F P
0 g
s
.56994 .42985 m .57758 .41976 L .5976 .43402 L p .683 .686 .847 r
F P
0 g
s
.47717 .42815 m .48419 .43581 L .46622 .44803 L p .75 .796 .89 r
F P
0 g
s
.46622 .44803 m .45613 .44331 L .47717 .42815 L p .75 .796 .89 r
F P
0 g
s
.57758 .41976 m .56994 .42985 L .54959 .42315 L p .698 .703 .851 r
F P
0 g
s
.52705 .43309 m .52745 .42213 L .54959 .42315 L p .708 .73 .868 r
F P
0 g
s
.52745 .42213 m .52705 .43309 L .50852 .43643 L p .722 .752 .877 r
F P
0 g
s
.50852 .43643 m .50511 .42667 L .52745 .42213 L p .722 .752 .877 r
F P
0 g
s
.82569 .57719 m .81067 .5682 L .80698 .48934 L p .583 .551 .784 r
F P
0 g
s
.79219 .48657 m .80698 .48934 L .81067 .5682 L p .585 .557 .789 r
F P
0 g
s
.73395 .47802 m .7196 .47651 L .70259 .42365 L p .639 .604 .797 r
F P
0 g
s
.68953 .42783 m .70259 .42365 L .7196 .47651 L p .641 .611 .804 r
F P
0 g
s
.66359 .43613 m .65071 .44025 L .62951 .40995 L p .669 .642 .814 r
F P
0 g
s
.61882 .41825 m .62951 .40995 L .65071 .44025 L p .669 .65 .822 r
F P
0 g
s
.25697 .52267 m .27216 .51584 L .26808 .54369 L p .784 .968 .919 r
F P
0 g
s
.26808 .54369 m .25312 .55133 L .25697 .52267 L p .784 .968 .919 r
F P
0 g
s
.37659 .45699 m .38952 .45672 L .37434 .48305 L p .787 .877 .913 r
F P
0 g
s
.37434 .48305 m .36013 .48618 L .37659 .45699 L p .787 .877 .913 r
F P
0 g
s
.61882 .41825 m .60818 .42627 L .58527 .40919 L p .687 .671 .829 r
F P
0 g
s
.57758 .41976 m .58527 .40919 L .60818 .42627 L p .685 .678 .837 r
F P
0 g
s
.43568 .43449 m .44595 .4388 L .42761 .45839 L p .771 .828 .897 r
F P
0 g
s
.42761 .45839 m .41503 .45742 L .43568 .43449 L p .771 .828 .897 r
F P
0 g
s
.54959 .42315 m .55377 .41165 L .57758 .41976 L p .698 .703 .851 r
F P
0 g
s
.55377 .41165 m .54959 .42315 L .52745 .42213 L p .714 .726 .86 r
F P
0 g
s
.74838 .47978 m .73395 .47802 L .71571 .41944 L p .638 .597 .791 r
F P
0 g
s
.70259 .42365 m .71571 .41944 L .73395 .47802 L p .639 .604 .797 r
F P
0 g
s
.67653 .43199 m .66359 .43613 L .64024 .40136 L p .669 .635 .807 r
F P
0 g
s
.62951 .40995 m .64024 .40136 L .66359 .43613 L p .669 .642 .814 r
F P
0 g
s
.84083 .58666 m .82569 .57719 L .82187 .49238 L p .58 .544 .779 r
F P
0 g
s
.80698 .48934 m .82187 .49238 L .82569 .57719 L p .583 .551 .784 r
F P
0 g
s
.50168 .41659 m .50511 .42667 L .48419 .43581 L p .743 .775 .879 r
F P
0 g
s
.48419 .43581 m .47717 .42815 L .50168 .41659 L p .743 .775 .879 r
F P
0 g
s
.24162 .53005 m .25697 .52267 L .25312 .55133 L p .787 .975 .911 r
F P
0 g
s
.25312 .55133 m .23805 .55944 L .24162 .53005 L p .787 .975 .911 r
F P
0 g
s
.58527 .40919 m .57758 .41976 L .55377 .41165 L p .702 .697 .842 r
F P
0 g
s
.47008 .42042 m .47717 .42815 L .45613 .44331 L p .761 .801 .885 r
F P
0 g
s
.45613 .44331 m .44595 .4388 L .47008 .42042 L p .761 .801 .885 r
F P
0 g
s
.52745 .42213 m .52785 .41067 L .55377 .41165 L p .714 .726 .86 r
F P
0 g
s
.52785 .41067 m .52745 .42213 L .50511 .42667 L p .73 .751 .869 r
F P
0 g
s
.50511 .42667 m .50168 .41659 L .52785 .41067 L p .73 .751 .869 r
F P
0 g
s
.62951 .40995 m .61882 .41825 L .593 .39815 L p .689 .664 .82 r
F P
0 g
s
.58527 .40919 m .593 .39815 L .61882 .41825 L p .687 .671 .829 r
F P
0 g
s
.36354 .45769 m .37659 .45699 L .36013 .48618 L p .797 .885 .909 r
F P
0 g
s
.36013 .48618 m .3458 .48982 L .36354 .45769 L p .797 .885 .909 r
F P
0 g
s
.7629 .48179 m .74838 .47978 L .72889 .41522 L p .636 .59 .786 r
F P
0 g
s
.71571 .41944 m .72889 .41522 L .74838 .47978 L p .638 .597 .791 r
F P
0 g
s
.68953 .42783 m .67653 .43199 L .65102 .3925 L p .669 .628 .8 r
F P
0 g
s
.64024 .40136 m .65102 .3925 L .67653 .43199 L p .669 .635 .807 r
F P
0 g
s
.42532 .43038 m .43568 .43449 L .41503 .45742 L p .782 .835 .893 r
F P
0 g
s
.41503 .45742 m .40233 .45686 L .42532 .43038 L p .782 .835 .893 r
F P
0 g
s
.8561 .59661 m .84083 .58666 L .83686 .49567 L p .577 .538 .775 r
F P
0 g
s
.82187 .49238 m .83686 .49567 L .84083 .58666 L p .58 .544 .779 r
F P
0 g
s
.22608 .53801 m .24162 .53005 L .23805 .55944 L p .79 .98 .904 r
F P
0 g
s
.23805 .55944 m .22286 .56802 L .22608 .53801 L p .79 .98 .904 r
F P
0 g
s
.55377 .41165 m .55799 .39961 L .58527 .40919 L p .702 .697 .842 r
F P
0 g
s
.55799 .39961 m .55377 .41165 L .52785 .41067 L p .72 .722 .851 r
F P
0 g
s
.593 .39815 m .58527 .40919 L .55799 .39961 L p .705 .691 .834 r
F P
0 g
s
.64024 .40136 m .62951 .40995 L .60076 .38663 L p .69 .657 .812 r
F P
0 g
s
.593 .39815 m .60076 .38663 L .62951 .40995 L p .689 .664 .82 r
F P
0 g
s
.49822 .40618 m .50168 .41659 L .47717 .42815 L p .753 .777 .873 r
F P
0 g
s
.47717 .42815 m .47008 .42042 L .49822 .40618 L p .753 .777 .873 r
F P
0 g
s
.7775 .48406 m .7629 .48179 L .74213 .41098 L p .635 .584 .78 r
F P
0 g
s
.72889 .41522 m .74213 .41098 L .7629 .48179 L p .636 .59 .786 r
F P
0 g
s
.70259 .42365 m .68953 .42783 L .66185 .38335 L p .669 .622 .793 r
F P
0 g
s
.65102 .3925 m .66185 .38335 L .68953 .42783 L p .669 .628 .8 r
F P
0 g
s
.35035 .45881 m .36354 .45769 L .3458 .48982 L p .806 .893 .906 r
F P
0 g
s
.3458 .48982 m .33135 .49397 L .35035 .45881 L p .806 .893 .906 r
F P
0 g
s
.46294 .41262 m .47008 .42042 L .44595 .4388 L p .771 .806 .88 r
F P
0 g
s
.44595 .4388 m .43568 .43449 L .46294 .41262 L p .771 .806 .88 r
F P
0 g
s
.52785 .41067 m .52826 .3987 L .55799 .39961 L p .72 .722 .851 r
F P
0 g
s
.52826 .3987 m .52785 .41067 L .50168 .41659 L p .738 .75 .862 r
F P
0 g
s
.87149 .60706 m .8561 .59661 L .85196 .49923 L p .575 .533 .77 r
F P
0 g
s
.83686 .49567 m .85196 .49923 L .8561 .59661 L p .577 .538 .775 r
F P
0 g
s
.21035 .54656 m .22608 .53801 L .22286 .56802 L p .792 .985 .895 r
F P
0 g
s
.22286 .56802 m .20755 .57708 L .21035 .54656 L p .792 .985 .895 r
F P
0 g
s
.50168 .41659 m .49822 .40618 L .52826 .3987 L p .738 .75 .862 r
F P
0 g
s
.41486 .42647 m .42532 .43038 L .40233 .45686 L p .792 .842 .889 r
F P
0 g
s
.40233 .45686 m .38952 .45672 L .41486 .42647 L p .792 .842 .889 r
F P
0 g
s
.60076 .38663 m .593 .39815 L .56222 .387 L p .708 .685 .826 r
F P
0 g
s
.55799 .39961 m .56222 .387 L .593 .39815 L p .705 .691 .834 r
F P
0 g
s
.65102 .3925 m .64024 .40136 L .60856 .37463 L p .691 .651 .805 r
F P
0 g
s
.60076 .38663 m .60856 .37463 L .64024 .40136 L p .69 .657 .812 r
F P
0 g
s
.79219 .48657 m .7775 .48406 L .75544 .40673 L p .634 .578 .775 r
F P
0 g
s
.74213 .41098 m .75544 .40673 L .7775 .48406 L p .635 .584 .78 r
F P
0 g
s
.71571 .41944 m .70259 .42365 L .67272 .37393 L p .669 .616 .786 r
F P
0 g
s
.66185 .38335 m .67272 .37393 L .70259 .42365 L p .669 .622 .793 r
F P
0 g
s
.56222 .387 m .55799 .39961 L .52826 .3987 L p .725 .718 .844 r
F P
0 g
s
.85196 .49923 m .86717 .50306 L .87149 .60706 L p .575 .533 .77 r
F P
0 g
s
.33702 .46037 m .35035 .45881 L .33135 .49397 L p .815 .901 .902 r
F P
0 g
s
.33135 .49397 m .31677 .49864 L .33702 .46037 L p .815 .901 .902 r
F P
0 g
s
.19441 .5557 m .21035 .54656 L .20755 .57708 L p .794 .99 .886 r
F P
0 g
s
.20755 .57708 m .1921 .58662 L .19441 .5557 L p .794 .99 .886 r
F P
0 g
s
.49473 .39545 m .49822 .40618 L .47008 .42042 L p .762 .779 .867 r
F P
0 g
s
.47008 .42042 m .46294 .41262 L .49473 .39545 L p .762 .779 .867 r
F P
0 g
s
.72889 .41522 m .71571 .41944 L .68362 .36422 L p .668 .61 .78 r
F P
0 g
s
.67272 .37393 m .68362 .36422 L .71571 .41944 L p .669 .616 .786 r
F P
0 g
s
.52826 .3987 m .52866 .38623 L .56222 .387 L p .725 .718 .844 r
F P
0 g
s
.52866 .38623 m .52826 .3987 L .49822 .40618 L p .745 .749 .855 r
F P
0 g
s
.66185 .38335 m .65102 .3925 L .61639 .36216 L p .692 .645 .798 r
F P
0 g
s
.60856 .37463 m .61639 .36216 L .65102 .3925 L p .691 .651 .805 r
F P
0 g
s
.45573 .40475 m .46294 .41262 L .43568 .43449 L p .782 .81 .875 r
F P
0 g
s
.43568 .43449 m .42532 .43038 L .45573 .40475 L p .782 .81 .875 r
F P
0 g
s
.80698 .48934 m .79219 .48657 L .76881 .40245 L p .632 .573 .77 r
F P
0 g
s
.75544 .40673 m .76881 .40245 L .79219 .48657 L p .634 .578 .775 r
F P
0 g
s
.60856 .37463 m .60076 .38663 L .56648 .37383 L p .711 .68 .818 r
F P
0 g
s
.56222 .387 m .56648 .37383 L .60076 .38663 L p .708 .685 .826 r
F P
0 g
s
.49822 .40618 m .49473 .39545 L .52866 .38623 L p .745 .749 .855 r
F P
0 g
s
.4043 .42278 m .41486 .42647 L .38952 .45672 L p .802 .848 .885 r
F P
0 g
s
.38952 .45672 m .37659 .45699 L .4043 .42278 L p .802 .848 .885 r
F P
0 g
s
.56648 .37383 m .56222 .387 L .52866 .38623 L p .73 .714 .836 r
F P
0 g
s
.17827 .56546 m .19441 .5557 L .1921 .58662 L p .795 .993 .877 r
F P
0 g
s
.1921 .58662 m .17651 .59667 L .17827 .56546 L p .795 .993 .877 r
F P
0 g
s
.74213 .41098 m .72889 .41522 L .69457 .35423 L p .668 .604 .774 r
F P
0 g
s
.68362 .36422 m .69457 .35423 L .72889 .41522 L p .668 .61 .78 r
F P
0 g
s
.67272 .37393 m .66185 .38335 L .62425 .34922 L p .693 .639 .791 r
F P
0 g
s
.61639 .36216 m .62425 .34922 L .66185 .38335 L p .692 .645 .798 r
F P
0 g
s
.82187 .49238 m .80698 .48934 L .78224 .39815 L p .631 .567 .765 r
F P
0 g
s
.76881 .40245 m .78224 .39815 L .80698 .48934 L p .632 .573 .77 r
F P
0 g
s
.32354 .46237 m .33702 .46037 L .31677 .49864 L p .823 .908 .897 r
F P
0 g
s
.31677 .49864 m .30205 .50384 L .32354 .46237 L p .823 .908 .897 r
F P
0 g
s
.61639 .36216 m .60856 .37463 L .57076 .36011 L p .714 .675 .81 r
F P
0 g
s
.56648 .37383 m .57076 .36011 L .60856 .37463 L p .711 .68 .818 r
F P
0 g
s
.49122 .3844 m .49473 .39545 L .46294 .41262 L p .77 .781 .861 r
F P
0 g
s
.46294 .41262 m .45573 .40475 L .49122 .3844 L p .77 .781 .861 r
F P
0 g
s
.52866 .38623 m .52907 .37325 L .56648 .37383 L p .73 .714 .836 r
F P
0 g
s
.52907 .37325 m .52866 .38623 L .49473 .39545 L p .752 .748 .848 r
F P
0 g
s
.44846 .39682 m .45573 .40475 L .42532 .43038 L p .791 .814 .87 r
F P
0 g
s
.42532 .43038 m .41486 .42647 L .44846 .39682 L p .791 .814 .87 r
F P
0 g
s
.57076 .36011 m .56648 .37383 L .52907 .37325 L p .734 .71 .829 r
F P
0 g
s
.75544 .40673 m .74213 .41098 L .70554 .34397 L p .668 .598 .769 r
F P
0 g
s
.69457 .35423 m .70554 .34397 L .74213 .41098 L p .668 .604 .774 r
F P
0 g
s
.68362 .36422 m .67272 .37393 L .63214 .3358 L p .694 .633 .784 r
F P
0 g
s
.62425 .34922 m .63214 .3358 L .67272 .37393 L p .693 .639 .791 r
F P
0 g
s
.49473 .39545 m .49122 .3844 L .52907 .37325 L p .752 .748 .848 r
F P
0 g
s
.39363 .41929 m .4043 .42278 L .37659 .45699 L p .812 .854 .88 r
F P
0 g
s
.37659 .45699 m .36354 .45769 L .39363 .41929 L p .812 .854 .88 r
F P
0 g
s
.83686 .49567 m .82187 .49238 L .79573 .39382 L p .629 .562 .76 r
F P
0 g
s
.78224 .39815 m .79573 .39382 L .82187 .49238 L p .631 .567 .765 r
F P
0 g
s
.62425 .34922 m .61639 .36216 L .57506 .34583 L p .716 .669 .803 r
F P
0 g
s
.57076 .36011 m .57506 .34583 L .61639 .36216 L p .714 .675 .81 r
F P
0 g
s
.30991 .46483 m .32354 .46237 L .30205 .50384 L p .832 .915 .893 r
F P
0 g
s
.30205 .50384 m .28718 .50957 L .30991 .46483 L p .832 .915 .893 r
F P
0 g
s
.76881 .40245 m .75544 .40673 L .71656 .33342 L p .667 .593 .763 r
F P
0 g
s
.70554 .34397 m .71656 .33342 L .75544 .40673 L p .668 .598 .769 r
F P
0 g
s
.69457 .35423 m .68362 .36422 L .64005 .32191 L p .695 .628 .778 r
F P
0 g
s
.63214 .3358 m .64005 .32191 L .68362 .36422 L p .694 .633 .784 r
F P
0 g
s
.52907 .37325 m .52948 .35977 L .57076 .36011 L p .734 .71 .829 r
F P
0 g
s
.52948 .35977 m .52907 .37325 L .49122 .3844 L p .758 .746 .842 r
F P
0 g
s
.57506 .34583 m .57076 .36011 L .52948 .35977 L p .738 .707 .822 r
F P
0 g
s
.48768 .37301 m .49122 .3844 L .45573 .40475 L p .779 .782 .855 r
F P
0 g
s
.45573 .40475 m .44846 .39682 L .48768 .37301 L p .779 .782 .855 r
F P
0 g
s
.85196 .49923 m .83686 .49567 L .80929 .38948 L p .628 .557 .755 r
F P
0 g
s
.79573 .39382 m .80929 .38948 L .83686 .49567 L p .629 .562 .76 r
F P
0 g
s
.63214 .3358 m .62425 .34922 L .57938 .33099 L p .718 .665 .797 r
F P
0 g
s
.57506 .34583 m .57938 .33099 L .62425 .34922 L p .716 .669 .803 r
F P
0 g
s
.44112 .38881 m .44846 .39682 L .41486 .42647 L p .8 .818 .865 r
F P
0 g
s
.41486 .42647 m .4043 .42278 L .44112 .38881 L p .8 .818 .865 r
F P
0 g
s
.49122 .3844 m .48768 .37301 L .52948 .35977 L p .758 .746 .842 r
F P
0 g
s
.38286 .41602 m .39363 .41929 L .36354 .45769 L p .821 .859 .876 r
F P
0 g
s
.36354 .45769 m .35035 .45881 L .38286 .41602 L p .821 .859 .876 r
F P
0 g
s
.70554 .34397 m .69457 .35423 L .64799 .30755 L p .695 .623 .772 r
F P
0 g
s
.64005 .32191 m .64799 .30755 L .69457 .35423 L p .695 .628 .778 r
F P
0 g
s
.78224 .39815 m .76881 .40245 L .7276 .3226 L p .667 .588 .758 r
F P
0 g
s
.71656 .33342 m .7276 .3226 L .76881 .40245 L p .667 .593 .763 r
F P
0 g
s
.29612 .46774 m .30991 .46483 L .28718 .50957 L p .839 .921 .888 r
F P
0 g
s
.28718 .50957 m .27216 .51584 L .29612 .46774 L p .839 .921 .888 r
F P
0 g
s
.57938 .33099 m .57506 .34583 L .5299 .34578 L p .742 .703 .815 r
F P
0 g
s
.52948 .35977 m .5299 .34578 L .57506 .34583 L p .738 .707 .822 r
F P
0 g
s
.64005 .32191 m .63214 .3358 L .58371 .3156 L p .72 .66 .79 r
F P
0 g
s
.57938 .33099 m .58371 .3156 L .63214 .3358 L p .718 .665 .797 r
F P
0 g
s
.86717 .50306 m .85196 .49923 L .82291 .38512 L p .627 .552 .751 r
F P
0 g
s
.80929 .38948 m .82291 .38512 L .85196 .49923 L p .628 .557 .755 r
F P
0 g
s
.5299 .34578 m .52948 .35977 L .48768 .37301 L p .764 .745 .835 r
F P
0 g
s
.71656 .33342 m .70554 .34397 L .65593 .29272 L p .695 .618 .766 r
F P
0 g
s
.64799 .30755 m .65593 .29272 L .70554 .34397 L p .695 .623 .772 r
F P
0 g
s
.79573 .39382 m .78224 .39815 L .73867 .31149 L p .666 .583 .753 r
F P
0 g
s
.7276 .3226 m .73867 .31149 L .78224 .39815 L p .667 .588 .758 r
F P
0 g
s
.48411 .3613 m .48768 .37301 L .44846 .39682 L p .786 .783 .85 r
F P
0 g
s
.44846 .39682 m .44112 .38881 L .48411 .3613 L p .786 .783 .85 r
F P
0 g
s
.48768 .37301 m .48411 .3613 L .5299 .34578 L p .764 .745 .835 r
F P
0 g
s
.64799 .30755 m .64005 .32191 L .58805 .29966 L p .721 .656 .784 r
F P
0 g
s
.58371 .3156 m .58805 .29966 L .64005 .32191 L p .72 .66 .79 r
F P
0 g
s
.43372 .38074 m .44112 .38881 L .4043 .42278 L p .809 .821 .86 r
F P
0 g
s
.4043 .42278 m .39363 .41929 L .43372 .38074 L p .809 .821 .86 r
F P
0 g
s
.58371 .3156 m .57938 .33099 L .53031 .33129 L p .745 .7 .808 r
F P
0 g
s
.5299 .34578 m .53031 .33129 L .57938 .33099 L p .742 .703 .815 r
F P
0 g
s
.7276 .3226 m .71656 .33342 L .6639 .27743 L p .696 .614 .761 r
F P
0 g
s
.65593 .29272 m .6639 .27743 L .71656 .33342 L p .695 .618 .766 r
F P
0 g
s
.37197 .41296 m .38286 .41602 L .35035 .45881 L p .83 .864 .871 r
F P
0 g
s
.35035 .45881 m .33702 .46037 L .37197 .41296 L p .83 .864 .871 r
F P
0 g
s
.82291 .38512 m .8366 .38074 L .86717 .50306 L p .627 .552 .751 r
F P
0 g
s
.80929 .38948 m .79573 .39382 L .74977 .30011 L p .666 .579 .748 r
F P
0 g
s
.73867 .31149 m .74977 .30011 L .79573 .39382 L p .666 .583 .753 r
F P
0 g
s
.28215 .47111 m .29612 .46774 L .27216 .51584 L p .847 .926 .883 r
F P
0 g
s
.27216 .51584 m .25697 .52267 L .28215 .47111 L p .847 .926 .883 r
F P
0 g
s
.53031 .33129 m .5299 .34578 L .48411 .3613 L p .769 .743 .829 r
F P
0 g
s
.65593 .29272 m .64799 .30755 L .59241 .28317 L p .723 .651 .778 r
F P
0 g
s
.58805 .29966 m .59241 .28317 L .64799 .30755 L p .721 .656 .784 r
F P
0 g
s
.73867 .31149 m .7276 .3226 L .67188 .26168 L p .696 .609 .755 r
F P
0 g
s
.6639 .27743 m .67188 .26168 L .7276 .3226 L p .696 .614 .761 r
F P
0 g
s
.58805 .29966 m .58371 .3156 L .53073 .31629 L p .749 .697 .802 r
F P
0 g
s
.53031 .33129 m .53073 .31629 L .58371 .3156 L p .745 .7 .808 r
F P
0 g
s
.82291 .38512 m .80929 .38948 L .76089 .28846 L p .665 .574 .743 r
F P
0 g
s
.74977 .30011 m .76089 .28846 L .80929 .38948 L p .666 .579 .748 r
F P
0 g
s
.48052 .34925 m .48411 .3613 L .44112 .38881 L p .794 .784 .844 r
F P
0 g
s
.44112 .38881 m .43372 .38074 L .48052 .34925 L p .794 .784 .844 r
F P
0 g
s
.48411 .3613 m .48052 .34925 L .53031 .33129 L p .769 .743 .829 r
F P
0 g
s
.6639 .27743 m .65593 .29272 L .59678 .26613 L p .724 .647 .772 r
F P
0 g
s
.59241 .28317 m .59678 .26613 L .65593 .29272 L p .723 .651 .778 r
F P
0 g
s
.74977 .30011 m .73867 .31149 L .67986 .24548 L p .696 .605 .75 r
F P
0 g
s
.67188 .26168 m .67986 .24548 L .73867 .31149 L p .696 .609 .755 r
F P
0 g
s
.42626 .3726 m .43372 .38074 L .39363 .41929 L p .817 .824 .854 r
F P
0 g
s
.39363 .41929 m .38286 .41602 L .42626 .3726 L p .817 .824 .854 r
F P
0 g
s
.53073 .31629 m .53031 .33129 L .48052 .34925 L p .775 .742 .823 r
F P
0 g
s
.36096 .41011 m .37197 .41296 L .33702 .46037 L p .838 .869 .866 r
F P
0 g
s
.33702 .46037 m .32354 .46237 L .36096 .41011 L p .838 .869 .866 r
F P
0 g
s
.268 .47496 m .28215 .47111 L .25697 .52267 L p .854 .932 .877 r
F P
0 g
s
.25697 .52267 m .24162 .53005 L .268 .47496 L p .854 .932 .877 r
F P
0 g
s
.59241 .28317 m .58805 .29966 L .53115 .30079 L p .752 .694 .796 r
F P
0 g
s
.53073 .31629 m .53115 .30079 L .58805 .29966 L p .749 .697 .802 r
F P
0 g
s
.8366 .38074 m .82291 .38512 L .77203 .27653 L p .665 .57 .739 r
F P
0 g
s
.76089 .28846 m .77203 .27653 L .82291 .38512 L p .665 .574 .743 r
F P
0 g
s
.67188 .26168 m .6639 .27743 L .60116 .24856 L p .725 .644 .767 r
F P
0 g
s
.59678 .26613 m .60116 .24856 L .6639 .27743 L p .724 .647 .772 r
F P
0 g
s
.76089 .28846 m .74977 .30011 L .68785 .22882 L p .696 .601 .745 r
F P
0 g
s
.67986 .24548 m .68785 .22882 L .74977 .30011 L p .696 .605 .75 r
F P
0 g
s
.48052 .34925 m .47691 .33687 L .53073 .31629 L p .775 .742 .823 r
F P
0 g
s
.47691 .33687 m .48052 .34925 L .43372 .38074 L p .8 .785 .838 r
F P
0 g
s
.53115 .30079 m .53073 .31629 L .47691 .33687 L p .779 .741 .817 r
F P
0 g
s
.67986 .24548 m .67188 .26168 L .60554 .23045 L p .727 .64 .761 r
F P
0 g
s
.60116 .24856 m .60554 .23045 L .67188 .26168 L p .725 .644 .767 r
F P
0 g
s
.59678 .26613 m .59241 .28317 L .53157 .28478 L p .754 .691 .79 r
F P
0 g
s
.53115 .30079 m .53157 .28478 L .59241 .28317 L p .752 .694 .796 r
F P
0 g
s
.43372 .38074 m .42626 .3726 L .47691 .33687 L p .8 .785 .838 r
F P
0 g
s
.77203 .27653 m .78319 .26432 L .8366 .38074 L p .665 .57 .739 r
F P
0 g
s
.77203 .27653 m .76089 .28846 L .69584 .21171 L p .697 .597 .741 r
F P
0 g
s
.68785 .22882 m .69584 .21171 L .76089 .28846 L p .696 .601 .745 r
F P
0 g
s
.41873 .36438 m .42626 .3726 L .38286 .41602 L p .825 .827 .849 r
F P
0 g
s
.38286 .41602 m .37197 .41296 L .41873 .36438 L p .825 .827 .849 r
F P
0 g
s
.68785 .22882 m .67986 .24548 L .60993 .2118 L p .728 .636 .756 r
F P
0 g
s
.60554 .23045 m .60993 .2118 L .67986 .24548 L p .727 .64 .761 r
F P
0 g
s
.34984 .40749 m .36096 .41011 L .32354 .46237 L p .846 .873 .861 r
F P
0 g
s
.32354 .46237 m .30991 .46483 L .34984 .40749 L p .846 .873 .861 r
F P
0 g
s
.78319 .26432 m .77203 .27653 L .70383 .19416 L p .697 .593 .736 r
F P
0 g
s
.69584 .21171 m .70383 .19416 L .77203 .27653 L p .697 .597 .741 r
F P
0 g
s
.25367 .47928 m .268 .47496 L .24162 .53005 L p .86 .936 .871 r
F P
0 g
s
.24162 .53005 m .22608 .53801 L .25367 .47928 L p .86 .936 .871 r
F P
0 g
s
.60116 .24856 m .59678 .26613 L .53199 .26828 L p .757 .688 .785 r
F P
0 g
s
.53157 .28478 m .53199 .26828 L .59678 .26613 L p .754 .691 .79 r
F P
0 g
s
.53157 .28478 m .53115 .30079 L .47327 .32416 L p .784 .739 .812 r
F P
0 g
s
.47691 .33687 m .47327 .32416 L .53115 .30079 L p .779 .741 .817 r
F P
0 g
s
.69584 .21171 m .68785 .22882 L .61432 .19264 L p .729 .633 .752 r
F P
0 g
s
.60993 .2118 m .61432 .19264 L .68785 .22882 L p .728 .636 .756 r
F P
0 g
s
.70383 .19416 m .71182 .17618 L .78319 .26432 L p .697 .593 .736 r
F P
0 g
s
.47327 .32416 m .47691 .33687 L .42626 .3726 L p .807 .785 .833 r
F P
0 g
s
.60554 .23045 m .60116 .24856 L .53242 .25128 L p .759 .685 .78 r
F P
0 g
s
.53199 .26828 m .53242 .25128 L .60116 .24856 L p .757 .688 .785 r
F P
0 g
s
.42626 .3726 m .41873 .36438 L .47327 .32416 L p .807 .785 .833 r
F P
0 g
s
.70383 .19416 m .69584 .21171 L .61871 .17295 L p .729 .629 .747 r
F P
0 g
s
.61432 .19264 m .61871 .17295 L .69584 .21171 L p .729 .633 .752 r
F P
0 g
s
.71182 .17618 m .70383 .19416 L .6231 .15275 L p .73 .626 .742 r
F P
0 g
s
.61871 .17295 m .6231 .15275 L .70383 .19416 L p .729 .629 .747 r
F P
0 g
s
.41113 .35609 m .41873 .36438 L .37197 .41296 L p .833 .829 .844 r
F P
0 g
s
.37197 .41296 m .36096 .41011 L .41113 .35609 L p .833 .829 .844 r
F P
0 g
s
.53199 .26828 m .53157 .28478 L .46961 .31111 L p .788 .738 .806 r
F P
0 g
s
.47327 .32416 m .46961 .31111 L .53157 .28478 L p .784 .739 .812 r
F P
0 g
s
.60993 .2118 m .60554 .23045 L .53284 .23378 L p .762 .682 .774 r
F P
0 g
s
.53242 .25128 m .53284 .23378 L .60554 .23045 L p .759 .685 .78 r
F P
0 g
s
.23914 .48411 m .25367 .47928 L .22608 .53801 L p .866 .941 .866 r
F P
0 g
s
.22608 .53801 m .21035 .54656 L .23914 .48411 L p .866 .941 .866 r
F P
0 g
s
.33859 .40508 m .34984 .40749 L .30991 .46483 L p .854 .877 .855 r
F P
0 g
s
.30991 .46483 m .29612 .46774 L .33859 .40508 L p .854 .877 .855 r
F P
0 g
s
.6231 .15275 m .62749 .13205 L .71182 .17618 L p .73 .626 .742 r
F P
0 g
s
.46961 .31111 m .47327 .32416 L .41873 .36438 L p .813 .786 .827 r
F P
0 g
s
.61432 .19264 m .60993 .2118 L .53327 .21579 L p .764 .679 .769 r
F P
0 g
s
.53284 .23378 m .53327 .21579 L .60993 .2118 L p .762 .682 .774 r
F P
0 g
s
.53242 .25128 m .53199 .26828 L .46592 .29773 L p .792 .736 .801 r
F P
0 g
s
.46961 .31111 m .46592 .29773 L .53199 .26828 L p .788 .738 .806 r
F P
0 g
s
.41873 .36438 m .41113 .35609 L .46961 .31111 L p .813 .786 .827 r
F P
0 g
s
.61871 .17295 m .61432 .19264 L .5337 .19731 L p .766 .677 .765 r
F P
0 g
s
.53327 .21579 m .5337 .19731 L .61432 .19264 L p .764 .679 .769 r
F P
0 g
s
.40346 .34772 m .41113 .35609 L .36096 .41011 L p .84 .831 .838 r
F P
0 g
s
.36096 .41011 m .34984 .40749 L .40346 .34772 L p .84 .831 .838 r
F P
0 g
s
.46592 .29773 m .46961 .31111 L .41113 .35609 L p .819 .786 .822 r
F P
0 g
s
.2244 .48943 m .23914 .48411 L .21035 .54656 L p .872 .945 .86 r
F P
0 g
s
.21035 .54656 m .19441 .5557 L .2244 .48943 L p .872 .945 .86 r
F P
0 g
s
.6231 .15275 m .61871 .17295 L .53413 .17835 L p .768 .674 .76 r
F P
0 g
s
.5337 .19731 m .53413 .17835 L .61871 .17295 L p .766 .677 .765 r
F P
0 g
s
.3272 .4029 m .33859 .40508 L .29612 .46774 L p .861 .88 .85 r
F P
0 g
s
.29612 .46774 m .28215 .47111 L .3272 .4029 L p .861 .88 .85 r
F P
0 g
s
.53284 .23378 m .53242 .25128 L .46222 .28401 L p .796 .735 .795 r
F P
0 g
s
.46592 .29773 m .46222 .28401 L .53242 .25128 L p .792 .736 .801 r
F P
0 g
s
.62749 .13205 m .6231 .15275 L .53455 .1589 L p .769 .672 .755 r
F P
0 g
s
.53413 .17835 m .53455 .1589 L .6231 .15275 L p .768 .674 .76 r
F P
0 g
s
.41113 .35609 m .40346 .34772 L .46592 .29773 L p .819 .786 .822 r
F P
0 g
s
.53455 .1589 m .53498 .13899 L .62749 .13205 L p .769 .672 .755 r
F P
0 g
s
.53327 .21579 m .53284 .23378 L .45849 .26996 L p .8 .733 .79 r
F P
0 g
s
.46222 .28401 m .45849 .26996 L .53284 .23378 L p .796 .735 .795 r
F P
0 g
s
.46222 .28401 m .46592 .29773 L .40346 .34772 L p .824 .786 .816 r
F P
0 g
s
.39573 .33928 m .40346 .34772 L .34984 .40749 L p .847 .833 .833 r
F P
0 g
s
.34984 .40749 m .33859 .40508 L .39573 .33928 L p .847 .833 .833 r
F P
0 g
s
.20945 .49527 m .2244 .48943 L .19441 .5557 L p .878 .948 .853 r
F P
0 g
s
.19441 .5557 m .17827 .56546 L .20945 .49527 L p .878 .948 .853 r
F P
0 g
s
.5337 .19731 m .53327 .21579 L .45474 .25557 L p .803 .732 .785 r
F P
0 g
s
.45849 .26996 m .45474 .25557 L .53327 .21579 L p .8 .733 .79 r
F P
0 g
s
.31569 .40095 m .3272 .4029 L .28215 .47111 L p .868 .883 .845 r
F P
0 g
s
.28215 .47111 m .268 .47496 L .31569 .40095 L p .868 .883 .845 r
F P
0 g
s
.40346 .34772 m .39573 .33928 L .46222 .28401 L p .824 .786 .816 r
F P
0 g
s
.45849 .26996 m .46222 .28401 L .39573 .33928 L p .83 .787 .811 r
F P
0 g
s
.53413 .17835 m .5337 .19731 L .45097 .24084 L p .806 .73 .781 r
F P
0 g
s
.45474 .25557 m .45097 .24084 L .5337 .19731 L p .803 .732 .785 r
F P
0 g
s
.38792 .33076 m .39573 .33928 L .33859 .40508 L p .853 .835 .828 r
F P
0 g
s
.33859 .40508 m .3272 .4029 L .38792 .33076 L p .853 .835 .828 r
F P
0 g
s
.53455 .1589 m .53413 .17835 L .44718 .22578 L p .809 .729 .776 r
F P
0 g
s
.45097 .24084 m .44718 .22578 L .53413 .17835 L p .806 .73 .781 r
F P
0 g
s
.45474 .25557 m .45849 .26996 L .38792 .33076 L p .835 .787 .806 r
F P
0 g
s
.39573 .33928 m .38792 .33076 L .45849 .26996 L p .83 .787 .811 r
F P
0 g
s
.30403 .39922 m .31569 .40095 L .268 .47496 L p .875 .886 .839 r
F P
0 g
s
.268 .47496 m .25367 .47928 L .30403 .39922 L p .875 .886 .839 r
F P
0 g
s
.53498 .13899 m .53455 .1589 L .44337 .21038 L p .812 .728 .771 r
F P
0 g
s
.44718 .22578 m .44337 .21038 L .53455 .1589 L p .809 .729 .776 r
F P
0 g
s
.44337 .21038 m .43954 .19464 L .53498 .13899 L p .812 .728 .771 r
F P
0 g
s
.45097 .24084 m .45474 .25557 L .38005 .32217 L p .839 .787 .801 r
F P
0 g
s
.38792 .33076 m .38005 .32217 L .45474 .25557 L p .835 .787 .806 r
F P
0 g
s
.38005 .32217 m .38792 .33076 L .3272 .4029 L p .859 .837 .823 r
F P
0 g
s
.3272 .4029 m .31569 .40095 L .38005 .32217 L p .859 .837 .823 r
F P
0 g
s
.29223 .39773 m .30403 .39922 L .25367 .47928 L p .881 .889 .834 r
F P
0 g
s
.25367 .47928 m .23914 .48411 L .29223 .39773 L p .881 .889 .834 r
F P
0 g
s
.44718 .22578 m .45097 .24084 L .3721 .3135 L p .844 .787 .796 r
F P
0 g
s
.38005 .32217 m .3721 .3135 L .45097 .24084 L p .839 .787 .801 r
F P
0 g
s
.3721 .3135 m .38005 .32217 L .31569 .40095 L p .865 .838 .817 r
F P
0 g
s
.31569 .40095 m .30403 .39922 L .3721 .3135 L p .865 .838 .817 r
F P
0 g
s
.44337 .21038 m .44718 .22578 L .36408 .30475 L p .848 .786 .791 r
F P
0 g
s
.3721 .3135 m .36408 .30475 L .44718 .22578 L p .844 .787 .796 r
F P
0 g
s
.28028 .39648 m .29223 .39773 L .23914 .48411 L p .887 .891 .828 r
F P
0 g
s
.23914 .48411 m .2244 .48943 L .28028 .39648 L p .887 .891 .828 r
F P
0 g
s
.43954 .19464 m .44337 .21038 L .35599 .29592 L p .852 .786 .787 r
F P
0 g
s
.36408 .30475 m .35599 .29592 L .44337 .21038 L p .848 .786 .791 r
F P
0 g
s
.36408 .30475 m .3721 .3135 L .30403 .39922 L p .87 .839 .812 r
F P
0 g
s
.30403 .39922 m .29223 .39773 L .36408 .30475 L p .87 .839 .812 r
F P
0 g
s
.35599 .29592 m .34782 .287 L .43954 .19464 L p .852 .786 .787 r
F P
0 g
s
.26817 .39546 m .28028 .39648 L .2244 .48943 L p .892 .893 .823 r
F P
0 g
s
.2244 .48943 m .20945 .49527 L .26817 .39546 L p .892 .893 .823 r
F P
0 g
s
.35599 .29592 m .36408 .30475 L .29223 .39773 L p .876 .84 .807 r
F P
0 g
s
.29223 .39773 m .28028 .39648 L .35599 .29592 L p .876 .84 .807 r
F P
0 g
s
.34782 .287 m .35599 .29592 L .28028 .39648 L p .88 .841 .802 r
F P
0 g
s
.28028 .39648 m .26817 .39546 L .34782 .287 L p .88 .841 .802 r
F P
0 g
s
.25 Mabswid
.68587 0 m
.96201 .42725 L
s
.96201 .42725 m
1 .7052 L
s
1 .7052 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.04606 .25376 m
0 .54443 L
s
0 .54443 m
.70353 .30431 L
s
.70353 .30431 m
.68587 0 L
s
.68587 0 m
.04606 .25376 L
s
.04606 .25376 m
.68587 0 L
s
.0596 .24839 m
.06434 .25293 L
s
[(-1)] .05011 .23931 1 .95754 Mshowa
.19909 .19306 m
.20361 .19783 L
s
[(-0.5)] .19006 .18353 .94726 1 Mshowa
.34662 .13455 m
.35087 .13955 L
s
[(0)] .33812 .12455 .85019 1 Mshowa
.5029 .07257 m
.50685 .07781 L
s
[(0.5)] .495 .06208 .75311 1 Mshowa
.66872 .0068 m
.67233 .01229 L
s
[(1)] .66152 -0.00418 .65604 1 Mshowa
.125 Mabswid
.08688 .23757 m
.0897 .24032 L
s
.11447 .22662 m
.11727 .2294 L
s
.14237 .21556 m
.14513 .21837 L
s
.17057 .20437 m
.17331 .20721 L
s
.22793 .18162 m
.23061 .18451 L
s
.2571 .17006 m
.25975 .17297 L
s
.2866 .15835 m
.28922 .1613 L
s
.31644 .14652 m
.31902 .14949 L
s
.37715 .12244 m
.37967 .12547 L
s
.40804 .11019 m
.41052 .11325 L
s
.43929 .0978 m
.44173 .10088 L
s
.47091 .08526 m
.47331 .08837 L
s
.53527 .05973 m
.5376 .0629 L
s
.56803 .04673 m
.57032 .04994 L
s
.60119 .03358 m
.60344 .03682 L
s
.63475 .02027 m
.63696 .02354 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 247.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001=B000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00k_ooool4o`000003oa0@4?oooooooooo07?ooooo003`ooooo`03o`00
0?oooooooooo07Gooooo003`ooooo`03o`000?oooooooooo07Gooooo003`ooooo`03o`000?oooooo
oooo07Gooooo003`ooooo`03o`000?oooooooooo07Gooooo003`ooooo`03o`000?oooooooooo07Go
oooo003`ooooo`03o`000?oooooooooo07Gooooo003^ooooo`03oeEEEOmVIVKo000007Oooooo003o
ooooo`cooooo1?l000000ol@413oooooooooo`1Fooooo`00ooooool>ooooo`03o`000?oooooooooo
05Sooooo003oooooo`?ooooo1_l00005ooooo`03o`000?oooooooooo05Sooooo003iooooo`;o0000
4_ooool00ol0003oooooooooo`1Hooooo`00m_ooool3o`000003ooooool0003ooooo017ooooo00?o
0000ooooooooool0F?ooool00?Cooooo0_l00004ooooo`;o00004Oooool00ol0003oooooooooo`1H
ooooo`00lOooool3o`000003ooooool0003ooooo00?ooooo00?o0000ooooool000004?ooool00ol0
003oooooooooo`1Hooooo`00koooool2o`0000Gooooo00Ko0000ooooooooooooooooo`000?ooool2
o`0000gooooo00?oEEEEofIVI_l00000F_ooool00>cooooo0ol0000;ooooo`;o000000?oooooo`00
0?ooool0JOooool00>Wooooo0ol0000>ooooo`05o`000?ooooooooooooooool00000JOooool00>Oo
oooo0_l000000ooooooo0000ooooo`0>ooooo`05o`000?ooooooooooooooool00000JOooool00>Co
oooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I_ooool00>;ooooo
0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00=oooooo0ol0
000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOooool00:Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo
0ol0000Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0I?ooool00:Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`?o0000
0oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo0_l0001Uooooo`00ZOoo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool05oooool2o`00027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Sooooo`00ZOooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool05Oooool3o`0002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Rooooo`00ZOooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`;o00009_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo06;ooooo002Yooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003o
ooooooooo`0Cooooo`?o00000_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0HOooool00:Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo013ooooo0ol0000[ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0H?ooool00:Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003Oooool2o`0002ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Pooooo`00b?ooool3o`00033ooooo
00?o0000ooooooooool02?ooool2o`00063ooooo0036ooooo`;o00000_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00Sooooo0_l0001Pooooo`00`oooool3o`0003Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Nooooo`00`Oooool2o`0003Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Mooooo`00__ooool3o`0003[ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Looooo`00_?ooool2o`0000;ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05cooooo002iooooo`?o00001Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Fooo
ool00;Oooooo0_l00013ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F_ooool0
0;Cooooo0ol00015ooooo`03o`000?oooooooooo00cooooo0_l0001Kooooo`00/_ooool2o`0000;o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Wo
oooo002_ooooo`?o0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo
002/ooooo`?o0000COooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Sooooo0024
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08Oooool2o`00053ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Gooooo`00Q?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01kooooo0ol0
0002ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Gooooo`00Q?ooool01Ol@413ooooooooooooooooo410@01cooooo0_l0001Eooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0E_ooool008Cooooo00Go0000ooooooooooooooooo`00
000Iooooo`?o0000Eoooool00ol0003oooooooooo`0Aooooo`;o0000E_ooool008Cooooo00Go0000
ooooooooooooooooo`00000Gooooo`;o0000F_ooool00ol0003oooooooooo`0@ooooo`;o00004Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0<?ooool008Cooooo00Go410@oooooooooooooooooa0@400Dooooo`?o00000_ooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02oooooo0024ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`0005oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`05ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool0;_ooool008Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0?ooooo`?o0000HOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo02oooooo002Fooooo`;o0000I?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0<?ooool009?ooooo0ol00002ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00ol0003oooooooooo`0booooo`00T?ooool3o`0006Wooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0booooo`00S_ooool2o`00053ooooo2Ol0000Dooooo`03o`000?oooooooooo01?ooooo0ol0
000<ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00037ooooo002;ooooo`?o0000@ooo
ool?o`0000Ooa:c100Co0000okZP_Ol0003o00004_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04oooooo0029ooooo`;o00000_ooool00ol0003oooooooooo`0iooooo`So00005_o4
[<401?l0003o^Z2mokZP_OnjX;d2o`00013ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1?ooooo`00Q_ooool3o`0000Gooooo00?o0000ooooooooool0=_ooool2o`000003olnjaOl0
003oa:c101_oa:c100?o0000okZP_OnjX;d00onjX;d2o`0000kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`1>ooooo`00Q?ooool2o`00043ooooo00Go0000olnjaOo?^/Gock[5o`00
000KolB/`@03o`000?njX;go^Z2m00Ko^Z2m0_l0000<ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0COooool0087ooooo0ol00010ooooo`;o00001?o?^/D00ol0003oa:c1olB/`@0I
olB/`@03o`000?njX;go^Z2m00So^Z2m0_l0000:ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0COooool007oooooo0_l00003ooooo`03o`000?oooooooooo03_ooooo0_l00005olnj
a@03o`000?o4[<7oa:c101[oa:c100?o0000okZP_OnjX;d02_njX;d2o`0000Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`1<ooooo`00O?ooool3o`0004;ooooo00?o0000olnjaOo?
^/D01Oo?^/D00ol0003oa:c1olB/`@0ColB/`@So00003_njX;d2o`0000Kooooo00?o0000oooooooo
ool06Oooool2o`0004gooooo0014ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@0Pooooo`;o0000@oooool2o`0000Sock[500?o0000olB/
`Oo4[<401?o4[<4?o`0000Ooa:c200?o0000okZQ_ol000003_njX;d2o`0000Cooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`1;ooooo`00A?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01cooooo1?l00012ooooo`;o00002Oo?^/D2o`00
0003olB/`Ol0003o000000?o00005_o4[<801?l0003o^Z6ookZQ_onjXKl2o`0000go^Z2m0_l00002
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0B_ooool003cooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`0Hooooo`?o00001?ooool0
0ol0003oooooooooo`0mooooo`;o00002Oo?^/D2o`000003olnja_l0003oa:c201_oa:c200?o0000
okZQ_onjXKl00onjXKl2o`0000go^Z2m0ol0000Mooooo`03o`000?oooooooooo04[ooooo0014oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Gooooo`;o0000A_ooool0
0ol0003ock[5olnja@07olnja@;o00000oo?^/H00ol0003oa:c2olB/`P0IolB/`P03o`000?njXKoo
^Z6o00Ko^Z6o0_l0000=okZP_@;o00007Oooool00ol0003oooooooooo`19ooooo`00A?ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Eooooo`?o0000A_oo
ool2o`0000Wock[500?o0000olnja_o?^/H00oo?^/H00ol0003oa:c2olB/`P0IolB/`P03o`000?nj
XKoo^Z6o00So^Z6o0_l0000;okZP_@04o`000?njX;go0000o`0001cooooo00?o0000ooooooooool0
B?ooool004Cooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo01Gooooo
0_l00002ooooo`03o`000?oooooooooo04;ooooo0_l00009olnja@;o00001_o?^/H00ol0003oa:c2
olB/`P0BolB/`PSo00003?njXKl2o`0000Wo^Z2m00Co0000okZP_OnjX;go^Z2m0_l0000Jooooo`03
o`000?oooooooooo04Sooooo0014ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`0Booooo`?o0000Aoooool2o`0000Wock[50_l00008olnjaP03o`000?o4[<;oa:c200Co
a:c23_l00007olB]``03o`000?njX/3o000000co^Z6o0_l00007okZP_@03o`000?njX;go^Z2m00?o
^Z2m00?o0000ooooooooool05oooool2o`0004Wooooo0014ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000oooooo0_l00019ooooo`03o`000?o?^/Gock[500Oock[50_l00009olnjaP;o
000000?oa:c2o`000?l000000ol0000EolB]``04o`000?njX/3o^Z;0okZR`0;o00002onjXKl2o`00
00Go^Z2m00?o0000okZP_OnjX;d00onjX;d00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Kooooo001Uooooo`?o0000BOooool2o`0000Sock[50_l00009olnjaP;o000000?oc[[7o`000?o4
[L<06Oo4[L<00ol0003o^Z;0okZR`004okZR`003o`000?njXKoo^Z6o00[o^Z6o0_l00004okZP_@07
o`000?njX;go^Z2mokZP_Ol0003o/YNlo`00000Jooooo`03o`000?oooooooooo04Kooooo001Soooo
o`;o00000oooool00ol0003oooooooooo`14ooooo`;o00002Oo?^/D00ol0003ock[6olnjaP07olnj
aP;o00000oo>^/L00ol0003oa:g3olB]``0HolB]``03o`000?njX/3o^Z;000Go^Z;00_l0000<okZQ
_`;o00000_njX;d01Ol0003o^Z2mokZP_OnjX;go000000;o/YNl00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`15ooooo`00H?ooool3o`0004_ooooo00?o0000olnjaOo?^/D01oo?^/D2o`00
00Sock[60_l00005oljja`03o`000?o4[L?oa:g301Soa:g300?o0000okZR`?njX/001onjX/02o`00
00co^Z6o0ol00002okZP_@03o`000?nbUkco/YNl00;o/YNl00?o0000ooooooooool06?ooool00ol0
003oooooooooo`14ooooo`00G_ooool2o`0004cooooo0_l00008olnja@;o00002Oo?^/H00ol0003o
c[[7oljja`05oljja`03o`000?o4[L?oa:g301Ooa:g300?o0000okZR`?njX/002_njX/02o`0000co
^Z6o0_l000000onjX;go0000ok:G_004ok:G_003o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0A?ooool005_ooooo1?l0001<ooooo`03o`000?o?^/Gock[500Kock[50_l00009olnjaP;o0000
2?o>^/L00ol0003oa:g3olB]``0:olB]``ko00003_njX/02o`0000[o^Z6o00?o0000okZQ_ol00000
1_nbUk`00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04?ooooo001Iooooo`;o00001?oo
ool00ol0003oooooooooo`18ooooo`;o00001_o?^/D2o`0000Wock[60_l00009oljja`;o000000?o
a:g3o`000?l000002Ol0000=ol>]a003o`000?njX/7o000000ko^Z;00_l00008okZQ_`03o`000?nj
XKoo000000Oo/YNl00?o0000ooooooooool05oooool2o`0004Cooooo001Fooooo`?o0000D?ooool0
0ol0003of/W9o`000005olnja@03o`000?o?^/Kock[600Oock[60_l00009oljja`;o000000?ocK_8
o`000?o3[L@06?o3[L@01?l0003o^Z;1okZR`OnjX/42o`0000go^Z;00_l00006okZQ_`;o000000?o
/YRmo`000?nbUk`01_nbUk`00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04;ooooo001C
ooooo`?o0000D_ooool01Ol0003of/W9om[9bOoJbLWo000000;ock[50_l00008olnjaP;o00002Oo>
^/L2o`0000?ocK_800?o0000ol>]a?o3[L@05oo3[L@00ol0003o^Z;1okZR`@03okZR`@?o00003?nj
X/000ol0003o^Z6ookZQ_`03okZQ_`;o00000_nbV;d00ol0003o/YNlok:G_005ok:G_003o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0@Oooool0057ooooo0_l000000ooooooo0000o`00001A
ooooo`03o`000?oJbLWof/W900;of/W900?o0000olnjaOl000002?o?^/H2o`0000Woc[[70_l00005
olfkb003o`000?o3[LCo`jg401Ko`jg400?o0000okZR`OnjX/401onjX/42o`0000_o^Z;00_l00003
okZQ_`03o`000?nbV;go/YRm00;o/YRm00?o0000ok:G_?nbUk`01OnbUk`00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo043ooooo001>ooooo`?o0000EOooool00ol0003of/W9om[9b@03om[9
b@03o`000?o?^/Kock[600Kock[60_l0000:oljja`03o`000?o=^lSocK_800GocK_800?o0000ol>]
a?o3[L@05_o3[L@00ol0003o^Z;1okZR`@09okZR`@;o00002onjX/02o`000003okZQ_ol0003o/YRm
00Co/YRm00?o0000ok:G_?nbUk`01?nbUk`00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
043ooooo000Xooooo`Co000000?o410@ooooooooool07Oooool2o`0005Oooooo00?o0000om[9bOoJ
bLT00ooJbLT2o`0000Oock[600?o0000oljjaoo>^/L02?o>^/L2o`0000SocK_800?o0000ol>]a?o3
[L@02_o3[L@=o`0000go^Z;10_l0000;okZR`0;o00001OnbV;d00ol0003o/YNlok:G_005ok:G_003
o`000?oooooooooo01Oooooo00?o0000ooooooooool0?oooool002[ooooo00?o0000ooooooooool0
7?ooool3o`0005Sooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:o`000005olnjaP;o0000
2Oo>^/L2o`0000WocK_80_l000000oo3[LCo0000o`000009o`0000co`jk600Co0000okZS`_l0003o
00003?njX/42o`0000Wo^Z;00_l00006ok:H_@03o`000?nbUkco/YNl00Go/YNl00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0nooooo`007oooool6o`0000Gooooo00?o0000ooooooooool0
6_ooool2o`0000?ooooo00?o0000ooooooooool0E?ooool00ol0003of/W9om[9b@03om[9b@05o`00
0?oIbL[ofLW:omW9b_l000000_o?^/H2o`0000Woc[[70_l00009olfkb0;o000000?oc;_:o`000?o3
[/H05_o3[/H00ol0003o^Z?2okZS`P02okZS`P;o00003?njX/43o`0000Go^Z;000?o0000ok:I__l0
00001onbV;d00ol0003o/YNlok:G_005ok:G_003o`000?oooooooooo01Gooooo0_l00008ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0<oooool002[ooooo00?o0000ooooooooool05oooool3o`0005_o
oooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP02omW9bP03o`000?o?^/Ko000000Wo
c[[70_l00009olfkb0;o00000oo<^lX00ol0003o`jk6ol>^aP0Eol>^aP03o`000?njXl;o^Z?200Co
^Z?20_l0000=okZR`@;o00000onjX/001?l0003o/YVno`000?l00007ok:H_@03o`000?nbUkco/YNl
00Go/YNl00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0<oooool002[ooooo00?o0000ooooooooool05Oooool2o`0005gooooo00?o0000om[9
bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?o>^/Ooc[[700Ooc[[70_l00009olfk
b0;o00001Oo<^lX00ol0003o`jk6ol>^aP0Eol>^aP03o`000?njXl;o^Z?200Ko^Z?20_l0000=okZR
`@;o000000Ko^Z;0o`000?nbVKko0000ok:I__l00007ok:H_@03o`000?nbUkco/YNl00Co/YNl00?o
0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100
<oooool002[ooooo00?o0000ooooooooool04_ooool4o`0005gooooo00?o0000om[9bOoJbLT00ooJ
bLT00ol0003ofLW:omW9bP03omW9bP;o00001oo>^/L2o`0000WocK_80_l00007olbkbP03o`000?o3
[/Ko`jk601Co`jk600?o0000okZS`_njXl802OnjXl82o`0000go^Z;100Co0000ok:I__nbVKko0000
0_nbVKh00ol0003o/YRmok:H_@05ok:H_@03o`000?nbUkco/YNl00Co/YNl00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000<oooool002[ooooo
00?o0000ooooooooool04?ooool2o`0000Cooooo00?o0000ooooooooool0FOooool00ol0003of/W9
om[9b@03om[9b@03o`000?oIbL[ofLW:00?ofLW:00Co0000omS9booHbL_o00001Oo>^/L00ol0003o
cK_8olfkb007olfkb0;o00002Oo<^lX00ol0003o`jk6ol>^aP09ol>^aPco00003OnjXl82o`0000_o
^Z;100Go0000ok:I__nbVKko/YVno`000002ok:I_P03o`000?nbV;go/YRm00Co/YRm00?o0000ok:G
_?nbUk`01OnbUk`00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000cooooo`00:?ooool00omEEEGoIVIVo`00000?ooooo`?o0000HOooool00ol0
003of/W9om[9b@03om[9b@03o`000?oIbL[ofLW:00?ofLW:00Go0000omS9booHbL_of<W;o`000003
oljja`;o00002?o=^lP2o`0000[oc;_:0_l000000oo3[/Ko0000o`000008o`0000_o`Zo700?o0000
okVTa?l000003OnjXl82o`0000So^Z;100?o0000ok:J_ol000000_nbVKh01?l0003o/YVnok:I__l0
0007ok:H_@03o`000?nbUkco/YNl00Go/YNl00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool@4100<oooool003Oooooo0ol0001Sooooo`03o`000?oJ
bLWof/W900?of/W900?o0000omW9b_oIbLX00ooIbLX00ol0003of<W;omS9b`02omS9b`04o`000?o>
^/Ooc[[7o`0000WocK_800?o0000olbkb_o<^lX02?o<^lX2o`000003ol^lbol0003o`Zo701Go`Zo7
00Co0000okVTa?niY<Co^JC40ol0000;okZS`P;o00001_njX/401_l0003o/YZook:J_ol0003o/YVn
o`0000?o/YVn00?o0000ok:H_OnbV;d01OnbV;d00ol0003o/YNlok:G_004ok:G_003o`000?oooooo
oooo01Cooooo0ol00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool003Gooooo0_l00003
ooooo`03o`000?oooooooooo05oooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03
omW9bP03o`000?oHbL_of<W;00?of<W;0_l00009olfkb0;o00002Oo<^lX2o`0000?obkc;00?o0000
ol:_aoo2[lL05?o2[lL00ol0003o^JC4okVTa004okVTa0;o00002onjXl82o`0000?o^Z;100?o0000
ok:J_onbV[l00_nbV[l2o`0000Co/YVn00?o0000ok:H_OnbV;d01OnbV;d00ol0003o/YNlok:G_004
ok:G_003o`000?oooooooooo01Kooooo00Wo0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h0<oooool003;ooooo0ol0001Vooooo`03o`000?oJbLWof/W900?of/W900?o0000omW9b_oIbLX0
0ooIbLX00ol0003of<W;omS9b`03omS9b`03o`000?oFbLgo000000OocK_80_l00009olbkbP;o0000
1Oo;_</00ol0003o`Zo7ol:_a`0Col:_a`03o`000?niY<Co^JC400Oo^JC40_l0000;okZS`P;o0000
00?o^Z;1o`000?nbV[l01?nbV[l00ol0003o/YVnok:I_P03ok:I_P03o`000?nbV;go/YRm00Go/YRm
00?o0000ok:G_?nbUk`01?nbUk`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Wooooo
000`ooooo`;o0000J?ooool00ol0003of/W9om[9b@03om[9b@03o`000?oIbL[ofLW:00?ofLW:00?o
0000omS9booHbL/00ooHbL/01?l0003oe/W=omK9cOl00005olfkb0;o00002Oo<^lX2o`0000Oobkc;
00?o0000ol:_aoo2[lL04oo2[lL00ol0003o^JC4okVTa009okVTa0;o00002onjXl800ol0003o/YZo
ok:J_`04ok:J_`;o00001OnbVKh00ol0003o/YRmok:H_@04ok:H_@03o`000?nbUkco/YNl00Go/YNl
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0hooooo`00;Oooool3o`000003ooooool0
003ooooo06Kooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?oH
bL_of<W;00?of<W;00?o0000omK9cOoFbLd00_oFbLd00ol0003ocK_8olfkb002o`0000Woc;_:0_l0
0009ol^lb`03o`000?o2[lOo`Zo700So`Zo73?l0000=okVTa0;o00002OnjXl800ol0003o/YZook:J
_`04ok:J_`03o`000?nbV[oo000000Go/YVn00?o0000ok:H_OnbV;d01?nbV;d00ol0003o/YNlok:G
_005ok:G_003o`000?oooooooooo01Gooooo00?o0000ooooooooool0=oooool002cooooo0_l00004
ooooo`03o`000?oooooooooo06?ooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03
omW9bP03o`000?oHbL_of<W;00?of<W;00?o0000omK9cOoFbLd00ooFbLd00ol0003ocK_8o`000009
olbkbP;o00002_o;_</2o`000003ol:_aol0003o000000Oo00002oo1/<P01?l0003o^JG5o`000?l0
000<okVTa0?o00001OnjXl800ol0003o/Y_1o`000005ok:J_`04o`000?nbV[oo/YZoo`0000Go/YVn
00?o0000ok:H_OnbV;d01?nbV;d00ol0003o/YNlok:G_004ok:G_003o`000?oooooooooo01Gooooo
00?o0000ooooooooool0=oooool002cooooo00?o0000ooooool00000J?ooool00ol0003of/W9om[9
b@03om[9b@03o`000?oIbL[ofLW:00?ofLW:00?o0000omS9booHbL/00ooHbL/00ol0003oe/W=omK9
c@03omK9c@;o00002Oo<^lX2o`0000[obkc;0_l000000oo:_<go0000ol6`b00Dol6`b004o`000?ni
YLGo^JG5okVUa@?o00003?niY<@2o`0000?o^Z?200Co0000ok:K`OnbVl7o00001?nbV[l01?l0003o
/YZook:J_ol00005ok:I_P03o`000?nbV;go/YRm00Go/YRm00?o0000ok:G_?nbUk`01?nbUk`00ol0
003oooooooooo`0Eooooo`;o0000=oooool002cooooo1?l0001Vooooo`03o`000?oJbLWof/W900?o
f/W900?o0000omW9b_oIbLX00ooIbLX00ol0003of<W;omS9b`03omS9b`03o`000?oFbLgoe/W=00?o
e/W=00?o0000omG9c_l000001oo<^lX2o`0000Wobkc;0ol00003olZlc@03o`000?o1/<So`K3801;o
`K3800?o0000okVUaOniYLD01OniYLD2o`0000co^JC40_l000000onjXl;o0000ok:K`@02ok:K`@05
o`000?nbV[oo/YZook:J_ol000000onbV[l00ol0003o/YVnok:I_P03ok:I_P03o`000?nbV;go/YRm
00Go/YRm00?o0000ok:G_?nbUk`01?nbUk`00ol0003oooooooooo`0Cooooo`03o`000?oooooo0000
03Oooooo000/ooooo`05o`000?ooooooooooooooool00000I?ooool00ol0003of/W9om[9b@03om[9
b@03o`000?oIbL[ofLW:00?ofLW:00?o0000omS9booHbL/00ooHbL/00ol0003oe/W=omK9c@03omK9
c@04o`000?oEbLkoeLW>o`0000Goc;_:0_l00009ol^lb`;o00001_o:_<d00ol0003o`K38ol6`b00B
ol6`b003o`000?niYLGo^JG500Oo^JG50_l0000<okVTa003o`000?nbVl7o/Y_100?o/Y_100Co0000
ok:J_onbV[oo00001?nbV[l00ol0003o/YVnok:I_P03ok:I_P03o`000?nbV;go/YRm00Go/YRm00?o
0000ok:G_?nbUk`01?nbUk`00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Gooooo000R
ooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo063ooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?oHbL_o
f<W;00?of<W;00?o0000omK9cOoFbLd00ooFbLd00ol0003oeLW>omG9cP02omG9cP03o`000?o<^l[o
c;_:00;o00002Oo;_</2o`0000Sob[c=00?o0000ol6`b?o1/<P02?o1/<P;o`0000_o^JG50_l0000:
okVTa003o`000?nbVl7o/Y_100Co/Y_100?o0000ok:J_ol000001OnbV[l00ol0003o/YVnok:I_P03
ok:I_P03o`000?nbV;go/YRm00Co/YRm00?o0000ok:G_?nbUk`01OnbUk`00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03Cooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Nooooo`03o`000?oJbLWof/W900?of/W900?o0000omW9
b_oIbLX00ooIbLX00ol0003of<W;omS9b`03omS9b`03o`000?oFbLgoe/W=00?oe/W=00?o0000omG9
c_oEbLh00ooEbLh00ol0003oc;_:o`000008ol^lb`?o00002Oo:_<d2o`000003ol6`b?l0003o0000
00Oo00002_o1/<X01?l0003o^JK7o`000?l0000:okVUa@;o00001oniY<@00ol0003o/Yg2o`000006
ok:K`@;o00001_nbV[l00ol0003o/YVnok:I_P03ok:I_P03o`000?nbV;go/YRm00Co/YRm00?o0000
ok:G_?nbUk`00onbUk`2o`0001Oooooo00?o0000ooooooooool0<oooool001Wooooo1_l00005oooo
o`03o`000?oooooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo05cooooo00?o0000om[9
bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?oHbL_of<W;00?of<W;00?o0000omK9
cOoFbLd00ooFbLd00ol0003oeLW>omG9cP03omG9cP;o00002?o;_</2o`0000[ob[c=0_l000000oo9
_<ko0000ol6`bP0Bol6`bP03o`000?niY/Oo^JK700;o^JK70_l0000:okVUa@?o00000oniY<@01Ol0
003o/Yg2ok:M`_nbWL;o000000Ko/Y_100?o0000ok:J_onbV[l01OnbV[l00ol0003o/YVnok:I_P03
ok:I_P03o`000?nbV;go/YRm00Co/YRm00Go0000ok:G_?nbUkco/YNlo`000002ojZA_@03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0<oooool002Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05[ooooo00?o0000om[9bOoJbLT00ooJbLT0
0ol0003ofLW:omW9bP03omW9bP03o`000?oHbL_of<W;00?of<W;00?o0000omK9cOoFbLd00ooFbLd0
0ol0003oeLW>omG9cP03omG9cP03o`000?oDbLoo000000Kobkc;0_l00009olZlc@?o00000oo9_<h0
0ol0003o`K3:ol6`bP0Aol6`bP03o`000?niY/Oo^JK700Co^JK70_l0000;okVUa@;o000000?o^JC4
o`000?nbWL800onbWL800ol0003o/Y_1ok:K`@03ok:K`@;o00001onbV[l00ol0003o/YVnok:I_P02
ok:I_P03o`000?nbV;go/YRm00Go/YRm00?o0000ok:G_?l000000onZTKd00ol0003oooooooooo`0E
ooooo`;o0000<oooool002Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo05Sooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9
bP03o`000?oHbL_of<W;00;of<W;0_l00004omK9c@;o00001OoEbLh01?l0003oe<W?omC9col00004
ol^lb`;o00002Oo:_<d2o`0000KobKc>00?o0000ol6`b_o1/<X04Oo1/<X00ol0003o^JK7okVVa`06
okVVa`?o00002_niYLD00ol0003o/Yg2ok:M`P04ok:M`P03o`000?nbVl7o/Y_100;o/Y_100?o0000
ok:K`Ol000001_nbV[l00ol0003o/YVnok:I_P03ok:I_P03o`000?nbV;go/YRm00Go/YRm00?o0000
ojZA_OnZTKd00onZTKd00ol0003oooooooooo`0Cooooo`;o0000=?ooool002Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o0000om[9
bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?oHbL_of<W;00;of<W;00?o0000omK9
cOoFbLd00ooFbLd00ol0003oeLW>omG9cP04omG9cP03o`000?oDbLooe<W?00;oe<W?00?o0000ol^l
bol000002_o:_<d2o`0000SobKc>00?o0000ol6`b_o1/<X04?o1/<X00ol0003o^JK7okVVa`0:okVV
a`;o00002?niYLD00ol0003o/Yg2ok:M`P05ok:M`P05o`000?nbVl7o/Y_1ok:K`Ol000000_nbVl40
0ol0003o/YZook:J_`04ok:J_`03o`000?nbVKko/YVn00?o/YVn00?o0000ok:H_OnbV;d00onbV;d0
0ol0003oZY6mojZA_@04ojZA_@03o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool0
02Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
05Cooooo00?o0000om[9bOoJbLT00ooJbLT00ol0003ofLW:omW9bP03omW9bP03o`000?oHbL_of<W;
00;of<W;00?o0000omK9cOoFbLd00ooFbLd00ol0003oeLW>omG9cP04omG9cP03o`000?oDbLooe<W?
00;oe<W?0_l0000:olZlc@;o00002Oo9_<h2o`000003ol6`b_l0003o0000013o00003_niY/L2o`00
00Go^JG500?o0000ok6Na?l000001onbWL801ol0003o/Y_1ok:K`OnbVl7o0000ok:K`Ol000001onb
V[l00ol0003o/YVnok:I_P03ok:I_P05o`000?nbV;go/YRmok:H_Ol000000_nZT[h6ojZA_@03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0<?ooool002;ooooo00?oEEEEofIVI_l000001Ooo
ool2o`0000cooooo00?o0000ooooooooool0D_ooool00ol0003of/W9om[9b@04om[9b@GofLW:00?o
0000omS9booHbL/00_oHbL/00ol0003oe/W=omK9c@03omK9c@03o`000?oEbLkoeLW>00?oeLW>0_l0
0004omC9c`03o`000?oBbM3o000000Sob[c=0_l00009olVlcP;o000000?ob;g?o`000?o0/L/04Oo0
/L/01?l0003o^:O8o`000?l0000=okVVa`;o00000oniYLD01?l0003o/Ik4ok6Na?l00007ok:M`P04
o`000?nbVl7o/Y_1o`0000;o/Y_100?o0000ok:J_onbV[l01OnbV[l00ol0003o/YVnok:I_P03ok:I
_P03o`000?nbV;go000000?oZY:n00?o0000ojZA_OnZTKd00onZTKd00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo033ooooo000Zooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0DOooool2o`0000Cof/W91OoIbLX00ol0003of<W;omS9b`02omS9b`03o`000?oFbLgoe/W=00?o
e/W=00?o0000omG9c_oEbLh00ooEbLh00ol0003oe<W?omC9c`03omC9c`04o`000?oBbM3od/W@o`00
00Gob[c=0ol00008olVlcP?o00000oo8_Ll00ol0003o`;7;ol2ab`0@ol2ab`04o`000?nhYlSo^:O8
okRWb0?o00003?niY/L2o`000003okVUaOl0003o/Ik400;o/Ik400?o0000ok:M`_nbWL801OnbWL80
0ol0003o/Y_1o`000003ok:K`@03o`000?nbV[oo/YZo00Go/YZo00?o0000ok:I__nbVKh00onbVKh0
0ol0003oZY:nojZB_P03ojZB_PGoZY6m00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_
ooooo`00:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04oooooo00Co0000on7G
cOoQelgo00000_oJbLT5omW9bP03o`000?oHbL_of<W;00;of<W;00?o0000omK9cOoFbLd00ooFbLd0
0ol0003oeLW>omG9cP03omG9cP03o`000?oDbLooe<W?00?oe<W?00?o0000om;9d?oBbM000_oBbM00
1Ol0003ob[c=olZlcOo:_<go000000WobKc>0_l00006olRmc`03o`000?o0/L_o`;7;00oo`;7;00?o
0000okRWb?nhYlP01OnhYlP2o`0000co^JK700?o0000ok6Na?naW/@00onaW/@00ol0003o/Yg2ok:M
`P05ok:M`P;o00001?nbVl400ol0003o/YZook:J_`05ok:J_`05o`000?nbVKko/YVnok:I__l00000
1_nZT[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;_ooool002[ooooo0_l0000?ooooo`03o`000?oooooooooo04gooooo00?o0000on7GcOoQeld00_oQ
eld00ol0003ofLW:omW9bP04omW9bPCof<W;00?o0000omK9cOoFbLd00ooFbLd00ol0003oeLW>omG9
cP03omG9cP03o`000?oDbLooe<W?00?oe<W?00?o0000om;9d?oBbM000ooBbM000ol0003ob[c=o`00
0009olVlcP;o00001oo8_Ll00ol0003o`;7;ol2ab`0@ol2ab`03o`000?nhYlSo^:O800Oo^:O80_l0
000:okVVa`;o00001OnaW/@00ol0003o/Yg2ok:M`P04ok:M`P;o00001OnbVl400ol0003o/YZook:J
_`05ok:J_`03o`000?nbVKko000000;oZYBo1_nZT[h00ol0003oZY6mojZA_@02ojZA_@03o`000?oo
oooooooo01Gooooo0ol0000_ooooo`00:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04_ooooo00?o0000on7GcOoQeld00ooQeld2o`0000CofLW:1?oHbL/00ol0003oe/W=omK9c@03
omK9c@03o`000?oEbLkoeLW>00;oeLW>0_l00005omC9c`03o`000?oBbM3od/W@00?od/W@0_l00009
olVlcP;o00002Oo8_Ll00ol0003o`;7;ol2ab`07ol2ab`[o00002onhYlP2o`0000Oo^JK700Co0000
ok6OaOnaWlGo00001OnaW/@00ol0003o/Yg2ok:M`P04ok:M`P03o`000?nbVl7o/Y_100Co/Y_100?o
0000ok:J_onbV[l01OnbV[l01Ol0003oZYBoojZD_onZU;oo000000GoZY:n00?o0000ojZA_OnZTKd0
0onZTKd00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo000Zooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0B_ooool00ol0003ohMO=on7Gc@02on7Gc@04o`000?oP
elkoh=O>o`0000;ofLW:1OoHbL/5omK9c@GoeLW>00?o0000omC9cooDbLl00ooDbLl2o`0000God/W@
00?o0000om79d_l000001oo9_<h2o`0000[ob;g?0_l000000oo0/L_o0000o`000006o`0000Wo_k;=
00Co0000okRXb_l0003o00002_nhYlP3o`0000?o^JK700?o0000ok6OaOnaWlD00_naWlD00ol0003o
/Ik4ok6Na003ok6Na003o`000?nbWL;o/Yg200?o/Yg20_l00006ok:K`@03o`000?nbV[oo/YZo00?o
/YZo00?o0000ojZD_onZU;l00onZU;l5ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0/ooooo`00:Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04Sooooo00?o0000on7GcOoQeld00_oQeld00ol0003oh=O>on3GcP02on3GcP03o`00
0?oHbL_of<W;00?of<W;1OoFbLd5omG9cP03o`000?oDbLooe<W?00?oe<W?00?o0000om;9d?oBbM00
1?oBbM001Ol0003odLWBom79d_oAbM;o000000CobKc>0_l00009olRmc`?o000000?oakgAo`000?no
//d04?no//d00ol0003o^:S:okRXbP02okRXbP?o00002_nhYlP2o`000003okVVaol0003o/Io500Co
/Io500?o0000ok6Na?naW/@00onaW/@01?l0003o/Yg2ok:M`_nbWL82o`000003ok:M`_l0003o/Y_1
00Go/Y_100Go0000ok:J_onbV[oo/YZoo`000002ojZE`0CoZYBo00?o0000ojZB__nZT[h00onZT[h0
0ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;?ooool0
02Wooooo00?o0000ooooooooool04oooool2o`0004Oooooo00?o0000on7GcOoQeld00_oQeld00ol0
003oh=O>on3GcP03on3GcP03o`000?oHbL_of<W;00;of<W;1OoFbLd5omG9cP03o`000?oDbLooe<W?
00?oe<W?00?o0000om;9d?oBbM001?oBbM000ol0003odLWBom79dP02om79dP04o`000?o9_<kobKc>
o`0000[ob;g?0_l00004olNmd@03o`000?no//go_k;=00oo_k;=00?o0000okRXb_nhZ<X01OnhZ<X2
o`0000[o^:O800?o0000ok6OaOnaWlD01OnaWlD00ol0003o/Ik4ok6Na003ok6Na0?o000000Go/Yg2
o`000?nbWL;o/Yg2o`000006ok:K`@03o`000?nbV[oo000000?oZYG000?o0000ojZD_onZU;l00_nZ
U;l00ol0003oZY:nojZB_P02ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0[ooooo`00:Oooool2o`0001Kooooo00?o0000ooooooooool0A?ooool0
0ol0003ohMO=on7Gc@02on7Gc@03o`000?oPelkoh=O>00;oh=O>00?o0000omkFcol000000_oHbL/5
omK9c@GoeLW>00?o0000omC9cooDbLl00ooDbLl00ol0003od/W@om;9d003om;9d0;o00001OoAbM82
o`0000Wob;g?0ol00006olNmd@03o`000?no//go_k;=00oo_k;=00?o0000okRXb_nhZ<X01onhZ<X2
o`0000So^:O80_l00007ok6Oa@03o`000?naW/Co000000;o000000?o/Ik4o`000?nbWL800_nbWL80
1?l0003o/Yg2ok:M`_l00006ok:K`@03o`000?nZUL3oZYG000?oZYG01?nZU;l00ol0003oZY:nojZB
_P03ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Zooooo`00:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo00?o0000
on7GcOoQeld00_oQeld00ol0003oh=O>on3GcP02on3GcP04o`000?oNe/oog]K?omkFc`;o00001?oF
bLd5omG9cP03o`000?oDbLooe<W?00?oe<W?00?o0000om;9d?oBbM000ooBbM000ol0003odLWBom79
dP04om79dP03o`000?o@bM?o000000Kob;g?0ol00009olNmd@03o`000?no//go_k;=00Ko_k;=2Ol0
000<okRXbP?o00001?nhYlP01?l0003o/J37ok6Paol00005ok6Oa@?o00001OnaW/@01Ol0003o/Yg2
ok:M`_nbWL;o000000;o/Yg200?o0000ok:K`OnbVl400onbVl400ol0003oZYG0ojZE`003ojZE`003
o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZT[h00_nZT[h00ol0003oZY6mojZA_@03ojZA_@03
o`000?oooooooooo01Kooooo0_l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0>ooooo`00:Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo043ooooo00?o0000on7GcOoQeld00_oQeld00ol0003oh=O>on3GcP02on3G
cP03o`000?oNe/oog]K?00;og]K?00?o0000omgFdOl000000_oFbLd5omG9cPKoe<W?00?o0000om;9
d?oBbM000ooBbM000ol0003odLWBom79dP04om79dP04o`000?o@bM?od<WCo`0000Cob;g?0_l0000;
olNmd@;o000000?o_k;=o`000?l000001Ol00008okjccP04o`000?ngZ/co0000o`0000co^:S:0_l0
00000onhYlSo0000ok6Pa`03ok6Pa`03o`000?naWlGo000000;o00000onaWlD00ol0003o/Ik4ok6N
a003ok6Na005o`000?nbWL;o/Yg2ok:M`_l000000_nbWL801_l0003o/Y_1ok:K`OnbVl7o0000ojZF
`PKoZYG000Go0000ojZD_onZU;ooZYBoo`000005ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000
ooooooooool05oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03Oooool002Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oQelgohMO=00;ohMO=00?o0000on3Gc_oPelh00_oPelh0
0ol0003og]K?omkFc`02omkFc`05o`000?oMe]7ogMKAomgFdOl000001OoEbLh6omC9c`03o`000?oB
bM3od/W@00?od/W@00?o0000om79d_oAbM800ooAbM82o`0000Cod<WC00Co0000olRmcol0003o0000
2_o7_M43o`000003olJmd_l0003o_[?>00oo_[?>00Co0000okNZc?ngZ/co]j[<0ol0000;okRXbP03
o`000?naX<Oo/J3700;o/J370ol00007ok6Oa@03o`000?naW/Co/Ik400?o/Ik400Co0000ok:M`_nb
WL;o00000onbWL800ol0003o/Y_1o`000002ojZF`P03o`000?nZUL3oZYG000?oZYG000?o0000ojZD
_onZU;l00_nZU;l00ol0003oZY:nojZB_P02ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0<ooooo`00:?ooool4o`0001Wooooo00?o0000ooooooooool0?Oooool00ol0
003ohMO=on7Gc@02on7Gc@03o`000?oPelkoh=O>00;oh=O>00Go0000omkFcooNe/oog]K?o`000004
omgFd@03o`000?oEbLkoeLW>00;oeLW>1_oDbLl5om;9d0;o00001OoAbM800ol0003od<WCom39d`03
om39d`;o00002_o7_M43o`0000Coa[gB00?o0000okjcc_nn/lh03Onn/lh00ol0003o]j[<okNZc005
okNZc0;o00002OnhZ<X5o`0000?o/J3700?o0000ok6OaOnaWlD01OnaWlD00ol0003o/Ik4ok6Na003
ok6Na004o`000?nbWL;o/Yg2o`0000;o/Yg20_l00004ojZF`PKoZYG000Go0000ojZD_onZU;ooZYBo
o`000005ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0=ooooo`00
:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03_ooooo00?o0000on7GcOoQeld0
0_oQeld00ol0003oh=O>on3GcP02on3GcP05o`000?oNe/oog]K?omkFcol000001?oMe]400ol0003o
fmKBo`000002omG9cPKoe<W?1OoBbM000ol0003odLWBom79dP04om79dP03o`000?o@bM?od<WC00?o
d<WC00?o0000olk8eOl000001oo7_M43o`0000Ooa[gB00?o0000okjcc_nn/lh03Onn/lh00ol0003o
]j[<okNZc007okNZc0;o00001_nhZ<X4o`0000Ko/J3700?o0000ok6OaOnaWlD01OnaWlD00ol0003o
/Ik4ok6Na003ok6Na003o`000?nbWL;o/Yg200;o000000?oZYO3ojZF`_nZU/800onZU/800ol0003o
ZYG0ojZE`003ojZE`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZT[h00_nZT[h00ol0003o
ZY6mojZA_@03ojZA_@03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00>ooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Wooooo00?o0000on7GcOoQeld00_oQ
eld00ol0003oh=O>on3GcP02on3GcP05o`000?oNe/oog]K?omkFcol000001?oMe]401Ol0003ofmKB
om_Fd_oKe];o000000Koe<W?1OoBbM000ol0003odLWBom79dP03om79dP;o00001Oo@bM<01?l0003o
c/SEolk8eOl00004olNmd@?o00002Oo6_M82o`000003okjcc_l0003o000000go00002ongZ/`7o`00
00?o/J;800?o0000ok6PaonaX<L01?naX<L00ol0003o/Io5ok6Oa@05ok6Oa@03o`000?naW/Co/Ik4
00?o/Ik400Co0000ok:M`_l0003o00000_nZUl<5ojZF`P03o`000?nZUL3oZYG000?oZYG000Go0000
ojZD_onZU;ooZYBoo`000005ojZB_P03o`000?nZTKgoZY6m00;oZY6m00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0@ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0hooooo`05o`00
0?oQelgohMO=on7GcOl000001?oPelh00ol0003og]K?omkFc`02omkFc`05o`000?oMe]7ogMKAomgF
dOl000001?oKe]82o`0000Coe<W?1OoBbM000ol0003odLWBom79dP03om79dP03o`000?o@bM?od<WC
00?od<WC0_l00004olk8e@04o`000?o7_M7o0000o`0000Woa[gB0ol000000oo4_]Co0000okfcd00>
okfcd003o`000?ngZlgo000000;o00001ongZ/`5o`000003okRXb_l0003o/J;800?o/J;800?o0000
ok6PaonaX<L01?naX<L00ol0003o/Io5ok6Oa@05ok6Oa@03o`000?naW/Co/Ik400?o/Ik400?o0000
ojZG`ol000000_nZUl<00ol0003oZYK2ojZF`P02ojZF`P03o`000?nZUL3oZYG000?oZYG000?o0000
ojZD_onZU;l00_nZU;l00ol0003oZY:nojZB_P02ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000
ooooooooool05_ooool3o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo013ooooo0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool2o`0001oooooo00?o0000ooooooooool0=_ooool00ol0003ohMO=on7G
c@02on7Gc@05o`000?oPelkoh=O>on3Gc_l000001?oNe/l01Ol0003ogMKAomgFdOoMe]7o000000Co
fmKB00Co0000om[EdooJeM?o00000_oDbLl5om;9d003o`000?oAbM;odLWB00;odLWB0_l00005om39
d`03o`000?o>b=Goc/SE00?oc/SE0_l00009olJmdP?o00001?o4_]@00ol0003o_K?@okfcd00=okfc
d003o`000?ngZlgo]j_=00;o]j_=0_l00002okNZc0?o00001OngZ/`00ol0003o/J;8ok6Rb004ok6R
b003o`000?naX<Oo/J3700Co/J3700?o0000ok6OaOnaWlD01OnaWlD01Ol0003o/Ik4ok6Na?naW/Co
000000?oZYO300?o0000ojZG`onZUl<01OnZU/800ol0003oZYG0ojZE`003ojZE`005o`000?nZU;oo
ZYBoojZD_ol000001?nZT[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01Wooooo00Wo
0000ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000oooooo000>ooooo`05
o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0=?ooool00ol0003ohMO=on7Gc@02on7Gc@03o`000?oPelkoh=O>
00;oh=O>00Go0000omkFcooNe/oog]K?o`000004omgFd@05o`000?oKe];ofmKBom_Fd_l000001?oJ
eM<00ol0003od/W@om;9d003om;9d0GodLWB00?o0000om39doo@bM<00oo@bM<2o`0000Goc/SE00?o
0000olc8e_l000001oo6_M82o`0000Ooa;kD00?o0000okfcd?nm/m003?nm/m000ol0003o]j_=okN[
c@04okN[c@?o00002?ngZ/`00ol0003o/J?:ok6Rb005ok6Rb003o`000?naX<Oo/J3700Co/J3700?o
0000ok6OaOnaWlD01OnaWlD00ol0003o/Ik4o`000002oj^Ia0?oZYO300?o0000ojZG`ol000001?nZ
U/800ol0003oZYG0ojZE`003ojZE`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZT[h00_nZ
T[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01Sooooo00?o0000ooooooooool09Ooo
ool000kooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03;ooooo00?o0000on7GcOoQeld0
0_oQeld00ol0003oh=O>on3GcP02on3GcP05o`000?oNe/oog]K?omkFcol000001?oMe]401Ol0003o
fmKBom_Fd_oKe];o000000Gof]GC00?o0000om;9d?oBbM000_oBbM05om79dP03o`000?o@bM?od<WC
00?od<WC00?o0000olk8eOo>b=D01?o>b=D01?l0003oc<SFolc8e_l00004olJmdP?o00002Oo4_]@0
0ol0003o_K?@okfcd00<okfcd004o`000?ngZlgo]j_=okN[c@?o00000ongZld3o`0000Co]j[<00Go
0000ok6Sb_naXl[o/J?:o`000005ok6Rb003o`000?naX<Oo/J3700Co/J3700?o0000ok6OaOnaWlD0
1OnaWlD01Ol0003oZiW4oj^Ia?n[VLCo000000;oZYO300Co0000ojZG`onZUl?o00001?nZU/800ol0
003oZYG0ojZE`003ojZE`005o`000?nZU;ooZYBoojZD_ol000001?nZT[h00ol0003oZY6mojZA_@03
ojZA_@03o`000?oooooooooo01Wooooo00?o0000ooooooooool09?ooool000kooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0aooooo`05o`000?oQelgohMO=on7GcOl000001?oPelh01Ol0003og]K?omkF
cooNe/oo000000CogMKA00Go0000om_Fd_oKe];ofmKBo`000005om[Ed`03o`000?oHeMGo000000;o
d/W@1OoAbM800ol0003od<WCom39d`03om39d`03o`000?o>b=Goc/SE00?oc/SE0_l00004olc8eP04
o`000?o6_M;o0000o`0000_oa;kD0_l000000onm/m3o0000o`00000?o`0000Wo]j_=0_l000000ong
Z/co0000ok6SbP04ok6SbP03o`000?naX/So/J;800?o/J;800?o0000ok6PaonaX<L01?naX<L00ol0
003o/Io5ok6Oa@03ok6Oa@03o`000?n[VLCoZiW400?oZiW400Ko0000ojZG`onZUl?o0000ojZG`ol0
0004ojZF`P03o`000?nZUL3oZYG000?oZYG000?o0000ojZD_onZU;l00_nZU;l00ol0003oZY:nojZB
_P02ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Sooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01Ooo
ool2o`0002Cooooo00?o0000ooooooooool0;oooool00ol0003ohMO=on7Gc@02on7Gc@05o`000?oP
elkoh=O>on3Gc_l000000ooNe/l00ol0003ogMKAomgFd@02omgFd@05o`000?oKe];ofmKBom_Fd_l0
00001OoJeM<01?l0003of=GEomSEeOoHeMD2o`0000CodLWB1Oo@bM<2o`0000Goc/SE00?o0000olc8
e_o<b=H00oo<b=H2o`0000_oa;kD0ol000000oo3_]Go0000okbddP0;okbddP?o000000Co]Zc?o`00
0?l0003o00002_ngZld00ol0003o/J?:ok6SbP05ok6SbP03o`000?naX/So/J;800?o/J;800?o0000
ok6PaonaX<L01?naX<L01Ol0003o/Io5ok6OaOnaWlGo000000;oZi[61?n[VL@01ol0003oZYO3ojZG
`onZUl?o0000ojZG`ol000001?nZU/800ol0003oZYG0ojZE`003ojZE`005o`000?nZU;ooZYBoojZD
_ol000001?nZT[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01Wooooo0_l0000Toooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0;Oooool00ol0003ohMO=on7Gc@02on7Gc@05o`000?oPelkoh=O>
on3Gc_l000001?oNe/l01Ol0003ogMKAomgFdOoMe]7o000000CofmKB00?o0000om[EdooJeM<00_oJ
eM<00ol0003of=GEomSEe@02omSEe@03o`000?oGe=Ko000000;odLWB1Oo@bM<00ol0003oc/SEolk8
e@04olk8e@03o`000?o<b=Koc<SF00?oc<SF00?o0000ol_8f?l000002?o4_]@3o`0000Co`kkE00?o
0000okbdd_nl]=801onl]=83o`000003okbdd_l0003o]Zc?00Co]Zc?0ol00007okN[c@03o`000?na
YLco/J?:00Ko/J?:00?o0000ok6Rb?naX/P00onaX/P00ol0003o/J37ok6Pa`04ok6Pa`03o`000?na
WlGo000000?oZi[600?o0000oj^Ia?n[VL@00_n[VL@01?l0003oZYO3ojZG`onZUl<2o`0000CoZYK2
00?o0000ojZE`?nZUL000onZUL000ol0003oZYBoojZD_`02ojZD_`03o`000?nZT[koZY:n00;oZY:n
00?o0000ojZA_OnZTKd00onZTKd00ol0003oooooooooo`0Hooooo`;o00009?ooool002Oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0/ooooo`05o`000?oQelgohMO=on7GcOl00000
1?oPelh01Ol0003og]K?omkFcooNe/oo000000CogMKA00Go0000om_Fd_oKe];ofmKBo`000004om[E
d`03o`000?oHeMGof=GE00;of=GE00Go0000omODe_oGe=KoemCFo`000005om39d`03o`000?o>b=Go
c/SE00?oc/SE0_l00004olc8eP;o00000_o;b=P00ol0003oa;kDolBne003olBne0?o00001oo3_]D0
0ol0003o_;CBokbddP04okbddP?o00001?nl]=800ol0003o]Zc?okJ/c`06okJ/c`;o00001?ngZld0
1Ol0003o/JG<ok6Uc?naYLco000000Ko/J?:00?o0000ok6Rb?naX/P00onaX/P00ol0003o/J37ok6P
a`03ok6Pa`;o00001On[V/H00ol0003oZiW4oj^Ia002oj^Ia006o`000?nZUl?oZYO3o`000?nZUl?o
00001?nZU/800ol0003oZYG0ojZE`002ojZE`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZ
T[h00_nZT[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08Oooool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Zooooo`05o`00
0?oQelgohMO=on7GcOl000001?oPelh01Ol0003og]K?omkFcooNe/oo000000CogMKA00Go0000om_F
d_oKe];ofmKBo`000004om[Ed`03o`000?oHeMGof=GE00;of=GE00?o0000omODe_oGe=H00_oGe=H0
0ol0003od<WCom39d`02om39d`Koc/SE00?o0000olc8e_o<b=H00oo<b=H00ol0003oblSHol_8f003
ol_8f003o`000?o4_]Co000000;o00002_o3_]D01?l0003o_;CBokbdd_nl]=83o`0000Oo_;CB00?o
0000okJ/conf[<l02?nf[<l3o`000003okN[cOl0003o/JG<00?o/JG<00?o0000ok6Sb_naXlX01?na
XlX00ol0003o/J;8ok6Rb003ok6Rb006o`000?naX<Oo/J37ok6Paol0003oZic71_n[V/H00ol0003o
ZiW4oj^Ia002oj^Ia004o`000?nZUl?oZYO3ojZG``;o00001?nZU/800ol0003oZYG0ojZE`003ojZE
`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZT[h00_nZT[h00ol0003oZY6mojZA_@03ojZA
_@03o`000?oooooooooo01Wooooo00?o0000ooooooooool08Oooool002Kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oQelgohMO=00;ohMO=00Go0000on3Gc_oP
elkoh=O>o`000003omkFc`03o`000?oMe]7ogMKA00;ogMKA00Go0000om_Fd_oKe];ofmKBo`000004
om[Ed`03o`000?oHeMGof=GE00;of=GE00?o0000omODe_oGe=H00_oGe=H00ol0003oeMCHo`000002
om39d`Koc/SE00?o0000olc8e_o<b=H00_o<b=H2o`0000GoblSH0ol0000;ol>neA3o00003_nf[<l0
0ol0003o/JG<ok6Uc004ok6Uc003o`000?naXl[o/J?:00Co/J?:00?o0000ok6Rb?naX/P00onaX/P0
0ol0003o/J37o`000003oj^La`KoZi[600?o0000oj^Ia?n[VL@00_n[VL@01?l0003oZYO3ojZG`onZ
Ul<2o`0000CoZYK200?o0000ojZE`?nZUL000_nZUL000ol0003oZYBoojZD_`02ojZD_`03o`000?nZ
T[koZY:n00;oZY:n00?o0000ojZA_OnZTKd00onZTKd00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo023ooooo000Vooooo`?o0000:Oooool00ol0003oooooooooo`0Vooooo`03o`000?oQelgo
hMO=00;ohMO=00Go0000on3Gc_oPelkoh=O>o`000003omkFc`03o`000?oMe]7ogMKA00;ogMKA00Go
0000om_Fd_oKe];ofmKBo`000004om[Ed`03o`000?oHeMGof=GE00;of=GE00?o0000omODe_oGe=H0
0_oGe=H01Ol0003oeMCHomGDf?oEe=So000000Koc/SE00?o0000olc8e_o<b=H00_o<b=H00ol0003o
blSHol_8f004ol_8f003o`000?o9b=Wo000000Wo`kkE0ol000000oo2_]Oo0000o`00000<ok^ee003
o`000?nf[]7o]ZkA00?o00002Onf[<l00ol0003o/:K>ok6Uc005ok6Uc003o`000?naXl[o/J?:00Co
/J?:00?o0000ok6Rb?naX/P00onaX/P00ol0003oZic7oj^La`02oj^La`03o`000?n[V/KoZi[600?o
Zi[600?o0000oj^Ia?n[VL@00_n[VL@00ol0003oZYO3ojZG``02ojZG``;o00000onZU/800ol0003o
ZYG0ojZE`003ojZE`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB__nZT[h00_nZT[h00ol0003o
ZY6mojZA_@02ojZA_@03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool002Kooooo
00?o0000ooooooooool0:_ooool2o`0002Kooooo00Go0000on7GcOoQelgohMO=o`000003on3GcP03
o`000?oNe/oog]K?00;og]K?00Go0000omgFdOoMe]7ogMKAo`000003om_FdP03o`000?oJeM?of]GC
00;of]GC00?o0000omSEeOoHeMD00_oHeMD00ol0003oemCFomODeP02omODeP03o`000?oEe=SoeMCH
00;oeMCH0_l00004olk8e@Coc<SF0_l00005ol_8f0;o00000_o9b=T00ol0003o`kkEol>ne@03ol>n
e@Co000000Ko`[kGo`000?l0003o0000ol:neol0000<ok^ee003o`000?nf[]7o]ZkA00?o]ZkA0ol0
0005okJ/c`05o`000?n`Y/ko/:K>ok2Vc_l000001OnaYL`00ol0003o/J?:ok6SbP04ok6SbP05o`00
0?naX/So/J;8ok6Rb?l000001_n[W<L00ol0003oZi[6oj^JaP03oj^JaP03o`000?n[VLCoZiW400;o
ZiW400Co0000ojZG`onZUl?oZYO30_l00004ojZF`P03o`000?nZUL3oZYG000;oZYG000?o0000ojZD
_onZU;l00_nZU;l00ol0003oZY:nojZB_P02ojZB_P03o`000?nZTKgoZY6m00?oZY6m00?o0000oooo
ooooool06_ooool2o`00023ooooo000Vooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool08_ooool01Ol0003ohMO=on7GcOoQelgo000000Coh=O>00Go0000omkFcooNe/oog]K?o`000003
omgFd@03o`000?oKe];ofmKB00;ofmKB00Go0000om[EdooJeM?of]GCo`000004omSEe@03o`000?oG
e=KoemCF00;oemCF00?o0000omGDf?oEe=P00_oEe=P01?l0003odm?Iom?CfOl00002olk8e@Coc<SF
00?o0000ol_8f?o;b=P01?o;b=P00ol0003obLSIolW8f@03olW8f@03o`000?o3_]Go000000;o0000
0_o2_]L3o`0000Co`[kG00?o0000ok^ee?nk]M@02Onk]M@00ol0003o]ZkAokJ^d@07okJ^d@?o0000
00?o]Zc?o`000?n`Y/h01?n`Y/h00ol0003o/JG<ok6Uc003ok6Uc003o`000?naXl[o/J?:00Co/J?:
00?o0000ok6Rb?l000000_n[WLT6oj^La`03o`000?n[V/KoZi[600;oZi[600?o0000oj^Ia?n[VL@0
0_n[VL@00ol0003oZYO3ojZG``02ojZG``;o00000onZU/800ol0003oZYG0ojZE`003ojZE`003o`00
0?nZU;ooZYBo00;oZYBo00Go0000ojZB__nZT[koZY:no`000005ojZA_@03o`000?oooooooooo01[o
oooo0_l0000Pooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo
00?o0000on7GcOoQeld00_oQeld01Ol0003oh=O>on3Gc_oPelko000000?og]K?00?o0000omgFdOoM
e]400_oMe]401Ol0003ofmKBom_Fd_oKe];o000000?of]GC00?o0000omSEeOoHeMD00_oHeMD00ol0
003oemCFomODeP02omODeP03o`000?oEe=SoeMCH00;oeMCH00?o0000om?CfOoCdmT00_oCdmT00ol0
003oc<SFolc8eP02olc8eP03o`000?o;b=SoblSH00?oblSH0_l00005olW8f@?o00000_o2_]L3o`00
00Go`[kG0ol000000onk]MCo0000o`000009o`0000co]ZkA00?o0000ok2Vc_n`Y/h01On`Y/h00ol0
003o/JG<ok6Uc003ok6Uc003o`000?naXl[o/J?:00?o/J?:0_l00004oj^Mb@GoZic700?o0000oj^J
a_n[V/H00on[V/H00ol0003oZiW4oj^Ia002oj^Ia003o`000?nZUl?oZYO300;oZYO300?o0000ojZF
`_nZU/800_nZU/800ol0003oZYG0ojZE`002ojZE`003o`000?nZU;ooZYBo00;oZYBo00?o0000ojZB
__nZT[h00_nZT[h00ol0003oZY6mojZA_@03ojZA_@03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07Oooool002Kooooo0_l0000_ooooo`03o`000?oooooooooo01oooooo00Go0000on7GcOoQ
elgohMO=o`000003on3GcP05o`000?oNe/oog]K?omkFcol000001?oMe]401Ol0003ofmKBom_Fd_oK
e];o000000Cof]GC00Go0000omSEeOoHeMGof=GEo`000004omODeP03o`000?oEe=SoeMCH00;oeMCH
00?o0000om?CfOoCdmT00_oCdmT00ol0003odM;Jo`000002olc8ePGoblSH0_l00005olW8f@;o0000
00?oalSJo`000?l000000_l00004ol:ne`Co00000_o0_mT00ol0003o^[KFokZfeP09okZfeP03o`00
0?ne[m?o000000;o00002?nf[]400ol0003o/:S?ok2VcP06ok2VcP03o`000?naYLco/JG<00?o/JG<
00Ko0000ok6Sb_naXl[o/J?:o`000?n[Wl/5oj^Mb@03o`000?n[W<OoZic700?oZic700?o0000oj^J
a_n[V/H00_n[V/H00ol0003oZiW4oj^Ia002oj^Ia003o`000?nZUl?oZYO300?oZYO300Go0000ojZF
`_nZU/;oZYK2o`000005ojZE`003o`000?nZU;ooZYBo00;oZYBo00Go0000ojZB__nZT[koZY:no`00
0005ojZA_@03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool002Kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Mooooo`05o`000?oQelgohMO=on7GcOl000000ooP
elh01Ol0003og]K?omkFcooNe/oo000000CogMKA00Go0000om_Fd_oKe];ofmKBo`000004om[Ed`05
o`000?oHeMGof=GEomSEeOl000001?oGe=H00ol0003oeMCHomGDf002omGDf003o`000?oCdmWodm?I
00;odm?I00Go0000om7Bf_oAd][odM;Jo`000005ol_8f003o`000?o9b=WobLSI00CobLSI00?o0000
olO8f_l000000ol00003ol:ne`?o00001_o0_mT00ol0003o^[KFokZfeP08okZfeP03o`000?ne[m?o
]JoC00?o]JoC0ol00004okJ^d@05o`000?n`Z<oo/:S?ok2Xcol000001_n`Y/h00ol0003o/JG<ok6U
c003ok6Uc003o`000?naXl[o000000?oZio;1On[WLT00ol0003oZic7oj^La`02oj^La`03o`000?n[
V/KoZi[600?oZi[600?o0000oj^Ia?n[VL@00_n[VL@00ol0003oZYO3ojZG``02ojZG``03o`000?nZ
U/;oZYK200;oZYK200?o0000ojZE`?nZUL000_nZUL000ol0003oZYBoojZD_`02ojZD_`03o`000?nZ
T[koZY:n00;oZY:n00?o0000ojZA_OnZTKd00_nZTKd2o`0001gooooo00?o0000ooooooooool07?oo
ool002Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Kooooo`05o`000?oQelgo
hMO=on7GcOl000000ooPelh01Ol0003og]K?omkFcooNe/oo000000CogMKA00Go0000om_Fd_oKe];o
fmKBo`000004om[Ed`03o`000?oHeMGof=GE00;of=GE00Go0000omODe_oGe=KoemCFo`000004omGD
f003o`000?oCdmWodm?I00;odm?I00Co0000om7Bf_oAd][odM;J0_l00004ol_8f003o`000?o9b=Wo
bLSI00?obLSI1?l00003olO8fP?o00002_o0_mT00ol0003o^[KFokZfeP08okZfeP03o`000?ne[m?o
]JoC00Ko]JoC0ol000000onf[]7o0000ok2Xc`03ok2Xc`03o`000?n`Y/ko/:K>00Co/:K>00?o0000
ok6Uc?naYL`00onaYL`00ol0003oZio;oj^Ob`03oj^Ob`CoZig900?o0000oj^Laon[W<L00on[W<L0
0ol0003oZi[6oj^JaP02oj^JaP03o`000?n[VLCoZiW400;oZiW400?o0000ojZG`onZUl<00onZUl<0
1Ol0003oZYK2ojZF`_nZU/;o000000GoZYG000?o0000ojZD_onZU;l00_nZU;l01_l0003oZY:nojZB
__nZT[ko0000ojZA_@?o000000?oX8g0o`000?ooool07Oooool00ol0003oooooooooo`0Kooooo`00
9Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo00?o0000on7GcOoQeld0
0_oQeld01Ol0003oh=O>on3Gc_oPelko000000?og]K?00Go0000omgFdOoMe]7ogMKAo`000004om_F
dP05o`000?oJeM?of]GCom[Edol000001?oHeMD00ol0003oemCFomODeP02omODeP05o`000?oEe=So
eMCHomGDf?l000001?oCdmT01Ol0003odM;Jom7Bf_oAd][o000000;ocm;L00?o0000ol_8f?o;b=P0
1Oo9b=T3o`0000CoalSJ0_l000000oo5amco0000ol2of@08ol2of@?o000000?o^[KFo`000?l00000
1ol0000<okF_d`03o`000?n`Z<oo/:S?00Co/:S?0_l00005ok2VcP04o`000?naYLco/JG<ok6Uc0;o
00001On[Wl/00ol0003oZig9oj^Mb@02oj^Mb@03o`000?n[W<OoZic700?oZic700?o0000oj^Ja_n[
V/H00_n[V/H00ol0003oZiW4oj^Ia002oj^Ia003o`000?nZUl?oZYO300;oZYO30_l00003ojZF`P03
o`000?nZUL3oZYG000;oZYG000?o0000ojZD_onZU;l00_nZU;l00ol0003oZY:nojZB_P03o`0000Co
X8g000?o0000ooooooooool06oooool2o`0001gooooo000Uooooo`?o0000<oooool00ol0003ooooo
ooooo`0Hooooo`05o`000?oQelgohMO=on7GcOl000000ooPelh01Ol0003og]K?omkFcooNe/oo0000
00CogMKA00Go0000om_Fd_oKe];ofmKBo`000003om[Ed`03o`000?oHeMGof=GE00;of=GE00?o0000
omODe_oGe=H00_oGe=H01Ol0003oeMCHomGDf?oEe=So000000Codm?I00Go0000om7Bf_oAd][odM;J
o`000004oloBg0;o00000_o9b=T3o`0000KoalSJ00Go0000olG7g?o5amcoaLOLo`000005ol2of@Co
00000_nn_mX00ol0003o^KOHokVgf007okVgf003o`000?nd/=Go000000;o00002?ne[m<00ol0003o
/:WAok2Xc`06ok2Xc`03o`000?n`Y/ko/:K>00?o/:K>00?o0000ok6Uc?l000000_n[X<`00ol0003o
Zio;oj^Ob`03oj^Ob`03o`000?n[WLWoZig900;oZig900?o0000oj^Laon[W<L00_n[W<L00ol0003o
Zi[6oj^JaP02oj^JaP03o`000?n[VLCoZiW400;oZiW400?o0000ojZG`onZUl<00onZUl<2o`0000;o
ZYK200?o0000ojZE`?nZUL000onZUL001?l0003oZYBoojZD_onZU;l3o`0000;oX8k11_nPSL000ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo000Uooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05_ooool01Ol0003ohMO=on7GcOoQelgo000000?oh=O>00Go0000omkF
cooNe/oog]K?o`000004omgFd@05o`000?oKe];ofmKBom_Fd_l000000ooJeM<00ol0003of=GEomSE
e@02omSEe@03o`000?oGe=KoemCF00;oemCF00Go0000omGDf?oEe=SoeMCHo`000004om?Cf@05o`00
0?oAd][odM;Jom7Bf_l000001?o?d]`00ol0003oc=7Mo`000002o`000003olW8fOl0003oalSJ00Co
alSJ0_l00005olG7g003o`000?o0_mWo000000;o00001_nn_mX00ol0003o^KOHokVgf007okVgf003
o`000?nd/=Go];3E00;o];3E0_l00005okF_d`05o`000?n`ZM7o/:WAok2YdOl000001_n`Z<l00ol0
003o/:K>ok2VcP03ok2VcP03o`000?n[X<coZj3<00;oZj3<00?o0000oj^Obon[Wl/00_n[Wl/00ol0
003oZig9oj^Mb@02oj^Mb@03o`000?n[W<OoZic700?oZic700?o0000oj^Ja_n[V/H00_n[V/H00ol0
003oZiW4oj^Ia002oj^Ia003o`000?nZUl?oZYO300;oZYO30_l00003ojZF`P03o`000?nZUL3oZYG0
00;oZYG000Go0000ojZD_ol0003o0000oj6?`P04oj2>`@03o`000?nPSL3oX8g000?oX8g000?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`006_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Dooooo`Oo00000_oPelh4
omkFc`CogMKA00Go0000om_Fd_oKe];ofmKBo`000003om[Ed`03o`000?oHeMGof=GE00;of=GE00?o
0000omODe_oGe=H00_oGe=H01Ol0003oeMCHomGDf?oEe=So000000Codm?I00Go0000om7Bf_oAd][o
dM;Jo`000004oloBg0?o000000?oc=7Mo`000?l000001Oo7b=X2o`0000KoaLOL0ol00008okjofP03
o`000?ni]mSo^KOH00Oo^KOH00?o0000okB`eOnd/=D01Ond/=D3o`000003okF_dol0003o/:WA00Co
/:WA00?o0000ok2Xcon`Z<l01?n`Z<l01?l0003o/:K>ok2Vc_n`Y/h2o`0000CoZj3<00?o0000oj^O
bon[Wl/00on[Wl/00ol0003oZig9oj^Mb@02oj^Mb@03o`000?n[W<OoZic700;oZic700?o0000oj^J
a_n[V/H00_n[V/H00ol0003oZiW4oj^Ia003oj^Ia003o`000?nZUl?oZYO300;oZYO30_l00002ojZF
`P04o`000?nZUL3oZYG0ojZE`0?o00000onQSl800ol0003oX8k1oj2>`@02oj2>`@GoX8g000?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`006_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`05o`000?oTi=;o
i>CBonCTd_l000000_oSi=<7o`0000?ogMKA1?oKe]83om[Ed`03o`000?oHeMGof=GE00;of=GE00?o
0000omODe_oGe=H00_oGe=H01Ol0003oeMCHomGDf?oEe=So000000Codm?I00Go0000om7Bf_oAd][o
dM;Jo`000002oloBg0?o00000oo<dMd00ol0003ob]3No`000004olO8fP03o`000?o5amcoaLOL00Co
aLOL0_l000000oo3amgo0000okjofP06okjofPgo00002_nd/=D00ol0003o/:WAok2Yd@05ok2Yd@03
o`000?n`Z<oo/:S?00Co/:S?00?o0000ok2Vc_l000000_n[X/h00ol0003oZj3<oj^Pc002oj^Pc003
o`000?n[Wl_oZio;00?oZio;00Go0000oj^MbOn[WLWoZig9o`000005oj^La`03o`000?n[V/KoZi[6
00;oZi[600?o0000oj^Ia?n[VL@00_n[VL@00ol0003oZYO3ojZG``02ojZG``03o`000?nZU/;o0000
00Go00000_nQTL<5oj6?`PCoX8k11OnPSL000ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01Sooooo000Jooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo017ooooo00Go0000onCTd_oTi=;oi>CBo`000003on?Td`05o`000?oQhmGo
hN?Eon7SeOl000000_oOh]H8o`0000;of]GC1?oHeMD00ol0003oemCFomODeP02omODeP05o`000?oE
e=SoeMCHomGDf?l000001?oCdmT01?l0003odM;Jom7Bf_oAd]X4o`000003oloBg?l0003oc=7M00;o
c=7M00Go0000ol[@g_o:d=kob]3No`000002olO8fP03o`000?o5amcoaLOL00?oaLOL0_l00004ol?7
g@03o`000?nn_m[o000000Co00000_nl_m`00ol0003o^;SIokRhf@07okRhf@03o`000?nc/]Oo/k;G
00?o00001Ond/=D00ol0003o[j_Do`000006ok2Yd@03o`000?n`Z<oo/:S?00?o/:S?0_l00004oj^R
cP03o`000?n[X<coZj3<00;oZj3<00?o0000oj^Obon[Wl/00_n[Wl/00ol0003oZig9oj^Mb@02oj^M
b@03o`000?n[W<OoZic700;oZic700?o0000oj^Ja_n[V/H00_n[V/H00ol0003oZiW4oj^Ia003oj^I
a004o`000?nZUl?oZYO3ojZG``?o00000_nQT/D5oj6A``03o`000?nQSl;oXHo200;oXHo21?nPS/40
0ol0003oX8g0oj2=`003oj2=`003o`000?oooooooooo01gooooo0_l00008ooooo`Co000000?o410@
ooooooooool02_ooool001[ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000>Oooool0
0ol0003oooooooooo`0@ooooo`04o`000?oTi=;oi>CBo`0000?ohnCC00Go0000on7SeOoQhmGohN?E
o`000004omoReP05o`000?oNh]Sog^;HomkRf?l000000_oLhMT3o`0000?of=GE1?oGe=H01Ol0003o
eMCHomGDf?oEe=So000000Codm?I00?o0000om7Bf_oAd]X00ol00003oloBg005o`000?o<dMgoc=7M
olcAgOl000001?o:d=h2o`0000KoaLOL00?o0000ol?7gOo3amd00oo3amd3o`0000Oo_;oL00?o0000
okRhfOnh^=T01onh^=T00ol0003o/k;Gok>be`03ok>be`?o000000?o];3Eo`000?n_Zm@00_n_Zm@2
o`0000Go/:WA00Oo0000ok2Xcon`Z<oo/:S?o`000?n[Y=3o000000CoZj;>00?o0000oj^Pc?n[X<`0
0_n[X<`00ol0003oZio;oj^Ob`03oj^Ob`03o`000?n[WLWoZig900;oZig900?o0000oj^Laon[W<L0
0_n[W<L00ol0003oZi[6oj^JaP02oj^JaP03o`000?n[VLCoZiW400;oZiW400Go0000ojZG`ol0003o
0000oj:CaP02oj6Ba@03o`000?nQT/Go000000GoXI731?nQSl800ol0003oX8k1oj2>`@02oj2>`@Go
X8g000?o0000ooooooooool07Oooool2o`0000[ooooo00?o0000ooooooooool03?ooool001[ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool03_ooool01Ol0003oi>CBonCTd_oTi=;o000000;ohnCC00Go0000on7SeOoQhmGohN?Eo`000004
omoReP05o`000?oNh]Sog^;HomkRf?l000000ooLhMT00ol0003of^3Jom[PfP04o`0000?oemCF0ooE
e=P00ol0003odm?Iom?Cf@02om?Cf@Go00001?o?d]`01Ol0003oc=7MolcAgOo<dMgo000000Cob]3N
00?o0000olS?gol000001?o5am`2o`0000Co`lOM0_l000000oo0a]oo0000okbog007okbog003o`00
0?nh^=Wo^;SI00Ko^;SI00?o0000ok>beonc/]L01onc/]L00ol0003o[j_Dojn[e004ojn[e003o`00
0?n`ZM7o/:WA00?o/:WA00?o0000ok2Xcol000000on[Y=000ol0003oZj;>oj^RcP02oj^RcP03o`00
0?n[X<coZj3<00;oZj3<00?o0000oj^Obon[Wl/00on[Wl/01Ol0003oZig9oj^MbOn[WLWo000000Go
Zic700Go0000oj^Ja_n[V/KoZi[6o`000003oj^Ia0?o00000onRTlH01Ol0003oXI;5oj6BaOl0003o
XI;500GoXI731?nQSl800ol0003oX8k1oj2>`@02oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000
ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo000Joooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo00cooooo00Go0000onCTd_oTi=;oi>CBo`000003on?Td`05o`000?oQhmGohN?Eon7SeOl00000
0ooOh]H01Ol0003og^;HomkRf?oNh]So000000?og>7I00?o0000om[Pf_oJh=X00_oJh=X00ol0003o
f=oLomSOg004o`0000;oeMCH0ooCdmT3o`0000;odM;J00?o0000oloBg?o?d]`00_o?d]`01Ol0003o
c=7MolcAgOo<dMgo000000Cob]3N00Go0000olS?goo8cmoob<oOo`000002olG7g003o`000?o3amgo
`lOM00;o`lOM0_l00003ol36g`03o`000?nl_mco_;oL00Co_;oL3?l00009ok>be`03o`000?n_[MKo
000000Go[j_D0_l00003ok2Yd@;o00001On[Y=001Ol0003oZj;>oj^Rc_n[X/ko000000CoZj3<00?o
0000oj^Obon[Wl/00on[Wl/00ol0003oZig9oj^Mb@02oj^Mb@03o`000?n[W<OoZic700;oZic700?o
0000oj^Ja_n[V/H01Ol00002oj:Ea`GoXY?60onQT/D2o`0000CoXI7300?o0000oj6?`_nQSl800_nQ
Sl801Ol0003oX8k1oj2>`OnPS/7o000000CoX8g000?o0000ooooooooool07oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00cooooo000Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo00Go0000onCTd_oTi=;o
i>CBo`000002on?Td`05o`000?oQhmGohN?Eon7SeOl000001?oOh]H01Ol0003og^;HomkRf?oNh]So
000000;og>7I00?o0000om[Pf_oJh=X00_oJh=X00ol0003of=oLomSOg002omSOg003o`000?oFg]go
e]kM00Go000000?odm?Iom7Bf_oAd]X00_oAd]X4oloBg005o`000?o<dMgoc=7MolcAgOl000001?o:
d=h00ol0003ob<oOolS?g`02olS?g`?o00001?o3amd00ol0003o`<KOol36g`04ol36g`03o`000?nl
_mco000000?o00000_nj`=h00ol0003o][WLokJig006okJig003o`000?nb/mWo000000;o00001?nc
/]L01Ol0003o[jgFojn]e_n_[MKo000000Ko[j_D00Go0000ok2YdOl0003oZjKBo`000005oj^Td003
o`000?n[X/koZj;>00;oZj;>00?o0000oj^Pc?n[X<`00_n[X<`00ol0003oZio;oj^Ob`03oj^Ob`05
o`000?n[WLWoZig9oj^MbOl000001?n[W<L3o`0000;oXYO91OnRULL00ol0003oXY?6oj:CaP02oj:C
aP03o`000?nQT/GoXI;500;o00001?nQTL<00ol0003oXHo2oj6?`P02oj6?`P05o`000?nPS/7oX8k1
oj2>`Ol000001OnPSL000ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool03?ooool001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool02Oooool01Ol0003oi>CBonCTd_oTi=;o000000?ohnCC00Go
0000on7SeOoQhmGohN?Eo`000003omoReP05o`000?oNh]Sog^;HomkRf?l000000ooLhMT01Ol0003o
f^3Jom[Pf_oJh=[o000000Cof=oL00?o0000omKNgOoFg]d00ol000000ooDgMko0000o`000002o`00
00;odM;J1?o?d]`01Ol0003oc=7MolcAgOo<dMgo000000?ob]3N0_l00004olS?g`05o`000?o5c^7o
aLkQolG>hOl000000_o3amd00ol0003o`<KOol36g`04ol36g`?o00001_nj`=h00ol0003o][WLokJi
g005okJig003o`000?nb/mWo/[?I00?o/[?I0_l000000onc/]Oo0000ojn]eP04ojn]eP03o`000?n_
ZmCo[j_D00Co[j_D00Go0000oj^Vd_n[Y];oZjKBo`000005oj^Td003o`000?n[X/koZj;>00;oZj;>
00?o0000oj^Pc?n[X<`00_n[X<`00ol0003oZio;oj^Ob`02oj^Ob`03o`000?n[WLWoZig900;oZig9
00Go0000oj^Laol0003o0000oj>HbP04oj:Gb@03o`000?nRULOoXYG700?oXYG71?nRTlH01Ol0003o
XI;5oj6BaOnQT/Go000000GoXI7300Go0000oj6?`_nQSl;oXHo2o`000004oj2>`@03o`000?nPSL3o
X8g000;oX8g000?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo000Sooooo`?o0000?oooool00ol0003oooooooooo`08ooooo`04o`000?oTi=;oi>CB
o`0000?ohnCC00Go0000on7SeOoQhmGohN?Eo`000004omoReP04o`000?oNh]Sog^;Ho`0000?og>7I
00Go0000om[Pf_oJh=[of^3Jo`000004omSOg0Go00001?oDgMh00ol0003od]_Pom;Kh003o`0000?o
cm;L0oo<dMd01Ol0003ob]3Nol[@g_o:d=ko000000Gob<oO00?o0000olG>hOo5c^400_o5c^42o`00
00Ko`<KO0_l000000onna^7o0000ok[0gP06ok[0gP03o`000?nf^Mco][WL00Go][WL00?o0000ok:c
fOnb/mT01Onb/mT00ol0003o[jgFojn]eP05ojn]eP07o`000?n_ZmCo[j_Dojn[e?l0003oZjSDo`00
0004oj^VdP03o`000?n[Y=3oZjC@00?oZjC@00Go0000oj^Rc_n[X/koZj;>o`000004oj^Pc003o`00
0?n[Wl_oZio;00?oZio;00?o0000oj^MbOn[WLT00ol00003oj>HbP03o`000?nRUlWoXYO900;oXYO9
1OnRULL01Ol0003oXY?6oj:Ca_nRTlKo000000CoXI;500?o0000oj6A`onQTL<00_nQTL<00ol0003o
XHo2oj6?`P02oj6?`P05o`000?nPS/7oX8k1oj2>`Ol000001?nPSL000ol0003oooooooooo`0Noooo
o`?o00001oooool00ol0003oooooooooo`0<ooooo`008oooool00ol0003oooooooooo`10ooooo`;o
00001oooool01Ol0003oi>CBonCTd_oTi=;o000000;ohnCC00Go0000on7SeOoQhmGohN?Eo`000004
omoReP05o`000?oNh]Sog^;HomkRf?l000000_oLhMT00ol0003of^3Jom[PfP02om[PfP03o`000?oH
gmcof=oL00?o00000_oFg]d00ol0003oe=gNomCMgP02omCMgP05o`000?oBfn3od]_Pom;Kh?l00000
0_o?f^44o`0000;oc=7M1?o:d=h5olS?g`03o`000?o5c^7oaLkQ00;oaLkQ00?o0000ol;=h_l00000
1?o0a]l2o`0000Co_/KQ00Co0000ok[0g_nj`=ko^/3N2ol00008ok:cf@04o`000?n^[mSo0000o`00
00Go[jgF00?o0000ojn[e?l000000on[Z=@00ol0003oZjKBoj^VdP02oj^VdP03o`000?n[Y=3oZjC@
00;oZjC@00?o0000oj^Rc_n[X/h00_n[X/h00ol0003oZj3<oj^Pc002oj^Pc004o`000?n[Wl_oZio;
oj^Ob`Co00000_nSV/`5oj>HbPCoXYO900?o0000oj:EaonRULL00_nRULL00ol0003oXY?6oj:CaP02
oj:CaP04o`000?nQT/GoXI;5oj6Ba@;o00000onQTL<00ol0003oXHo2oj6?`P02oj6?`P05o`000?nP
S/7oX8k1oj2>`Ol000001?nPSL000ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00;ooooo
00?oEEEEofIVI_l000003_ooool002?ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`03ooooo`05o`000?oTi=;oi>CBonCTd_l000000ooSi=<01Ol0003ohN?Eon7SeOoQhmGo000000?o
gn;F00Go0000omkRf?oNh]Sog^;Ho`000003omcQf@06o`000?oJh=[of^3Jom[Pf_l0003of=oL0_l0
00001OoHgmco0000omKNgOoFg]go000000Coe=gN00Go0000om;Kh?oBfn3od]_Po`000004oloJh@03
o`000?o=fN;ocMWR00?o00000_o:d=h5olS?g`03o`000?o5c^7oaLkQ00;oaLkQ00Go0000ol;=h_o2
cN;o`/gRo`000002ol36g`03o`000?nna^7o_/KQ00?o_/KQ1Ol00003okS0h003o`000?ne^]ko]K[N
00Co]K[N00?o0000ok6eg?na]M`00ol00002ok:cf@03o`000?n^[mSo[ZoH00;o[ZoH00?o0000ojn]
e_n_[MH00on_[MH00ol0003oZjSDoj^Xe003oj^Xe003o`000?n[Y];oZjKB00;oZjKB00?o0000oj^T
d?n[Y=000_n[Y=001Ol0003oZj;>oj^Rc_n[X/ko000000CoZj3<1?l00002ojBLc@CoXi[<00?o0000
oj>Hb_nSV<X00_nSV<X01Ol0003oXYO9oj:GbOnRUlWo000000GoXYG71?nRTlH01?l0003oXI;5oj6B
aOnQT/D2o`0000?oXI7300?o0000oj6?`_nQSl800_nQSl801Ol0003oX8k1oj2>`OnPS/7o000000Go
X8g000?o0000ooooooooool07oooool3o`0001Cooooo000Sooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool00_ooool01Ol0003oi>CBonCTd_oTi=;o000000;ohnCC00Go0000on7SeOoQ
hmGohN?Eo`000004omoReP04o`000?oNh]Sog^;Ho`0000?og>7I00Co0000om[Pf_oJh=[of^3J0ol0
0002omSOg005o`000?oFg]goe]kMomKNgOl000000ooDgMh01Ol0003od]_Pom;Kh?oBfn3o000000Co
cm[Q00Go0000olgIh_o=fN;ocMWRo`000002ol[Gh`;o00001?o8cml01?l0003oaLkQolG>hOo5c^42
o`0000Co`/gR0_l00004okk6h@?o000000?o^lGRo`000?nh`>001Onh`>000ol0003o]K[NokFjgP03
okFjgP03o`000?na]Mco/KGL00Co/KGL0_l00006ojj_f0;o000000Co[jgFo`000?n[Z]Ko00001On[
Z=@00ol0003oZjKBoj^VdP02oj^VdP03o`000?n[Y=3oZjC@00;oZjC@00?o0000oj^Rc_n[X/h00_n[
X/h01Ol0003oZj3<o`000?l0003oY9k?00GoY9c=00?o0000oj>Jc?nSV/`00_nSV/`4oj>HbP03o`00
0?nRUlWoXYO900;oXYO900?o0000oj:EaonRULL00_nRULL01Ol0003oXY?6oj:Ca_nRTlKo000000Co
XI;50_l00003oj6A``05o`000?nQSl;oXHo2oj6?`_l000001?nPS/400ol0003oX8g0oj2=`002oj2=
`003o`000?oooooooooo01cooooo0ol00002ooooo`03o`000?oooooooooo01;ooooo000Sooooo`;o
0000AOooool01?l0003oooooooooool00003onCTdP05o`000?oSi=?ohnCCon?Tdol000000ooQhmD0
1Ol0003ogn;FomoRe_oOh]Ko000000?og^;H00Go0000omcQfOoLhMWo0000om[PfP04o`0000?of=oL
00Go0000omKNgOoFg]goe]kMo`000003omCMgP05o`000?oBfn3od]_Pom;Kh?l000001?o?f^401Ol0
003ocMWRolgIh_o=fN;o000000?ob]OS00Ko0000olSEi?l0003o0000olS?gol00003olG>h@03o`00
0?o2cN;o`/gR00;o`/gR0_l00002oko;h`04o`000?nna^7o_/KQo`0000Go^lGR00?o0000okS0h?nh
`>002_l00006ok6eg004o`000?n^/M_o[[7Ko`0000Ko[ZoH00Go0000oj^Ze_n[Z]KoZj[Fo`000005
oj^Xe003o`000?n[Y];oZjKB00;oZjKB00?o0000oj^Td?n[Y=000_n[Y=000ol0003oZj;>oj^RcP03
o`0000?oY9k?00?o0000ojBLcOnTW<d00onTW<d4oj>Jc003o`000?nSV<[oXiS:00;oXiS:00Go0000
oj:GbOnRUlWoXYO9o`000004oj:Ea`05o`000?nRTlKoXY?6oj:Ca_l000001?nQT/D00ol0003oXI73
o`000002oj6A``03o`000?nQSl;oXHo200;oXHo200Go0000oj2>`OnPS/7oX8k1o`000004oj2=`003
o`000?oooooooooo01Wooooo0ol00005ooooo`03o`000?oooooooooo01;ooooo000Sooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooool000000_oTi=801Ol0003ohnCCon?TdooSi=?o000000?o
hN?E00Go0000omoRe_oOh]Kogn;Fo`000003omkRf003o`000?oLhMWog>7I00?o00000_oJh=X00ol0
003of=oLomSOg002omSOg004o`000?oFg]goe]kMo`0000?oe=gN00Go0000om;Kh?oBfn3od]_Po`00
0004oloJh@05o`000?o=fN;ocMWRolgIh_l000000oo:en<00ol0003ob=GTolSEi002olSEi0?o0000
0_o5c^44ol;=hP03o`000?nobn?o_l_S00;o_l_S0ol00005ok_5hPCo00000onf`>800ol0003o/k_P
ok>kh003ok>kh003o`000?n`]mko000000;o000000?o/KGLo`000?n^/M/00on^/M/01ol0003o[ZoH
ojj_f?n^[mSo0000oj^/fOl000001?n[Z]H00ol0003oZjSDoj^Xe003oj^Xe003o`000?n[Y];oZjKB
00;oZjKB00?o0000oj^Td?n[Y=001?l00002ojBPd@GoY9k?00?o0000ojBLcOnTW<d00_nTW<d01Ol0
003oXi[<oj>Jc?nSV/co000000CoXiS:00Go0000oj:GbOnRUlWoXYO9o`000004oj:Ea`03o`000?nR
TlKoXY?600;oXY?600Go0000oj6BaOnQT/GoXI;5o`000002oj6A``03o`000?nQTL?o000000CoXHo2
00Go0000oj2>`OnPS/7oX8k1o`000004oj2=`003o`000?oooooooooo01Kooooo0ol00008ooooo`03
o`000?oooooooooo01;ooooo000Sooooo`03o`000?oooooooooo04Kooooo00Go0000onCTd_oTi=;o
i>CBo`000002on?Td`05o`000?oQhmGohN?Eon7SeOl000001?oOh]H00ol0003og^;HomkRf005o`00
00?of^3J00?o0000omSOg?oHgm`00_oHgm`01?l0003oe]kMomKNgOl00003omCMgP05o`000?oBfn3o
d]_Pom;Kh?l000001?o?f^401Ol0003ocMWRolgIh_o=fN;o000000?ob]OS00?o0000olSEi?o8eN@0
0_o8eN@01?l0003oaM?UolGCiOo5dnD3o`0000;o`/gR00?o0000oko;honobn<00_nobn<01Ol0003o
_<[Uokc:iOnlb^Go000000;o^lGR0_l000000onhaNCo0000okK0hP04okK0hP03o`000?nc^n3o/k_P
00?o/k_P00?o0000ok2gg_n`]mh00_n`]mh00ol0003o[[7Kojjaf`04ojjaf`03o`000?n^[mSo0000
00?oZjcI00?o0000oj^Ze_n[Z]H00_n[Z]H00ol0003oZjSDoj^Xe002oj^Xe003o`000?n[Y];oZjKB
00;oZjKB0ol00002ojFRdPGoY:3A1?nTW/l00ol0003oY9c=ojBLc@02ojBLc@03o`000?nSV/coXi[<
00;oXi[<00Go0000oj>Hb_nSV<[oXiS:o`000004oj:Gb@03o`000?nRULOoXYG700;oXYG700Go0000
oj:Ca_nRTlKoXY?6o`000003oj6Ba@06o`000?nQTL?oXI73o`000?nQTL?o00001?nQSl800ol0003o
X8k1oj2>`@02oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000ooooooooool04Oooool4o`0000_o
oooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool0A_ooool01Ol0003oi>CB
onCTd_oTi=;o000000?ohnCC00Go0000on7SeOoQhmGohN?Eo`000003omoReP03o`000?oNh]So0000
00;o00000ooLhMT01?l0003of^3Jom[Pf_l00004omSOg005o`000?oFg]goe]kMomKNgOl000000ooD
gMh01Ol0003od]_Pom;Kh?oBfn3o000000?ocm[Q00Go0000olgIh_o=fN;ocMWRo`000003ol[Gh`03
o`000?o8eNCob=GT00;ob=GT00Go0000olGCiOo5dnGoaM?Uo`000003ol;BiP;o00000onobn<2o`00
00Co_<[U0_l00005okS5i003o`000?nf`>;o]/3R00;o]/3R00?o0000ok>kh?nc^n000_nc^n000ol0
003o/;ONok2ggP03ok2ggP04o`000?n]/mgo0000o`0000Co[[7K00?o0000oj^/fOn[[=T00on[[=T0
0ol0003oZj[Foj^ZeP02oj^ZeP03o`000?n[Z=CoZjSD00;oZjSD00Go0000oj^Vd_l0003o0000ojFT
e005ojFRdPCoY:3A00Go0000ojBNconTW/ooY9k?o`000005ojBLc@05o`000?nSV/coXi[<oj>Jc?l0
00000onSV<X00ol0003oXYO9oj:Gb@02oj:Gb@03o`000?nRULOoXYG700;oXYG700Go0000oj:Ca_nR
TlKoXY?6o`000004oj6Ba@06o`000?nQTL?oXI73o`000?nQTL?o00000onQSl800ol0003oX8k1oj2>
`@02oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000ooooooooool03_ooool3o`00013ooooo00?o
0000ooooooooool04Oooool002;ooooo00?o0000ooooooooool0A_ooool01Ol0003oi>CBonCTd_oT
i=;o000000;ohnCC00Go0000on7SeOoQhmGohN?Eo`000003omoReP?o000000?og^;Ho`000?oLhMT0
0_oLhMT01Ol0003of^3Jom[Pf_oJh=[o000000Cof=oL00Co0000omKNgOoFg]go00000ooDgMh01Ol0
003od]_Pom;Kh?oBfn3o000000Cocm[Q00Go0000olgIh_o=fN;ocMWRo`000002ol[Gh`03o`000?o8
eNCob=GT00;ob=GT00Go0000olGCiOo5dnGoaM?Uo`000004ol;BiP03o`000?nod>Oo000000;o_l_S
1Onlb^D00ol0003o^LSVo`000004okS5i0co000000Go/;ONo`000?n`]mko/;ONo`000004ojfcg@03
o`000?n^/M_o000000;oZZoK00?o0000oj^/fOn[[=T00on[[=T00ol0003oZj[Foj^ZeP02oj^ZeP03
o`000?n[Z=CoZjSD00?o00001?nUY=@4ojFRdP05o`000?nTX=7oY:3AojBPdOl000001?nTW/l00ol0
003oY9c=ojBLc@02ojBLc@05o`000?nSV/coXi[<oj>Jc?l000001?nSV<X01Ol0003oXYO9oj:GbOnR
UlWo000000CoXYG700?o0000oj:Ca_nRTlH00_nRTlH01Ol0003oXI;5oj6BaOnQT/Go000000?oXI73
0_l00004oj6?`P05o`000?nPS/7oX8k1oj2>`Ol000001?nPSL000ol0003oooooooooo`0;ooooo`?o
00004oooool00ol0003oooooooooo`0Aooooo`008_ooool2o`0004Kooooo00Go0000onCTd_oTi=;o
i>CBo`000003on?Td`05o`000?oQhmGohN?Eo`000?oOh]H01?l00002omkRf005o`000?oLhMWog>7I
omcQfOl000000ooJh=X00ol0003of=oLomSOg002omSOg004o`000?oFg]goe]kMo`0000?oe=gN00Go
0000om;Kh?oBfn3od]_Po`000004oloJh@05o`000?o=fN;ocMWRolgIh_l000000oo:en<01Ol0003o
b=GTolSEi?o8eNCo000000?oaM?U00?o0000ol;Bi_o2d^H00_o2d^H01?l0003o_m3Woko@ionod>L2
o`0000Co_<[U00Ko0000okW8i_nib>Ko^LSVo`000?nhaN@2o`000003okG4iOl0003o/l7T00?o/l7T
00?o0000ok6lh_na_>800_na_>800ol0003o[[WQojjih@02o`0000Ko[K?M00?o0000ojZ_fonZ[m/0
0_nZ[m/00ol0003oZjcIoj^/f@03oj^/f@03o`000?n[Z]KoZj[F00Co00000_nVY]H5ojFTe005o`00
0?nUX];oYJ;BojFRd_l000001?nTX=401Ol0003oY9k?ojBNconTW/oo000000CoY9c=00?o0000oj>J
c?nSV/`00_nSV/`01Ol0003oXiS:oj>Hb_nSV<[o000000CoXYO900?o0000oj:EaonRULL00_nRULL0
1Ol0003oXY?6oj:Ca_nRTlKo000000?oXI;500?o0000oj6A`onQTL<00_nQTL<00ol0003oXHo2oj6?
`P02oj6?`P05o`000?nPS/7oX8k1oj2>`Ol000001?nPSL000ol0003oooooooooo`08ooooo`?o0000
5_ooool00ol0003oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`15ooooo`04o`000?oT
i=;oi>CBo`0000?ohnCC00?o0000on7SeOoQhmD00ol00002omoReP04o`000?oNh]Sog^;Ho`0000Co
g>7I00Co0000om[Pf_oJh=[o00001?oHgm`01Ol0003oe]kMomKNgOoFg]go000000;oe=gN00Go0000
om;Kh?oBfn3od]_Po`000004oloJh@05o`000?o=fN;ocMWRolgIh_l000000oo:en<01Ol0003ob=GT
olSEi?o8eNCo000000?oaM?U00?o0000ol;Bi_o2d^H00_o2d^H01Ol0003o_m3Woko@ionod>Oo0000
00;o_<kX0_l000000onlb^Go0000okW8iP03okW8iP;o00001?nea>D01Ol0003o/l7Tok?1i?nc`NCo
000000?o/KcR00?o0000ojjihOn^^N400_n^^N402?l0003o[;KPo`000?l0003o[K?Mo`000?nZ/Mgo
00001OnZ[m/00ol0003oZjcIoj^/f@02oj^/f@?o00000_nVZ=P5ojJVePCoYJCD00?o0000ojFRd_nU
X]800_nUX]801Ol0003oY:3AojBPdOnTX=7o000000?oY9k?00?o0000ojBLcOnTW<d00onTW<d01Ol0
003oXi[<oj>Jc?nSV/co000000?oXiS:00?o0000oj:GbOnRUlT00_nRUlT00ol0003oXYG7oj:Ea`02
oj:Ea`05o`000?nRTlKoXY?6oj:Ca_l000001?nQT/D01?l0003oXI73oj6A`onQTL<2o`0000?oXHo2
00?o0000oj2>`OnPS/400_nPS/400ol0003oX8g0oj2=`002oj2=`003o`000?oooooooooo00?ooooo
1?l0000Iooooo`03o`000?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo04Cooooo00Go
0000onCTd_oTi=;oi>CBo`000002on?Td`Go00001?oOh]H01?l0003og^;HomkRf?l00003omcQf@05
o`000?oJh=[of^3Jom[Pf_l000000ooHgm`01Ol0003oe]kMomKNgOoFg]go000000;oe=gN00Go0000
om;Kh?oBfn3od]_Po`000004oloJh@05o`000?o=fN;ocMWRolgIh_l000000oo:en<01Ol0003ob=GT
olSEi?o8eNCo000000?oaM?U00?o0000ol;Bi_o2d^H00_o2d^H01Ol0003o_m3Woko@ionod>Oo0000
00Co_<kX1?l000000onib>Ko0000o`000002okK7i`03o`000?nea>Go]LCU00Wo000000Go[[WQo`00
0?n^^N7o[[WQo`000004ojbfh005o`000?nZ/MgoZ[7MojZagOl000001OnZ[m/01_l0003oZjcIo`00
0?l0003oYZ_Jo`0000CoYZSH1?nVY]H00ol0003oYJCDojFTe002ojFTe005o`000?nUX];oYJ;BojFR
d_l000001?nTX=401Ol0003oY9k?ojBNconTW/oo000000CoY9c=00Go0000oj>Jc?nSV/coXi[<o`00
0004oj>HbP05o`000?nRUlWoXYO9oj:GbOl000001?nRULL01Ol0003oXY?6oj:Ca_nRTlKo000000Co
XI;500?o0000oj6A`onQTL<00_nQTL<01Ol0003oXHo2oj6?`_nQSl;o000000CoX8k100?o0000oj2=
`?nPSL000_nPSL000ol0003oooooooooo`03o`0001gooooo00?o0000ooooooooool04Oooool002;o
oooo00?o0000ooooooooool0@oooool01_l0003oi>CBonCTd_oTi=;o0000on?Td`?o00000ooQhmD0
1Ol0003ogn;FomoRe_oOh]Ko000000;og^;H00Go0000omcQfOoLhMWog>7Io`000003om[PfP03o`00
0?oHgmcof=oL00;of=oL00?o0000omKNgOoFg]d07ol00002ol;BiP05o`000?nod>Oo_m3Woko@iol0
00001?nlc^P00ol0003o^<_XokS;j002okS;j0;o00000onfanL3o`000003ok;3iol0003o/L7V00;o
/L7V00Co0000ojnniOn__^Go00000_n]^n@2o`0000?o[;KP00?o0000ojVdh?l000001?nZ/Md01?l0
003oZZoKojZ_fonZ[m/3o`0000?oYZ_J00?o0000ojJXf?nVZ=P00_nVZ=P01Ol0003oYZKFojJVe_nV
Y]Ko000000CoYJCD00Go0000ojFRd_nUX];oYJ;Bo`000004ojBPd@05o`000?nTW/ooY9k?ojBNcol0
00001?nTW<d00ol0003oXi[<oj>Jc002oj>Jc005o`000?nSV<[oXiS:oj>Hb_l000000onRUlT00ol0
003oXYG7oj:Ea`02oj:Ea`03o`000?nRTlKoXY?600;oXY?600Go0000oj6BaOnQT/GoXI;5o`000004
oj6A``;o00000onQSl801Ol0003oX8k1oj2>`OnPS/7o000000CoX8g00ol0000Pooooo`03o`000?oo
oooooooo017ooooo000Qooooo`04o`000?oooooo0000o`0004?ooooo00?o0000onCTd_oTi=800ol0
00000ooSi=?o0000on7Se@02on7Se@05o`000?oOh]Kogn;FomoRe_l000000_oNh]P00ol0003og>7I
omcQf@02omcQf@04o`000?oJh=[of^3Jo`0000Cof=oL1Ol00002om3ViP05o`000?o>i>Ooc^CWolkT
iol000001?o<h^P01Ol0003obN3YolWPjOo9h>Wo000000?oa]kZ00Go0000olCKjoo4fn_oa=_[o`00
0003ol7Ij`03o`000?nne^_o_]K[00So00000_nlc^P00ol0003o^<_XokS;j002okS;j008o`000?ne
bNWo]LWYo`000?nfanOo0000ok;5j?l00003ok;3i`06o`000?na`NKo/L7Vo`000?n__^Go00000on]
^n@01Ol0003oZkSSo`000?n/]^3o000000?oZKCP00?o0000ojZagOnZ/Md01Ol00002ojN^g003o`00
0?nVZm[oYZ_J00;oYZ_J00Go0000ojJXf?nVZ=SoYZSHo`000004ojJVeP05o`000?nUY=CoYJCDojFT
e?l000001?nUX]801Ol0003oY:3AojBPdOnTX=7o000000?oY9k?00?o0000ojBLcOnTW<d00_nTW<d0
0ol0003oXi[<oj>Jc002oj>Jc005o`000?nSV<[oXiS:oj>Hb_l000001?nRUlT00ol0003oXYG7oj:E
a`02oj:Ea`05o`000?nRTlKoXY?6oj:Ca_l000000onQT/D00ol0003oXI73oj6A``02oj6A``;o0000
0onQSl800ol0003oX8k1oj2>`@02oj2>`@05o`000?nPSL3oX8g0oj2=`?l000008_ooool00ol0003o
ooooooooo`0Aooooo`008Oooool2o`0004Cooooo1Ol00003on?Td`04o`000?oQhmGohN?Eo`0000Co
gn;F00Co0000omkRf?oNh]So00000ooLhMT:o`0000;od^SU00Co0000om3Vi_o@i^Ko00000oo>i>L0
0ol0003oc>;XolcRj002olcRj005o`000?o9h>WobN3YolWPjOl000000oo6g^X01Ol0003oa=_[olCK
joo4fn_o000000?o`MW[00?o0000okkFjonne^/00_nne^/01Ol0003o^m?/ok_Ck?nkdnco000000;o
^M7/1?l00002okS;j003o`000?nebNWo]LWY00;o]LWY0_l00002ok;5j003o`000?nb`nOo000000Oo
000000?o[K_To`000?n[^><00_n[^><00ol0003oZKCPojVdh003ojVdh0;o00000_nW/=l00ol0003o
YjkLojN^g003ojN^g005o`000?nVZm[oYZ_JojJ[f_l000001?nVZ=P01Ol0003oYZKFojJVe_nVY]Ko
000000CoYJCD00Go0000ojFRd_nUX];oYJ;Bo`000004ojBPd@05o`000?nTW/ooY9k?ojBNcol00000
1?nTW<d01Ol0003oXi[<oj>Jc?nSV/co000000?oXiS:00?o0000oj:GbOnRUlT00_nRUlT00ol0003o
XYG7oj:Ea`02oj:Ea`05o`000?nRTlKoXY?6oj:Ca_l000001?nQT/D00ol0003oXI73oj6A``02oj6A
``;o00000_nQSl800ol0003oX8k1oj2>`@02oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`11
ooooo`?o00000_oTi=801Ol0003ohnCCon?TdooSi=?o000000?ohN?E00Go0000omoRe_oOh]Kogn;F
o`000002omkRf003o`000?oLhMWo000000?o00000_oFjn<00ol0003oe>[TomCZi002omCZi004o`00
0?oBj>God^SUo`0000?od>KV00Go0000olkTioo>i>Ooc^CWo`000003olcRj005o`000?o9h>WobN3Y
olWPjOl000000oo6g^X00ol0003oa=_[olCKj`02olCKj`04o`000?o1fN_o`MW[o`0000Co_]K[00Go
0000ok_Ck?nkdnco^m?/o`000004okWAk003o`000?nfc^co]/k/00Co00000_nebNT01Ol0003o//KY
ok;6jOl0003o//GX00;o000000Wo[l;Xo`000?n^`NSo[/7Xo`000?n/_nOo0000oj^li_l000000_n[
^><01Ol0003oZKOSojVghol0003oZKCP00;o000000?oYk?Qo`000?nW/=l00onW/=l00ol0003oYjkL
ojN^g002ojN^g005o`000?nVZm[oYZ_JojJ[f_l000001?nVZ=P01Ol0003oYZKFojJVe_nVY]Ko0000
00CoYJCD00Go0000ojFRd_nUX];oYJ;Bo`000004ojBPd@05o`000?nTW/ooY9k?ojBNcol000001?nT
W<d00ol0003oXi[<oj>Jc002oj>Jc005o`000?nSV<[oXiS:oj>Hb_l000000onRUlT00ol0003oXYG7
oj:Ea`02oj:Ea`05o`000?nRTlKoXY?6oj:Ca_l000001?nQT/D00ol0003oXI73oj6A``02oj6A``05
o`000?nQSl;o0000oj6?`_l000001?nPS/400ol0003oX8g0oj2=`002oj2=`003o`000?oooooooooo
023ooooo00?o0000ooooooooool04?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03kooooo0ol000000ooo
oooo0000onCTdP02onCTdP04o`000?oSi=?ohnCCo`0000?ohN?E00?o0000omoRe_oOh]H00_oOh]H5
o`0000;of>gR00Co0000omK[hooFjn?o00001?oDj^@01Ol0003od^SUom;XiOoBj>Go000000;od>KV
00Go0000olkTioo>i>Ooc^CWo`000004olcRj005o`000?o9h>WobN3YolWPjOl000000_o6g^X00ol0
003oa=_[olCKj`02olCKj`05o`000?o1fN_o`MW[ol7Ijol000000onne^/01Ol0003o^m?/ok_Ck?nk
dnco000000Co^M7/00?o0000okK>k?nfc^`00_nfc^`00ol0003o/l_/ok?;k004o`0000;o//KY0_l0
00002On_`nWo0000ojo2j?l0003o[/7Xo`000?n/_nOoZkcVo`000002ojVkiP03o`000?nY]n?oZKOS
00;oZKOS00?o0000ojNchOnW/n400_nW/n401Ol0003oYk3OojN`gonW/=oo000000CoYjkL00?o0000
ojJ[f_nVZmX00_nVZmX01Ol0003oYZSHojJXf?nVZ=So000000CoYZKF00Go0000ojFTe?nUY=CoYJCD
o`000004ojFRdP05o`000?nTX=7oY:3AojBPdOl000000onTW/l00ol0003oY9c=ojBLc@02ojBLc@03
o`000?nSV/coXi[<00;oXi[<00Go0000oj>Hb_nSV<[oXiS:o`000004oj:Gb@05o`000?nRULOoXYG7
oj:Eaol000001?nRTlH01Ol0003oXI;5oj6BaOnQT/Go000000CoXI7300Ko0000oj6?`_nQSl;o0000
oj6?`_l00003oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0@ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0kooooo`?o00000oooool01Ol0003oi>CBonCTd_oTi=;o0000
00?ohnCC00Go0000on7SeOoQhmGohN?Eo`000003omoReP;o000000?of^kPo`000?oHkN800_oHkN80
1Ol0003oe^_SomK[hooFjn?o000000Coe>[T00Co0000om;XiOoBj>Go00000oo@i^H01Ol0003oc^CW
olkTioo>i>Oo000000?oc>;X00Go0000olWPjOo9h>WobN3Yo`000003olKNjP05o`000?o4fn_oa=_[
olCKjol000000oo1fN/00ol0003o_]K[okkFj`02okkFj`06o`000?nkdnco^m?/ok_Ck?l0003o^M7/
1Ol00002okK>k005o`000?ncbnco/l_/ok?;k?l000000on`b>`5o`000003ojo3jOl0003o000000Co
000000CoZK_Vo`000?nX^NKoZ;WV0_l00003ojNfi005o`000?nW/n7oYk?QojNchOl000000_nW/=lU
o`000003ojBNcol0003oY9c=00?oY9c=00Go0000oj>Jc?nSV/coXi[<o`000003oj>HbP03o`000?nR
UlWoXYO900;oXYO900?o0000oj:EaonRULL00_nRULL01Ol0003oXY?6oj:Ca_nRTlKo000000?oXI;5
00?o0000oj6A`onQTL<00_nQTL<01_l0003oXHo2oj6?`_l0003oXHo2o`0000CoX8k100Go0000oj2=
`?nPSL3oX8g0o`00000Rooooo`03o`000?oooooooooo013ooooo0007ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`;o0000>Oooool3o`0000Kooooo00Go0000
onCTd_oTi=;oi>CBo`000002on?Td`06o`000?oQhmGohN?Eon7SeOl0003ogn;F0ol00002om[^h003
o`000?oHkN;of>gR00;of>gR00Co0000omK[hooFjn?o00001?oDj^@01?l0003od^SUom;XiOl00003
om3ViP05o`000?o>i>Ooc^CWolkTiol000000oo<h^P00ol0003obN3YolWPj@02olWPj@04o`000?o6
g^[oa]kZo`0000Coa=_[3ol00002ok?Cl@03o`000?nad?3o/M3`00go000000?o[LC[o`000?l00000
0_l000000on[`N[o0000o`000002o`000004ojRii_nW^NKoYkWVojNiiP?o00000_nW]^@6o`0000;o
Xk3Q00?o0000oj:]gonR[Ml00_nR[Ml4oj6[gPGoX:SL1?nOYMX5oijSf0CoWJ3G1OnLW]D3oi^Ld`[o
000000?oXi[<o`000?nSV<X00_nSV<X01Ol0003oXYO9oj:GbOnRUlWo000000CoXYG700Go0000oj:C
a_nRTlKoXY?6o`000004oj6Ba@03o`000?nQTL?oXI7300;oXI7300?o0000oj6?`_nQSl800_l00004
oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000ooooooooool07oooool00ol0003oooooooooo`0@
ooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c003ooooo`03o`000?oooooooooo03Kooooo0ol00008ooooo`05o`000?oTi=;oi>CBonCTd_l00000
0ooSi=<00ol0003ohN?Eo`000003o`0000;og>oN00Co0000om[^h?oJk^3o00000ooHkN801Ol0003o
e^_SomK[hooFjn?o000000Coe>[T00Co0000om;XiOoBj>Go00000oo@i^H01Ol0003oc^CWolkTioo>
i>Oo000000?oc>;X00Co0000olWPjOo9h>WobN3Y2_l00002okWMlP03o`000?ngf_;o]m[b00;o]m[b
00Go0000okGGlOneeo7o]MOao`000004ok?Cl@05o`000?nad?3o/M3`ok7@l?l000000on_c>l00ol0
003o[LW^ojg9kP02ojg9kP03o`000?nZaNgo000000co00000_nV^^L00ol0003oYKOUojFgi@02ojFg
i@05o`000?nT/n?oY;?SojBchol000000onS/>400ol0003oXZgOoj:]g`02oj:]g`05o`000?nQZmko
XJ_Noj6[g_l000001?nPZ=`01Ol0003oWjGJoinUf_nOYM[o000000CoWZ?H00Go0000oifPeonMX=Oo
WJ3Go`000004oibNe@04o`000?nKW=?oVicCoi^Ld`GoVYWB1?nIUm09o`000003oj:GbOl0003oXYG7
00;oXYG700Go0000oj:Ca_nRTlKoXY?6o`000004oj6Ba@03o`000?nQTL?oXI7300;oXI7300Co0000
oj6?`_nQSl;oXHo20_l00003oj2>`@03o`000?nPSL3oX8g000;oX8g000?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0@ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`?o00002oooool01?l0003oi>CBonCT
d_oTi=83on?Td`?o000000?ogO3Mo`000?oLkmh00_oLkmh01?l0003of^kPom[^h?l00004omS]hP04
o`000?oFjn?oe^_So`0000Coe>[T00Co0000om;XiOoBj>Go00000oo@i^H01Ol0003oc^CWolkTioo>
i>Oo000000?oc>;X00?o0000olWPjOl000000ol00002okgTlP03o`000?nkhO;o^n7b00;o^n7b00Go
0000okWMl_nigO;o^Mgbo`000004okOJlP04o`000?neeo7o]MOao`0000Co/m?a00?o0000ok7@l?l0
00003Ol00002ojS6k`?o000000?oYl?]o`000?l000001_l000000onV^^Oo0000o`000006o`000003
ojBchol0003oXk3Q00?oXk3Q00Go0000oj:]gonR[MooXZgOo`000003oj6[gP03o`000?nPZ=coX:SL
00;oX:SL00Go0000oinUf_nOYM[oWjGJo`000004oijSf005o`000?nMX=OoWJ3GoifPeol000001?nL
W]D01Ol0003oVicCoi^LdonKW=?o000000CoVYWB00?o0000oiVGd?nIUm000_nIUm04oiREc`CoV9?>
1Ol000000onRULOo0000oj:CaP02oj:CaP05o`000?nQT/GoXI;5oj6BaOl000001?nQTL<00ol0003o
XHo2oj6?`P02oj6?`P05o`000?nPS/7oX8k1oj2>`Ol000001?nPSL000ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo013ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo037ooooo0_l0000=ooooo`04o`000?oTi=;oi>CB
onCTdPCo00000ooMl=d00ol0003og>oNomc_gP02omc_gP04o`000?oJk^3of^kPo`0000?of>gR00Go
0000omK[hooFjn?oe^_So`000003omCZi005o`000?oBj>God^SUom;XiOl000000oo@i^H01?l0003o
c^CWolkTioo>i>L6o`0000;o_nOb00Go0000okgTl_nmi?;o_NCbo`000004ok_QlP04o`000?nigO;o
^Mgbo`0000Co]m[b00?o0000okGGlOl000002?l00002oj_Am003o`000?nZc_?oZ/kc00;oZ/kc00Go
0000ojW:lOnYb_7o0000ojW:l@02o`0000?oYlO`00?o0000ojO3kOl000000ol000001_nS_^go0000
o`000?l0003oX[_[ojBjj@;o00000onR]nL00ol0003oX;CVoj2diP09o`000003oj:]gol0003oXJ_N
00?oXJ_N00?o0000oj2Xg?nPZ=`00_nPZ=`01?l0003oWjGJoinUf_l00004oijSf005o`000?nMX=Oo
WJ3GoifPeol000001?nLW]D01Ol0003oVicCoi^LdonKW=?o000000CoVYWB00?o0000oiVGd?nIUm00
0_nIUm04oiREc`GoV9?>1?nGT/`9o`000003oj6BaOl0003oXI7300;oXI7300?o0000oj6?`_nQSl80
0_nQSl800ol0003oX8k1oj2>`@02oj2>`@05o`000?nPSL3oX8g0oj2=`?l000008Oooool00ol0003o
ooooooooo`0@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`03
o`000?oooooooooo02kooooo0ol0000>ooooo`03o`000?oTi=;oi>CB00?o00000_oOlM`01Ol0003o
gO3Momg`gOoMl=go000000?og>oN00Co0000om[^h?oJk^3o00001?oHkN801?l0003oe^_SomK[hol0
0004omCZi004o`000?oBj>God^SUo`0000?od>KV00?o0000olkTioo>i>L00ol00002ol7Yl@03o`00
0?noio;o_nOb00;o_nOb00Go0000okgTl_nmi?;o_NCbo`000003ok_QlP05o`000?nigO;o^MgbokWM
l_l000000_ngf_84o`0000;o[=Wg00?o0000ojcEm_n/eOH00_n/eOH01Ol0003oZm7doj_Am?l0003o
Zm7d00Oo00000onVbo<3o`0000;oYLG`1_l00002oinlk@04oj2lk?l0003o0000o`0000;oWkSZ0ol0
0003oj2diP03o`000?nN/NGoW[7U00;oW[7U00?o0000oib^honL[^<01Ol000000onQZmko0000oj2X
g003oj2Xg005o`000?nOYM[oWjGJoinUf_l000000onNXmP01Ol0003oWJ3GoifPeonMX=Oo000000Co
W9kE00Go0000oi^LdonKW=?oVicCo`000004oiZIdP03o`000?nIUm3oVIO@00;oVIO@00Go0000oiRE
conHULooV9G?o`000004oiRCcPGoUi;<1?nFT</4oiF>b@Go000000?oXI73o`000?nQSl800_nQSl82
o`0000?oX8k100?o0000oj2=`?nPSL000_nPSL000ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00oooooo000Pooooo`;o0000;?ooool3o`00017ooooo0ol000001OoPl][o0000omoag?oOlMco
000000?ogO3M00?o0000omc_g_oLkmh00_oLkmh01?l0003of^kPom[^h?l00003omS]hP05o`000?oF
jn?oe^_SomK[hol000000ooDj^@01?l0003od^SUom;XiOl00004om3ViP?o000000?o`^cao`000?o1
jO400_o1jO400ol0003o_nObokoWlP02okoWlP04o`000?nmi?;o_NCbo`0000Co^n7b00?o0000okWM
l_l000001?l00002ojcMn003o`000?n/fOOo[=Wg00;o[=Wg00?o0000ojcEm_n/eOH01?l00003ojCB
n003o`000?nUc_GoYLke00;oYLke0_l00003ojC:m005o`000?nUaO3oYLG`o`000?nS`o000_l00000
1OnP_nko0000oinmk_l0003oWkc]00;o00000_nL^>`01Ol0003oWkSZoinhj_l0003oW;CY00;o0000
00?oX;CVo`000?nN/ND00onN/ND01Ol0003oW:kSoib^honL[^?o000000?oVZ_R1Ol000000onPZ=co
0000oinUfP02oinUfP03o`000?nNXmSoWZ?H00;oWZ?H00Go0000oifPeonMX=OoWJ3Go`000003oibN
e@05o`000?nKW=?oVicCoi^Ldol000001?nJVM800ol0003oVIO@oiVGd002oiVGd005o`000?nHULoo
V9G?oiREcol000001?nHTlh00ol0003oUi;<oiNBc002oiNBc0CoUY3;1OnES/T4oiF=b0Go000000?o
XHo2o`000?l000000_nPS/400ol0003oX8g0oj2=`002oj2=`003o`000?oooooooooo01oooooo00?o
0000ooooooooool03oooool0023ooooo00?o0000ooooooooool0:?ooool3o`0001?ooooo00Go0000
on3bf_oPl][oh?;Jo`000003omoag005o`000?oMl=gogO3Momg`gOl000000ooLkmh01?l0003of^kP
om[^h?l00004omS]hP05o`000?oFjn?oe^_SomK[hol000000ooDj^@01Ol0003od^SUom;XiOl0003o
d>KV00?o00001?o2k?401Ol0003o`NWaol7YlOo1jO7o000000?o_nOb00Go0000okgTl_nmi?;o_NCb
o`000002ok_QlPCo00000_n/h?T00ol0003o[=ghojcMn002ojcMn004o`000?n/fOOo[=WgojcIm`Co
00000_nSe_X00ol0003oY=;hojCBn003ojCBn0;o00000onQc_L00ol0003oY<[do`000003oj;8m0[o
00000onK^Nh2oibhk0?o00001?nL]>T3o`000003oijaiOl0003oW:kS00?oW:kS00?o0000oiZ[h_nJ
Zn800_nJZn801?l0003oV:OQoiRWhOnHYn44o`000003oinUf_l0003oWZ?H00?oWZ?H00Go0000oifP
eonMX=OoWJ3Go`000004oibNe@04o`000?nKW=?oVicCo`0000CoVYWB00?o0000oiVGd?nIUm000_nI
Um001Ol0003oV9G?oiREconHULoo000000CoV9?>00?o0000oiNBc?nGT/`00_nGT/`01Ol0003oUY3;
oiJ@bonFT<_o000000CoUHk91OnESLP4oiB;a`Go000000?oX8k1o`000?nPSL000_nPSL000ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00oooooo000Oooooo`03o`000?oooooooooo02Kooooo
0ol0000Fooooo`05o`000?oPl][oh?;Jon3bf_l000000_oOlM`01Ol0003ogO3Momg`gOoMl=go0000
00Cog>oN00Co0000om[^h?oJk^3o00000ooHkN801Ol0003oe^_SomK[hooFjn?o000000?oe>[T00?o
0000om;XiOl000000ol00002olC_l005o`000?o2k?7o`^caol;/lOl000000oo1jO400ol0003o_nOb
okoWlP02okoWlP03o`000?nmi?;o_NCb00Co00000_n/i?T00ol0003o[>3iojcPn@02ojcPn@03o`00
0?n/gOSo[=gh00;o[=gh0ol00002oj7In`03o`000?nSe_[oXmKj00;oXmKj00Co0000ojCBn?l0003o
00000onNdOT01Ol0003oXLkgoj7>monQc_Oo000000;oX/Sd00Oo0000oj35lonPaO?oX<Gco`000?nN
`_;o000000;oW;k`00Co0000oiZkkonJ^noo00000_nK^Nh2o`0000?oV;G/00Co0000oibdjOnL]>Wo
00000onI/NP3o`0000;oW:kS00?o0000oiZ[h_nJZn800_nJZn800ol0003oV:OQoiRWh@03oiRWh@03
o`000?nFY=ooUZCO00?o00000onNXmP01Ol0003oWJ3GoifPeonMX=Oo000000CoW9kE00Co0000oi^L
donKW=?o00001?nJVM800ol0003oVIO@oiVGd002oiVGd005o`000?nHULooV9G?oiREcol000001?nH
Tlh00ol0003oUi;<oiNBc002oiNBc005o`000?nFT<_oUY3;oiJ@bol000001?nES/T00ol0003oUHg8
oiF=b002oiF=b0GoU8_70_nCRLH00ol0003oThW6o`000002o`0000;oX8g000?o0000ooooooooool0
7oooool00ol0003oooooooooo`0?ooooo`007oooool00ol0003oooooooooo`0Sooooo`?o00006?oo
ool01Ol0003oh?;Jon3bf_oPl][o000000?ogo7L00Go0000omg`gOoMl=gogO3Mo`000003omc_gP05
o`000?oJk^3of^kPom[^h?l000000ooHkN801Ol0003oe^_SomK[hooFjn?o000000?oe>[T0_l00000
0oo5lNoo0000olC_l003olC_l005o`000?o2k?7o`^caol;/lOl000000oo1jO400ol0003o_nObokoW
lP02okoWlP?o000000?o[>Ojo`000?n/i?T00on/i?T00ol0003o[>3iojcPn@02ojcPn@03o`000?n/
gOSo[=gh00?o00001OnQfO/01_l0003oXmKjoj?Fn_l0003oXmKjo`0000KoW]7i0_l00003oik;m`So
00000onL__000ol0003oV[__o`000002o`0000;oU[O^00Co0000oiRek?nH]NcoV;G/0ol00003oiVa
j006o`000?nF[^OoUZkWo`000?nL[^?o00001?nJZn800ol0003oV:OQoiRWh@02oiRWh@03o`000?nF
Y=ooUZCO00;oUZCO0_nDX]d2o`000003oijSf?l0003oWJ3G00;oWJ3G00?o0000oibNeOnLW]D00_nL
W]D01Ol0003oVicCoi^LdonKW=?o000000CoVYWB00Go0000oiVGd?nIUm3oVIO@o`000003oiREc`03
o`000?nHTlkoV9?>00;oV9?>00?o0000oiNBc?nGT/`00_nGT/`01Ol0003oUY3;oiJ@bonFT<_o0000
00CoUHk900?o0000oiF=b?nESLP00_nESLP5oiB;a`?oThW600Co0000oi>9a_nCR<GoThS50_l00000
0onPSL3o0000ooooo`0Oooooo`03o`000?oooooooooo00oooooo000Oooooo`03o`000?oooooooooo
023ooooo0ol0000Kooooo`05o`000?oPl][oh?;Jon3bf_l000000ooOlM`01?l0003ogO3Momg`gOl0
0003omc_gP05o`000?oJk^3of^kPom[^h?l000000ooHkN801Ol0003oe^_SomK[hooFjn?o000000;o
e>[T0_l00003olGak`03o`000?o4ko3oa>o`00;oa>o`00Go0000ol;/lOo2k?7o`^cao`000003ol7Y
l@03o`000?noio;o_nOb00?o00001?n/ioX00ol0003o[>CiojcTn@02ojcTn@03o`000?n/h?Wo[>3i
00Co00001?nNgOd00ol0003oXMWkoj7In`02oj7In`;o00001OnKe?`2o`0000GoV/kj00?o0000oic7
m_nLaoH00_nLaoH01?l0003oVL;doiW2m?nI`_@6o`000003oiJil?l0003oU[O^00?oU[O^00?o0000
oiRek?l000000onD/^`00ol0003oVK7Xo`000005oiJ^i`?o00000_nJZn800ol0003oV:OQoiRWh@02
oiRWh@03o`000?nFY=ooUZCO00;oUZCO1OnDX]d3o`000003oifPeol0003oW9kE00?oW9kE00Go0000
oi^LdonKW=?oVicCo`000004oiZIdP05o`000?nIUm3oVIO@oiVGd?l000000onHULl00ol0003oV9?>
oiRCcP02oiRCcP03o`000?nGT/coUi;<00;oUi;<00Go0000oiJ@bonFT<_oUY3;o`000004oiF>b@03
o`000?nESLSoUHg800;oUHg800?o0000oiB;aonDRlL00_nDRlL4oi>9aP03o`000?nCR<GoThS500?o
ThS500?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`007oooool3o`0001gooooo
0ol0000Mooooo`05o`000?oPl][oh?;Jon3bf_l000000ooOlM`01Ol0003ogO3Momg`gOoMl=go0000
00?og>oN00Go0000om[^h?oJk^3of^kPo`000003omS]hP04o`000?oFjn?oe^_SomK[h`?o000000?o
a_?^o`000?o5lNl00_o5lNl01Ol0003oa>o`olC_l?o4ko3o000000Co`^ca00?o0000ol7YlOo1jO40
1?l00002oj_Zn@03o`000?n/io[o[>Oj00;o[>Oj00?o0000ojcTnOn/i?T01Ol00004oi_Oo@03o`00
0?nNgOgoW]gm00;oW]gm0_l00004oiKGoP;o000000?oVmClo`000?nEd?`00_nEd?`3o`000003oi[>
n_l0003oUlWi00;oUlWi0_l00002oiW2m003o`000?nI`_Co000000?oUkgb00Go0000oiJil?nF^O3o
U[W`o`000002oiJgkPCo00000onD/^`3o`0000CoUZkW00Co0000oi>[i_nCZnKoTj_V0ol00004oiRW
h@05o`000?nFY=ooUZCOoiJTgol000001OnDX]d3oi>Og0?o00000onLW]D01Ol0003oVicCoi^LdonK
W=?o000000CoVYWB00?o0000oiVGd?nIUm000_nIUm001?l0003oV9G?oiREcol00004oiRCcP03o`00
0?nGT/coUi;<00;oUi;<00?o0000oiJ@bonFT</00_nFT</4oiF>b@03o`000?nESLSoUHg800;oUHg8
00?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nCR<GoThS500;oThS5
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`007oooool00ol0003ooooooooo
o`0Jooooo`?o00008?ooool01Ol0003oh?;Jon3bf_oPl][o000000?ogo7L00Co0000omg`gOoMl=go
00000ooLkmh01Ol0003of^kPom[^h?oJk^3o000000?of>gR00?o0000omK[hooFjn<00_l00004olKc
kP05o`000?o5lNooaO7_olGakol000000oo4ko001?l0003o`^caol;/lOo2k?44o`000003oj[]nOl0
003oZn[i00CoZn[i00Co0000ojcWn_n/io[o[>Oj0ol00004oiORo@;o00001?nKgod2o`0000CoT=Wo
0ol00003oiKGoP03o`000?nEd?coUM3l00GoUM3l00Co0000oiO9nOnGbOWo00000_nGbOT01?l0003o
U<?goiC3monD`oL<o`0000CoTKC^00?o0000oiBbk?l000000on@[n/2o`000003oiJ^iol0003oTj_V
00CoTj_V00Ko0000oi2WiOl0003o0000oiRWhOl00004oiJTg`03o`000?nDX]goU:;M00;oU:;M00?o
0000oi>Og?nCWm`00_nCWm`2oi6Lf`;o000000?oW9kEo`000?nKW=<00_nKW=<00ol0003oVYWBoiZI
dP02oiZIdP03o`000?nIUm3oVIO@00;oVIO@00Go0000oiREconHULooV9G?o`000003oiRCcP03o`00
0?nGT/coUi;<00;oUi;<00?o0000oiJ@bonFT</00_nFT</01Ol0003oUHk9oiF>bOnES/Wo000000Co
UHg800?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nCR<GoThS500;o
ThS500?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003ooooo
ooooo`0Gooooo`?o00008oooool01Ol0003oh?;Jon3bf_oPl][o000000;ogo7L00Go0000omg`gOoM
l=gogO3Mo`000003omc_gP05o`000?oJk^3of^kPom[^h?l000000ooHkN83o`000003olOfk?l0003o
a_?^00;oa_?^00Go0000olGakoo5lNooaO7_o`000004olC_l003o`000?o2k?7o000000;o00001OnZ
kOT00ol0003oZn[ioj_Zn@02oj_Zn@04o`000?n/io[o0000o`0000?oT^Cl00?o0000oiORoOnGh_d0
0onGh_d00ol0003oVmomo`000004oh[Ko`?o00000on@fOl2o`0000GoS];n0ol00005oi7:n`;o0000
0_nD`oL01?l0003oU<?goiC3mol00004oi:lm003o`000?nA]o7oTKOa00;oTKOa00Co0000oi6dk_nA
]>koTKC^1?l00004oi2_j`?o00001?nCZnH00ol0003oT:OUoi2Wi@03oi2Wi@;o00000onFY=l00ol0
003oU:;MoiBRg@02oiBRg@03o`000?nCWmcoTioL00;oTioL1OnAW=/2o`0000;oVicC00?o0000oiZI
d_nJVM800_nJVM800ol0003oVIO@oiVGd002oiVGd005o`000?nHULooV9G?oiREcol000000onHTlh0
0ol0003oUi;<oiNBc002oiNBc003o`000?nFT<_oUY3;00;oUY3;00Go0000oiF>bOnES/WoUHk9o`00
0004oiF=b003o`000?nDRlOoU8_700;oU8_700?o0000oi>9a_nCRLH00_nCRLH2o`0000?oThS500?o
0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`007oooool00ol0003oooooooooo`0D
ooooo`?o00009Oooool01Ol0003oh?;Jon3bf_oPl][o000000?ogo7L00Go0000omg`gOoMl=gogO3M
o`000002omc_gP05o`000?oJk^3of^kPom[^h?l000000_oHkN82o`0000CoaoK/00Go0000olKck_o6
lnkoa_?^o`000003olGak`04o`000?o4ko3oa>o`olC_l0?o00000_nYkoL00ol0003oZ^gioj[]n@03
oj[]n@04o`000?n[j_WoZn[ioj_Zn@?o00001onBi?`01_l0003oUn;moiORoOl0003oUn;mo`0000So
R]_o0_l00004ohOCo`?o000000?oS];no`000?n:bod00on:bod3o`000003oi7:nol0003oS/?i00;o
S/?i4?l00004ohbak`04o`000?n@[n_o0000o`0000?oS:_[0_l000000onCZnKo0000oi2Wi@04oi2W
i@03o`000?n=Y>CoSJCT00?o00001?nDX]d00ol0003oTioLoi>Og002oi>Og003o`000?nAW=_oTIcK
00?oTIcK0_n?VMT3o`0000CoVYWB00?o0000oiVGd?nIUm000_nIUm001Ol0003oV9G?oiREconHULoo
000000CoV9?>00Go0000oiNBc?nGT/coUi;<o`000004oiJ@b`05o`000?nES/WoUHk9oiF>bOl00000
1?nESLP00ol0003oU8_7oiB;a`02oiB;a`03o`000?nCRLKoThW600;oThW600?o0000oi>8aOl00000
0_nCR<D00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oo
oooo000001;ooooo0ol0000Xooooo`05o`000?oPl][oh?;Jon3bf_l000000_oOlM`01Ol0003ogO3M
omg`gOoMl=go000000?og>oN00Co0000om[^h?oJk^3of^kP0ol000000oo8mn_o0000olOfk002olOf
k003o`000?o6lnkoa_?^00;oa_?^00Co0000olGakoo5lNooaO7_1?l000000onWlOGo0000ojW_m`03
ojW_m`03o`000?nZkOWoZ^gi00?oZ^gi0ol00004ohgUnP?o00001?nBi?`2o`0000KoP]_m1?l00004
oggCo`?o00000on7dol00ol0003oR/_moh[;o@06oh[;o@05o`000?n>`oWoS/?iohk3nOl000000_n>
`oT00ol0003oS;_fohbkmP03ohbkmP03o`000?n;]O;oRkGb00?oRkGb00Co0000ohbakon</NooS;7_
1Ol00005ohb[j`?o00001?n@YnD00ol0003oSJCTohfTi003ohfTi0;o00000onDX]d00ol0003oTioL
oi>Og002oi>Og003o`000?nAW=_oTIcK00;oTIcK00?o0000ohnIfOn?VMT00_n?VMT4o`000003oiZI
d_l0003oVIO@00?oVIO@00Go0000oiREconHULooV9G?o`000004oiRCcP03o`000?nGT/coUi;<00;o
Ui;<00Go0000oiJ@bonFT<_oUY3;o`000003oiF>b@03o`000?nESLSoUHg800;oUHg800?o0000oiB;
aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nCR<Go000000;oThS500?o0000oooo
ooooool07oooool00ol0003oooooooooo`0>ooooo`007_ooool2o`00013ooooo0ol0000Zooooo`05
o`000?oPl][oh?;Jon3bf_l000000ooOlM`01Ol0003ogO3Momg`gOoMl=go000000;og>oN00?o0000
om[^h?oJk^000_l00004olSgj`05o`000?o7m^coaoK/olOfk?l000001?o6lnh00ol0003oaO7_olGa
k`02o`0000GoYo7e00?o0000ojW_monYkoL00_nYkoL01?l0003oZ^gio`000?l00004ohKUm`?o0000
1?n=iOX2o`0000OoN=[j1?l00004og;Bo@?o00000ommdol2o`0000KoP/co1?l00005ohO3na;o0000
1On7[^l00ol0003oS:_[o`000002o`0000?oR:SZ0_l000000on@YnGo0000ohfTi004ohfTi003o`00
0?n:XN?oRZ7S00;o000000?oU:;Mo`000?nCWm`00onCWm`00ol0003oTIcKoi6Lf`02oi6Lf`03o`00
0?n?VMWoSiWI00;oSiWI1?n>UmP3o`0000?oVIO@00Go0000oiREconHULooV9G?o`000004oiRCcP03
o`000?nGT/coUi;<00;oUi;<00Go0000oiJ@bonFT<_oUY3;o`000003oiF>b@03o`000?nESLSoUHg8
00;oUHg800?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP06o`000?nCR<GoThS5
o`000?nCR<Go00008Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`0<
ooooo`?o0000;Oooool01Ol0003oh?;Jon3bf_oPl][o000000;ogo7L00Go0000omg`gOoMl=gogO3M
o`000003omc_gP?o000000?obOWYo`000?o8mn/00oo8mn/01Ol0003oaoK/olOfk?o7m^co000000?o
a_?^1?l000000onUl_?o0000ojOam@05ojOam@03o`000?nYkoOoZNog00?o00002On6iOL2o`0000Oo
K=Se1Ol00004ofK@n@Co00000ombd_d2o`0000OoN<_o1?l00005ogo2o0So00000_n6^_L00ol0003o
QK?cohFcl`04ohFcl`03o`000?n7[^ooQjk_00;oQjk_1?l00007ohRXjP;o00001On=Y>@00ol0003o
RZ7SohZQh`03ohZQh`;o00001?nCWm`00ol0003oTIcKoi6Lf`02oi6Lf`03o`000?n?VMWoSiWI00;o
SiWI1On>UmP2ohbDeP;o000000?oVIO@o`000?nHULl00_nHULl00ol0003oV9?>oiRCcP02oiRCcP03
o`000?nGT/coUi;<00;oUi;<00Go0000oiJ@bonFT<_oUY3;o`000003oiF>b@03o`000?nESLSoUHg8
00;oUHg800?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP04o`000?nCR<GoThS5
oi>8a@;o00008Oooool00ol0003oooooooooo`0>ooooo`007_ooool00ol0003oooooooooo`09oooo
o`?o0000;oooool01Ol0003oh?;Jon3bf_oPl][o000000?ogo7L00Ko0000omg`gOoMl=gogO3Mo`00
0?oLkmh2o`0000CobOWY00?o0000olSgjoo8mn/00_o8mn/01Ol0003oaoK/olOfk?o7m^co000000;o
a_?^0_l00005ojGbl`03o`000?nWlOGoYo7e00CoYo7e0_l00007ogoTlPCo00001omOdnh5o`0000Go
El_c0ol00004ofK@n@;o00001om]bOh4o`0000CoMl7n1Ol000000omo`_co0000ognhn003ognhn0ko
00001?n2Z^h00ol0003oR:SZohRXjP02ohRXjP;o00000_n3Y>T01Ol0003oSJCTohfTi?n=Y>Co0000
00GoRZ7S00?o0000ohNMh_n7WN800_l00002oi>Og005o`000?nAW=_oTIcKoi6Lfol000001?n?VMT0
0ol0003oSYOHohjGf003ohjGf0GoS9CF0_l00002oiREc`03o`000?nHTlkoV9?>00;oV9?>00?o0000
oiNBc?nGT/`00_nGT/`01Ol0003oUY3;oiJ@bonFT<_o000000?oUHk900?o0000oiF=b?nESLP00_nE
SLP00ol0003oU8_7oiB;a`02oiB;a`03o`000?nCRLKoThW600;oThW600?o0000oi>8aOnCR<D00_nC
R<D00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00kooooo000Nooooo`03o`000?oooooo
oooo00Kooooo0ol0000booooo`05o`000?oPl][oh?;Jon3bf_l000000_oOlM`01?l0003ogO3Momg`
gOoMl=d3o`000003ol[jiol0003obOWY00?obOWY00Go0000olSgjoo8mn_ob?O[o`000003olOfk0Co
00000_nRlo000ol0003oYO;cojGbl`03ojGbl`03o`000?nWlOGo000000;o00001?mfh^`3o`0000;o
OnCb0_l00007oe7=h`Go00002?m6`nT00ol0003oEl_coeO;l`02oeO;l`;o00001omOa_`5o`0000Co
KKon0ol00003ogO1oPOo00000_mo^?P00ol0003oOk3cogn`l`04ogn`l`03o`000?n2Z^koPZ[^00Ko
PZ[^00Co0000ohRXj_l0003o00001On3Y>T00ol0003oSJCTo`000005ohZQh`03o`000?n7WN;oQigR
00?oQigR0_l00004oi6Lf`03o`000?n?VMWoSiWI00;oSiWI00?o0000ohjGf?n>UmP00_n>UmP00ol0
003oS9CFohbDeP03ohbDeP;oRi;E00?o0000oiREcol000001?nHTlh00ol0003oUi;<oiNBc002oiNB
c005o`000?nFT<_oUY3;oiJ@bol000001?nES/T01Ol0003oUHg8oiF=b?nESLSo000000CoU8_700?o
0000oi>9a_nCRLH00_nCRLH00ol0003oThS5oi>8a@02oi>8a@03o`000?oooooooooo01oooooo00?o
0000ooooooooool03_ooool001kooooo0ol00003ooooo`?o0000=Oooool01?l0003oh?;Jon3bf_l0
0003omoag005o`000?oMl=gogO3Momg`gOl000000oo:n^L00ol0003obOWYolWij@02olWij@05o`00
0?o8mn_ob?O[olSgjol000000_o7m^`3o`0000GoX_?`00?o0000ojGblonUl_<00_nUl_<2o`0000[o
M^;/0_l00006oe7=h`Go00002?ld^M`6o`0000Go@;[_1?l000000omA`OOo0000o`000003o`0000Co
H[cm0ol00003offooPGo00000omg]_T8o`0000;oOk3c00?o0000oh:Zk_n2Z^h00_n2Z^h6o`0000Ko
PjCY0ol00004ohZQh`03o`000?n7WN;oQigR00CoQigR0ol00003oi6Lf`03o`000?n?VMWoSiWI00;o
SiWI00?o0000ohjGf?n>UmP00_n>UmP00ol0003oS9CFohbDeP03ohbDeP?oRi;E0_l00004oiRCcP03
o`000?nGT/coUi;<00;oUi;<00Go0000oiJ@bonFT<_oUY3;o`000004oiF>b@05o`000?nESLSoUHg8
oiF=b?l000001?nDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nCR<GoThS500;oThS50_l0000Q
ooooo`03o`000?oooooooooo00gooooo000Mooooo`;o00000_ooool3o`0003Oooooo00Go0000on3b
f_oPl][oh?;Jo`000003omoag004o`000?oMl=go0000o`0000Cob_[W00Go0000olWijOo9nNWobOWY
o`000004olSgj`03o`000?o7m^co000000?oWoC/00?o0000oj;cl?nRlo000onRlo001?l0003oYO;c
o`000?l00006ofcNi0Go00001Om1a=L3o`0000Oo3Ijk00Go0000oooooooooooooooooc800006o`28
]P;o1YO80_lJYMP4o`000003obj`iOm0^^oo@;[_00;o@;[_0ol00003oeFhn`Co00000omR_?d;o`00
0003ogNfnOl0003oNJgd00?oNJgd1ol00006ogfWkP03o`000?n3Y>WoPjCY00?o00000omoXNP2o`00
0003ohZQhol0003oQigR00GoQigR00Co0000ohBJhOn4V^7oQ9[Q0ol00004ohnIf@03o`000?n>UmSo
SYOH00?oSYOH00?o0000ohbDe_n<U=H00_n<U=H00ol0003oRi;Eoh^Be@02oh^Be@;o00000onHTlh0
0ol0003oUi;<oiNBc002oiNBc005o`000?nFT<_oUY3;oiJ@bol000001?nES/T00ol0003oUHg8oiF=
b002oiF=b005o`000?nDRlOoU8_7oiB;aol000001?nCRLH00ol0003oThS5oi>8a@02oi>8a@03o`00
0?oooooo0000023ooooo00?o0000ooooooooool03Oooool001Cooooo1?l000000ol@413ooooooooo
o`02ooooo`Co0000>_ooool01?l0003oh?;Jon3bf_l00003omoag0?o000000?ob_cUo`000?o:n^L0
0oo:n^L01Ol0003obOWYolWijOo9nNWo000000Cob?O[0_l00005oiodk003o`000?nRlo3oX_?`00;o
X_?`0_l00005ofcNi0Co00000_la^LP2o`0000;o8:bg1?lG00000ol0003oooooooooo`0Dooooo`03
o`000?l0R;Ko08Rf00Co000000Co6ZGHo`000?l0003o00000olg[?82o`0000CoEKSk1?l000000omR
_?go0000ofJ`nP02ofJ`nPco00000omi[O@00ol0003oOJO^ogfWkP03ogfWkPKo00001omoXNP3o`00
00GoQigR00?o0000ohBJhOn4V^400on4V^43o`0000?oSiWI00?o0000ohjGf?n>UmP00on>UmP00ol0
003oS9CFohbDeP02ohbDeP03o`000?n;T]GoRi;E00;oRi;E0_n9T=@4o`0000CoUi;<00Go0000oiJ@
bonFT<_oUY3;o`000004oiF>b@03o`000?nESLSoUHg800;oUHg800Go0000oiB;aonDRlOoU8_7o`00
0004oi>9aP03o`000?nCR<GoThS500;oThS500Co0000oooooooooooo00007oooool00ol0003ooooo
ooooo`0=ooooo`005_ooool00ol0003oooooooooo`04ooooo`;o0000>oooool01Ol0003oh?;Jon3b
f_oPl][o000000?ogo7L00Go0000ol[liOo:o>Gob_cUo`000004ol[ji`05o`000?o9nNWobOWYolWi
jOl000000oo8mn/3o`0000KoWoC/00Co0000oj;cl?l0003o00001_mRf=X2o`0000;o8:bg0ol00003
ooooo`03o`000?oooooooooo027ooooo00Oo07:jo`000?l2SMKo5IWRo`000?lWXn_o000000Co=jcb
1?l000000omE^?_o0000o`000003o`0000GoI[3j1_l000000ombZOCo0000o`000007o`0000CoMj?^
00?o0000ognQj?moXNP00omoXNP3o`0000?oNigW00Go0000ohNMh_n7WN;oQigRo`000005ohBJh@05
o`000?n1UmooPIOOoh6Ggol000000_n?VMT00ol0003oSYOHohjGf002ohjGf003o`000?n<U=KoS9CF
00?oS9CF00?o0000oh^BeOn;T]D00_n;T]D5ohV@e0;o00000onGT/`00ol0003oUY3;oiJ@b`02oiJ@
b`05o`000?nES/WoUHk9oiF>bOl000001?nESLP00ol0003oU8_7oiB;a`02oiB;a`05o`000?nCRLKo
ThW6oi>9a_l000001?nCR<D01?l0003oooooooooool0000Oooooo`03o`000?oooooooooo00gooooo
000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool01_l0003oh?;Jon3b
f_oPl][o0000omoag0;o00001?o:o>D01Ol0003ob_[Wol[jioo:n^Oo000000CobOWY1?l00003oicc
i`03o`000?nOm>coWoC/00?oWoC/0_l00002of;HfP;o00000_mGdLl3o`000003o`h00?oooooooooo
00Oooooo00?o0000ooooooooool09Oooool00ol0L[[o0000oaFIhP02o`000004obNSjol0003o0000
o`0000;o=jcb2ol000000omV/?[o0000of^Vm002of^Vm0Go000000?oLZWdo`000?mgXnh01omgXnh0
0ol0003oOj7Xo`000002o`0000OoNigW00?o0000ohNMh_l000001On4V^400ol0003oPIOOoh6Gg`03
oh6Gg`;o00001On>UmP00ol0003oS9CFohbDeP02ohbDeP03o`000?n;T]GoRi;E00;oRi;E00?o0000
ohV@e?n9T=@00on9T=@2ohR=dPCo00001?nFT</01Ol0003oUHk9oiF>bOnES/Wo000000CoUHg800?o
0000oiB;aonDRlL00_nDRlL01Ol0003oThW6oi>9a_nCRLKo000000CoThS500Go0000oooooooooooo
ooooo`00000Nooooo`03o`000?oooooooooo00gooooo000Fooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0=_ooool01?l0003oh?;Jon3bf_oPl]X3o`000003ol_mh_l0003ob_cU00?o
b_cU00Go0000ol[jioo:n^Oob_[Wo`000003olWij@?o00001_nLlnL00ol0003oWoC/o`000002o`00
00?oEm7?0_l00003o`h000kooooo00?o0000ooooooooool0:?ooool2o`000005o`:=e_l0003o0000
o`000?lWXn/02_l000000omL[O[o0000o`000004o`0000CoJjKd3Ol00008og^Mi`?o00001On4V^40
0ol0003oPIOOoh6Gg`04oh6Gg`?o00001?n>UmP00ol0003oS9CFohbDeP02ohbDeP03o`000?n;T]Go
Ri;E00;oRi;E00?o0000ohV@e?n9T=@00on9T=@5ohR=dP;o00000onFT</01Ol0003oUHk9oiF>bOnE
S/Wo000000CoUHg800?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP05o`000?nC
R<GoThS5oi>8aOl000001?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo
000Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool01Ol0003oh?;Jon3b
f_oPl][o000000?obogR00?o0000ol[liOo:o>D00_o:o>D01_l0003ob_[Wol[jioo:n^Oo0000olWi
j@;o00000onHl^<2o`0000CoW??W0_l000001OmGdLoo0000od_9`om;bL?o000000;o3P004oooool0
0ol0003oooooooooo`0Zoooooa;o00000omSX_<6o`000003of^Vm?l0003oLYo]00SoLYo]00?o0000
og^MiomkWNL01Ol00003ogNIiP05o`000?n4V^7oQ9[QohBJhOl000001_n1Uml01?l0003oOYCNogjD
g_mnU=h2o`0000;oSYOH00?o0000ohbDe_n<U=H00_n<U=H00ol0003oRi;Eoh^Be@02oh^Be@03o`00
0?n9T=CoRI3D00;oRI3D00?o0000ohR=d_n8SM800on8SM82ohJ;d@;o000000?oUY3;o`000?nES/T0
0_nES/T00ol0003oUHg8oiF=b002oiF=b003o`000?nDRlOoU8_700;oU8_700?o0000oi>9a_nCRLH0
0_nCRLH01Ol0003oThS5oi>8aOnCR<Go000000Gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0=ooooo`005_ooool00ol0003oooooooooo`09ooooo`;o0000=Oooool01?l0003oh?;J
o`000?l00004ol_mhP05o`000?o:o>Gob_cUol[liOl000001?o:n^L2o`0000OoV?;S00Co0000oicc
iol0003o00000_m;bL<01?lo`;Ko0000o`000?l>000Gooooo`03o`000?oooooooooo02cooooo2?l0
00000oljWOCo0000o`000008o`0000GoHj;c3_l00009ogNIiP03o`000?n4V^7o000000KoPIOO00?o
0000ogjDg_mnU=h01?mnU=h2o`0000CoS9CF00?o0000oh^BeOn;T]D00_n;T]D00ol0003oRI3DohV@
e003ohV@e003o`000?n8SM;oR8gB00;oR8gB00?o0000ohJ;dOn6Rm400_n6Rm42o`0000?oUHk900?o
0000oiF=b?nESLP00_nESLP00ol0003oU8_7oiB;a`02oiB;a`03o`000?nCRLKoThW600;oThW600?o
0000oi>8aOnCR<D00_nCR<D00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03?ooool001Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0a
ooooo`?o000000?obokPo`000?o;oN800oo;oN801Ol0003ob_cUol[liOo:o>Go000000?ob_[W1?l0
0006oiSbh`;o000000CoBlW3oco0]_l0003o00007?ooool00ol0003oooooooooo`0^ooooo`So0000
00?o>Ygdo`000?l000003?l000000omSX_?o0000ofbLk@08ofbLk@03o`000?mgVNKoMiWV00KoMiWV
1?l00005oh6Gg`03o`000?mnU=koOYCN00GoOYCN0ol00003ohbDeP03o`000?n;T]GoRi;E00;oRi;E
00?o0000ohV@e?n9T=@00on9T=@00ol0003oR8gBohR=dP02ohR=dP03o`000?n6Rm7oQX_A00?oQX_A
0_l00002oiF>b@03o`000?nESLSoUHg800;oUHg800?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6
oi>9aP02oi>9aP03o`000?nCR<GoThS500;oThS500?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00cooooo000Dooooo`03oeEEEOmVIVKo000000kooooo00?o
0000ooooooooool0<?ooool01Ol0003obokPol_nh?o;o^3o000000CobogR00Ko0000ol[liOo:o>Go
b_cUo`000?o:n^L2o`0000CoTo7M0ol000001?nHl^?o0000o`000?lo`;H2o`00023ooooo00?o0000
ooooooooool0:_ooool3o`0000?ooooo2?l00002ocZMm0So00000_mKW_<9o`0000?oK9c]00?o0000
ogNIi_mgVNH01Ol00004og>Fi@05o`000?n1UmooPIOOoh6Ggol000001omnU=h01Ol0003oO97MogbA
gOmlTMgo000000;oS9CF00?o0000oh^BeOn;T]D00_n;T]D00ol0003oRI3DohV@e002ohV@e003o`00
0?n8SM;oR8gB00?oR8gB00?o0000ohJ;dOn6Rm400on6Rm42ohF9d003o`000?nES/Wo000000CoUHg8
00?o0000oiB;aonDRlL00_nDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nCR<GoThS500;oThS5
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo
000Vooooo`;o0000;oooool00ol0003obokPol_nh002ol_nh005o`000?o;oN;obogRol_mh_l00000
1?o:o>D2o`0000SoTo7M1?l0000Tooooo`03o`000?oooooooooo02Kooooo0ol00008ooooo`03o`1X
cOl0003o000000Oo00000_m;U?0:o`0000GoIYS/1_l0000:og>Fi@03o`000?n1Umoo000000OoOYCN
00?o0000ogbAgOmlTMd00omlTMd2o`0000CoRi;E00?o0000ohV@e?n9T=@00on9T=@00ol0003oR8gB
ohR=dP02ohR=dP03o`000?n6Rm7oQX_A00?oQX_A00Co0000ohF9d?n5RM3oQHW@0_l00004oiF=b003
o`000?nDRlOoU8_700;oU8_700?o0000oi>9a_nCRLH00_nCRLH00ol0003oThS5oi>8a@02oi>8a@03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<ooooo`00
:?ooool00ol0003oooooooooo`0/ooooo`03o`000?o;o^3obokP00;obokP00Go0000ol_mh_o;oN;o
bogRo`000003ol[li@Go00000onClMd4o`0002Sooooo00?o0000ooooooooool08_ooool3o`0000ko
oooo2_l00003od^Dl0?o00000_mCVO85o`0000KoIYS/00?o0000og>FiOmcU^D01omcU^D4o`0000Go
OYCN0_l00006ogbAg@?o00000on;T]D00ol0003oRI3DohV@e003ohV@e003o`000?n8SM;oR8gB00;o
R8gB00?o0000ohJ;dOn6Rm400on6Rm400ol0003oQHW@ohF9d002ohF9d0;o00000onESLP00ol0003o
U8_7oiB;a`02oiB;a`03o`000?nCRLKoThW600;oThW600?o0000oi>8aOnCR<D00_nCR<D00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool002Wooooo
00?o0000ooooooooool0:oooool00ol0003obokPol_nh002ol_nh006o`000?o;oN;obogRol_mh_l0
003ob_cU0_l00005oho_e`Go0000:oooool00ol0003oooooooooo`0Mooooo`Co00004oooool<o`00
00;oBiC`1Ol00002of2Cj`Ko000000?oIYS/o`000?mcU^D00_mcU^D5o`0000CoKi;T00Go0000ogjD
g_mnU=koOYCNo`000007ogbAg@05o`000?miS]_oNHkKogV>fol000000_n;T]D00ol0003oRI3DohV@
e003ohV@e003o`000?n8SM;oR8gB00;oR8gB00?o0000ohJ;dOn6Rm400on6Rm400ol0003oQHW@ohF9
d002ohF9d0;oQ8O>0_l000000onESLSo0000oiB;a`03oiB;a`03o`000?nCRLKoThW600;oThW600?o
0000oi>8aOnCR<D00_nCR<D00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool002[ooooo00?o0000ooooooooool0:_ooool01Ol0003obokPol_nh?o;
o^3o000000CobogR0_l00006oho_e`?o0000;oooool00ol0003oooooooooo`0Iooooo`?o00006Ooo
ool00ol0D[Oo0000o`00000;o`0000;oBiC`1Ol00004of2Cj`Go00002_m_T^@00ol0003oOYCNo`00
0007ogbAg@03o`000?miS]_oNHkK00?oNHkK0_l00005ohV@e003o`000?n8SM;oR8gB00;oR8gB00?o
0000ohJ;dOn6Rm400on6Rm400ol0003oQHW@ohF9d003ohF9d0CoQ8O>0_l00004oiB;a`03o`000?nC
RLKoThW600;oThW600?o0000oi>8aOnCR<D00_nCR<D00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03?ooool002_ooooo0_l0000Zooooo`05o`000?o;o^3o
bokPol_nh?l000000oo;oN8:o`0003;ooooo00?o0000ooooooooool05Oooool3o`0001oooooo4?l0
0002oeZ?j@Oo000000?oH9?[o`000?m_T^@01Om_T^@7o`0000GoO97M0_l00006ogV>f`?o00001?n9
T=@00ol0003oR8gBohR=dP02ohR=dP03o`000?n6Rm7oQX_A00?oQX_A00?o0000ohF9d?n5RM000_n5
RM000ol0003oQ8O>ohB7cP03ohB7cP;o00000onDRlL00ol0003oThW6oi>9aP02oi>9aP03o`000?nC
R<GoThS500;oThS500?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00cooooo000]ooooo`03o`000?oooooooooo02Oooooo00Ko0000ol_nh?o;o^3obokPo`00
0?o;oN82o`0000GoR^c@0ol0000eooooo`03o`000?oooooooooo017ooooo0ol0000Tooooo`Oo0000
0_liR^d3o`000003od:?kol0003o000000;o00001_mJSnT8o`0000OoJhkS00Go0000ogbAgOmlTMgo
O97Mo`000007ogV>f`04o`000?mgRm[oMh_JogN;fP;o00000_n9T=@00ol0003oR8gBohR=dP02ohR=
dP03o`000?n6Rm7oQX_A00?oQX_A00?o0000ohF9d?n5RM000_n5RM000ol0003oQ8O>ohB7cP03ohB7
cP;oPXG=0_l000000onDRlOo0000oi>9aP03oi>9aP03o`000?nCR<GoThS500;oThS500?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo000^ooooo`03
o`000?oooooooooo02Gooooo00?o0000ol_nh?o;o^000_o;o^02o`0000;oR^c@1_l0000hooooo`03
o`000?oooooooooo00cooooo1?l0000Yooooo`So00000_liR^d4o`000003oeB;j?l0003o000000?o
00001?mJSnT00ol0003oJhkSof^>h`0:of^>h`03o`000?mlTMgo000000OoNHkK00?o0000ogN;f_mg
RmX01?mgRmX2o`0000CoR8gB00?o0000ohJ;dOn6Rm400on6Rm400ol0003oQHW@ohF9d003ohF9d003
o`000?n4QlkoQ8O>00;oQ8O>00?o0000oh:5cOn2QLd00_n2QLd2o`0000CoThW600?o0000oi>8aOnC
R<D00_nCR<D00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02oooool002oooooo0_l0000Uooooo`04o`000?o;o^3obokPol_nh0Go000000CoQNW8o`000?l0
003o0000>oooool00ol0003oooooooooo`08ooooo`?o0000;oooool8o`0000?o>H[]1?l00003oeB;
j0Ko00001_m[S^<7o`0000KoNHkK0_l00007ogN;fP?o00000on8SM800ol0003oQX_AohJ;d@03ohJ;
d@03o`000?n5RM3oQHW@00;oQHW@00?o0000ohB7c_n4Qlh00on4Qlh00ol0003oPXG=oh:5c@03oh:5
c@;o00000onCRLH00ol0003oThS5oi>8a@02oi>8a@03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`00<Oooool00ol0003oooooooooo`0Rooooo`04
o`000?o;o^3o0000o`0000GoQNW80_l0000nooooo`03o`000?oooooooooo00Cooooo0ol0000doooo
o`So00000_liR^d00ol0003oCXKWodj6i`04o`0000CoE8_X1ol00006ofN;hP03o`000?miS]_oNHkK
00?oNHkK00?o0000ogN;f_mgRmX01_mgRmX01Ol0003oM8SIogB8fOmdR=Wo000000;oR8gB00?o0000
ohJ;dOn6Rm400_n6Rm400ol0003oQHW@ohF9d003ohF9d003o`000?n4QlkoQ8O>00?oQ8O>00?o0000
oh:5cOn2QLd00on2QLd2oh63c0;o000000?oThW6o`000?nCR<D00onCR<D00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool003;ooooo00?o0000oooo
ooooool08Oooool2o`0000;oQNW81Ol00011ooooo`03o`000?oooooooooo00?o0000>Oooool:o`00
00GoCXKW0ol00003oeB;j003o`000?mWRn;oIh_R00WoIh_R00Go0000ogV>fomiS]_oNHkKo`000007
ogN;fP;o00001OmdR=T2o`0000GoQX_A00?o0000ohF9d?n5RM000on5RM000ol0003oQ8O>ohB7cP02
ohB7cP03o`000?n2QLgoPXG=00CoPXG=1?n1Pl`2o`0000CoThS500?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000cooooo`03o`000?oooooooooo
023ooooo1?l00017ooooo`;o0000?Oooool;o`0000KoCXKW1Ol0000;ofN;hP03o`000?miS]_o0000
00OoMh_J00?o0000ogB8fOmdR=T01OmdR=T2o`0000GoQX_A00?o0000ohF9d?n5RM000_n5RM000ol0
003oQ8O>ohB7cP03ohB7cP03o`000?n2QLgoPXG=00?oPXG=00?o0000oh63c?n1Pl`00on1Pl`2o`00
00?oThS500?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00_ooooo000dooooo`;o0000Joooool00ol0003oooooooooo`0nooooo`So000000?oB8;Uo`000?l0
00000_l00006odj6i`oo00001_mgRmX00ol0003oM8SIogB8f@05ogB8f@04o`000?mbQMOoLXGGo`00
00?oQX_A00?o0000ohF9d?n5RM000on5RM000ol0003oQ8O>ohB7cP03ohB7cP03o`000?n2QLgoPXG=
00?oPXG=00?o0000oh63c?n1Pl`00on1Pl`2oh21b`;o000000?oThS5o`000?ooool03_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo000fooooo`03o`000?oooooooooo06So
oooo00?o0000ooooooooool0@?ooool9o`0000;oB8;U1Ol00003odj6i`03o`000?mSQn3oHhOP00[o
HhOP00Co0000ogN;f_mgRm[oMh_J0_l00007ogB8f@03o`000?mbQMOoLXGG00;oLXGG00Co0000ohJ;
dOn6Rm7o00001On5RM000ol0003oQ8O>ohB7cP02ohB7cP03o`000?n2QLgoPXG=00CoPXG=00?o0000
oh63c?n1Pl`00_n1Pl`00ol0003oP87;oh21b`02oh21b`;o00003oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo000gooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool0@Oooool7o`000004od9mhol0003o0000o`0000CoB8;U1Ol0000<of>7h003o`000?mgRm[o
000000SoM8SI00?o0000og:5eombQML01?mbQML00ol0003oQX_Ao`000005ohF9d003o`000?n4Qlko
Q8O>00;oQ8O>00?o0000oh:5cOn2QLd00on2QLd00ol0003oPH?<oh63c003oh63c003o`000?n0PL_o
P87;00?oP87;00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00[ooooo000hooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0@oooool8o`00
0003od9mhol0003o000000;o00001?m8P^D?o`0000OoM8SI0_l00007og:5e`?o00001?n5RM000ol0
003oQ8O>ohB7cP03ohB7cP03o`000?n2QLgoPXG=00?oPXG=00?o0000oh63c?n1Pl`00on1Pl`00ol0
003oP87;oh21b`03oh21b`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0:ooooo`00>Oooool2o`0006Kooooo00?o0000ooooooooool0A?ooool6o`000004
ocaih_l0003o0000o`0000;o@WgS0ol00002odR2i@03o`000?mOQ=ooGhCO00_oGhCO00?o0000ogB8
fOmdR=T00omdR=T00ol0003oLXGGog:5e`06og:5e`05o`000?m`PmKoL8?Fog23e_l000000on5RM00
0ol0003oQ8O>ohB7cP02ohB7cP03o`000?n2QLgoPXG=00CoPXG=00?o0000oh63c?n1Pl`00_n1Pl`0
0ol0003oP87;oh21b`04oh21b`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0:ooooo`00>oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
04Kooooo1_l00002ocaihP?o00000_m2ON<4o`0000goGhCO00Go0000ogB8fOmdR=WoM8SIo`000007
og:5e`;o00001Om`PmH01?l0003oQHW@ohF9d?l00004ohB7cP03o`000?n2QLgoPXG=00?oPXG=00?o
0000oh63c?n1Pl`00on1Pl`00ol0003oP87;oh21b`03oh21b`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`00??ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo04Sooooo1ol00002ocaihP?o00000_m2ON<:o`0000GoGhCO00?o0000
ogB8fOl000001ombQML00ol0003oL8?Fog23eP06og23eP;o00001On4Qlh00ol0003oPXG=oh:5c@03
oh:5c@03o`000?n1PlcoPH?<00?oPH?<00?o0000oh21bon0PL/00on0PL/00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool003gooooo0_l0001Roooo
o`03o`000?oooooooooo04Wooooo1Ol000001?lfM=oo0000o`000?l00002ocaihP?o000000?o@WgS
o`000?mKP=d01_mKP=d8o`0000KoLXGG00?o0000og23e_m`PmH01om`PmH2o`0000CoQ8O>00?o0000
oh:5cOn2QLd01?n2QLd00ol0003oPH?<oh63c002oh63c003o`000?n0PL_oP87;00CoP87;00?o0000
ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo000ooooo
o`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Boooool5o`0000;o=WCO0ol00002ocai
hP?o00003_mKP=d01?l0003oLXGGog:5eombQML2o`0000SoL8?F0_l00002ofj0e005o`000?n4Qlko
Q8O>ohB7c_l000001On2QLd00ol0003oPH?<oh63c003oh63c003o`000?n0PL_oP87;00?oP87;00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0010
ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0C?ooool7o`0000;o=WCO0_l00003
ocaihPWo00001_mKP=d00ol0003oLXGGo`000009og23eP03o`000?m^P=CoKX3D00?oKX3D00Co0000
ohB7c_n4Qlko00001On2QLd00ol0003oPH?<oh63c003oh63c003o`000?n0PL_oP87;00?oP87;00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo0011
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0C_ooool4o`000003oc1`gOl0003o
000000;o=WCO0ol000000ollNN;o0000oeMmg006oeMmg0So00002?m`PmH2o`0000OoKX3D0_l00006
oh:5c@03o`000?n1PlcoPH?<00;oPH?<00?o0000oh21bon0PL/01?n0PL/00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool004;ooooo0_l0001Moooo
o`03o`000?oooooooooo053ooooo1?l000000ol`L=go0000o`000003ocIdg`?o00003OmGOM`00ol0
003oL8?Fog23eP04og23eP;o00002Om^P=@3o`0000CoPXG=00?o0000oh63c?n1Pl`00on1Pl`00ol0
003oP87;oh21b`03oh21b`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`00A?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo057o
oooo1Ol000000ol`L=go0000o`000004ocIdg`Go00002OmGOM`00ol0003oL8?Fog23eP02og23eP03
o`000?m^P=CoKX3D00OoKX3D0_l00003ofand`05o`000?n2QLgoPXG=oh:5cOl000001On1Pl`00ol0
003oP87;oh21b`03oh21b`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`00AOooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo05?o
oooo00?o0000obEVfOl000000_l000000ol`L=go0000o`000002ocIdg`03o`000?mDNM[oE7WJ00;o
E7WJ2?l00002oeMmg004o`000?m`PmKo0000o`0000WoKX3D00?o0000ofandom/O]<01?m/O]<01?l0
003oPXG=oh:5cOl00004oh63c003o`000?n0PL_oP87;00CoP87;00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0016ooooo`;o0000F?ooool00ol0
003oooooooooo`1Eooooo`;o000000?o9FKIo`000?l000001_l0000;oeAifPCo00002Om^P=@2o`00
00SoK7kC0_l00005oh63c003o`000?n0PL_oP87;00?oP87;00?o0000ooooooooool06oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0018ooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool0Eoooool2o`000003obEVfOl0003o000000;o000000?o<73Mo`000?l0
00003_mDNMX00ol0003oKX3Dofj0e004ofj0e0;o00002_m/O]<2o`0000GoPH?<00?o0000oh21bon0
PL/00on0PL/00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool004Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`1Iooooo`05o`00
0?lUI]Wo9FKIo`000?lZJm/00_l000000ol`L=go0000o`000003o`0000[oE7WJ00?o0000ofj0e?m^
P=@00_m^P=@00ol0003oK7kCofand`08ofand`;o00000_mYNm801Ol0003oPH?<oh63c?n1Plco0000
00KoP87;00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo001:ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0F_ooool2o`000004
obEVfOl0003o0000obY[f`?o00000om@M]T9o`0000;oE7WJ00Co0000ofj0e?l0003o00002Om/O]<2
o`0000GoJG_B00Co0000oh63c?n1Plco00001On0PL/00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool004_ooooo0_l0001Cooooo`03o`000?oooooo
oooo05cooooo0_l000001?lUI]Wo0000o`000?lZJm/2o`0000_oD7KI1?l00009ofand`;o00002?mY
Nm800ol0003oPH?<o`000005oh21b`03o`000?oooooooooo01oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`00COooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo05kooooo00?o0000obEVfOlUI]T00_l000000olZJm_o0000o`000002o`0000_oD7KI00?o0000
ofandom/O]<01Om/O]<00ol0003oJG_BofUkdP08ofUkdP;o00001_n0PL/00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool004kooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`1Oooooo`;o00000_lUI]T3o`0000;oCG;G1_l00006oe1f
f@03o`000?m/O]?oK7kC00;oK7kC0_l00009ofUkdP;o00000_mWNM400ol0003oP87;oh21b`02oh21
b`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`00Coooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo067ooooo0_l00002obEVf@;o
00001om=L]L6o`000003oe1ffOl0003oK7kC00;o00002OmYNm82o`0000GoIgWA00Go0000oh21bon0
PL_oP87;o`00000Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0053o
oooo0_l0001>ooooo`03o`000?oooooooooo06?ooooo00Co0000obEVfOlUI]Wo9FKI0ol0000:odeb
e`?o00002OmYNm82o`0000SoIgWA00Co0000oh21bon0PL_o00009Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool0I?ooool2o`000004obEVfOl0003oBFoFodU_ePGo00002?m=L]L00ol0003oJG_BofUkdP05
ofUkdP03o`000?mWNM7oIgWA00WoIgWA0_l0000Wooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool005?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`1Voooo
o`?o00001_m9KmH5o`0000CoCG;G00?o0000ofUkd_mYNm800_mYNm82o`0000coIgWA0_l0000Woooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool005Cooooo0_l0001:ooooo`03
o`000?oooooooooo06Sooooo00?o0000odU_e_m9KmH02Om9KmH6o`000003ofUkd_l0003o000000co
IgWA0_l0000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool005Kooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Yooooo`?o00003Om9KmH2o`0000coIgWA
0_l0000]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool005Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`1/ooooo`Co00002_m9KmH00ol0003oIgWAofMi
d@07ofMid@?o0000;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo001H
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0L?ooool4o`0000OoBFoF00?o0000
ofMidOmWNM401?mWNM42o`0003?ooooo00Go0000ooooooooooooooooo`000009ooooo`00FOooool2
o`0004Gooooo00?o0000ooooooooool0M?ooool4o`0000CoBFoF00Co0000ofMidOmWNM7oIgWA0_l0
000fooooo`04o`000?ooooooooooo`0000Wooooo001Kooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0N?ooool5o`000003ofMidOl0003o000003Wooooo00?o0000ooooool000002Ooo
ool005cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1looooo`;o0000>oooool0
1?l0003oooooooooool00008ooooo`00GOooool2o`00047ooooo00?o0000ooooooooool0^_ooool0
0ol0003oooooo`000008ooooo`00Goooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
0;_ooooo0_l00008ooooo`00H?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0;[o
oooo0ol00008ooooo`00HOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0;Kooooo
1?l0000;ooooo`00H_ooool2o`0003cooooo00?o0000ooooooooool0/_ooool4o`0000oooooo001T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0[_ooool4o`0001?ooooo001Uoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Z_ooool4o`0001Oooooo001Vooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0Y_ooool4o`0001_ooooo001Wooooo`;o0000
=oooool00ol0003oooooooooo`2Rooooo`Co00007oooool006Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`2Nooooo`Co00008oooool006[ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`2Looooo`?o00009oooool006_ooooo0_l0000booooo`03o`000?oooooooooo
09Sooooo1?l0000Zooooo`00KOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09Co
oooo1?l0000^ooooo`00K_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo093ooooo
1?l0000booooo`00Koooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08cooooo1?l0
000fooooo`00L?ooool2o`0002gooooo00?o0000ooooooooool0R?ooool4o`0003[ooooo001boooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Q?ooool4o`0003kooooo001cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0P?ooool4o`0004;ooooo001dooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0O?ooool4o`0004Kooooo001eooooo`;o0000:?oo
ool00ol0003oooooooooo`1hooooo`Co0000B_ooool007Oooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1dooooo`Co0000C_ooool007Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1`ooooo`Co0000D_ooool007Wooooo0_l0000Tooooo`03o`000?oooooooooo06co
oooo1?l0001Fooooo`00Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo06Sooooo
1?l0001Jooooo`00O?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Cooooo1?l0
001Nooooo`00OOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo063ooooo1?l0001R
ooooo`00O_ooool2o`0001oooooo00?o0000ooooooooool0G?ooool4o`0006Kooooo0020ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0FOooool3o`0006[ooooo0021ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0EOooool4o`0006gooooo0022ooooo`;o00006ooo
ool00ol0003oooooooooo`1Aooooo`Co0000LOooool008Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1=ooooo`Co0000MOooool008Gooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`19ooooo`Co0000NOooool008Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`15ooooo`Co0000OOooool008Oooooo0_l0000Fooooo`03o`000?oooooooooo047ooooo
1?l00021ooooo`00ROooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03gooooo1?l0
0025ooooo`00R_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03Wooooo1?l00029
ooooo`00Roooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Gooooo1?l0002=oooo
o`00S?ooool2o`00017ooooo00?o0000ooooooooool0<Oooool4o`00097ooooo002>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;_ooool4o`0009Gooooo002?ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0:_ooool4o`0009Wooooo002@ooooo`;o00003?ooool0
0ol0003oooooooooo`0Vooooo`Co0000WOooool009;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Rooooo`Co0000XOooool009?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Nooooo`Co0000YOooool009Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Kooooo`?o0000ZOooool009Gooooo0_l00007ooooo`03o`000?oooooooooo01Oooooo1?l0
002/ooooo`00Uoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1?l0002`
ooooo`00V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo1?l0002doooo
o`00VOooool2o`0000?ooooo00?o0000ooooooooool02oooool4o`000;Sooooo002Kooooo`04o`00
0?ooooooooooo`0000Wooooo1?l0002looooo`00W?ooool00ol0003oooooo`000005ooooo`Co0000
`?ooool009gooooo0_l000000ooooooo0000o`000002o`000<Cooooo002Nooooo`;o0000b?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
037ooooo0ol000000ol@413oooooooooo`26ooooo`04oa0@4?l0003o0000o`000:Oooooo000coooo
o`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0Yoooool003?ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`2Wooooo`009_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj
^P;ooooo00Kok^k^oeEEEOl0003o0000ogMgMol00003ooooo`06oiRHV?l0003o0000ogMgMol0003o
410@0_ooool5o`0000;ooooo1Ol00004ooooo`Go00000_ooool00ol@413o0000ohN7Q`02o`000003
ofIVI_o^k^ko410@00Go00001?ooool5o`0000?ooooo00KoV9RHo`000?l0003oMgMgo`000?l@4102
o`0000;ooooo00Go0000oooooooooooo0000oa0@4002ooooo`06onk^k_mEEEGo0000o`000?mEEEGo
k^k^0_ooool00ol@413o0000o`000002o`000003oa0@4?oooooooooo00Kooooo00KoV9RHo`000?l0
003oMgMgoa0@4?l0000:ooooo`05o`000?o<c<cogMgMo`000?o^k^h00_ooool02?nHV9So0000o`00
0?mgMgOo410@o`000?oooooo410@1Ol00004ooooo`09o`000?mgMgOo0000o`000?mEEEGok^k^oooo
ooo^k^koEEEE00;o000000KoA4A4okZj^_ooooooooooonk^k_mEEED2o`000003oiRHV?l0003o410@
00Oooooo00GoIVIVo`000?l0003oA4A4olc<c003ooooo`Go000000?ooooooa0@4?l000001?l00004
ooooo`05ofIVI_l0003o0000odA4A?o<c<`00oooool01onHV9So0000o`000?mgMgOo0000oa0@4?oo
ool01Ol00003ooooo`08oiRHV?l0003o0000ogMgMol@413o0000ooooool@4105o`0000Kooooo00Ko
k^k^oeEEEOl0003o0000oiRHV?l00002oa0@40Go00001?ooool01_nHV9So0000o`000?mgMgOo0000
oa0@40;o00000_ooool01?l0003oooooooooool00002oa0@40;o000000Ooooooo`000?l0003o410@
ooooooo^k^koEEEE00;o000000GoA4A4okZj^_oooooooooooiRHV002o`000003ogMgMol@413o0000
00;ooooo00Ook^k^oeEEEOl0003o0000oiRHV?l0003o410@00cooooo000Vooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@0_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000ojVY
ZOooooooQhN7o`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIV0_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooooooooeEEEOmgMgL2ooooo`03ogMgMomE
EEGooooo00?ooooo00?o0000ooooooooool02Oooool01Ol0003oc<c<onk^k_n7QhOo000000[ooooo
00KoZJVYo`000?n7QhOoV9RHo`000?nHV9P2ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool0
0ol0003oooooooooo`05ooooo`0=o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMgoooo
ooo^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00001oooool01_mVIVKoMgMg
ooooooooooooQhN7oa0@40Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol0003oZJVYoooooon7QhOo000000Cooooo
00?o0000ooooooooool00oooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00?o0000oooooooo
ool01oooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003oZJVYoooooon7QhOo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00003ooooo`09o`000?oooooooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00;ooooo00Go
0000olc<c?o^k^koQhN7o`000003ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00003Oooool002Ko
oooo00?o0000ooooooooool01Oooool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?o^k^kooooo00;ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00Go410@ohN7Qoooooook^k^o`00000:ooooo`06oeEEEOn7
QhOoA4A4oeEEEOmgMgOoEEEE0_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00?o0000oooo
ooooool01Oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo000000Oooooo00Ko0000oooo
ooooooooooooonk^k_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03
o`000?oooooooooo00Oooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool01?l0003oooooooooool00007ooooo`05oa0@4?n7QhOooooo
onk^k_l000000oooool01_l0003oooooooooooooooook^k^o`0000gooooo000Vooooo`Ko00000_oo
ool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?o^k^kooooo00;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o^[Zjoa0@4?l000000_l0000:ooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00000_ooool0
0onj^[[o410@o`000002o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooo000000Go00000_ooool01_l0003oooooooooooooooook^k^o`0000Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000ooooooooool01oooool01_l0003o
ooooooooooooooook^k^o`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Ko00000_ooool00onj^[[o410@o`000002o`0000?ooooo00Ko0000oooooooo
ooooooooonk^k_l0000=ooooo`009_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko
IVIVogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool01_l0
003oEEEEonk^k_ooooooMgMgoeEEE@;ooooo00?o0000oc8b<_oMgMd01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003oc<c<olc<c?l0003oZJVYomgM
gOlQ8B400oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@Cooooo00?o0000ooooooooool03?oo
ool00oo<c<co0000ooooo`08ooooo`08ojVYZOlQ8B7oooooohN7QomEEEGooooooc8b<_nYZJT4oooo
o`03olc<c?l0003ooooo00?ooooo00?o0000oc8b<_oMgMd01Oooool03Ol0003oEEEEonk^k_oooooo
MgMgofIVI_ooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800_ooool01_mVIVKoMgMgooooooo^k^ko
EEEEo`0000Oooooo00KoIVIVogMgMoooooooooooohN7Qol00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000oc8b<_oMgMd01?ooool01_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00ooo
ool00ol0003o<S8bomgMg@07ooooo`06ofIVI_mgMgOoooooonk^k_mEEEGo00000oooool00ol0003o
<S8bomgMg@05ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003oc<c<olc<c?l0003o
ZJVYomgMgOlQ8B400_ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^ko
ooooohN7Qolb<S85ooooo`03olc<c?l0003ooooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl0
000=ooooo`009_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00[ok^k^oeEEEOl0003o
0000ogMgMol0003o410@ooooool@413o00000_ooool2o`0000?ooooo00?o410@o`000?l000001_oo
ool00ol0003oooooooooo`04ooooo`03oa0@4?l0003o000000Gooooo00Oo0000olc<c?l@413o0000
oeEEEOo^k^kooooo00;o000000CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000004oooo
o`04oa0@4?l0003oooooooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nY
ZJT00oooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo00?o410@o`000?l000000ol00009
ooooo`04oc8b<_l0003o0000oiRHV0Wooooo0ol00002ooooo`?o00000_ooool01?lb<S;o0000o`00
0?nHV9P3ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool00ol@413o0000ogMgM`02o`000005
ofIVI_o^k^koooooonk^k_mEEED00_l000002_m4A4Cok^k^ooooooooooook^k^oeEEEOl0003o410@
olc<c?l00007ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00000oooool00ol@413o0000o`000004
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000;o
oooo00Co410@o`000?oooooooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00Co<S8bo`00
0?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Gooooo00Kok^k^oeEEEOl0003o410@
olc<c?l00002ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01?l@413o0000ooooooooool2
o`000009ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVY00;ooooo00Go0000ogMgMol0
003o0000oiRHV002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0oooool01?lb<S;o0000o`00
0?nHV9P3ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00003Oooool004Sooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0;ooooo`00@Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01kooooo00?o410@okZj^_ooool0AOooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool0047ooooo00?o410@ooooooooool00_oo
ool00ol@413o0000o`000008ooooo`03oa0@4?oooooooooo00;ooooo00?o410@o`000?ooool04?oo
ool00ol@413oooooooooo`0Nooooo`04okZj^_l@413o0000oa0@44?ooooo0_l0000Booooo`03oa0@
4?oooooooooo01[ooooo00?o410@o`000?l000007?ooool2o`0001[ooooo00?o410@o`000?ooool0
6Oooool2o`0000gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {308.375, 0}} -> {-0.0883988, 0.00525911, \
0.00369676, 0.00369676}}]
}, Open  ]],

Cell[TextData[{
  "\tOn the other hand, for time-dependent boundary conditions, the eigenmode \
approach must be used. Even if we choose ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " to satisfy the Laplace equation, a source function will still appear in \
Eq. ",
  ButtonBox["(4.4.16)",
    ButtonData:>"(4.4.16)",
    ButtonStyle->"Hyperlink"],
  ",  because the time-dependent boundary conditions imply that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 u/\[PartialD]t\^2\  \[NotEqual] \ 
        0. \)]],
  " Problems of this sort follow an identical path to solution as for the \
one-dimensional wave equation with a source function, and examples are left \
to the exercises."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4.2 Large-Scale Ocean Modes", "Subsubtitle",
  CellTags->{"i:92", "c:40"}],

Cell[TextData[{
  "The large-scale waves of the ocean provide an instructive example of waves \
in spherical geometry. Here, for simplicity we take the idealized case of a \
\"water world\", where the ocean completely covers the earth's surface, with \
uniform depth ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_o\) \(\(<<\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the radius of the earth. Also, we will neglect the effects of earth's \
rotation on the wave dynamics."
}], "Text"],

Cell[TextData[{
  "\tAs we saw in Exercise (4) of Sec. ",
  ButtonBox["3.1",
    ButtonData:>{"Chapter3.nb", "c:23"},
    ButtonStyle->"Hyperlink"],
  ", waves in shallow water (for which the wavelength ",
  Cell[BoxData[
      \(TraditionalForm\` >> \)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`d\_o\)]],
  ") satisfy a wave equation with speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(g\ d\_o\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"], " "}]}]}], TraditionalForm]]],
  " is the acceleration of gravity. On the spherical surface of the earth, \
these waves will also satisfy the wave equation, written in  spherical \
coordinates. That is, the depth of the ocean now varies according to ",
  Cell[BoxData[
      \(TraditionalForm\`d = d\_o + h(\[Theta], \[Phi], t)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is the change in height of the surface due to the waves, at latitude and \
longitude specified by the spherical polar angles \[Theta] and \[Phi].  The \
function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h\)\(\ \)\)\)]],
  "satisfies the wave equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 
            h/\[PartialD]t\^2 = \(\(c\^2\) \[Del]\^2\( h(\[Theta], \[Phi], 
                t)\) = \(c\^2\/R\^2\) \((\(1\/sin\[Theta]\) \(\[PartialD]\/\
\[PartialD]\[Theta]\) \((sin\[Theta] \[PartialD]h\/\[PartialD]\[Theta])\) + \
\(1\/\(\(sin\^2\) \[Theta]\)\) \[PartialD]\^2 \
h\/\[PartialD]\[Phi]\^2)\)\)\)]],
  ", "
}], "NE5",
  CellTags->"(4.4.23)"],

Cell[TextData[{
  "where we have used the spherical form of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\)]],
  ", Eq. ",
  ButtonBox["(3.2.27)",
    ButtonData:>{"Chapter3.nb", "(3.2.27)"},
    ButtonStyle->"Hyperlink"],
  " [see ",
  ButtonBox["Lamb (1932, pg. 301)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tFrom our work on Poisson's equation in spherical coordinates, we know \
that the eigenmodes of the operator on the ",
  "right-hand",
  " side of Eq. ",
  ButtonBox["(4.4.23)",
    ButtonData:>"(4.4.23)",
    ButtonStyle->"Hyperlink"],
  " are spherical harmonics ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_\(l, \ m\)\)(\[Theta], \[Phi])\)]],
  ". Furthermore, we know that the eigenvalues of this operator are  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-c\^2\) \(l(l + 1)\)/R\^2\)]],
  " [see Eq. ",
  ButtonBox["(4.3.55)",
    ButtonData:>"(4.3.55)",
    ButtonStyle->"Hyperlink"],
  "]. Therefore, the amplitude of each spherical harmonic oscillates in time \
at the frequency"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_l\  = \ c \@\( l(l + 1)\)/R\)]],
  ". "
}], "NE5",
  CellTags->"(4.4.24)"],

Cell["The solution is a sum of these modes,", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`h(\[Theta], \[Phi], 
        t) = \[Sum]\+\(l = 0\)\%\[Infinity]\(\[Sum]\+\(m = \
\(-l\)\)\%l\((\(A\_\(\(l\)\(\ \)\(m\)\(\ \)\)\) cos\ \(\[Omega]\_l\) 
                  t\  + \ \(B\_\(l\ m\)\) 
                  sin\ \[Omega]\_l\ t)\) \(\(\(Y\_\(l, \ 
                    m\)\)(\[Theta], \[Phi])\)\(.\)\)\)\)]]], "NE5",
  CellTags->"(4.4.25)"],

Cell[TextData[{
  "It is entertaining to work out the frequencies and shapes of some of the \
low-order modes, for earth-like parameters. Taking an average ocean depth of \
roughly  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_o = \ 4\ km\)]],
  ", the wave speed is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{
            RowBox[{\(\@\(9.8\[Cross]4000\)\), 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], "/", 
                StyleBox["s",
                  FontSlant->"Plain"]}]}], "=", 
            RowBox[{"198", " ", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], "/", 
                StyleBox["s",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". The earth's radius is approximately ",
  Cell[BoxData[
      \(TraditionalForm\`R = 6400\ km\)]],
  ", so the lowest-frequency modes, with ",
  Cell[BoxData[
      \(TraditionalForm\`l = 1\)]],
  ", have frequency ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_1\), "=", 
          RowBox[{\(\(\@2\) c/R\), "=", 
            RowBox[{"4.4", "\[Times]", \(10\^\(-5\)\), 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], \(-1\)]}]}]}], TraditionalForm]]],
  " , corresponding to a period of ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/\[Omega]\_1 = 1.4\[Cross]10\^5\)]],
  " s, or 40 hours. The ",
  Cell[BoxData[
      \(TraditionalForm\`l = 2\)]],
  " modes have a frequency that is larger by the factor ",
  Cell[BoxData[
      \(TraditionalForm\`\@3\)]],
  ", giving a period of ",
  Cell[BoxData[
      \(TraditionalForm\`23\ hours\)]],
  ".  The ",
  Cell[BoxData[
      \(TraditionalForm\`l = 1\)]],
  " and 2 modes are shown in Cells ",
  ButtonBox["4.45",
    ButtonData:>"Cell 4.45",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4.46",
    ButtonData:>"Cell 4.46",
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(l = 1; \ m = 0;\), "\n", 
    \(\(Table[
        ParametricPlot3D[\((1\  +  .4  Cos[t] 
                  SphericalHarmonicY[l, 
                    m, \[Theta], \[Phi]])\) {Sin[\[Theta]] Cos[\[Phi]], 
              Sin[\[Theta]] Sin[\[Phi]], Cos[\[Theta]]}, {\[Theta], 0, 
            Pi}, {\[Phi], 0, 2  Pi}, 
          PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}, {\(-1.2\), 
                1.2}}], {t, 0, 2  Pi - 0.2  Pi,  .2\ Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.45"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48003 .59173 m .4741 .62973 L .54395 .63304 L p .719 .594 .715 r
F P
0 g
s
.54395 .63304 m .54195 .59473 L .48003 .59173 L p .719 .594 .715 r
F P
0 g
s
.54564 .67266 m .54395 .63304 L .4741 .62973 L p .72 .571 .686 r
F P
0 g
s
.54195 .59473 m .54395 .63304 L .61231 .62311 L p .669 .556 .717 r
F P
0 g
s
.54395 .63304 m .54564 .67266 L .6206 .66205 L p .665 .527 .687 r
F P
0 g
s
.6206 .66205 m .61231 .62311 L .54395 .63304 L p .665 .527 .687 r
F P
0 g
s
.48668 .55562 m .48003 .59173 L .54195 .59473 L p .717 .616 .744 r
F P
0 g
s
.54195 .59473 m .53971 .55825 L .48668 .55562 L p .717 .616 .744 r
F P
0 g
s
.53971 .55825 m .54195 .59473 L .60252 .58573 L p .673 .582 .745 r
F P
0 g
s
.61231 .62311 m .60252 .58573 L .54195 .59473 L p .669 .556 .717 r
F P
0 g
s
.4741 .62973 m .46909 .66913 L .54564 .67266 L p .72 .571 .686 r
F P
0 g
s
.54695 .7129 m .54564 .67266 L .46909 .66913 L p .72 .545 .653 r
F P
0 g
s
.54564 .67266 m .54695 .7129 L .62702 .70185 L p .658 .496 .654 r
F P
0 g
s
.62702 .70185 m .6206 .66205 L .54564 .67266 L p .658 .496 .654 r
F P
0 g
s
.42216 .57693 m .40869 .6134 L .4741 .62973 L p .766 .639 .72 r
F P
0 g
s
.4741 .62973 m .48003 .59173 L .42216 .57693 L p .766 .639 .72 r
F P
0 g
s
.46909 .66913 m .4741 .62973 L .40869 .6134 L p .773 .62 .69 r
F P
0 g
s
.43724 .54269 m .42216 .57693 L .48003 .59173 L p .758 .656 .749 r
F P
0 g
s
.48003 .59173 m .48668 .55562 L .43724 .54269 L p .758 .656 .749 r
F P
0 g
s
.49389 .52175 m .48668 .55562 L .53971 .55825 L p .713 .637 .771 r
F P
0 g
s
.53971 .55825 m .53728 .52394 L .49389 .52175 L p .713 .637 .771 r
F P
0 g
s
.53728 .52394 m .53971 .55825 L .59154 .55037 L p .675 .608 .772 r
F P
0 g
s
.60252 .58573 m .59154 .55037 L .53971 .55825 L p .673 .582 .745 r
F P
0 g
s
.40869 .6134 m .39729 .65165 L .46909 .66913 L p .773 .62 .69 r
F P
0 g
s
.46521 .70922 m .46909 .66913 L .39729 .65165 L p .778 .598 .655 r
F P
0 g
s
.46909 .66913 m .46521 .70922 L .54695 .7129 L p .72 .545 .653 r
F P
0 g
s
.45355 .51097 m .43724 .54269 L .48668 .55562 L p .748 .672 .776 r
F P
0 g
s
.48668 .55562 m .49389 .52175 L .45355 .51097 L p .748 .672 .776 r
F P
0 g
s
.60252 .58573 m .61231 .62311 L .67325 .60058 L p .613 .521 .726 r
F P
0 g
s
.61231 .62311 m .6206 .66205 L .68763 .6379 L p .601 .486 .694 r
F P
0 g
s
.68763 .6379 m .67325 .60058 L .61231 .62311 L p .601 .486 .694 r
F P
0 g
s
.59154 .55037 m .60252 .58573 L .65631 .56533 L p .624 .553 .755 r
F P
0 g
s
.67325 .60058 m .65631 .56533 L .60252 .58573 L p .613 .521 .726 r
F P
0 g
s
.5478 .75286 m .54695 .7129 L .46521 .70922 L p .718 .515 .615 r
F P
0 g
s
.54695 .7129 m .5478 .75286 L .63119 .74165 L p .65 .461 .615 r
F P
0 g
s
.63119 .74165 m .62702 .70185 L .54695 .7129 L p .65 .461 .615 r
F P
0 g
s
.6206 .66205 m .62702 .70185 L .69879 .67668 L p .587 .447 .658 r
F P
0 g
s
.69879 .67668 m .68763 .6379 L .6206 .66205 L p .587 .447 .658 r
F P
0 g
s
.59154 .55037 m .57963 .51737 L .53728 .52394 L p .675 .608 .772 r
F P
0 g
s
.57963 .51737 m .59154 .55037 L .63738 .53257 L p .634 .585 .782 r
F P
0 g
s
.65631 .56533 m .63738 .53257 L .59154 .55037 L p .624 .553 .755 r
F P
0 g
s
.39729 .65165 m .38844 .69102 L .46521 .70922 L p .778 .598 .655 r
F P
0 g
s
.46269 .74913 m .46521 .70922 L .38844 .69102 L p .782 .572 .615 r
F P
0 g
s
.46521 .70922 m .46269 .74913 L .5478 .75286 L p .718 .515 .615 r
F P
0 g
s
.50154 .49031 m .49389 .52175 L .53728 .52394 L p .708 .657 .798 r
F P
0 g
s
.53728 .52394 m .53469 .49201 L .50154 .49031 L p .708 .657 .798 r
F P
0 g
s
.53469 .49201 m .53728 .52394 L .57963 .51737 L p .677 .634 .799 r
F P
0 g
s
.47081 .48194 m .45355 .51097 L .49389 .52175 L p .737 .687 .803 r
F P
0 g
s
.49389 .52175 m .50154 .49031 L .47081 .48194 L p .737 .687 .803 r
F P
0 g
s
.39608 .52042 m .3737 .55135 L .42216 .57693 L p .797 .704 .762 r
F P
0 g
s
.42216 .57693 m .43724 .54269 L .39608 .52042 L p .797 .704 .762 r
F P
0 g
s
.40869 .6134 m .42216 .57693 L .3737 .55135 L p .812 .693 .733 r
F P
0 g
s
.3737 .55135 m .35362 .58509 L .40869 .6134 L p .812 .693 .733 r
F P
0 g
s
.39729 .65165 m .40869 .6134 L .35362 .58509 L p .826 .678 .7 r
F P
0 g
s
.42019 .49248 m .39608 .52042 L .43724 .54269 L p .78 .714 .789 r
F P
0 g
s
.43724 .54269 m .45355 .51097 L .42019 .49248 L p .78 .714 .789 r
F P
0 g
s
.57963 .51737 m .56703 .48691 L .53469 .49201 L p .677 .634 .799 r
F P
0 g
s
.56703 .48691 m .57963 .51737 L .61694 .50257 L p .643 .616 .808 r
F P
0 g
s
.63738 .53257 m .61694 .50257 L .57963 .51737 L p .634 .585 .782 r
F P
0 g
s
.62702 .70185 m .63119 .74165 L .70607 .71609 L p .569 .402 .616 r
F P
0 g
s
.70607 .71609 m .69879 .67668 L .62702 .70185 L p .569 .402 .616 r
F P
0 g
s
.54811 .79144 m .5478 .75286 L .46269 .74913 L p .714 .48 .57 r
F P
0 g
s
.5478 .75286 m .54811 .79144 L .63274 .78036 L p .639 .419 .569 r
F P
0 g
s
.63274 .78036 m .63119 .74165 L .5478 .75286 L p .639 .419 .569 r
F P
0 g
s
.35362 .58509 m .33655 .62127 L .39729 .65165 L p .826 .678 .7 r
F P
0 g
s
.38844 .69102 m .39729 .65165 L .33655 .62127 L p .838 .661 .662 r
F P
0 g
s
.50954 .46142 m .50154 .49031 L .53469 .49201 L p .701 .678 .825 r
F P
0 g
s
.53469 .49201 m .53199 .46259 L .50954 .46142 L p .701 .678 .825 r
F P
0 g
s
.53199 .46259 m .53469 .49201 L .56703 .48691 L p .677 .66 .826 r
F P
0 g
s
.44555 .46763 m .42019 .49248 L .45355 .51097 L p .762 .721 .815 r
F P
0 g
s
.45355 .51097 m .47081 .48194 L .44555 .46763 L p .762 .721 .815 r
F P
0 g
s
.38844 .69102 m .38268 .73066 L .46269 .74913 L p .782 .572 .615 r
F P
0 g
s
.46176 .78775 m .46269 .74913 L .38268 .73066 L p .784 .539 .567 r
F P
0 g
s
.46269 .74913 m .46176 .78775 L .54811 .79144 L p .714 .48 .57 r
F P
0 g
s
.48877 .45566 m .47081 .48194 L .50154 .49031 L p .722 .701 .829 r
F P
0 g
s
.50154 .49031 m .50954 .46142 L .48877 .45566 L p .722 .701 .829 r
F P
0 g
s
.63738 .53257 m .65631 .56533 L .69813 .53501 L p .567 .529 .773 r
F P
0 g
s
.65631 .56533 m .67325 .60058 L .72098 .56695 L p .545 .487 .742 r
F P
0 g
s
.72098 .56695 m .69813 .53501 L .65631 .56533 L p .545 .487 .742 r
F P
0 g
s
.61694 .50257 m .63738 .53257 L .67272 .50624 L p .587 .568 .799 r
F P
0 g
s
.69813 .53501 m .67272 .50624 L .63738 .53257 L p .567 .529 .773 r
F P
0 g
s
.56703 .48691 m .55388 .45907 L .53199 .46259 L p .677 .66 .826 r
F P
0 g
s
.55388 .45907 m .56703 .48691 L .59538 .47543 L p .651 .648 .834 r
F P
0 g
s
.61694 .50257 m .59538 .47543 L .56703 .48691 L p .643 .616 .808 r
F P
0 g
s
.67325 .60058 m .68763 .6379 L .74045 .60175 L p .52 .442 .708 r
F P
0 g
s
.74045 .60175 m .72098 .56695 L .67325 .60058 L p .52 .442 .708 r
F P
0 g
s
.33655 .62127 m .32327 .65932 L .38844 .69102 L p .838 .661 .662 r
F P
0 g
s
.38268 .73066 m .38844 .69102 L .32327 .65932 L p .849 .638 .616 r
F P
0 g
s
.59538 .47543 m .61694 .50257 L .64544 .48076 L p .606 .605 .824 r
F P
0 g
s
.67272 .50624 m .64544 .48076 L .61694 .50257 L p .587 .568 .799 r
F P
0 g
s
.63119 .74165 m .63274 .78036 L .70876 .75509 L p .547 .349 .564 r
F P
0 g
s
.70876 .75509 m .70607 .71609 L .63119 .74165 L p .547 .349 .564 r
F P
0 g
s
.47184 .44587 m .44555 .46763 L .47081 .48194 L p .74 .727 .839 r
F P
0 g
s
.47081 .48194 m .48877 .45566 L .47184 .44587 L p .74 .727 .839 r
F P
0 g
s
.68763 .6379 m .69879 .67668 L .75562 .6389 L p .492 .389 .666 r
F P
0 g
s
.75562 .6389 m .74045 .60175 L .68763 .6379 L p .492 .389 .666 r
F P
0 g
s
.51781 .43513 m .50954 .46142 L .53199 .46259 L p .691 .7 .853 r
F P
0 g
s
.53199 .46259 m .52919 .43574 L .51781 .43513 L p .691 .7 .853 r
F P
0 g
s
.52919 .43574 m .53199 .46259 L .55388 .45907 L p .675 .688 .854 r
F P
0 g
s
.54781 .82736 m .54811 .79144 L .46176 .78775 L p .705 .434 .512 r
F P
0 g
s
.54811 .79144 m .54781 .82736 L .63128 .81671 L p .622 .367 .51 r
F P
0 g
s
.63128 .81671 m .63274 .78036 L .54811 .79144 L p .622 .367 .51 r
F P
0 g
s
.59538 .47543 m .57297 .4512 L .55388 .45907 L p .651 .648 .834 r
F P
0 g
s
.57297 .4512 m .59538 .47543 L .61682 .4586 L p .624 .641 .847 r
F P
0 g
s
.64544 .48076 m .61682 .4586 L .59538 .47543 L p .606 .605 .824 r
F P
0 g
s
.39731 .46788 m .3675 .4906 L .39608 .52042 L p .808 .764 .812 r
F P
0 g
s
.39608 .52042 m .42019 .49248 L .39731 .46788 L p .808 .764 .812 r
F P
0 g
s
.3737 .55135 m .39608 .52042 L .3675 .4906 L p .834 .764 .785 r
F P
0 g
s
.50731 .43217 m .48877 .45566 L .50954 .46142 L p .705 .715 .856 r
F P
0 g
s
.50954 .46142 m .51781 .43513 L .50731 .43217 L p .705 .715 .856 r
F P
0 g
s
.3675 .4906 m .33965 .51694 L .3737 .55135 L p .834 .764 .785 r
F P
0 g
s
.35362 .58509 m .3737 .55135 L .33965 .51694 L p .858 .761 .754 r
F P
0 g
s
.42847 .44871 m .39731 .46788 L .42019 .49248 L p .782 .762 .835 r
F P
0 g
s
.42019 .49248 m .44555 .46763 L .42847 .44871 L p .782 .762 .835 r
F P
0 g
s
.55388 .45907 m .54028 .43393 L .52919 .43574 L p .675 .688 .854 r
F P
0 g
s
.54028 .43393 m .55388 .45907 L .57297 .4512 L p .659 .68 .859 r
F P
0 g
s
.38268 .73066 m .38055 .76949 L .46176 .78775 L p .784 .539 .567 r
F P
0 g
s
.46264 .82382 m .46176 .78775 L .38055 .76949 L p .782 .497 .504 r
F P
0 g
s
.46176 .78775 m .46264 .82382 L .54781 .82736 L p .705 .434 .512 r
F P
0 g
s
.33965 .51694 m .31454 .54683 L .35362 .58509 L p .858 .761 .754 r
F P
0 g
s
.33655 .62127 m .35362 .58509 L .31454 .54683 L p .881 .754 .717 r
F P
0 g
s
.49881 .42717 m .47184 .44587 L .48877 .45566 L p .716 .732 .863 r
F P
0 g
s
.48877 .45566 m .50731 .43217 L .49881 .42717 L p .716 .732 .863 r
F P
0 g
s
.32327 .65932 m .31462 .69844 L .38268 .73066 L p .849 .638 .616 r
F P
0 g
s
.38055 .76949 m .38268 .73066 L .31462 .69844 L p .858 .607 .558 r
F P
0 g
s
.69879 .67668 m .70607 .71609 L .76553 .67766 L p .457 .327 .615 r
F P
0 g
s
.76553 .67766 m .75562 .6389 L .69879 .67668 L p .457 .327 .615 r
F P
0 g
s
.46055 .43299 m .42847 .44871 L .44555 .46763 L p .753 .757 .856 r
F P
0 g
s
.44555 .46763 m .47184 .44587 L .46055 .43299 L p .753 .757 .856 r
F P
0 g
s
.57297 .4512 m .5499 .42989 L .54028 .43393 L p .659 .68 .859 r
F P
0 g
s
.5499 .42989 m .57297 .4512 L .58727 .43971 L p .641 .677 .868 r
F P
0 g
s
.61682 .4586 m .58727 .43971 L .57297 .4512 L p .624 .641 .847 r
F P
0 g
s
.63274 .78036 m .63128 .81671 L .70622 .7924 L p .516 .28 .495 r
F P
0 g
s
.70622 .7924 m .70876 .75509 L .63274 .78036 L p .516 .28 .495 r
F P
0 g
s
.31454 .54683 m .29307 .58005 L .33655 .62127 L p .881 .754 .717 r
F P
0 g
s
.32327 .65932 m .33655 .62127 L .29307 .58005 L p .904 .742 .671 r
F P
0 g
s
.61682 .4586 m .64544 .48076 L .66193 .4539 L p .565 .601 .848 r
F P
0 g
s
.64544 .48076 m .67272 .50624 L .69357 .47359 L p .532 .558 .827 r
F P
0 g
s
.69357 .47359 m .66193 .4539 L .64544 .48076 L p .532 .558 .827 r
F P
0 g
s
.67272 .50624 m .69813 .53501 L .72324 .49721 L p .495 .509 .801 r
F P
0 g
s
.72324 .49721 m .69357 .47359 L .67272 .50624 L p .495 .509 .801 r
F P
0 g
s
.49322 .42062 m .46055 .43299 L .47184 .44587 L p .722 .75 .874 r
F P
0 g
s
.47184 .44587 m .49881 .42717 L .49322 .42062 L p .722 .75 .874 r
F P
0 g
s
.58727 .43971 m .61682 .4586 L .62898 .43801 L p .596 .641 .866 r
F P
0 g
s
.66193 .4539 m .62898 .43801 L .61682 .4586 L p .565 .601 .848 r
F P
0 g
s
.52919 .43574 m .52632 .41153 L .51781 .43513 L closepath p .677 .722 .883 r
F P
0 g
s
.54028 .43393 m .52632 .41153 L .52919 .43574 L closepath p .672 .718 .884 r
F P
0 g
s
.69813 .53501 m .72098 .56695 L .75008 .5248 L p .453 .454 .769 r
F P
0 g
s
.75008 .5248 m .72324 .49721 L .69813 .53501 L p .453 .454 .769 r
F P
0 g
s
.51781 .43513 m .52632 .41153 L .50731 .43217 L closepath p .682 .728 .885 r
F P
0 g
s
.5499 .42989 m .52632 .41153 L .54028 .43393 L closepath p .665 .715 .886 r
F P
0 g
s
.50731 .43217 m .52632 .41153 L .49881 .42717 L closepath p .686 .734 .887 r
F P
0 g
s
.58727 .43971 m .55704 .42403 L .5499 .42989 L p .641 .677 .868 r
F P
0 g
s
.55704 .42403 m .58727 .43971 L .59519 .42575 L p .625 .679 .881 r
F P
0 g
s
.62898 .43801 m .59519 .42575 L .58727 .43971 L p .596 .641 .866 r
F P
0 g
s
.70607 .71609 m .70876 .75509 L .76921 .71706 L p .412 .249 .548 r
F P
0 g
s
.76921 .71706 m .76553 .67766 L .70607 .71609 L p .412 .249 .548 r
F P
0 g
s
.55704 .42403 m .52632 .41153 L .5499 .42989 L closepath p .659 .715 .889 r
F P
0 g
s
.72098 .56695 m .74045 .60175 L .77308 .55622 L p .404 .389 .728 r
F P
0 g
s
.77308 .55622 m .75008 .5248 L .72098 .56695 L p .404 .389 .728 r
F P
0 g
s
.54684 .85919 m .54781 .82736 L .46264 .82382 L p .689 .372 .434 r
F P
0 g
s
.54781 .82736 m .54684 .85919 L .62651 .84924 L p .596 .295 .429 r
F P
0 g
s
.62651 .84924 m .63128 .81671 L .54781 .82736 L p .596 .295 .429 r
F P
0 g
s
.49881 .42717 m .52632 .41153 L .49322 .42062 L closepath p .688 .74 .891 r
F P
0 g
s
.31462 .69844 m .31141 .73763 L .38055 .76949 L p .858 .607 .558 r
F P
0 g
s
.38256 .80625 m .38055 .76949 L .31141 .73763 L p .861 .562 .48 r
F P
0 g
s
.38055 .76949 m .38256 .80625 L .46264 .82382 L p .782 .497 .504 r
F P
0 g
s
.29307 .58005 m .27631 .61616 L .32327 .65932 L p .904 .742 .671 r
F P
0 g
s
.31462 .69844 m .32327 .65932 L .27631 .61616 L p .924 .723 .612 r
F P
0 g
s
.45621 .41832 m .42161 .42699 L .42847 .44871 L p .759 .788 .877 r
F P
0 g
s
.42847 .44871 m .46055 .43299 L .45621 .41832 L p .759 .788 .877 r
F P
0 g
s
.39731 .46788 m .42847 .44871 L .42161 .42699 L p .793 .806 .863 r
F P
0 g
s
.42161 .42699 m .38773 .43944 L .39731 .46788 L p .793 .806 .863 r
F P
0 g
s
.3675 .4906 m .39731 .46788 L .38773 .43944 L p .827 .823 .844 r
F P
0 g
s
.49118 .41322 m .45621 .41832 L .46055 .43299 L p .724 .768 .888 r
F P
0 g
s
.46055 .43299 m .49322 .42062 L .49118 .41322 L p .724 .768 .888 r
F P
0 g
s
.5609 .41696 m .52632 .41153 L .55704 .42403 L closepath p .654 .716 .894 r
F P
0 g
s
.59519 .42575 m .5609 .41696 L .55704 .42403 L p .625 .679 .881 r
F P
0 g
s
.46552 .85588 m .46264 .82382 L .38256 .80625 L p .772 .436 .418 r
F P
0 g
s
.46264 .82382 m .46552 .85588 L .54684 .85919 L p .689 .372 .434 r
F P
0 g
s
.38773 .43944 m .35507 .45592 L .3675 .4906 L p .827 .823 .844 r
F P
0 g
s
.33965 .51694 m .3675 .4906 L .35507 .45592 L p .862 .837 .819 r
F P
0 g
s
.49322 .42062 m .52632 .41153 L .49118 .41322 L closepath p .687 .746 .896 r
F P
0 g
s
.74045 .60175 m .75562 .6389 L .79109 .59115 L p .345 .309 .675 r
F P
0 g
s
.79109 .59115 m .77308 .55622 L .74045 .60175 L p .345 .309 .675 r
F P
0 g
s
.5609 .41696 m .59519 .42575 L .59575 .41076 L p .611 .687 .896 r
F P
0 g
s
.59519 .42575 m .62898 .43801 L .63023 .41573 L p .569 .65 .89 r
F P
0 g
s
.63023 .41573 m .59575 .41076 L .59519 .42575 L p .569 .65 .89 r
F P
0 g
s
.56104 .40943 m .52632 .41153 L .5609 .41696 L closepath p .65 .719 .899 r
F P
0 g
s
.59575 .41076 m .56104 .40943 L .5609 .41696 L p .611 .687 .896 r
F P
0 g
s
.35507 .45592 m .32434 .47664 L .33965 .51694 L p .862 .837 .819 r
F P
0 g
s
.31454 .54683 m .33965 .51694 L .32434 .47664 L p .898 .848 .786 r
F P
0 g
s
.62898 .43801 m .66193 .4539 L .66413 .42461 L p .521 .607 .88 r
F P
0 g
s
.66413 .42461 m .63023 .41573 L .62898 .43801 L p .521 .607 .88 r
F P
0 g
s
.55032 .39621 m .52632 .41153 L .55739 .40225 L closepath p .648 .73 .909 r
F P
0 g
s
.54058 .39201 m .52632 .41153 L .55032 .39621 L closepath p .65 .737 .913 r
F P
0 g
s
.49295 .40576 m .52632 .41153 L .49837 .39905 L closepath p .68 .754 .907 r
F P
0 g
s
.49118 .41322 m .52632 .41153 L .49295 .40576 L closepath p .685 .751 .902 r
F P
0 g
s
.55739 .40225 m .52632 .41153 L .56104 .40943 L closepath p .648 .724 .904 r
F P
0 g
s
.52924 .39012 m .52632 .41153 L .54058 .39201 L closepath p .654 .744 .915 r
F P
0 g
s
.51757 .39076 m .52632 .41153 L .52924 .39012 L closepath p .66 .749 .916 r
F P
0 g
s
.50689 .39385 m .52632 .41153 L .51757 .39076 L closepath p .667 .753 .914 r
F P
0 g
s
.49837 .39905 m .52632 .41153 L .50689 .39385 L closepath p .674 .755 .911 r
F P
0 g
s
.63128 .81671 m .62651 .84924 L .69791 .82659 L p .471 .186 .399 r
F P
0 g
s
.69791 .82659 m .70622 .7924 L .63128 .81671 L p .471 .186 .399 r
F P
0 g
s
.45621 .41832 m .49118 .41322 L .49295 .40576 L p .718 .784 .904 r
F P
0 g
s
.66193 .4539 m .69357 .47359 L .69693 .43772 L p .466 .557 .864 r
F P
0 g
s
.69693 .43772 m .66413 .42461 L .66193 .4539 L p .466 .557 .864 r
F P
0 g
s
.49295 .40576 m .45946 .40342 L .45621 .41832 L p .718 .784 .904 r
F P
0 g
s
.42161 .42699 m .45621 .41832 L .45946 .40342 L p .752 .817 .903 r
F P
0 g
s
.56104 .40943 m .59575 .41076 L .5887 .39636 L p .601 .7 .912 r
F P
0 g
s
.5887 .39636 m .55739 .40225 L .56104 .40943 L p .601 .7 .912 r
F P
0 g
s
.27631 .61616 m .26534 .6545 L .31462 .69844 L p .924 .723 .612 r
F P
0 g
s
.31141 .73763 m .31462 .69844 L .26534 .6545 L p .94 .69 .531 r
F P
0 g
s
.70876 .75509 m .70622 .7924 L .76574 .75586 L p .352 .147 .456 r
F P
0 g
s
.76574 .75586 m .76921 .71706 L .70876 .75509 L p .352 .147 .456 r
F P
0 g
s
.32434 .47664 m .29644 .50176 L .31454 .54683 L p .898 .848 .786 r
F P
0 g
s
.29307 .58005 m .31454 .54683 L .29644 .50176 L p .933 .854 .74 r
F P
0 g
s
.45946 .40342 m .49295 .40576 L .49837 .39905 L p .705 .795 .921 r
F P
0 g
s
.69357 .47359 m .72324 .49721 L .72792 .45539 L p .4 .495 .84 r
F P
0 g
s
.72792 .45539 m .69693 .43772 L .69357 .47359 L p .4 .495 .84 r
F P
0 g
s
.45946 .40342 m .42606 .40474 L .42161 .42699 L p .752 .817 .903 r
F P
0 g
s
.38773 .43944 m .42161 .42699 L .42606 .40474 L p .788 .851 .898 r
F P
0 g
s
.75562 .6389 m .76553 .67766 L .80289 .62899 L p .269 .209 .602 r
F P
0 g
s
.80289 .62899 m .79109 .59115 L .75562 .6389 L p .269 .209 .602 r
F P
0 g
s
.59575 .41076 m .63023 .41573 L .62005 .39414 L p .546 .668 .917 r
F P
0 g
s
.62005 .39414 m .5887 .39636 L .59575 .41076 L p .546 .668 .917 r
F P
0 g
s
.55739 .40225 m .5887 .39636 L .57467 .38416 L p .598 .718 .928 r
F P
0 g
s
.57467 .38416 m .55032 .39621 L .55739 .40225 L p .598 .718 .928 r
F P
0 g
s
.31141 .73763 m .31443 .77562 L .38256 .80625 L p .861 .562 .48 r
F P
0 g
s
.38914 .83949 m .38256 .80625 L .31443 .77562 L p .854 .494 .369 r
F P
0 g
s
.38256 .80625 m .38914 .83949 L .46552 .85588 L p .772 .436 .418 r
F P
0 g
s
.47011 .38992 m .49837 .39905 L .50689 .39385 L p .685 .799 .935 r
F P
0 g
s
.49837 .39905 m .47011 .38992 L .45946 .40342 L p .705 .795 .921 r
F P
0 g
s
.42606 .40474 m .39309 .41008 L .38773 .43944 L p .788 .851 .898 r
F P
0 g
s
.35507 .45592 m .38773 .43944 L .39309 .41008 L p .826 .886 .886 r
F P
0 g
s
.55032 .39621 m .57467 .38416 L .55511 .37562 L p .602 .739 .941 r
F P
0 g
s
.55511 .37562 m .54058 .39201 L .55032 .39621 L p .602 .739 .941 r
F P
0 g
s
.72324 .49721 m .75008 .5248 L .75614 .47787 L p .317 .415 .804 r
F P
0 g
s
.75614 .47787 m .72792 .45539 L .72324 .49721 L p .317 .415 .804 r
F P
0 g
s
.54515 .88533 m .54684 .85919 L .46552 .85588 L p .657 .279 .317 r
F P
0 g
s
.54684 .85919 m .54515 .88533 L .61819 .87638 L p .55 .189 .307 r
F P
0 g
s
.61819 .87638 m .62651 .84924 L .54684 .85919 L p .55 .189 .307 r
F P
0 g
s
.42606 .40474 m .45946 .40342 L .47011 .38992 L p .731 .84 .931 r
F P
0 g
s
.48713 .37938 m .50689 .39385 L .51757 .39076 L p .661 .794 .946 r
F P
0 g
s
.50689 .39385 m .48713 .37938 L .47011 .38992 L p .685 .799 .935 r
F P
0 g
s
.29644 .50176 m .27246 .53124 L .29307 .58005 L p .933 .854 .74 r
F P
0 g
s
.27631 .61616 m .29307 .58005 L .27246 .53124 L p .967 .851 .675 r
F P
0 g
s
.63023 .41573 m .66413 .42461 L .6511 .39601 L p .477 .627 .917 r
F P
0 g
s
.6511 .39601 m .62005 .39414 L .63023 .41573 L p .477 .627 .917 r
F P
0 g
s
.54058 .39201 m .55511 .37562 L .53223 .37177 L p .615 .761 .949 r
F P
0 g
s
.53223 .37177 m .52924 .39012 L .54058 .39201 L p .615 .761 .949 r
F P
0 g
s
.47055 .88235 m .46552 .85588 L .38914 .83949 L p .744 .341 .287 r
F P
0 g
s
.46552 .85588 m .47055 .88235 L .54515 .88533 L p .657 .279 .317 r
F P
0 g
s
.50865 .37307 m .51757 .39076 L .52924 .39012 L p .636 .781 .951 r
F P
0 g
s
.51757 .39076 m .50865 .37307 L .48713 .37938 L p .661 .794 .946 r
F P
0 g
s
.52924 .39012 m .53223 .37177 L .50865 .37307 L p .636 .781 .951 r
F P
0 g
s
.5887 .39636 m .62005 .39414 L .5992 .37574 L p .532 .697 .945 r
F P
0 g
s
.5992 .37574 m .57467 .38416 L .5887 .39636 L p .532 .697 .945 r
F P
0 g
s
.26534 .6545 m .26128 .69413 L .31141 .73763 L p .94 .69 .531 r
F P
0 g
s
.31443 .77562 m .31141 .73763 L .26128 .69413 L p .946 .635 .415 r
F P
0 g
s
.39309 .41008 m .36106 .41983 L .35507 .45592 L p .826 .886 .886 r
F P
0 g
s
.32434 .47664 m .35507 .45592 L .36106 .41983 L p .866 .919 .863 r
F P
0 g
s
.76553 .67766 m .76921 .71706 L .80726 .66886 L p .168 .075 .498 r
F P
0 g
s
.80726 .66886 m .80289 .62899 L .76553 .67766 L p .168 .075 .498 r
F P
0 g
s
.75008 .5248 m .77308 .55622 L .78048 .50527 L p .212 .311 .749 r
F P
0 g
s
.78048 .50527 m .75614 .47787 L .75008 .5248 L p .212 .311 .749 r
F P
0 g
s
.70622 .7924 m .69791 .82659 L .75442 .79259 L p .262 .004 .32 r
F P
0 g
s
.75442 .79259 m .76574 .75586 L .70622 .7924 L p .262 .004 .32 r
F P
0 g
s
.47011 .38992 m .44173 .38444 L .42606 .40474 L p .731 .84 .931 r
F P
0 g
s
.39309 .41008 m .42606 .40474 L .44173 .38444 L p .758 .888 .937 r
F P
0 g
s
.62651 .84924 m .61819 .87638 L .68344 .85604 L p .396 .047 .252 r
F P
0 g
s
.68344 .85604 m .69791 .82659 L .62651 .84924 L p .396 .047 .252 r
F P
0 g
s
.66413 .42461 m .69693 .43772 L .68139 .40244 L p .387 .569 .909 r
F P
0 g
s
.68139 .40244 m .6511 .39601 L .66413 .42461 L p .387 .569 .909 r
F P
0 g
s
.44173 .38444 m .47011 .38992 L .48713 .37938 L p .694 .848 .957 r
F P
0 g
s
.27246 .53124 m .25364 .56488 L .27631 .61616 L p .967 .851 .675 r
F P
0 g
s
.26534 .6545 m .27631 .61616 L .25364 .56488 L p .993 .831 .579 r
F P
0 g
s
.57467 .38416 m .5992 .37574 L .56982 .36278 L p .532 .734 .967 r
F P
0 g
s
.56982 .36278 m .55511 .37562 L .57467 .38416 L p .532 .734 .967 r
F P
0 g
s
.36106 .41983 m .3307 .43442 L .32434 .47664 L p .866 .919 .863 r
F P
0 g
s
.29644 .50176 m .32434 .47664 L .3307 .43442 L p .905 .949 .821 r
F P
0 g
s
.62005 .39414 m .6511 .39601 L .62367 .37145 L p .439 .66 .955 r
F P
0 g
s
.62367 .37145 m .5992 .37574 L .62005 .39414 L p .439 .66 .955 r
F P
0 g
s
.46717 .36849 m .48713 .37938 L .50865 .37307 L p .644 .839 .975 r
F P
0 g
s
.48713 .37938 m .46717 .36849 L .44173 .38444 L p .694 .848 .957 r
F P
0 g
s
.31443 .77562 m .32433 .81096 L .38914 .83949 L p .854 .494 .369 r
F P
0 g
s
.40061 .86762 m .38914 .83949 L .32433 .81096 L p .818 .379 .196 r
F P
0 g
s
.38914 .83949 m .40061 .86762 L .47055 .88235 L p .744 .341 .287 r
F P
0 g
s
.69693 .43772 m .72792 .45539 L .7102 .41396 L p .267 .485 .883 r
F P
0 g
s
.7102 .41396 m .68139 .40244 L .69693 .43772 L p .267 .485 .883 r
F P
0 g
s
.77308 .55622 m .79109 .59115 L .79963 .5375 L p .072 .17 .662 r
F P
0 g
s
.79963 .5375 m .78048 .50527 L .77308 .55622 L p .072 .17 .662 r
F P
0 g
s
.55511 .37562 m .56982 .36278 L .53525 .35691 L p .552 .774 .981 r
F P
0 g
s
.53525 .35691 m .53223 .37177 L .55511 .37562 L p .552 .774 .981 r
F P
0 g
s
.44173 .38444 m .41351 .38308 L .39309 .41008 L p .758 .888 .937 r
F P
0 g
s
.36106 .41983 m .39309 .41008 L .41351 .38308 L p .783 .938 .93 r
F P
0 g
s
.49961 .3589 m .50865 .37307 L .53223 .37177 L p .592 .812 .984 r
F P
0 g
s
.50865 .37307 m .49961 .3589 L .46717 .36849 L p .644 .839 .975 r
F P
0 g
s
.53223 .37177 m .53525 .35691 L .49961 .3589 L p .592 .812 .984 r
F P
0 g
s
.76921 .71706 m .76574 .75586 L .80313 .70957 L p .029 0 .342 r
F P
0 g
s
.80313 .70957 m .80726 .66886 L .76921 .71706 L p .029 0 .342 r
F P
0 g
s
.41351 .38308 m .44173 .38444 L .46717 .36849 L p .694 .902 .97 r
F P
0 g
s
.26128 .69413 m .26511 .73383 L .31443 .77562 L p .946 .635 .415 r
F P
0 g
s
.32433 .81096 m .31443 .77562 L .26511 .73383 L p .922 .535 .24 r
F P
0 g
s
.3307 .43442 m .30295 .45422 L .29644 .50176 L p .905 .949 .821 r
F P
0 g
s
.27246 .53124 m .29644 .50176 L .30295 .45422 L p .935 .965 .746 r
F P
0 g
s
.54271 .90415 m .54515 .88533 L .47055 .88235 L p .585 .122 .122 r
F P
0 g
s
.54515 .88533 m .54271 .90415 L .6062 .89648 L p .46 .015 .105 r
F P
0 g
s
.6062 .89648 m .61819 .87638 L .54515 .88533 L p .46 .015 .105 r
F P
0 g
s
.25364 .56488 m .24129 .60215 L .26534 .6545 L p .993 .831 .579 r
F P
0 g
s
.26128 .69413 m .26534 .6545 L .24129 .60215 L p .997 .779 .433 r
F P
0 g
s
.4778 .90159 m .47055 .88235 L .40061 .86762 L p .67 .177 .068 r
F P
0 g
s
.47055 .88235 m .4778 .90159 L .54271 .90415 L p .585 .122 .122 r
F P
0 g
s
.5992 .37574 m .62367 .37145 L .58456 .35406 L p .421 .709 .983 r
F P
0 g
s
.58456 .35406 m .56982 .36278 L .5992 .37574 L p .421 .709 .983 r
F P
0 g
s
.6511 .39601 m .68139 .40244 L .64768 .37193 L p .302 .595 .947 r
F P
0 g
s
.64768 .37193 m .62367 .37145 L .6511 .39601 L p .302 .595 .947 r
F P
0 g
s
.69791 .82659 m .68344 .85604 L .73476 .82561 L p .122 0 .107 r
F P
0 g
s
.73476 .82561 m .75442 .79259 L .69791 .82659 L p .122 0 .107 r
F P
0 g
s
.72792 .45539 m .75614 .47787 L .73663 .43108 L p .098 .36 .826 r
F P
0 g
s
.73663 .43108 m .7102 .41396 L .72792 .45539 L p .098 .36 .826 r
F P
0 g
s
.41351 .38308 m .38589 .3864 L .36106 .41983 L p .783 .938 .93 r
F P
0 g
s
.3307 .43442 m .36106 .41983 L .38589 .3864 L p .799 .983 .896 r
F P
0 g
s
.79109 .59115 m .80289 .62899 L .81222 .57415 L p 0 0 .521 r
F P
0 g
s
.81222 .57415 m .79963 .5375 L .79109 .59115 L p 0 0 .521 r
F P
0 g
s
.44721 .36173 m .46717 .36849 L .49961 .3589 L p .602 .882 .992 r
F P
0 g
s
.46717 .36849 m .44721 .36173 L .41351 .38308 L p .694 .902 .97 r
F P
0 g
s
.61819 .87638 m .6062 .89648 L .66267 .87908 L p .26 0 .006 r
F P
0 g
s
.66267 .87908 m .68344 .85604 L .61819 .87638 L p .26 0 .006 r
F P
0 g
s
.56982 .36278 m .58456 .35406 L .5383 .34615 L p .441 .769 .997 r
F P
0 g
s
.5383 .34615 m .53525 .35691 L .56982 .36278 L p .441 .769 .997 r
F P
0 g
s
.30295 .45422 m .27895 .47949 L .27246 .53124 L p .935 .965 .746 r
F P
0 g
s
.25364 .56488 m .27246 .53124 L .27895 .47949 L p .938 .946 .613 r
F P
0 g
s
.38589 .3864 m .41351 .38308 L .44721 .36173 L p .673 .948 .957 r
F P
0 g
s
.76574 .75586 m .75442 .79259 L .78965 .74964 L p 0 0 .103 r
F P
0 g
s
.78965 .74964 m .80313 .70957 L .76574 .75586 L p 0 0 .103 r
F P
0 g
s
.49054 .34883 m .49961 .3589 L .53525 .35691 L p .506 .832 .999 r
F P
0 g
s
.49961 .3589 m .49054 .34883 L .44721 .36173 L p .602 .882 .992 r
F P
0 g
s
.24129 .60215 m .2367 .64226 L .26128 .69413 L p .997 .779 .433 r
F P
0 g
s
.26511 .73383 m .26128 .69413 L .2367 .64226 L p .947 .661 .209 r
F P
0 g
s
.53525 .35691 m .5383 .34615 L .49054 .34883 L p .506 .832 .999 r
F P
0 g
s
.32433 .81096 m .34153 .84204 L .40061 .86762 L p .818 .379 .196 r
F P
0 g
s
.4171 .88898 m .40061 .86762 L .34153 .84204 L p .706 .172 0 r
F P
0 g
s
.40061 .86762 m .4171 .88898 L .4778 .90159 L p .67 .177 .068 r
F P
0 g
s
.75614 .47787 m .78048 .50527 L .75955 .45419 L p 0 .171 .708 r
F P
0 g
s
.75955 .45419 m .73663 .43108 L .75614 .47787 L p 0 .171 .708 r
F P
0 g
s
.68139 .40244 m .7102 .41396 L .67068 .3779 L p .094 .476 .894 r
F P
0 g
s
.67068 .3779 m .64768 .37193 L .68139 .40244 L p .094 .476 .894 r
F P
0 g
s
.26511 .73383 m .27764 .77213 L .32433 .81096 L p .922 .535 .24 r
F P
0 g
s
.34153 .84204 m .32433 .81096 L .27764 .77213 L p .825 .354 0 r
F P
0 g
s
.38589 .3864 m .35953 .39503 L .3307 .43442 L p .799 .983 .896 r
F P
0 g
s
.30295 .45422 m .3307 .43442 L .35953 .39503 L p .783 .997 .806 r
F P
0 g
s
.62367 .37145 m .64768 .37193 L .5991 .3502 L p .236 .638 .959 r
F P
0 g
s
.5991 .3502 m .58456 .35406 L .62367 .37145 L p .236 .638 .959 r
F P
0 g
s
.80289 .62899 m .80726 .66886 L .8169 .61449 L p 0 0 .301 r
F P
0 g
s
.8169 .61449 m .81222 .57415 L .80289 .62899 L p 0 0 .301 r
F P
0 g
s
.27895 .47949 m .26001 .51025 L .25364 .56488 L p .938 .946 .613 r
F P
0 g
s
.24129 .60215 m .25364 .56488 L .26001 .51025 L p .876 .851 .393 r
F P
0 g
s
.42757 .3598 m .44721 .36173 L .49054 .34883 L p .501 .891 .954 r
F P
0 g
s
.44721 .36173 m .42757 .3598 L .38589 .3864 L p .673 .948 .957 r
F P
0 g
s
.68344 .85604 m .66267 .87908 L .70669 .85319 L p 0 0 0 r
F P
0 g
s
.70669 .85319 m .73476 .82561 L .68344 .85604 L p 0 0 0 r
F P
0 g
s
.53952 .91407 m .54271 .90415 L .4778 .90159 L p .405 0 0 r
F P
0 g
s
.54271 .90415 m .53952 .91407 L .59061 .90794 L p .259 0 0 r
F P
0 g
s
.59061 .90794 m .6062 .89648 L .54271 .90415 L p .259 0 0 r
F P
0 g
s
.35953 .39503 m .38589 .3864 L .42757 .3598 L p .595 .95 .87 r
F P
0 g
s
.48724 .91203 m .4778 .90159 L .4171 .88898 L p .468 0 0 r
F P
0 g
s
.4778 .90159 m .48724 .91203 L .53952 .91407 L p .405 0 0 r
F P
0 g
s
.78048 .50527 m .79963 .5375 L .77767 .48346 L p 0 0 .492 r
F P
0 g
s
.77767 .48346 m .75955 .45419 L .78048 .50527 L p 0 0 .492 r
F P
0 g
s
.58456 .35406 m .5991 .3502 L .5413 .34029 L p .237 .702 .946 r
F P
0 g
s
.5413 .34029 m .5383 .34615 L .58456 .35406 L p .237 .702 .946 r
F P
0 g
s
.2367 .64226 m .24103 .68404 L .26511 .73383 L p .947 .661 .209 r
F P
0 g
s
.27764 .77213 m .26511 .73383 L .24103 .68404 L p .79 .442 0 r
F P
0 g
s
.7102 .41396 m .73663 .43108 L .69189 .39011 L p 0 .266 .742 r
F P
0 g
s
.69189 .39011 m .67068 .3779 L .7102 .41396 L p 0 .266 .742 r
F P
0 g
s
.35953 .39503 m .33528 .4096 L .30295 .45422 L p .783 .997 .806 r
F P
0 g
s
.27895 .47949 m .30295 .45422 L .33528 .4096 L p .692 .927 .61 r
F P
0 g
s
.75442 .79259 m .73476 .82561 L .76635 .78735 L p 0 0 0 r
F P
0 g
s
.76635 .78735 m .78965 .74964 L .75442 .79259 L p 0 0 0 r
F P
0 g
s
.48158 .34365 m .49054 .34883 L .5383 .34615 L p .332 .793 .941 r
F P
0 g
s
.49054 .34883 m .48158 .34365 L .42757 .3598 L p .501 .891 .954 r
F P
0 g
s
.6062 .89648 m .59061 .90794 L .63579 .8941 L p .005 0 0 r
F P
0 g
s
.63579 .8941 m .66267 .87908 L .6062 .89648 L p .005 0 0 r
F P
0 g
s
.80726 .66886 m .80313 .70957 L .81249 .65741 L p 0 0 0 r
F P
0 g
s
.81249 .65741 m .8169 .61449 L .80726 .66886 L p 0 0 0 r
F P
0 g
s
.5383 .34615 m .5413 .34029 L .48158 .34365 L p .332 .793 .941 r
F P
0 g
s
.64768 .37193 m .67068 .3779 L .61308 .35208 L p 0 .468 .825 r
F P
0 g
s
.61308 .35208 m .5991 .3502 L .64768 .37193 L p 0 .468 .825 r
F P
0 g
s
.27764 .77213 m .29935 .80737 L .34153 .84204 L p .825 .354 0 r
F P
0 g
s
.36617 .86715 m .34153 .84204 L .29935 .80737 L p .583 .054 0 r
F P
0 g
s
.34153 .84204 m .36617 .86715 L .4171 .88898 L p .706 .172 0 r
F P
0 g
s
.26001 .51025 m .24754 .54624 L .24129 .60215 L p .876 .851 .393 r
F P
0 g
s
.2367 .64226 m .24129 .60215 L .24754 .54624 L p .706 .641 .083 r
F P
0 g
s
.43851 .90196 m .4171 .88898 L .36617 .86715 L p .42 0 0 r
F P
0 g
s
.4171 .88898 m .43851 .90196 L .48724 .91203 L p .468 0 0 r
F P
0 g
s
.42757 .3598 m .40872 .3635 L .35953 .39503 L p .595 .95 .87 r
F P
0 g
s
.33528 .4096 m .35953 .39503 L .40872 .3635 L p .412 .825 .635 r
F P
0 g
s
.79963 .5375 m .81222 .57415 L .78964 .51875 L p .726 .395 0 r
F P
0 g
s
.78964 .51875 m .77767 .48346 L .79963 .5375 L p .726 .395 0 r
F P
0 g
s
.40872 .3635 m .42757 .3598 L .48158 .34365 L p .288 .786 .771 r
F P
0 g
s
.33528 .4096 m .31419 .43064 L .27895 .47949 L p .692 .927 .61 r
F P
0 g
s
.26001 .51025 m .27895 .47949 L .31419 .43064 L p 0 0 0 r
F P
0 g
s
.73663 .43108 m .75955 .45419 L .71039 .40922 L p .549 .033 0 r
F P
0 g
s
.71039 .40922 m .69189 .39011 L .73663 .43108 L p .549 .033 0 r
F P
0 g
s
.24103 .68404 m .25514 .72601 L .27764 .77213 L p .79 .442 0 r
F P
0 g
s
.29935 .80737 m .27764 .77213 L .25514 .72601 L p 0 0 .448 r
F P
0 g
s
.66267 .87908 m .63579 .8941 L .67059 .87361 L p .376 .807 .635 r
F P
0 g
s
.67059 .87361 m .70669 .85319 L .66267 .87908 L p .376 .807 .635 r
F P
0 g
s
.5991 .3502 m .61308 .35208 L .5442 .34026 L p 0 .495 .725 r
F P
0 g
s
.5442 .34026 m .5413 .34029 L .5991 .3502 L p 0 .495 .725 r
F P
0 g
s
.80313 .70957 m .78965 .74964 L .7981 .70139 L p .818 .821 .341 r
F P
0 g
s
.7981 .70139 m .81249 .65741 L .80313 .70957 L p .818 .821 .341 r
F P
0 g
s
.73476 .82561 m .70669 .85319 L .73328 .82084 L p .622 .896 .585 r
F P
0 g
s
.73328 .82084 m .76635 .78735 L .73476 .82561 L p .622 .896 .585 r
F P
0 g
s
.24754 .54624 m .2429 .5868 L .2367 .64226 L p .706 .641 .083 r
F P
0 g
s
.24103 .68404 m .2367 .64226 L .2429 .5868 L p 0 0 .245 r
F P
0 g
s
.48158 .34365 m .47295 .34428 L .40872 .3635 L p .288 .786 .771 r
F P
0 g
s
.47295 .34428 m .48158 .34365 L .5413 .34029 L p 0 0 0 r
F P
0 g
s
.67068 .3779 m .69189 .39011 L .62603 .36062 L p .418 0 0 r
F P
0 g
s
.62603 .36062 m .61308 .35208 L .67068 .3779 L p .418 0 0 r
F P
0 g
s
.53565 .91369 m .53952 .91407 L .48724 .91203 L p 0 .562 .716 r
F P
0 g
s
.53952 .91407 m .53565 .91369 L .5717 .90936 L p .116 .668 .736 r
F P
0 g
s
.5717 .90936 m .59061 .90794 L .53952 .91407 L p .116 .668 .736 r
F P
0 g
s
.5413 .34029 m .5442 .34026 L .47295 .34428 L p 0 0 0 r
F P
0 g
s
.49871 .91225 m .48724 .91203 L .43851 .90196 L p 0 .521 .772 r
F P
0 g
s
.48724 .91203 m .49871 .91225 L .53565 .91369 L p 0 .562 .716 r
F P
0 g
s
.81222 .57415 m .8169 .61449 L .7941 .55952 L p .92 .638 .152 r
F P
0 g
s
.7941 .55952 m .78964 .51875 L .81222 .57415 L p .92 .638 .152 r
F P
0 g
s
.29935 .80737 m .33025 .83774 L .36617 .86715 L p .583 .054 0 r
F P
0 g
s
.36617 .86715 m .39796 .88464 L .43851 .90196 L p .42 0 0 r
F P
0 g
s
.39796 .88464 m .36617 .86715 L .33025 .83774 L p 0 .298 .749 r
F P
0 g
s
.59061 .90794 m .5717 .90936 L .60336 .89963 L p .333 .816 .819 r
F P
0 g
s
.60336 .89963 m .63579 .8941 L .59061 .90794 L p .333 .816 .819 r
F P
0 g
s
.40872 .3635 m .39128 .37368 L .33528 .4096 L p .412 .825 .635 r
F P
0 g
s
.31419 .43064 m .33528 .4096 L .39128 .37368 L p 0 0 0 r
F P
0 g
s
.31419 .43064 m .29746 .45846 L .26001 .51025 L p 0 0 0 r
F P
0 g
s
.24754 .54624 m .26001 .51025 L .29746 .45846 L p 0 0 .044 r
F P
0 g
s
.39128 .37368 m .40872 .3635 L .47295 .34428 L p .012 0 0 r
F P
0 g
s
.75955 .45419 m .77767 .48346 L .72509 .4357 L p .8 .321 0 r
F P
0 g
s
.72509 .4357 m .71039 .40922 L .75955 .45419 L p .8 .321 0 r
F P
0 g
s
.46442 .90515 m .43851 .90196 L .39796 .88464 L p .02 .531 .867 r
F P
0 g
s
.43851 .90196 m .46442 .90515 L .49871 .91225 L p 0 .521 .772 r
F P
0 g
s
.25514 .72601 m .27948 .76638 L .29935 .80737 L p 0 0 .448 r
F P
0 g
s
.33025 .83774 m .29935 .80737 L .27948 .76638 L p 0 .178 .712 r
F P
0 g
s
.78965 .74964 m .76635 .78735 L .77335 .7446 L p .906 .951 .604 r
F P
0 g
s
.77335 .7446 m .7981 .70139 L .78965 .74964 L p .906 .951 .604 r
F P
0 g
s
.2429 .5868 m .24727 .63086 L .24103 .68404 L p 0 0 .245 r
F P
0 g
s
.25514 .72601 m .24103 .68404 L .24727 .63086 L p 0 0 .504 r
F P
0 g
s
.61308 .35208 m .62603 .36062 L .54689 .3471 L p .422 0 0 r
F P
0 g
s
.54689 .3471 m .5442 .34026 L .61308 .35208 L p .422 0 0 r
F P
0 g
s
.70669 .85319 m .67059 .87361 L .69109 .84823 L p .726 .989 .827 r
F P
0 g
s
.69109 .84823 m .73328 .82084 L .70669 .85319 L p .726 .989 .827 r
F P
0 g
s
.63579 .8941 m .60336 .89963 L .6274 .88534 L p .569 .937 .906 r
F P
0 g
s
.6274 .88534 m .67059 .87361 L .63579 .8941 L p .569 .937 .906 r
F P
0 g
s
.69189 .39011 m .71039 .40922 L .63737 .37672 L p .678 .132 0 r
F P
0 g
s
.63737 .37672 m .62603 .36062 L .69189 .39011 L p .678 .132 0 r
F P
0 g
s
.8169 .61449 m .81249 .65741 L .78989 .60472 L p .993 .781 .408 r
F P
0 g
s
.78989 .60472 m .7941 .55952 L .8169 .61449 L p .993 .781 .408 r
F P
0 g
s
.46494 .3517 m .47295 .34428 L .5442 .34026 L p .285 0 0 r
F P
0 g
s
.47295 .34428 m .46494 .3517 L .39128 .37368 L p .012 0 0 r
F P
0 g
s
.5442 .34026 m .54689 .3471 L .46494 .3517 L p .285 0 0 r
F P
0 g
s
.29746 .45846 m .28641 .49307 L .24754 .54624 L p 0 0 .044 r
F P
0 g
s
.2429 .5868 m .24754 .54624 L .28641 .49307 L p 0 0 .31 r
F P
0 g
s
.39128 .37368 m .37605 .39112 L .31419 .43064 L p 0 0 0 r
F P
0 g
s
.29746 .45846 m .31419 .43064 L .37605 .39112 L p .091 0 .06 r
F P
0 g
s
.77767 .48346 m .78964 .51875 L .73481 .46965 L p .915 .515 .2 r
F P
0 g
s
.73481 .46965 m .72509 .4357 L .77767 .48346 L p .915 .515 .2 r
F P
0 g
s
.33025 .83774 m .36984 .86146 L .39796 .88464 L p 0 .298 .749 r
F P
0 g
s
.43617 .89302 m .39796 .88464 L .36984 .86146 L p .162 .554 .929 r
F P
0 g
s
.39796 .88464 m .43617 .89302 L .46442 .90515 L p .02 .531 .867 r
F P
0 g
s
.76635 .78735 m .73328 .82084 L .73845 .78497 L p .906 .983 .77 r
F P
0 g
s
.73845 .78497 m .77335 .7446 L .76635 .78735 L p .906 .983 .77 r
F P
0 g
s
.37605 .39112 m .39128 .37368 L .46494 .3517 L p .259 0 0 r
F P
0 g
s
.27948 .76638 m .31391 .80321 L .33025 .83774 L p 0 .178 .712 r
F P
0 g
s
.36984 .86146 m .33025 .83774 L .31391 .80321 L p .105 .411 .861 r
F P
0 g
s
.5312 .90199 m .53565 .91369 L .49871 .91225 L p .382 .79 .982 r
F P
0 g
s
.53565 .91369 m .5312 .90199 L .55 .89971 L p .45 .839 .984 r
F P
0 g
s
.55 .89971 m .5717 .90936 L .53565 .91369 L p .45 .839 .984 r
F P
0 g
s
.24727 .63086 m .26152 .6769 L .25514 .72601 L p 0 0 .504 r
F P
0 g
s
.27948 .76638 m .25514 .72601 L .26152 .6769 L p .037 .171 .675 r
F P
0 g
s
.51189 .90123 m .49871 .91225 L .46442 .90515 L p .355 .748 .986 r
F P
0 g
s
.49871 .91225 m .51189 .90123 L .5312 .90199 L p .382 .79 .982 r
F P
0 g
s
.5717 .90936 m .55 .89971 L .56639 .89461 L p .542 .882 .987 r
F P
0 g
s
.56639 .89461 m .60336 .89963 L .5717 .90936 L p .542 .882 .987 r
F P
0 g
s
.81249 .65741 m .7981 .70139 L .77622 .65281 L p .995 .848 .582 r
F P
0 g
s
.77622 .65281 m .78989 .60472 L .81249 .65741 L p .995 .848 .582 r
F P
0 g
s
.67059 .87361 m .6274 .88534 L .64112 .86781 L p .734 .966 .936 r
F P
0 g
s
.64112 .86781 m .69109 .84823 L .67059 .87361 L p .734 .966 .936 r
F P
0 g
s
.49406 .8975 m .46442 .90515 L .43617 .89302 L p .368 .716 .987 r
F P
0 g
s
.46442 .90515 m .49406 .8975 L .51189 .90123 L p .355 .748 .986 r
F P
0 g
s
.62603 .36062 m .63737 .37672 L .54924 .36177 L p .617 .107 .017 r
F P
0 g
s
.54924 .36177 m .54689 .3471 L .62603 .36062 L p .617 .107 .017 r
F P
0 g
s
.71039 .40922 m .72509 .4357 L .64641 .40105 L p .797 .341 .157 r
F P
0 g
s
.64641 .40105 m .63737 .37672 L .71039 .40922 L p .797 .341 .157 r
F P
0 g
s
.28641 .49307 m .28229 .53401 L .2429 .5868 L p 0 0 .31 r
F P
0 g
s
.24727 .63086 m .2429 .5868 L .28229 .53401 L p .144 .057 .491 r
F P
0 g
s
.60336 .89963 m .56639 .89461 L .57862 .88719 L p .632 .904 .984 r
F P
0 g
s
.57862 .88719 m .6274 .88534 L .60336 .89963 L p .632 .904 .984 r
F P
0 g
s
.37605 .39112 m .36393 .41642 L .29746 .45846 L p .091 0 .06 r
F P
0 g
s
.28641 .49307 m .29746 .45846 L .36393 .41642 L p .251 0 .292 r
F P
0 g
s
.78964 .51875 m .7941 .55952 L .73845 .51074 L p .946 .627 .398 r
F P
0 g
s
.73845 .51074 m .73481 .46965 L .78964 .51875 L p .946 .627 .398 r
F P
0 g
s
.45793 .36686 m .46494 .3517 L .54689 .3471 L p .482 .004 .042 r
F P
0 g
s
.46494 .3517 m .45793 .36686 L .37605 .39112 L p .259 0 0 r
F P
0 g
s
.73328 .82084 m .69109 .84823 L .69435 .82037 L p .863 .964 .864 r
F P
0 g
s
.69435 .82037 m .73845 .78497 L .73328 .82084 L p .863 .964 .864 r
F P
0 g
s
.26152 .6769 m .28599 .72299 L .27948 .76638 L p .037 .171 .675 r
F P
0 g
s
.31391 .80321 m .27948 .76638 L .28599 .72299 L p .203 .343 .783 r
F P
0 g
s
.54689 .3471 m .54924 .36177 L .45793 .36686 L p .482 .004 .042 r
F P
0 g
s
.31391 .80321 m .35763 .8345 L .36984 .86146 L p .105 .411 .861 r
F P
0 g
s
.41697 .87692 m .36984 .86146 L .35763 .8345 L p .311 .569 .93 r
F P
0 g
s
.36984 .86146 m .41697 .87692 L .43617 .89302 L p .162 .554 .929 r
F P
0 g
s
.47954 .89116 m .43617 .89302 L .41697 .87692 L p .409 .692 .978 r
F P
0 g
s
.43617 .89302 m .47954 .89116 L .49406 .8975 L p .368 .716 .987 r
F P
0 g
s
.7981 .70139 m .77335 .7446 L .75282 .7018 L p .964 .873 .698 r
F P
0 g
s
.75282 .7018 m .77622 .65281 L .7981 .70139 L p .964 .873 .698 r
F P
0 g
s
.36393 .41642 m .37605 .39112 L .45793 .36686 L p .406 .033 .215 r
F P
0 g
s
.28229 .53401 m .28618 .58029 L .24727 .63086 L p .144 .057 .491 r
F P
0 g
s
.26152 .6769 m .24727 .63086 L .28618 .58029 L p .26 .213 .613 r
F P
0 g
s
.6274 .88534 m .57862 .88719 L .58536 .87818 L p .699 .899 .968 r
F P
0 g
s
.58536 .87818 m .64112 .86781 L .6274 .88534 L p .699 .899 .968 r
F P
0 g
s
.72509 .4357 m .73481 .46965 L .6524 .43397 L p .84 .467 .347 r
F P
0 g
s
.6524 .43397 m .64641 .40105 L .72509 .4357 L p .84 .467 .347 r
F P
0 g
s
.69109 .84823 m .64112 .86781 L .64269 .84878 L p .803 .923 .916 r
F P
0 g
s
.64269 .84878 m .69435 .82037 L .69109 .84823 L p .803 .923 .916 r
F P
0 g
s
.52632 .8785 m .5312 .90199 L .51189 .90123 L closepath p .576 .801 .985 r
F P
0 g
s
.52632 .8785 m .55 .89971 L .5312 .90199 L closepath p .592 .813 .984 r
F P
0 g
s
.28599 .72299 m .32035 .76695 L .31391 .80321 L p .203 .343 .783 r
F P
0 g
s
.35763 .8345 m .31391 .80321 L .32035 .76695 L p .329 .474 .853 r
F P
0 g
s
.52632 .8785 m .51189 .90123 L .49406 .8975 L closepath p .565 .787 .982 r
F P
0 g
s
.7941 .55952 m .78989 .60472 L .73502 .55801 L p .942 .692 .531 r
F P
0 g
s
.73502 .55801 m .73845 .51074 L .7941 .55952 L p .942 .692 .531 r
F P
0 g
s
.63737 .37672 m .64641 .40105 L .55112 .38509 L p .703 .284 .248 r
F P
0 g
s
.55112 .38509 m .54924 .36177 L .63737 .37672 L p .703 .284 .248 r
F P
0 g
s
.52632 .8785 m .56639 .89461 L .55 .89971 L closepath p .612 .82 .98 r
F P
0 g
s
.36393 .41642 m .35589 .4498 L .28641 .49307 L p .251 0 .292 r
F P
0 g
s
.28229 .53401 m .28641 .49307 L .35589 .4498 L p .354 .141 .445 r
F P
0 g
s
.35763 .8345 m .40913 .8584 L .41697 .87692 L p .311 .569 .93 r
F P
0 g
s
.4699 .88285 m .41697 .87692 L .40913 .8584 L p .461 .675 .957 r
F P
0 g
s
.41697 .87692 m .4699 .88285 L .47954 .89116 L p .409 .692 .978 r
F P
0 g
s
.52632 .8785 m .49406 .8975 L .47954 .89116 L closepath p .562 .774 .977 r
F P
0 g
s
.77335 .7446 m .73845 .78497 L .72004 .74935 L p .92 .878 .778 r
F P
0 g
s
.72004 .74935 m .75282 .7018 L .77335 .7446 L p .92 .878 .778 r
F P
0 g
s
.52632 .8785 m .57862 .88719 L .56639 .89461 L closepath p .632 .823 .974 r
F P
0 g
s
.45233 .39052 m .45793 .36686 L .54924 .36177 L p .581 .188 .263 r
F P
0 g
s
.45793 .36686 m .45233 .39052 L .36393 .41642 L p .406 .033 .215 r
F P
0 g
s
.52632 .8785 m .47954 .89116 L .4699 .88285 L closepath p .566 .761 .97 r
F P
0 g
s
.28618 .58029 m .2988 .63035 L .26152 .6769 L p .26 .213 .613 r
F P
0 g
s
.28599 .72299 m .26152 .6769 L .2988 .63035 L p .346 .332 .7 r
F P
0 g
s
.54924 .36177 m .55112 .38509 L .45233 .39052 L p .581 .188 .263 r
F P
0 g
s
.32035 .76695 m .36359 .80647 L .35763 .8345 L p .329 .474 .853 r
F P
0 g
s
.40913 .8584 m .35763 .8345 L .36359 .80647 L p .429 .578 .899 r
F P
0 g
s
.64112 .86781 m .58536 .87818 L .58577 .86853 L p .736 .872 .944 r
F P
0 g
s
.58577 .86853 m .64269 .84878 L .64112 .86781 L p .736 .872 .944 r
F P
0 g
s
.35589 .4498 m .36393 .41642 L .45233 .39052 L p .489 .186 .379 r
F P
0 g
s
.52632 .8785 m .58536 .87818 L .57862 .88719 L closepath p .65 .821 .966 r
F P
0 g
s
.73845 .78497 m .69435 .82037 L .679 .79297 L p .869 .872 .837 r
F P
0 g
s
.679 .79297 m .72004 .74935 L .73845 .78497 L p .869 .872 .837 r
F P
0 g
s
.78989 .60472 m .77622 .65281 L .72391 .60989 L p .923 .731 .625 r
F P
0 g
s
.72391 .60989 m .73502 .55801 L .78989 .60472 L p .923 .731 .625 r
F P
0 g
s
.40913 .8584 m .46625 .8734 L .4699 .88285 L p .461 .675 .957 r
F P
0 g
s
.52632 .8785 m .4699 .88285 L .46625 .8734 L closepath p .575 .751 .961 r
F P
0 g
s
.73481 .46965 m .73845 .51074 L .65464 .47526 L p .85 .545 .473 r
F P
0 g
s
.65464 .47526 m .6524 .43397 L .73481 .46965 L p .85 .545 .473 r
F P
0 g
s
.35589 .4498 m .35289 .49101 L .28229 .53401 L p .354 .141 .445 r
F P
0 g
s
.28618 .58029 m .28229 .53401 L .35289 .49101 L p .422 .257 .551 r
F P
0 g
s
.36359 .80647 m .41395 .83937 L .40913 .8584 L p .429 .578 .899 r
F P
0 g
s
.46625 .8734 m .40913 .8584 L .41395 .83937 L p .514 .666 .931 r
F P
0 g
s
.52632 .8785 m .58577 .86853 L .58536 .87818 L closepath p .662 .814 .956 r
F P
0 g
s
.2988 .63035 m .32039 .68209 L .28599 .72299 L p .346 .332 .7 r
F P
0 g
s
.32035 .76695 m .28599 .72299 L .32039 .68209 L p .414 .429 .766 r
F P
0 g
s
.64641 .40105 m .6524 .43397 L .55237 .41749 L p .74 .394 .396 r
F P
0 g
s
.55237 .41749 m .55112 .38509 L .64641 .40105 L p .74 .394 .396 r
F P
0 g
s
.69435 .82037 m .64269 .84878 L .63144 .83029 L p .812 .857 .882 r
F P
0 g
s
.63144 .83029 m .679 .79297 L .69435 .82037 L p .812 .857 .882 r
F P
0 g
s
.41395 .83937 m .4691 .86381 L .46625 .8734 L p .514 .666 .931 r
F P
0 g
s
.52632 .8785 m .46625 .8734 L .4691 .86381 L closepath p .588 .745 .951 r
F P
0 g
s
.52632 .8785 m .56763 .85147 L .57967 .85928 L closepath p .671 .79 .938 r
F P
0 g
s
.52632 .8785 m .5509 .84601 L .56763 .85147 L closepath p .667 .777 .931 r
F P
0 g
s
.52632 .8785 m .53136 .84354 L .5509 .84601 L closepath p .659 .765 .928 r
F P
0 g
s
.52632 .8785 m .51124 .84438 L .53136 .84354 L closepath p .648 .754 .927 r
F P
0 g
s
.52632 .8785 m .49285 .84841 L .51124 .84438 L closepath p .634 .747 .929 r
F P
0 g
s
.52632 .8785 m .47827 .85515 L .49285 .84841 L closepath p .619 .742 .934 r
F P
0 g
s
.52632 .8785 m .4691 .86381 L .47827 .85515 L closepath p .604 .742 .942 r
F P
0 g
s
.52632 .8785 m .57967 .85928 L .58577 .86853 L closepath p .669 .803 .946 r
F P
0 g
s
.64269 .84878 m .58577 .86853 L .57967 .85928 L p .747 .835 .918 r
F P
0 g
s
.57967 .85928 m .63144 .83029 L .64269 .84878 L p .747 .835 .918 r
F P
0 g
s
.77622 .65281 m .75282 .7018 L .70495 .66419 L p .898 .756 .697 r
F P
0 g
s
.70495 .66419 m .72391 .60989 L .77622 .65281 L p .898 .756 .697 r
F P
0 g
s
.44862 .4231 m .45233 .39052 L .55112 .38509 L p .631 .307 .405 r
F P
0 g
s
.45233 .39052 m .44862 .4231 L .35589 .4498 L p .489 .186 .379 r
F P
0 g
s
.32039 .68209 m .35051 .73304 L .32035 .76695 L p .414 .429 .766 r
F P
0 g
s
.36359 .80647 m .32035 .76695 L .35051 .73304 L p .469 .512 .82 r
F P
0 g
s
.35289 .49101 m .35589 .4498 L .44862 .4231 L p .539 .291 .488 r
F P
0 g
s
.55112 .38509 m .55237 .41749 L .44862 .4231 L p .631 .307 .405 r
F P
0 g
s
.35289 .49101 m .35572 .53913 L .28618 .58029 L p .422 .257 .551 r
F P
0 g
s
.2988 .63035 m .28618 .58029 L .35572 .53913 L p .471 .347 .629 r
F P
0 g
s
.43139 .82196 m .47827 .85515 L .4691 .86381 L p .562 .665 .906 r
F P
0 g
s
.4691 .86381 m .41395 .83937 L .43139 .82196 L p .562 .665 .906 r
F P
0 g
s
.35051 .73304 m .38808 .78052 L .36359 .80647 L p .469 .512 .82 r
F P
0 g
s
.41395 .83937 m .36359 .80647 L .38808 .78052 L p .518 .589 .866 r
F P
0 g
s
.73845 .51074 m .73502 .55801 L .65253 .52406 L p .847 .598 .562 r
F P
0 g
s
.65253 .52406 m .65464 .47526 L .73845 .51074 L p .847 .598 .562 r
F P
0 g
s
.38808 .78052 m .43139 .82196 L .41395 .83937 L p .518 .589 .866 r
F P
0 g
s
.63144 .83029 m .57967 .85928 L .56763 .85147 L p .742 .796 .896 r
F P
0 g
s
.75282 .7018 m .72004 .74935 L .67857 .71828 L p .869 .774 .755 r
F P
0 g
s
.67857 .71828 m .70495 .66419 L .75282 .7018 L p .869 .774 .755 r
F P
0 g
s
.45987 .80825 m .49285 .84841 L .47827 .85515 L p .605 .671 .887 r
F P
0 g
s
.47827 .85515 m .43139 .82196 L .45987 .80825 L p .605 .671 .887 r
F P
0 g
s
.6524 .43397 m .65464 .47526 L .55284 .45887 L p .755 .468 .497 r
F P
0 g
s
.55284 .45887 m .55237 .41749 L .6524 .43397 L p .755 .468 .497 r
F P
0 g
s
.679 .79297 m .63144 .83029 L .60816 .81449 L p .794 .793 .851 r
F P
0 g
s
.56763 .85147 m .60816 .81449 L .63144 .83029 L p .742 .796 .896 r
F P
0 g
s
.72004 .74935 m .679 .79297 L .64578 .7693 L p .835 .786 .805 r
F P
0 g
s
.64578 .7693 m .67857 .71828 L .72004 .74935 L p .835 .786 .805 r
F P
0 g
s
.60816 .81449 m .56763 .85147 L .5509 .84601 L p .726 .76 .879 r
F P
0 g
s
.35572 .53913 m .3649 .59257 L .2988 .63035 L p .471 .347 .629 r
F P
0 g
s
.32039 .68209 m .2988 .63035 L .3649 .59257 L p .508 .42 .691 r
F P
0 g
s
.60816 .81449 m .64578 .7693 L .679 .79297 L p .794 .793 .851 r
F P
0 g
s
.49629 .79999 m .51124 .84438 L .49285 .84841 L p .642 .684 .874 r
F P
0 g
s
.49285 .84841 m .45987 .80825 L .49629 .79999 L p .642 .684 .874 r
F P
0 g
s
.44862 .4231 m .44723 .46445 L .35289 .49101 L p .539 .291 .488 r
F P
0 g
s
.35572 .53913 m .35289 .49101 L .44723 .46445 L p .571 .369 .568 r
F P
0 g
s
.5509 .84601 m .57521 .80333 L .60816 .81449 L p .726 .76 .879 r
F P
0 g
s
.57521 .80333 m .5509 .84601 L .53136 .84354 L p .703 .729 .87 r
F P
0 g
s
.44723 .46445 m .44862 .4231 L .55237 .41749 L p .658 .389 .501 r
F P
0 g
s
.73502 .55801 m .72391 .60989 L .64568 .57877 L p .838 .637 .63 r
F P
0 g
s
.64568 .57877 m .65253 .52406 L .73502 .55801 L p .838 .637 .63 r
F P
0 g
s
.53636 .79828 m .53136 .84354 L .51124 .84438 L p .675 .703 .868 r
F P
0 g
s
.51124 .84438 m .49629 .79999 L .53636 .79828 L p .675 .703 .868 r
F P
0 g
s
.42913 .75989 m .45987 .80825 L .43139 .82196 L p .585 .606 .84 r
F P
0 g
s
.43139 .82196 m .38808 .78052 L .42913 .75989 L p .585 .606 .84 r
F P
0 g
s
.53136 .84354 m .53636 .79828 L .57521 .80333 L p .703 .729 .87 r
F P
0 g
s
.55237 .41749 m .55284 .45887 L .44723 .46445 L p .658 .389 .501 r
F P
0 g
s
.3649 .59257 m .38053 .64907 L .32039 .68209 L p .508 .42 .691 r
F P
0 g
s
.35051 .73304 m .32039 .68209 L .38053 .64907 L p .538 .485 .745 r
F P
0 g
s
.40224 .70585 m .42913 .75989 L .38808 .78052 L p .563 .546 .793 r
F P
0 g
s
.38808 .78052 m .35051 .73304 L .40224 .70585 L p .563 .546 .793 r
F P
0 g
s
.38053 .64907 m .40224 .70585 L .35051 .73304 L p .538 .485 .745 r
F P
0 g
s
.64578 .7693 m .60816 .81449 L .57521 .80333 L p .764 .739 .83 r
F P
0 g
s
.65464 .47526 m .65253 .52406 L .5524 .50839 L p .76 .521 .571 r
F P
0 g
s
.5524 .50839 m .55284 .45887 L .65464 .47526 L p .76 .521 .571 r
F P
0 g
s
.72391 .60989 m .70495 .66419 L .63403 .63704 L p .826 .667 .687 r
F P
0 g
s
.63403 .63704 m .64568 .57877 L .72391 .60989 L p .826 .667 .687 r
F P
0 g
s
.48229 .74737 m .49629 .79999 L .45987 .80825 L p .64 .629 .823 r
F P
0 g
s
.45987 .80825 m .42913 .75989 L .48229 .74737 L p .64 .629 .823 r
F P
0 g
s
.44723 .46445 m .44854 .51373 L .35572 .53913 L p .571 .369 .568 r
F P
0 g
s
.3649 .59257 m .35572 .53913 L .44854 .51373 L p .594 .431 .63 r
F P
0 g
s
.67857 .71828 m .64578 .7693 L .59795 .75244 L p .79 .717 .783 r
F P
0 g
s
.57521 .80333 m .59795 .75244 L .64578 .7693 L p .764 .739 .83 r
F P
0 g
s
.44854 .51373 m .44723 .46445 L .55284 .45887 L p .674 .449 .573 r
F P
0 g
s
.59795 .75244 m .57521 .80333 L .53636 .79828 L p .727 .694 .819 r
F P
0 g
s
.70495 .66419 m .67857 .71828 L .61789 .69598 L p .81 .694 .736 r
F P
0 g
s
.61789 .69598 m .63403 .63704 L .70495 .66419 L p .81 .694 .736 r
F P
0 g
s
.59795 .75244 m .61789 .69598 L .67857 .71828 L p .79 .717 .783 r
F P
0 g
s
.54106 .74476 m .53636 .79828 L .49629 .79999 L p .686 .658 .817 r
F P
0 g
s
.49629 .79999 m .48229 .74737 L .54106 .74476 L p .686 .658 .817 r
F P
0 g
s
.55284 .45887 m .5524 .50839 L .44854 .51373 L p .674 .449 .573 r
F P
0 g
s
.53636 .79828 m .54106 .74476 L .59795 .75244 L p .727 .694 .819 r
F P
0 g
s
.44854 .51373 m .45278 .56931 L .3649 .59257 L p .594 .431 .63 r
F P
0 g
s
.38053 .64907 m .3649 .59257 L .45278 .56931 L p .611 .484 .683 r
F P
0 g
s
.46998 .68924 m .48229 .74737 L .42913 .75989 L p .633 .58 .776 r
F P
0 g
s
.42913 .75989 m .40224 .70585 L .46998 .68924 L p .633 .58 .776 r
F P
0 g
s
.65253 .52406 m .64568 .57877 L .55097 .56442 L p .761 .563 .63 r
F P
0 g
s
.55097 .56442 m .5524 .50839 L .65253 .52406 L p .761 .563 .63 r
F P
0 g
s
.45278 .56931 m .45999 .6288 L .38053 .64907 L p .611 .484 .683 r
F P
0 g
s
.40224 .70585 m .38053 .64907 L .45999 .6288 L p .623 .532 .731 r
F P
0 g
s
.45999 .6288 m .46998 .68924 L .40224 .70585 L p .623 .532 .731 r
F P
0 g
s
.61789 .69598 m .59795 .75244 L .54106 .74476 L p .742 .662 .772 r
F P
0 g
s
.45278 .56931 m .44854 .51373 L .5524 .50839 L p .683 .498 .63 r
F P
0 g
s
.64568 .57877 m .63403 .63704 L .54855 .62456 L p .758 .599 .68 r
F P
0 g
s
.54855 .62456 m .55097 .56442 L .64568 .57877 L p .758 .599 .68 r
F P
0 g
s
.54519 .68577 m .54106 .74476 L .48229 .74737 L p .691 .618 .77 r
F P
0 g
s
.48229 .74737 m .46998 .68924 L .54519 .68577 L p .691 .618 .77 r
F P
0 g
s
.5524 .50839 m .55097 .56442 L .45278 .56931 L p .683 .498 .63 r
F P
0 g
s
.54106 .74476 m .54519 .68577 L .61789 .69598 L p .742 .662 .772 r
F P
0 g
s
.63403 .63704 m .61789 .69598 L .54519 .68577 L p .752 .631 .727 r
F P
0 g
s
.54519 .68577 m .54855 .62456 L .63403 .63704 L p .752 .631 .727 r
F P
0 g
s
.45999 .6288 m .45278 .56931 L .55097 .56442 L p .689 .54 .679 r
F P
0 g
s
.54855 .62456 m .54519 .68577 L .46998 .68924 L p .691 .579 .725 r
F P
0 g
s
.46998 .68924 m .45999 .6288 L .54855 .62456 L p .691 .579 .725 r
F P
0 g
s
.55097 .56442 m .54855 .62456 L .45999 .6288 L p .689 .54 .679 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005<0001JB000`400?l00000o`00003ooooooom=
ooooo`00oooooom=ooooo`00oooooom=ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Wooooo
003>ooooo`03o`000?oooooooooo07_ooooo003>ooooo`03o`000?oooooooooo07_ooooo003>oooo
o`03o`000?oooooooooo07_ooooo003>ooooo`03o`000?oooooooooo07_ooooo003>ooooo`03o`00
0?oooooooooo07_ooooo003>ooooo`03o`000?oooooooooo01;ooooo0_l0001Wooooo`00c?ooool0
0omEEEGoIVIVo`00000Aooooo`?o000000?oooooo`000?ooool0I_ooool00=kooooo0_l00004oooo
o`;o0000I_ooool00=cooooo0_l00006ooooo`03o`000?oooooo000006Gooooo003Iooooo`Co0000
1oooool00ol0003oooooo`00001Uooooo`00eoooool2o`0000Cooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0001Tooooo`00eOooool2o`0000gooooo00Co0000oooooooooooo0000
I?ooool00=;ooooo0ol0000?ooooo`05o`000?ooooooooooooooool00000Hoooool00=3ooooo0_l0
0002ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Pooooo`00cOooool3o`0000Gooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000006;ooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05oooooo0039ooooo`?o00006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05oooooo002Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Looooo`?o00000oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0G_ooool009Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Iooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05gooooo002Dooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Fooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05gooooo002Dooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0D
ooooo`?o00000_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0G?ooool009Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`04oooool2o`0002Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1Kooooo`00U?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04_oo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Kooooo`00U?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04?ooool2o`000003ooooool0
003ooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Jooooo`00U?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000=ooooo`;o00000oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0F_ooool00;?ooooo0ol0000_
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0FOooool00;7ooooo0_l0000boooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Hooooo`00
[?ooool3o`0003Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`00Z_oo
ool2o`0003Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`00Yoooool3
o`000003ooooool0003ooooo03Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1F
ooooo`00YOooool2o`0000Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo05Gooooo002Sooooo`;o0000@Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05Gooooo001jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Dooooo`00N_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01oooooo0_l00003ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Cooooo`00N_ooool01Ol@413ooooooooooooooooo410@01go
oooo0_l00018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Doooool007[ooooo
00Go0000ooooooooooooooooo`00000Jooooo`?o0000B_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo05;ooooo001jooooo`05o`000?ooooooooooooooool000006?ooool2o`0000;o
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05;o
oooo001jooooo`05oa0@4?ooooooooooooooool@41005Oooool3o`0004oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Aooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo0_l0001Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool007[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`;o00000_ooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0D?ooool008gooooo0ol0001Fooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0Coooool008_ooooo0_l0001Iooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0Coooool008Sooooo1?l0001Jooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0C_ooool008Kooooo0_l00004ooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00Q?ooool2o`00063o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00POooool3o`0006;ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1<ooooo`00Ooooool2o`0000?ooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo001m
ooooo`;o00001_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0Boooool004Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0001Zooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0B_ooool004Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Kooooo`;o00000oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B_ooool003kooooo1_l00002ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`0Gooooo`?o0000Koooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Wooooo0016ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`0Fooooo`;o0000L_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo04Sooooo0016ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`18ooooo`00A_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool05?ooool3o`0007Kooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
4_ooool2o`0007Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000?ooooo`;o00000_ooool00ol0003ooooo
ooooo`1fooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A_ooool006Oooooo0ol0
001mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool006Gooooo0_l00020
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0AOooool006;ooooo0ol000000ooo
oooo0000ooooo`1oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0A?ooool0063o
oooo0_l00025ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@oooool005kooooo
0_l00027ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@oooool005_ooooo0ol0
00000ooooooo0000ooooo`26ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@_oo
ool005Wooooo0_l00005ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`12ooooo`00<_ooool4o`000003oa0@4?oooooooooo01kooooo0_l0002>oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0@Oooool003Cooooo00?o0000oooooooo
ool07Oooool3o`000003ooooool0003ooooo08kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`10ooooo`00:Oooool6o`0000Gooooo00?o0000ooooooooool06oooool2o`0009Cooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`00=?ooool00ol0003ooooooooo
o`0Hooooo`?o0000U_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo000d
ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`03o`000?oooooooooo09Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?ooool00ol0003oooooooooo`0Doooo
o`;o0000Voooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo000dooooo`03
o`000?oooooooooo017ooooo0ol0002Mooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0?Oooool003;ooooo00?oEEEEofIVI_l000004Oooool2o`0000;ooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo0014ooooo`;o0000X_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo0011ooooo`?o0000Y?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03_ooooo000oooooo`;o00000_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool003co
oooo0ol0002Yooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool003[ooooo
0_l0002/ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool003Sooooo0_l0
00000ooooooo0000ooooo`2[ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Ooo
ool003Gooooo0ol00004ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0hooooo`00<oooool2o`000;?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0hooooo`00<Oooool2o`0000;ooooo00?o0000ooooooooool0/?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo000^ooooo`?o0000^?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo000]ooooo`03o`000?oooooooooo0;Wooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Oooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool002gooooo0_l0002joooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool002gooooo00?o0000ooooool0
0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo000/ooooo`05o`00
0?ooooooooooooooool00000^?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?o
oooo000/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0]Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03?ooooo000/ooooo`;o00001?ooool00ol0003ooooooooo
o`2dooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool002cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0<_ooool002cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool002cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0<?ooool002_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2`ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0<?ooool002_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool002_ooooo0ol0000:ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0_ooooo`00:oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
0:gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`008Oooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2/ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool002?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`006?ooool6o`0000Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0/ooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo02_ooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l0000Booooo`03o`000?oooooooooo
0:Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Z?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo02[ooooo000Sooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool0:_ooool0027ooooo00?oEEEEofIVI_l000001_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Yooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0:Gooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xoooo
o`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`0001[ooooo00?o0000ooooooooool0
X_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000Yooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02Gooooo000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02Cooooo000Xooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0I?ooool?o`0002[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Sooooo`00:?ooool2o`00027ooooo00?o0000ooooooooool0E_ooool=o`0000_oB00000Co
0000of`00?m/003oK0001Ol0000Uooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
8oooool002Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Booooo`Co00002om8
000Ao`0000CoK0001_l0000Oooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_oo
ool002Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1>oooooa;o00003Omk0@X0
1?l0003oWA/4oidK1?nM6`@6o`0000CoK0001_l0000Jooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool08_ooool002Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`19
ooooo`Oo00000_m200000ol0003oN`4:og/12P0Gog/12P03o`000?nM6`CoWA/400OoWA/41ol00002
of`000Co00005oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo000Woooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0AOooool3o`000004o`<00?l0003o0000
o`0000Co@P0000?o0000og/12_mk0@X06Omk0@X00ol0003oWA/4oidK100=oidK10So00005Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0@_ooool7o`0000Oo@P0000?o0000og/12_mk0@X06Omk0@X00ol0
003oWA/4oidK100CoidK10Go00004_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
023ooooo000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0?_ooool6o`0000_o
@P0000?o0000og/12_mk0@X02omk0@XBo`0001CoWA/400?o0000ojdQ0?l000000_l0000@ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool07oooool002Oooooo0_l0000Xooooo`03o`00
0?oooooooooo03_ooooo1Ol0000;od80017o00003_nD<4<01?l0003o/dPook=8?oncB3l7o`0000ko
WA/400Co0000ojdQ0?n]8@3o[B400_l0000>ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool07oooool002Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0hooooo`Co
00002om20003o`0000;oI`Pg00?o0000oi@`@onD<4<06_nD<4<00ol0003o/dPook=8?`08ok=8?`Oo
00002?nM6`@00ol0003o[B40ojdQ0002ojdQ00;o00003?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=Oooool3o`0000_o@P000ol00005ofL8=`03o`000?nD<4?oU31301[oU31300?o0000ok=8?oncB3l0
3oncB3l7o`000003oidK1?l0003o[B4000Go[B400ol00009ooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool07Oooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0cooooo`?o00002Om20003o`0000OoI`Pg00?o0000oi@`@onD<4<06onD<4<00ol0003o/dPook=8
?`0Fok=8?`Co00001on]8@02o`0000Oooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Mooooo`009_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo033ooooo1?l00006
od8000Co00002_mW23L00ol0003oU313oi@`@`0Koi@`@`03o`000?ncB3oo/dPo01So/dPo00Co0000
olaG:?l0003o00001on]8@02o`0000Gooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Looooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02kooooo1?l00004
od8000?o00003_mW23L00ol0003oU313oi@`@`0Koi@`@`03o`000?ncB3oo/dPo01Wo/dPo00?o0000
olaG:?o<EbP00_l00007ojdQ00?o00000_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01_ooooo000Vooooo`?o0000;_ooool00ol0003oooooooooo`0[ooooo`Go00000_m20003o`00
017oI`Pg00?o0000oi@`@onD<4<04onD<4<<o`0001So/dPo00?o0000olaG:?o<EbP00_o<EbP2o`00
00So[B400ol00012ooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0:Oooool8o`0001?oI`Pg00?o0000oi@`@onD<4<01OnD<4<?o`0000So
XDiW00Co0000okeTIOnmI6Go_FAU1_l0000Bok=8?`03o`000?o<EbSoc5LX00Coc5LX0_l00008ojdQ
00;o0000@_ooool00ol0003oooooooooo`0Jooooo`009_ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02Kooooo1ol0000DofL8=`[o00005onQCVL00ol0003o_FAUokeTI@07okeTI@Ko
00003OncB3l00ol0003oc5LXolaG:005olaG:0?o00001On]8@000ol0003oS0P0o`000011ooooo`03
o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool09?ooool5o`000003oaL03ol0003oI`Pg017oI`Pg0ol00002ogd_H@03o`000?nQCVOoXDiW
01coXDiW00?o0000okeTIOnmI6D03OnmI6D6o`0000Oo/dPo00?o0000olaG:?o<EbP02?o<EbP2o`00
00?o[B400_l000000on<203o0000ooooo`10ooooo`03o`000?oooooooooo01Wooooo000;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo027ooooo1_l000000olG00oo0000ofL8=`0>ofL8
=`Co00001Omm;f400ol0003oXDiWoj5>I`0Loj5>I`03o`000?nmI6Go_FAU01?o_FAU1_l000000onc
B3oo0000olaG:00;olaG:0;o000000Ko[B40o`000?n]8@3o0000oh`80?l00011ooooo`03o`000?oo
oooooooo01Sooooo0003ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01oooooo1Ol0
0003oaL03`03o`000?mW23OoI`Pg00[oI`Pg0ol00009ogd_H@03o`000?nQCVOoXDiW01coXDiW00?o
0000okeTIOnmI6D06OnmI6D4o`0000coc5LX0ol000001?n]8@3o0000oh`80?l00010ooooo`03o`00
0?oooooooooo01Sooooo000;ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool5o`0000Co5`0?
00?o0000ofL8=omW23L01omW23L4o`0000coOBmQ00?o0000oj5>IonQCVL07OnQCVL00ol0003o_FAU
okeTI@0JokeTI@04o`000?oGMeSo0000o`0000coc5LX0ol00002oh`80003o`000?oooooooooo03ko
oooo00?o0000ooooooooool05oooool000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool2o`0003Oooooo00?o0000ooooooooool06_ooool5o`00
00Go5`0?00?o0000ofL8=omW23L01?mW23L3o`00013oOBmQ00?o0000oj5>IonQCVL07OnQCVL00ol0
003o_FAUokeTI@0JokeTI@04o`000?oGMeSoegMHomMgF0?o00002Oo<EbP01?l0003oc5LXo`000?l0
0002oh`80003o`000?oooooooooo03gooooo00?o0000ooooooooool05oooool000_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Hooooo`Co00001_lG00l01?l0003oI`PgofL8=omW23L4o`0001;oOBmQ
00?o0000oj5>IonQCVL07_nQCVL00ol0003o_FAUokeTI@0KokeTI@03o`000?oGMeSoegMH00?oegMH
0_l00007olaG:004o`000?o<EbSoc5LXolaG:0;o000000?oS0P0o`000?ooool0?_ooool00ol0003o
ooooooooo`0Fooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Kooooo1?l00007oaL03`Co
00005_mm;f400ol0003oXDiWoj5>I`0Noj5>I`03o`000?nmI6Go_FAU01_o_FAU00?o0000omMgF?oG
MeP01OoGMeP2o`0000Goc5LX00Wo0000olaG:?o<EbSoc5LXo`000?o<DP3o0000oh`80?l00000?Ooo
ool3o`0001Oooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Dooooo`?o00001olG00l3o`0001WoOBmQ00?o
0000oj5>IonQCVL05_nQCVL<o`0001[o_FAU00?o0000omMgF?oGMeP01ooGMeP3o`0000;oc5LX00?o
0000olaG:?o<EbP00_o<EbP01Ol0003oc580o`000?n<203o000003Wooooo0ol00002ooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04_oo
ool3o`0000Oo5`0?00?o0000od00B_l000006_mm;f400ol0003oXDiWoj5>I`05oj5>Ia7o00002?nX
Hh001?l0003o`GMool5gOoo1Mgl6o`0001Co_FAU00?o0000omMgF?oGMeP02_oGMeP3o`0000Goc5LX
00Go0000olaB0?l0003oS0P0o`00000eooooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`00
9?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo013ooooo0_l00007oaL03`;o0000
0_m004X00ol0003oOBmQogd_H@0Fogd_H@[o00006OnXHh000ol0003o`GMool5gO`07ol5gO`Oo0000
3OnmI6D00ol0003oegMHomMgF00<omMgF0;o00001?o<EbP01_l0003oc580olaB0?l0003oS0P0o`00
037ooooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool03_ooool00ol0003o5`0?oaL03`06oaL03`05o`000?m004[o@01:od00
B_l000005_mm;f43o`0000;oRDYl00?o0000ojQSP?nXHh007_nXHh000ol0003o`GMool5gO`0>ol5g
O`Ko00002?nmI6D00ol0003oegMHomMgF00;omMgF004o`000?oGMeSo0000o`0000?oc5LX00Ko0000
olaB0?o<DP3o0000oh`80?l0000]ooooo`?o00002oooool00ol0003oooooooooo`0Eooooo`009?oo
ool2o`0003oooooo00?o0000ooooooooool03?ooool00ol0003o5`0?oaL03`05oaL03`;o00001?m0
04X00ol0003oOBmQogd_H@0@ogd_H@Co00001On9BW`00ol0003oZ6>0ojQSP00NojQSP003o`000?o1
Mgoo`GMo01Co`GMo1_l00002okeTI@03o`000?oGMeSoegMH00_oegMH00Co0000omMgF?oGMeSoegMH
1?l00003olaB0003o`000?n<203o000002Wooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo
000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool00ol0003o5`0?oaL0
3`04oaL03`03o`000?m004[o@01:00Co@01:00?o0000ogd_HOmm;f403?mm;f44o`0000WoRDYl00?o
0000ojQSP?nXHh007_nXHh000ol0003o`GMool5gO`0Jol5gO`Co00003?oGMeP00ol0003oegMHomMg
F004omMgF0;o00000oo<DP02o`0002Kooooo0ol0000Booooo`03o`000?oooooooooo01Cooooo000S
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool02Oooool00ol0003o5`0?oaL03`03
oaL03`;o00001om004X00ol0003oOBmQogd_H@09ogd_H@?o00003On9BW`00ol0003oZ6>0ojQSP00N
ojQSP003o`000?o1Mgoo`GMo01co`GMo00?o0000omV;NOl000000_l00009omMgF003o`000?oGMeSo
egMH00KoegMH0_l00003olaB0003o`000?oooooooooo023ooooo0ol0000Eooooo`03o`000?oooooo
oooo01Cooooo000Sooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01oooool2o`00
00?o5`0?0_l00009od00BP03o`000?mm;f7oOBmQ00GoOBmQ1?l0000@ohU:O003o`000?nXHh3oZ6>0
01koZ6>000?o0000ol5gOoo1Mgl07?o1Mgl00ol0003ofH]iomV;N@02omV;N@;o00001ooGMeP00ol0
003oegMHomMgF006omMgF003o`000?oZPc?o000000?oc58000?o0000ooooooooool07?ooool3o`00
01Sooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`06ooooo`05o`000?lG00oo5`0?oaL03ol000002_m004X00ol0003oOBmQogd_H@02ogd_
H@Co00005?n9BW`00ol0003oZ6>0ojQSP00NojQSP003o`000?o1Mgoo`GMo01co`GMo00?o0000omV;
NOoIRgT01?oIRgT2o`0000GoegMH00?o0000omMgF?oGMeP01_oGMeP01?l0003ojX<conZ3<ol00003
olaB0003o`000?oooooooooo01Sooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo000Soooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01?ooool00ol0003o5`0?oaL03`02o`00
00_o@01:00?o0000ogd_HOl000000_l0000HohU:O003o`000?nXHh3oZ6>001koZ6>000?o0000ol5g
Ooo1Mgl07?o1Mgl00ol0003ofH]iomV;N@06omV;N@?o00000_oGMeP00ol0003oegMHomMgF007omMg
F004o`000?oZPc?ojX<co`0000?oc58000?o0000ooooooooool05?ooool3o`0001kooooo00?o0000
ooooooooool05?ooool002?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02oooo
o`;o000000?o5`0?o`000?m004X02om004X3o`0001_oRDYl00?o0000ojQSP?nXHh007_nXHh000ol0
003o`GMool5gO`0Lol5gO`03o`000?oIRgWofH]i00WofH]i0ol00009omMgF005o`000?oZPc?ojX<c
onZ3<ol000000oo<DP000ol0003oooooooooo`0@ooooo`?o00008Oooool00ol0003oooooooooo`0D
ooooo`008oooool2o`0004Oooooo00Co0000oooooooooooooooo0ol0000<od00BP03o`000?mJ977o
000001coRDYl00?o0000ojQSP?nXHh007_nXHh000ol0003o`GMool5gO`0Lol5gO`03o`000?oIRgWo
fH]i00_ofH]i0_l00008omMgF003o`000?oZPc?ojX<c00;ojX<c00Go0000olaB0?o<DP3oc580o`00
000>ooooo`?o00009Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`17
ooooo`04o`000?oooooo0000o`0000co@01:0_l00002oeXTL@03o`000?n9BWcoRDYl01[oRDYl00?o
0000ojQSP?nXHh007_nXHh000ol0003o`GMool5gO`0Mol5gO`03o`000?oIRgWofH]i00_ofH]i1?l0
0006omMgF003o`000?oZPc?ojX<c00;ojX<c00Go0000olaB0?o<DP3oc580o`00000:ooooo`?o0000
:?ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`19ooooo`;o00002om0
04X2o`0000CoFRAa00?o0000ohU:O?n9BW`06_n9BW`00ol0003oZ6>0ojQSP00FojQSP0co00007?o1
Mgl00ol0003ofH]iomV;N@0;omV;N@04o`000?oIRgWofH]iomV;N@;o00001?oGMeP00ol0003ojX<c
onZ3<`03onZ3<`04o`000?o<DP3oc580o`0000Oooooo0ol0000[ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo04Sooooo0ol0000:od00BP03o`000?mJ977oFRAa00CoFRAa
00?o0000ohU:O?n9BW`06_n9BW`00ol0003oZ6>0ojQSP005ojQSP17o00002?n/LY801?l0003o`XFB
ol:5T_o2QI87o`0001Go`GMo00?o0000omV;NOoIRgT02ooIRgT00ol0003ofH]iomV;N@03omV;N@;o
00000_oGMeP00ol0003ojX<conZ3<`04onZ3<`04o`000?o<DP3oc580o`0000?ooooo0ol0000^oooo
o`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04Sooooo0_l00009od00BP;o
00001omJ97400ol0003oRDYlohU:O00HohU:O0[o00006On/LY800ol0003o`XFBol:5TP08ol:5TPKo
00003oo1Mgl00ol0003ofH]iomV;N@0;omV;N@03o`000?oIRgWofH]i00GofH]i1?l00006onZ3<`03
o`000?o<DP3o000000?o0000<Oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooo
ooooo`17ooooo`?o00002?m004X00ol0003oFRAaoeXTL@07oeXTL@03o`000?n9BWcoRDYl01CoRDYl
1?l00002oi9NT@03o`000?n/LY;o[7:B01ko[7:B00?o0000ol:5T_o2QI803_o2QI86o`0000Wo`GMo
00?o0000omV;NOoIRgT02ooIRgT00ol0003ofH]iomV;N@08omV;N@;o00001_oZPc<00ol0003oc580
o`00000cooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04Kooooo0_l0
00000ol000_o0000od00BP05od00BP;o00002OmJ97400ol0003oRDYlohU:O00BohU:O0?o00001_nB
GY400ol0003o[7:BojabTP0NojabTP03o`000?o2QI;o`XFB01Co`XFB1ol00002ol5gO`03o`000?oI
RgWofH]i00_ofH]i00?o0000omV;NOoIRgT02?oIRgT00ol0003olZ1Uo`000006onZ3<`03o`000?o<
DP3o000003;ooooo00?o0000ooooooooool04oooool002;ooooo0_l00017ooooo`?o00001_m004X0
0ol0003oFRAaoeXTL@09oeXTL@03o`000?n9BWcoRDYl00koRDYl1?l00009oi9NT@03o`000?n/LY;o
[7:B01ko[7:B00?o0000ol:5T_o2QI806oo2QI84o`0000cofH]i00?o0000omV;NOoIRgT02?oIRgT0
1?l0003olZ1Uoo:PIOl00006onZ3<`;o0000<oooool00ol0003oooooooooo`0Booooo`008Oooool0
0ol0003oooooooooo`16ooooo`;o000000?o000;o`000?m004X00om004X2o`0000coFRAa00?o0000
ohU:O?n9BW`02_n9BW`4o`0000goTUjA00?o0000ojabT_n/LY807_n/LY800ol0003o`XFBol:5TP0M
ol:5TP03o`000?oHVHoo000000;o00002OoIRgT00ol0003ofH]iomV;N@08omV;N@05o`000?obX6Go
lZ1Uoo:PIOl000001_oZPc<2o`0003;ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000
ooooooooool0AOooool2o`0000;o000;00?o0000od00B_m004X00_l0000>oeXTL@03o`000?n9BWco
RDYl00KoRDYl1?l0000Aoi9NT@03o`000?n/LY;o[7:B01ko[7:B00?o0000ol:5T_o2QI807Oo2QI80
0ol0003of9V?omRIS`02omRIS`;o00001ooIRgT00ol0003ofH]iomV;N@08omV;N@03o`000?obX6Go
lZ1U00;olZ1U00?o0000onZ3<ooZPc<01?oZPc<00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01;ooooo000Qooooo`03o`000?oooooooooo04Gooooo00Co0000o`002ol000_o00000_m004X0
0ol0003oFRAaoeXTL@0>oeXTL@03o`000?n9BWcoRDYl00?oRDYl0ol0000Eoi9NT@03o`000?n/LY;o
[7:B01ko[7:B00?o0000ol:5T_o2QI807Oo2QI800ol0003of9V?omRIS`04omRIS`;o00001OoIRgT0
0ol0003ofH]iomV;N@08omV;N@03o`000?obX6GolZ1U00?olZ1U00?o0000onZ3<ooZPc<01?oZPc<0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo
04Cooooo0_l00002o`002`?o00004OmJ97400ol0003oRDYlo`000003o`0001SoTUjA00?o0000ojab
T_n/LY807_n/LY800ol0003o`XFBol:5TP0Mol:5TP03o`000?oHVHoof9V?00Kof9V?0ol00002omV;
N@03o`000?oIRgWofH]i00SofH]i00?o0000oo:PIOobX6D01?obX6D00ol0003ojX<conZ3<`03onZ3
<`03o`000?oooooooooo02oooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool0@oooool2o`0000?o000;00?o0000oeXTLOmJ97404?mJ9743o`0001coTUjA00?o0000ojabT_n/
LY807_n/LY800ol0003o`XFBol:5TP0Mol:5TP03o`000?oHVHoof9V?00Wof9V?0ol0000;omV;N@03
o`000?obX6GolZ1U00ColZ1U00?o0000onZ3<ooZPc<00ooZPc<00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04?ooooo00Go0000o`002ol000_o
000;o`00000BoeXTL@03o`000?m/@Hgo000001goTUjA00?o0000ojabT_n/LY807_n/LY800ol0003o
`XFBol:5TP0Mol:5TP03o`000?oHVHoof9V?00_of9V?0_l0000:omV;N@03o`000?obX6GolZ1U00Go
lZ1U00?o0000onZ3<ooZPc<00_oZPc<00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01;o
oooo000Pooooo`?o0000@oooool00ol0003o000;o`002`02o`002`03o`000?mJ977oFRAa00koFRAa
0_l00002ofa1S@03o`000?nBGY7oTUjA01_oTUjA00?o0000ojabT_n/LY807_n/LY800ol0003o`XFB
ol:5TP0Mol:5TP03o`000?oHVHoof9V?00_of9V?00?o0000omRISol000000_l00007omV;N@03o`00
0?obX6GolZ1U00KolZ1U00Go0000onZ3<ooZPc?ojX<co`00000`ooooo`03o`000?oooooooooo01;o
oooo000Pooooo`03o`000?oooooooooo04;ooooo0_l00003o`002`;o00003_mJ9742o`0000CoK46=
00?o0000oi9NTOnBGY406onBGY400ol0003o[7:BojabTP0NojabTP03o`000?o2QI;o`XFB01go`XFB
00?o0000omRISooHVHl02ooHVHl00ol0003of9V?omRIS`02omRIS`;o00001OoIRgT00ol0003olZ1U
oo:PI@07oo:PI@05o`000?oZPc?ojX<conZ3<ol00000<?ooool00ol0003oooooooooo`0Aooooo`00
5Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0@_ooool01ol0003o
000;o`002ol000_o0000o`00Col000003OmJ97400ol0003oK46=ofa1S@04ofa1S@03o`000?nBGY7o
TUjA01_oTUjA00?o0000ojabT_n/LY807_n/LY800ol0003o`XFBol:5TP0Lol:5TP03o`000?oHVHoo
f9V?00cof9V?00?o0000omRISooHVHl01?oHVHl2o`0000?ofH]i00?o0000oo:PIOobX6D02?obX6D0
1?l0003ojX<conZ3<ol0000`ooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`11ooooo`03o`000?l000_o000;00;o000;00?o
0000o`00Col000002omJ9742o`0000OoK46=00?o0000oi9NTOnBGY406onBGY400ol0003o[7:Bojab
TP0NojabTP03o`000?o2QI;o`XFB01co`XFB00?o0000omRISooHVHl03?oHVHl00ol0003of9V?omRI
S`06omRIS`Co00002oobX6D01?l0003ojX<co`000?l0000_ooooo`03o`000?oooooooooo017ooooo
000Eooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`10ooooo`03o`00
0?l000_o000;00;o000;00Co0000o`00Col004oo00002_mJ97400ol0003oK46=ofa1S@07ofa1S@03
o`000?nBGY7oTUjA01_oTUjA00?o0000ojabT_n/LY803_n/LY8Do`0001_o`XFB00?o0000omRISooH
VHl03OoHVHl00ol0003of9V?omRIS`08omRIS`;o00002oobX6D00ol0003ojX<co`00000_ooooo`03
o`000?oooooooooo017ooooo000Eooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`10ooooo`05o`000?l000_o000;o`002ol000000ol004l00ol0003oFRAaoeXTL@06oeXT
L@;o00002_m/@Hd00ol0003oTUjAoi9NT@0Ioi9NTA?o00004?n^Oj401?l0003o`Y2Qol:@XOo2T:46
o`0001Go`XFB00?o0000omRISooHVHl03OoHVHl00ol0003of9V?omRIS`08omRIS`03o`000?oa/HOo
000000_olZ1U0ol0000^ooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`10ooooo`05o`000?l000_o000;o`002ol000000ol0
04l00ol0003oFRAaoeXTL@06oeXTL@03o`000?m/@HgoK46=00_oK46=00?o0000oi9NTOnBGY405OnB
GY43o`0000;oV6jQ00?o0000ojioXOn^Oj407_n^Oj400ol0003o`Y2Qol:@X@07ol:@X@Oo00003_o2
QI800ol0003of9V?omRIS`0=omRIS`03o`000?oHVHoof9V?00Sof9V?00Co0000oo6aQooa/HOo0000
2oobX6D2o`0002kooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo043ooooo00Go0000o`002ol000_o000;o`000003o`00C`03
o`000?mJ977oFRAa00CoFRAa0_l0000>ofa1S@03o`000?nBGY7oTUjA017oTUjA1?l00005oiQ^X@03
o`000?n^Oj7o[WnQ01ko[WnQ00?o0000ol:@XOo2T:403_o2T:46o`0000So`XFB00?o0000omRISooH
VHl03OoHVHl00ol0003of9V?omRIS`08omRIS`05o`000?oa/HOolK67oo6aQol000002oobX6D00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`00047ooooo00Co0000o`002ol000_o00001?l004l00ol0003oFRAaoeXTL@02
oeXTL@;o00004?m/@Hd00ol0003oTUjAoi9NT@0=oi9NT@Co00002OnHKZ400ol0003o[WnQojioX@0N
ojioX@03o`000?o2T:7o`Y2Q01Co`Y2Q1_l00002ol:5TP03o`000?oHVHoof9V?00gof9V?00?o0000
omRISooHVHl02?oHVHl00ol0003olK67oo6aQ`02oo6aQ`03o`000?obX6GolZ1U00SolZ1U0_l0000^
ooooo`03o`000?oooooooooo013ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`0oooooo`04o`000?l000_o000;o`0000Go001?00Go0000oeXTLOmJ977oFRAa
o`00000Bofa1S@03o`000?nBGY7oTUjA00[oTUjA0ol0000=oiQ^X@03o`000?n^Oj7o[WnQ01ko[WnQ
00?o0000ol:@XOo2T:406_o2T:44o`0000kof9V?00?o0000omRISooHVHl02?oHVHl00ol0003olK67
oo6aQ`03oo6aQ`03o`000?obX6GolZ1U00OolZ1U0_l0000^ooooo`03o`000?oooooooooo013ooooo
000Oooooo`03o`000?oooooooooo03oooooo00Co0000o`002ol000_o00001Ol004l01?l0003oFRAa
o`000?l0000Cofa1S@03o`000?nBGY7oTUjA00KoTUjA1?l0000@oiQ^X@03o`000?n^Oj7o[WnQ01ko
[WnQ00?o0000ol:@XOo2T:407?o2T:400ol0003oeZ>Qo`000002o`0000_of9V?00?o0000omRISooH
VHl02?oHVHl00ol0003olK67oo6aQ`04oo6aQ`03o`000?obX6GolZ1U00KolZ1U0ol0000]ooooo`03
o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03oooooo00?o0000o`002ol00000
1_l004l2o`0001GoK46=00?o0000oi9NTOnBGY400_nBGY44o`0001CoV6jQ00?o0000ojioXOn^Oj40
7_n^Oj400ol0003o`Y2Qol:@X@0Lol:@X@03o`000?oFXj7oeZ>Q00;oeZ>Q0ol00008omRIS`03o`00
0?oHVHoof9V?00Sof9V?00?o0000oo6aQooa/HL01Ooa/HL00ol0003olZ1Uoo:PI@06oo:PI@;o0000
;Oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`0nooooo`03o`000?l0
00_o000000Oo001?00?o0000ofa1SOm/@Hd05?m/@Hd00ol0003oTUjAo`000002o`0001SoV6jQ00?o
0000ojioXOn^Oj407_n^Oj400ol0003o`Y2Qol:@X@0Lol:@X@03o`000?oFXj7oeZ>Q00GoeZ>Q0_l0
0006omRIS`03o`000?oHVHoof9V?00Oof9V?00?o0000oo6aQooa/HL01ooa/HL2o`0000KolZ1U0_l0
000]ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo03oooooo0_l00008
o`00C`03o`000?m/@HgoK46=01?oK46=0ol0000KoiQ^X@03o`000?n^Oj7o[WnQ01go[WnQ00?o0000
ol:@XOo2T:407Oo2T:400ol0003oeZ>QomJSX@07omJSX@?o00000ooHVHl00ol0003of9V?omRIS`07
omRIS`03o`000?oa/HOolK6700WolK6700?o0000oo:PIOobX6D00oobX6D3o`0002cooooo00?o0000
ooooooooool04?ooool001kooooo00?o0000ooooooooool0?oooool2o`0000Oo001?0_l0000Cofa1
S@;o000000?oN5RQo`000?nHKZ406onHKZ400ol0003o[WnQojioX@0MojioX@03o`000?o2T:7o`Y2Q
01co`Y2Q00?o0000omJSXOoFXj402ooFXj42o`000003omRISol0003of9V?00Sof9V?00?o0000oo6a
Qooa/HL02_oa/HL00ol0003olZ1Uoo:PI@02oo:PI@03o`000?o[XbKo000002cooooo00?o0000oooo
ooooool04?ooool001kooooo0_l0000oooooo`;o00001ol004l00ol0003o90imo`00000Bofa1S@05
o`000?mhF:7oN5RQogQHXOl000007OnHKZ400ol0003o[WnQojioX@0LojioX@03o`000?o2T:7o`Y2Q
01co`Y2Q00?o0000omJSXOoFXj403OoFXj43o`0000Sof9V?00?o0000oo6aQooa/HL02ooa/HL01_l0
003olZ1Uoo:PIOobX6Go0000on^S9P;o0000;?ooool00ol0003oooooooooo`0?ooooo`007_ooool0
0ol0003oooooooooo`0nooooo`03o`000?l004oo001?00Go001?00Co0000ob@>OOlT3Wgo00004?m/
@Hd2o`0000CoN5RQ00?o0000oiQ^XOnHKZ406onHKZ400ol0003o[WnQojioX@0LojioX@03o`000?o2
T:7o`Y2Q01co`Y2Q00?o0000omJSXOoFXj403_oFXj400ol0003oeZ>Qo`000002o`0000Gof9V?00?o
0000oo6aQooa/HL03?oa/HL01?l0003olZ1Uoo:PIOl00002on^S9P03o`000?oooooooooo02[ooooo
00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0?_ooool00ol0003o001?o`00
C`04o`00C`05o`000?lT3Wgo90imob@>OOl000003_m/@Hd2o`0000OoN5RQ00?o0000oiQ^XOnHKZ40
6_nHKZ400ol0003o[WnQojioX@0LojioX@03o`000?o2T:7o`Y2Q01co`Y2Q00?o0000omJSXOoFXj40
3_oFXj400ol0003oeZ>QomJSX@02omJSX@;o00000ooHVHl00ol0003olK67oo6aQ`0=oo6aQ`03o`00
0?obX6Go000000;ojj<V00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`007_oo
ool00ol0003oooooooooo`0nooooo`03o`000?l004oo001?00Co001?00Go0000ob@>OOlT3Wgo90im
o`00000=ofa1S@03o`000?mhF:7oN5RQ00OoN5RQ00?o0000oiQ^XOnHKZ406_nHKZ400ol0003o[WnQ
ojioX@0LojioX@03o`000?o2T:7o`Y2Q01co`Y2Q00?o0000omJSXOoFXj403_oFXj400ol0003oeZ>Q
omJSX@04omJSX@Co00004?oa/HL01?l0003olZ1Uo`000?o[XbH2o`0002_ooooo00?o0000oooooooo
ool03oooool001gooooo00?o0000ooooooooool0?oooool00ol0003o001?o`00C`03o`00C`03o`00
0?lT3Wgo90im00;o90im00?o0000ofa1SOm/@Hd02Om/@Hd2o`0000[oN5RQ00?o0000oiQ^XOnHKZ40
6_nHKZ400ol0003o[WnQojioX@0LojioX@03o`000?o2T:7o`Y2Q01co`Y2Q00?o0000omJSXOoFXj40
3_oFXj400ol0003oeZ>QomJSX@07omJSX@;o00004?oa/HL2o`0000;ojj<V00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0nooooo`03o`000?l0
04oo001?00?o001?00?o0000ob@>OOlT3Wd01?lT3Wd00ol0003oK46=ofa1S@06ofa1S@;o00003?mh
F:400ol0003oV6jQoiQ^X@0JoiQ^X@03o`000?n^Oj7o[WnQ01co[WnQ00?o0000ol:@XOo2T:407?o2
T:400ol0003oeZ>QomJSX@0>omJSX@03o`000?oFXj7oeZ>Q00OoeZ>Q00?o0000onbkWol000004?oa
/HL01?l0003ojj<Von^S9_l0000[ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oo
oooooooo03kooooo00?o0000o`00Col004l00_l004l00ol0003o90imob@>O@05ob@>O@03o`000?m/
@HgoK46=00GoK46=00?o0000ogQHXOmhF:403?mhF:400ol0003oV6jQoiQ^X@0JoiQ^X@03o`000?n^
Oj7o[WnQ01Co[WnQ3?l0000Kol:@X@03o`000?oFXj7oeZ>Q00ooeZ>Q00?o0000omJSXOoFXj401_oF
Xj401?l0003ok;^OonbkWol0000?oo6aQ`05o`000?o[XbKojj<Von^S9_l00000:_ooool00ol0003o
ooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0nooooo`05o`000?l004oo001?o`00Col0
00002?lT3Wd00ol0003oK46=ofa1S@03ofa1S@;o00004?mhF:400ol0003oV6jQoiQ^X@0IoiQ^X@03
o`000?n^Oj7o[WnQ00Go[WnQ3ol00008ok2:[@04o`000?o2VJko`YV^ol:I[PKo00005Oo2T:400ol0
003oeZ>QomJSX@0?omJSX@03o`000?oFXj7oeZ>Q00KoeZ>Q00Go0000onbkWoo/^iook;^Oo`00000>
oo6aQ`;o00000_o[XbH00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo000Moooo
o`;o0000?oooool01?l0003o001?o`00Col00009ob@>O@04o`000?m/@HgoK46=ofa1S@;o00004_mh
F:400ol0003oV6jQoiQ^X@0GoiQ^X@[o00005on`RZd00ol0003o`YV^ol:I[P07ol:I[PKo00003_o2
T:400ol0003oeZ>QomJSX@0@omJSX@03o`000?oFXj7oeZ>Q00GoeZ>Q00?o0000onbkWoo/^il00oo/
^il00ol0003olK67oo6aQ`0;oo6aQ`;o00000_o[XbH00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00kooooo000Mooooo`03o`000?oooooooooo03kooooo00Co0000o`00Col004oo00002OlT
3Wd01?l0003oK46=ofa1SOl0000DogQHX@03o`000?nHKZ7oV6jQ01?oV6jQ1?l00002oiak[P03o`00
0?n`RZgo/8Z]01co/8Z]00?o0000ol:I[_o2VJh03Oo2VJh6o`0000So`Y2Q00?o0000omJSXOoFXj40
4?oFXj400ol0003oeZ>QomJSX@05omJSX@03o`000?o/^iook;^O00Cok;^O00?o0000oo6aQooa/HL0
2Ooa/HL00ol0003oo/MXo`000003on^S9P03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0?oooool00ol0003o001?o`00000:ob@>O@?o00005Omh
F:400ol0003oV6jQoiQ^X@0?oiQ^X@Co00001_nLNjh00ol0003o/8Z]ok2:[@0Lok2:[@03o`000?o2
VJko`YV^01?o`YV^1_l00002ol:@X@03o`000?oFXj7oeZ>Q013oeZ>Q00?o0000omJSXOoFXj401OoF
Xj400ol0003ok;^OonbkW`05onbkW`03o`000?oa/HOolK6700SolK6700Co0000ook7J?onafSo0000
0_o[XbH00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oo
oooooooo03kooooo00?o0000o`00Col000002olT3Wd00ol0003oN5RQogQHX@0EogQHX@03o`000?nH
KZ7oV6jQ00_oV6jQ1?l0000:oiak[P03o`000?n`RZgo/8Z]01co/8Z]00?o0000ol:I[_o2VJh06Oo2
VJh4o`00017oeZ>Q00?o0000omJSXOoFXj401OoFXj400ol0003ok;^OonbkW`06onbkW`;o00002?oa
/HL01?l0003oo/MXook7J?l00002on^S9P03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0?_ooool2o`0000co90im00?o0000ogQHXOmhF:405Omh
F:400ol0003oV6jQoiQ^X@08oiQ^X@?o00003onLNjh00ol0003o/8Z]ok2:[@0Kok2:[@03o`000?o2
VJko`YV^01_o`YV^00?o0000om>Z[ol000000_l0000>omJSX@03o`000?oFXj7oeZ>Q00GoeZ>Q00?o
0000onbkWoo/^il02?o/^il00ol0003olK67oo6aQ`05oo6aQ`07o`000?onafSoo/MXook7J?l0003o
jj<Vo`00000Zooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo03kooooo
00?o0000ob@>OOlT3Wd02_lT3Wd2o`0001SoN5RQ00?o0000oiQ^XOnHKZ400onHKZ44o`0001;oW7^^
00?o0000ok2:[On`RZd06on`RZd00ol0003o`YV^ol:I[P0Kol:I[P03o`000?oCZZoodjZ_00;odjZ_
0_l0000:omJSX@?o00001_oFXj400ol0003ok;^OonbkW`0:onbkW`03o`000?oa/HOolK6700ColK67
00Go0000ook7J?onafSoo/MXo`000002on^S9P03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool03_ooool001cooooo00?o0000ooooooooool0?_ooool00ol0003o90imob@>O@09ob@>O@04o`00
0?m2=Yco@SJLo`0001OoN5RQ00?o0000oiQ^XOl000000ol0000Foiak[P03o`000?n`RZgo/8Z]01_o
/8Z]00?o0000ol:I[_o2VJh06_o2VJh00ol0003odjZ_om>Z[`05om>Z[`?o00001?oFXj43o`0000;o
eZ>Q00?o0000omJSXOoFXj401?oFXj400ol0003ok;^OonbkW`0;onbkW`03o`000?oa/HOolK6700?o
lK6700?o0000ook7J?onafP00_onafP00ol0003ojj<Vo`00000Yooooo`03o`000?oooooooooo00ko
oooo000Looooo`;o0000?oooool00ol0003o90imob@>O@08ob@>O@05o`000?m2=Yco@SJLod8fW?l0
00005_mhF:43o`0001[oW7^^00?o0000ok2:[On`RZd06on`RZd00ol0003o`YV^ol:I[P0Jol:I[P03
o`000?oCZZoodjZ_00SodjZ_1?l00006omJSX@03o`000?oFXj7oeZ>Q00?oeZ>Q00?o0000onbkWoo/
^il03?o/^il00ol0003olK67oo6aQ`02oo6aQ`03o`000?onafSoo/MX00;oo/MX00?o0000on^S9_l0
0000:_ooool00ol0003oooooooooo`0=ooooo`006oooool2o`00043ooooo00?o0000ob@>OOlT3Wd0
2?lT3Wd01Ol0003o@SJLod8fW?m2=Yco000001CoN5RQ0_l000000on2Jk3o0000oiak[P0Joiak[P03
o`000?n`RZgo/8Z]01[o/8Z]00?o0000ol:I[_o2VJh06oo2VJh00ol0003odjZ_om>Z[`06om>Z[`?o
000000CodjZ_o`000?l0003o00001_oFXj400ol0003oeZ>QomJSX@02omJSX@03o`000?o/^iook;^O
00gok;^O00Co0000oo6aQooa/HOo00001OonafP00ol0003ojj<Vo`00000Zooooo`03o`000?oooooo
oooo00gooooo000Kooooo`03o`000?oooooooooo03oooooo00?o000no`000?lT3Wd01olT3Wd00ol0
003o@SJLod8fW002od8fW003o`000?mhF:7oN5RQ017oN5RQ00Go0000oh9[/?n2Jk3oPV^`o`00000K
oiak[P03o`000?n`RZgo/8Z]01[o/8Z]00?o0000ol:I[_o2VJh06oo2VJh00ol0003odjZ_om>Z[`02
om>Z[`Co00001ooCZZl2o`0000GoeZ>Q00Go0000omJSXOoFXj7oeZ>Qo`00000@onbkW`03o`000?oa
/HOo000000Koo/MX0_l0000Zooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooo
oooo03kooooo00?o0000o`00?_l000001olT3Wd00ol0003o@SJLod8fW004od8fW003o`000?mhF:7o
N5RQ00koN5RQ0_l00005oh9[/003o`000?nLNjkoW7^^01WoW7^^00?o0000ok2:[On`RZd06On`RZd0
0ol0003o`YV^ol:I[P0Kol:I[P03o`000?oCZZoo000000;o00003OoCZZl3o`0000?oeZ>Q00Co0000
omJSXOoFXj7o00004Oo/^il2o`0000Koo/MX0_l0000Zooooo`03o`000?oooooooooo00gooooo000K
ooooo`03o`000?oooooooooo03kooooo00?o0000o`00?_l000001_lT3Wd00ol0003o@SJLod8fW005
od8fW003o`000?mhF:7oN5RQ00coN5RQ0_l00007oh9[/003o`000?nLNjkoW7^^01WoW7^^00?o0000
ok2:[On`RZd06On`RZd00ol0003o`YV^ol:I[P0Jol:I[P?o00004ooCZZl2o`000004omJSXOl0003o
eZ>Qo`0001?ok;^O00?o0000ook7J?onafP01OonafP00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000o`00?_l000001_lT3Wd0
0ol0003o@SJLod8fW005od8fW003o`000?mhF:7oN5RQ00[oN5RQ0_l00009oh9[/003o`000?nLNjko
W7^^01WoW7^^00?o0000ok2:[On`RZd06On`RZd00ol0003o`YV^ol:I[P0Gol:I[PCo00005ooCZZl4
o`0001?ok;^O00?o0000ook7J?onafP01OonafP2o`0002Wooooo00?o0000ooooooooool03Oooool0
01_ooooo00?o0000ooooooooool0?_ooool00ol0003o000no`000005ob@>O@03o`000?m2=Yco@SJL
00Ko@SJL00?o0000ogQHXOmhF:402OmhF:400ol0003oPV^`oh9[/00:oh9[/003o`000?nLNjkoW7^^
01SoW7^^00?o0000ok2:[On`RZd06On`RZd00ol0003o`YV^ol:I[P0Col:I[PCo00000oo2VJh00ol0
003odjZ_om>Z[`0Hom>Z[`;o00004_o/^il2o`0000Koo/MX0_l0000Yooooo`03o`000?oooooooooo
00gooooo000Kooooo`03o`000?oooooooooo03kooooo00?o0000o`00?_l000001?lT3Wd00ol0003o
@SJLod8fW008od8fW003o`000?mhF:7oN5RQ00KoN5RQ0_l0000=oh9[/003o`000?nLNjkoW7^^01So
W7^^00?o0000ok2:[On`RZd06On`RZd00ol0003o`YV^ol:I[P0@ol:I[P?o00001oo2VJh00ol0003o
djZ_om>Z[`0Hom>Z[`?o00004?o/^il00ol0003oo]VDo`000007ook7J003o`000?oooooooooo02So
oooo00?o0000ooooooooool03?ooool001[ooooo0ol0000oooooo`03o`000?l003ko000000?o90im
00?o0000od8fW?m2=Y`02Om2=Y`00ol0003oN5RQogQHX@04ogQHX@;o00003on2Jk000ol0003oW7^^
oiak[P0Hoiak[P03o`000?n`RZgo/8Z]01Wo/8Z]00?o0000ol:I[_o2VJh03Oo2VJh3o`0000Wo`YV^
00?o0000om>Z[ooCZZl06?oCZZl00ol0003oiL6bonG1/P02o`0000ook;^O00Co0000ookIU?onfICo
00001_onafP00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`00
0?oooooooooo03oooooo00Co0000o`00?_l003ko00000_lT3Wd00ol0003o@SJLod8fW009od8fW003
o`000?mhF:7oN5RQ00;oN5RQ0_l0000Aoh9[/003o`000?nLNjkoW7^^01WoW7^^00?o0000ok2:[On`
RZd06?n`RZd00ol0003o`YV^ol:I[P09ol:I[PCo00003?o2VJh00ol0003odjZ_om>Z[`0Hom>Z[`06
o`000?oU`K;oiL6bo`000?oU`K;o00003_o/^il01?l0003oo]VDookIU?l00006ook7J003o`000?oo
oooooooo02Sooooo00?o0000ooooooooool03?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0oooooo`06o`00
0?l003ko000no`000?lT3Wgo00003?m2=Y`01Ol0003oN5RQogQHXOmhF:7o000001CoPV^`00?o0000
oiak[_nLNjh06?nLNjh00ol0003o/8Z]ok2:[@0;ok2:[A7o00001Oo2VJh3o`00013o`YV^00?o0000
om>Z[ooCZZl06?oCZZl01_l0003oiL6bonG1/_oU`K;o0000onG1/P;o00003?o/^il01?l0003oo]VD
ookIU?l00006ook7J003o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00004oiRH
V?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0?oooool00ol0003o000no`00?P02o`0000ko@SJL0ol0000Eoh9[/003o`000?nLNjkoW7^^01Ko
W7^^4?l0000=ok2D^@04o`000?o0XK[o`:6jol2Q^POo00004Oo2VJh00ol0003odjZ_om>Z[`0Gom>Z
[`03o`000?oU`K;oiL6b00?oiL6b00Co0000onG1/_oU`K;o00002_o/^il00ol0003oo]VDookIU002
ookIU003o`000?onafSoo/MX00;oo/MX00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<
ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?_ooool01Ol0003o000no`00?_l003ko000000oo@SJL00?o0000oh9[/?n2Jk005On2Jk00
0ol0003oW7^^oiak[P0Coiak[P?o00000_nOR;/00ol0003o/9Biok2D^@0Hok2D^@03o`000?o0XK[o
`:6j00?o00001Oo0XKX7o`0000[o`YV^00?o0000om>Z[ooCZZl05ooCZZl00ol0003oiL6bonG1/P04
onG1/P04o`000?oU`K;oiL6bo`0000Wok;^O00?o0000ookIU?onfI@00_onfI@00ol0003oo/MXook7
J002ook7J003o`000?oooooooooo02Wooooo00?o0000ooooooooool03?ooool000?ooooo00?o0000
ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03kooooo00Go0000
o`00?_l003ko000no`00000?od8fW003o`000?n2Jk3oPV^`01GoPV^`00?o0000oiak[_nLNjh03onL
Njh4o`0000GoWhRk00?o0000ok2D^On`U;T05on`U;T4o`0000oo`:6j1ol00002ol:I[P03o`000?oC
ZZoodjZ_01SodjZ_00?o0000onG1/_oU`K801OoU`K801?l0003oiL6bonG1/_l00008onbkW`03o`00
0?onfICoo]VD00?oo]VD00Go0000ook7J?onafSoo/MXo`00000[ooooo`03o`000?oooooooooo00co
oooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo03oooooo00Go0000o`00?_l003ko000no`00000>od8fW003o`000?mHE;?o0000
01OoPV^`00?o0000oiak[_nLNjh02_nLNjh4o`0000WoWhRk00?o0000ok2D^On`U;T05?n`U;T3o`00
0003ok2D^Ol0003o`:6j01Oo`:6j1?l0000Hom>Z[`03o`000?oU`K;oiL6b00OoiL6b00Co0000onG1
/_oU`K;o00001_o/^il00ol0003oo]VDookIU004ookIU005o`000?onafSoo/MXook7J?l00000;?oo
ool00ol0003oooooooooo`0;ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0?oooool01_l0003o000no`00?_l003ko0021o`0000co@SJL
00Co0000oeQD/omHE;?o00005on2Jk000ol0003oW7^^oiak[P07oiak[P?o00003_nOR;/00ol0003o
/9Biok2D^@0@ok2D^@?o00001?n`U;T00ol0003o`:6jol2Q^P0Hol2Q^P03o`000?o?/Kco000000;o
00005OoCZZl00ol0003oiL6bonG1/P07onG1/P04o`000?oU`K;oiL6bonG1/P;o00001?o/^il00ol0
003oo]VDookIU005ookIU004o`000?onafSoo/MXo`0002cooooo00?o0000ooooooooool02oooool0
0004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`00043ooooo00Ko0000
o`00?_l003ko000no`00POl0000;od8fW003o`000?mHE;?oF5Bc00;oF5Bc00?o0000oh9[/?n2Jk00
5?n2Jk000ol0003oW7^^oiak[P03oiak[PCo00004OnOR;/00ol0003o/9Biok2D^@0=ok2D^@?o0000
1on`U;T00ol0003o`:6jol2Q^P0Hol2Q^P03o`000?o?/Kcock6l00;ock6l0_l0000Com>Z[`03o`00
0?oU`K;oiL6b00SoiL6b00?o0000onG1/_oU`K800_oU`K801Ol0003ok;^OonbkWoo/^ioo000000Oo
o]VD00Co0000ook7J?onafSo0000;?ooool00ol0003oooooooooo`0;ooooo`0000Co<S8bo`000?lb
<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0?oooool01_l0003o000no`00?_l0003o
0021o`0000[o@SJL00?o0000oeQD/omHE;<00omHE;<00ol0003oPV^`oh9[/00Eoh9[/003o`000?nL
Njko000000;o00005OnOR;/00ol0003o/9Biok2D^@09ok2D^@Co00002_n`U;T00ol0003o`:6jol2Q
^P0Gol2Q^P03o`000?o?/Kcock6l00Gock6l0ol0000?om>Z[`03o`000?oU`K;oiL6b00[oiL6b00?o
0000onG1/_oU`K800_oU`K801?l0003ok;^OonbkWol00007ookIU004o`000?onafSoo/MXo`0002co
oooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0?oooool01_l0003o000n
o`00?_l0003o0021o`0000[o@SJL00?o0000oeQD/omHE;<00omHE;<00ol0003oPV^`oh9[/00Doh9[
/0?o00006?nOR;/00ol0003o/9Biok2D^@06ok2D^@?o00003_n`U;T00ol0003o`:6jol2Q^P0Gol2Q
^P03o`000?o?/Kcock6l00Sock6l0ol0000<om>Z[`03o`000?oU`K;oiL6b00_oiL6b00?o0000onG1
/_oU`K800_oU`K82o`0000Woo]VD0_l0000]ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03oooooo00Co0000o`00?_l003ko00000_l008400ol0003o@SJLod8fW006od8f
W003o`000?mHE;?oF5Bc00GoF5Bc00?o0000oh9[/?n2Jk004On2Jk02o`000003ohUl__l0003oWhRk
01SoWhRk00?o0000ok2D^On`U;T00on`U;T3o`00017o/9Bi00?o0000ol2Q^_o0XKX05oo0XKX00ol0
003ock6lolna_00;olna_0;o00002_oCZZl00ol0003oiL6bonG1/P0<onG1/P03o`000?oU`K;oiL6b
00;oiL6b00?o0000ookIU?onfI@01oonfI@2o`0002gooooo00?o0000ooooooooool02oooool001So
oooo00?o0000ooooooooool0@Oooool00ol0003o000no`000002o`00P@03o`000?m2=Yco@SJL00Go
@SJL00?o0000oeQD/omHE;<01_mHE;<00ol0003oPV^`oh9[/00?oh9[/0;o00001?n9O;h00ol0003o
WhRkoin8^`0Foin8^`03o`000?n`U;Wo/9Bi00?o00004on`U;T00ol0003o`:6jol2Q^P0Hol2Q^P03
o`000?o?/Kcock6l00gock6l0ol00006om>Z[`03o`000?oU`K;oiL6b00goiL6b00?o0000onG1/_oU
`K800_oU`K800ol0003oo]VDookIU008ookIU003o`000?oooooooooo02_ooooo00?o0000oooooooo
ool02oooool001Sooooo00?o0000ooooooooool0@Oooool00ol0003o000no`000002o`00P@03o`00
0?m2=Yco@SJL00Co@SJL00?o0000oeQD/omHE;<02?mHE;<00ol0003oPV^`oh9[/00<oh9[/0;o0000
1_n9O;h00ol0003oWhRkoin8^`0Eoin8^`Co00005_n`U;T00ol0003o`:6jol2Q^P0Gol2Q^P03o`00
0?o?/Kcock6l017ock6l0_l00004om>Z[`03o`000?oU`K;oiL6b00koiL6b00Ko0000onG1/_oU`K;o
0000ooKO/_l00009ookIU003o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool001So
oooo00?o0000ooooooooool0@Oooool00ol0003o000no`000003o`00P@03o`000?m2=Yco@SJL00;o
@SJL00?o0000oeQD/omHE;<02OmHE;<00ol0003oPV^`oh9[/00:oh9[/0;o00002?n9O;h00ol0003o
WhRkoin8^`0Boin8^`?o00000_nOR;/00ol0003o/9Biok2D^@0Eok2D^@03o`000?o0XK[o`:6j01Oo
`:6j00?o0000olna_?o?/K`04oo?/K`3o`000003om>Z[ol0003oiL6b013oiL6b00Go0000onG1/_l0
003om]nbo`000009ookIU003o`000?oooooooooo02cooooo00?o0000ooooooooool02_ooool001So
oooo00?o0000ooooooooool0@Oooool00ol0003o000no`000003o`00P@03o`000?m2=Yco@SJL00;o
@SJL00?o0000oeQD/omHE;<02_mHE;<00ol0003oPV^`oh9[/008oh9[/003o`000?n9O;koRGbn00Wo
RGbn00?o0000oin8^onOR;/03_nOR;/3o`0000GoWhRk00?o0000ok2D^On`U;T05On`U;T00ol0003o
`:6jol2Q^P0Gol2Q^P03o`000?o?/Kcock6l01Kock6l0_l0000BonG1/P05o`000?ofgk;om]nbooKO
/_l000001oonfI@2o`0002kooooo00?o0000ooooooooool02_ooool001Sooooo0_l00012ooooo`03
o`000?l003ko000000?o002100Go0000od8fW?m2=Yco@SJLo`00000=oeQD/`03o`000?n2Jk3oPV^`
00KoPV^`0_l0000<ohUl_P03o`000?nOR;_oWhRk00[oWhRk1?l00008oin8^`03o`000?n`U;Wo/9Bi
01Go/9Bi00?o0000ol2Q^_o0XKX05_o0XKX00ol0003ock6lolna_00Golna_003o`000?oNa/7o0000
017oiL6b0_l00002ooKO/P03o`000?onfICoo]VD00Goo]VD00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`11ooooo`03o`000?l003ko000000?o
002100Co0000od8fW?m2=Yco00003_mHE;<00ol0003oPV^`oh9[/004oh9[/0;o00003on9O;h00ol0
003oWhRkoin8^`06oin8^`?o00003?nOR;/00ol0003o/9Biok2D^@0Eok2D^@03o`000?o0XK[o`:6j
01Ko`:6j00?o0000olna_?o?/K`05_o?/K`01Ol0003og/K1omk6`OoNa/7o000000ooiL6b00?o0000
ooKO/_l000000oofgk800ol0003oo]VDookIU004ookIU003o`000?oooooooooo02gooooo00?o0000
ooooooooool02_ooool001Oooooo00?o0000ooooooooool0@_ooool2o`0000Go00210_l0000@oeQD
/`04o`000?n2Jk3oPV^`oh9[/0;o00004On9O;h00ol0003oWhRkoin8^`03oin8^`?o00003onOR;/0
0ol0003o/9Biok2D^@0Eok2D^@03o`000?o0XK[o`:6j01Ko`:6j00?o0000olna_?o?/K`05_o?/K`0
0ol0003og/K1omk6`@02omk6`@;o00003OoU`K801?l0003om]nbooKO/_l00002ooKO/P03o`000?on
fICoo]VD00?oo]VD0_l0000_ooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooo
oooo04?ooooo00?o0000o`00POl008400ol008400ol0003oF5BcoeQD/`0?oeQD/`04o`000?n2Jk3o
0000o`0001?oRGbn00?o0000oin8^onOR;/00ol0000Boin8^`03o`000?n`U;Wo/9Bi01Go/9Bi00?o
0000ol2Q^_o0XKX05_o0XKX00ol0003ock6lolna_00Eolna_003o`000?oNa/7og/K100Gog/K100?o
0000onG1/_oU`K802OoU`K800ol0003om]nbooKO/P02ooKO/P04o`000?ofgk;om]nbo`0000Coo]VD
0_l0000_ooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooooooo04?ooooo00?o
0000o`00POl008400ol008400ol0003oF5BcoeQD/`0@oeQD/`03o`000?n9O;koRGbn01;oRGbn1?l0
000Foin8^`03o`000?n`U;Wo/9Bi01Co/9Bi00?o0000ol2Q^_o0XKX05Oo0XKX00ol0003ock6lolna
_00Folna_003o`000?oNa/7og/K100Kog/K10_l00009onG1/P03o`000?ofgk;om]nb00?om]nb00?o
0000ooKO/_l000001?onfI@2o`0002oooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000
ooooooooool0@oooool00ol0003o0021o`00P@03o`00P@03o`T[[?l0003oF5Bc013oF5Bc00?o0000
ohUl__n9O;h03on9O;h3o`0000;oRGbn00?o0000oin8^onOR;/05OnOR;/00ol0003o/9Biok2D^@09
ok2D^@oo00005?o0XKX00ol0003ock6lolna_00Eolna_003o`000?oNa/7og/K100Wog/K100?o0000
onG1/_oU`K801_oU`K800ol0003om]nbooKO/P04ooKO/P;o00001?onfI@00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo04?ooooo00?o0000o`00
POl008400ol00842o`00013oF5Bc00?o0000ofU]a?l000003On9O;h3o`0000GoRGbn00?o0000oin8
^onOR;/04onOR;/>o`0000_o/9k500Co0000okfYaOnmZLGo_JW51_l0000>ol2Q^P03o`000?o?/Kco
ck6l01Gock6l00?o0000omk6`OoNa/402_oNa/400ol0003oiL6bonG1/P04onG1/P03o`000?ofgk;o
m]nb00Gom]nb00?o0000ooKO/_l000000_onfI@2o`00037ooooo00?o0000ooooooooool02Oooool0
01Oooooo00?o0000ooooooooool0@oooool00ol0003o0021o`00P@03o`00P@03o`000?l9:jco0000
00koF5Bc00Co0000ofU]a?mYKLCo00002_n9O;h3o`0000WoRGbn00?o0000oin8^onOR;/03onOR;/3
o`0000;oXYC600?o0000ok2NaOn`W/D05?n`W/D00ol0003o_JW5okfYa@07okfYa@Go00002Oo0XKX0
0ol0003ock6lolna_00Dolna_003o`000?oNa/7og/K100cog/K10_l00004onG1/P03o`000?ofgk;o
m]nb00Kom]nb0_l00002ookIU0;o0000<Oooool00ol0003oooooooooo`09ooooo`005oooool2o`00
04Gooooo00Go0000o`00POl0087o0021o`000003o`T[[003o`000?mHE;?oF5Bc00[oF5Bc00?o0000
ofU]a?mYKL@00_mYKL@00ol0003oRGbnohUl_P03ohUl_PCo00003?n9O;h00ol0003oWhRkoin8^`0;
oin8^`Co00001OnRU<H00ol0003o/9k5ok2Na@0Dok2Na@03o`000?nmZLGo_JW500co_JW51_l00002
ol2Q^P03o`000?o?/Kcock6l01Cock6l00?o0000omk6`OoNa/403ooNa/401?l0003oiL6bonG1/_l0
000:ooKO/P;o000000?oo]VDo`000?l00000<Oooool00ol0003oooooooooo`09ooooo`005_ooool0
0ol0003oooooooooo`15ooooo`05o`000?l0087o0021o`00POl000000ol9:j`00ol0003oF5BcoeQD
/`09oeQD/`03o`000?mYKLCoJFg400CoJFg400?o0000ohUl__l000000_l0000AohUl_P03o`000?nO
R;_oWhRk00OoWhRk0ol0000:oj:DaP03o`000?n`W/Go/9k501?o/9k500?o0000okfYaOnmZLD04_nm
ZLD4o`0001Gock6l00?o0000omk6`OoNa/404?oNa/400ol0003oiL6bo`00000;ooKO/P;o000000?o
dM9Go`000?ooool0<?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`15
ooooo`05o`000?l0087o0021o`00POl000001?l9:j`00ol0003oF5BcoeQD/`07oeQD/`03o`000?mY
KLCoJFg400CoJFg40ol0000DohUl_P03o`000?nOR;_oWhRk00?oWhRk1?l0000=oj:DaP03o`000?n`
W/Go/9k501?o/9k500?o0000okfYaOnmZLD05?nmZLD00ol0003ob[O8o`000002o`00017ock6l00?o
0000omk6`OoNa/404_oNa/400ol0003om]nbooKO/P0;ooKO/P03o`000?oAdUOo0000037ooooo00?o
0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0A_ooool01?l0003o0021o`00POl0
0004o`T[[003o`000?mHE;?oF5Bc00KoF5Bc00?o0000ofU]a?mYKL@00_mYKL@3o`0000;oJFg400?o
0000ohUl__n9O;h04_n9O;h00ol0003oWhRkoin8^`03o`00017oXYC600?o0000ok2NaOn`W/D04on`
W/D00ol0003o_JW5okfYa@0CokfYa@03o`000?o:]lSob[O800?ob[O80ol0000>olna_003o`000?oN
a/7og/K101;og/K100?o0000ooKO/_ofgk802oofgk82o`0003;ooooo00?o0000ooooooooool02Ooo
ool001Kooooo00?o0000ooooooooool0A_ooool01?l0003o0021o`00POl00005o`T[[003o`000?mH
E;?oF5Bc00GoF5Bc1Ol00005ofU]a003o`000?n9O;koRGbn01;oRGbn0ol0000Doj:DaP03o`000?n`
W/Go/9k501?o/9k500?o0000okfYaOnmZLD04onmZLD00ol0003ob[O8olZgb006olZgb0?o00002_o?
/K`00ol0003og/K1omk6`@0Bomk6`@03o`000?o[h<Oo000000_om]nb0ol0000cooooo`03o`000?oo
oooooooo00Sooooo000Fooooo`03o`000?oooooooooo04Kooooo00Co0000o`00POl0087o00001Ol9
:j`00ol0003oF5BcoeQD/`03oeQD/`?o00002_mYKL@00ol0003oRGbnohUl_P0?ohUl_P;o000000?o
T8_;o`000?nRU<H05?nRU<H00ol0003o/9k5ok2Na@0Cok2Na@03o`000?nmZLGo_JW501?o_JW500?o
0000olZgb?o:]lP02Oo:]lP2o`0000Sock6l00?o0000omk6`OoNa/404OoNa/401?l0003ojn37on_P
aol0000;ooKO/P04o`000?oAdUOo0000o`0003;ooooo00?o0000ooooooooool02?ooool001Kooooo
00?o0000ooooooooool0Aoooool00ol0003o0021o`000006o`T[[003o`000?mHE;?o000000?o0000
3?mYKL@00ol0003oRGbnohUl_P0=ohUl_P;o00001?n@Rl/00ol0003oXYC6oj:DaP0Coj:DaP03o`00
0?n`W/Go/9k501;o/9k500?o0000okfYaOnmZLD04_nmZLD00ol0003ob[O8olZgb00<olZgb0?o0000
1?o?/K`00ol0003og/K1omk6`@0Aomk6`@03o`000?o[h<Oojn3700;ojn3700?o0000ooKO/_ofgk80
1oofgk82o`000004om7BEol0003oooooo`00037ooooo00?o0000ooooooooool02?ooool001Gooooo
00?o0000ooooooooool0B?ooool2o`0000Ko2B^/0ol00002oeQD/`03o`000?mYKLCoJFg400coJFg4
00?o0000ohUl__n9O;h02_n9O;h2o`0000KoT8_;00?o0000oj:Da_nRU<H04onRU<H00ol0003o/9k5
ok2Na@0Aok2Na@03o`000?nmZLGo_JW501?o_JW500?o0000olZgb?o:]lP03oo:]lP3o`000003olna
_?l0003og/K101;og/K100?o0000on_Paoo[h<L00_o[h<L00ol0003om]nbooKO/P06ooKO/P04o`00
0?oWli[o0000o`0000?ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`00
5Oooool3o`0004Sooooo0_l00002o`T[[0Co00000_l9:j`00ol0003oF5Bco`00000?ofU]a003o`00
0?n9O;koRGbn00OoRGbn0ol00009oi2;b`03o`000?nRU<KoXYC601;oXYC600?o0000ok2NaOn`W/D0
4On`W/D00ol0003o_JW5okfYa@0CokfYa@03o`000?o:]lSob[O801;ob[O80_l0000Bomk6`@03o`00
0?o[h<Oojn3700?ojn3700?o0000ooKO/_ofgk801_ofgk801?l0003oio>Jo`000?l00003ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0
BOooool3o`0000Oo2B^/00?o0000ofU]a?mYKL@03omYKL@00ol0003oRGbnohUl_P04ohUl_P;o0000
3?n@Rl/00ol0003oXYC6oj:DaP0Boj:DaP03o`000?n`W/Go/9k5017o/9k500?o0000okfYaOnmZLD0
4_nmZLD00ol0003ob[O8olZgb00ColZgb003o`000?oEbLko0000013og/K100?o0000on_Paoo[h<L0
1Oo[h<L00ol0003om]nbooKO/P04ooKO/P03o`000?oWli[oio>J00;o00001?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Kooooo1?l0
0009o`T[[003o`000?mYKLCoJFg4013oJFg400Co0000ohUl__n9O;koRGbn0_l0000?oi2;b`03o`00
0?nRU<KoXYC6017oXYC600?o0000ok2NaOn`W/D04On`W/D00ol0003o_JW5okfYa@0BokfYa@03o`00
0?o:]lSob[O801;ob[O800Co0000omG9c_oEbLkoeLW>0_l0000=omk6`@03o`000?o[h<Oojn3700Ko
jn3700?o0000ooKO/_ofgk801?ofgk801?l0003oio>Jo`000?l00006ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0@_ooool4o`0000?o
oooo00?o0000o`T[[?l9:j`01ol9:j`2o`00017oJFg400Co0000ohUl__l0003o00004On@Rl/00ol0
003oXYC6oj:DaP0Boj:DaP03o`000?n`W/Go/9k5013o/9k500?o0000okfYaOnmZLD04_nmZLD00ol0
003ob[O8olZgb00AolZgb003o`000?oEbLkoeLW>00CoeLW>00?o0000omk6`OoNa/402_oNa/400ol0
003ojn37on_Pa`07on_Pa`03o`000?ofgk;om]nb00;om]nb00?o0000onOcV_oWliX00_l00007oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool0?oooool3o`0000Sooooo00?o0000o`T[[?l9:j`01_l9:j`00ol0003o<eO8o`00000AofU]a003
o`000?n@Rl_oT8_;01;oT8_;00?o0000oj:Da_nRU<H04OnRU<H00ol0003o/9k5ok2Na@0@ok2Na@03
o`000?nmZLGo_JW5017o_JW500?o0000olZgb?o:]lP04_o:]lP00ol0003oeLW>omG9cP05omG9cP;o
00002OoNa/400ol0003ojn37on_Pa`08on_Pa`03o`000?ofgk;om]nb00;om]nb00?o0000onOcV_oW
liX00_l00008ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool001Cooooo
00?o0000ooooooooool0?Oooool3o`0000_ooooo00?o001bo`000?l9:j`01Ol9:j`01Ol0003o<eO8
oc=Gb?lcElSo0000013oJFg400?o0000oi2;bon@Rl/04_n@Rl/00ol0003oXYC6oj:DaP0Aoj:DaP03
o`000?n`W/Go/9k5013o/9k500?o0000okfYaOnmZLD04OnmZLD00ol0003ob[O8olZgb00AolZgb003
o`000?oEbLkoeLW>00SoeLW>00?o0000omk6`OoNa/401OoNa/400ol0003ojn37on_Pa`0:on_Pa`04
o`000?ofgk;om]nbo`0000?oio>J00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03[ooooo0ol0000?ooooo`03
o`000?l9:jco2B^/00Co2B^/00?o0000oc=Gb?lcElP00_lcElP00ol0003oJFg4ofU]a00<ofU]a003
o`000?mhPm7o000001?oT8_;00?o0000oj:Da_nRU<H04OnRU<H00ol0003o/9k5ok2Na@0@ok2Na@03
o`000?nmZLGo_JW5017o_JW500?o0000olZgb?o:]lP04Oo:]lP00ol0003oeLW>omG9cP09omG9cP03
o`000?oNa/7og/K100Cog/K100?o0000on_Paoo[h<L02_o[h<L00ol0003om]nbo`000004onOcVP03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0fooooo`Co00004_ooool00ol007;o0000o`T[[004o`T[[003o`00
0?lcElSo<eO800;o<eO800?o0000ofU]a?mYKL@02omYKL@01Ol0003oN8?AogR3dOmhPm7o000001?o
T8_;00?o0000oj:Da_nRU<H04?nRU<H00ol0003o/9k5ok2Na@0@ok2Na@03o`000?nmZLGo_JW5013o
_JW500?o0000olZgb?o:]lP04Oo:]lP00ol0003oeLW>omG9cP0;omG9cP;o00000ooNa/400ol0003o
jn37on_Pa`0;on_Pa`03o`000?ofgk;o000000?oio>J0_l0000;ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01oooool001Cooooo0ol0000cooooo`?o00005oooool00ol0003o2B^/
o`T[[003o`T[[003o`000?lcElSo<eO800?o<eO800?o0000ofU]a?mYKL@02OmYKL@00ol0003oN8?A
ogR3d@03ogR3d@03o`000?n@Rl_oT8_;013oT8_;00?o0000oj:Da_nRU<H04OnRU<H00ol0003o/9k5
ok2Na@06ok2Na@oo00003OnmZLD00ol0003ob[O8olZgb00@olZgb003o`000?oEbLkoeLW>00koeLW>
00?o0000omk6`Ol000003oo[h<L00ol0003oio>JonOcVP02onOcVP03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`0`ooooo`?o00006_ooool2o`0000Co2B^/00?o0000oc=Gb?lcElP01?lcElP00ol0003oJFg4ofU]
a007ofU]a003o`000?mhPm7oN8?A00GoN8?A00?o0000oi2;bon@Rl/04?n@Rl/00ol0003oXYC6oj:D
aP0>oj:DaP_o00002On_Z=400ol0003o^[7AokZad@03okZad@Wo00001?nmZLD00ol0003ob[O8olZg
b00@olZgb003o`000?oEbLkoeLW>00ooeLW>00?o0000on_Paoo[h<L03_o[h<L00ol0003oio>JonOc
VP02onOcVP03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool3
o`0001kooooo00?o001bo`000?l9:j`00_l9:j`00ol0003o<eO8oc=Gb005oc=Gb003o`000?mYKLCo
JFg400GoJFg400?o0000ogR3dOmhPm401_mhPm400ol0003oT8_;oi2;b`0@oi2;b`03o`000?nRU<Ko
XYC600[oXYC61?l00002oj>QdP03o`000?n_Z=7o[jSA00oo[jSA00?o0000okZadOnj/M403?nj/M45
o`00017ob[O800?o0000omG9c_oEbLh04?oEbLh00ol0003ojn37on_Pa`0=on_Pa`;o00001?oWliX0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool0
00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`Co00008Oooool2o`00
00?o2B^/00?o0000oc=Gb?lcElP01OlcElP00ol0003oJFg4ofU]a005ofU]a003o`000?mhPm7oN8?A
00OoN8?A00?o0000oi2;bon@Rl/04?n@Rl/00ol0003oXYC6oj:DaP04oj:DaPGo00001_nSXM800ol0
003o[jSAojnXd@0?ojnXd@03o`000?nj/M7o^[7A00oo^[7A00?o0000ol>me?l000000_l0000=olZg
b003o`000?oEbLkoeLW>013oeLW>00?o0000omkOe_l000003Oo[h<L00ol0003oio_5o`000003onOc
VP03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06oooo
o`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo0ol0000Uooooo`05
o`000?l007;o0000o`T[[?l000002OlcElP00ol0003oJFg4ofU]a003ofU]a003o`000?mhPm7oN8?A
00WoN8?A00?o0000oi2;bon@Rl/03on@Rl/00ol0003oXYC6oj:DaP04o`0000coXj7B00?o0000ojnX
dOn_Z=403_n_Z=400ol0003o^[7AokZad@0>okZad@03o`000?o3_MCo`kgD00?o`kgD0_l0000;olZg
b003o`000?oEbLkoeLW>00ooeLW>00Co0000omkOe_oNgmKo00003?o[h<L00ol0003oio_5o`000004
onOcVP03o`000?oooooooooo00oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06
ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo0ol0000Yoooo
o`;o000000?o2B^/o`000?lcElP02OlcElP01Ol0003oJFg4ofU]a?mYKLCo000000goN8?A00?o0000
oi2;bon@Rl/03_n@Rl/3o`00013oXj7B00?o0000ojnXdOn_Z=403_n_Z=400ol0003o^[7AokZad@0>
okZad@03o`000?o3_MCo`kgD00Go`kgD0ol00007olZgb003o`000?oEbLkoeLW>00ooeLW>00?o0000
omkOe_oNgmH00_oNgmH00ol0003ojn37on_Pa`08on_Pa`04o`000?oWnlGoio_5o`0000?oio>J00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool3o`0002cooooo00Co0000
o`00L_l0003o00002olcElP00ol0003oJFg4o`00000?ogR3d@03o`000?n@Rl_oT8_;00_oT8_;0_l0
00000onEVmOo0000oj>QdP0@oj>QdP03o`000?n_Z=7o[jSA00ko[jSA00?o0000okZadOnj/M403Onj
/M400ol0003o`kgDol>me009ol>me0;o00001Oo:]lP00ol0003oeLW>omG9cP0>omG9cP03o`000?oN
gmKog]oF00?og]oF00?o0000on_Paoo[h<L01oo[h<L01Ol0003oio_5onOkaOoWnlGo000000;oio>J
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool4o`00033ooooo00?o
0000o`00L_l000003?lcElP2o`0000ooN8?A00?o0000oi2;bon@Rl/02On@Rl/2o`0000CoUI_G00?o
0000oj>Qd_nSXM803_nSXM800ol0003o[jSAojnXd@0>ojnXd@03o`000?nj/M7o^[7A00go^[7A00?o
0000ol>me?o3_M@02oo3_M@3o`000003olZgb?l0003oeLW>00ooeLW>00?o0000omkOe_oNgmH01OoN
gmH00ol0003ojn37on_Pa`05on_Pa`03o`000?oWnlGoio_500;oio_500Co0000onOcV_oWli[o0000
5_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool06_ooool3o`0003Cooooo00Co0000o`00L_l0;KKo0000
2olcElP2oeAifP03o`000?mhPm7oN8?A00goN8?A00?o0000oi2;bon@Rl/01On@Rl/3o`0000OoUI_G
00?o0000oj>Qd_nSXM803_nSXM800ol0003o[jSAojnXd@0=ojnXd@03o`000?nj/M7o^[7A00go^[7A
00?o0000ol>me?o3_M@03_o3_M@2o`0000ooeLW>00?o0000omkOe_oNgmH01_oNgmH00ol0003ojn37
on_Pa`05on_Pa`03o`000?oWnlGoio_500;oio_500?o0000onOcV_l000005oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0
000Hooooo`?o0000>?ooool01?l0003o001bo`0]]_l0000:oc=Gb004o`000?mDNM[oE7WJo`0000oo
N8?A00?o0000oi2;bon@Rl/00_n@Rl/2o`0000[oUI_G00?o0000oj>Qd_nSXM803_nSXM800ol0003o
[jSAojnXd@0<ojnXd@03o`000?nj/M7o^[7A00go^[7A00?o0000ol>me?o3_M@03oo3_M@00ol0003o
bl_Io`00000=omG9cP03o`000?oNgmKog]oF00Sog]oF00?o0000on_Paoo[h<L00oo[h<L00ol0003o
io_5onOka@03onOka@03o`000?oWli[o000001Sooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`06ooooo`004_ooool2o`0001Gooooo1?l0000kooooo`05o`000?l007;o0000o`0]]_l0
00002OlcElP01Ol0003oE7WJoeAif_mDNM[o000000ooN8?A00Co0000oi2;bol0003o00003OnEVmL0
0ol0003oXj7Boj>QdP0=oj>QdP03o`000?n_Z=7o[jSA00co[jSA00?o0000okZadOnj/M403Onj/M40
0ol0003o`kgDol>me00>ol>me004o`000?o;bmWobl_Iol_;f@;o00002_oEbLh00ol0003og]oFomkO
eP09omkOeP03o`000?o[h<Oojn3700;ojn3700?o0000onOkaOoWnlD01?oWnlD2o`0001[ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0A
ooooo`?o0000@?ooool01Ol0003o001bo`000?l0;KKo000000Oo<eO800?o0000oeAif_mDNMX00omD
NMX00ol0003oN8?AogR3d@0=ogR3d@;o00003onEVmL00ol0003oXj7Boj>QdP0<oj>QdP03o`000?n_
Z=7o[jSA00co[jSA00?o0000okZadOnj/M403?nj/M400ol0003o`kgDol>me00>ol>me003o`000?o;
bmWobl_I00Cobl_I00?o0000omG9c_oEbLh01_oEbLh00ol0003og]oFomkOeP0;omkOeP04o`000?o[
h<Oojn37o`0000Koio_50_l0000Looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1Oooool001;ooooo00?o0000ooooooooool03_ooool3o`0004Cooooo00Go001bo`000?l0;KKo02ff
o`000006oc=Gb003o`000?mDNM[oE7WJ00CoE7WJ00?o0000ogR3dOmhPm402omhPm401?l0003oQ9KM
ohBFgOl0000>oiFKe`03o`000?nSXM;oXj7B00goXj7B00?o0000ojnXdOn_Z=402on_Z=400ol0003o
^[7AokZad@0<okZad@03o`000?o3_MCo`kgD00go`kgD00?o0000ol_;fOo;bmT01_o;bmT00ol0003o
eLW>omG9cP04omG9cP03o`000?oNgmKog]oF00cog]oF00?o0000on_Paol000001ooWnlD2o`0001go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`0;ooooo`?o0000Aoooool00ol0003o001bo`000002o`0]]P03o`000?lcElSo<eO800?o<eO8
00?o0000oeAif_mDNMX01OmDNMX00ol0003oN8?AogR3d@09ogR3d@03o`000?n4U]goQ9KM00;oQ9KM
00?o0000oiFKeonEVmL03?nEVmL00ol0003oXj7Boj>QdP0<oj>QdP03o`000?n_Z=7o[jSA00_o[jSA
00?o0000okZadOnj/M402onj/M400ol0003o`kgDol>me00=ol>me003o`000?o;bmWobl_I00Sobl_I
0_l00003omG9cP03o`000?oNgmKog]oF00kog]oF00?o0000onOkaOoWnlD01_oWnlD00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o
0000ooooooooool01oooool4o`0004_ooooo0_l00003o`0]]P03o`000?lcElSo<eO800;o<eO800?o
0000oeAif_mDNMX01_mDNMX00ol0003oN8?AogR3d@07ogR3d@03o`000?n4U]goQ9KM00CoQ9KM00?o
0000oiFKeonEVmL03?nEVmL00ol0003oXj7Boj>QdP0;oj>QdP03o`000?n_Z=7o[jSA00_o[jSA00?o
0000okZadOnj/M402onj/M400ol0003o`kgDol>me00<ol>me003o`000?o;bmWobl_I00_obl_I00?o
0000omG9c_l000003ooNgmH00ol0003og?KMo`000008onOka@03o`000?oooooooooo01gooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`04
ooooo`?o0000D?ooool00ol0003o02ffo`0]]P02o`0]]P05o`000?lcElSo<eO8oc=Gb?l000002OmD
NMX00ol0003oN8?AogR3d@05ogR3d@03o`000?n4U]goQ9KM00KoQ9KM00?o0000oiFKeonEVmL02onE
VmL00ol0003oXj7Boj>QdP0;oj>QdP03o`000?n_Z=7o[jSA00_o[jSA00?o0000okZadOnj/M402onj
/M400ol0003o`kgDol>me00;ol>me003o`000?o;bmWobl_I00gobl_I00?o0000omkOe_oNgmH03OoN
gmH01?l0003og?KMomcfgOl00007onOka@03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000Dooo
ool2o`0000Co02ff00?o0000oc=Gb?l000002omDNMX00ol0003oN8?AogR3d@03ogR3d@03o`000?n4
U]goQ9KM00SoQ9KM00?o0000oiFKeonEVmL02onEVmL00ol0003oXj7Boj>QdP0;oj>QdP03o`000?n_
Z=7o[jSA00[o[jSA00?o0000okZadOnj/M402_nj/M400ol0003o`kgDol>me00<ol>me003o`000?o;
bmWobl_I00_obl_I00?o0000oloKhOl000003_oNgmH01Ol0003og?KMomcfgOoLm]go000000Koio_5
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
000Aooooo`03o`000?oooooo000000;o0000Eoooool00ol0003o02ffo`0]]P03o`0]]P03oc=Gb?l0
003oE7WJ00_oE7WJ00Go0000ogR3dOmhPm7oN8?Ao`00000<ohBFg@03o`000?nEVmOoUI_G00_oUI_G
00?o0000oj>Qd_nSXM802?nSXM8Fo`0000Ko^[7A00?o0000ol>me?o3_M@02oo3_M@00ol0003obl_I
ol_;f@0;ol_;f@05o`000?o?fn7ocm_QoloKhOl000002ooNgmH2o`0000Cog?KM00?o0000onOkaOoW
nlD00ooWnlD00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01Oooool0017ooooo0_l0001Jooooo`;o00001Ol0;KH2o`0000coE7WJ00?o0000ogR3dOl00000
3_n4U]d00ol0003oUI_GoiFKe`0:oiFKe`03o`000?nSXM;oXj7B00CoXj7B1?l00002ojB_g`03o`00
0?n//mko[;?N00[o[;?N00?o0000ok>jg_nc^]h01?nc^]h7o`0000co`kgD00?o0000ol_;fOo;bmT0
2oo;bmT00ol0003ocm_QoloKh@02oloKh@03o`000?oNgmKog]oF00Sog]oF00?o0000omcfgOoLm]d0
1?oLm]d00ol0003oio_5onOka@02onOka@03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004oooool00ol0003oooooooooo`1Hooooo`03o`000?l0
;KKo02ff00?o02ff0_lJJM`00ol0003oE7WJoeAifP0:oeAifP;o00003on4U]d00ol0003oUI_GoiFK
e`0:oiFKe`03o`000?nSXM;oXj7B00?o00001onT[ml00ol0003o[;?NojbcgP09ojbcgP03o`000?nc
^]ko/k[N00Wo/k[N00?o0000okW2hOl000000_l00008ol>me003o`000?o;bmWobl_I00_obl_I00?o
0000oloKhOo?fn401?o?fn400ol0003og]oFomkOeP06omkOeP03o`000?oLm]gog?KM00Cog?KM00?o
0000onOkaOoWnlD00_oWnlD00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01?ooool001Cooooo0_l0001Iooooo`;o00001?l0;KH2oaYYg003o`000?mDNM[o
E7WJ00WoE7WJ0_m]TnH00ol0003oQ9KMohBFg@0=ohBFg@03o`000?nEVmOoUI_G00WoUI_G0ol0000:
ojB_g`03o`000?n//mko[;?N00Wo[;?N00?o0000ok>jg_nc^]h02?nc^]h00ol0003o^L;QokW2h@03
okW2h@;o00001Oo3_M@00ol0003obl_Iol_;f@0;ol_;f@03o`000?o?fn7ocm_Q00Kocm_Q00?o0000
omkOe_oNgmH00ooNgmH2o`0000Oog?KM00Co0000onOkaOoWnlGoio_50_l0000Yooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000ooooooooool0F?ooool0
1Ol0003o02ffo`0]]_l0;KKo000000;o6VWL0_l00009oeAifP03o`000?m]TnKoKI?V00;o00003_n4
U]d00ol0003oUI_GoiFKe`06oiFKe`;o000000?oVZ_So`000?nT[ml02_nT[ml00ol0003o[;?Nojbc
gP08ojbcgP03o`000?nc^]ko/k[N00Wo/k[N00?o0000okW2hOni`^401Oni`^43o`000003ol>me?l0
003obl_I00_obl_I0_l00009oloKh@03o`000?oNgmKog]oF00;og]oF00?o0000omcfgOoLm]d01ooL
m]d00ol0003oio_5onOka@02o`0002_ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`04ooooo`005oooool2o`0005Wooooo00Go0000o`0]]_l0;KKo02ffo`000003oaYYg003o`000?mD
NM[oE7WJ00GoE7WJ00?o0000offCi_m]TnH00om]TnH00ol0003oQ9KMohBFg@0<ohBFg@03o`000?nE
VmOoUI_G00;oUI_G0ol00004oiZ[h`03o`000?nT[mooY:oO00WoY:oO00?o0000ojbcg_n//mh01on/
/mh00ol0003o/k[Nok>jgP08ok>jgP03o`000?ni`^7o^L;Q00Wo^L;Q00?o0000ol_;fOo;bmT02_o;
bmT00ol0003ocm_QoloKh@0:oloKh@04o`000?oNgmKog]oFo`0000[og?KM00Co0000onOkaOl0003o
0000;Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o0000
FOooool01?l0003o02ffo`0]]_l00004oaYYg003o`000?mDNM[oE7WJ00CoE7WJ00?o0000offCi_m]
TnH01?m]TnH2o`0000goQ9KM00Co0000oiFKeol0003o00002?nJZn<00ol0003oY:oOojB_g`08ojB_
g`03o`000?n//mko[;?N00Oo[;?N00?o0000ok>jg_nc^]h01onc^]h00ol0003o^L;QokW2h@09okW2
h@?o_L_U00?o0000ol_;fOo;bmT01oo;bmT00ol0003ocm_QoloKh@0;oloKh@03o`000?oNgmKo0000
00_og?KM0ol0000_ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool001[o
oooo00?o0000ooooooooool0Eoooool01?l0003o02ffo`0]]_l00004oaYYg003o`000?mDNM[oE7WJ
00?oE7WJ00?o0000offCi_m]TnH01_m]TnH00ol0003oQ9KMohBFg@0;ohBFg@;o00002_nJZn<00ol0
003oY:oOojB_g`07ojB_g`03o`000?n//mko[;?N00Oo[;?N00?o0000ok>jg_nc^]h01onc^]h00ol0
003o^L;QokW2h@07okW2h@03o`000?nmbnGo_L_U00?o_L_U0_l00006ol_;f@03o`000?o?fn7ocm_Q
00gocm_Q00?o0000omcfgOoLm]d02_oLm]d2o`00033ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`04ooooo`006oooool2o`000003ooooool0003ooooo05Gooooo00?o0000o`0]]_l0
00001OlJJM`2o`0000?oE7WJ00?o0000offCi_m]TnH01om]TnH00ol0003oQ9KMohBFg@09ohBFg@04
o`000?n?Z^OoSj[Wo`0000[oVZ_S00?o0000ojB_gonT[ml01onT[ml00ol0003o[;?NojbcgP06ojbc
gP03o`000?nc^]ko/k[N00Ko/k[N00?o0000okW2hOni`^401oni`^400ol0003o_L_Uokg;i@06okg;
i@;o00000oo;bmT00ol0003ocm_QoloKh@0;oloKh@;o000000?ocNcZo`000?oLm]d02?oLm]d2o`00
0003okWmdol0003ooooo037ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`007Oooool2o`0005Oooooo00?o02ffo`000?lJJM`01_lJJM`01?l0003oE7WJoeAif_l0000:offC
iP;o00002?n4U]d00ol0003oSj[WohnZi`02ohnZi`03o`000?nJZn?oVZ_S00SoVZ_S00?o0000ojB_
gonT[ml01_nT[ml00ol0003o[;?NojbcgP06ojbcgP03o`000?nc^]ko/k[N00Ko/k[N00?o0000okW2
hOni`^401_ni`^400ol0003o_L_Uokg;i@09okg;i@03o`000?o;bmWo000000gocm_Q00Go0000olg/
j_o=k>[ocNcZo`000008omcfg@04o`000?nioM?o^OgCo`0003Cooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`03ooooo`007_ooool00ol0003oooooooooo`1Fooooo`03o`0]]_l0003o
6VWL00Ko6VWL00?oE7WJo`000?m]TnH03?m]TnH00ol0003oQ9KMohBFg@04ohBFg@03o`000?n?Z^Oo
Sj[W00CoSj[W00?o0000oiZ[honJZn<01onJZn<00ol0003oY:oOojB_g`06ojB_g`03o`000?n//mko
[;?N00Ko[;?N00?o0000ok>jg_nc^]h01Onc^]h00ol0003o^L;QokW2h@05okW2h@;o00003OnmbnD0
0ol0003ocm_QoloKh@0:oloKh@;o00001?o=k>X00ol0003og?KMomcfg@04omcfg@;o00000_nioM<0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool0
01oooooo0_l0001Gooooo`03o`000?lJJMco6VWL00Ko6VWL0_l0000=offCiP;o00000on4U]d00ol0
003oSj[WohnZi`06ohnZi`;o00002?nJZn<00ol0003oY:oOojB_g`06ojB_g`03o`000?n//mko[;?N
00Co[;?N00?o0000ok>jg_nc^]h01_nc^]h00ol0003o^L;QokW2h@04okW2h@03o`000?nmbnGo_L_U
00_o_L_U00?o0000okoEjol000002_o?fn42o`0000KocNcZ00?o0000omcfgOoLm]d00_oLm]d2o`00
00?o^OgC00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00?ooooo000Qooooo`03o`000?oooooooooo05Gooooo0_l00006oaYYg004o`000?m?TNko0000o`00
00goKI?V0_n4U]d00ol0003oSj[WohnZi`09ohnZi`03o`000?nJZn?oVZ_S00KoVZ_S00?o0000ojB_
gonT[ml01OnT[ml00ol0003o[;?NojbcgP04ojbcgP03o`000?nc^]ko/k[N00Go/k[N00?o0000okW2
hOni`^401?ni`^400ol0003o_L_Uokg;i@09okg;i@;o00001?noeN/00ol0003ocm_QoloKh@05oloK
h@;o00001oo=k>X01?l0003og?KMomcfgOoLm]d2o`0000Co^OgC00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Rooooo`?o0000E_ooool00ol0
003o6VWLoaYYg004oaYYg003o`000?m?TNkoCi7^00;o00003?m]TnH2o`0000coSj[W00?o0000oiZ[
honJZn<01_nJZn<00ol0003oY:oOojB_g`04ojB_g`03o`000?n//mko[;?N00Co[;?N00?o0000ok>j
g_nc^]h01?nc^]h00ol0003o^L;QokW2h@04okW2h@03o`000?nmbnGo_L_U00So_L_U0_l00006okoE
j`03o`000?o?fn7ocm_Q00?ocm_Q0_l00009olg/jP04o`000?oLm]gog?KMo`0000Go^OgC00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo000Toooo
o`03o`000?oooooooooo05Gooooo0_l00004oaYYg003o`000?m?TNkoCi7^00;oCi7^0_l0000:offC
iP03o`000?n3Z^ko000000;o00002_n?Z^L2o`0000OoVZ_S00Co0000ojB_gonT[mooY:oO3Ol00003
ok>jgP03o`000?ni`^7o^L;Q00?o^L;Q00?o0000okg;iOnmbnD01onmbnD2o`0000Wo_mG[00Go0000
oloKhOo?fn7ocm_Qo`00000;olg/jP?o00001OnioM<00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool002Cooooo0ol0001Fooooo`;o00001?lJJM`0
0ol0003oCi7^odnAkP03odnAkP?o00001om]TnH00ol0003oPj[^oh>ZkP02oh>ZkP;o00002_n?Z^L0
0ol0003oVZ_SoiZ[h`04oiZ[h`Co00000onR_nd00ol0003oYL7]ojG1k@03ojG1k@04o`000?nX`ngo
Z<?]ojS3k@Ko00000_ni`^400ol0003o_L_Uokg;i@07okg;i@03o`000?noeN_o_mG[00Wo_mG[00Co
0000oloKhOl0003o00003?o=k>X00ol0003o^OgCokWmd`04okWmd`03o`000?oooooooooo03gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009oooool00ol0003ooooooooo
o`1Dooooo`?o00000_lJJM`00ol0003oCi7^odnAkP06odnAkP;o00001Om]TnH00ol0003oPj[^oh>Z
kP04oh>ZkP?o00002?n?Z^L01?l0003oVZ_SoiZ[honJZn<2o`0000;oW[g_00?o0000oj:okOnR_nd0
0onR_nd00ol0003oYL7]ojG1k@02ojG1k@03o`000?nX`ngoZ<?]00?oZ<?]00Co0000oj[6k_nZa^ko
Z/K^0_l00008okg;i@;o00003OnoeN/00ol0003ocNcZolg/jP09olg/jP;o000000?o^oO_o`000?ni
oM<01?nioM<00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool002Sooooo00?o0000ooooooooool0EOooool01?l0C;oo0000oaYYg?l0000:odnAkP;o
00000_m]TnH00ol0003oPj[^oh>ZkP08oh>ZkP?o00001_n?Z^L00ol0003oVZ_So`000005oijmk`03
o`000?nR_ngoX[o]00;oX[o]00?o0000ojG1kOnU`Nd00_nU`Nd00ol0003oZ<?]ojS3k@02ojS3k@05
o`000?nZa^koZ/K^oj[6k_l000000on[b_000ol0003o_L_Uokg;i@02okg;i@;o00003?noeN/2o`00
0003okcOlOl0003ocNcZ00SocNcZ0_l00002ok_gk`03o`000?nioM?o^OgC00;o^OgC0_l00012oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool002Wooooo0_l0001Fooooo`;o
000000?o6VWLo`000?m?TNh02_m?TNh00ol0003oKI?Vo`00000=oh>ZkP;o00001On?Z^L2o`0000Ko
W[g_00Go0000oj:okOnR_ngoX[o]o`000003ojG1k@03o`000?nX`ngoZ<?]00;oZ<?]00?o0000oj[6
k_nZa^h00_l00005oj_:l004o`000?nmbnGo0000o`0000[o_mG[0ol00004okcOl@03o`000?o=k>[o
cNcZ00CocNcZ0ol00003ok_gk`04o`000?nioM?o^OgCokWmd`;o0000AOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo000Nooooo`Co000000?o410@ooooooooool01Oooool2
o`0005Kooooo00?o0000o`1<_ol000003Om?TNh3o`0000goPj[^0ol000001?n?Z^Oo0000oiZmlOnJ
_O42o`0000GoW[g_00Go0000oj:okOnR_ngoX[o]o`000002ojG1k@05o`000?nX`ngoZ<?]ojS3kOl0
00000_nZa^h00ol0003oZl[`oj_:l005oj_:l0;o00002OnoeN/3o`0000Oo_=oa00?o0000olg/j_o=
k>X00_o=k>X2o`0000Go^oO_00?o0000okWmdonioM<00_l00018ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool02Oooool2o`0005Gooooo
00?o0000o`1<_ol000000_l0000:odnAkP03o`000?mf[?CoMZcd00Go00002on3Z^h3o`0000?oV[ga
0_l00004oijmk`04o`000?nR_ngoX[o]o`0000;oYL7]00Go0000ojS3kOnX`ngo0000oj[6kP02o`00
00GoZl[`0ol000000on[cO;o0000okoEj`05okoEj`?o00002_nlgo400ol0003ocNcZolg/jP02o`00
00Oo^oO_00Co0000okWmdol0003o0000B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00;ooooo000Eooooo`Ko00001Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
05?ooooo0_l000000ol0C;oo:Hg]o`000003o`0000OoCi7^00?o0000ogJ/m?mf[?@01?mf[?@4o`00
00OoPj[^00?o0000oiJnlonF__<00ol00002oiZml@?o00000_nN_Nl00ol0003oX[o]o`000002ojG1
k@03o`000?nX`ngoZ<?]00;o00001?n[b_03o`0000GoZlgb00?o0000okoEjonoeN/00ol0000=okcO
l@?o00002?nkmnl3o`0004gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02oooo
o`008?ooool00ol0003oooooooooo`0<ooooo`;o0000EOooool00ol0003o04boo`000003obV=k@?o
00001?m?TNh00ol0003oMZcdogJ/m008ogJ/m0Co00000_n3Z^h00ol0003oU[kcoiJnl`04oiJnl`Co
000000[oV[gao`000?l0003oW[g_o`000?nR_ngo0000ojG1kOl0003oZ<?]0_l00002oj_:l0?o0000
1_n[cO85o`00013o_=oa00?o0000ok_gkonkmnl01onkmnl2o`0004oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003oooooooooo`0=ooooo`;o0000E_oo
ool3o`0000Co:Hg]1Ol0000?ogJ/m0Oo00001OnF__<8o`000003ojS3kOl0003o000000?o00000_n[
cO87o`0000?oZM3d00?o0000okcOlOnlgo401_nlgo46o`0000;o/^Kg00?o0000ok_gkonkmnl01onk
mnl00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00Ooo
ool0023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`03o`000?l0C;oo
000000Oo:Hg]1_l0000;ogJ/m003o`000?nC`?KoTl3f00?oTl3f5Ol0000:ojW@m003o`000?nlgo7o
_=oa00Ko00001onbi_L00ol0003o^oO_ok_gk`03ok_gk`Go0000E?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo013ooooo0_l0001Foooo
o`;o00002?lYSNd01?l0003oJ;7jofRan_mX/OX9o`0000?oMZcd00?o0000oi?0m_nC`?H01_nC`?HN
o`0000co/^Kg00?o0000ok_gkonkmnl01?l000000onAknOo0000o`00001Gooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00Oooool001kooooo00?oEEEEofIVI_l000005?ooool2o`00
05Kooooo00?o0000obV=kOlYSNd01_lYSNd00ol0003oJ;7jofRanP09ofRanPco00000on@`_P4o`00
0003oi39nol0003oUm3k00So00002OnVd_L00ol0003o/^Kgok;Vm`0;ok;Vm`Co00000onAknL2o`00
05[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00=_ooool2o`0005Ko
oooo0ol00006obV=k@03o`000?mX/O[oJ;7j00coJ;7j00?o0000oi32n?n@`_P01?n@`_P4o`000004
oho6n_l0003oT<Wkoi39n`;o00000_nGd?/00ol0003oW=7jo`000002o`0000;oXM;i1Ol00003ojKB
m`03o`000?nbi_Oo/^Kg00Co/^Kg1Ol00002ok;Vm`;o00001OnAknL2o`0005_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`01ooooo`00>?ooool00ol0003oooooooooo`1Eooooo`Go
00000olYSNd00ol0003oJ;7jofRanP0<ofRanP03o`000?n@`_SoT<;h00?o00000on?a_X2o`0000?o
T<Wk00?o0000oi?=o?l000000_nGd?/01?l0003oW=7joicAn_nLdOX2o`0000GoXM;i2_l00005oj7W
n`03o`000?nAknOoTNoW00CoTNoW0_l0001Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00Oooool003Wooooo00Co0000oooooooooooo0000E?ooool01?l0003oooooo`000?l5Qmd3
o`000003obV=kOl0003oJ;7j00KoJ;7j1_l000000omX/O[o0000o`000004oho6nP;o00001?n@bO/0
1?l0003oTlgloi?=o?l00003oiO@n`03o`000?nLdO[oW=7j00;oW=7j0ol000000onQd_Wo0000o`00
000<oj7Wn`;o00001_nAknL00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00Oooool003[ooooo0ol0001Dooooo`03o`000?oooooooooo00;ooooo0_l00000
0ol5Qmgo0000o`000006o`0000WoG[Ol0_l000000on?a_[o0000oi39n`04oi39n`05o`000?nCcOco
Tlgloi?=o?l000001?nGd?/00ol0003oW=7joicAnP03oicAnPGo00002_nQio/00ol0003oTNoWoi7_
i`03oi7_i`?o0000Hoooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00??ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Cooooo0ol00002o`F7g@?o00003?mN]o`4
o`0000?oT<Wk00?o0000oi?=o?nCcO`00_nCcO`00ol0003oUm3koiO@n`02oiO@n`03o`000?nLdO[o
000000;o00001On:hO`6o`0000?oXNOk00?o0000oi7_iol000001?l0001Wooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o0000D_ooool00ol0003oooooooooo`07oooo
o`Co000000Co1HOMo`000?l0003o00000_mN]o`5o`0000KoF[ol4?l0000=oh[Qo0Oo0000J_ooool0
0ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00[ooooo0_l0QLD2o`000003o`F7gOl0003o000000coF[ol00?o0000of7:
nomQb_/01?mQb_/00ol0003oLmKkog?Fn`05og?Fn`?o00001on:hO`6o`0006oooooo00?o0000oooo
ooooool01oooool1o`00007ooooo0Oooool0043ooooo0_l0001?ooooo`03o`000?oooooooooo00oo
oooo0ol0QLD4o`0000KoF[ol00?o0000of7:nomQb_/01OmQb_/00ol0003oLmKkog?Fn`08og?Fn`04
o`000?n:hOcoR^7loh[Qo0Ko0000Loooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00@Oooool2o`0004kooooo00?o0000ooooooooool05?ooool2o`25a@?o00000_mJ_o`00ol0003o
HL[kof7:n`07of7:n`03o`000?mce__oLmKk00?oLmKk2Ol0001iooooo`03o`000?oooooooooo00Go
oooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
6OoooolBo`000003oaf[_?oooooooooo083ooooo00?o0000ooooooooool01?ooool1o`00007ooooo
0Oooool004Cooooo0_l0001;ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo0016ooooo`;o0000BOooool00ol0003oooooooooo`2_ooooo`03o`000?oooooo
oooo00Cooooo0Ol00001ooooo`00Aoooool2o`0004Sooooo00?o0000ooooooooool0/?ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01om4A4Co0000o`000?lb<S;ogMgMooooool00000Aoooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00<_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B48ooooo`05ogMgMolb<S;oooooooooool00000A_ooool00ol0003ooooo
ooooo`2booooo`05o`000?ooooooooooooooool000000Oooool002[ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool01?l0003oooooooooooooool2o`0004Cooooo00?o0000oooo
ooooool0/oooool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool2o`0004?ooooo00?o0000ooooooooool0/oooool0
1?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c006ooooo`;o0000@?ooool00ol0003oooooooooo`2eooooo`03o`00
0?oooooooooo007o0000000booooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooo000003gooooo00?o0000ooooooooool0]_ooool1o`00007ooooo
0Ol0000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00_ooooo
0_l0000mooooo`03o`000?oooooooooo0;Oooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00002oooool2o`0003cooooo00?o0000ooooooooool0]_ooool3o`000000E?oo
ool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo0;7ooooo1Ol00003ooooo`00EOoo
ool3o`0003Sooooo00?o0000ooooooooool0[Oooool4o`0000Sooooo001Gooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0ZOooool4o`0000cooooo001Gooooo`;o0000=oooool00ol0
003oooooooooo`2Tooooo`Go00004?ooool005Wooooo0_l0000eooooo`03o`000?oooooooooo0:3o
oooo1?l0000Eooooo`00Foooool2o`0003?ooooo00?o0000ooooooooool0W?ooool4o`0001Wooooo
001Looooo`;o0000<_ooool00ol0003oooooooooo`2Gooooo`Go00007Oooool005kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co00008_ooool005oooooo0ol0000^oooo
o`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00HOooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo08[ooooo1?l0000[ooooo`00HOooool2o`0002gooooo00?o0000ooooooooool0
Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool2o`0002_ooooo
00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3Oooool2o`0002Wooooo00?o0000ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?oo
ooooooooooooool@41003_ooool2o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo
001Cooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07Cooooo1Ol00010ooooo`00Doooool01Ol0003ooooooooooooooooo0000017ooooo
00?o0000ooooool000009?ooool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go
410@oooooooooooooooooa0@400Booooo`;o00009?ooool00ol0003oooooooooo`1[ooooo`Go0000
BOooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`;o00008oooool00ol0003ooooo
ooooo`1Wooooo`Co0000C_ooool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`;o0000
00?oooooo`000?ooool07_ooool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006oooooo0_l0
000Oooooo`03o`000?oooooooooo05kooooo1Ol0001Fooooo`00L?ooool2o`0001kooooo00?o0000
ooooooooool0F_ooool4o`0005_ooooo001booooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0E_ooool4o`0005oooooo001cooooo`;o00006oooool00ol0003oooooooooo`1Aooooo`Go
0000Hoooool007Cooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0001Xooooo`00M_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001/ooooo`00Moooool3
o`0001Kooooo00?o0000ooooooooool0A?ooool5o`00073ooooo001iooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`;o00005?ooool00ol0003o
ooooooooo`0looooo`Go0000NOooool007_ooooo0_l000000ooooooo0000ooooo`0?ooooo`03o`00
0?oooooooooo03Sooooo1?l0001nooooo`00I?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool2o`00013ooooo00?o0000oooooooo
ool0=?ooool4o`0008;ooooo001Tooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool00_ooool3o`0000oooooo00?o0000ooooooooool0;oooool5o`0008Ko
oooo001Tooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000cooooo00?o0000ooooooooool0:oooool4o`0008_ooooo001Tooooo`05o`00
0?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`;o00003?ooool00ol0003o
ooooooooo`0Wooooo`Co0000Soooool006Cooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`02?ooool2o`0000_ooooo00?o0000ooooooooool08_ooool5o`00
09?ooooo001Tooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool07_ooool4o`0009Sooooo001Tooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`;o00002?ooool00ol0
003oooooooooo`0Iooooo`Go0000W?ooool006Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00003Oooool2o`0000Oooooo00?o0000ooooooooool05Oooool4o`000:7ooooo0028ooooo`;o
00001Oooool00ol0003oooooooooo`0Aooooo`Co0000YOooool008[ooooo0_l00003ooooo`03o`00
0?oooooooooo00cooooo1Ol0002Yooooo`00Roooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0002^ooooo`00S?ooool2o`000003ooooool0003ooooo00Gooooo1?l0002booooo`00S_ooool2
o`000003ooooool0003o000000?o0000]_ooool008oooooo0_l0002kooooo`00oooooom=ooooo`00
oooooom=ooooo`00Q?ooool4o`000003oa0@4?oooooooooo0<7ooooo0026ooooo`03o`000?oooooo
oooo0<?ooooo0026ooooo`03o`000?oooooooooo0<?ooooo0026ooooo`03o`000?oooooooooo0<?o
oooo0026ooooo`03o`000?oooooooooo0<?ooooo0026ooooo`03o`000?oooooooooo0<?ooooo0026
ooooo`03o`000?oooooooooo0<?ooooo0024ooooo`03oeEEEOmVIVKo00000<Gooooo0000\
\>"],
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0.000526569, -0.0237064, \
0.00341193, 0.00341193}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47907 .59191 m .47333 .63042 L .54421 .63377 L p .719 .589 .708 r
F P
0 g
s
.54421 .63377 m .54228 .59497 L .47907 .59191 L p .719 .589 .708 r
F P
0 g
s
.54581 .67344 m .54421 .63377 L .47333 .63042 L p .72 .565 .678 r
F P
0 g
s
.54228 .59497 m .54421 .63377 L .61358 .6237 L p .668 .549 .71 r
F P
0 g
s
.54421 .63377 m .54581 .67344 L .62142 .66274 L p .663 .52 .679 r
F P
0 g
s
.62142 .66274 m .61358 .6237 L .54421 .63377 L p .663 .52 .679 r
F P
0 g
s
.48563 .5549 m .47907 .59191 L .54228 .59497 L p .717 .611 .737 r
F P
0 g
s
.54228 .59497 m .54006 .5576 L .48563 .5549 L p .717 .611 .737 r
F P
0 g
s
.54006 .5576 m .54228 .59497 L .60409 .58578 L p .672 .576 .739 r
F P
0 g
s
.61358 .6237 m .60409 .58578 L .54228 .59497 L p .668 .549 .71 r
F P
0 g
s
.43488 .54162 m .42 .5768 L .47907 .59191 L p .76 .652 .742 r
F P
0 g
s
.47907 .59191 m .48563 .5549 L .43488 .54162 L p .76 .652 .742 r
F P
0 g
s
.47333 .63042 m .47907 .59191 L .42 .5768 L p .768 .634 .713 r
F P
0 g
s
.42 .5768 m .40695 .61385 L .47333 .63042 L p .768 .634 .713 r
F P
0 g
s
.46859 .66988 m .47333 .63042 L .40695 .61385 L p .774 .615 .682 r
F P
0 g
s
.47333 .63042 m .46859 .66988 L .54581 .67344 L p .72 .565 .678 r
F P
0 g
s
.54701 .71327 m .54581 .67344 L .46859 .66988 L p .72 .539 .645 r
F P
0 g
s
.54581 .67344 m .54701 .71327 L .62731 .70219 L p .657 .489 .645 r
F P
0 g
s
.62731 .70219 m .62142 .66274 L .54581 .67344 L p .657 .489 .645 r
F P
0 g
s
.49287 .51981 m .48563 .5549 L .54006 .5576 L p .714 .632 .764 r
F P
0 g
s
.54006 .5576 m .53762 .52207 L .49287 .51981 L p .714 .632 .764 r
F P
0 g
s
.53762 .52207 m .54006 .5576 L .59326 .54951 L p .675 .602 .766 r
F P
0 g
s
.60409 .58578 m .59326 .54951 L .54006 .5576 L p .672 .576 .739 r
F P
0 g
s
.45124 .50868 m .43488 .54162 L .48563 .5549 L p .75 .668 .77 r
F P
0 g
s
.48563 .5549 m .49287 .51981 L .45124 .50868 L p .75 .668 .77 r
F P
0 g
s
.40695 .61385 m .39615 .65225 L .46859 .66988 L p .774 .615 .682 r
F P
0 g
s
.46504 .70958 m .46859 .66988 L .39615 .65225 L p .779 .592 .647 r
F P
0 g
s
.46859 .66988 m .46504 .70958 L .54701 .71327 L p .72 .539 .645 r
F P
0 g
s
.59326 .54951 m .60409 .58578 L .65904 .56496 L p .622 .546 .748 r
F P
0 g
s
.60409 .58578 m .61358 .6237 L .67545 .60084 L p .611 .512 .718 r
F P
0 g
s
.67545 .60084 m .65904 .56496 L .60409 .58578 L p .611 .512 .718 r
F P
0 g
s
.61358 .6237 m .62142 .66274 L .68906 .63839 L p .598 .477 .686 r
F P
0 g
s
.68906 .63839 m .67545 .60084 L .61358 .6237 L p .598 .477 .686 r
F P
0 g
s
.59326 .54951 m .58132 .51529 L .53762 .52207 L p .675 .602 .766 r
F P
0 g
s
.58132 .51529 m .59326 .54951 L .64035 .53123 L p .632 .578 .776 r
F P
0 g
s
.65904 .56496 m .64035 .53123 L .59326 .54951 L p .622 .546 .748 r
F P
0 g
s
.50065 .48695 m .49287 .51981 L .53762 .52207 L p .709 .653 .792 r
F P
0 g
s
.53762 .52207 m .535 .48872 L .50065 .48695 L p .709 .653 .792 r
F P
0 g
s
.535 .48872 m .53762 .52207 L .58132 .51529 L p .677 .628 .794 r
F P
0 g
s
.54774 .75238 m .54701 .71327 L .46504 .70958 L p .717 .509 .606 r
F P
0 g
s
.54701 .71327 m .54774 .75238 L .6309 .74121 L p .648 .453 .606 r
F P
0 g
s
.6309 .74121 m .62731 .70219 L .54701 .71327 L p .648 .453 .606 r
F P
0 g
s
.46879 .47826 m .45124 .50868 L .49287 .51981 L p .739 .683 .797 r
F P
0 g
s
.49287 .51981 m .50065 .48695 L .46879 .47826 L p .739 .683 .797 r
F P
0 g
s
.62142 .66274 m .62731 .70219 L .6993 .67695 L p .583 .437 .649 r
F P
0 g
s
.6993 .67695 m .68906 .63839 L .62142 .66274 L p .583 .437 .649 r
F P
0 g
s
.39615 .65225 m .38804 .69133 L .46504 .70958 L p .779 .592 .647 r
F P
0 g
s
.46287 .74867 m .46504 .70958 L .38804 .69133 L p .783 .566 .606 r
F P
0 g
s
.46504 .70958 m .46287 .74867 L .54774 .75238 L p .717 .509 .606 r
F P
0 g
s
.39258 .51873 m .37048 .55068 L .42 .5768 L p .801 .701 .755 r
F P
0 g
s
.42 .5768 m .43488 .54162 L .39258 .51873 L p .801 .701 .755 r
F P
0 g
s
.40695 .61385 m .42 .5768 L .37048 .55068 L p .815 .689 .725 r
F P
0 g
s
.58132 .51529 m .56851 .48342 L .535 .48872 L p .677 .628 .794 r
F P
0 g
s
.56851 .48342 m .58132 .51529 L .61984 .49999 L p .641 .61 .802 r
F P
0 g
s
.64035 .53123 m .61984 .49999 L .58132 .51529 L p .632 .578 .776 r
F P
0 g
s
.37048 .55068 m .35102 .58513 L .40695 .61385 L p .815 .689 .725 r
F P
0 g
s
.39615 .65225 m .40695 .61385 L .35102 .58513 L p .829 .675 .691 r
F P
0 g
s
.41678 .48957 m .39258 .51873 L .43488 .54162 L p .784 .711 .783 r
F P
0 g
s
.43488 .54162 m .45124 .50868 L .41678 .48957 L p .784 .711 .783 r
F P
0 g
s
.50887 .45656 m .50065 .48695 L .535 .48872 L p .702 .674 .82 r
F P
0 g
s
.535 .48872 m .53222 .45779 L .50887 .45656 L p .702 .674 .82 r
F P
0 g
s
.53222 .45779 m .535 .48872 L .56851 .48342 L p .677 .656 .821 r
F P
0 g
s
.62731 .70219 m .6309 .74121 L .70556 .71571 L p .565 .392 .606 r
F P
0 g
s
.70556 .71571 m .6993 .67695 L .62731 .70219 L p .565 .392 .606 r
F P
0 g
s
.44259 .4634 m .41678 .48957 L .45124 .50868 L p .765 .719 .81 r
F P
0 g
s
.45124 .50868 m .46879 .47826 L .44259 .4634 L p .765 .719 .81 r
F P
0 g
s
.35102 .58513 m .33485 .62161 L .39615 .65225 L p .829 .675 .691 r
F P
0 g
s
.38804 .69133 m .39615 .65225 L .33485 .62161 L p .841 .656 .652 r
F P
0 g
s
.48727 .45056 m .46879 .47826 L .50065 .48695 L p .725 .698 .824 r
F P
0 g
s
.50065 .48695 m .50887 .45656 L .48727 .45056 L p .725 .698 .824 r
F P
0 g
s
.54793 .78975 m .54774 .75238 L .46287 .74867 L p .712 .472 .56 r
F P
0 g
s
.54774 .75238 m .54793 .78975 L .63187 .77875 L p .636 .41 .559 r
F P
0 g
s
.63187 .77875 m .6309 .74121 L .54774 .75238 L p .636 .41 .559 r
F P
0 g
s
.56851 .48342 m .55498 .45412 L .53222 .45779 L p .677 .656 .821 r
F P
0 g
s
.55498 .45412 m .56851 .48342 L .5979 .47149 L p .65 .642 .829 r
F P
0 g
s
.61984 .49999 m .5979 .47149 L .56851 .48342 L p .641 .61 .802 r
F P
0 g
s
.64035 .53123 m .65904 .56496 L .70179 .53399 L p .562 .52 .765 r
F P
0 g
s
.65904 .56496 m .67545 .60084 L .72394 .5667 L p .54 .477 .734 r
F P
0 g
s
.72394 .5667 m .70179 .53399 L .65904 .56496 L p .54 .477 .734 r
F P
0 g
s
.61984 .49999 m .64035 .53123 L .67669 .50416 L p .583 .559 .793 r
F P
0 g
s
.70179 .53399 m .67669 .50416 L .64035 .53123 L p .562 .52 .765 r
F P
0 g
s
.38804 .69133 m .38308 .73024 L .46287 .74867 L p .783 .566 .606 r
F P
0 g
s
.46228 .78609 m .46287 .74867 L .38308 .73024 L p .784 .532 .556 r
F P
0 g
s
.46287 .74867 m .46228 .78609 L .54793 .78975 L p .712 .472 .56 r
F P
0 g
s
.67545 .60084 m .68906 .63839 L .74239 .60191 L p .514 .43 .698 r
F P
0 g
s
.74239 .60191 m .72394 .5667 L .67545 .60084 L p .514 .43 .698 r
F P
0 g
s
.5979 .47149 m .61984 .49999 L .6493 .47745 L p .602 .597 .819 r
F P
0 g
s
.67669 .50416 m .6493 .47745 L .61984 .49999 L p .583 .559 .793 r
F P
0 g
s
.46965 .44034 m .44259 .4634 L .46879 .47826 L p .744 .726 .835 r
F P
0 g
s
.46879 .47826 m .48727 .45056 L .46965 .44034 L p .744 .726 .835 r
F P
0 g
s
.33485 .62161 m .32268 .65954 L .38804 .69133 L p .841 .656 .652 r
F P
0 g
s
.38308 .73024 m .38804 .69133 L .32268 .65954 L p .851 .632 .605 r
F P
0 g
s
.51745 .42885 m .50887 .45656 L .53222 .45779 L p .693 .697 .85 r
F P
0 g
s
.53222 .45779 m .52932 .42948 L .51745 .42885 L p .693 .697 .85 r
F P
0 g
s
.52932 .42948 m .53222 .45779 L .55498 .45412 L p .676 .685 .851 r
F P
0 g
s
.6309 .74121 m .63187 .77875 L .70724 .75366 L p .541 .337 .552 r
F P
0 g
s
.70724 .75366 m .70556 .71571 L .6309 .74121 L p .541 .337 .552 r
F P
0 g
s
.68906 .63839 m .6993 .67695 L .75631 .63906 L p .485 .376 .656 r
F P
0 g
s
.75631 .63906 m .74239 .60191 L .68906 .63839 L p .485 .376 .656 r
F P
0 g
s
.5065 .42576 m .48727 .45056 L .50887 .45656 L p .707 .713 .853 r
F P
0 g
s
.50887 .45656 m .51745 .42885 L .5065 .42576 L p .707 .713 .853 r
F P
0 g
s
.5979 .47149 m .57484 .4459 L .55498 .45412 L p .65 .642 .829 r
F P
0 g
s
.57484 .4459 m .5979 .47149 L .62016 .45401 L p .621 .635 .843 r
F P
0 g
s
.6493 .47745 m .62016 .45401 L .5979 .47149 L p .602 .597 .819 r
F P
0 g
s
.3931 .46412 m .36316 .48808 L .39258 .51873 L p .814 .763 .806 r
F P
0 g
s
.39258 .51873 m .41678 .48957 L .3931 .46412 L p .814 .763 .806 r
F P
0 g
s
.37048 .55068 m .39258 .51873 L .36316 .48808 L p .839 .763 .778 r
F P
0 g
s
.55498 .45412 m .54087 .42759 L .52932 .42948 L p .676 .685 .851 r
F P
0 g
s
.54087 .42759 m .55498 .45412 L .57484 .4459 L p .658 .676 .856 r
F P
0 g
s
.42484 .44372 m .3931 .46412 L .41678 .48957 L p .787 .762 .83 r
F P
0 g
s
.41678 .48957 m .44259 .4634 L .42484 .44372 L p .787 .762 .83 r
F P
0 g
s
.36316 .48808 m .33563 .51552 L .37048 .55068 L p .839 .763 .778 r
F P
0 g
s
.35102 .58513 m .37048 .55068 L .33563 .51552 L p .863 .759 .746 r
F P
0 g
s
.49764 .42052 m .46965 .44034 L .48727 .45056 L p .719 .731 .86 r
F P
0 g
s
.48727 .45056 m .5065 .42576 L .49764 .42052 L p .719 .731 .86 r
F P
0 g
s
.54753 .82418 m .54793 .78975 L .46228 .78609 L p .703 .425 .5 r
F P
0 g
s
.54793 .78975 m .54753 .82418 L .6299 .81364 L p .618 .356 .497 r
F P
0 g
s
.6299 .81364 m .63187 .77875 L .54793 .78975 L p .618 .356 .497 r
F P
0 g
s
.45788 .4269 m .42484 .44372 L .44259 .4634 L p .758 .757 .852 r
F P
0 g
s
.44259 .4634 m .46965 .44034 L .45788 .4269 L p .758 .757 .852 r
F P
0 g
s
.33563 .51552 m .31127 .54627 L .35102 .58513 L p .863 .759 .746 r
F P
0 g
s
.33485 .62161 m .35102 .58513 L .31127 .54627 L p .887 .751 .707 r
F P
0 g
s
.57484 .4459 m .55091 .42336 L .54087 .42759 L p .658 .676 .856 r
F P
0 g
s
.55091 .42336 m .57484 .4459 L .58973 .43392 L p .64 .673 .866 r
F P
0 g
s
.62016 .45401 m .58973 .43392 L .57484 .4459 L p .621 .635 .843 r
F P
0 g
s
.38308 .73024 m .38175 .76796 L .46228 .78609 L p .784 .532 .556 r
F P
0 g
s
.46347 .82067 m .46228 .78609 L .38175 .76796 L p .781 .488 .491 r
F P
0 g
s
.46228 .78609 m .46347 .82067 L .54753 .82418 L p .703 .425 .5 r
F P
0 g
s
.32268 .65954 m .31522 .69811 L .38308 .73024 L p .851 .632 .605 r
F P
0 g
s
.38175 .76796 m .38308 .73024 L .31522 .69811 L p .859 .599 .545 r
F P
0 g
s
.6993 .67695 m .70556 .71571 L .76484 .67739 L p .448 .312 .602 r
F P
0 g
s
.76484 .67739 m .75631 .63906 L .6993 .67695 L p .448 .312 .602 r
F P
0 g
s
.62016 .45401 m .6493 .47745 L .66639 .44966 L p .559 .593 .843 r
F P
0 g
s
.6493 .47745 m .67669 .50416 L .69819 .47057 L p .525 .547 .821 r
F P
0 g
s
.69819 .47057 m .66639 .44966 L .6493 .47745 L p .525 .547 .821 r
F P
0 g
s
.49181 .41366 m .45788 .4269 L .46965 .44034 L p .726 .75 .872 r
F P
0 g
s
.46965 .44034 m .49764 .42052 L .49181 .41366 L p .726 .75 .872 r
F P
0 g
s
.67669 .50416 m .70179 .53399 L .72753 .49534 L p .487 .497 .794 r
F P
0 g
s
.72753 .49534 m .69819 .47057 L .67669 .50416 L p .487 .497 .794 r
F P
0 g
s
.58973 .43392 m .62016 .45401 L .63281 .4326 L p .592 .635 .863 r
F P
0 g
s
.66639 .44966 m .63281 .4326 L .62016 .45401 L p .559 .593 .843 r
F P
0 g
s
.52932 .42948 m .52632 .40403 L .51745 .42885 L closepath p .678 .721 .881 r
F P
0 g
s
.54087 .42759 m .52632 .40403 L .52932 .42948 L closepath p .672 .716 .882 r
F P
0 g
s
.31127 .54627 m .29093 .58002 L .33485 .62161 L p .887 .751 .707 r
F P
0 g
s
.32268 .65954 m .33485 .62161 L .29093 .58002 L p .908 .738 .659 r
F P
0 g
s
.51745 .42885 m .52632 .40403 L .5065 .42576 L closepath p .684 .727 .883 r
F P
0 g
s
.55091 .42336 m .52632 .40403 L .54087 .42759 L closepath p .666 .714 .884 r
F P
0 g
s
.63187 .77875 m .6299 .81364 L .70381 .78961 L p .509 .266 .481 r
F P
0 g
s
.70381 .78961 m .70724 .75366 L .63187 .77875 L p .509 .266 .481 r
F P
0 g
s
.70179 .53399 m .72394 .5667 L .75357 .52389 L p .443 .44 .76 r
F P
0 g
s
.75357 .52389 m .72753 .49534 L .70179 .53399 L p .443 .44 .76 r
F P
0 g
s
.5065 .42576 m .52632 .40403 L .49764 .42052 L closepath p .687 .733 .886 r
F P
0 g
s
.58973 .43392 m .55835 .41723 L .55091 .42336 L p .64 .673 .866 r
F P
0 g
s
.55835 .41723 m .58973 .43392 L .598 .41935 L p .623 .675 .879 r
F P
0 g
s
.63281 .4326 m .598 .41935 L .58973 .43392 L p .592 .635 .863 r
F P
0 g
s
.55835 .41723 m .52632 .40403 L .55091 .42336 L closepath p .659 .713 .888 r
F P
0 g
s
.49764 .42052 m .52632 .40403 L .49181 .41366 L closepath p .689 .74 .89 r
F P
0 g
s
.45334 .41158 m .41767 .42113 L .42484 .44372 L p .764 .79 .875 r
F P
0 g
s
.42484 .44372 m .45788 .4269 L .45334 .41158 L p .764 .79 .875 r
F P
0 g
s
.3931 .46412 m .42484 .44372 L .41767 .42113 L p .8 .809 .859 r
F P
0 g
s
.72394 .5667 m .74239 .60191 L .77538 .55597 L p .392 .372 .717 r
F P
0 g
s
.77538 .55597 m .75357 .52389 L .72394 .5667 L p .392 .372 .717 r
F P
0 g
s
.70556 .71571 m .70724 .75366 L .76714 .71592 L p .402 .231 .533 r
F P
0 g
s
.76714 .71592 m .76484 .67739 L .70556 .71571 L p .402 .231 .533 r
F P
0 g
s
.41767 .42113 m .38313 .43468 L .3931 .46412 L p .8 .809 .859 r
F P
0 g
s
.36316 .48808 m .3931 .46412 L .38313 .43468 L p .835 .825 .839 r
F P
0 g
s
.48967 .40592 m .45334 .41158 L .45788 .4269 L p .727 .77 .886 r
F P
0 g
s
.45788 .4269 m .49181 .41366 L .48967 .40592 L p .727 .77 .886 r
F P
0 g
s
.56239 .40983 m .52632 .40403 L .55835 .41723 L closepath p .653 .714 .892 r
F P
0 g
s
.598 .41935 m .56239 .40983 L .55835 .41723 L p .623 .675 .879 r
F P
0 g
s
.29093 .58002 m .27555 .61626 L .32268 .65954 L p .908 .738 .659 r
F P
0 g
s
.31522 .69811 m .32268 .65954 L .27555 .61626 L p .928 .717 .597 r
F P
0 g
s
.54648 .85432 m .54753 .82418 L .46347 .82067 L p .686 .36 .418 r
F P
0 g
s
.54753 .82418 m .54648 .85432 L .62473 .84452 L p .59 .281 .413 r
F P
0 g
s
.62473 .84452 m .6299 .81364 L .54753 .82418 L p .59 .281 .413 r
F P
0 g
s
.38313 .43468 m .35029 .45237 L .36316 .48808 L p .835 .825 .839 r
F P
0 g
s
.33563 .51552 m .36316 .48808 L .35029 .45237 L p .87 .839 .812 r
F P
0 g
s
.31522 .69811 m .31321 .73633 L .38175 .76796 L p .859 .599 .545 r
F P
0 g
s
.38446 .8033 m .38175 .76796 L .31321 .73633 L p .861 .552 .464 r
F P
0 g
s
.38175 .76796 m .38446 .8033 L .46347 .82067 L p .781 .488 .491 r
F P
0 g
s
.49181 .41366 m .52632 .40403 L .48967 .40592 L closepath p .689 .746 .895 r
F P
0 g
s
.56239 .40983 m .598 .41935 L .5986 .40368 L p .608 .683 .895 r
F P
0 g
s
.598 .41935 m .63281 .4326 L .63416 .4094 L p .563 .643 .888 r
F P
0 g
s
.63416 .4094 m .5986 .40368 L .598 .41935 L p .563 .643 .888 r
F P
0 g
s
.56254 .40194 m .52632 .40403 L .56239 .40983 L closepath p .649 .717 .898 r
F P
0 g
s
.5986 .40368 m .56254 .40194 L .56239 .40983 L p .608 .683 .895 r
F P
0 g
s
.46659 .85106 m .46347 .82067 L .38446 .8033 L p .769 .424 .401 r
F P
0 g
s
.46347 .82067 m .46659 .85106 L .54648 .85432 L p .686 .36 .418 r
F P
0 g
s
.63281 .4326 m .66639 .44966 L .66874 .41931 L p .512 .598 .877 r
F P
0 g
s
.66874 .41931 m .63416 .4094 L .63281 .4326 L p .512 .598 .877 r
F P
0 g
s
.55136 .3881 m .52632 .40403 L .55874 .39442 L closepath p .647 .729 .909 r
F P
0 g
s
.5412 .38369 m .52632 .40403 L .55136 .3881 L closepath p .649 .736 .913 r
F P
0 g
s
.52937 .38171 m .52632 .40403 L .5412 .38369 L closepath p .654 .743 .916 r
F P
0 g
s
.51719 .38238 m .52632 .40403 L .52937 .38171 L closepath p .66 .749 .916 r
F P
0 g
s
.50604 .38563 m .52632 .40403 L .51719 .38238 L closepath p .668 .754 .915 r
F P
0 g
s
.49716 .39108 m .52632 .40403 L .50604 .38563 L closepath p .675 .755 .911 r
F P
0 g
s
.49151 .3981 m .52632 .40403 L .49716 .39108 L closepath p .682 .754 .906 r
F P
0 g
s
.48967 .40592 m .52632 .40403 L .49151 .3981 L closepath p .686 .751 .901 r
F P
0 g
s
.55874 .39442 m .52632 .40403 L .56254 .40194 L closepath p .647 .723 .904 r
F P
0 g
s
.74239 .60191 m .75631 .63906 L .7919 .59118 L p .33 .289 .661 r
F P
0 g
s
.7919 .59118 m .77538 .55597 L .74239 .60191 L p .33 .289 .661 r
F P
0 g
s
.35029 .45237 m .31988 .4743 L .33563 .51552 L p .87 .839 .812 r
F P
0 g
s
.31127 .54627 m .33563 .51552 L .31988 .4743 L p .906 .849 .776 r
F P
0 g
s
.45334 .41158 m .48967 .40592 L .49151 .3981 L p .722 .787 .903 r
F P
0 g
s
.66639 .44966 m .69819 .47057 L .70174 .43362 L p .454 .544 .859 r
F P
0 g
s
.70174 .43362 m .66874 .41931 L .66639 .44966 L p .454 .544 .859 r
F P
0 g
s
.49151 .3981 m .4567 .396 L .45334 .41158 L p .722 .787 .903 r
F P
0 g
s
.41767 .42113 m .45334 .41158 L .4567 .396 L p .758 .822 .902 r
F P
0 g
s
.56254 .40194 m .5986 .40368 L .59129 .38862 L p .597 .696 .912 r
F P
0 g
s
.59129 .38862 m .55874 .39442 L .56254 .40194 L p .597 .696 .912 r
F P
0 g
s
.6299 .81364 m .62473 .84452 L .69481 .8222 L p .461 .168 .38 r
F P
0 g
s
.69481 .8222 m .70381 .78961 L .6299 .81364 L p .461 .168 .38 r
F P
0 g
s
.4567 .396 m .49151 .3981 L .49716 .39108 L p .708 .798 .921 r
F P
0 g
s
.27555 .61626 m .26612 .65429 L .31522 .69811 L p .928 .717 .597 r
F P
0 g
s
.31321 .73633 m .31522 .69811 L .26612 .65429 L p .943 .682 .512 r
F P
0 g
s
.4567 .396 m .42224 .39796 L .41767 .42113 L p .758 .822 .902 r
F P
0 g
s
.38313 .43468 m .41767 .42113 L .42224 .39796 L p .796 .857 .896 r
F P
0 g
s
.31988 .4743 m .2928 .50047 L .31127 .54627 L p .906 .849 .776 r
F P
0 g
s
.29093 .58002 m .31127 .54627 L .2928 .50047 L p .941 .854 .727 r
F P
0 g
s
.70724 .75366 m .70381 .78961 L .76246 .75349 L p .338 .125 .436 r
F P
0 g
s
.76246 .75349 m .76714 .71592 L .70724 .75366 L p .338 .125 .436 r
F P
0 g
s
.69819 .47057 m .72753 .49534 L .73242 .45254 L p .383 .478 .833 r
F P
0 g
s
.73242 .45254 m .70174 .43362 L .69819 .47057 L p .383 .478 .833 r
F P
0 g
s
.55874 .39442 m .59129 .38862 L .57668 .37587 L p .593 .716 .929 r
F P
0 g
s
.57668 .37587 m .55136 .3881 L .55874 .39442 L p .593 .716 .929 r
F P
0 g
s
.5986 .40368 m .63416 .4094 L .62363 .38691 L p .537 .662 .917 r
F P
0 g
s
.62363 .38691 m .59129 .38862 L .5986 .40368 L p .537 .662 .917 r
F P
0 g
s
.75631 .63906 m .76484 .67739 L .80206 .62886 L p .25 .184 .584 r
F P
0 g
s
.80206 .62886 m .7919 .59118 L .75631 .63906 L p .25 .184 .584 r
F P
0 g
s
.46778 .38189 m .49716 .39108 L .50604 .38563 L p .687 .803 .936 r
F P
0 g
s
.49716 .39108 m .46778 .38189 L .4567 .396 L p .708 .798 .921 r
F P
0 g
s
.55136 .3881 m .57668 .37587 L .55632 .36693 L p .597 .739 .943 r
F P
0 g
s
.55632 .36693 m .5412 .38369 L .55136 .3881 L p .597 .739 .943 r
F P
0 g
s
.42224 .39796 m .3886 .40425 L .38313 .43468 L p .796 .857 .896 r
F P
0 g
s
.35029 .45237 m .38313 .43468 L .3886 .40425 L p .835 .892 .881 r
F P
0 g
s
.31321 .73633 m .3173 .77302 L .38446 .8033 L p .861 .552 .464 r
F P
0 g
s
.39159 .83491 m .38446 .8033 L .3173 .77302 L p .851 .48 .347 r
F P
0 g
s
.38446 .8033 m .39159 .83491 L .46659 .85106 L p .769 .424 .401 r
F P
0 g
s
.42224 .39796 m .4567 .396 L .46778 .38189 L p .736 .846 .932 r
F P
0 g
s
.48549 .37086 m .50604 .38563 L .51719 .38238 L p .661 .797 .948 r
F P
0 g
s
.50604 .38563 m .48549 .37086 L .46778 .38189 L p .687 .803 .936 r
F P
0 g
s
.72753 .49534 m .75357 .52389 L .75983 .47618 L p .296 .394 .793 r
F P
0 g
s
.75983 .47618 m .73242 .45254 L .72753 .49534 L p .296 .394 .793 r
F P
0 g
s
.63416 .4094 m .66874 .41931 L .65535 .38965 L p .463 .617 .916 r
F P
0 g
s
.65535 .38965 m .62363 .38691 L .63416 .4094 L p .463 .617 .916 r
F P
0 g
s
.5412 .38369 m .55632 .36693 L .53247 .36289 L p .611 .762 .951 r
F P
0 g
s
.53247 .36289 m .52937 .38171 L .5412 .38369 L p .611 .762 .951 r
F P
0 g
s
.2928 .50047 m .27006 .53075 L .29093 .58002 L p .941 .854 .727 r
F P
0 g
s
.27555 .61626 m .29093 .58002 L .27006 .53075 L p .973 .848 .657 r
F P
0 g
s
.50791 .36426 m .51719 .38238 L .52937 .38171 L p .634 .783 .953 r
F P
0 g
s
.51719 .38238 m .50791 .36426 L .48549 .37086 L p .661 .797 .948 r
F P
0 g
s
.52937 .38171 m .53247 .36289 L .50791 .36426 L p .634 .783 .953 r
F P
0 g
s
.54474 .87875 m .54648 .85432 L .46659 .85106 L p .65 .262 .295 r
F P
0 g
s
.54648 .85432 m .54474 .87875 L .61617 .86996 L p .541 .169 .285 r
F P
0 g
s
.61617 .86996 m .62473 .84452 L .54648 .85432 L p .541 .169 .285 r
F P
0 g
s
.59129 .38862 m .62363 .38691 L .60202 .36773 L p .521 .692 .946 r
F P
0 g
s
.60202 .36773 m .57668 .37587 L .59129 .38862 L p .521 .692 .946 r
F P
0 g
s
.47177 .87582 m .46659 .85106 L .39159 .83491 L p .738 .324 .263 r
F P
0 g
s
.46659 .85106 m .47177 .87582 L .54474 .87875 L p .65 .262 .295 r
F P
0 g
s
.3886 .40425 m .35636 .41518 L .35029 .45237 L p .835 .892 .881 r
F P
0 g
s
.31988 .4743 m .35029 .45237 L .35636 .41518 L p .875 .926 .855 r
F P
0 g
s
.26612 .65429 m .26356 .69317 L .31321 .73633 L p .943 .682 .512 r
F P
0 g
s
.3173 .77302 m .31321 .73633 L .26356 .69317 L p .945 .621 .389 r
F P
0 g
s
.46778 .38189 m .43847 .3768 L .42224 .39796 L p .736 .846 .932 r
F P
0 g
s
.3886 .40425 m .42224 .39796 L .43847 .3768 L p .764 .897 .936 r
F P
0 g
s
.43847 .3768 m .46778 .38189 L .48549 .37086 L p .695 .855 .959 r
F P
0 g
s
.76484 .67739 m .76714 .71592 L .8048 .66811 L p .144 .044 .473 r
F P
0 g
s
.8048 .66811 m .80206 .62886 L .76484 .67739 L p .144 .044 .473 r
F P
0 g
s
.66874 .41931 m .70174 .43362 L .68585 .39724 L p .366 .553 .904 r
F P
0 g
s
.68585 .39724 m .65535 .38965 L .66874 .41931 L p .366 .553 .904 r
F P
0 g
s
.75357 .52389 m .77538 .55597 L .78292 .50453 L p .184 .283 .732 r
F P
0 g
s
.78292 .50453 m .75983 .47618 L .75357 .52389 L p .184 .283 .732 r
F P
0 g
s
.70381 .78961 m .69481 .8222 L .75021 .78872 L p .243 0 .292 r
F P
0 g
s
.75021 .78872 m .76246 .75349 L .70381 .78961 L p .243 0 .292 r
F P
0 g
s
.62473 .84452 m .61617 .86996 L .67995 .84997 L p .381 .022 .225 r
F P
0 g
s
.67995 .84997 m .69481 .8222 L .62473 .84452 L p .381 .022 .225 r
F P
0 g
s
.57668 .37587 m .60202 .36773 L .57152 .3542 L p .52 .731 .97 r
F P
0 g
s
.57152 .3542 m .55632 .36693 L .57668 .37587 L p .52 .731 .97 r
F P
0 g
s
.27006 .53075 m .25279 .56482 L .27555 .61626 L p .973 .848 .657 r
F P
0 g
s
.26612 .65429 m .27555 .61626 L .25279 .56482 L p .996 .824 .554 r
F P
0 g
s
.35636 .41518 m .32628 .43106 L .31988 .4743 L p .875 .926 .855 r
F P
0 g
s
.2928 .50047 m .31988 .4743 L .32628 .43106 L p .913 .954 .806 r
F P
0 g
s
.62363 .38691 m .65535 .38965 L .62702 .36417 L p .418 .651 .955 r
F P
0 g
s
.62702 .36417 m .60202 .36773 L .62363 .38691 L p .418 .651 .955 r
F P
0 g
s
.46487 .36016 m .48549 .37086 L .50791 .36426 L p .641 .845 .979 r
F P
0 g
s
.48549 .37086 m .46487 .36016 L .43847 .3768 L p .695 .855 .959 r
F P
0 g
s
.55632 .36693 m .57152 .3542 L .5356 .34807 L p .541 .775 .985 r
F P
0 g
s
.5356 .34807 m .53247 .36289 L .55632 .36693 L p .541 .775 .985 r
F P
0 g
s
.70174 .43362 m .73242 .45254 L .7144 .4101 L p .234 .461 .873 r
F P
0 g
s
.7144 .4101 m .68585 .39724 L .70174 .43362 L p .234 .461 .873 r
F P
0 g
s
.43847 .3768 m .40964 .37623 L .3886 .40425 L p .764 .897 .936 r
F P
0 g
s
.35636 .41518 m .3886 .40425 L .40964 .37623 L p .789 .948 .925 r
F P
0 g
s
.3173 .77302 m .32801 .80681 L .39159 .83491 L p .851 .48 .347 r
F P
0 g
s
.40338 .86135 m .39159 .83491 L .32801 .80681 L p .809 .357 .164 r
F P
0 g
s
.39159 .83491 m .40338 .86135 L .47177 .87582 L p .738 .324 .263 r
F P
0 g
s
.77538 .55597 m .7919 .59118 L .80049 .53735 L p .036 .133 .636 r
F P
0 g
s
.80049 .53735 m .78292 .50453 L .77538 .55597 L p .036 .133 .636 r
F P
0 g
s
.49857 .35015 m .50791 .36426 L .53247 .36289 L p .584 .816 .987 r
F P
0 g
s
.50791 .36426 m .49857 .35015 L .46487 .36016 L p .641 .845 .979 r
F P
0 g
s
.53247 .36289 m .5356 .34807 L .49857 .35015 L p .584 .816 .987 r
F P
0 g
s
.40964 .37623 m .43847 .3768 L .46487 .36016 L p .694 .911 .97 r
F P
0 g
s
.76714 .71592 m .76246 .75349 L .79923 .70778 L p 0 0 .306 r
F P
0 g
s
.79923 .70778 m .8048 .66811 L .76714 .71592 L p 0 0 .306 r
F P
0 g
s
.26356 .69317 m .26874 .73174 L .3173 .77302 L p .945 .621 .389 r
F P
0 g
s
.32801 .80681 m .3173 .77302 L .26874 .73174 L p .913 .513 .203 r
F P
0 g
s
.32628 .43106 m .29931 .45213 L .2928 .50047 L p .913 .954 .806 r
F P
0 g
s
.27006 .53075 m .2928 .50047 L .29931 .45213 L p .94 .964 .721 r
F P
0 g
s
.25279 .56482 m .24216 .6021 L .26612 .65429 L p .996 .824 .554 r
F P
0 g
s
.26356 .69317 m .26612 .65429 L .24216 .6021 L p .993 .762 .396 r
F P
0 g
s
.54229 .89599 m .54474 .87875 L .47177 .87582 L p .571 .097 .09 r
F P
0 g
s
.54474 .87875 m .54229 .89599 L .60416 .88847 L p .443 0 .071 r
F P
0 g
s
.60416 .88847 m .61617 .86996 L .54474 .87875 L p .443 0 .071 r
F P
0 g
s
.60202 .36773 m .62702 .36417 L .58659 .34609 L p .395 .7 .983 r
F P
0 g
s
.58659 .34609 m .57152 .3542 L .60202 .36773 L p .395 .7 .983 r
F P
0 g
s
.65535 .38965 m .68585 .39724 L .65123 .36576 L p .266 .576 .941 r
F P
0 g
s
.65123 .36576 m .62702 .36417 L .65535 .38965 L p .266 .576 .941 r
F P
0 g
s
.47903 .89348 m .47177 .87582 L .40338 .86135 L p .655 .15 .032 r
F P
0 g
s
.47177 .87582 m .47903 .89348 L .54229 .89599 L p .571 .097 .09 r
F P
0 g
s
.73242 .45254 m .75983 .47618 L .74009 .42857 L p .052 .322 .805 r
F P
0 g
s
.74009 .42857 m .7144 .4101 L .73242 .45254 L p .052 .322 .805 r
F P
0 g
s
.69481 .8222 m .67995 .84997 L .73003 .82011 L p .094 0 .067 r
F P
0 g
s
.73003 .82011 m .75021 .78872 L .69481 .8222 L p .094 0 .067 r
F P
0 g
s
.40964 .37623 m .38182 .38069 L .35636 .41518 L p .789 .948 .925 r
F P
0 g
s
.32628 .43106 m .35636 .41518 L .38182 .38069 L p .8 .99 .882 r
F P
0 g
s
.7919 .59118 m .80206 .62886 L .81133 .57418 L p 0 0 .483 r
F P
0 g
s
.81133 .57418 m .80049 .53735 L .7919 .59118 L p 0 0 .483 r
F P
0 g
s
.44447 .35407 m .46487 .36016 L .49857 .35015 L p .59 .888 .991 r
F P
0 g
s
.46487 .36016 m .44447 .35407 L .40964 .37623 L p .694 .911 .97 r
F P
0 g
s
.61617 .86996 m .60416 .88847 L .65914 .87142 L p .235 0 0 r
F P
0 g
s
.65914 .87142 m .67995 .84997 L .61617 .86996 L p .235 0 0 r
F P
0 g
s
.57152 .3542 m .58659 .34609 L .53871 .33788 L p .413 .763 .995 r
F P
0 g
s
.53871 .33788 m .5356 .34807 L .57152 .3542 L p .413 .763 .995 r
F P
0 g
s
.38182 .38069 m .40964 .37623 L .44447 .35407 L p .664 .955 .947 r
F P
0 g
s
.29931 .45213 m .27653 .47848 L .27006 .53075 L p .94 .964 .721 r
F P
0 g
s
.25279 .56482 m .27006 .53075 L .27653 .47848 L p .932 .933 .573 r
F P
0 g
s
.48929 .34066 m .49857 .35015 L .5356 .34807 L p .484 .831 .997 r
F P
0 g
s
.49857 .35015 m .48929 .34066 L .44447 .35407 L p .59 .888 .991 r
F P
0 g
s
.76246 .75349 m .75021 .78872 L .78465 .74648 L p 0 0 .055 r
F P
0 g
s
.78465 .74648 m .79923 .70778 L .76246 .75349 L p 0 0 .055 r
F P
0 g
s
.5356 .34807 m .53871 .33788 L .48929 .34066 L p .484 .831 .997 r
F P
0 g
s
.24216 .6021 m .23928 .64174 L .26356 .69317 L p .993 .762 .396 r
F P
0 g
s
.26874 .73174 m .26356 .69317 L .23928 .64174 L p .928 .631 .159 r
F P
0 g
s
.75983 .47618 m .78292 .50453 L .76185 .45291 L p 0 .117 .669 r
F P
0 g
s
.76185 .45291 m .74009 .42857 L .75983 .47618 L p 0 .117 .669 r
F P
0 g
s
.32801 .80681 m .34568 .83623 L .40338 .86135 L p .809 .357 .164 r
F P
0 g
s
.41991 .88111 m .40338 .86135 L .34568 .83623 L p .683 .138 0 r
F P
0 g
s
.40338 .86135 m .41991 .88111 L .47903 .89348 L p .655 .15 .032 r
F P
0 g
s
.68585 .39724 m .7144 .4101 L .67404 .37312 L p .035 .438 .871 r
F P
0 g
s
.67404 .37312 m .65123 .36576 L .68585 .39724 L p .035 .438 .871 r
F P
0 g
s
.26874 .73174 m .2823 .7686 L .32801 .80681 L p .913 .513 .203 r
F P
0 g
s
.34568 .83623 m .32801 .80681 L .2823 .7686 L p .802 .319 0 r
F P
0 g
s
.38182 .38069 m .35568 .39068 L .32628 .43106 L p .8 .99 .882 r
F P
0 g
s
.29931 .45213 m .32628 .43106 L .35568 .39068 L p .772 .991 .772 r
F P
0 g
s
.62702 .36417 m .65123 .36576 L .60125 .34331 L p .185 .613 .944 r
F P
0 g
s
.60125 .34331 m .58659 .34609 L .62702 .36417 L p .185 .613 .944 r
F P
0 g
s
.80206 .62886 m .8048 .66811 L .81427 .61421 L p 0 0 .246 r
F P
0 g
s
.81427 .61421 m .81133 .57418 L .80206 .62886 L p 0 0 .246 r
F P
0 g
s
.27653 .47848 m .25915 .51002 L .25279 .56482 L p .932 .933 .573 r
F P
0 g
s
.24216 .6021 m .25279 .56482 L .25915 .51002 L p .85 .817 .334 r
F P
0 g
s
.42466 .35322 m .44447 .35407 L .48929 .34066 L p .469 .883 .932 r
F P
0 g
s
.44447 .35407 m .42466 .35322 L .38182 .38069 L p .664 .955 .947 r
F P
0 g
s
.67995 .84997 m .65914 .87142 L .70194 .84607 L p 0 0 0 r
F P
0 g
s
.70194 .84607 m .73003 .82011 L .67995 .84997 L p 0 0 0 r
F P
0 g
s
.35568 .39068 m .38182 .38069 L .42466 .35322 L p .566 .937 .833 r
F P
0 g
s
.53914 .90462 m .54229 .89599 L .47903 .89348 L p .376 0 0 r
F P
0 g
s
.54229 .89599 m .53914 .90462 L .58876 .89862 L p .228 0 0 r
F P
0 g
s
.58876 .89862 m .60416 .88847 L .54229 .89599 L p .228 0 0 r
F P
0 g
s
.48836 .90262 m .47903 .89348 L .41991 .88111 L p .436 0 0 r
F P
0 g
s
.47903 .89348 m .48836 .90262 L .53914 .90462 L p .376 0 0 r
F P
0 g
s
.78292 .50453 m .80049 .53735 L .7785 .48313 L p 0 0 .429 r
F P
0 g
s
.7785 .48313 m .76185 .45291 L .78292 .50453 L p 0 0 .429 r
F P
0 g
s
.58659 .34609 m .60125 .34331 L .54175 .33306 L p .179 .673 .918 r
F P
0 g
s
.54175 .33306 m .53871 .33788 L .58659 .34609 L p .179 .673 .918 r
F P
0 g
s
.23928 .64174 m .24512 .68259 L .26874 .73174 L p .928 .631 .159 r
F P
0 g
s
.2823 .7686 m .26874 .73174 L .24512 .68259 L p .751 .397 0 r
F P
0 g
s
.7144 .4101 m .74009 .42857 L .69469 .38686 L p 0 .203 .686 r
F P
0 g
s
.69469 .38686 m .67404 .37312 L .7144 .4101 L p 0 .203 .686 r
F P
0 g
s
.35568 .39068 m .33209 .4067 L .29931 .45213 L p .772 .991 .772 r
F P
0 g
s
.27653 .47848 m .29931 .45213 L .33209 .4067 L p .657 .892 .547 r
F P
0 g
s
.75021 .78872 m .73003 .82011 L .76076 .78259 L p 0 0 0 r
F P
0 g
s
.76076 .78259 m .78465 .74648 L .75021 .78872 L p 0 0 0 r
F P
0 g
s
.48025 .33654 m .48929 .34066 L .53871 .33788 L p .281 .769 .909 r
F P
0 g
s
.48929 .34066 m .48025 .33654 L .42466 .35322 L p .469 .883 .932 r
F P
0 g
s
.60416 .88847 m .58876 .89862 L .63262 .88508 L p 0 0 0 r
F P
0 g
s
.63262 .88508 m .65914 .87142 L .60416 .88847 L p 0 0 0 r
F P
0 g
s
.8048 .66811 m .79923 .70778 L .80831 .65632 L p 0 0 0 r
F P
0 g
s
.80831 .65632 m .81427 .61421 L .8048 .66811 L p 0 0 0 r
F P
0 g
s
.53871 .33788 m .54175 .33306 L .48025 .33654 L p .281 .769 .909 r
F P
0 g
s
.65123 .36576 m .67404 .37312 L .61513 .34662 L p 0 .411 .771 r
F P
0 g
s
.61513 .34662 m .60125 .34331 L .65123 .36576 L p 0 .411 .771 r
F P
0 g
s
.2823 .7686 m .30456 .80221 L .34568 .83623 L p .802 .319 0 r
F P
0 g
s
.37035 .85974 m .34568 .83623 L .30456 .80221 L p .54 .011 0 r
F P
0 g
s
.34568 .83623 m .37035 .85974 L .41991 .88111 L p .683 .138 0 r
F P
0 g
s
.25915 .51002 m .24842 .54636 L .24216 .6021 L p .85 .817 .334 r
F P
0 g
s
.23928 .64174 m .24216 .6021 L .24842 .54636 L p 0 0 0 r
F P
0 g
s
.44104 .89277 m .41991 .88111 L .37035 .85974 L p .379 0 0 r
F P
0 g
s
.41991 .88111 m .44104 .89277 L .48836 .90262 L p .436 0 0 r
F P
0 g
s
.80049 .53735 m .81133 .57418 L .78879 .51896 L p .778 .454 0 r
F P
0 g
s
.78879 .51896 m .7785 .48313 L .80049 .53735 L p .778 .454 0 r
F P
0 g
s
.42466 .35322 m .40596 .35834 L .35568 .39068 L p .566 .937 .833 r
F P
0 g
s
.33209 .4067 m .35568 .39068 L .40596 .35834 L p 0 0 0 r
F P
0 g
s
.40596 .35834 m .42466 .35322 L .48025 .33654 L p .226 .737 .702 r
F P
0 g
s
.33209 .4067 m .31206 .42911 L .27653 .47848 L p .657 .892 .547 r
F P
0 g
s
.25915 .51002 m .27653 .47848 L .31206 .42911 L p 0 0 0 r
F P
0 g
s
.74009 .42857 m .76185 .45291 L .71226 .40746 L p .619 .105 0 r
F P
0 g
s
.71226 .40746 m .69469 .38686 L .74009 .42857 L p .619 .105 0 r
F P
0 g
s
.24512 .68259 m .26037 .72325 L .2823 .7686 L p .751 .397 0 r
F P
0 g
s
.30456 .80221 m .2823 .7686 L .26037 .72325 L p 0 0 .493 r
F P
0 g
s
.65914 .87142 m .63262 .88508 L .66635 .86507 L p .405 .832 .673 r
F P
0 g
s
.66635 .86507 m .70194 .84607 L .65914 .87142 L p .405 .832 .673 r
F P
0 g
s
.79923 .70778 m .78465 .74648 L .79278 .69907 L p .842 .85 .39 r
F P
0 g
s
.79278 .69907 m .80831 .65632 L .79923 .70778 L p .842 .85 .39 r
F P
0 g
s
.60125 .34331 m .61513 .34662 L .54462 .33449 L p .171 0 0 r
F P
0 g
s
.54462 .33449 m .54175 .33306 L .60125 .34331 L p .171 0 0 r
F P
0 g
s
.73003 .82011 m .70194 .84607 L .7277 .81443 L p .645 .917 .623 r
F P
0 g
s
.7277 .81443 m .76076 .78259 L .73003 .82011 L p .645 .917 .623 r
F P
0 g
s
.24842 .54636 m .24551 .58677 L .23928 .64174 L p 0 0 0 r
F P
0 g
s
.24512 .68259 m .23928 .64174 L .24551 .58677 L p 0 0 .299 r
F P
0 g
s
.48025 .33654 m .47168 .33861 L .40596 .35834 L p .226 .737 .702 r
F P
0 g
s
.47168 .33861 m .48025 .33654 L .54175 .33306 L p .044 0 0 r
F P
0 g
s
.53536 .90341 m .53914 .90462 L .48836 .90262 L p .019 .591 .751 r
F P
0 g
s
.53914 .90462 m .53536 .90341 L .57028 .89918 L p .15 .693 .769 r
F P
0 g
s
.57028 .89918 m .58876 .89862 L .53914 .90462 L p .15 .693 .769 r
F P
0 g
s
.67404 .37312 m .69469 .38686 L .62774 .35681 L p .491 0 0 r
F P
0 g
s
.62774 .35681 m .61513 .34662 L .67404 .37312 L p .491 0 0 r
F P
0 g
s
.49957 .902 m .48836 .90262 L .44104 .89277 L p 0 .549 .802 r
F P
0 g
s
.48836 .90262 m .49957 .902 L .53536 .90341 L p .019 .591 .751 r
F P
0 g
s
.54175 .33306 m .54462 .33449 L .47168 .33861 L p .044 0 0 r
F P
0 g
s
.30456 .80221 m .33547 .83095 L .37035 .85974 L p .54 .011 0 r
F P
0 g
s
.37035 .85974 m .40171 .87584 L .44104 .89277 L p .379 0 0 r
F P
0 g
s
.40171 .87584 m .37035 .85974 L .33547 .83095 L p 0 .329 .777 r
F P
0 g
s
.81133 .57418 m .81427 .61421 L .79159 .55974 L p .943 .674 .209 r
F P
0 g
s
.79159 .55974 m .78879 .51896 L .81133 .57418 L p .943 .674 .209 r
F P
0 g
s
.58876 .89862 m .57028 .89918 L .60094 .88968 L p .359 .832 .844 r
F P
0 g
s
.60094 .88968 m .63262 .88508 L .58876 .89862 L p .359 .832 .844 r
F P
0 g
s
.40596 .35834 m .38899 .37012 L .33209 .4067 L p 0 0 0 r
F P
0 g
s
.31206 .42911 m .33209 .4067 L .38899 .37012 L p 0 0 0 r
F P
0 g
s
.31206 .42911 m .29671 .45805 L .25915 .51002 L p 0 0 0 r
F P
0 g
s
.24842 .54636 m .25915 .51002 L .29671 .45805 L p 0 0 .107 r
F P
0 g
s
.76185 .45291 m .7785 .48313 L .72575 .4352 L p .836 .373 0 r
F P
0 g
s
.72575 .4352 m .71226 .40746 L .76185 .45291 L p .836 .373 0 r
F P
0 g
s
.38899 .37012 m .40596 .35834 L .47168 .33861 L p .077 0 0 r
F P
0 g
s
.46635 .89507 m .44104 .89277 L .40171 .87584 L p .054 .552 .885 r
F P
0 g
s
.44104 .89277 m .46635 .89507 L .49957 .902 L p 0 .549 .802 r
F P
0 g
s
.26037 .72325 m .28531 .76205 L .30456 .80221 L p 0 0 .493 r
F P
0 g
s
.33547 .83095 m .30456 .80221 L .28531 .76205 L p 0 .211 .736 r
F P
0 g
s
.78465 .74648 m .76076 .78259 L .76743 .74073 L p .912 .96 .634 r
F P
0 g
s
.76743 .74073 m .79278 .69907 L .78465 .74648 L p .912 .96 .634 r
F P
0 g
s
.24551 .58677 m .25141 .63015 L .24512 .68259 L p 0 0 .299 r
F P
0 g
s
.26037 .72325 m .24512 .68259 L .25141 .63015 L p 0 0 .537 r
F P
0 g
s
.70194 .84607 m .66635 .86507 L .68616 .8403 L p .733 .991 .843 r
F P
0 g
s
.68616 .8403 m .7277 .81443 L .70194 .84607 L p .733 .991 .843 r
F P
0 g
s
.61513 .34662 m .62774 .35681 L .54724 .34302 L p .48 0 0 r
F P
0 g
s
.54724 .34302 m .54462 .33449 L .61513 .34662 L p .48 0 0 r
F P
0 g
s
.63262 .88508 m .60094 .88968 L .62419 .87574 L p .581 .94 .918 r
F P
0 g
s
.62419 .87574 m .66635 .86507 L .63262 .88508 L p .581 .94 .918 r
F P
0 g
s
.81427 .61421 m .80831 .65632 L .78592 .60439 L p .997 .796 .445 r
F P
0 g
s
.78592 .60439 m .79159 .55974 L .81427 .61421 L p .997 .796 .445 r
F P
0 g
s
.69469 .38686 m .71226 .40746 L .63852 .37459 L p .716 .189 0 r
F P
0 g
s
.63852 .37459 m .62774 .35681 L .69469 .38686 L p .716 .189 0 r
F P
0 g
s
.46389 .34771 m .47168 .33861 L .54462 .33449 L p .342 0 0 r
F P
0 g
s
.47168 .33861 m .46389 .34771 L .38899 .37012 L p .077 0 0 r
F P
0 g
s
.29671 .45805 m .28719 .49337 L .24842 .54636 L p 0 0 .107 r
F P
0 g
s
.24551 .58677 m .24842 .54636 L .28719 .49337 L p .018 0 .351 r
F P
0 g
s
.54462 .33449 m .54724 .34302 L .46389 .34771 L p .342 0 0 r
F P
0 g
s
.38899 .37012 m .37451 .38916 L .31206 .42911 L p 0 0 0 r
F P
0 g
s
.29671 .45805 m .31206 .42911 L .37451 .38916 L p .133 0 .12 r
F P
0 g
s
.33547 .83095 m .37448 .8532 L .40171 .87584 L p 0 .329 .777 r
F P
0 g
s
.43902 .88323 m .40171 .87584 L .37448 .8532 L p .187 .568 .937 r
F P
0 g
s
.40171 .87584 m .43902 .88323 L .46635 .89507 L p .054 .552 .885 r
F P
0 g
s
.7785 .48313 m .78879 .51896 L .73413 .47003 L p .926 .545 .248 r
F P
0 g
s
.73413 .47003 m .72575 .4352 L .7785 .48313 L p .926 .545 .248 r
F P
0 g
s
.76076 .78259 m .7277 .81443 L .73259 .7794 L p .904 .982 .784 r
F P
0 g
s
.73259 .7794 m .76743 .74073 L .76076 .78259 L p .904 .982 .784 r
F P
0 g
s
.53103 .89147 m .53536 .90341 L .49957 .902 L p .399 .794 .987 r
F P
0 g
s
.53536 .90341 m .53103 .89147 L .54922 .88925 L p .464 .841 .988 r
F P
0 g
s
.54922 .88925 m .57028 .89918 L .53536 .90341 L p .464 .841 .988 r
F P
0 g
s
.28531 .76205 m .31971 .79721 L .33547 .83095 L p 0 .211 .736 r
F P
0 g
s
.37448 .8532 m .33547 .83095 L .31971 .79721 L p .13 .43 .87 r
F P
0 g
s
.51237 .89073 m .49957 .902 L .46635 .89507 L p .371 .753 .989 r
F P
0 g
s
.49957 .902 m .51237 .89073 L .53103 .89147 L p .399 .794 .987 r
F P
0 g
s
.25141 .63015 m .26679 .67503 L .26037 .72325 L p 0 0 .537 r
F P
0 g
s
.28531 .76205 m .26037 .72325 L .26679 .67503 L p .066 .199 .693 r
F P
0 g
s
.37451 .38916 m .38899 .37012 L .46389 .34771 L p .3 0 .029 r
F P
0 g
s
.57028 .89918 m .54922 .88925 L .56506 .88428 L p .551 .881 .99 r
F P
0 g
s
.56506 .88428 m .60094 .88968 L .57028 .89918 L p .551 .881 .99 r
F P
0 g
s
.80831 .65632 m .79278 .69907 L .77118 .6514 L p .991 .853 .604 r
F P
0 g
s
.77118 .6514 m .78592 .60439 L .80831 .65632 L p .991 .853 .604 r
F P
0 g
s
.66635 .86507 m .62419 .87574 L .63743 .85865 L p .735 .962 .94 r
F P
0 g
s
.63743 .85865 m .68616 .8403 L .66635 .86507 L p .735 .962 .94 r
F P
0 g
s
.49513 .88709 m .46635 .89507 L .43902 .88323 L p .382 .72 .989 r
F P
0 g
s
.46635 .89507 m .49513 .88709 L .51237 .89073 L p .371 .753 .989 r
F P
0 g
s
.62774 .35681 m .63852 .37459 L .54948 .35947 L p .643 .156 .08 r
F P
0 g
s
.54948 .35947 m .54724 .34302 L .62774 .35681 L p .643 .156 .08 r
F P
0 g
s
.71226 .40746 m .72575 .4352 L .64682 .40043 L p .811 .375 .207 r
F P
0 g
s
.64682 .40043 m .63852 .37459 L .71226 .40746 L p .811 .375 .207 r
F P
0 g
s
.28719 .49337 m .28461 .53448 L .24551 .58677 L p .018 0 .351 r
F P
0 g
s
.25141 .63015 m .24551 .58677 L .28461 .53448 L p .168 .089 .516 r
F P
0 g
s
.60094 .88968 m .56506 .88428 L .57688 .87705 L p .636 .901 .985 r
F P
0 g
s
.57688 .87705 m .62419 .87574 L .60094 .88968 L p .636 .901 .985 r
F P
0 g
s
.7277 .81443 m .68616 .8403 L .68922 .81313 L p .859 .96 .87 r
F P
0 g
s
.68922 .81313 m .73259 .7794 L .7277 .81443 L p .859 .96 .87 r
F P
0 g
s
.78879 .51896 m .79159 .55974 L .7364 .51144 L p .947 .643 .428 r
F P
0 g
s
.7364 .51144 m .73413 .47003 L .78879 .51896 L p .947 .643 .428 r
F P
0 g
s
.37451 .38916 m .36338 .41585 L .29671 .45805 L p .133 0 .12 r
F P
0 g
s
.28719 .49337 m .29671 .45805 L .36338 .41585 L p .277 .018 .33 r
F P
0 g
s
.26679 .67503 m .29182 .71959 L .28531 .76205 L p .066 .199 .693 r
F P
0 g
s
.31971 .79721 m .28531 .76205 L .29182 .71959 L p .221 .36 .793 r
F P
0 g
s
.45722 .36461 m .46389 .34771 L .54724 .34302 L p .511 .054 .103 r
F P
0 g
s
.46389 .34771 m .45722 .36461 L .37451 .38916 L p .3 0 .029 r
F P
0 g
s
.31971 .79721 m .36273 .8269 L .37448 .8532 L p .13 .43 .87 r
F P
0 g
s
.42047 .86753 m .37448 .8532 L .36273 .8269 L p .326 .577 .933 r
F P
0 g
s
.37448 .8532 m .42047 .86753 L .43902 .88323 L p .187 .568 .937 r
F P
0 g
s
.4811 .88092 m .43902 .88323 L .42047 .86753 L p .42 .696 .978 r
F P
0 g
s
.43902 .88323 m .4811 .88092 L .49513 .88709 L p .382 .72 .989 r
F P
0 g
s
.54724 .34302 m .54948 .35947 L .45722 .36461 L p .511 .054 .103 r
F P
0 g
s
.79278 .69907 m .76743 .74073 L .74724 .69888 L p .958 .874 .71 r
F P
0 g
s
.74724 .69888 m .77118 .6514 L .79278 .69907 L p .958 .874 .71 r
F P
0 g
s
.36338 .41585 m .37451 .38916 L .45722 .36461 L p .428 .073 .258 r
F P
0 g
s
.62419 .87574 m .57688 .87705 L .58338 .86828 L p .699 .895 .968 r
F P
0 g
s
.58338 .86828 m .63743 .85865 L .62419 .87574 L p .699 .895 .968 r
F P
0 g
s
.28461 .53448 m .28985 .58033 L .25141 .63015 L p .168 .089 .516 r
F P
0 g
s
.26679 .67503 m .25141 .63015 L .28985 .58033 L p .277 .234 .629 r
F P
0 g
s
.68616 .8403 m .63743 .85865 L .6389 .84012 L p .8 .919 .918 r
F P
0 g
s
.6389 .84012 m .68922 .81313 L .68616 .8403 L p .8 .919 .918 r
F P
0 g
s
.52632 .86843 m .53103 .89147 L .51237 .89073 L closepath p .579 .8 .983 r
F P
0 g
s
.52632 .86843 m .54922 .88925 L .53103 .89147 L closepath p .595 .811 .982 r
F P
0 g
s
.29182 .71959 m .32611 .76181 L .31971 .79721 L p .221 .36 .793 r
F P
0 g
s
.36273 .8269 m .31971 .79721 L .32611 .76181 L p .341 .484 .857 r
F P
0 g
s
.52632 .86843 m .51237 .89073 L .49513 .88709 L closepath p .569 .787 .981 r
F P
0 g
s
.52632 .86843 m .56506 .88428 L .54922 .88925 L closepath p .614 .819 .979 r
F P
0 g
s
.72575 .4352 m .73413 .47003 L .65198 .43447 L p .844 .486 .377 r
F P
0 g
s
.65198 .43447 m .64682 .40043 L .72575 .4352 L p .844 .486 .377 r
F P
0 g
s
.79159 .55974 m .78592 .60439 L .73179 .5584 L p .939 .7 .55 r
F P
0 g
s
.73179 .5584 m .7364 .51144 L .79159 .55974 L p .939 .7 .55 r
F P
0 g
s
.36273 .8269 m .41293 .84949 L .42047 .86753 L p .326 .577 .933 r
F P
0 g
s
.47179 .87282 m .42047 .86753 L .41293 .84949 L p .469 .678 .956 r
F P
0 g
s
.42047 .86753 m .47179 .87282 L .4811 .88092 L p .42 .696 .978 r
F P
0 g
s
.52632 .86843 m .49513 .88709 L .4811 .88092 L closepath p .566 .773 .976 r
F P
0 g
s
.63852 .37459 m .64682 .40043 L .55121 .38441 L p .714 .313 .287 r
F P
0 g
s
.55121 .38441 m .54948 .35947 L .63852 .37459 L p .714 .313 .287 r
F P
0 g
s
.36338 .41585 m .35646 .45025 L .28719 .49337 L p .277 .018 .33 r
F P
0 g
s
.28461 .53448 m .28719 .49337 L .35646 .45025 L p .369 .166 .469 r
F P
0 g
s
.76743 .74073 m .73259 .7794 L .71457 .74465 L p .914 .877 .785 r
F P
0 g
s
.71457 .74465 m .74724 .69888 L .76743 .74073 L p .914 .877 .785 r
F P
0 g
s
.52632 .86843 m .57688 .87705 L .56506 .88428 L closepath p .634 .821 .972 r
F P
0 g
s
.52632 .86843 m .4811 .88092 L .47179 .87282 L closepath p .569 .761 .969 r
F P
0 g
s
.45208 .38986 m .45722 .36461 L .54948 .35947 L p .595 .219 .3 r
F P
0 g
s
.45722 .36461 m .45208 .38986 L .36338 .41585 L p .428 .073 .258 r
F P
0 g
s
.28985 .58033 m .30346 .62938 L .26679 .67503 L p .277 .234 .629 r
F P
0 g
s
.29182 .71959 m .26679 .67503 L .30346 .62938 L p .358 .346 .71 r
F P
0 g
s
.32611 .76181 m .3686 .79959 L .36273 .8269 L p .341 .484 .857 r
F P
0 g
s
.41293 .84949 m .36273 .8269 L .3686 .79959 L p .437 .584 .901 r
F P
0 g
s
.63743 .85865 m .58338 .86828 L .58376 .85889 L p .734 .868 .944 r
F P
0 g
s
.58376 .85889 m .6389 .84012 L .63743 .85865 L p .734 .868 .944 r
F P
0 g
s
.52632 .86843 m .58338 .86828 L .57688 .87705 L closepath p .65 .819 .964 r
F P
0 g
s
.54948 .35947 m .55121 .38441 L .45208 .38986 L p .595 .219 .3 r
F P
0 g
s
.35646 .45025 m .36338 .41585 L .45208 .38986 L p .501 .211 .405 r
F P
0 g
s
.73259 .7794 m .68922 .81313 L .67425 .78645 L p .864 .869 .84 r
F P
0 g
s
.67425 .78645 m .71457 .74465 L .73259 .7794 L p .864 .869 .84 r
F P
0 g
s
.41293 .84949 m .46827 .86362 L .47179 .87282 L p .469 .678 .956 r
F P
0 g
s
.52632 .86843 m .47179 .87282 L .46827 .86362 L closepath p .578 .751 .96 r
F P
0 g
s
.78592 .60439 m .77118 .6514 L .71981 .60933 L p .919 .735 .637 r
F P
0 g
s
.71981 .60933 m .73179 .5584 L .78592 .60439 L p .919 .735 .637 r
F P
0 g
s
.3686 .79959 m .41763 .83097 L .41293 .84949 L p .437 .584 .901 r
F P
0 g
s
.46827 .86362 m .41293 .84949 L .41763 .83097 L p .519 .669 .931 r
F P
0 g
s
.52632 .86843 m .58376 .85889 L .58338 .86828 L closepath p .663 .812 .955 r
F P
0 g
s
.73413 .47003 m .7364 .51144 L .65338 .47632 L p .85 .557 .492 r
F P
0 g
s
.65338 .47632 m .65198 .43447 L .73413 .47003 L p .85 .557 .492 r
F P
0 g
s
.35646 .45025 m .35458 .4919 L .28461 .53448 L p .369 .166 .469 r
F P
0 g
s
.28985 .58033 m .28461 .53448 L .35458 .4919 L p .432 .275 .566 r
F P
0 g
s
.30346 .62938 m .32552 .67963 L .29182 .71959 L p .358 .346 .71 r
F P
0 g
s
.32611 .76181 m .29182 .71959 L .32552 .67963 L p .422 .439 .772 r
F P
0 g
s
.68922 .81313 m .6389 .84012 L .62797 .82213 L p .809 .854 .883 r
F P
0 g
s
.62797 .82213 m .67425 .78645 L .68922 .81313 L p .809 .854 .883 r
F P
0 g
s
.41763 .83097 m .47104 .8543 L .46827 .86362 L p .519 .669 .931 r
F P
0 g
s
.52632 .86843 m .46827 .86362 L .47104 .8543 L closepath p .591 .745 .95 r
F P
0 g
s
.64682 .40043 m .65198 .43447 L .55229 .41805 L p .744 .412 .421 r
F P
0 g
s
.55229 .41805 m .55121 .38441 L .64682 .40043 L p .744 .412 .421 r
F P
0 g
s
.52632 .86843 m .56622 .8423 L .57786 .84989 L closepath p .671 .789 .937 r
F P
0 g
s
.52632 .86843 m .55006 .83698 L .56622 .8423 L closepath p .667 .776 .931 r
F P
0 g
s
.52632 .86843 m .53119 .83459 L .55006 .83698 L closepath p .659 .764 .927 r
F P
0 g
s
.52632 .86843 m .51175 .8354 L .53119 .83459 L closepath p .649 .754 .926 r
F P
0 g
s
.52632 .86843 m .49399 .83932 L .51175 .8354 L closepath p .635 .747 .929 r
F P
0 g
s
.52632 .86843 m .47991 .84588 L .49399 .83932 L closepath p .621 .742 .934 r
F P
0 g
s
.52632 .86843 m .47104 .8543 L .47991 .84588 L closepath p .605 .742 .941 r
F P
0 g
s
.52632 .86843 m .57786 .84989 L .58376 .85889 L closepath p .669 .801 .945 r
F P
0 g
s
.6389 .84012 m .58376 .85889 L .57786 .84989 L p .745 .832 .918 r
F P
0 g
s
.57786 .84989 m .62797 .82213 L .6389 .84012 L p .745 .832 .918 r
F P
0 g
s
.77118 .6514 m .74724 .69888 L .70045 .66214 L p .894 .758 .705 r
F P
0 g
s
.70045 .66214 m .71981 .60933 L .77118 .6514 L p .894 .758 .705 r
F P
0 g
s
.32552 .67963 m .35553 .72876 L .32611 .76181 L p .422 .439 .772 r
F P
0 g
s
.3686 .79959 m .32611 .76181 L .35553 .72876 L p .475 .519 .823 r
F P
0 g
s
.44888 .42364 m .45208 .38986 L .55121 .38441 L p .638 .327 .428 r
F P
0 g
s
.45208 .38986 m .44888 .42364 L .35646 .45025 L p .501 .211 .405 r
F P
0 g
s
.43454 .81403 m .47991 .84588 L .47104 .8543 L p .565 .667 .906 r
F P
0 g
s
.47104 .8543 m .41763 .83097 L .43454 .81403 L p .565 .667 .906 r
F P
0 g
s
.35458 .4919 m .35646 .45025 L .44888 .42364 L p .546 .308 .506 r
F P
0 g
s
.35553 .72876 m .39241 .77433 L .3686 .79959 L p .475 .519 .823 r
F P
0 g
s
.41763 .83097 m .3686 .79959 L .39241 .77433 L p .522 .594 .867 r
F P
0 g
s
.35458 .4919 m .35839 .53982 L .28985 .58033 L p .432 .275 .566 r
F P
0 g
s
.30346 .62938 m .28985 .58033 L .35839 .53982 L p .478 .359 .64 r
F P
0 g
s
.39241 .77433 m .43454 .81403 L .41763 .83097 L p .522 .594 .867 r
F P
0 g
s
.55121 .38441 m .55229 .41805 L .44888 .42364 L p .638 .327 .428 r
F P
0 g
s
.62797 .82213 m .57786 .84989 L .56622 .8423 L p .74 .794 .896 r
F P
0 g
s
.7364 .51144 m .73179 .5584 L .65053 .52499 L p .846 .606 .575 r
F P
0 g
s
.65053 .52499 m .65338 .47632 L .7364 .51144 L p .846 .606 .575 r
F P
0 g
s
.74724 .69888 m .71457 .74465 L .67418 .71438 L p .865 .774 .76 r
F P
0 g
s
.67418 .71438 m .70045 .66214 L .74724 .69888 L p .865 .774 .76 r
F P
0 g
s
.4621 .80071 m .49399 .83932 L .47991 .84588 L p .606 .673 .887 r
F P
0 g
s
.47991 .84588 m .43454 .81403 L .4621 .80071 L p .606 .673 .887 r
F P
0 g
s
.67425 .78645 m .62797 .82213 L .60543 .80677 L p .791 .792 .853 r
F P
0 g
s
.56622 .8423 m .60543 .80677 L .62797 .82213 L p .74 .794 .896 r
F P
0 g
s
.60543 .80677 m .56622 .8423 L .55006 .83698 L p .725 .759 .88 r
F P
0 g
s
.71457 .74465 m .67425 .78645 L .64201 .76342 L p .831 .785 .809 r
F P
0 g
s
.64201 .76342 m .67418 .71438 L .71457 .74465 L p .831 .785 .809 r
F P
0 g
s
.65198 .43447 m .65338 .47632 L .55258 .4601 L p .757 .479 .513 r
F P
0 g
s
.55258 .4601 m .55229 .41805 L .65198 .43447 L p .757 .479 .513 r
F P
0 g
s
.60543 .80677 m .64201 .76342 L .67425 .78645 L p .791 .792 .853 r
F P
0 g
s
.35839 .53982 m .36828 .59237 L .30346 .62938 L p .478 .359 .64 r
F P
0 g
s
.32552 .67963 m .30346 .62938 L .36828 .59237 L p .513 .429 .699 r
F P
0 g
s
.49731 .79269 m .51175 .8354 L .49399 .83932 L p .642 .685 .875 r
F P
0 g
s
.49399 .83932 m .4621 .80071 L .49731 .79269 L p .642 .685 .875 r
F P
0 g
s
.55006 .83698 m .57357 .79593 L .60543 .80677 L p .725 .759 .88 r
F P
0 g
s
.57357 .79593 m .55006 .83698 L .53119 .83459 L p .702 .729 .871 r
F P
0 g
s
.53603 .79102 m .53119 .83459 L .51175 .8354 L p .674 .704 .87 r
F P
0 g
s
.51175 .8354 m .49731 .79269 L .53603 .79102 L p .674 .704 .87 r
F P
0 g
s
.53119 .83459 m .53603 .79102 L .57357 .79593 L p .702 .729 .871 r
F P
0 g
s
.43221 .75427 m .4621 .80071 L .43454 .81403 L p .587 .61 .842 r
F P
0 g
s
.43454 .81403 m .39241 .77433 L .43221 .75427 L p .587 .61 .842 r
F P
0 g
s
.44888 .42364 m .44801 .46562 L .35458 .4919 L p .546 .308 .506 r
F P
0 g
s
.35839 .53982 m .35458 .4919 L .44801 .46562 L p .576 .381 .58 r
F P
0 g
s
.73179 .5584 m .71981 .60933 L .64316 .57886 L p .836 .642 .64 r
F P
0 g
s
.64316 .57886 m .65053 .52499 L .73179 .5584 L p .836 .642 .64 r
F P
0 g
s
.44801 .46562 m .44888 .42364 L .55229 .41805 L p .662 .402 .516 r
F P
0 g
s
.36828 .59237 m .38424 .64739 L .32552 .67963 L p .513 .429 .699 r
F P
0 g
s
.35553 .72876 m .32552 .67963 L .38424 .64739 L p .541 .492 .75 r
F P
0 g
s
.40585 .70228 m .43221 .75427 L .39241 .77433 L p .566 .551 .796 r
F P
0 g
s
.39241 .77433 m .35553 .72876 L .40585 .70228 L p .566 .551 .796 r
F P
0 g
s
.55229 .41805 m .55258 .4601 L .44801 .46562 L p .662 .402 .516 r
F P
0 g
s
.64201 .76342 m .60543 .80677 L .57357 .79593 L p .762 .739 .832 r
F P
0 g
s
.38424 .64739 m .40585 .70228 L .35553 .72876 L p .541 .492 .75 r
F P
0 g
s
.71981 .60933 m .70045 .66214 L .63127 .63565 L p .823 .671 .693 r
F P
0 g
s
.63127 .63565 m .64316 .57886 L .71981 .60933 L p .823 .671 .693 r
F P
0 g
s
.4837 .74211 m .49731 .79269 L .4621 .80071 L p .641 .632 .826 r
F P
0 g
s
.4621 .80071 m .43221 .75427 L .4837 .74211 L p .641 .632 .826 r
F P
0 g
s
.65338 .47632 m .65053 .52499 L .55198 .50958 L p .761 .529 .582 r
F P
0 g
s
.55198 .50958 m .55258 .4601 L .65338 .47632 L p .761 .529 .582 r
F P
0 g
s
.44801 .46562 m .44977 .51483 L .35839 .53982 L p .576 .381 .58 r
F P
0 g
s
.36828 .59237 m .35839 .53982 L .44977 .51483 L p .597 .44 .639 r
F P
0 g
s
.67418 .71438 m .64201 .76342 L .59566 .74704 L p .788 .718 .787 r
F P
0 g
s
.57357 .79593 m .59566 .74704 L .64201 .76342 L p .762 .739 .832 r
F P
0 g
s
.59566 .74704 m .57357 .79593 L .53603 .79102 L p .726 .696 .821 r
F P
0 g
s
.70045 .66214 m .67418 .71438 L .61521 .69268 L p .808 .696 .741 r
F P
0 g
s
.61521 .69268 m .63127 .63565 L .70045 .66214 L p .808 .696 .741 r
F P
0 g
s
.54059 .73957 m .53603 .79102 L .49731 .79269 L p .686 .66 .819 r
F P
0 g
s
.49731 .79269 m .4837 .74211 L .54059 .73957 L p .686 .66 .819 r
F P
0 g
s
.59566 .74704 m .61521 .69268 L .67418 .71438 L p .788 .718 .787 r
F P
0 g
s
.44977 .51483 m .44801 .46562 L .55258 .4601 L p .676 .459 .583 r
F P
0 g
s
.53603 .79102 m .54059 .73957 L .59566 .74704 L p .726 .696 .821 r
F P
0 g
s
.47163 .68612 m .4837 .74211 L .43221 .75427 L p .634 .583 .78 r
F P
0 g
s
.43221 .75427 m .40585 .70228 L .47163 .68612 L p .634 .583 .78 r
F P
0 g
s
.55258 .4601 m .55198 .50958 L .44977 .51483 L p .676 .459 .583 r
F P
0 g
s
.44977 .51483 m .45434 .5696 L .36828 .59237 L p .597 .44 .639 r
F P
0 g
s
.38424 .64739 m .36828 .59237 L .45434 .5696 L p .613 .49 .689 r
F P
0 g
s
.65053 .52499 m .64316 .57886 L .55045 .56482 L p .76 .569 .638 r
F P
0 g
s
.55045 .56482 m .55198 .50958 L .65053 .52499 L p .76 .569 .638 r
F P
0 g
s
.4617 .62762 m .47163 .68612 L .40585 .70228 L p .625 .537 .735 r
F P
0 g
s
.40585 .70228 m .38424 .64739 L .4617 .62762 L p .625 .537 .735 r
F P
0 g
s
.61521 .69268 m .59566 .74704 L .54059 .73957 L p .741 .665 .775 r
F P
0 g
s
.45434 .5696 m .4617 .62762 L .38424 .64739 L p .613 .49 .689 r
F P
0 g
s
.45434 .5696 m .44977 .51483 L .55198 .50958 L p .684 .505 .638 r
F P
0 g
s
.54464 .68275 m .54059 .73957 L .4837 .74211 L p .691 .621 .773 r
F P
0 g
s
.4837 .74211 m .47163 .68612 L .54464 .68275 L p .691 .621 .773 r
F P
0 g
s
.64316 .57886 m .63127 .63565 L .54797 .62348 L p .757 .603 .687 r
F P
0 g
s
.54797 .62348 m .55045 .56482 L .64316 .57886 L p .757 .603 .687 r
F P
0 g
s
.54059 .73957 m .54464 .68275 L .61521 .69268 L p .741 .665 .775 r
F P
0 g
s
.63127 .63565 m .61521 .69268 L .54464 .68275 L p .751 .634 .731 r
F P
0 g
s
.55198 .50958 m .55045 .56482 L .45434 .5696 L p .684 .505 .638 r
F P
0 g
s
.54464 .68275 m .54797 .62348 L .63127 .63565 L p .751 .634 .731 r
F P
0 g
s
.4617 .62762 m .45434 .5696 L .55045 .56482 L p .689 .545 .685 r
F P
0 g
s
.54797 .62348 m .54464 .68275 L .47163 .68612 L p .691 .583 .729 r
F P
0 g
s
.47163 .68612 m .4617 .62762 L .54797 .62348 L p .691 .583 .729 r
F P
0 g
s
.55045 .56482 m .54797 .62348 L .4617 .62762 L p .689 .545 .685 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48293 .55303 m .4766 .59237 L .54311 .59559 L p .719 .598 .721 r
F P
0 g
s
.54311 .59559 m .54098 .55591 L .48293 .55303 L p .719 .598 .721 r
F P
0 g
s
.54488 .63567 m .54311 .59559 L .4766 .59237 L p .72 .575 .691 r
F P
0 g
s
.54098 .55591 m .54311 .59559 L .60819 .58593 L p .67 .561 .722 r
F P
0 g
s
.54311 .59559 m .54488 .63567 L .61687 .62524 L p .666 .532 .692 r
F P
0 g
s
.61687 .62524 m .60819 .58593 L .54311 .59559 L p .666 .532 .692 r
F P
0 g
s
.49021 .5148 m .48293 .55303 L .54098 .55591 L p .716 .62 .75 r
F P
0 g
s
.54098 .55591 m .53852 .51725 L .49021 .5148 L p .716 .62 .75 r
F P
0 g
s
.53852 .51725 m .54098 .55591 L .59772 .54727 L p .674 .588 .751 r
F P
0 g
s
.60819 .58593 m .59772 .54727 L .54098 .55591 L p .67 .561 .722 r
F P
0 g
s
.4766 .59237 m .47134 .6322 L .54488 .63567 L p .72 .575 .691 r
F P
0 g
s
.54625 .67547 m .54488 .63567 L .47134 .6322 L p .72 .55 .659 r
F P
0 g
s
.54488 .63567 m .54625 .67547 L .62357 .66454 L p .66 .502 .66 r
F P
0 g
s
.62357 .66454 m .61687 .62524 L .54488 .63567 L p .66 .502 .66 r
F P
0 g
s
.42875 .53884 m .41437 .57647 L .4766 .59237 L p .764 .641 .726 r
F P
0 g
s
.4766 .59237 m .48293 .55303 L .42875 .53884 L p .764 .641 .726 r
F P
0 g
s
.47134 .6322 m .4766 .59237 L .41437 .57647 L p .771 .623 .695 r
F P
0 g
s
.44525 .50274 m .42875 .53884 L .48293 .55303 L p .755 .659 .755 r
F P
0 g
s
.48293 .55303 m .49021 .5148 L .44525 .50274 L p .755 .659 .755 r
F P
0 g
s
.41437 .57647 m .40242 .61502 L .47134 .6322 L p .771 .623 .695 r
F P
0 g
s
.4673 .67183 m .47134 .6322 L .40242 .61502 L p .777 .602 .661 r
F P
0 g
s
.47134 .6322 m .4673 .67183 L .54625 .67547 L p .72 .55 .659 r
F P
0 g
s
.49832 .47826 m .49021 .5148 L .53852 .51725 L p .712 .643 .779 r
F P
0 g
s
.53852 .51725 m .53578 .4802 L .49832 .47826 L p .712 .643 .779 r
F P
0 g
s
.53578 .4802 m .53852 .51725 L .5857 .5099 L p .676 .616 .781 r
F P
0 g
s
.59772 .54727 m .5857 .5099 L .53852 .51725 L p .674 .588 .751 r
F P
0 g
s
.54716 .71423 m .54625 .67547 L .4673 .67183 L p .719 .522 .623 r
F P
0 g
s
.54625 .67547 m .54716 .71423 L .62806 .70308 L p .652 .469 .623 r
F P
0 g
s
.62806 .70308 m .62357 .66454 L .54625 .67547 L p .652 .469 .623 r
F P
0 g
s
.59772 .54727 m .60819 .58593 L .66611 .564 L p .616 .527 .731 r
F P
0 g
s
.60819 .58593 m .61687 .62524 L .68116 .60152 L p .604 .492 .699 r
F P
0 g
s
.68116 .60152 m .66611 .564 L .60819 .58593 L p .604 .492 .699 r
F P
0 g
s
.5857 .5099 m .59772 .54727 L .64804 .52773 L p .627 .561 .761 r
F P
0 g
s
.66611 .564 m .64804 .52773 L .59772 .54727 L p .616 .527 .731 r
F P
0 g
s
.46356 .46873 m .44525 .50274 L .49021 .5148 L p .744 .676 .784 r
F P
0 g
s
.49021 .5148 m .49832 .47826 L .46356 .46873 L p .744 .676 .784 r
F P
0 g
s
.61687 .62524 m .62357 .66454 L .6928 .63966 L p .59 .454 .665 r
F P
0 g
s
.6928 .63966 m .68116 .60152 L .61687 .62524 L p .59 .454 .665 r
F P
0 g
s
.40242 .61502 m .39319 .65383 L .4673 .67183 L p .777 .602 .661 r
F P
0 g
s
.46458 .71052 m .4673 .67183 L .39319 .65383 L p .781 .577 .624 r
F P
0 g
s
.4673 .67183 m .46458 .71052 L .54716 .71423 L p .719 .522 .623 r
F P
0 g
s
.5857 .5099 m .57233 .47439 L .53578 .4802 L p .676 .616 .781 r
F P
0 g
s
.57233 .47439 m .5857 .5099 L .62735 .49333 L p .638 .595 .79 r
F P
0 g
s
.64804 .52773 m .62735 .49333 L .5857 .5099 L p .627 .561 .761 r
F P
0 g
s
.40792 .48202 m .38349 .51436 L .42875 .53884 L p .792 .705 .768 r
F P
0 g
s
.42875 .53884 m .44525 .50274 L .40792 .48202 L p .792 .705 .768 r
F P
0 g
s
.41437 .57647 m .42875 .53884 L .38349 .51436 L p .809 .694 .738 r
F P
0 g
s
.38349 .51436 m .36209 .54894 L .41437 .57647 L p .809 .694 .738 r
F P
0 g
s
.40242 .61502 m .41437 .57647 L .36209 .54894 L p .823 .68 .705 r
F P
0 g
s
.50713 .444 m .49832 .47826 L .53578 .4802 L p .705 .666 .809 r
F P
0 g
s
.53578 .4802 m .5328 .44536 L .50713 .444 L p .705 .666 .809 r
F P
0 g
s
.5328 .44536 m .53578 .4802 L .57233 .47439 L p .678 .645 .811 r
F P
0 g
s
.62357 .66454 m .62806 .70308 L .70061 .67766 L p .573 .412 .625 r
F P
0 g
s
.70061 .67766 m .6928 .63966 L .62357 .66454 L p .573 .412 .625 r
F P
0 g
s
.54758 .75115 m .54716 .71423 L .46458 .71052 L p .715 .489 .581 r
F P
0 g
s
.54716 .71423 m .54758 .75115 L .63013 .74005 L p .642 .43 .581 r
F P
0 g
s
.63013 .74005 m .62806 .70308 L .54716 .71423 L p .642 .43 .581 r
F P
0 g
s
.48338 .43736 m .46356 .46873 L .49832 .47826 L p .73 .692 .814 r
F P
0 g
s
.49832 .47826 m .50713 .444 L .48338 .43736 L p .73 .692 .814 r
F P
0 g
s
.43491 .45242 m .40792 .48202 L .44525 .50274 L p .774 .715 .797 r
F P
0 g
s
.44525 .50274 m .46356 .46873 L .43491 .45242 L p .774 .715 .797 r
F P
0 g
s
.36209 .54894 m .34424 .58521 L .40242 .61502 L p .823 .68 .705 r
F P
0 g
s
.39319 .65383 m .40242 .61502 L .34424 .58521 L p .836 .664 .669 r
F P
0 g
s
.57233 .47439 m .55783 .4413 L .5328 .44536 L p .678 .645 .811 r
F P
0 g
s
.55783 .4413 m .57233 .47439 L .60443 .46131 L p .648 .63 .819 r
F P
0 g
s
.62735 .49333 m .60443 .46131 L .57233 .47439 L p .638 .595 .79 r
F P
0 g
s
.39319 .65383 m .387 .69214 L .46458 .71052 L p .781 .577 .624 r
F P
0 g
s
.46333 .74746 m .46458 .71052 L .387 .69214 L p .784 .548 .579 r
F P
0 g
s
.46458 .71052 m .46333 .74746 L .54758 .75115 L p .715 .489 .581 r
F P
0 g
s
.62735 .49333 m .64804 .52773 L .68701 .49874 L p .573 .539 .778 r
F P
0 g
s
.64804 .52773 m .66611 .564 L .71133 .53132 L p .551 .496 .748 r
F P
0 g
s
.71133 .53132 m .68701 .49874 L .64804 .52773 L p .551 .496 .748 r
F P
0 g
s
.46396 .42603 m .43491 .45242 L .46356 .46873 L p .751 .722 .825 r
F P
0 g
s
.46356 .46873 m .48338 .43736 L .46396 .42603 L p .751 .722 .825 r
F P
0 g
s
.66611 .564 m .68116 .60152 L .73168 .56606 L p .526 .45 .714 r
F P
0 g
s
.73168 .56606 m .71133 .53132 L .66611 .564 L p .526 .45 .714 r
F P
0 g
s
.60443 .46131 m .62735 .49333 L .65931 .46885 L p .595 .58 .807 r
F P
0 g
s
.68701 .49874 m .65931 .46885 L .62735 .49333 L p .573 .539 .778 r
F P
0 g
s
.34424 .58521 m .33041 .62251 L .39319 .65383 L p .836 .664 .669 r
F P
0 g
s
.387 .69214 m .39319 .65383 L .33041 .62251 L p .847 .643 .626 r
F P
0 g
s
.62806 .70308 m .63013 .74005 L .70422 .71472 L p .552 .362 .577 r
F P
0 g
s
.70422 .71472 m .70061 .67766 L .62806 .70308 L p .552 .362 .577 r
F P
0 g
s
.51651 .41258 m .50713 .444 L .5328 .44536 L p .695 .691 .841 r
F P
0 g
s
.5328 .44536 m .52963 .41329 L .51651 .41258 L p .695 .691 .841 r
F P
0 g
s
.52963 .41329 m .5328 .44536 L .55783 .4413 L p .677 .677 .843 r
F P
0 g
s
.50441 .40913 m .48338 .43736 L .50713 .444 L p .712 .708 .845 r
F P
0 g
s
.50713 .444 m .51651 .41258 L .50441 .40913 L p .712 .708 .845 r
F P
0 g
s
.68116 .60152 m .6928 .63966 L .74746 .60236 L p .498 .399 .674 r
F P
0 g
s
.74746 .60236 m .73168 .56606 L .68116 .60152 L p .498 .399 .674 r
F P
0 g
s
.60443 .46131 m .57969 .4322 L .55783 .4413 L p .648 .63 .819 r
F P
0 g
s
.57969 .4322 m .60443 .46131 L .62882 .44211 L p .616 .621 .833 r
F P
0 g
s
.65931 .46885 m .62882 .44211 L .60443 .46131 L p .595 .58 .807 r
F P
0 g
s
.54747 .78533 m .54758 .75115 L .46333 .74746 L p .708 .449 .53 r
F P
0 g
s
.54758 .75115 m .54747 .78533 L .6296 .77453 L p .627 .383 .528 r
F P
0 g
s
.6296 .77453 m .63013 .74005 L .54758 .75115 L p .627 .383 .528 r
F P
0 g
s
.55783 .4413 m .54241 .41118 L .52963 .41329 L p .677 .677 .843 r
F P
0 g
s
.54241 .41118 m .55783 .4413 L .57969 .4322 L p .657 .668 .848 r
F P
0 g
s
.387 .69214 m .38414 .72915 L .46333 .74746 L p .784 .548 .579 r
F P
0 g
s
.46366 .78174 m .46333 .74746 L .38414 .72915 L p .783 .51 .524 r
F P
0 g
s
.46333 .74746 m .46366 .78174 L .54747 .78533 L p .708 .449 .53 r
F P
0 g
s
.41542 .43079 m .38217 .45436 L .40792 .48202 L p .799 .761 .818 r
F P
0 g
s
.40792 .48202 m .43491 .45242 L .41542 .43079 L p .799 .761 .818 r
F P
0 g
s
.38349 .51436 m .40792 .48202 L .38217 .45436 L p .826 .762 .791 r
F P
0 g
s
.4946 .40328 m .46396 .42603 L .48338 .43736 L p .725 .728 .853 r
F P
0 g
s
.48338 .43736 m .50441 .40913 L .4946 .40328 L p .725 .728 .853 r
F P
0 g
s
.38217 .45436 m .35186 .4815 L .38349 .51436 L p .826 .762 .791 r
F P
0 g
s
.36209 .54894 m .38349 .51436 L .35186 .4815 L p .852 .76 .76 r
F P
0 g
s
.33041 .62251 m .32112 .66013 L .387 .69214 L p .847 .643 .626 r
F P
0 g
s
.38414 .72915 m .387 .69214 L .32112 .66013 L p .856 .615 .573 r
F P
0 g
s
.45096 .41111 m .41542 .43079 L .43491 .45242 L p .768 .757 .843 r
F P
0 g
s
.43491 .45242 m .46396 .42603 L .45096 .41111 L p .768 .757 .843 r
F P
0 g
s
.35186 .4815 m .32515 .51181 L .36209 .54894 L p .852 .76 .76 r
F P
0 g
s
.34424 .58521 m .36209 .54894 L .32515 .51181 L p .877 .754 .724 r
F P
0 g
s
.6928 .63966 m .70061 .67766 L .75809 .6395 L p .465 .34 .626 r
F P
0 g
s
.75809 .6395 m .74746 .60236 L .6928 .63966 L p .465 .34 .626 r
F P
0 g
s
.57969 .4322 m .55351 .40646 L .54241 .41118 L p .657 .668 .848 r
F P
0 g
s
.55351 .40646 m .57969 .4322 L .59612 .4189 L p .637 .664 .859 r
F P
0 g
s
.62882 .44211 m .59612 .4189 L .57969 .4322 L p .616 .621 .833 r
F P
0 g
s
.63013 .74005 m .6296 .77453 L .70328 .74992 L p .525 .301 .516 r
F P
0 g
s
.70328 .74992 m .70422 .71472 L .63013 .74005 L p .525 .301 .516 r
F P
0 g
s
.48813 .39563 m .45096 .41111 L .46396 .42603 L p .733 .75 .866 r
F P
0 g
s
.46396 .42603 m .4946 .40328 L .48813 .39563 L p .733 .75 .866 r
F P
0 g
s
.32515 .51181 m .30275 .54481 L .34424 .58521 L p .877 .754 .724 r
F P
0 g
s
.33041 .62251 m .34424 .58521 L .30275 .54481 L p .899 .744 .68 r
F P
0 g
s
.52963 .41329 m .52632 .38458 L .51651 .41258 L closepath p .68 .717 .877 r
F P
0 g
s
.54241 .41118 m .52632 .38458 L .52963 .41329 L closepath p .674 .712 .877 r
F P
0 g
s
.51651 .41258 m .52632 .38458 L .50441 .40913 L closepath p .686 .724 .878 r
F P
0 g
s
.62882 .44211 m .65931 .46885 L .67799 .43861 L p .546 .573 .833 r
F P
0 g
s
.65931 .46885 m .68701 .49874 L .71023 .46269 L p .508 .522 .807 r
F P
0 g
s
.71023 .46269 m .67799 .43861 L .65931 .46885 L p .508 .522 .807 r
F P
0 g
s
.59612 .4189 m .62882 .44211 L .64276 .41854 L p .583 .62 .855 r
F P
0 g
s
.67799 .43861 m .64276 .41854 L .62882 .44211 L p .546 .573 .833 r
F P
0 g
s
.55351 .40646 m .52632 .38458 L .54241 .41118 L closepath p .666 .709 .88 r
F P
0 g
s
.68701 .49874 m .71133 .53132 L .73872 .49046 L p .465 .466 .775 r
F P
0 g
s
.73872 .49046 m .71023 .46269 L .68701 .49874 L p .465 .466 .775 r
F P
0 g
s
.50441 .40913 m .52632 .38458 L .4946 .40328 L closepath p .691 .731 .882 r
F P
0 g
s
.59612 .4189 m .56176 .39962 L .55351 .40646 L p .637 .664 .859 r
F P
0 g
s
.56176 .39962 m .59612 .4189 L .60528 .40272 L p .618 .665 .873 r
F P
0 g
s
.64276 .41854 m .60528 .40272 L .59612 .4189 L p .583 .62 .855 r
F P
0 g
s
.5468 .8158 m .54747 .78533 L .46366 .78174 L p .696 .396 .463 r
F P
0 g
s
.54747 .78533 m .5468 .8158 L .62628 .80557 L p .606 .321 .459 r
F P
0 g
s
.62628 .80557 m .6296 .77453 L .54747 .78533 L p .606 .321 .459 r
F P
0 g
s
.56176 .39962 m .52632 .38458 L .55351 .40646 L closepath p .659 .708 .884 r
F P
0 g
s
.70061 .67766 m .70422 .71472 L .76301 .67667 L p .423 .269 .565 r
F P
0 g
s
.76301 .67667 m .75809 .6395 L .70061 .67766 L p .423 .269 .565 r
F P
0 g
s
.32112 .66013 m .31682 .69724 L .38414 .72915 L p .856 .615 .573 r
F P
0 g
s
.38489 .76394 m .38414 .72915 L .31682 .69724 L p .862 .577 .505 r
F P
0 g
s
.38414 .72915 m .38489 .76394 L .46366 .78174 L p .783 .51 .524 r
F P
0 g
s
.4946 .40328 m .52632 .38458 L .48813 .39563 L closepath p .693 .739 .886 r
F P
0 g
s
.71133 .53132 m .73168 .56606 L .76271 .52151 L p .416 .402 .736 r
F P
0 g
s
.76271 .52151 m .73872 .49046 L .71133 .53132 L p .416 .402 .736 r
F P
0 g
s
.46566 .8124 m .46366 .78174 L .38489 .76394 L p .777 .459 .45 r
F P
0 g
s
.46366 .78174 m .46566 .8124 L .5468 .8158 L p .696 .396 .463 r
F P
0 g
s
.30275 .54481 m .28533 .57995 L .33041 .62251 L p .899 .744 .68 r
F P
0 g
s
.32112 .66013 m .33041 .62251 L .28533 .57995 L p .92 .727 .625 r
F P
0 g
s
.44589 .39409 m .40745 .40589 L .41542 .43079 L p .776 .794 .868 r
F P
0 g
s
.41542 .43079 m .45096 .41111 L .44589 .39409 L p .776 .794 .868 r
F P
0 g
s
.38217 .45436 m .41542 .43079 L .40745 .40589 L p .815 .814 .849 r
F P
0 g
s
.56623 .39135 m .52632 .38458 L .56176 .39962 L closepath p .653 .709 .889 r
F P
0 g
s
.60528 .40272 m .56623 .39135 L .56176 .39962 L p .618 .665 .873 r
F P
0 g
s
.48575 .38697 m .44589 .39409 L .45096 .41111 L p .736 .772 .882 r
F P
0 g
s
.45096 .41111 m .48813 .39563 L .48575 .38697 L p .736 .772 .882 r
F P
0 g
s
.40745 .40589 m .37117 .42229 L .38217 .45436 L p .815 .814 .849 r
F P
0 g
s
.35186 .4815 m .38217 .45436 L .37117 .42229 L p .852 .83 .825 r
F P
0 g
s
.48813 .39563 m .52632 .38458 L .48575 .38697 L closepath p .693 .746 .892 r
F P
0 g
s
.6296 .77453 m .62628 .80557 L .69751 .78226 L p .487 .221 .435 r
F P
0 g
s
.69751 .78226 m .70328 .74992 L .6296 .77453 L p .487 .221 .435 r
F P
0 g
s
.73168 .56606 m .74746 .60236 L .7814 .55532 L p .358 .326 .686 r
F P
0 g
s
.7814 .55532 m .76271 .52151 L .73168 .56606 L p .358 .326 .686 r
F P
0 g
s
.37117 .42229 m .33783 .44312 L .35186 .4815 L p .852 .83 .825 r
F P
0 g
s
.32515 .51181 m .35186 .4815 L .33783 .44312 L p .89 .843 .793 r
F P
0 g
s
.56642 .38253 m .52632 .38458 L .56623 .39135 L closepath p .648 .713 .896 r
F P
0 g
s
.56623 .39135 m .60528 .40272 L .60602 .38529 L p .601 .673 .891 r
F P
0 g
s
.60602 .38529 m .56642 .38253 L .56623 .39135 L p .601 .673 .891 r
F P
0 g
s
.60528 .40272 m .64276 .41854 L .64438 .39295 L p .549 .628 .883 r
F P
0 g
s
.64438 .39295 m .60602 .38529 L .60528 .40272 L p .549 .628 .883 r
F P
0 g
s
.55407 .36702 m .52632 .38458 L .56223 .37411 L closepath p .645 .727 .908 r
F P
0 g
s
.54281 .36208 m .52632 .38458 L .55407 .36702 L closepath p .648 .735 .913 r
F P
0 g
s
.48776 .37822 m .52632 .38458 L .49401 .37036 L closepath p .685 .755 .905 r
F P
0 g
s
.48575 .38697 m .52632 .38458 L .48776 .37822 L closepath p .69 .752 .899 r
F P
0 g
s
.56223 .37411 m .52632 .38458 L .56642 .38253 L closepath p .645 .719 .902 r
F P
0 g
s
.5297 .35986 m .52632 .38458 L .54281 .36208 L closepath p .653 .743 .916 r
F P
0 g
s
.5162 .36061 m .52632 .38458 L .5297 .35986 L closepath p .66 .75 .916 r
F P
0 g
s
.50385 .36425 m .52632 .38458 L .5162 .36061 L closepath p .669 .754 .915 r
F P
0 g
s
.49401 .37036 m .52632 .38458 L .50385 .36425 L closepath p .677 .756 .911 r
F P
0 g
s
.64276 .41854 m .67799 .43861 L .68074 .40551 L p .491 .576 .868 r
F P
0 g
s
.68074 .40551 m .64438 .39295 L .64276 .41854 L p .491 .576 .868 r
F P
0 g
s
.44589 .39409 m .48575 .38697 L .48776 .37822 L p .73 .792 .901 r
F P
0 g
s
.70422 .71472 m .70328 .74992 L .76173 .71294 L p .369 .178 .485 r
F P
0 g
s
.76173 .71294 m .76301 .67667 L .70422 .71472 L p .369 .178 .485 r
F P
0 g
s
.28533 .57995 m .27358 .61652 L .32112 .66013 L p .92 .727 .625 r
F P
0 g
s
.31682 .69724 m .32112 .66013 L .27358 .61652 L p .938 .699 .552 r
F P
0 g
s
.56642 .38253 m .60602 .38529 L .59801 .36851 L p .588 .689 .911 r
F P
0 g
s
.59801 .36851 m .56223 .37411 L .56642 .38253 L p .588 .689 .911 r
F P
0 g
s
.48776 .37822 m .44953 .37674 L .44589 .39409 L p .73 .792 .901 r
F P
0 g
s
.40745 .40589 m .44589 .39409 L .44953 .37674 L p .771 .831 .899 r
F P
0 g
s
.33783 .44312 m .30825 .46817 L .32515 .51181 L p .89 .843 .793 r
F P
0 g
s
.30275 .54481 m .32515 .51181 L .30825 .46817 L p .926 .851 .749 r
F P
0 g
s
.67799 .43861 m .71023 .46269 L .7143 .42293 L p .423 .513 .846 r
F P
0 g
s
.7143 .42293 m .68074 .40551 L .67799 .43861 L p .423 .513 .846 r
F P
0 g
s
.31682 .69724 m .31793 .73293 L .38489 .76394 L p .862 .577 .505 r
F P
0 g
s
.38946 .79554 m .38489 .76394 L .31793 .73293 L p .859 .521 .411 r
F P
0 g
s
.38489 .76394 m .38946 .79554 L .46566 .8124 L p .777 .459 .45 r
F P
0 g
s
.54553 .84154 m .5468 .8158 L .46566 .8124 L p .673 .321 .369 r
F P
0 g
s
.5468 .8158 m .54553 .84154 L .62007 .83212 L p .571 .236 .362 r
F P
0 g
s
.62007 .83212 m .62628 .80557 L .5468 .8158 L p .571 .236 .362 r
F P
0 g
s
.74746 .60236 m .75809 .6395 L .79402 .59124 L p .286 .231 .619 r
F P
0 g
s
.79402 .59124 m .7814 .55532 L .74746 .60236 L p .286 .231 .619 r
F P
0 g
s
.44953 .37674 m .48776 .37822 L .49401 .37036 L p .715 .806 .921 r
F P
0 g
s
.44953 .37674 m .41231 .3803 L .40745 .40589 L p .771 .831 .899 r
F P
0 g
s
.37117 .42229 m .40745 .40589 L .41231 .3803 L p .813 .87 .889 r
F P
0 g
s
.46941 .83841 m .46566 .8124 L .38946 .79554 L p .759 .385 .346 r
F P
0 g
s
.46566 .8124 m .46941 .83841 L .54553 .84154 L p .673 .321 .369 r
F P
0 g
s
.56223 .37411 m .59801 .36851 L .58193 .35427 L p .582 .71 .931 r
F P
0 g
s
.58193 .35427 m .55407 .36702 L .56223 .37411 L p .582 .71 .931 r
F P
0 g
s
.60602 .38529 m .64438 .39295 L .63298 .36808 L p .518 .648 .915 r
F P
0 g
s
.63298 .36808 m .59801 .36851 L .60602 .38529 L p .518 .648 .915 r
F P
0 g
s
.71023 .46269 m .73872 .49046 L .74418 .44509 L p .341 .435 .812 r
F P
0 g
s
.74418 .44509 m .7143 .42293 L .71023 .46269 L p .341 .435 .812 r
F P
0 g
s
.4617 .36099 m .49401 .37036 L .50385 .36425 L p .691 .811 .939 r
F P
0 g
s
.49401 .37036 m .4617 .36099 L .44953 .37674 L p .715 .806 .921 r
F P
0 g
s
.30825 .46817 m .28328 .4971 L .30275 .54481 L p .926 .851 .749 r
F P
0 g
s
.28533 .57995 m .30275 .54481 L .28328 .4971 L p .961 .851 .689 r
F P
0 g
s
.55407 .36702 m .58193 .35427 L .55946 .34428 L p .587 .736 .947 r
F P
0 g
s
.55946 .34428 m .54281 .36208 L .55407 .36702 L p .587 .736 .947 r
F P
0 g
s
.62628 .80557 m .62007 .83212 L .6867 .81069 L p .429 .108 .318 r
F P
0 g
s
.6867 .81069 m .69751 .78226 L .62628 .80557 L p .429 .108 .318 r
F P
0 g
s
.27358 .61652 m .26814 .65374 L .31682 .69724 L p .938 .699 .552 r
F P
0 g
s
.31793 .73293 m .31682 .69724 L .26814 .65374 L p .947 .654 .452 r
F P
0 g
s
.41231 .3803 m .44953 .37674 L .4617 .36099 L p .747 .86 .932 r
F P
0 g
s
.41231 .3803 m .37688 .38904 L .37117 .42229 L p .813 .87 .889 r
F P
0 g
s
.33783 .44312 m .37117 .42229 L .37688 .38904 L p .856 .907 .869 r
F P
0 g
s
.48122 .34868 m .50385 .36425 L .5162 .36061 L p .66 .805 .952 r
F P
0 g
s
.50385 .36425 m .48122 .34868 L .4617 .36099 L p .691 .811 .939 r
F P
0 g
s
.70328 .74992 m .69751 .78226 L .75387 .74729 L p .294 .055 .371 r
F P
0 g
s
.75387 .74729 m .76173 .71294 L .70328 .74992 L p .294 .055 .371 r
F P
0 g
s
.54281 .36208 m .55946 .34428 L .53312 .33977 L p .603 .764 .956 r
F P
0 g
s
.53312 .33977 m .5297 .35986 L .54281 .36208 L p .603 .764 .956 r
F P
0 g
s
.64438 .39295 m .68074 .40551 L .66641 .37306 L p .428 .592 .911 r
F P
0 g
s
.66641 .37306 m .63298 .36808 L .64438 .39295 L p .428 .592 .911 r
F P
0 g
s
.75809 .6395 m .76301 .67667 L .79988 .62849 L p .194 .11 .526 r
F P
0 g
s
.79988 .62849 m .79402 .59124 L .75809 .6395 L p .194 .11 .526 r
F P
0 g
s
.50598 .3413 m .5162 .36061 L .5297 .35986 L p .629 .788 .959 r
F P
0 g
s
.5162 .36061 m .50598 .3413 L .48122 .34868 L p .66 .805 .952 r
F P
0 g
s
.5297 .35986 m .53312 .33977 L .50598 .3413 L p .629 .788 .959 r
F P
0 g
s
.73872 .49046 m .76271 .52151 L .76949 .47176 L p .238 .334 .761 r
F P
0 g
s
.76949 .47176 m .74418 .44509 L .73872 .49046 L p .238 .334 .761 r
F P
0 g
s
.59801 .36851 m .63298 .36808 L .60937 .34681 L p .495 .68 .948 r
F P
0 g
s
.60937 .34681 m .58193 .35427 L .59801 .36851 L p .495 .68 .948 r
F P
0 g
s
.28328 .4971 m .26378 .52947 L .28533 .57995 L p .961 .851 .689 r
F P
0 g
s
.27358 .61652 m .28533 .57995 L .26378 .52947 L p .989 .837 .602 r
F P
0 g
s
.31793 .73293 m .32481 .76619 L .38946 .79554 L p .859 .521 .411 r
F P
0 g
s
.39802 .82289 m .38946 .79554 L .32481 .76619 L p .839 .433 .273 r
F P
0 g
s
.38946 .79554 m .39802 .82289 L .46941 .83841 L p .759 .385 .346 r
F P
0 g
s
.37688 .38904 m .34406 .40303 L .33783 .44312 L p .856 .907 .869 r
F P
0 g
s
.30825 .46817 m .33783 .44312 L .34406 .40303 L p .897 .941 .831 r
F P
0 g
s
.42999 .35687 m .4617 .36099 L .48122 .34868 L p .699 .872 .963 r
F P
0 g
s
.4617 .36099 m .42999 .35687 L .41231 .3803 L p .747 .86 .932 r
F P
0 g
s
.37688 .38904 m .41231 .3803 L .42999 .35687 L p .777 .917 .932 r
F P
0 g
s
.68074 .40551 m .7143 .42293 L .69751 .38366 L p .31 .512 .891 r
F P
0 g
s
.69751 .38366 m .66641 .37306 L .68074 .40551 L p .31 .512 .891 r
F P
0 g
s
.54366 .86149 m .54553 .84154 L .46941 .83841 L p .626 .206 .225 r
F P
0 g
s
.54553 .84154 m .54366 .86149 L .6109 .85311 L p .509 .106 .212 r
F P
0 g
s
.6109 .85311 m .62007 .83212 L .54553 .84154 L p .509 .106 .212 r
F P
0 g
s
.76271 .52151 m .7814 .55532 L .78931 .50257 L p .104 .201 .681 r
F P
0 g
s
.78931 .50257 m .76949 .47176 L .76271 .52151 L p .104 .201 .681 r
F P
0 g
s
.58193 .35427 m .60937 .34681 L .57594 .3318 L p .49 .724 .975 r
F P
0 g
s
.57594 .3318 m .55946 .34428 L .58193 .35427 L p .49 .724 .975 r
F P
0 g
s
.47496 .8587 m .46941 .83841 L .39802 .82289 L p .715 .265 .183 r
F P
0 g
s
.46941 .83841 m .47496 .8587 L .54366 .86149 L p .626 .206 .225 r
F P
0 g
s
.26814 .65374 m .26955 .69066 L .31793 .73293 L p .947 .654 .452 r
F P
0 g
s
.32481 .76619 m .31793 .73293 L .26955 .69066 L p .936 .576 .305 r
F P
0 g
s
.76301 .67667 m .76173 .71294 L .79836 .66614 L p .069 0 .391 r
F P
0 g
s
.79836 .66614 m .79988 .62849 L .76301 .67667 L p .069 0 .391 r
F P
0 g
s
.45888 .33842 m .48122 .34868 L .50598 .3413 L p .633 .859 .985 r
F P
0 g
s
.48122 .34868 m .45888 .33842 L .42999 .35687 L p .699 .872 .963 r
F P
0 g
s
.63298 .36808 m .66641 .37306 L .63579 .34511 L p .367 .624 .952 r
F P
0 g
s
.63579 .34511 m .60937 .34681 L .63298 .36808 L p .367 .624 .952 r
F P
0 g
s
.69751 .78226 m .6867 .81069 L .73919 .7786 L p .18 0 .201 r
F P
0 g
s
.73919 .7786 m .75387 .74729 L .69751 .78226 L p .18 0 .201 r
F P
0 g
s
.34406 .40303 m .31472 .42228 L .30825 .46817 L p .897 .941 .831 r
F P
0 g
s
.28328 .4971 m .30825 .46817 L .31472 .42228 L p .932 .962 .763 r
F P
0 g
s
.26378 .52947 m .25057 .56467 L .27358 .61652 L p .989 .837 .602 r
F P
0 g
s
.26814 .65374 m .27358 .61652 L .25057 .56467 L p .999 .795 .472 r
F P
0 g
s
.62007 .83212 m .6109 .85311 L .67081 .83409 L p .33 0 .135 r
F P
0 g
s
.67081 .83409 m .6867 .81069 L .62007 .83212 L p .33 0 .135 r
F P
0 g
s
.55946 .34428 m .57594 .3318 L .53652 .32499 L p .512 .775 .991 r
F P
0 g
s
.53652 .32499 m .53312 .33977 L .55946 .34428 L p .512 .775 .991 r
F P
0 g
s
.42999 .35687 m .39956 .35835 L .37688 .38904 L p .777 .917 .932 r
F P
0 g
s
.34406 .40303 m .37688 .38904 L .39956 .35835 L p .8 .97 .909 r
F P
0 g
s
.7143 .42293 m .74418 .44509 L .7254 .39998 L p .147 .393 .842 r
F P
0 g
s
.7254 .39998 m .69751 .38366 L .7143 .42293 L p .147 .393 .842 r
F P
0 g
s
.49584 .3273 m .50598 .3413 L .53312 .33977 L p .564 .824 .994 r
F P
0 g
s
.50598 .3413 m .49584 .3273 L .45888 .33842 L p .633 .859 .985 r
F P
0 g
s
.53312 .33977 m .53652 .32499 L .49584 .3273 L p .564 .824 .994 r
F P
0 g
s
.7814 .55532 m .79402 .59124 L .80276 .53698 L p 0 .021 .555 r
F P
0 g
s
.80276 .53698 m .78931 .50257 L .7814 .55532 L p 0 .021 .555 r
F P
0 g
s
.39956 .35835 m .42999 .35687 L .45888 .33842 L p .691 .932 .967 r
F P
0 g
s
.32481 .76619 m .33765 .79593 L .39802 .82289 L p .839 .433 .273 r
F P
0 g
s
.41064 .84491 m .39802 .82289 L .33765 .79593 L p .774 .283 .058 r
F P
0 g
s
.39802 .82289 m .41064 .84491 L .47496 .8587 L p .715 .265 .183 r
F P
0 g
s
.31472 .42228 m .28979 .44664 L .28328 .4971 L p .932 .962 .763 r
F P
0 g
s
.26378 .52947 m .28328 .4971 L .28979 .44664 L p .943 .953 .644 r
F P
0 g
s
.76173 .71294 m .75387 .74729 L .789 .70311 L p 0 0 .191 r
F P
0 g
s
.789 .70311 m .79836 .66614 L .76173 .71294 L p 0 0 .191 r
F P
0 g
s
.60937 .34681 m .63579 .34511 L .59189 .32525 L p .326 .674 .977 r
F P
0 g
s
.59189 .32525 m .57594 .3318 L .60937 .34681 L p .326 .674 .977 r
F P
0 g
s
.26955 .69066 m .27825 .72625 L .32481 .76619 L p .936 .576 .305 r
F P
0 g
s
.33765 .79593 m .32481 .76619 L .27825 .72625 L p .877 .439 .085 r
F P
0 g
s
.66641 .37306 m .69751 .38366 L .66053 .34958 L p .17 .519 .917 r
F P
0 g
s
.66053 .34958 m .63579 .34511 L .66641 .37306 L p .17 .519 .917 r
F P
0 g
s
.25057 .56467 m .24444 .60194 L .26814 .65374 L p .999 .795 .472 r
F P
0 g
s
.26955 .69066 m .26814 .65374 L .24444 .60194 L p .969 .703 .279 r
F P
0 g
s
.74418 .44509 m .76949 .47176 L .74918 .42201 L p 0 .215 .739 r
F P
0 g
s
.74918 .42201 m .7254 .39998 L .74418 .44509 L p 0 .215 .739 r
F P
0 g
s
.39956 .35835 m .37115 .36575 L .34406 .40303 L p .8 .97 .909 r
F P
0 g
s
.31472 .42228 m .34406 .40303 L .37115 .36575 L p .796 .999 .835 r
F P
0 g
s
.5412 .87461 m .54366 .86149 L .47496 .8587 L p .521 .011 0 r
F P
0 g
s
.54366 .86149 m .5412 .87461 L .59881 .86749 L p .384 0 0 r
F P
0 g
s
.59881 .86749 m .6109 .85311 L .54366 .86149 L p .384 0 0 r
F P
0 g
s
.4373 .33401 m .45888 .33842 L .49584 .3273 L p .558 .897 .981 r
F P
0 g
s
.45888 .33842 m .4373 .33401 L .39956 .35835 L p .691 .932 .967 r
F P
0 g
s
.48227 .87223 m .47496 .8587 L .41064 .84491 L p .601 .059 0 r
F P
0 g
s
.47496 .8587 m .48227 .87223 L .5412 .87461 L p .521 .011 0 r
F P
0 g
s
.79402 .59124 m .79988 .62849 L .80901 .57425 L p 0 0 .36 r
F P
0 g
s
.80901 .57425 m .80276 .53698 L .79402 .59124 L p 0 0 .36 r
F P
0 g
s
.6867 .81069 m .67081 .83409 L .71767 .80572 L p .005 0 0 r
F P
0 g
s
.71767 .80572 m .73919 .7786 L .6867 .81069 L p .005 0 0 r
F P
0 g
s
.57594 .3318 m .59189 .32525 L .53981 .31621 L p .338 .741 .982 r
F P
0 g
s
.53981 .31621 m .53652 .32499 L .57594 .3318 L p .338 .741 .982 r
F P
0 g
s
.37115 .36575 m .39956 .35835 L .4373 .33401 L p .634 .96 .91 r
F P
0 g
s
.6109 .85311 m .59881 .86749 L .64991 .85139 L p .153 0 0 r
F P
0 g
s
.64991 .85139 m .67081 .83409 L .6109 .85311 L p .153 0 0 r
F P
0 g
s
.28979 .44664 m .27022 .47584 L .26378 .52947 L p .943 .953 .644 r
F P
0 g
s
.25057 .56467 m .26378 .52947 L .27022 .47584 L p .897 .878 .446 r
F P
0 g
s
.48602 .31927 m .49584 .3273 L .53652 .32499 L p .422 .822 .981 r
F P
0 g
s
.49584 .3273 m .48602 .31927 L .4373 .33401 L p .558 .897 .981 r
F P
0 g
s
.53652 .32499 m .53981 .31621 L .48602 .31927 L p .422 .822 .981 r
F P
0 g
s
.75387 .74729 m .73919 .7786 L .77159 .73821 L p 0 0 0 r
F P
0 g
s
.77159 .73821 m .789 .70311 L .75387 .74729 L p 0 0 0 r
F P
0 g
s
.69751 .38366 m .7254 .39998 L .68287 .36058 L p 0 .325 .792 r
F P
0 g
s
.68287 .36058 m .66053 .34958 L .69751 .38366 L p 0 .325 .792 r
F P
0 g
s
.76949 .47176 m .78931 .50257 L .7679 .44957 L p 0 0 .543 r
F P
0 g
s
.7679 .44957 m .74918 .42201 L .76949 .47176 L p 0 0 .543 r
F P
0 g
s
.24444 .60194 m .24603 .64035 L .26955 .69066 L p .969 .703 .279 r
F P
0 g
s
.27825 .72625 m .26955 .69066 L .24603 .64035 L p .854 .526 .003 r
F P
0 g
s
.37115 .36575 m .34559 .37931 L .31472 .42228 L p .796 .999 .835 r
F P
0 g
s
.28979 .44664 m .31472 .42228 L .34559 .37931 L p .724 .953 .661 r
F P
0 g
s
.33765 .79593 m .35653 .82102 L .41064 .84491 L p .774 .283 .058 r
F P
0 g
s
.42726 .86054 m .41064 .84491 L .35653 .82102 L p .6 .028 0 r
F P
0 g
s
.41064 .84491 m .42726 .86054 L .48227 .87223 L p .601 .059 0 r
F P
0 g
s
.63579 .34511 m .66053 .34958 L .60691 .32523 L p .046 .534 .885 r
F P
0 g
s
.60691 .32523 m .59189 .32525 L .63579 .34511 L p .046 .534 .885 r
F P
0 g
s
.27825 .72625 m .29446 .75935 L .33765 .79593 L p .877 .439 .085 r
F P
0 g
s
.35653 .82102 m .33765 .79593 L .29446 .75935 L p .714 .205 0 r
F P
0 g
s
.79988 .62849 m .79836 .66614 L .80738 .61346 L p 0 0 .082 r
F P
0 g
s
.80738 .61346 m .80901 .57425 L .79988 .62849 L p 0 0 .082 r
F P
0 g
s
.41704 .33599 m .4373 .33401 L .48602 .31927 L p .373 .84 .851 r
F P
0 g
s
.4373 .33401 m .41704 .33599 L .37115 .36575 L p .634 .96 .91 r
F P
0 g
s
.27022 .47584 m .25691 .50941 L .25057 .56467 L p .897 .878 .446 r
F P
0 g
s
.24444 .60194 m .25057 .56467 L .25691 .50941 L p .754 .699 .159 r
F P
0 g
s
.67081 .83409 m .64991 .85139 L .68953 .82748 L p 0 0 0 r
F P
0 g
s
.68953 .82748 m .71767 .80572 L .67081 .83409 L p 0 0 0 r
F P
0 g
s
.34559 .37931 m .37115 .36575 L .41704 .33599 L p .474 .874 .709 r
F P
0 g
s
.53816 .87991 m .5412 .87461 L .48227 .87223 L p .28 0 0 r
F P
0 g
s
.5412 .87461 m .53816 .87991 L .58395 .87428 L p .127 0 0 r
F P
0 g
s
.58395 .87428 m .59881 .86749 L .5412 .87461 L p .127 0 0 r
F P
0 g
s
.78931 .50257 m .80276 .53698 L .78065 .48228 L p .671 .336 0 r
F P
0 g
s
.78065 .48228 m .7679 .44957 L .78931 .50257 L p .671 .336 0 r
F P
0 g
s
.49128 .87803 m .48227 .87223 L .42726 .86054 L p .33 0 0 r
F P
0 g
s
.48227 .87223 m .49128 .87803 L .53816 .87991 L p .28 0 0 r
F P
0 g
s
.59189 .32525 m .60691 .32523 L .54292 .31411 L p .023 .578 .819 r
F P
0 g
s
.54292 .31411 m .53981 .31621 L .59189 .32525 L p .023 .578 .819 r
F P
0 g
s
.24603 .64035 m .25582 .67881 L .27825 .72625 L p .854 .526 .003 r
F P
0 g
s
.29446 .75935 m .27825 .72625 L .25582 .67881 L p 0 0 .323 r
F P
0 g
s
.7254 .39998 m .74918 .42201 L .70201 .37832 L p .481 0 0 r
F P
0 g
s
.70201 .37832 m .68287 .36058 L .7254 .39998 L p .481 0 0 r
F P
0 g
s
.34559 .37931 m .32373 .39911 L .28979 .44664 L p .724 .953 .661 r
F P
0 g
s
.27022 .47584 m .28979 .44664 L .32373 .39911 L p 0 0 0 r
F P
0 g
s
.73919 .7786 m .71767 .80572 L .74618 .77018 L p 0 0 0 r
F P
0 g
s
.74618 .77018 m .77159 .73821 L .73919 .7786 L p 0 0 0 r
F P
0 g
s
.47676 .31789 m .48602 .31927 L .53981 .31621 L p .139 .684 .8 r
F P
0 g
s
.48602 .31927 m .47676 .31789 L .41704 .33599 L p .373 .84 .851 r
F P
0 g
s
.59881 .86749 m .58395 .87428 L .62434 .86157 L p 0 0 0 r
F P
0 g
s
.62434 .86157 m .64991 .85139 L .59881 .86749 L p 0 0 0 r
F P
0 g
s
.79836 .66614 m .789 .70311 L .79741 .65349 L p .77 .754 .239 r
F P
0 g
s
.79741 .65349 m .80738 .61346 L .79836 .66614 L p .77 .754 .239 r
F P
0 g
s
.53981 .31621 m .54292 .31411 L .47676 .31789 L p .139 .684 .8 r
F P
0 g
s
.66053 .34958 m .68287 .36058 L .62052 .33228 L p .334 0 0 r
F P
0 g
s
.62052 .33228 m .60691 .32523 L .66053 .34958 L p .334 0 0 r
F P
0 g
s
.29446 .75935 m .31818 .78875 L .35653 .82102 L p .714 .205 0 r
F P
0 g
s
.35653 .82102 m .38127 .84036 L .42726 .86054 L p .6 .028 0 r
F P
0 g
s
.38127 .84036 m .35653 .82102 L .31818 .78875 L p 0 .115 .586 r
F P
0 g
s
.25691 .50941 m .25072 .54666 L .24444 .60194 L p .754 .699 .159 r
F P
0 g
s
.24603 .64035 m .24444 .60194 L .25072 .54666 L p 0 0 .162 r
F P
0 g
s
.42726 .86054 m .44764 .86879 L .49128 .87803 L p .33 0 0 r
F P
0 g
s
.44764 .86879 m .42726 .86054 L .38127 .84036 L p 0 .323 .675 r
F P
0 g
s
.80276 .53698 m .80901 .57425 L .78658 .5195 L p .887 .591 .081 r
F P
0 g
s
.78658 .5195 m .78065 .48228 L .80276 .53698 L p .887 .591 .081 r
F P
0 g
s
.41704 .33599 m .3987 .3448 L .34559 .37931 L p .474 .874 .709 r
F P
0 g
s
.32373 .39911 m .34559 .37931 L .3987 .3448 L p 0 0 0 r
F P
0 g
s
.3987 .3448 m .41704 .33599 L .47676 .31789 L p 0 0 0 r
F P
0 g
s
.64991 .85139 m .62434 .86157 L .6553 .84282 L p .481 .891 .77 r
F P
0 g
s
.6553 .84282 m .68953 .82748 L .64991 .85139 L p .481 .891 .77 r
F P
0 g
s
.32373 .39911 m .30649 .4251 L .27022 .47584 L p 0 0 0 r
F P
0 g
s
.25691 .50941 m .27022 .47584 L .30649 .4251 L p 0 0 0 r
F P
0 g
s
.25582 .67881 m .27401 .71606 L .29446 .75935 L p 0 0 .323 r
F P
0 g
s
.31818 .78875 m .29446 .75935 L .27401 .71606 L p 0 .045 .609 r
F P
0 g
s
.74918 .42201 m .7679 .44957 L .71715 .40284 L p .763 .273 0 r
F P
0 g
s
.71715 .40284 m .70201 .37832 L .74918 .42201 L p .763 .273 0 r
F P
0 g
s
.789 .70311 m .77159 .73821 L .7789 .69303 L p .891 .915 .516 r
F P
0 g
s
.7789 .69303 m .79741 .65349 L .789 .70311 L p .891 .915 .516 r
F P
0 g
s
.71767 .80572 m .68953 .82748 L .71317 .79774 L p .698 .963 .72 r
F P
0 g
s
.71317 .79774 m .74618 .77018 L .71767 .80572 L p .698 .963 .72 r
F P
0 g
s
.60691 .32523 m .62052 .33228 L .54574 .31931 L p .353 0 0 r
F P
0 g
s
.54574 .31931 m .54292 .31411 L .60691 .32523 L p .353 0 0 r
F P
0 g
s
.5346 .87661 m .53816 .87991 L .49128 .87803 L p .122 .664 .838 r
F P
0 g
s
.53816 .87991 m .5346 .87661 L .5666 .87266 L p .242 .755 .851 r
F P
0 g
s
.5666 .87266 m .58395 .87428 L .53816 .87991 L p .242 .755 .851 r
F P
0 g
s
.25072 .54666 m .25233 .58668 L .24603 .64035 L p 0 0 .162 r
F P
0 g
s
.25582 .67881 m .24603 .64035 L .25233 .58668 L p 0 0 .431 r
F P
0 g
s
.50181 .87529 m .49128 .87803 L .44764 .86879 L p .091 .617 .874 r
F P
0 g
s
.49128 .87803 m .50181 .87529 L .5346 .87661 L p .122 .664 .838 r
F P
0 g
s
.46835 .32372 m .47676 .31789 L .54292 .31411 L p .216 0 0 r
F P
0 g
s
.47676 .31789 m .46835 .32372 L .3987 .3448 L p 0 0 0 r
F P
0 g
s
.68287 .36058 m .70201 .37832 L .63223 .3468 L p .639 .078 0 r
F P
0 g
s
.63223 .3468 m .62052 .33228 L .68287 .36058 L p .639 .078 0 r
F P
0 g
s
.31818 .78875 m .34909 .81326 L .38127 .84036 L p 0 .115 .586 r
F P
0 g
s
.41147 .8529 m .38127 .84036 L .34909 .81326 L p 0 .412 .842 r
F P
0 g
s
.38127 .84036 m .41147 .8529 L .44764 .86879 L p 0 .323 .675 r
F P
0 g
s
.58395 .87428 m .5666 .87266 L .59464 .86379 L p .425 .866 .902 r
F P
0 g
s
.59464 .86379 m .62434 .86157 L .58395 .87428 L p .425 .866 .902 r
F P
0 g
s
.80901 .57425 m .80738 .61346 L .78504 .56031 L p .983 .75 .348 r
F P
0 g
s
.78504 .56031 m .78658 .5195 L .80901 .57425 L p .983 .75 .348 r
F P
0 g
s
.54292 .31411 m .54574 .31931 L .46835 .32372 L p .216 0 0 r
F P
0 g
s
.4714 .86882 m .44764 .86879 L .41147 .8529 L p .145 .604 .928 r
F P
0 g
s
.44764 .86879 m .4714 .86882 L .50181 .87529 L p .091 .617 .874 r
F P
0 g
s
.3987 .3448 m .38295 .36076 L .32373 .39911 L p 0 0 0 r
F P
0 g
s
.30649 .4251 m .32373 .39911 L .38295 .36076 L p .049 0 .003 r
F P
0 g
s
.30649 .4251 m .29472 .45697 L .25691 .50941 L p 0 0 0 r
F P
0 g
s
.25072 .54666 m .25691 .50941 L .29472 .45697 L p 0 0 .257 r
F P
0 g
s
.27401 .71606 m .3005 .75077 L .31818 .78875 L p 0 .045 .609 r
F P
0 g
s
.34909 .81326 m .31818 .78875 L .3005 .75077 L p 0 .298 .794 r
F P
0 g
s
.77159 .73821 m .74618 .77018 L .75203 .73066 L p .919 .975 .705 r
F P
0 g
s
.75203 .73066 m .7789 .69303 L .77159 .73821 L p .919 .975 .705 r
F P
0 g
s
.7679 .44957 m .78065 .48228 L .7275 .43391 L p .901 .484 .149 r
F P
0 g
s
.7275 .43391 m .71715 .40284 L .7679 .44957 L p .901 .484 .149 r
F P
0 g
s
.38295 .36076 m .3987 .3448 L .46835 .32372 L p .216 0 0 r
F P
0 g
s
.68953 .82748 m .6553 .84282 L .67334 .81966 L p .747 .991 .882 r
F P
0 g
s
.67334 .81966 m .71317 .79774 L .68953 .82748 L p .747 .991 .882 r
F P
0 g
s
.25233 .58668 m .26221 .6283 L .25582 .67881 L p 0 0 .431 r
F P
0 g
s
.27401 .71606 m .25582 .67881 L .26221 .6283 L p 0 .091 .617 r
F P
0 g
s
.62434 .86157 m .59464 .86379 L .61585 .8508 L p .61 .941 .946 r
F P
0 g
s
.61585 .8508 m .6553 .84282 L .62434 .86157 L p .61 .941 .946 r
F P
0 g
s
.80738 .61346 m .79741 .65349 L .77557 .60354 L p .999 .829 .533 r
F P
0 g
s
.77557 .60354 m .78504 .56031 L .80738 .61346 L p .999 .829 .533 r
F P
0 g
s
.62052 .33228 m .63223 .3468 L .54817 .33232 L p .589 .061 0 r
F P
0 g
s
.54817 .33232 m .54574 .31931 L .62052 .33228 L p .589 .061 0 r
F P
0 g
s
.70201 .37832 m .71715 .40284 L .64153 .369 L p .783 .31 .11 r
F P
0 g
s
.64153 .369 m .63223 .3468 L .70201 .37832 L p .783 .31 .11 r
F P
0 g
s
.34909 .81326 m .38655 .83172 L .41147 .8529 L p 0 .412 .842 r
F P
0 g
s
.44642 .85777 m .41147 .8529 L .38655 .83172 L p .252 .602 .952 r
F P
0 g
s
.41147 .8529 m .44642 .85777 L .4714 .86882 L p .145 .604 .928 r
F P
0 g
s
.29472 .45697 m .28923 .49413 L .25072 .54666 L p 0 0 .257 r
F P
0 g
s
.25233 .58668 m .25072 .54666 L .28923 .49413 L p .107 .008 .448 r
F P
0 g
s
.53062 .86414 m .5346 .87661 L .50181 .87529 L p .44 .803 .996 r
F P
0 g
s
.5346 .87661 m .53062 .86414 L .54719 .86208 L p .497 .843 .996 r
F P
0 g
s
.54719 .86208 m .5666 .87266 L .5346 .87661 L p .497 .843 .996 r
F P
0 g
s
.74618 .77018 m .71317 .79774 L .71738 .76491 L p .894 .975 .818 r
F P
0 g
s
.71738 .76491 m .75203 .73066 L .74618 .77018 L p .894 .975 .818 r
F P
0 g
s
.3005 .75077 m .33478 .78158 L .34909 .81326 L p 0 .298 .794 r
F P
0 g
s
.38655 .83172 m .34909 .81326 L .33478 .78158 L p .198 .477 .892 r
F P
0 g
s
.46111 .33725 m .46835 .32372 L .54574 .31931 L p .452 0 0 r
F P
0 g
s
.46835 .32372 m .46111 .33725 L .38295 .36076 L p .216 0 0 r
F P
0 g
s
.5136 .86345 m .50181 .87529 L .4714 .86882 L p .414 .764 .995 r
F P
0 g
s
.50181 .87529 m .5136 .86345 L .53062 .86414 L p .44 .803 .996 r
F P
0 g
s
.38295 .36076 m .37047 .384 L .30649 .4251 L p .049 0 .003 r
F P
0 g
s
.29472 .45697 m .30649 .4251 L .37047 .384 L p .224 0 .253 r
F P
0 g
s
.78065 .48228 m .78658 .5195 L .73233 .471 L p .943 .607 .359 r
F P
0 g
s
.73233 .471 m .7275 .43391 L .78065 .48228 L p .943 .607 .359 r
F P
0 g
s
.26221 .6283 m .2805 .67017 L .27401 .71606 L p 0 .091 .617 r
F P
0 g
s
.3005 .75077 m .27401 .71606 L .2805 .67017 L p .139 .27 .738 r
F P
0 g
s
.5666 .87266 m .54719 .86208 L .56161 .85746 L p .572 .876 .994 r
F P
0 g
s
.56161 .85746 m .59464 .86379 L .5666 .87266 L p .572 .876 .994 r
F P
0 g
s
.54574 .31931 m .54817 .33232 L .46111 .33725 L p .452 0 0 r
F P
0 g
s
.6553 .84282 m .61585 .8508 L .62786 .8349 L p .735 .948 .949 r
F P
0 g
s
.62786 .8349 m .67334 .81966 L .6553 .84282 L p .735 .948 .949 r
F P
0 g
s
.4979 .86008 m .4714 .86882 L .44642 .85777 L p .419 .731 .99 r
F P
0 g
s
.4714 .86882 m .4979 .86008 L .5136 .86345 L p .414 .764 .995 r
F P
0 g
s
.79741 .65349 m .7789 .69303 L .75806 .64774 L p .978 .863 .656 r
F P
0 g
s
.75806 .64774 m .77557 .60354 L .79741 .65349 L p .978 .863 .656 r
F P
0 g
s
.37047 .384 m .38295 .36076 L .46111 .33725 L p .383 0 .175 r
F P
0 g
s
.59464 .86379 m .56161 .85746 L .57236 .85075 L p .644 .89 .985 r
F P
0 g
s
.57236 .85075 m .61585 .8508 L .59464 .86379 L p .644 .89 .985 r
F P
0 g
s
.71317 .79774 m .67334 .81966 L .67593 .79435 L p .846 .947 .884 r
F P
0 g
s
.67593 .79435 m .71738 .76491 L .71317 .79774 L p .846 .947 .884 r
F P
0 g
s
.28923 .49413 m .29066 .5357 L .25233 .58668 L p .107 .008 .448 r
F P
0 g
s
.26221 .6283 m .25233 .58668 L .29066 .5357 L p .229 .167 .577 r
F P
0 g
s
.33478 .78158 m .37597 .80717 L .38655 .83172 L p .198 .477 .892 r
F P
0 g
s
.42954 .84315 m .38655 .83172 L .37597 .80717 L p .364 .6 .938 r
F P
0 g
s
.38655 .83172 m .42954 .84315 L .44642 .85777 L p .252 .602 .952 r
F P
0 g
s
.2805 .67017 m .307 .71076 L .3005 .75077 L p .139 .27 .738 r
F P
0 g
s
.33478 .78158 m .3005 .75077 L .307 .71076 L p .271 .406 .816 r
F P
0 g
s
.48513 .85435 m .44642 .85777 L .42954 .84315 L p .448 .705 .977 r
F P
0 g
s
.44642 .85777 m .48513 .85435 L .4979 .86008 L p .419 .731 .99 r
F P
0 g
s
.71715 .40284 m .7275 .43391 L .64789 .3988 L p .835 .447 .315 r
F P
0 g
s
.64789 .3988 m .64153 .369 L .71715 .40284 L p .835 .447 .315 r
F P
0 g
s
.63223 .3468 m .64153 .369 L .55011 .35342 L p .692 .257 .212 r
F P
0 g
s
.55011 .35342 m .54817 .33232 L .63223 .3468 L p .692 .257 .212 r
F P
0 g
s
.78658 .5195 m .78504 .56031 L .73107 .51325 L p .944 .676 .499 r
F P
0 g
s
.73107 .51325 m .73233 .471 L .78658 .5195 L p .944 .676 .499 r
F P
0 g
s
.37047 .384 m .36193 .41437 L .29472 .45697 L p .224 0 .253 r
F P
0 g
s
.28923 .49413 m .29472 .45697 L .36193 .41437 L p .334 .109 .415 r
F P
0 g
s
.7789 .69303 m .75203 .73066 L .73277 .69129 L p .941 .874 .741 r
F P
0 g
s
.73277 .69129 m .75806 .64774 L .7789 .69303 L p .941 .874 .741 r
F P
0 g
s
.61585 .8508 m .57236 .85075 L .57824 .84262 L p .698 .883 .966 r
F P
0 g
s
.57824 .84262 m .62786 .8349 L .61585 .8508 L p .698 .883 .966 r
F P
0 g
s
.45535 .35872 m .46111 .33725 L .54817 .33232 L p .567 .16 .229 r
F P
0 g
s
.46111 .33725 m .45535 .35872 L .37047 .384 L p .383 0 .175 r
F P
0 g
s
.52632 .84233 m .53062 .86414 L .5136 .86345 L closepath p .589 .796 .979 r
F P
0 g
s
.52632 .84233 m .54719 .86208 L .53062 .86414 L closepath p .603 .806 .978 r
F P
0 g
s
.67334 .81966 m .62786 .8349 L .62908 .81769 L p .79 .906 .922 r
F P
0 g
s
.62908 .81769 m .67593 .79435 L .67334 .81966 L p .79 .906 .922 r
F P
0 g
s
.52632 .84233 m .5136 .86345 L .4979 .86008 L closepath p .58 .784 .976 r
F P
0 g
s
.54817 .33232 m .55011 .35342 L .45535 .35872 L p .567 .16 .229 r
F P
0 g
s
.307 .71076 m .34104 .74847 L .33478 .78158 L p .271 .406 .816 r
F P
0 g
s
.37597 .80717 m .33478 .78158 L .34104 .74847 L p .374 .513 .868 r
F P
0 g
s
.29066 .5357 m .29941 .58044 L .26221 .6283 L p .229 .167 .577 r
F P
0 g
s
.2805 .67017 m .26221 .6283 L .29941 .58044 L p .319 .289 .668 r
F P
0 g
s
.52632 .84233 m .56161 .85746 L .54719 .86208 L closepath p .62 .813 .974 r
F P
0 g
s
.52632 .84233 m .4979 .86008 L .48513 .85435 L closepath p .576 .772 .972 r
F P
0 g
s
.37597 .80717 m .42276 .82639 L .42954 .84315 L p .364 .6 .938 r
F P
0 g
s
.47668 .84683 m .42954 .84315 L .42276 .82639 L p .489 .687 .955 r
F P
0 g
s
.42954 .84315 m .47668 .84683 L .48513 .85435 L p .448 .705 .977 r
F P
0 g
s
.36193 .41437 m .37047 .384 L .45535 .35872 L p .475 .16 .351 r
F P
0 g
s
.52632 .84233 m .57236 .85075 L .56161 .85746 L closepath p .637 .815 .968 r
F P
0 g
s
.75203 .73066 m .71738 .76491 L .70037 .73246 L p .898 .872 .803 r
F P
0 g
s
.70037 .73246 m .73277 .69129 L .75203 .73066 L p .898 .872 .803 r
F P
0 g
s
.78504 .56031 m .77557 .60354 L .72338 .55941 L p .929 .718 .596 r
F P
0 g
s
.72338 .55941 m .73107 .51325 L .78504 .56031 L p .929 .718 .596 r
F P
0 g
s
.52632 .84233 m .48513 .85435 L .47668 .84683 L closepath p .579 .761 .965 r
F P
0 g
s
.7275 .43391 m .73233 .471 L .65087 .43578 L p .849 .53 .448 r
F P
0 g
s
.65087 .43578 m .64789 .3988 L .7275 .43391 L p .849 .53 .448 r
F P
0 g
s
.36193 .41437 m .35794 .45141 L .28923 .49413 L p .334 .109 .415 r
F P
0 g
s
.29066 .5357 m .28923 .49413 L .35794 .45141 L p .407 .229 .525 r
F P
0 g
s
.62786 .8349 m .57824 .84262 L .57856 .83392 L p .728 .859 .943 r
F P
0 g
s
.57856 .83392 m .62908 .81769 L .62786 .8349 L p .728 .859 .943 r
F P
0 g
s
.34104 .74847 m .38158 .78176 L .37597 .80717 L p .374 .513 .868 r
F P
0 g
s
.42276 .82639 m .37597 .80717 L .38158 .78176 L p .459 .6 .905 r
F P
0 g
s
.52632 .84233 m .57824 .84262 L .57236 .85075 L closepath p .652 .813 .961 r
F P
0 g
s
.29941 .58044 m .31556 .62686 L .2805 .67017 L p .319 .289 .668 r
F P
0 g
s
.307 .71076 m .2805 .67017 L .31556 .62686 L p .387 .385 .735 r
F P
0 g
s
.64153 .369 m .64789 .3988 L .55143 .38262 L p .735 .376 .372 r
F P
0 g
s
.55143 .38262 m .55011 .35342 L .64153 .369 L p .735 .376 .372 r
F P
0 g
s
.42276 .82639 m .47351 .8383 L .47668 .84683 L p .489 .687 .955 r
F P
0 g
s
.52632 .84233 m .47668 .84683 L .47351 .8383 L closepath p .586 .751 .956 r
F P
0 g
s
.71738 .76491 m .67593 .79435 L .66197 .76956 L p .85 .862 .85 r
F P
0 g
s
.66197 .76956 m .70037 .73246 L .71738 .76491 L p .85 .862 .85 r
F P
0 g
s
.38158 .78176 m .42717 .80921 L .42276 .82639 L p .459 .6 .905 r
F P
0 g
s
.47351 .8383 m .42276 .82639 L .42717 .80921 L p .532 .676 .93 r
F P
0 g
s
.52632 .84233 m .57856 .83392 L .57824 .84262 L closepath p .663 .806 .952 r
F P
0 g
s
.77557 .60354 m .75806 .64774 L .70919 .60789 L p .907 .745 .669 r
F P
0 g
s
.70919 .60789 m .72338 .55941 L .77557 .60354 L p .907 .745 .669 r
F P
0 g
s
.45141 .38813 m .45535 .35872 L .55011 .35342 L p .623 .287 .381 r
F P
0 g
s
.45535 .35872 m .45141 .38813 L .36193 .41437 L p .475 .16 .351 r
F P
0 g
s
.67593 .79435 m .62908 .81769 L .619 .80103 L p .798 .847 .888 r
F P
0 g
s
.619 .80103 m .66197 .76956 L .67593 .79435 L p .798 .847 .888 r
F P
0 g
s
.31556 .62686 m .33883 .67322 L .307 .71076 L p .387 .385 .735 r
F P
0 g
s
.34104 .74847 m .307 .71076 L .33883 .67322 L p .443 .466 .789 r
F P
0 g
s
.42717 .80921 m .47606 .82967 L .47351 .8383 L p .532 .676 .93 r
F P
0 g
s
.52632 .84233 m .47351 .8383 L .47606 .82967 L closepath p .597 .745 .947 r
F P
0 g
s
.35794 .45141 m .36193 .41437 L .45141 .38813 L p .529 .27 .466 r
F P
0 g
s
.55011 .35342 m .55143 .38262 L .45141 .38813 L p .623 .287 .381 r
F P
0 g
s
.52632 .84233 m .56256 .81857 L .57317 .82559 L closepath p .67 .785 .935 r
F P
0 g
s
.52632 .84233 m .54788 .81367 L .56256 .81857 L closepath p .667 .774 .93 r
F P
0 g
s
.52632 .84233 m .53074 .81146 L .54788 .81367 L closepath p .659 .763 .926 r
F P
0 g
s
.52632 .84233 m .51309 .8122 L .53074 .81146 L closepath p .649 .753 .925 r
F P
0 g
s
.52632 .84233 m .49696 .81582 L .51309 .8122 L closepath p .637 .747 .928 r
F P
0 g
s
.52632 .84233 m .48415 .82188 L .49696 .81582 L closepath p .624 .743 .932 r
F P
0 g
s
.52632 .84233 m .47606 .82967 L .48415 .82188 L closepath p .61 .742 .939 r
F P
0 g
s
.52632 .84233 m .57317 .82559 L .57856 .83392 L closepath p .669 .797 .943 r
F P
0 g
s
.35794 .45141 m .35898 .49424 L .29066 .5357 L p .407 .229 .525 r
F P
0 g
s
.29941 .58044 m .29066 .5357 L .35898 .49424 L p .458 .32 .605 r
F P
0 g
s
.62908 .81769 m .57856 .83392 L .57317 .82559 L p .739 .826 .918 r
F P
0 g
s
.57317 .82559 m .619 .80103 L .62908 .81769 L p .739 .826 .918 r
F P
0 g
s
.73233 .471 m .73107 .51325 L .65009 .47908 L p .848 .585 .54 r
F P
0 g
s
.65009 .47908 m .65087 .43578 L .73233 .471 L p .848 .585 .54 r
F P
0 g
s
.33883 .67322 m .36853 .71766 L .34104 .74847 L p .443 .466 .789 r
F P
0 g
s
.38158 .78176 m .34104 .74847 L .36853 .71766 L p .491 .539 .833 r
F P
0 g
s
.44268 .79354 m .48415 .82188 L .47606 .82967 L p .573 .674 .908 r
F P
0 g
s
.47606 .82967 m .42717 .80921 L .44268 .79354 L p .573 .674 .908 r
F P
0 g
s
.75806 .64774 m .73277 .69129 L .68879 .65685 L p .882 .763 .726 r
F P
0 g
s
.68879 .65685 m .70919 .60789 L .75806 .64774 L p .882 .763 .726 r
F P
0 g
s
.36853 .71766 m .40361 .75833 L .38158 .78176 L p .491 .539 .833 r
F P
0 g
s
.42717 .80921 m .38158 .78176 L .40361 .75833 L p .533 .607 .872 r
F P
0 g
s
.40361 .75833 m .44268 .79354 L .42717 .80921 L p .533 .607 .872 r
F P
0 g
s
.64789 .3988 m .65087 .43578 L .55205 .41952 L p .752 .453 .477 r
F P
0 g
s
.55205 .41952 m .55143 .38262 L .64789 .3988 L p .752 .453 .477 r
F P
0 g
s
.619 .80103 m .57317 .82559 L .56256 .81857 L p .734 .791 .898 r
F P
0 g
s
.46784 .78124 m .49696 .81582 L .48415 .82188 L p .61 .678 .89 r
F P
0 g
s
.48415 .82188 m .44268 .79354 L .46784 .78124 L p .61 .678 .89 r
F P
0 g
s
.35898 .49424 m .36534 .5416 L .29941 .58044 L p .458 .32 .605 r
F P
0 g
s
.31556 .62686 m .29941 .58044 L .36534 .5416 L p .496 .392 .667 r
F P
0 g
s
.73277 .69129 m .70037 .73246 L .66282 .70429 L p .853 .776 .775 r
F P
0 g
s
.66282 .70429 m .68879 .65685 L .73277 .69129 L p .853 .776 .775 r
F P
0 g
s
.56256 .81857 m .59838 .78683 L .619 .80103 L p .734 .791 .898 r
F P
0 g
s
.59838 .78683 m .56256 .81857 L .54788 .81367 L p .72 .759 .883 r
F P
0 g
s
.66197 .76956 m .619 .80103 L .59838 .78683 L p .782 .79 .859 r
F P
0 g
s
.45141 .38813 m .44957 .42506 L .35794 .45141 L p .529 .27 .466 r
F P
0 g
s
.35898 .49424 m .35794 .45141 L .44957 .42506 L p .564 .349 .548 r
F P
0 g
s
.44957 .42506 m .45141 .38813 L .55143 .38262 L p .653 .372 .481 r
F P
0 g
s
.73107 .51325 m .72338 .55941 L .64535 .52742 L p .841 .624 .608 r
F P
0 g
s
.64535 .52742 m .65009 .47908 L .73107 .51325 L p .841 .624 .608 r
F P
0 g
s
.49991 .77384 m .51309 .8122 L .49696 .81582 L p .644 .69 .878 r
F P
0 g
s
.49696 .81582 m .46784 .78124 L .49991 .77384 L p .644 .69 .878 r
F P
0 g
s
.70037 .73246 m .66197 .76956 L .63227 .74823 L p .821 .785 .818 r
F P
0 g
s
.63227 .74823 m .66282 .70429 L .70037 .73246 L p .821 .785 .818 r
F P
0 g
s
.59838 .78683 m .63227 .74823 L .66197 .76956 L p .782 .79 .859 r
F P
0 g
s
.54788 .81367 m .56933 .77683 L .59838 .78683 L p .72 .759 .883 r
F P
0 g
s
.56933 .77683 m .54788 .81367 L .53074 .81146 L p .699 .73 .875 r
F P
0 g
s
.55143 .38262 m .55205 .41952 L .44957 .42506 L p .653 .372 .481 r
F P
0 g
s
.53515 .7723 m .53074 .81146 L .51309 .8122 L p .674 .707 .873 r
F P
0 g
s
.51309 .8122 m .49991 .77384 L .53515 .7723 L p .674 .707 .873 r
F P
0 g
s
.53074 .81146 m .53515 .7723 L .56933 .77683 L p .699 .73 .875 r
F P
0 g
s
.44018 .73977 m .46784 .78124 L .44268 .79354 L p .593 .62 .848 r
F P
0 g
s
.44268 .79354 m .40361 .75833 L .44018 .73977 L p .593 .62 .848 r
F P
0 g
s
.36534 .5416 m .37704 .59185 L .31556 .62686 L p .496 .392 .667 r
F P
0 g
s
.33883 .67322 m .31556 .62686 L .37704 .59185 L p .526 .454 .718 r
F P
0 g
s
.65087 .43578 m .65009 .47908 L .55189 .46331 L p .759 .507 .552 r
F P
0 g
s
.55189 .46331 m .55205 .41952 L .65087 .43578 L p .759 .507 .552 r
F P
0 g
s
.63227 .74823 m .59838 .78683 L .56933 .77683 L p .756 .741 .839 r
F P
0 g
s
.41517 .69305 m .44018 .73977 L .40361 .75833 L p .573 .565 .806 r
F P
0 g
s
.40361 .75833 m .36853 .71766 L .41517 .69305 L p .573 .565 .806 r
F P
0 g
s
.37704 .59185 m .39384 .64304 L .33883 .67322 L p .526 .454 .718 r
F P
0 g
s
.36853 .71766 m .33883 .67322 L .39384 .64304 L p .551 .511 .764 r
F P
0 g
s
.72338 .55941 m .70919 .60789 L .63663 .57909 L p .83 .654 .664 r
F P
0 g
s
.63663 .57909 m .64535 .52742 L .72338 .55941 L p .83 .654 .664 r
F P
0 g
s
.39384 .64304 m .41517 .69305 L .36853 .71766 L p .551 .511 .764 r
F P
0 g
s
.44957 .42506 m .45005 .46868 L .35898 .49424 L p .564 .349 .548 r
F P
0 g
s
.36534 .5416 m .35898 .49424 L .45005 .46868 L p .588 .411 .61 r
F P
0 g
s
.48733 .72853 m .49991 .77384 L .46784 .78124 L p .642 .64 .832 r
F P
0 g
s
.46784 .78124 m .44018 .73977 L .48733 .72853 L p .642 .64 .832 r
F P
0 g
s
.45005 .46868 m .44957 .42506 L .55205 .41952 L p .67 .434 .554 r
F P
0 g
s
.56933 .77683 m .58976 .73309 L .63227 .74823 L p .756 .741 .839 r
F P
0 g
s
.58976 .73309 m .56933 .77683 L .53515 .7723 L p .723 .7 .828 r
F P
0 g
s
.66282 .70429 m .63227 .74823 L .58976 .73309 L p .781 .722 .797 r
F P
0 g
s
.70919 .60789 m .68879 .65685 L .62413 .63208 L p .817 .679 .712 r
F P
0 g
s
.62413 .63208 m .63663 .57909 L .70919 .60789 L p .817 .679 .712 r
F P
0 g
s
.55205 .41952 m .55189 .46331 L .45005 .46868 L p .67 .434 .554 r
F P
0 g
s
.53937 .7262 m .53515 .7723 L .49991 .77384 L p .685 .666 .826 r
F P
0 g
s
.49991 .77384 m .48733 .72853 L .53937 .7262 L p .685 .666 .826 r
F P
0 g
s
.53515 .7723 m .53937 .7262 L .58976 .73309 L p .723 .7 .828 r
F P
0 g
s
.68879 .65685 m .66282 .70429 L .6083 .68415 L p .801 .701 .755 r
F P
0 g
s
.58976 .73309 m .6083 .68415 L .66282 .70429 L p .781 .722 .797 r
F P
0 g
s
.6083 .68415 m .62413 .63208 L .68879 .65685 L p .801 .701 .755 r
F P
0 g
s
.65009 .47908 m .64535 .52742 L .5509 .51267 L p .761 .549 .611 r
F P
0 g
s
.5509 .51267 m .55189 .46331 L .65009 .47908 L p .761 .549 .611 r
F P
0 g
s
.45005 .46868 m .45298 .51769 L .36534 .5416 L p .588 .411 .61 r
F P
0 g
s
.37704 .59185 m .36534 .5416 L .45298 .51769 L p .605 .463 .662 r
F P
0 g
s
.4759 .67807 m .48733 .72853 L .44018 .73977 L p .637 .595 .79 r
F P
0 g
s
.44018 .73977 m .41517 .69305 L .4759 .67807 L p .637 .595 .79 r
F P
0 g
s
.45298 .51769 m .45005 .46868 L .55189 .46331 L p .681 .482 .611 r
F P
0 g
s
.6083 .68415 m .58976 .73309 L .53937 .7262 L p .738 .671 .785 r
F P
0 g
s
.45298 .51769 m .45839 .57035 L .37704 .59185 L p .605 .463 .662 r
F P
0 g
s
.39384 .64304 m .37704 .59185 L .45839 .57035 L p .618 .509 .707 r
F P
0 g
s
.46612 .62458 m .4759 .67807 L .41517 .69305 L p .629 .552 .749 r
F P
0 g
s
.41517 .69305 m .39384 .64304 L .46612 .62458 L p .629 .552 .749 r
F P
0 g
s
.45839 .57035 m .46612 .62458 L .39384 .64304 L p .618 .509 .707 r
F P
0 g
s
.64535 .52742 m .63663 .57909 L .54909 .56585 L p .759 .584 .66 r
F P
0 g
s
.54909 .56585 m .5509 .51267 L .64535 .52742 L p .759 .584 .66 r
F P
0 g
s
.55189 .46331 m .5509 .51267 L .45298 .51769 L p .681 .482 .611 r
F P
0 g
s
.5432 .67495 m .53937 .7262 L .48733 .72853 L p .69 .629 .783 r
F P
0 g
s
.48733 .72853 m .4759 .67807 L .5432 .67495 L p .69 .629 .783 r
F P
0 g
s
.53937 .7262 m .5432 .67495 L .6083 .68415 L p .738 .671 .785 r
F P
0 g
s
.62413 .63208 m .6083 .68415 L .5432 .67495 L p .748 .643 .744 r
F P
0 g
s
.63663 .57909 m .62413 .63208 L .54649 .62071 L p .754 .614 .703 r
F P
0 g
s
.54649 .62071 m .54909 .56585 L .63663 .57909 L p .754 .614 .703 r
F P
0 g
s
.45839 .57035 m .45298 .51769 L .5509 .51267 L p .687 .523 .659 r
F P
0 g
s
.5432 .67495 m .54649 .62071 L .62413 .63208 L p .748 .643 .744 r
F P
0 g
s
.54649 .62071 m .5432 .67495 L .4759 .67807 L p .692 .594 .742 r
F P
0 g
s
.4759 .67807 m .46612 .62458 L .54649 .62071 L p .692 .594 .742 r
F P
0 g
s
.5509 .51267 m .54909 .56585 L .45839 .57035 L p .687 .523 .659 r
F P
0 g
s
.46612 .62458 m .45839 .57035 L .54909 .56585 L p .691 .56 .702 r
F P
0 g
s
.54909 .56585 m .54649 .62071 L .46612 .62458 L p .691 .56 .702 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48699 .50871 m .47964 .55076 L .54208 .55385 L p .717 .609 .734 r
F P
0 g
s
.54208 .55385 m .5396 .51139 L .48699 .50871 L p .717 .609 .734 r
F P
0 g
s
.54413 .59636 m .54208 .55385 L .47964 .55076 L p .72 .584 .703 r
F P
0 g
s
.5396 .51139 m .54208 .55385 L .60316 .54455 L p .673 .574 .736 r
F P
0 g
s
.54208 .55385 m .54413 .59636 L .61318 .5861 L p .668 .544 .705 r
F P
0 g
s
.61318 .5861 m .60316 .54455 L .54208 .55385 L p .668 .544 .705 r
F P
0 g
s
.47964 .55076 m .47357 .59294 L .54413 .59636 L p .72 .584 .703 r
F P
0 g
s
.5457 .63801 m .54413 .59636 L .47357 .59294 L p .72 .559 .67 r
F P
0 g
s
.54413 .59636 m .5457 .63801 L .62091 .62712 L p .662 .513 .671 r
F P
0 g
s
.62091 .62712 m .61318 .5861 L .54413 .59636 L p .662 .513 .671 r
F P
0 g
s
.43796 .49552 m .42129 .53546 L .47964 .55076 L p .76 .649 .74 r
F P
0 g
s
.47964 .55076 m .48699 .50871 L .43796 .49552 L p .76 .649 .74 r
F P
0 g
s
.47357 .59294 m .47964 .55076 L .42129 .53546 L p .768 .63 .708 r
F P
0 g
s
.42129 .53546 m .4075 .57607 L .47357 .59294 L p .768 .63 .708 r
F P
0 g
s
.4689 .63438 m .47357 .59294 L .4075 .57607 L p .775 .609 .674 r
F P
0 g
s
.47357 .59294 m .4689 .63438 L .5457 .63801 L p .72 .559 .67 r
F P
0 g
s
.49551 .46773 m .48699 .50871 L .5396 .51139 L p .714 .633 .766 r
F P
0 g
s
.5396 .51139 m .53673 .46987 L .49551 .46773 L p .714 .633 .766 r
F P
0 g
s
.53673 .46987 m .5396 .51139 L .59101 .50336 L p .676 .604 .768 r
F P
0 g
s
.60316 .54455 m .59101 .50336 L .5396 .51139 L p .673 .574 .736 r
F P
0 g
s
.54678 .67796 m .5457 .63801 L .4689 .63438 L p .719 .531 .634 r
F P
0 g
s
.5457 .63801 m .54678 .67796 L .62621 .66675 L p .655 .48 .635 r
F P
0 g
s
.62621 .66675 m .62091 .62712 L .5457 .63801 L p .655 .48 .635 r
F P
0 g
s
.45721 .45717 m .43796 .49552 L .48699 .50871 L p .749 .668 .771 r
F P
0 g
s
.48699 .50871 m .49551 .46773 L .45721 .45717 L p .749 .668 .771 r
F P
0 g
s
.59101 .50336 m .60316 .54455 L .65741 .52347 L p .623 .544 .745 r
F P
0 g
s
.60316 .54455 m .61318 .5861 L .67476 .56282 L p .61 .507 .712 r
F P
0 g
s
.67476 .56282 m .65741 .52347 L .60316 .54455 L p .61 .507 .712 r
F P
0 g
s
.4075 .57607 m .39686 .61646 L .4689 .63438 L p .775 .609 .674 r
F P
0 g
s
.4657 .67423 m .4689 .63438 L .39686 .61646 L p .78 .585 .636 r
F P
0 g
s
.4689 .63438 m .4657 .67423 L .54678 .67796 L p .719 .531 .634 r
F P
0 g
s
.61318 .5861 m .62091 .62712 L .68817 .60236 L p .595 .468 .677 r
F P
0 g
s
.68817 .60236 m .67476 .56282 L .61318 .5861 L p .595 .468 .677 r
F P
0 g
s
.59101 .50336 m .57697 .46344 L .53673 .46987 L p .676 .604 .768 r
F P
0 g
s
.57697 .46344 m .59101 .50336 L .63648 .48522 L p .634 .581 .777 r
F P
0 g
s
.65741 .52347 m .63648 .48522 L .59101 .50336 L p .623 .544 .745 r
F P
0 g
s
.50503 .42877 m .49551 .46773 L .53673 .46987 L p .707 .658 .798 r
F P
0 g
s
.53673 .46987 m .53351 .43028 L .50503 .42877 L p .707 .658 .798 r
F P
0 g
s
.53351 .43028 m .53673 .46987 L .57697 .46344 L p .678 .635 .8 r
F P
0 g
s
.47866 .42133 m .45721 .45717 L .49551 .46773 L p .734 .685 .803 r
F P
0 g
s
.49551 .46773 m .50503 .42877 L .47866 .42133 L p .734 .685 .803 r
F P
0 g
s
.54735 .71542 m .54678 .67796 L .4657 .67423 L p .716 .499 .594 r
F P
0 g
s
.54678 .67796 m .54735 .71542 L .62899 .70418 L p .645 .442 .593 r
F P
0 g
s
.62899 .70418 m .62621 .66675 L .54678 .67796 L p .645 .442 .593 r
F P
0 g
s
.62091 .62712 m .62621 .66675 L .69739 .64122 L p .579 .426 .638 r
F P
0 g
s
.69739 .64122 m .68817 .60236 L .62091 .62712 L p .579 .426 .638 r
F P
0 g
s
.39715 .47282 m .37239 .50903 L .42129 .53546 L p .8 .698 .753 r
F P
0 g
s
.42129 .53546 m .43796 .49552 L .39715 .47282 L p .8 .698 .753 r
F P
0 g
s
.4075 .57607 m .42129 .53546 L .37239 .50903 L p .817 .685 .719 r
F P
0 g
s
.42557 .43908 m .39715 .47282 L .43796 .49552 L p .781 .709 .784 r
F P
0 g
s
.43796 .49552 m .45721 .45717 L .42557 .43908 L p .781 .709 .784 r
F P
0 g
s
.37239 .50903 m .35184 .54681 L .4075 .57607 L p .817 .685 .719 r
F P
0 g
s
.39686 .61646 m .4075 .57607 L .35184 .54681 L p .831 .669 .682 r
F P
0 g
s
.57697 .46344 m .56129 .42574 L .53351 .43028 L p .678 .635 .8 r
F P
0 g
s
.56129 .42574 m .57697 .46344 L .61237 .44894 L p .646 .619 .808 r
F P
0 g
s
.63648 .48522 m .61237 .44894 L .57697 .46344 L p .634 .581 .777 r
F P
0 g
s
.39686 .61646 m .38955 .65576 L .4657 .67423 L p .78 .585 .636 r
F P
0 g
s
.46402 .71168 m .4657 .67423 L .38955 .65576 L p .783 .557 .593 r
F P
0 g
s
.4657 .67423 m .46402 .71168 L .54735 .71542 L p .716 .499 .594 r
F P
0 g
s
.45705 .40864 m .42557 .43908 L .45721 .45717 L p .758 .718 .815 r
F P
0 g
s
.45721 .45717 m .47866 .42133 L .45705 .40864 L p .758 .718 .815 r
F P
0 g
s
.35184 .54681 m .33591 .58531 L .39686 .61646 L p .831 .669 .682 r
F P
0 g
s
.38955 .65576 m .39686 .61646 L .33591 .58531 L p .843 .649 .64 r
F P
0 g
s
.62621 .66675 m .62899 .70418 L .70223 .67854 L p .559 .377 .592 r
F P
0 g
s
.70223 .67854 m .69739 .64122 L .62621 .66675 L p .559 .377 .592 r
F P
0 g
s
.63648 .48522 m .65741 .52347 L .69961 .49213 L p .564 .518 .763 r
F P
0 g
s
.65741 .52347 m .67476 .56282 L .72301 .52806 L p .538 .471 .728 r
F P
0 g
s
.72301 .52806 m .69961 .49213 L .65741 .52347 L p .538 .471 .728 r
F P
0 g
s
.61237 .44894 m .63648 .48522 L .67152 .45837 L p .588 .563 .794 r
F P
0 g
s
.69961 .49213 m .67152 .45837 L .63648 .48522 L p .564 .518 .763 r
F P
0 g
s
.51537 .39282 m .50503 .42877 L .53351 .43028 L p .698 .684 .833 r
F P
0 g
s
.53351 .43028 m .53002 .39362 L .51537 .39282 L p .698 .684 .833 r
F P
0 g
s
.53002 .39362 m .53351 .43028 L .56129 .42574 L p .678 .67 .835 r
F P
0 g
s
.50186 .38893 m .47866 .42133 L .50503 .42877 L p .716 .703 .837 r
F P
0 g
s
.50503 .42877 m .51537 .39282 L .50186 .38893 L p .716 .703 .837 r
F P
0 g
s
.54739 .74962 m .54735 .71542 L .46402 .71168 L p .71 .461 .545 r
F P
0 g
s
.54735 .71542 m .54739 .74962 L .62918 .73861 L p .632 .397 .544 r
F P
0 g
s
.62918 .73861 m .62899 .70418 L .54735 .71542 L p .632 .397 .544 r
F P
0 g
s
.67476 .56282 m .68817 .60236 L .74119 .56528 L p .51 .419 .689 r
F P
0 g
s
.74119 .56528 m .72301 .52806 L .67476 .56282 L p .51 .419 .689 r
F P
0 g
s
.61237 .44894 m .58558 .41555 L .56129 .42574 L p .646 .619 .808 r
F P
0 g
s
.58558 .41555 m .61237 .44894 L .63936 .42761 L p .611 .608 .824 r
F P
0 g
s
.67152 .45837 m .63936 .42761 L .61237 .44894 L p .588 .563 .794 r
F P
0 g
s
.56129 .42574 m .54428 .39124 L .53002 .39362 L p .678 .67 .835 r
F P
0 g
s
.54428 .39124 m .56129 .42574 L .58558 .41555 L p .657 .659 .841 r
F P
0 g
s
.38955 .65576 m .38572 .69315 L .46402 .71168 L p .783 .557 .593 r
F P
0 g
s
.46391 .74596 m .46402 .71168 L .38572 .69315 L p .784 .522 .54 r
F P
0 g
s
.46402 .71168 m .46391 .74596 L .54739 .74962 L p .71 .461 .545 r
F P
0 g
s
.4909 .38233 m .45705 .40864 L .47866 .42133 L p .73 .725 .846 r
F P
0 g
s
.47866 .42133 m .50186 .38893 L .4909 .38233 L p .73 .725 .846 r
F P
0 g
s
.33591 .58531 m .32494 .62361 L .38955 .65576 L p .843 .649 .64 r
F P
0 g
s
.38572 .69315 m .38955 .65576 L .32494 .62361 L p .854 .623 .589 r
F P
0 g
s
.40394 .41502 m .36882 .44244 L .39715 .47282 L p .809 .759 .806 r
F P
0 g
s
.39715 .47282 m .42557 .43908 L .40394 .41502 L p .809 .759 .806 r
F P
0 g
s
.37239 .50903 m .39715 .47282 L .36882 .44244 L p .839 .759 .775 r
F P
0 g
s
.68817 .60236 m .69739 .64122 L .75372 .6029 L p .477 .36 .642 r
F P
0 g
s
.75372 .6029 m .74119 .56528 L .68817 .60236 L p .477 .36 .642 r
F P
0 g
s
.36882 .44244 m .33803 .47345 L .37239 .50903 L p .839 .759 .775 r
F P
0 g
s
.35184 .54681 m .37239 .50903 L .33803 .47345 L p .866 .755 .739 r
F P
0 g
s
.44253 .39189 m .40394 .41502 L .42557 .43908 L p .777 .756 .834 r
F P
0 g
s
.42557 .43908 m .45705 .40864 L .44253 .39189 L p .777 .756 .834 r
F P
0 g
s
.58558 .41555 m .55668 .38592 L .54428 .39124 L p .657 .659 .841 r
F P
0 g
s
.55668 .38592 m .58558 .41555 L .60388 .40064 L p .635 .654 .852 r
F P
0 g
s
.63936 .42761 m .60388 .40064 L .58558 .41555 L p .611 .608 .824 r
F P
0 g
s
.62899 .70418 m .62918 .73861 L .70256 .7135 L p .533 .319 .535 r
F P
0 g
s
.70256 .7135 m .70223 .67854 L .62899 .70418 L p .533 .319 .535 r
F P
0 g
s
.33803 .47345 m .3123 .50725 L .35184 .54681 L p .866 .755 .739 r
F P
0 g
s
.33591 .58531 m .35184 .54681 L .3123 .50725 L p .89 .747 .696 r
F P
0 g
s
.48366 .37368 m .44253 .39189 L .45705 .40864 L p .74 .749 .859 r
F P
0 g
s
.45705 .40864 m .4909 .38233 L .48366 .37368 L p .74 .749 .859 r
F P
0 g
s
.53002 .39362 m .52632 .3609 L .51537 .39282 L closepath p .683 .714 .872 r
F P
0 g
s
.54428 .39124 m .52632 .3609 L .53002 .39362 L closepath p .675 .708 .873 r
F P
0 g
s
.51537 .39282 m .52632 .3609 L .50186 .38893 L closepath p .689 .721 .874 r
F P
0 g
s
.5469 .77984 m .54739 .74962 L .46391 .74596 L p .7 .412 .484 r
F P
0 g
s
.54739 .74962 m .5469 .77984 L .62677 .7693 L p .613 .34 .481 r
F P
0 g
s
.62677 .7693 m .62918 .73861 L .54739 .74962 L p .613 .34 .481 r
F P
0 g
s
.55668 .38592 m .52632 .3609 L .54428 .39124 L closepath p .667 .704 .875 r
F P
0 g
s
.60388 .40064 m .63936 .42761 L .65491 .40138 L p .574 .606 .846 r
F P
0 g
s
.63936 .42761 m .67152 .45837 L .69217 .42511 L p .534 .553 .821 r
F P
0 g
s
.69217 .42511 m .65491 .40138 L .63936 .42761 L p .534 .553 .821 r
F P
0 g
s
.67152 .45837 m .69961 .49213 L .72497 .45304 L p .49 .496 .79 r
F P
0 g
s
.72497 .45304 m .69217 .42511 L .67152 .45837 L p .49 .496 .79 r
F P
0 g
s
.50186 .38893 m .52632 .3609 L .4909 .38233 L closepath p .694 .729 .877 r
F P
0 g
s
.69739 .64122 m .70223 .67854 L .7603 .64003 L p .437 .291 .584 r
F P
0 g
s
.7603 .64003 m .75372 .6029 L .69739 .64122 L p .437 .291 .584 r
F P
0 g
s
.38572 .69315 m .38545 .7278 L .46391 .74596 L p .784 .522 .54 r
F P
0 g
s
.46536 .77633 m .46391 .74596 L .38545 .7278 L p .78 .476 .473 r
F P
0 g
s
.46391 .74596 m .46536 .77633 L .5469 .77984 L p .7 .412 .484 r
F P
0 g
s
.32494 .62361 m .31919 .66085 L .38572 .69315 L p .854 .623 .589 r
F P
0 g
s
.38545 .7278 m .38572 .69315 L .31919 .66085 L p .861 .589 .525 r
F P
0 g
s
.60388 .40064 m .5659 .37819 L .55668 .38592 L p .635 .654 .852 r
F P
0 g
s
.5659 .37819 m .60388 .40064 L .61415 .38246 L p .613 .656 .868 r
F P
0 g
s
.65491 .40138 m .61415 .38246 L .60388 .40064 L p .574 .606 .846 r
F P
0 g
s
.5659 .37819 m .52632 .3609 L .55668 .38592 L closepath p .659 .703 .88 r
F P
0 g
s
.69961 .49213 m .72301 .52806 L .75248 .48447 L p .44 .431 .753 r
F P
0 g
s
.75248 .48447 m .72497 .45304 L .69961 .49213 L p .44 .431 .753 r
F P
0 g
s
.3123 .50725 m .29226 .54302 L .33591 .58531 L p .89 .747 .696 r
F P
0 g
s
.32494 .62361 m .33591 .58531 L .29226 .54302 L p .913 .732 .643 r
F P
0 g
s
.4909 .38233 m .52632 .3609 L .48366 .37368 L closepath p .697 .737 .883 r
F P
0 g
s
.57092 .36884 m .52632 .3609 L .5659 .37819 L closepath p .652 .705 .886 r
F P
0 g
s
.61415 .38246 m .57092 .36884 L .5659 .37819 L p .613 .656 .868 r
F P
0 g
s
.62918 .73861 m .62677 .7693 L .69837 .74529 L p .499 .245 .461 r
F P
0 g
s
.69837 .74529 m .70256 .7135 L .62918 .73861 L p .499 .245 .461 r
F P
0 g
s
.48098 .36388 m .43681 .37275 L .44253 .39189 L p .744 .774 .877 r
F P
0 g
s
.44253 .39189 m .48366 .37368 L .48098 .36388 L p .744 .774 .877 r
F P
0 g
s
.40394 .41502 m .44253 .39189 L .43681 .37275 L p .787 .798 .861 r
F P
0 g
s
.43681 .37275 m .39495 .38727 L .40394 .41502 L p .787 .798 .861 r
F P
0 g
s
.36882 .44244 m .40394 .41502 L .39495 .38727 L p .829 .818 .838 r
F P
0 g
s
.72301 .52806 m .74119 .56528 L .77395 .51858 L p .383 .356 .705 r
F P
0 g
s
.77395 .51858 m .75248 .48447 L .72301 .52806 L p .383 .356 .705 r
F P
0 g
s
.48366 .37368 m .52632 .3609 L .48098 .36388 L closepath p .697 .745 .889 r
F P
0 g
s
.39495 .38727 m .35652 .40711 L .36882 .44244 L p .829 .818 .838 r
F P
0 g
s
.33803 .47345 m .36882 .44244 L .35652 .40711 L p .87 .834 .809 r
F P
0 g
s
.70223 .67854 m .70256 .7135 L .76076 .67577 L p .386 .205 .51 r
F P
0 g
s
.76076 .67577 m .7603 .64003 L .70223 .67854 L p .386 .205 .51 r
F P
0 g
s
.57115 .35886 m .52632 .3609 L .57092 .36884 L closepath p .647 .709 .893 r
F P
0 g
s
.57092 .36884 m .61415 .38246 L .61506 .36284 L p .594 .664 .888 r
F P
0 g
s
.61506 .36284 m .57115 .35886 L .57092 .36884 L p .594 .664 .888 r
F P
0 g
s
.61415 .38246 m .65491 .40138 L .65688 .37281 L p .536 .613 .877 r
F P
0 g
s
.65688 .37281 m .61506 .36284 L .61415 .38246 L p .536 .613 .877 r
F P
0 g
s
.29226 .54302 m .27842 .57986 L .32494 .62361 L p .913 .732 .643 r
F P
0 g
s
.31919 .66085 m .32494 .62361 L .27842 .57986 L p .933 .708 .575 r
F P
0 g
s
.48098 .36388 m .52632 .3609 L .4832 .35398 L closepath p .694 .752 .896 r
F P
0 g
s
.56649 .34932 m .52632 .3609 L .57115 .35886 L closepath p .644 .715 .9 r
F P
0 g
s
.55738 .34129 m .52632 .3609 L .56649 .34932 L closepath p .644 .724 .907 r
F P
0 g
s
.54479 .33568 m .52632 .3609 L .55738 .34129 L closepath p .647 .733 .912 r
F P
0 g
s
.5301 .33316 m .52632 .3609 L .54479 .33568 L closepath p .653 .742 .915 r
F P
0 g
s
.51499 .33401 m .52632 .3609 L .5301 .33316 L closepath p .661 .75 .916 r
F P
0 g
s
.50116 .33814 m .52632 .3609 L .51499 .33401 L closepath p .67 .755 .914 r
F P
0 g
s
.49017 .34507 m .52632 .3609 L .50116 .33814 L closepath p .68 .757 .91 r
F P
0 g
s
.4832 .35398 m .52632 .3609 L .49017 .34507 L closepath p .688 .756 .903 r
F P
0 g
s
.54588 .8054 m .5469 .77984 L .46536 .77633 L p .681 .347 .402 r
F P
0 g
s
.5469 .77984 m .54588 .8054 L .62178 .79556 L p .583 .265 .395 r
F P
0 g
s
.62178 .79556 m .62677 .7693 L .5469 .77984 L p .583 .265 .395 r
F P
0 g
s
.31919 .66085 m .31879 .69617 L .38545 .7278 L p .861 .589 .525 r
F P
0 g
s
.38878 .75897 m .38545 .7278 L .31879 .69617 L p .861 .539 .441 r
F P
0 g
s
.38545 .7278 m .38878 .75897 L .46536 .77633 L p .78 .476 .473 r
F P
0 g
s
.43681 .37275 m .48098 .36388 L .4832 .35398 L p .738 .796 .898 r
F P
0 g
s
.35652 .40711 m .32254 .43177 L .33803 .47345 L p .87 .834 .809 r
F P
0 g
s
.3123 .50725 m .33803 .47345 L .32254 .43177 L p .91 .846 .768 r
F P
0 g
s
.65491 .40138 m .69217 .42511 L .69547 .38858 L p .469 .552 .858 r
F P
0 g
s
.69547 .38858 m .65688 .37281 L .65491 .40138 L p .469 .552 .858 r
F P
0 g
s
.46838 .80212 m .46536 .77633 L .38878 .75897 L p .767 .411 .382 r
F P
0 g
s
.46536 .77633 m .46838 .80212 L .54588 .8054 L p .681 .347 .402 r
F P
0 g
s
.74119 .56528 m .75372 .6029 L .78882 .55451 L p .313 .264 .642 r
F P
0 g
s
.78882 .55451 m .77395 .51858 L .74119 .56528 L p .313 .264 .642 r
F P
0 g
s
.57115 .35886 m .61506 .36284 L .60623 .34391 L p .579 .681 .91 r
F P
0 g
s
.60623 .34391 m .56649 .34932 L .57115 .35886 L p .579 .681 .91 r
F P
0 g
s
.4832 .35398 m .44076 .35319 L .43681 .37275 L p .738 .796 .898 r
F P
0 g
s
.39495 .38727 m .43681 .37275 L .44076 .35319 L p .784 .839 .894 r
F P
0 g
s
.69217 .42511 m .72497 .45304 L .72973 .40978 L p .389 .477 .83 r
F P
0 g
s
.72973 .40978 m .69547 .38858 L .69217 .42511 L p .389 .477 .83 r
F P
0 g
s
.44076 .35319 m .4832 .35398 L .49017 .34507 L p .722 .812 .921 r
F P
0 g
s
.62677 .7693 m .62178 .79556 L .68968 .77316 L p .448 .146 .358 r
F P
0 g
s
.68968 .77316 m .69837 .74529 L .62677 .7693 L p .448 .146 .358 r
F P
0 g
s
.32254 .43177 m .29394 .46063 L .3123 .50725 L p .91 .846 .768 r
F P
0 g
s
.29226 .54302 m .3123 .50725 L .29394 .46063 L p .948 .85 .713 r
F P
0 g
s
.56649 .34932 m .60623 .34391 L .58837 .32782 L p .572 .704 .931 r
F P
0 g
s
.58837 .32782 m .55738 .34129 L .56649 .34932 L p .572 .704 .931 r
F P
0 g
s
.44076 .35319 m .40014 .35866 L .39495 .38727 L p .784 .839 .894 r
F P
0 g
s
.35652 .40711 m .39495 .38727 L .40014 .35866 L p .83 .881 .88 r
F P
0 g
s
.27842 .57986 m .27114 .61685 L .31919 .66085 L p .933 .708 .575 r
F P
0 g
s
.31879 .69617 m .31919 .66085 L .27114 .61685 L p .946 .669 .483 r
F P
0 g
s
.61506 .36284 m .65688 .37281 L .64445 .34497 L p .498 .633 .913 r
F P
0 g
s
.64445 .34497 m .60623 .34391 L .61506 .36284 L p .498 .633 .913 r
F P
0 g
s
.70256 .7135 m .69837 .74529 L .75504 .70925 L p .316 .093 .407 r
F P
0 g
s
.75504 .70925 m .76076 .67577 L .70256 .7135 L p .316 .093 .407 r
F P
0 g
s
.45425 .33541 m .49017 .34507 L .50116 .33814 L p .695 .818 .941 r
F P
0 g
s
.49017 .34507 m .45425 .33541 L .44076 .35319 L p .722 .812 .921 r
F P
0 g
s
.75372 .6029 m .7603 .64003 L .79665 .59132 L p .224 .148 .556 r
F P
0 g
s
.79665 .59132 m .78882 .55451 L .75372 .6029 L p .224 .148 .556 r
F P
0 g
s
.72497 .45304 m .75248 .48447 L .75867 .43592 L p .29 .382 .785 r
F P
0 g
s
.75867 .43592 m .72973 .40978 L .72497 .45304 L p .29 .382 .785 r
F P
0 g
s
.55738 .34129 m .58837 .32782 L .56332 .31651 L p .577 .734 .95 r
F P
0 g
s
.56332 .31651 m .54479 .33568 L .55738 .34129 L p .577 .734 .95 r
F P
0 g
s
.31879 .69617 m .32379 .72872 L .38878 .75897 L p .861 .539 .441 r
F P
0 g
s
.39566 .78591 m .38878 .75897 L .32379 .72872 L p .849 .465 .321 r
F P
0 g
s
.38878 .75897 m .39566 .78591 L .46838 .80212 L p .767 .411 .382 r
F P
0 g
s
.40014 .35866 m .44076 .35319 L .45425 .33541 L p .758 .873 .931 r
F P
0 g
s
.47599 .32149 m .50116 .33814 L .51499 .33401 L p .66 .812 .956 r
F P
0 g
s
.50116 .33814 m .47599 .32149 L .45425 .33541 L p .695 .818 .941 r
F P
0 g
s
.29394 .46063 m .27155 .49296 L .29226 .54302 L p .948 .85 .713 r
F P
0 g
s
.27842 .57986 m .29226 .54302 L .27155 .49296 L p .98 .842 .633 r
F P
0 g
s
.54479 .33568 m .56332 .31651 L .53391 .31139 L p .594 .765 .961 r
F P
0 g
s
.53391 .31139 m .5301 .33316 L .54479 .33568 L p .594 .765 .961 r
F P
0 g
s
.40014 .35866 m .36249 .37036 L .35652 .40711 L p .83 .881 .88 r
F P
0 g
s
.32254 .43177 m .35652 .40711 L .36249 .37036 L p .877 .921 .852 r
F P
0 g
s
.54435 .82567 m .54588 .8054 L .46838 .80212 L p .646 .251 .282 r
F P
0 g
s
.54588 .8054 m .54435 .82567 L .61427 .81673 L p .534 .156 .271 r
F P
0 g
s
.61427 .81673 m .62178 .79556 L .54588 .8054 L p .534 .156 .271 r
F P
0 g
s
.50361 .31313 m .51499 .33401 L .5301 .33316 L p .624 .793 .963 r
F P
0 g
s
.51499 .33401 m .50361 .31313 L .47599 .32149 L p .66 .812 .956 r
F P
0 g
s
.65688 .37281 m .69547 .38858 L .68003 .35265 L p .391 .564 .904 r
F P
0 g
s
.68003 .35265 m .64445 .34497 L .65688 .37281 L p .391 .564 .904 r
F P
0 g
s
.5301 .33316 m .53391 .31139 L .50361 .31313 L p .624 .793 .963 r
F P
0 g
s
.47291 .8227 m .46838 .80212 L .39566 .78591 L p .735 .314 .247 r
F P
0 g
s
.46838 .80212 m .47291 .8227 L .54435 .82567 L p .646 .251 .282 r
F P
0 g
s
.60623 .34391 m .64445 .34497 L .61841 .3211 L p .469 .667 .949 r
F P
0 g
s
.61841 .3211 m .58837 .32782 L .60623 .34391 L p .469 .667 .949 r
F P
0 g
s
.75248 .48447 m .77395 .51858 L .78141 .46631 L p .162 .256 .715 r
F P
0 g
s
.78141 .46631 m .75867 .43592 L .75248 .48447 L p .162 .256 .715 r
F P
0 g
s
.27114 .61685 m .27063 .65306 L .31879 .69617 L p .946 .669 .483 r
F P
0 g
s
.32379 .72872 m .31879 .69617 L .27063 .65306 L p .942 .603 .352 r
F P
0 g
s
.7603 .64003 m .76076 .67577 L .79719 .62805 L p .106 0 .433 r
F P
0 g
s
.79719 .62805 m .79665 .59132 L .7603 .64003 L p .106 0 .433 r
F P
0 g
s
.62178 .79556 m .61427 .81673 L .67665 .79642 L p .368 .003 .206 r
F P
0 g
s
.67665 .79642 m .68968 .77316 L .62178 .79556 L p .368 .003 .206 r
F P
0 g
s
.69837 .74529 m .68968 .77316 L .74324 .73961 L p .217 0 .259 r
F P
0 g
s
.74324 .73961 m .75504 .70925 L .69837 .74529 L p .217 0 .259 r
F P
0 g
s
.41956 .3324 m .45425 .33541 L .47599 .32149 L p .703 .887 .965 r
F P
0 g
s
.45425 .33541 m .41956 .3324 L .40014 .35866 L p .758 .873 .931 r
F P
0 g
s
.36249 .37036 m .32892 .38808 L .32254 .43177 L p .877 .921 .852 r
F P
0 g
s
.29394 .46063 m .32254 .43177 L .32892 .38808 L p .919 .953 .797 r
F P
0 g
s
.36249 .37036 m .40014 .35866 L .41956 .3324 L p .79 .936 .926 r
F P
0 g
s
.27155 .49296 m .25602 .52789 L .27842 .57986 L p .98 .842 .633 r
F P
0 g
s
.27114 .61685 m .27842 .57986 L .25602 .52789 L p .999 .811 .515 r
F P
0 g
s
.69547 .38858 m .72973 .40978 L .7119 .3669 L p .244 .462 .872 r
F P
0 g
s
.7119 .3669 m .68003 .35265 L .69547 .38858 L p .244 .462 .872 r
F P
0 g
s
.58837 .32782 m .61841 .3211 L .58139 .30421 L p .458 .714 .979 r
F P
0 g
s
.58139 .30421 m .56332 .31651 L .58837 .32782 L p .458 .714 .979 r
F P
0 g
s
.32379 .72872 m .33411 .75773 L .39566 .78591 L p .849 .465 .321 r
F P
0 g
s
.406 .80798 m .39566 .78591 L .33411 .75773 L p .805 .345 .141 r
F P
0 g
s
.39566 .78591 m .406 .80798 L .47291 .8227 L p .735 .314 .247 r
F P
0 g
s
.77395 .51858 m .78882 .55451 L .79721 .50015 L p 0 .086 .602 r
F P
0 g
s
.79721 .50015 m .78141 .46631 L .77395 .51858 L p 0 .086 .602 r
F P
0 g
s
.4515 .31166 m .47599 .32149 L .50361 .31313 L p .624 .872 .989 r
F P
0 g
s
.47599 .32149 m .4515 .31166 L .41956 .3324 L p .703 .887 .965 r
F P
0 g
s
.64445 .34497 m .68003 .35265 L .64661 .3216 L p .308 .592 .944 r
F P
0 g
s
.64661 .3216 m .61841 .3211 L .64445 .34497 L p .308 .592 .944 r
F P
0 g
s
.54233 .84009 m .54435 .82567 L .47291 .8227 L p .574 .101 .095 r
F P
0 g
s
.54435 .82567 m .54233 .84009 L .60436 .83224 L p .443 0 .076 r
F P
0 g
s
.60436 .83224 m .61427 .81673 L .54435 .82567 L p .443 0 .076 r
F P
0 g
s
.56332 .31651 m .58139 .30421 L .53764 .29654 L p .481 .772 .995 r
F P
0 g
s
.53764 .29654 m .53391 .31139 L .56332 .31651 L p .481 .772 .995 r
F P
0 g
s
.32892 .38808 m .30046 .41144 L .29394 .46063 L p .919 .953 .797 r
F P
0 g
s
.27155 .49296 m .29394 .46063 L .30046 .41144 L p .945 .96 .697 r
F P
0 g
s
.76076 .67577 m .75504 .70925 L .79039 .66371 L p 0 0 .253 r
F P
0 g
s
.79039 .66371 m .79719 .62805 L .76076 .67577 L p 0 0 .253 r
F P
0 g
s
.27063 .65306 m .27695 .68756 L .32379 .72872 L p .942 .603 .352 r
F P
0 g
s
.33411 .75773 m .32379 .72872 L .27695 .68756 L p .903 .489 .159 r
F P
0 g
s
.49249 .29914 m .50361 .31313 L .53391 .31139 L p .541 .829 .998 r
F P
0 g
s
.50361 .31313 m .49249 .29914 L .4515 .31166 L p .624 .872 .989 r
F P
0 g
s
.47891 .83748 m .47291 .8227 L .406 .80798 L p .66 .155 .037 r
F P
0 g
s
.47291 .8227 m .47891 .83748 L .54233 .84009 L p .574 .101 .095 r
F P
0 g
s
.41956 .3324 m .38713 .33632 L .36249 .37036 L p .79 .936 .926 r
F P
0 g
s
.32892 .38808 m .36249 .37036 L .38713 .33632 L p .808 .988 .883 r
F P
0 g
s
.53391 .31139 m .53764 .29654 L .49249 .29914 L p .541 .829 .998 r
F P
0 g
s
.72973 .40978 m .75867 .43592 L .739 .38747 L p .037 .304 .794 r
F P
0 g
s
.739 .38747 m .7119 .3669 L .72973 .40978 L p .037 .304 .794 r
F P
0 g
s
.25602 .52789 m .24782 .56449 L .27114 .61685 L p .999 .811 .515 r
F P
0 g
s
.27063 .65306 m .27114 .61685 L .24782 .56449 L p .983 .735 .339 r
F P
0 g
s
.38713 .33632 m .41956 .3324 L .4515 .31166 L p .684 .95 .956 r
F P
0 g
s
.68968 .77316 m .67665 .79642 L .72557 .76609 L p .067 0 .038 r
F P
0 g
s
.72557 .76609 m .74324 .73961 L .68968 .77316 L p .067 0 .038 r
F P
0 g
s
.61427 .81673 m .60436 .83224 L .6595 .81444 L p .232 0 0 r
F P
0 g
s
.6595 .81444 m .67665 .79642 L .61427 .81673 L p .232 0 0 r
F P
0 g
s
.78882 .55451 m .79665 .59132 L .80556 .53651 L p 0 0 .425 r
F P
0 g
s
.80556 .53651 m .79721 .50015 L .78882 .55451 L p 0 0 .425 r
F P
0 g
s
.61841 .3211 m .64661 .3216 L .59845 .29949 L p .244 .637 .96 r
F P
0 g
s
.59845 .29949 m .58139 .30421 L .61841 .3211 L p .244 .637 .96 r
F P
0 g
s
.30046 .41144 m .27803 .43985 L .27155 .49296 L p .945 .96 .697 r
F P
0 g
s
.25602 .52789 m .27155 .49296 L .27803 .43985 L p .923 .912 .521 r
F P
0 g
s
.68003 .35265 m .7119 .3669 L .67204 .32958 L p .051 .443 .876 r
F P
0 g
s
.67204 .32958 m .64661 .3216 L .68003 .35265 L p .051 .443 .876 r
F P
0 g
s
.33411 .75773 m .34959 .78246 L .406 .80798 L p .805 .345 .141 r
F P
0 g
s
.41963 .82456 m .406 .80798 L .34959 .78246 L p .688 .144 0 r
F P
0 g
s
.406 .80798 m .41963 .82456 L .47891 .83748 L p .66 .155 .037 r
F P
0 g
s
.75504 .70925 m .74324 .73961 L .77638 .69734 L p 0 0 0 r
F P
0 g
s
.77638 .69734 m .79039 .66371 L .75504 .70925 L p 0 0 0 r
F P
0 g
s
.75867 .43592 m .78141 .46631 L .76042 .41389 L p 0 .068 .631 r
F P
0 g
s
.76042 .41389 m .739 .38747 L .75867 .43592 L p 0 .068 .631 r
F P
0 g
s
.38713 .33632 m .35798 .3473 L .32892 .38808 L p .808 .988 .883 r
F P
0 g
s
.30046 .41144 m .32892 .38808 L .35798 .3473 L p .775 .989 .756 r
F P
0 g
s
.24782 .56449 m .24725 .60175 L .27063 .65306 L p .983 .735 .339 r
F P
0 g
s
.27695 .68756 m .27063 .65306 L .24725 .60175 L p .895 .585 .086 r
F P
0 g
s
.27695 .68756 m .28999 .71947 L .33411 .75773 L p .903 .489 .159 r
F P
0 g
s
.34959 .78246 m .33411 .75773 L .28999 .71947 L p .784 .297 0 r
F P
0 g
s
.42845 .30925 m .4515 .31166 L .49249 .29914 L p .513 .896 .957 r
F P
0 g
s
.4515 .31166 m .42845 .30925 L .38713 .33632 L p .684 .95 .956 r
F P
0 g
s
.53985 .84816 m .54233 .84009 L .47891 .83748 L p .416 0 0 r
F P
0 g
s
.54233 .84009 m .53985 .84816 L .5922 .84157 L p .265 0 0 r
F P
0 g
s
.5922 .84157 m .60436 .83224 L .54233 .84009 L p .265 0 0 r
F P
0 g
s
.79665 .59132 m .79719 .62805 L .80614 .57434 L p 0 0 .164 r
F P
0 g
s
.80614 .57434 m .80556 .53651 L .79665 .59132 L p 0 0 .164 r
F P
0 g
s
.58139 .30421 m .59845 .29949 L .54117 .2894 L p .246 .704 .951 r
F P
0 g
s
.54117 .2894 m .53764 .29654 L .58139 .30421 L p .246 .704 .951 r
F P
0 g
s
.35798 .3473 m .38713 .33632 L .42845 .30925 L p .584 .945 .843 r
F P
0 g
s
.48627 .84597 m .47891 .83748 L .41963 .82456 L p .482 0 0 r
F P
0 g
s
.47891 .83748 m .48627 .84597 L .53985 .84816 L p .416 0 0 r
F P
0 g
s
.67665 .79642 m .6595 .81444 L .70242 .78797 L p 0 0 0 r
F P
0 g
s
.70242 .78797 m .72557 .76609 L .67665 .79642 L p 0 0 0 r
F P
0 g
s
.48198 .29283 m .49249 .29914 L .53764 .29654 L p .343 .797 .946 r
F P
0 g
s
.49249 .29914 m .48198 .29283 L .42845 .30925 L p .513 .896 .957 r
F P
0 g
s
.27803 .43985 m .2624 .47257 L .25602 .52789 L p .923 .912 .521 r
F P
0 g
s
.24782 .56449 m .25602 .52789 L .2624 .47257 L p .808 .763 .25 r
F P
0 g
s
.53764 .29654 m .54117 .2894 L .48198 .29283 L p .343 .797 .946 r
F P
0 g
s
.60436 .83224 m .5922 .84157 L .63853 .82667 L p .003 0 0 r
F P
0 g
s
.63853 .82667 m .6595 .81444 L .60436 .83224 L p .003 0 0 r
F P
0 g
s
.7119 .3669 m .739 .38747 L .69381 .34504 L p 0 .175 .664 r
F P
0 g
s
.69381 .34504 m .67204 .32958 L .7119 .3669 L p 0 .175 .664 r
F P
0 g
s
.78141 .46631 m .79721 .50015 L .77538 .44544 L p 0 0 .353 r
F P
0 g
s
.77538 .44544 m .76042 .41389 L .78141 .46631 L p 0 0 .353 r
F P
0 g
s
.74324 .73961 m .72557 .76609 L .7555 .72803 L p 0 0 0 r
F P
0 g
s
.7555 .72803 m .77638 .69734 L .74324 .73961 L p 0 0 0 r
F P
0 g
s
.35798 .3473 m .3331 .36522 L .30046 .41144 L p .775 .989 .756 r
F P
0 g
s
.27803 .43985 m .30046 .41144 L .3331 .36522 L p .632 .861 .491 r
F P
0 g
s
.24725 .60175 m .25437 .63865 L .27695 .68756 L p .895 .585 .086 r
F P
0 g
s
.28999 .71947 m .27695 .68756 L .25437 .63865 L p .698 .343 0 r
F P
0 g
s
.64661 .3216 m .67204 .32958 L .61391 .30283 L p 0 .422 .785 r
F P
0 g
s
.61391 .30283 m .59845 .29949 L .64661 .3216 L p 0 .422 .785 r
F P
0 g
s
.34959 .78246 m .36993 .80224 L .41963 .82456 L p .688 .144 0 r
F P
0 g
s
.43632 .83514 m .41963 .82456 L .36993 .80224 L p .434 0 0 r
F P
0 g
s
.41963 .82456 m .43632 .83514 L .48627 .84597 L p .482 0 0 r
F P
0 g
s
.28999 .71947 m .30947 .74793 L .34959 .78246 L p .784 .297 0 r
F P
0 g
s
.36993 .80224 m .34959 .78246 L .30947 .74793 L p .54 .015 0 r
F P
0 g
s
.79719 .62805 m .79039 .66371 L .79889 .61254 L p .721 .692 .153 r
F P
0 g
s
.79889 .61254 m .80614 .57434 L .79719 .62805 L p .721 .692 .153 r
F P
0 g
s
.4076 .31466 m .42845 .30925 L .48198 .29283 L p .247 .754 .721 r
F P
0 g
s
.42845 .30925 m .4076 .31466 L .35798 .3473 L p .584 .945 .843 r
F P
0 g
s
.2624 .47257 m .25414 .50865 L .24782 .56449 L p .808 .763 .25 r
F P
0 g
s
.24725 .60175 m .24782 .56449 L .25414 .50865 L p 0 0 .077 r
F P
0 g
s
.3331 .36522 m .35798 .3473 L .4076 .31466 L p 0 0 0 r
F P
0 g
s
.6595 .81444 m .63853 .82667 L .67426 .80462 L p .391 .813 .629 r
F P
0 g
s
.67426 .80462 m .70242 .78797 L .6595 .81444 L p .391 .813 .629 r
F P
0 g
s
.53694 .84948 m .53985 .84816 L .48627 .84597 L p .108 0 0 r
F P
0 g
s
.53985 .84816 m .53694 .84948 L .57802 .84431 L p 0 0 0 r
F P
0 g
s
.57802 .84431 m .5922 .84157 L .53985 .84816 L p 0 0 0 r
F P
0 g
s
.79721 .50015 m .80556 .53651 L .7833 .48123 L p .837 .526 0 r
F P
0 g
s
.7833 .48123 m .77538 .44544 L .79721 .50015 L p .837 .526 0 r
F P
0 g
s
.48627 .84597 m .49487 .84776 L .53694 .84948 L p .108 0 0 r
F P
0 g
s
.49487 .84776 m .48627 .84597 L .43632 .83514 L p 0 .445 .695 r
F P
0 g
s
.59845 .29949 m .61391 .30283 L .54437 .29059 L p .154 0 0 r
F P
0 g
s
.54437 .29059 m .54117 .2894 L .59845 .29949 L p .154 0 0 r
F P
0 g
s
.25437 .63865 m .26901 .67414 L .28999 .71947 L p .698 .343 0 r
F P
0 g
s
.30947 .74793 m .28999 .71947 L .26901 .67414 L p 0 0 .526 r
F P
0 g
s
.739 .38747 m .76042 .41389 L .7111 .36773 L p .671 .164 0 r
F P
0 g
s
.7111 .36773 m .69381 .34504 L .739 .38747 L p .671 .164 0 r
F P
0 g
s
.72557 .76609 m .70242 .78797 L .72826 .75493 L p .662 .924 .625 r
F P
0 g
s
.72826 .75493 m .7555 .72803 L .72557 .76609 L p .662 .924 .625 r
F P
0 g
s
.3331 .36522 m .31338 .38971 L .27803 .43985 L p .632 .861 .491 r
F P
0 g
s
.2624 .47257 m .27803 .43985 L .31338 .38971 L p 0 0 0 r
F P
0 g
s
.5922 .84157 m .57802 .84431 L .61417 .83267 L p .287 .783 .756 r
F P
0 g
s
.61417 .83267 m .63853 .82667 L .5922 .84157 L p .287 .783 .756 r
F P
0 g
s
.48198 .29283 m .47244 .29475 L .4076 .31466 L p .247 .754 .721 r
F P
0 g
s
.47244 .29475 m .48198 .29283 L .54117 .2894 L p .025 0 0 r
F P
0 g
s
.79039 .66371 m .77638 .69734 L .78399 .65 L p .871 .88 .444 r
F P
0 g
s
.78399 .65 m .79889 .61254 L .79039 .66371 L p .871 .88 .444 r
F P
0 g
s
.54117 .2894 m .54437 .29059 L .47244 .29475 L p .025 0 0 r
F P
0 g
s
.30947 .74793 m .33495 .77218 L .36993 .80224 L p .54 .015 0 r
F P
0 g
s
.36993 .80224 m .39472 .8165 L .43632 .83514 L p .434 0 0 r
F P
0 g
s
.39472 .8165 m .36993 .80224 L .33495 .77218 L p 0 .285 .746 r
F P
0 g
s
.67204 .32958 m .69381 .34504 L .6272 .31448 L p .52 0 0 r
F P
0 g
s
.6272 .31448 m .61391 .30283 L .67204 .32958 L p .52 0 0 r
F P
0 g
s
.25414 .50865 m .25356 .54704 L .24725 .60175 L p 0 0 .077 r
F P
0 g
s
.25437 .63865 m .24725 .60175 L .25356 .54704 L p 0 0 .366 r
F P
0 g
s
.45577 .83928 m .43632 .83514 L .39472 .8165 L p 0 .468 .82 r
F P
0 g
s
.43632 .83514 m .45577 .83928 L .49487 .84776 L p 0 .445 .695 r
F P
0 g
s
.80556 .53651 m .80614 .57434 L .78386 .52016 L p .967 .716 .284 r
F P
0 g
s
.78386 .52016 m .7833 .48123 L .80556 .53651 L p .967 .716 .284 r
F P
0 g
s
.4076 .31466 m .38971 .32801 L .3331 .36522 L p 0 0 0 r
F P
0 g
s
.31338 .38971 m .3331 .36522 L .38971 .32801 L p 0 0 0 r
F P
0 g
s
.63853 .82667 m .61417 .83267 L .64176 .81554 L p .565 .937 .874 r
F P
0 g
s
.64176 .81554 m .67426 .80462 L .63853 .82667 L p .565 .937 .874 r
F P
0 g
s
.38971 .32801 m .4076 .31466 L .47244 .29475 L p .098 0 0 r
F P
0 g
s
.26901 .67414 m .2908 .70721 L .30947 .74793 L p 0 0 .526 r
F P
0 g
s
.33495 .77218 m .30947 .74793 L .2908 .70721 L p 0 .208 .734 r
F P
0 g
s
.31338 .38971 m .29958 .42014 L .2624 .47257 L p 0 0 0 r
F P
0 g
s
.25414 .50865 m .2624 .47257 L .29958 .42014 L p 0 0 .185 r
F P
0 g
s
.70242 .78797 m .67426 .80462 L .69537 .77728 L p .744 .993 .822 r
F P
0 g
s
.69537 .77728 m .72826 .75493 L .70242 .78797 L p .744 .993 .822 r
F P
0 g
s
.77638 .69734 m .7555 .72803 L .76187 .68561 L p .922 .963 .651 r
F P
0 g
s
.76187 .68561 m .78399 .65 L .77638 .69734 L p .922 .963 .651 r
F P
0 g
s
.76042 .41389 m .77538 .44544 L .72322 .3971 L p .87 .428 .059 r
F P
0 g
s
.72322 .3971 m .7111 .36773 L .76042 .41389 L p .87 .428 .059 r
F P
0 g
s
.53368 .84374 m .53694 .84948 L .49487 .84776 L p .257 .74 .928 r
F P
0 g
s
.53694 .84948 m .53368 .84374 L .56207 .84016 L p .357 .814 .934 r
F P
0 g
s
.56207 .84016 m .57802 .84431 L .53694 .84948 L p .357 .814 .934 r
F P
0 g
s
.50455 .84255 m .49487 .84776 L .45577 .83928 L p .225 .69 .945 r
F P
0 g
s
.49487 .84776 m .50455 .84255 L .53368 .84374 L p .257 .74 .928 r
F P
0 g
s
.25356 .54704 m .26074 .58657 L .25437 .63865 L p 0 0 .366 r
F P
0 g
s
.26901 .67414 m .25437 .63865 L .26074 .58657 L p 0 .029 .57 r
F P
0 g
s
.61391 .30283 m .6272 .31448 L .54713 .30046 L p .503 0 0 r
F P
0 g
s
.54713 .30046 m .54437 .29059 L .61391 .30283 L p .503 0 0 r
F P
0 g
s
.33495 .77218 m .36582 .79153 L .39472 .8165 L p 0 .285 .746 r
F P
0 g
s
.42345 .82475 m .39472 .8165 L .36582 .79153 L p .107 .509 .907 r
F P
0 g
s
.39472 .8165 m .42345 .82475 L .45577 .83928 L p 0 .468 .82 r
F P
0 g
s
.57802 .84431 m .56207 .84016 L .58692 .8321 L p .499 .889 .957 r
F P
0 g
s
.58692 .8321 m .61417 .83267 L .57802 .84431 L p .499 .889 .957 r
F P
0 g
s
.69381 .34504 m .7111 .36773 L .63781 .33437 L p .744 .235 .003 r
F P
0 g
s
.63781 .33437 m .6272 .31448 L .69381 .34504 L p .744 .235 .003 r
F P
0 g
s
.80614 .57434 m .79889 .61254 L .77697 .56102 L p 1 .812 .489 r
F P
0 g
s
.77697 .56102 m .78386 .52016 L .80614 .57434 L p 1 .812 .489 r
F P
0 g
s
.46422 .30523 m .47244 .29475 L .54437 .29059 L p .363 0 0 r
F P
0 g
s
.47244 .29475 m .46422 .30523 L .38971 .32801 L p .098 0 0 r
F P
0 g
s
.47758 .83667 m .45577 .83928 L .42345 .82475 L p .259 .661 .966 r
F P
0 g
s
.45577 .83928 m .47758 .83667 L .50455 .84255 L p .225 .69 .945 r
F P
0 g
s
.2908 .70721 m .31913 .73694 L .33495 .77218 L p 0 .208 .734 r
F P
0 g
s
.36582 .79153 m .33495 .77218 L .31913 .73694 L p .108 .4 .854 r
F P
0 g
s
.54437 .29059 m .54713 .30046 L .46422 .30523 L p .363 0 0 r
F P
0 g
s
.7555 .72803 m .72826 .75493 L .73318 .71833 L p .911 .978 .779 r
F P
0 g
s
.73318 .71833 m .76187 .68561 L .7555 .72803 L p .911 .978 .779 r
F P
0 g
s
.29958 .42014 m .29226 .45563 L .25414 .50865 L p 0 0 .185 r
F P
0 g
s
.25356 .54704 m .25414 .50865 L .29226 .45563 L p .067 0 .403 r
F P
0 g
s
.67426 .80462 m .64176 .81554 L .65767 .79445 L p .754 .977 .919 r
F P
0 g
s
.65767 .79445 m .69537 .77728 L .67426 .80462 L p .754 .977 .919 r
F P
0 g
s
.38971 .32801 m .37547 .34915 L .31338 .38971 L p 0 0 0 r
F P
0 g
s
.29958 .42014 m .31338 .38971 L .37547 .34915 L p .173 0 .183 r
F P
0 g
s
.61417 .83267 m .58692 .8321 L .60566 .82032 L p .637 .932 .969 r
F P
0 g
s
.60566 .82032 m .64176 .81554 L .61417 .83267 L p .637 .932 .969 r
F P
0 g
s
.77538 .44544 m .7833 .48123 L .72966 .4323 L p .937 .579 .307 r
F P
0 g
s
.72966 .4323 m .72322 .3971 L .77538 .44544 L p .937 .579 .307 r
F P
0 g
s
.26074 .58657 m .27548 .62603 L .26901 .67414 L p 0 .029 .57 r
F P
0 g
s
.2908 .70721 m .26901 .67414 L .27548 .62603 L p .091 .216 .702 r
F P
0 g
s
.37547 .34915 m .38971 .32801 L .46422 .30523 L p .329 0 .082 r
F P
0 g
s
.36582 .79153 m .40133 .80542 L .42345 .82475 L p .107 .509 .907 r
F P
0 g
s
.45547 .82664 m .42345 .82475 L .40133 .80542 L p .332 .642 .966 r
F P
0 g
s
.42345 .82475 m .45547 .82664 L .47758 .83667 L p .259 .661 .966 r
F P
0 g
s
.79889 .61254 m .78399 .65 L .76286 .60249 L p .986 .854 .624 r
F P
0 g
s
.76286 .60249 m .77697 .56102 L .79889 .61254 L p .986 .854 .624 r
F P
0 g
s
.53011 .83079 m .53368 .84374 L .50455 .84255 L p .489 .808 1 r
F P
0 g
s
.53368 .84374 m .53011 .83079 L .54471 .82893 L p .535 .841 .999 r
F P
0 g
s
.54471 .82893 m .56207 .84016 L .53368 .84374 L p .535 .841 .999 r
F P
0 g
s
.51511 .83017 m .50455 .84255 L .47758 .83667 L p .465 .774 .997 r
F P
0 g
s
.50455 .84255 m .51511 .83017 L .53011 .83079 L p .489 .808 1 r
F P
0 g
s
.72826 .75493 m .69537 .77728 L .6988 .74722 L p .874 .96 .855 r
F P
0 g
s
.6988 .74722 m .73318 .71833 L .72826 .75493 L p .874 .96 .855 r
F P
0 g
s
.31913 .73694 m .35321 .76247 L .36582 .79153 L p .108 .4 .854 r
F P
0 g
s
.40133 .80542 m .36582 .79153 L .35321 .76247 L p .283 .535 .914 r
F P
0 g
s
.56207 .84016 m .54471 .82893 L .5574 .82477 L p .594 .865 .994 r
F P
0 g
s
.5574 .82477 m .58692 .8321 L .56207 .84016 L p .594 .865 .994 r
F P
0 g
s
.6272 .31448 m .63781 .33437 L .54933 .31902 L p .664 .195 .129 r
F P
0 g
s
.54933 .31902 m .54713 .30046 L .6272 .31448 L p .664 .195 .129 r
F P
0 g
s
.29226 .45563 m .29175 .49508 L .25356 .54704 L p .067 0 .403 r
F P
0 g
s
.26074 .58657 m .25356 .54704 L .29175 .49508 L p .201 .128 .546 r
F P
0 g
s
.27548 .62603 m .29731 .66421 L .2908 .70721 L p .091 .216 .702 r
F P
0 g
s
.31913 .73694 m .2908 .70721 L .29731 .66421 L p .227 .356 .786 r
F P
0 g
s
.7111 .36773 m .72322 .3971 L .64526 .36206 L p .825 .41 .258 r
F P
0 g
s
.64526 .36206 m .63781 .33437 L .7111 .36773 L p .825 .41 .258 r
F P
0 g
s
.64176 .81554 m .60566 .82032 L .61618 .80594 L p .731 .927 .956 r
F P
0 g
s
.61618 .80594 m .65767 .79445 L .64176 .81554 L p .731 .927 .956 r
F P
0 g
s
.50128 .82713 m .47758 .83667 L .45547 .82664 L p .465 .743 .989 r
F P
0 g
s
.47758 .83667 m .50128 .82713 L .51511 .83017 L p .465 .774 .997 r
F P
0 g
s
.7833 .48123 m .78386 .52016 L .73011 .47221 L p .946 .66 .466 r
F P
0 g
s
.73011 .47221 m .72966 .4323 L .7833 .48123 L p .946 .66 .466 r
F P
0 g
s
.37547 .34915 m .36546 .3776 L .29958 .42014 L p .173 0 .183 r
F P
0 g
s
.29226 .45563 m .29958 .42014 L .36546 .3776 L p .306 .065 .375 r
F P
0 g
s
.45766 .32424 m .46422 .30523 L .54713 .30046 L p .533 .093 .15 r
F P
0 g
s
.46422 .30523 m .45766 .32424 L .37547 .34915 L p .329 0 .082 r
F P
0 g
s
.58692 .8321 m .5574 .82477 L .56685 .81872 L p .651 .874 .982 r
F P
0 g
s
.56685 .81872 m .60566 .82032 L .58692 .8321 L p .651 .874 .982 r
F P
0 g
s
.78399 .65 m .76187 .68561 L .742 .64326 L p .955 .869 .714 r
F P
0 g
s
.742 .64326 m .76286 .60249 L .78399 .65 L p .955 .869 .714 r
F P
0 g
s
.54713 .30046 m .54933 .31902 L .45766 .32424 L p .533 .093 .15 r
F P
0 g
s
.69537 .77728 m .65767 .79445 L .65973 .77148 L p .826 .927 .9 r
F P
0 g
s
.65973 .77148 m .6988 .74722 L .69537 .77728 L p .826 .927 .9 r
F P
0 g
s
.35321 .76247 m .39211 .78311 L .40133 .80542 L p .283 .535 .914 r
F P
0 g
s
.4406 .81341 m .40133 .80542 L .39211 .78311 L p .414 .629 .943 r
F P
0 g
s
.40133 .80542 m .4406 .81341 L .45547 .82664 L p .332 .642 .966 r
F P
0 g
s
.49005 .82196 m .45547 .82664 L .4406 .81341 L p .485 .717 .973 r
F P
0 g
s
.45547 .82664 m .49005 .82196 L .50128 .82713 L p .465 .743 .989 r
F P
0 g
s
.29731 .66421 m .32553 .69996 L .31913 .73694 L p .227 .356 .786 r
F P
0 g
s
.35321 .76247 m .31913 .73694 L .32553 .69996 L p .332 .464 .843 r
F P
0 g
s
.36546 .3776 m .37547 .34915 L .45766 .32424 L p .45 .113 .302 r
F P
0 g
s
.29175 .49508 m .29811 .53719 L .26074 .58657 L p .201 .128 .546 r
F P
0 g
s
.27548 .62603 m .26074 .58657 L .29811 .53719 L p .297 .256 .642 r
F P
0 g
s
.60566 .82032 m .56685 .81872 L .572 .8114 L p .694 .866 .963 r
F P
0 g
s
.572 .8114 m .61618 .80594 L .60566 .82032 L p .694 .866 .963 r
F P
0 g
s
.76187 .68561 m .73318 .71833 L .71512 .68203 L p .916 .87 .778 r
F P
0 g
s
.71512 .68203 m .742 .64326 L .76187 .68561 L p .916 .87 .778 r
F P
0 g
s
.52632 .81063 m .53011 .83079 L .51511 .83017 L closepath p .6 .791 .972 r
F P
0 g
s
.52632 .81063 m .54471 .82893 L .53011 .83079 L closepath p .612 .8 .971 r
F P
0 g
s
.52632 .81063 m .51511 .83017 L .50128 .82713 L closepath p .592 .781 .97 r
F P
0 g
s
.78386 .52016 m .77697 .56102 L .72452 .51549 L p .934 .707 .572 r
F P
0 g
s
.72452 .51549 m .73011 .47221 L .78386 .52016 L p .934 .707 .572 r
F P
0 g
s
.65767 .79445 m .61618 .80594 L .61714 .79043 L p .774 .888 .927 r
F P
0 g
s
.61714 .79043 m .65973 .77148 L .65767 .79445 L p .774 .888 .927 r
F P
0 g
s
.52632 .81063 m .5574 .82477 L .54471 .82893 L closepath p .627 .806 .968 r
F P
0 g
s
.72322 .3971 m .72966 .4323 L .64922 .39678 L p .847 .51 .415 r
F P
0 g
s
.64922 .39678 m .64526 .36206 L .72322 .3971 L p .847 .51 .415 r
F P
0 g
s
.52632 .81063 m .50128 .82713 L .49005 .82196 L closepath p .589 .77 .966 r
F P
0 g
s
.32553 .69996 m .35924 .73223 L .35321 .76247 L p .332 .464 .843 r
F P
0 g
s
.39211 .78311 m .35321 .76247 L .35924 .73223 L p .416 .55 .882 r
F P
0 g
s
.39211 .78311 m .43473 .79826 L .4406 .81341 L p .414 .629 .943 r
F P
0 g
s
.48263 .81519 m .4406 .81341 L .43473 .79826 L p .515 .699 .953 r
F P
0 g
s
.4406 .81341 m .48263 .81519 L .49005 .82196 L p .485 .717 .973 r
F P
0 g
s
.36546 .3776 m .36015 .41254 L .29226 .45563 L p .306 .065 .375 r
F P
0 g
s
.29175 .49508 m .29226 .45563 L .36015 .41254 L p .39 .2 .499 r
F P
0 g
s
.63781 .33437 m .64526 .36206 L .55088 .34592 L p .725 .344 .328 r
F P
0 g
s
.55088 .34592 m .54933 .31902 L .63781 .33437 L p .725 .344 .328 r
F P
0 g
s
.52632 .81063 m .56685 .81872 L .5574 .82477 L closepath p .641 .807 .963 r
F P
0 g
s
.29811 .53719 m .31113 .58058 L .27548 .62603 L p .297 .256 .642 r
F P
0 g
s
.29731 .66421 m .27548 .62603 L .31113 .58058 L p .368 .354 .712 r
F P
0 g
s
.52632 .81063 m .49005 .82196 L .48263 .81519 L closepath p .591 .76 .96 r
F P
0 g
s
.73318 .71833 m .6988 .74722 L .68312 .71765 L p .874 .864 .826 r
F P
0 g
s
.68312 .71765 m .71512 .68203 L .73318 .71833 L p .874 .864 .826 r
F P
0 g
s
.61618 .80594 m .572 .8114 L .57224 .80358 L p .72 .845 .941 r
F P
0 g
s
.57224 .80358 m .61714 .79043 L .61618 .80594 L p .72 .845 .941 r
F P
0 g
s
.52632 .81063 m .572 .8114 L .56685 .81872 L closepath p .653 .805 .956 r
F P
0 g
s
.45304 .35141 m .45766 .32424 L .54933 .31902 L p .609 .252 .339 r
F P
0 g
s
.45766 .32424 m .45304 .35141 L .36546 .3776 L p .45 .113 .302 r
F P
0 g
s
.35924 .73223 m .39737 .76009 L .39211 .78311 L p .416 .55 .882 r
F P
0 g
s
.43473 .79826 m .39211 .78311 L .39737 .76009 L p .487 .623 .91 r
F P
0 g
s
.43473 .79826 m .47988 .80752 L .48263 .81519 L p .515 .699 .953 r
F P
0 g
s
.52632 .81063 m .48263 .81519 L .47988 .80752 L closepath p .596 .752 .952 r
F P
0 g
s
.77697 .56102 m .76286 .60249 L .71307 .56064 L p .914 .736 .648 r
F P
0 g
s
.71307 .56064 m .72452 .51549 L .77697 .56102 L p .914 .736 .648 r
F P
0 g
s
.54933 .31902 m .55088 .34592 L .45304 .35141 L p .609 .252 .339 r
F P
0 g
s
.36015 .41254 m .36546 .3776 L .45304 .35141 L p .516 .242 .437 r
F P
0 g
s
.6988 .74722 m .65973 .77148 L .64706 .74907 L p .83 .853 .864 r
F P
0 g
s
.64706 .74907 m .68312 .71765 L .6988 .74722 L p .83 .853 .864 r
F P
0 g
s
.31113 .58058 m .33033 .62379 L .29731 .66421 L p .368 .354 .712 r
F P
0 g
s
.32553 .69996 m .29731 .66421 L .33033 .62379 L p .425 .434 .766 r
F P
0 g
s
.39737 .76009 m .43875 .78279 L .43473 .79826 L p .487 .623 .91 r
F P
0 g
s
.47988 .80752 m .43473 .79826 L .43875 .78279 L p .549 .687 .93 r
F P
0 g
s
.52632 .81063 m .57224 .80358 L .572 .8114 L closepath p .662 .799 .948 r
F P
0 g
s
.36015 .41254 m .35978 .45284 L .29175 .49508 L p .39 .2 .499 r
F P
0 g
s
.29811 .53719 m .29175 .49508 L .35978 .45284 L p .446 .297 .584 r
F P
0 g
s
.72966 .4323 m .73011 .47221 L .6495 .43739 L p .849 .571 .517 r
F P
0 g
s
.6495 .43739 m .64922 .39678 L .72966 .4323 L p .849 .571 .517 r
F P
0 g
s
.43875 .78279 m .48215 .79977 L .47988 .80752 L p .549 .687 .93 r
F P
0 g
s
.52632 .81063 m .47988 .80752 L .48215 .79977 L closepath p .605 .746 .944 r
F P
0 g
s
.65973 .77148 m .61714 .79043 L .60812 .77544 L p .782 .837 .894 r
F P
0 g
s
.60812 .77544 m .64706 .74907 L .65973 .77148 L p .782 .837 .894 r
F P
0 g
s
.52632 .81063 m .55814 .78982 L .56747 .79611 L closepath p .668 .781 .934 r
F P
0 g
s
.52632 .81063 m .54524 .78543 L .55814 .78982 L closepath p .665 .771 .928 r
F P
0 g
s
.52632 .81063 m .5302 .78345 L .54524 .78543 L closepath p .659 .761 .925 r
F P
0 g
s
.52632 .81063 m .51471 .78412 L .5302 .78345 L closepath p .65 .753 .925 r
F P
0 g
s
.52632 .81063 m .50055 .78736 L .51471 .78412 L closepath p .64 .747 .927 r
F P
0 g
s
.52632 .81063 m .48928 .79279 L .50055 .78736 L closepath p .628 .744 .931 r
F P
0 g
s
.52632 .81063 m .48215 .79977 L .48928 .79279 L closepath p .616 .744 .937 r
F P
0 g
s
.52632 .81063 m .56747 .79611 L .57224 .80358 L closepath p .667 .791 .94 r
F P
0 g
s
.61714 .79043 m .57224 .80358 L .56747 .79611 L p .729 .817 .92 r
F P
0 g
s
.56747 .79611 m .60812 .77544 L .61714 .79043 L p .729 .817 .92 r
F P
0 g
s
.33033 .62379 m .35502 .66543 L .32553 .69996 L p .425 .434 .766 r
F P
0 g
s
.35924 .73223 m .32553 .69996 L .35502 .66543 L p .471 .503 .81 r
F P
0 g
s
.76286 .60249 m .742 .64326 L .69623 .60613 L p .89 .755 .706 r
F P
0 g
s
.69623 .60613 m .71307 .56064 L .76286 .60249 L p .89 .755 .706 r
F P
0 g
s
.64526 .36206 m .64922 .39678 L .55171 .3804 L p .749 .434 .45 r
F P
0 g
s
.55171 .3804 m .55088 .34592 L .64526 .36206 L p .749 .434 .45 r
F P
0 g
s
.45254 .76872 m .48928 .79279 L .48215 .79977 L p .583 .684 .91 r
F P
0 g
s
.48215 .79977 m .43875 .78279 L .45254 .76872 L p .583 .684 .91 r
F P
0 g
s
.35502 .66543 m .38431 .7042 L .35924 .73223 L p .471 .503 .81 r
F P
0 g
s
.39737 .76009 m .35924 .73223 L .38431 .7042 L p .512 .566 .847 r
F P
0 g
s
.41718 .73894 m .45254 .76872 L .43875 .78279 L p .549 .625 .88 r
F P
0 g
s
.43875 .78279 m .39737 .76009 L .41718 .73894 L p .549 .625 .88 r
F P
0 g
s
.60812 .77544 m .56747 .79611 L .55814 .78982 L p .725 .787 .901 r
F P
0 g
s
.38431 .7042 m .41718 .73894 L .39737 .76009 L p .512 .566 .847 r
F P
0 g
s
.35978 .45284 m .3644 .49711 L .29811 .53719 L p .446 .297 .584 r
F P
0 g
s
.31113 .58058 m .29811 .53719 L .3644 .49711 L p .486 .372 .648 r
F P
0 g
s
.45059 .38598 m .45304 .35141 L .55088 .34592 L p .646 .351 .456 r
F P
0 g
s
.45304 .35141 m .45059 .38598 L .36015 .41254 L p .516 .242 .437 r
F P
0 g
s
.742 .64326 m .71512 .68203 L .67462 .65041 L p .865 .768 .754 r
F P
0 g
s
.67462 .65041 m .69623 .60613 L .742 .64326 L p .865 .768 .754 r
F P
0 g
s
.47479 .75769 m .50055 .78736 L .48928 .79279 L p .616 .687 .894 r
F P
0 g
s
.48928 .79279 m .45254 .76872 L .47479 .75769 L p .616 .687 .894 r
F P
0 g
s
.35978 .45284 m .36015 .41254 L .45059 .38598 L p .556 .33 .528 r
F P
0 g
s
.73011 .47221 m .72452 .51549 L .64605 .48247 L p .843 .613 .591 r
F P
0 g
s
.64605 .48247 m .6495 .43739 L .73011 .47221 L p .843 .613 .591 r
F P
0 g
s
.55814 .78982 m .58984 .7627 L .60812 .77544 L p .725 .787 .901 r
F P
0 g
s
.58984 .7627 m .55814 .78982 L .54524 .78543 L p .713 .758 .888 r
F P
0 g
s
.55088 .34592 m .55171 .3804 L .45059 .38598 L p .646 .351 .456 r
F P
0 g
s
.64706 .74907 m .60812 .77544 L .58984 .7627 L p .77 .787 .867 r
F P
0 g
s
.50306 .75107 m .51471 .78412 L .50055 .78736 L p .646 .697 .883 r
F P
0 g
s
.50055 .78736 m .47479 .75769 L .50306 .75107 L p .646 .697 .883 r
F P
0 g
s
.71512 .68203 m .68312 .71765 L .64906 .69207 L p .837 .778 .795 r
F P
0 g
s
.64906 .69207 m .67462 .65041 L .71512 .68203 L p .837 .778 .795 r
F P
0 g
s
.54524 .78543 m .5642 .75375 L .58984 .7627 L p .713 .758 .888 r
F P
0 g
s
.5642 .75375 m .54524 .78543 L .5302 .78345 L p .695 .733 .88 r
F P
0 g
s
.68312 .71765 m .64706 .74907 L .62048 .72985 L p .806 .784 .832 r
F P
0 g
s
.58984 .7627 m .62048 .72985 L .64706 .74907 L p .77 .787 .867 r
F P
0 g
s
.62048 .72985 m .64906 .69207 L .68312 .71765 L p .806 .784 .832 r
F P
0 g
s
.5341 .74969 m .5302 .78345 L .51471 .78412 L p .672 .712 .879 r
F P
0 g
s
.51471 .78412 m .50306 .75107 L .5341 .74969 L p .672 .712 .879 r
F P
0 g
s
.5302 .78345 m .5341 .74969 L .5642 .75375 L p .695 .733 .88 r
F P
0 g
s
.3644 .49711 m .37384 .54379 L .31113 .58058 L p .486 .372 .648 r
F P
0 g
s
.33033 .62379 m .31113 .58058 L .37384 .54379 L p .517 .433 .7 r
F P
0 g
s
.44982 .72224 m .47479 .75769 L .45254 .76872 L p .601 .635 .857 r
F P
0 g
s
.45254 .76872 m .41718 .73894 L .44982 .72224 L p .601 .635 .857 r
F P
0 g
s
.64922 .39678 m .6495 .43739 L .55177 .42133 L p .758 .494 .534 r
F P
0 g
s
.55177 .42133 m .55171 .3804 L .64922 .39678 L p .758 .494 .534 r
F P
0 g
s
.62048 .72985 m .58984 .7627 L .5642 .75375 L p .747 .743 .849 r
F P
0 g
s
.72452 .51549 m .71307 .56064 L .63902 .53038 L p .833 .645 .647 r
F P
0 g
s
.63902 .53038 m .64605 .48247 L .72452 .51549 L p .833 .645 .647 r
F P
0 g
s
.37384 .54379 m .38772 .59122 L .33033 .62379 L p .517 .433 .7 r
F P
0 g
s
.35502 .66543 m .33033 .62379 L .38772 .59122 L p .543 .488 .744 r
F P
0 g
s
.42644 .68189 m .44982 .72224 L .41718 .73894 L p .584 .586 .82 r
F P
0 g
s
.41718 .73894 m .38431 .7042 L .42644 .68189 L p .584 .586 .82 r
F P
0 g
s
.45059 .38598 m .45041 .4268 L .35978 .45284 L p .556 .33 .528 r
F P
0 g
s
.3644 .49711 m .35978 .45284 L .45041 .4268 L p .582 .395 .594 r
F P
0 g
s
.38772 .59122 m .40548 .63777 L .35502 .66543 L p .543 .488 .744 r
F P
0 g
s
.38431 .7042 m .35502 .66543 L .40548 .63777 L p .565 .537 .783 r
F P
0 g
s
.49172 .71215 m .50306 .75107 L .47479 .75769 L p .645 .652 .842 r
F P
0 g
s
.47479 .75769 m .44982 .72224 L .49172 .71215 L p .645 .652 .842 r
F P
0 g
s
.40548 .63777 m .42644 .68189 L .38431 .7042 L p .565 .537 .783 r
F P
0 g
s
.45041 .4268 m .45059 .38598 L .55171 .3804 L p .666 .419 .536 r
F P
0 g
s
.5642 .75375 m .58264 .71624 L .62048 .72985 L p .747 .743 .849 r
F P
0 g
s
.58264 .71624 m .5642 .75375 L .5341 .74969 L p .717 .706 .838 r
F P
0 g
s
.55171 .3804 m .55177 .42133 L .45041 .4268 L p .666 .419 .536 r
F P
0 g
s
.64906 .69207 m .62048 .72985 L .58264 .71624 L p .772 .727 .811 r
F P
0 g
s
.71307 .56064 m .69623 .60613 L .62868 .57938 L p .821 .669 .694 r
F P
0 g
s
.62868 .57938 m .63902 .53038 L .71307 .56064 L p .821 .669 .694 r
F P
0 g
s
.5379 .71006 m .5341 .74969 L .50306 .75107 L p .683 .676 .836 r
F P
0 g
s
.50306 .75107 m .49172 .71215 L .5379 .71006 L p .683 .676 .836 r
F P
0 g
s
.5341 .74969 m .5379 .71006 L .58264 .71624 L p .717 .706 .838 r
F P
0 g
s
.6495 .43739 m .64605 .48247 L .55105 .46725 L p .761 .538 .595 r
F P
0 g
s
.55105 .46725 m .55177 .42133 L .6495 .43739 L p .761 .538 .595 r
F P
0 g
s
.45041 .4268 m .45255 .47243 L .3644 .49711 L p .582 .395 .594 r
F P
0 g
s
.37384 .54379 m .3644 .49711 L .45255 .47243 L p .601 .448 .646 r
F P
0 g
s
.67462 .65041 m .64906 .69207 L .59994 .67384 L p .791 .709 .774 r
F P
0 g
s
.58264 .71624 m .59994 .67384 L .64906 .69207 L p .772 .727 .811 r
F P
0 g
s
.69623 .60613 m .67462 .65041 L .61548 .62774 L p .808 .691 .736 r
F P
0 g
s
.61548 .62774 m .62868 .57938 L .69623 .60613 L p .808 .691 .736 r
F P
0 g
s
.48106 .66835 m .49172 .71215 L .44982 .72224 L p .641 .611 .804 r
F P
0 g
s
.44982 .72224 m .42644 .68189 L .48106 .66835 L p .641 .611 .804 r
F P
0 g
s
.59994 .67384 m .61548 .62774 L .67462 .65041 L p .791 .709 .774 r
F P
0 g
s
.45255 .47243 m .45041 .4268 L .55177 .42133 L p .678 .47 .596 r
F P
0 g
s
.59994 .67384 m .58264 .71624 L .5379 .71006 L p .732 .68 .8 r
F P
0 g
s
.45255 .47243 m .45691 .52119 L .37384 .54379 L p .601 .448 .646 r
F P
0 g
s
.38772 .59122 m .37384 .54379 L .45691 .52119 L p .615 .493 .69 r
F P
0 g
s
.47146 .62089 m .48106 .66835 L .42644 .68189 L p .634 .572 .767 r
F P
0 g
s
.42644 .68189 m .40548 .63777 L .47146 .62089 L p .634 .572 .767 r
F P
0 g
s
.54147 .66552 m .5379 .71006 L .49172 .71215 L p .689 .642 .798 r
F P
0 g
s
.49172 .71215 m .48106 .66835 L .54147 .66552 L p .689 .642 .798 r
F P
0 g
s
.55177 .42133 m .55105 .46725 L .45255 .47243 L p .678 .47 .596 r
F P
0 g
s
.64605 .48247 m .63902 .53038 L .54959 .51645 L p .759 .573 .645 r
F P
0 g
s
.54959 .51645 m .55105 .46725 L .64605 .48247 L p .759 .573 .645 r
F P
0 g
s
.5379 .71006 m .54147 .66552 L .59994 .67384 L p .732 .68 .8 r
F P
0 g
s
.45691 .52119 m .4633 .57127 L .38772 .59122 L p .615 .493 .69 r
F P
0 g
s
.40548 .63777 m .38772 .59122 L .4633 .57127 L p .626 .533 .73 r
F P
0 g
s
.4633 .57127 m .47146 .62089 L .40548 .63777 L p .626 .533 .73 r
F P
0 g
s
.61548 .62774 m .59994 .67384 L .54147 .66552 L p .743 .655 .763 r
F P
0 g
s
.45691 .52119 m .45255 .47243 L .55105 .46725 L p .685 .511 .644 r
F P
0 g
s
.63902 .53038 m .62868 .57938 L .54744 .56709 L p .756 .603 .687 r
F P
0 g
s
.54744 .56709 m .54959 .51645 L .63902 .53038 L p .756 .603 .687 r
F P
0 g
s
.54469 .61736 m .54147 .66552 L .48106 .66835 L p .692 .61 .761 r
F P
0 g
s
.48106 .66835 m .47146 .62089 L .54469 .61736 L p .692 .61 .761 r
F P
0 g
s
.62868 .57938 m .61548 .62774 L .54469 .61736 L p .751 .63 .726 r
F P
0 g
s
.54147 .66552 m .54469 .61736 L .61548 .62774 L p .743 .655 .763 r
F P
0 g
s
.54469 .61736 m .54744 .56709 L .62868 .57938 L p .751 .63 .726 r
F P
0 g
s
.55105 .46725 m .54959 .51645 L .45691 .52119 L p .685 .511 .644 r
F P
0 g
s
.4633 .57127 m .45691 .52119 L .54959 .51645 L p .69 .546 .686 r
F P
0 g
s
.54744 .56709 m .54469 .61736 L .47146 .62089 L p .692 .579 .724 r
F P
0 g
s
.47146 .62089 m .4633 .57127 L .54744 .56709 L p .692 .579 .724 r
F P
0 g
s
.54959 .51645 m .54744 .56709 L .4633 .57127 L p .69 .546 .686 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48443 .50387 m .47702 .54894 L .54297 .55222 L p .718 .601 .724 r
F P
0 g
s
.54297 .55222 m .54047 .50673 L .48443 .50387 L p .718 .601 .724 r
F P
0 g
s
.54494 .59696 m .54297 .55222 L .47702 .54894 L p .72 .574 .69 r
F P
0 g
s
.54047 .50673 m .54297 .55222 L .60748 .54238 L p .671 .564 .726 r
F P
0 g
s
.54297 .55222 m .54494 .59696 L .61717 .58624 L p .666 .533 .692 r
F P
0 g
s
.61717 .58624 m .60748 .54238 L .54297 .55222 L p .666 .533 .692 r
F P
0 g
s
.47702 .54894 m .47116 .5934 L .54494 .59696 L p .72 .574 .69 r
F P
0 g
s
.54636 .63987 m .54494 .59696 L .47116 .5934 L p .72 .547 .655 r
F P
0 g
s
.54494 .59696 m .54636 .63987 L .62415 .62863 L p .659 .499 .656 r
F P
0 g
s
.62415 .62863 m .61717 .58624 L .54494 .59696 L p .659 .499 .656 r
F P
0 g
s
.43216 .48978 m .41534 .53277 L .47702 .54894 L p .762 .643 .729 r
F P
0 g
s
.47702 .54894 m .48443 .50387 L .43216 .48978 L p .762 .643 .729 r
F P
0 g
s
.47116 .5934 m .47702 .54894 L .41534 .53277 L p .771 .622 .695 r
F P
0 g
s
.49328 .45936 m .48443 .50387 L .54047 .50673 L p .715 .626 .757 r
F P
0 g
s
.54047 .50673 m .53748 .46168 L .49328 .45936 L p .715 .626 .757 r
F P
0 g
s
.53748 .46168 m .54047 .50673 L .59524 .49815 L p .675 .596 .759 r
F P
0 g
s
.60748 .54238 m .59524 .49815 L .54047 .50673 L p .671 .564 .726 r
F P
0 g
s
.45216 .44798 m .43216 .48978 L .48443 .50387 L p .751 .662 .763 r
F P
0 g
s
.48443 .50387 m .49328 .45936 L .45216 .44798 L p .751 .662 .763 r
F P
0 g
s
.41534 .53277 m .40201 .57575 L .47116 .5934 L p .771 .622 .695 r
F P
0 g
s
.46695 .63613 m .47116 .5934 L .40201 .57575 L p .777 .599 .657 r
F P
0 g
s
.47116 .5934 m .46695 .63613 L .54636 .63987 L p .72 .547 .655 r
F P
0 g
s
.59524 .49815 m .60748 .54238 L .6649 .52007 L p .619 .533 .735 r
F P
0 g
s
.60748 .54238 m .61717 .58624 L .68168 .56188 L p .605 .493 .699 r
F P
0 g
s
.68168 .56188 m .6649 .52007 L .60748 .54238 L p .605 .493 .699 r
F P
0 g
s
.54722 .67997 m .54636 .63987 L .46695 .63613 L p .718 .515 .615 r
F P
0 g
s
.54636 .63987 m .54722 .67997 L .62834 .66854 L p .65 .462 .615 r
F P
0 g
s
.62834 .66854 m .62415 .62863 L .54636 .63987 L p .65 .462 .615 r
F P
0 g
s
.59524 .49815 m .58065 .45474 L .53748 .46168 L p .675 .596 .759 r
F P
0 g
s
.58065 .45474 m .59524 .49815 L .64375 .47876 L p .632 .571 .768 r
F P
0 g
s
.6649 .52007 m .64375 .47876 L .59524 .49815 L p .619 .533 .735 r
F P
0 g
s
.50336 .41667 m .49328 .45936 L .53748 .46168 L p .709 .652 .791 r
F P
0 g
s
.53748 .46168 m .53408 .41832 L .50336 .41667 L p .709 .652 .791 r
F P
0 g
s
.53408 .41832 m .53748 .46168 L .58065 .45474 L p .678 .629 .793 r
F P
0 g
s
.61717 .58624 m .62415 .62863 L .6938 .60303 L p .589 .45 .66 r
F P
0 g
s
.6938 .60303 m .68168 .56188 L .61717 .58624 L p .589 .45 .66 r
F P
0 g
s
.4749 .40859 m .45216 .44798 L .49328 .45936 L p .737 .681 .796 r
F P
0 g
s
.49328 .45936 m .50336 .41667 L .4749 .40859 L p .737 .681 .796 r
F P
0 g
s
.40201 .57575 m .39239 .61761 L .46695 .63613 L p .777 .599 .657 r
F P
0 g
s
.46441 .67616 m .46695 .63613 L .39239 .61761 L p .782 .572 .616 r
F P
0 g
s
.46695 .63613 m .46441 .67616 L .54722 .67997 L p .718 .515 .615 r
F P
0 g
s
.38856 .46549 m .36353 .50476 L .41534 .53277 L p .805 .693 .742 r
F P
0 g
s
.41534 .53277 m .43216 .48978 L .38856 .46549 L p .805 .693 .742 r
F P
0 g
s
.40201 .57575 m .41534 .53277 L .36353 .50476 L p .822 .679 .705 r
F P
0 g
s
.58065 .45474 m .56403 .41339 L .53408 .41832 L p .678 .629 .793 r
F P
0 g
s
.56403 .41339 m .58065 .45474 L .61868 .43911 L p .645 .611 .801 r
F P
0 g
s
.64375 .47876 m .61868 .43911 L .58065 .45474 L p .632 .571 .768 r
F P
0 g
s
.41814 .42845 m .38856 .46549 L .43216 .48978 L p .786 .706 .776 r
F P
0 g
s
.43216 .48978 m .45216 .44798 L .41814 .42845 L p .786 .706 .776 r
F P
0 g
s
.62415 .62863 m .62834 .66854 L .7011 .64248 L p .57 .403 .616 r
F P
0 g
s
.7011 .64248 m .6938 .60303 L .62415 .62863 L p .57 .403 .616 r
F P
0 g
s
.36353 .50476 m .34362 .54511 L .40201 .57575 L p .822 .679 .705 r
F P
0 g
s
.39239 .61761 m .40201 .57575 L .34362 .54511 L p .836 .66 .664 r
F P
0 g
s
.5475 .71638 m .54722 .67997 L .46441 .67616 L p .713 .479 .569 r
F P
0 g
s
.54722 .67997 m .5475 .71638 L .62974 .70506 L p .638 .418 .568 r
F P
0 g
s
.62974 .70506 m .62834 .66854 L .54722 .67997 L p .638 .418 .568 r
F P
0 g
s
.45156 .3948 m .41814 .42845 L .45216 .44798 L p .762 .715 .808 r
F P
0 g
s
.45216 .44798 m .4749 .40859 L .45156 .3948 L p .762 .715 .808 r
F P
0 g
s
.51447 .37711 m .50336 .41667 L .53408 .41832 L p .699 .68 .828 r
F P
0 g
s
.53408 .41832 m .53032 .37798 L .51447 .37711 L p .699 .68 .828 r
F P
0 g
s
.53032 .37798 m .53408 .41832 L .56403 .41339 L p .679 .665 .829 r
F P
0 g
s
.39239 .61761 m .38662 .65732 L .46441 .67616 L p .782 .572 .616 r
F P
0 g
s
.46357 .71262 m .46441 .67616 L .38662 .65732 L p .784 .539 .566 r
F P
0 g
s
.46441 .67616 m .46357 .71262 L .5475 .71638 L p .713 .479 .569 r
F P
0 g
s
.49984 .37286 m .4749 .40859 L .50336 .41667 L p .718 .7 .832 r
F P
0 g
s
.50336 .41667 m .51447 .37711 L .49984 .37286 L p .718 .7 .832 r
F P
0 g
s
.61868 .43911 m .64375 .47876 L .68126 .45001 L p .583 .552 .786 r
F P
0 g
s
.64375 .47876 m .6649 .52007 L .70969 .48685 L p .557 .504 .751 r
F P
0 g
s
.70969 .48685 m .68126 .45001 L .64375 .47876 L p .557 .504 .751 r
F P
0 g
s
.6649 .52007 m .68168 .56188 L .73238 .52544 L p .529 .452 .713 r
F P
0 g
s
.73238 .52544 m .70969 .48685 L .6649 .52007 L p .529 .452 .713 r
F P
0 g
s
.56403 .41339 m .54576 .37538 L .53032 .37798 L p .679 .665 .829 r
F P
0 g
s
.54576 .37538 m .56403 .41339 L .59026 .40231 L p .656 .654 .836 r
F P
0 g
s
.61868 .43911 m .59026 .40231 L .56403 .41339 L p .645 .611 .801 r
F P
0 g
s
.59026 .40231 m .61868 .43911 L .64776 .41607 L p .608 .6 .817 r
F P
0 g
s
.68126 .45001 m .64776 .41607 L .61868 .43911 L p .583 .552 .786 r
F P
0 g
s
.34362 .54511 m .32922 .58539 L .39239 .61761 L p .836 .66 .664 r
F P
0 g
s
.38662 .65732 m .39239 .61761 L .32922 .58539 L p .849 .637 .616 r
F P
0 g
s
.48795 .36565 m .45156 .3948 L .4749 .40859 L p .734 .723 .841 r
F P
0 g
s
.4749 .40859 m .49984 .37286 L .48795 .36565 L p .734 .723 .841 r
F P
0 g
s
.62834 .66854 m .62974 .70506 L .70353 .67925 L p .546 .347 .562 r
F P
0 g
s
.70353 .67925 m .7011 .64248 L .62834 .66854 L p .546 .347 .562 r
F P
0 g
s
.68168 .56188 m .6938 .60303 L .74883 .56465 L p .497 .395 .669 r
F P
0 g
s
.74883 .56465 m .73238 .52544 L .68168 .56188 L p .497 .395 .669 r
F P
0 g
s
.39478 .40245 m .35816 .43292 L .38856 .46549 L p .816 .758 .798 r
F P
0 g
s
.38856 .46549 m .41814 .42845 L .39478 .40245 L p .816 .758 .798 r
F P
0 g
s
.36353 .50476 m .38856 .46549 L .35816 .43292 L p .847 .757 .764 r
F P
0 g
s
.59026 .40231 m .55919 .36957 L .54576 .37538 L p .656 .654 .836 r
F P
0 g
s
.55919 .36957 m .59026 .40231 L .61006 .3861 L p .633 .648 .847 r
F P
0 g
s
.64776 .41607 m .61006 .3861 L .59026 .40231 L p .608 .6 .817 r
F P
0 g
s
.54723 .74838 m .5475 .71638 L .46357 .71262 L p .705 .434 .512 r
F P
0 g
s
.5475 .71638 m .54723 .74838 L .62841 .73744 L p .622 .366 .509 r
F P
0 g
s
.62841 .73744 m .62974 .70506 L .5475 .71638 L p .622 .366 .509 r
F P
0 g
s
.43582 .37658 m .39478 .40245 L .41814 .42845 L p .783 .755 .828 r
F P
0 g
s
.41814 .42845 m .45156 .3948 L .43582 .37658 L p .783 .755 .828 r
F P
0 g
s
.35816 .43292 m .32695 .467 L .36353 .50476 L p .847 .757 .764 r
F P
0 g
s
.34362 .54511 m .36353 .50476 L .32695 .467 L p .874 .751 .723 r
F P
0 g
s
.38662 .65732 m .38468 .69396 L .46357 .71262 L p .784 .539 .566 r
F P
0 g
s
.46437 .74474 m .46357 .71262 L .38468 .69396 L p .782 .497 .504 r
F P
0 g
s
.46357 .71262 m .46437 .74474 L .54723 .74838 L p .705 .434 .512 r
F P
0 g
s
.32922 .58539 m .32054 .6245 L .38662 .65732 L p .849 .637 .616 r
F P
0 g
s
.38468 .69396 m .38662 .65732 L .32054 .6245 L p .858 .606 .556 r
F P
0 g
s
.6938 .60303 m .7011 .64248 L .75876 .60334 L p .459 .328 .615 r
F P
0 g
s
.75876 .60334 m .74883 .56465 L .6938 .60303 L p .459 .328 .615 r
F P
0 g
s
.4801 .35619 m .43582 .37658 L .45156 .3948 L p .744 .748 .855 r
F P
0 g
s
.45156 .3948 m .48795 .36565 L .4801 .35619 L p .744 .748 .855 r
F P
0 g
s
.53032 .37798 m .52632 .34202 L .51447 .37711 L closepath p .684 .711 .869 r
F P
0 g
s
.54576 .37538 m .52632 .34202 L .53032 .37798 L closepath p .676 .705 .869 r
F P
0 g
s
.51447 .37711 m .52632 .34202 L .49984 .37286 L closepath p .691 .718 .87 r
F P
0 g
s
.55919 .36957 m .52632 .34202 L .54576 .37538 L closepath p .667 .701 .872 r
F P
0 g
s
.49984 .37286 m .52632 .34202 L .48795 .36565 L closepath p .696 .727 .874 r
F P
0 g
s
.32695 .467 m .30197 .5036 L .34362 .54511 L p .874 .751 .723 r
F P
0 g
s
.32922 .58539 m .34362 .54511 L .30197 .5036 L p .9 .74 .674 r
F P
0 g
s
.61006 .3861 m .64776 .41607 L .66461 .38768 L p .569 .596 .841 r
F P
0 g
s
.64776 .41607 m .68126 .45001 L .70351 .41431 L p .525 .54 .813 r
F P
0 g
s
.70351 .41431 m .66461 .38768 L .64776 .41607 L p .525 .54 .813 r
F P
0 g
s
.62974 .70506 m .62841 .73744 L .70122 .71251 L p .515 .278 .494 r
F P
0 g
s
.70122 .71251 m .70353 .67925 L .62974 .70506 L p .515 .278 .494 r
F P
0 g
s
.68126 .45001 m .70969 .48685 L .7368 .4453 L p .477 .477 .779 r
F P
0 g
s
.7368 .4453 m .70351 .41431 L .68126 .45001 L p .477 .477 .779 r
F P
0 g
s
.56919 .36112 m .52632 .34202 L .55919 .36957 L closepath p .659 .7 .877 r
F P
0 g
s
.61006 .3861 m .56919 .36112 L .55919 .36957 L p .633 .648 .847 r
F P
0 g
s
.56919 .36112 m .61006 .3861 L .62123 .3663 L p .611 .65 .864 r
F P
0 g
s
.66461 .38768 m .62123 .3663 L .61006 .3861 L p .569 .596 .841 r
F P
0 g
s
.48795 .36565 m .52632 .34202 L .4801 .35619 L closepath p .699 .736 .88 r
F P
0 g
s
.70969 .48685 m .73238 .52544 L .76353 .47965 L p .422 .405 .736 r
F P
0 g
s
.76353 .47965 m .7368 .4453 L .70969 .48685 L p .422 .405 .736 r
F P
0 g
s
.7011 .64248 m .70353 .67925 L .76208 .64047 L p .411 .247 .546 r
F P
0 g
s
.76208 .64047 m .75876 .60334 L .7011 .64248 L p .411 .247 .546 r
F P
0 g
s
.57466 .3509 m .52632 .34202 L .56919 .36112 L closepath p .652 .702 .883 r
F P
0 g
s
.62123 .3663 m .57466 .3509 L .56919 .36112 L p .611 .65 .864 r
F P
0 g
s
.54643 .77538 m .54723 .74838 L .46437 .74474 L p .69 .375 .437 r
F P
0 g
s
.54723 .74838 m .54643 .77538 L .62448 .76505 L p .596 .297 .432 r
F P
0 g
s
.62448 .76505 m .62841 .73744 L .54723 .74838 L p .596 .297 .432 r
F P
0 g
s
.47717 .34548 m .42955 .35571 L .43582 .37658 L p .748 .774 .874 r
F P
0 g
s
.43582 .37658 m .4801 .35619 L .47717 .34548 L p .748 .774 .874 r
F P
0 g
s
.39478 .40245 m .43582 .37658 L .42955 .35571 L p .795 .799 .856 r
F P
0 g
s
.30197 .5036 m .28382 .54158 L .32922 .58539 L p .9 .74 .674 r
F P
0 g
s
.32054 .6245 m .32922 .58539 L .28382 .54158 L p .923 .721 .612 r
F P
0 g
s
.42955 .35571 m .38496 .37238 L .39478 .40245 L p .795 .799 .856 r
F P
0 g
s
.35816 .43292 m .39478 .40245 L .38496 .37238 L p .839 .82 .831 r
F P
0 g
s
.32054 .6245 m .31763 .66144 L .38468 .69396 L p .858 .606 .556 r
F P
0 g
s
.38652 .72671 m .38468 .69396 L .31763 .66144 L p .862 .562 .479 r
F P
0 g
s
.38468 .69396 m .38652 .72671 L .46437 .74474 L p .782 .497 .504 r
F P
0 g
s
.4801 .35619 m .52632 .34202 L .47717 .34548 L closepath p .699 .744 .887 r
F P
0 g
s
.46675 .77195 m .46437 .74474 L .38652 .72671 L p .773 .439 .421 r
F P
0 g
s
.46437 .74474 m .46675 .77195 L .54643 .77538 L p .69 .375 .437 r
F P
0 g
s
.38496 .37238 m .34478 .39495 L .35816 .43292 L p .839 .82 .831 r
F P
0 g
s
.32695 .467 m .35816 .43292 L .34478 .39495 L p .882 .836 .796 r
F P
0 g
s
.73238 .52544 m .74883 .56465 L .78302 .51622 L p .356 .319 .68 r
F P
0 g
s
.78302 .51622 m .76353 .47965 L .73238 .52544 L p .356 .319 .68 r
F P
0 g
s
.57493 .33997 m .52632 .34202 L .57466 .3509 L closepath p .646 .706 .89 r
F P
0 g
s
.57466 .3509 m .62123 .3663 L .6223 .3449 L p .59 .658 .885 r
F P
0 g
s
.6223 .3449 m .57493 .33997 L .57466 .3509 L p .59 .658 .885 r
F P
0 g
s
.62123 .3663 m .66461 .38768 L .6669 .35669 L p .527 .603 .872 r
F P
0 g
s
.6669 .35669 m .6223 .3449 L .62123 .3663 L p .527 .603 .872 r
F P
0 g
s
.56002 .32071 m .52632 .34202 L .56989 .32952 L closepath p .643 .722 .905 r
F P
0 g
s
.54636 .31456 m .52632 .34202 L .56002 .32071 L closepath p .646 .731 .911 r
F P
0 g
s
.53043 .31179 m .52632 .34202 L .54636 .31456 L closepath p .653 .741 .914 r
F P
0 g
s
.51402 .31273 m .52632 .34202 L .53043 .31179 L closepath p .662 .749 .915 r
F P
0 g
s
.49902 .31727 m .52632 .34202 L .51402 .31273 L closepath p .672 .755 .913 r
F P
0 g
s
.4871 .32486 m .52632 .34202 L .49902 .31727 L closepath p .682 .757 .908 r
F P
0 g
s
.47956 .33464 m .52632 .34202 L .4871 .32486 L closepath p .69 .756 .902 r
F P
0 g
s
.47717 .34548 m .52632 .34202 L .47956 .33464 L closepath p .696 .751 .894 r
F P
0 g
s
.56989 .32952 m .52632 .34202 L .57493 .33997 L closepath p .643 .713 .898 r
F P
0 g
s
.62841 .73744 m .62448 .76505 L .69438 .74153 L p .47 .188 .402 r
F P
0 g
s
.69438 .74153 m .70122 .71251 L .62841 .73744 L p .47 .188 .402 r
F P
0 g
s
.42955 .35571 m .47717 .34548 L .47956 .33464 L p .743 .798 .896 r
F P
0 g
s
.66461 .38768 m .70351 .41431 L .70729 .37499 L p .454 .536 .851 r
F P
0 g
s
.70729 .37499 m .6669 .35669 L .66461 .38768 L p .454 .536 .851 r
F P
0 g
s
.34478 .39495 m .31025 .42265 L .32695 .467 L p .882 .836 .796 r
F P
0 g
s
.30197 .5036 m .32695 .467 L .31025 .42265 L p .924 .847 .749 r
F P
0 g
s
.28382 .54158 m .27284 .57979 L .32054 .6245 L p .923 .721 .612 r
F P
0 g
s
.31763 .66144 m .32054 .6245 L .27284 .57979 L p .941 .689 .529 r
F P
0 g
s
.57493 .33997 m .6223 .3449 L .61281 .32421 L p .574 .675 .908 r
F P
0 g
s
.61281 .32421 m .56989 .32952 L .57493 .33997 L p .574 .675 .908 r
F P
0 g
s
.70353 .67925 m .70122 .71251 L .75893 .67505 L p .348 .143 .454 r
F P
0 g
s
.75893 .67505 m .76208 .64047 L .70353 .67925 L p .348 .143 .454 r
F P
0 g
s
.47956 .33464 m .43375 .33436 L .42955 .35571 L p .743 .798 .896 r
F P
0 g
s
.38496 .37238 m .42955 .35571 L .43375 .33436 L p .792 .844 .891 r
F P
0 g
s
.74883 .56465 m .75876 .60334 L .79481 .55386 L p .274 .212 .604 r
F P
0 g
s
.79481 .55386 m .78302 .51622 L .74883 .56465 L p .274 .212 .604 r
F P
0 g
s
.43375 .33436 m .47956 .33464 L .4871 .32486 L p .727 .816 .92 r
F P
0 g
s
.31763 .66144 m .32039 .6953 L .38652 .72671 L p .862 .562 .479 r
F P
0 g
s
.39194 .75493 m .38652 .72671 L .32039 .6953 L p .856 .498 .372 r
F P
0 g
s
.38652 .72671 m .39194 .75493 L .46675 .77195 L p .773 .439 .421 r
F P
0 g
s
.70351 .41431 m .7368 .4453 L .74216 .3992 L p .364 .451 .817 r
F P
0 g
s
.74216 .3992 m .70729 .37499 L .70351 .41431 L p .364 .451 .817 r
F P
0 g
s
.54514 .79694 m .54643 .77538 L .46675 .77195 L p .662 .292 .333 r
F P
0 g
s
.54643 .77538 m .54514 .79694 L .61813 .78742 L p .556 .202 .324 r
F P
0 g
s
.61813 .78742 m .62448 .76505 L .54643 .77538 L p .556 .202 .324 r
F P
0 g
s
.56989 .32952 m .61281 .32421 L .59352 .3066 L p .566 .7 .931 r
F P
0 g
s
.59352 .3066 m .56002 .32071 L .56989 .32952 L p .566 .7 .931 r
F P
0 g
s
.6223 .3449 m .6669 .35669 L .65365 .32642 L p .486 .622 .91 r
F P
0 g
s
.65365 .32642 m .61281 .32421 L .6223 .3449 L p .486 .622 .91 r
F P
0 g
s
.43375 .33436 m .39039 .34131 L .38496 .37238 L p .792 .844 .891 r
F P
0 g
s
.34478 .39495 m .38496 .37238 L .39039 .34131 L p .842 .889 .874 r
F P
0 g
s
.31025 .42265 m .28242 .45456 L .30197 .5036 L p .924 .847 .749 r
F P
0 g
s
.28382 .54158 m .30197 .5036 L .28242 .45456 L p .962 .847 .682 r
F P
0 g
s
.47059 .79377 m .46675 .77195 L .39194 .75493 L p .751 .356 .304 r
F P
0 g
s
.46675 .77195 m .47059 .79377 L .54514 .79694 L p .662 .292 .333 r
F P
0 g
s
.44829 .31492 m .4871 .32486 L .49902 .31727 L p .698 .823 .942 r
F P
0 g
s
.4871 .32486 m .44829 .31492 L .43375 .33436 L p .727 .816 .92 r
F P
0 g
s
.56002 .32071 m .59352 .3066 L .56641 .29421 L p .57 .732 .951 r
F P
0 g
s
.56641 .29421 m .54636 .31456 L .56002 .32071 L p .57 .732 .951 r
F P
0 g
s
.7368 .4453 m .76353 .47965 L .77036 .42851 L p .25 .341 .762 r
F P
0 g
s
.77036 .42851 m .74216 .3992 L .7368 .4453 L p .25 .341 .762 r
F P
0 g
s
.27284 .57979 m .26917 .61711 L .31763 .66144 L p .941 .689 .529 r
F P
0 g
s
.32039 .6953 m .31763 .66144 L .26917 .61711 L p .947 .635 .412 r
F P
0 g
s
.62448 .76505 m .61813 .78742 L .68334 .76577 L p .402 .062 .271 r
F P
0 g
s
.68334 .76577 m .69438 .74153 L .62448 .76505 L p .402 .062 .271 r
F P
0 g
s
.47179 .29967 m .49902 .31727 L .51402 .31273 L p .661 .816 .958 r
F P
0 g
s
.49902 .31727 m .47179 .29967 L .44829 .31492 L p .698 .823 .942 r
F P
0 g
s
.39039 .34131 m .43375 .33436 L .44829 .31492 L p .765 .881 .93 r
F P
0 g
s
.75876 .60334 m .76208 .64047 L .79877 .59139 L p .165 .072 .495 r
F P
0 g
s
.79877 .59139 m .79481 .55386 L .75876 .60334 L p .165 .072 .495 r
F P
0 g
s
.70122 .71251 m .69438 .74153 L .74962 .70625 L p .259 .003 .323 r
F P
0 g
s
.74962 .70625 m .75893 .67505 L .70122 .71251 L p .259 .003 .323 r
F P
0 g
s
.54636 .31456 m .56641 .29421 L .53455 .2886 L p .589 .765 .963 r
F P
0 g
s
.53455 .2886 m .53043 .31179 L .54636 .31456 L p .589 .765 .963 r
F P
0 g
s
.50171 .29051 m .51402 .31273 L .53043 .31179 L p .621 .796 .966 r
F P
0 g
s
.51402 .31273 m .50171 .29051 L .47179 .29967 L p .661 .816 .958 r
F P
0 g
s
.39039 .34131 m .35092 .35534 L .34478 .39495 L p .842 .889 .874 r
F P
0 g
s
.31025 .42265 m .34478 .39495 L .35092 .35534 L p .891 .93 .838 r
F P
0 g
s
.53043 .31179 m .53455 .2886 L .50171 .29051 L p .621 .796 .966 r
F P
0 g
s
.6669 .35669 m .70729 .37499 L .691 .33622 L p .366 .544 .897 r
F P
0 g
s
.691 .33622 m .65365 .32642 L .6669 .35669 L p .366 .544 .897 r
F P
0 g
s
.28242 .45456 m .26208 .48961 L .28382 .54158 L p .962 .847 .682 r
F P
0 g
s
.27284 .57979 m .28382 .54158 L .26208 .48961 L p .992 .83 .581 r
F P
0 g
s
.61281 .32421 m .65365 .32642 L .62568 .30042 L p .451 .657 .949 r
F P
0 g
s
.62568 .30042 m .59352 .3066 L .61281 .32421 L p .451 .657 .949 r
F P
0 g
s
.32039 .6953 m .32853 .72531 L .39194 .75493 L p .856 .498 .372 r
F P
0 g
s
.40069 .7781 m .39194 .75493 L .32853 .72531 L p .827 .397 .217 r
F P
0 g
s
.39194 .75493 m .40069 .7781 L .47059 .79377 L p .751 .356 .304 r
F P
0 g
s
.76353 .47965 m .78302 .51622 L .79104 .4619 L p .1 .191 .673 r
F P
0 g
s
.79104 .4619 m .77036 .42851 L .76353 .47965 L p .1 .191 .673 r
F P
0 g
s
.54339 .81277 m .54514 .79694 L .47059 .79377 L p .608 .167 .176 r
F P
0 g
s
.54514 .79694 m .54339 .81277 L .60957 .80423 L p .484 .061 .161 r
F P
0 g
s
.60957 .80423 m .61813 .78742 L .54514 .79694 L p .484 .061 .161 r
F P
0 g
s
.41119 .31272 m .44829 .31492 L .47179 .29967 L p .705 .897 .966 r
F P
0 g
s
.44829 .31492 m .41119 .31272 L .39039 .34131 L p .765 .881 .93 r
F P
0 g
s
.35092 .35534 m .39039 .34131 L .41119 .31272 L p .799 .948 .919 r
F P
0 g
s
.47576 .80992 m .47059 .79377 L .40069 .7781 L p .697 .225 .128 r
F P
0 g
s
.47059 .79377 m .47576 .80992 L .54339 .81277 L p .608 .167 .176 r
F P
0 g
s
.35092 .35534 m .31671 .37602 L .31025 .42265 L p .891 .93 .838 r
F P
0 g
s
.28242 .45456 m .31025 .42265 L .31671 .37602 L p .933 .958 .767 r
F P
0 g
s
.26917 .61711 m .27265 .6525 L .32039 .6953 L p .947 .635 .412 r
F P
0 g
s
.32853 .72531 m .32039 .6953 L .27265 .6525 L p .925 .541 .242 r
F P
0 g
s
.76208 .64047 m .75893 .67505 L .79502 .62769 L p .019 0 .337 r
F P
0 g
s
.79502 .62769 m .79877 .59139 L .76208 .64047 L p .019 0 .337 r
F P
0 g
s
.70729 .37499 m .74216 .3992 L .72351 .35338 L p .195 .423 .854 r
F P
0 g
s
.72351 .35338 m .691 .33622 L .70729 .37499 L p .195 .423 .854 r
F P
0 g
s
.59352 .3066 m .62568 .30042 L .58578 .28198 L p .437 .707 .98 r
F P
0 g
s
.58578 .28198 m .56641 .29421 L .59352 .3066 L p .437 .707 .98 r
F P
0 g
s
.26208 .48961 m .24974 .52661 L .27284 .57979 L p .992 .83 .581 r
F P
0 g
s
.26917 .61711 m .27284 .57979 L .24974 .52661 L p .997 .777 .429 r
F P
0 g
s
.69438 .74153 m .68334 .76577 L .73462 .7334 L p .127 0 .13 r
F P
0 g
s
.73462 .7334 m .74962 .70625 L .69438 .74153 L p .127 0 .13 r
F P
0 g
s
.61813 .78742 m .60957 .80423 L .6685 .78485 L p .29 0 .071 r
F P
0 g
s
.6685 .78485 m .68334 .76577 L .61813 .78742 L p .29 0 .071 r
F P
0 g
s
.44556 .29011 m .47179 .29967 L .50171 .29051 L p .617 .88 .99 r
F P
0 g
s
.47179 .29967 m .44556 .29011 L .41119 .31272 L p .705 .897 .966 r
F P
0 g
s
.65365 .32642 m .691 .33622 L .65534 .30263 L p .265 .567 .936 r
F P
0 g
s
.65534 .30263 m .62568 .30042 L .65365 .32642 L p .265 .567 .936 r
F P
0 g
s
.78302 .51622 m .79481 .55386 L .8036 .4982 L p 0 0 .526 r
F P
0 g
s
.8036 .4982 m .79104 .4619 L .78302 .51622 L p 0 0 .526 r
F P
0 g
s
.56641 .29421 m .58578 .28198 L .53855 .2736 L p .459 .769 .996 r
F P
0 g
s
.53855 .2736 m .53455 .2886 L .56641 .29421 L p .459 .769 .996 r
F P
0 g
s
.32853 .72531 m .34165 .75088 L .40069 .7781 L p .827 .397 .217 r
F P
0 g
s
.41247 .79588 m .40069 .7781 L .34165 .75088 L p .745 .232 0 r
F P
0 g
s
.40069 .7781 m .41247 .79588 L .47576 .80992 L p .697 .225 .128 r
F P
0 g
s
.31671 .37602 m .28893 .40268 L .28242 .45456 L p .933 .958 .767 r
F P
0 g
s
.26208 .48961 m .28242 .45456 L .28893 .40268 L p .946 .949 .634 r
F P
0 g
s
.48979 .27645 m .50171 .29051 L .53455 .2886 L p .525 .832 1 r
F P
0 g
s
.50171 .29051 m .48979 .27645 L .44556 .29011 L p .617 .88 .99 r
F P
0 g
s
.41119 .31272 m .37711 .31856 L .35092 .35534 L p .799 .948 .919 r
F P
0 g
s
.31671 .37602 m .35092 .35534 L .37711 .31856 L p .81 .996 .857 r
F P
0 g
s
.53455 .2886 m .53855 .2736 L .48979 .27645 L p .525 .832 1 r
F P
0 g
s
.74216 .3992 m .77036 .42851 L .75 .37736 L p 0 .231 .748 r
F P
0 g
s
.75 .37736 m .72351 .35338 L .74216 .3992 L p 0 .231 .748 r
F P
0 g
s
.75893 .67505 m .74962 .70625 L .78395 .66174 L p 0 0 .104 r
F P
0 g
s
.78395 .66174 m .79502 .62769 L .75893 .67505 L p 0 0 .104 r
F P
0 g
s
.37711 .31856 m .41119 .31272 L .44556 .29011 L p .676 .958 .945 r
F P
0 g
s
.27265 .6525 m .28295 .68505 L .32853 .72531 L p .925 .541 .242 r
F P
0 g
s
.34165 .75088 m .32853 .72531 L .28295 .68505 L p .841 .379 0 r
F P
0 g
s
.54125 .82272 m .54339 .81277 L .47576 .80992 L p .495 0 0 r
F P
0 g
s
.54339 .81277 m .54125 .82272 L .59906 .81531 L p .35 0 0 r
F P
0 g
s
.59906 .81531 m .60957 .80423 L .54339 .81277 L p .35 0 0 r
F P
0 g
s
.24974 .52661 m .2456 .56434 L .26917 .61711 L p .997 .777 .429 r
F P
0 g
s
.27265 .6525 m .26917 .61711 L .2456 .56434 L p .944 .659 .2 r
F P
0 g
s
.48212 .82025 m .47576 .80992 L .41247 .79588 L p .572 .015 0 r
F P
0 g
s
.47576 .80992 m .48212 .82025 L .54125 .82272 L p .495 0 0 r
F P
0 g
s
.68334 .76577 m .6685 .78485 L .71456 .75597 L p 0 0 0 r
F P
0 g
s
.71456 .75597 m .73462 .7334 L .68334 .76577 L p 0 0 0 r
F P
0 g
s
.79481 .55386 m .79877 .59139 L .80782 .53613 L p 0 0 .295 r
F P
0 g
s
.80782 .53613 m .8036 .4982 L .79481 .55386 L p 0 0 .295 r
F P
0 g
s
.62568 .30042 m .65534 .30263 L .60375 .27865 L p .182 .606 .942 r
F P
0 g
s
.60375 .27865 m .58578 .28198 L .62568 .30042 L p .182 .606 .942 r
F P
0 g
s
.60957 .80423 m .59906 .81531 L .65034 .79854 L p .104 0 0 r
F P
0 g
s
.65034 .79854 m .6685 .78485 L .60957 .80423 L p .104 0 0 r
F P
0 g
s
.691 .33622 m .72351 .35338 L .68135 .31338 L p 0 .38 .835 r
F P
0 g
s
.68135 .31338 m .65534 .30263 L .691 .33622 L p 0 .38 .835 r
F P
0 g
s
.28893 .40268 m .26851 .43436 L .26208 .48961 L p .946 .949 .634 r
F P
0 g
s
.24974 .52661 m .26208 .48961 L .26851 .43436 L p .884 .855 .402 r
F P
0 g
s
.77036 .42851 m .79104 .4619 L .76953 .4073 L p 0 0 .529 r
F P
0 g
s
.76953 .4073 m .75 .37736 L .77036 .42851 L p 0 0 .529 r
F P
0 g
s
.37711 .31856 m .34733 .33239 L .31671 .37602 L p .81 .996 .857 r
F P
0 g
s
.28893 .40268 m .31671 .37602 L .34733 .33239 L p .745 .964 .681 r
F P
0 g
s
.4213 .28925 m .44556 .29011 L .48979 .27645 L p .477 .888 .932 r
F P
0 g
s
.44556 .29011 m .4213 .28925 L .37711 .31856 L p .676 .958 .945 r
F P
0 g
s
.34165 .75088 m .35926 .77155 L .41247 .79588 L p .745 .232 0 r
F P
0 g
s
.42691 .80807 m .41247 .79588 L .35926 .77155 L p .555 0 0 r
F P
0 g
s
.41247 .79588 m .42691 .80807 L .48212 .82025 L p .572 .015 0 r
F P
0 g
s
.74962 .70625 m .73462 .7334 L .76619 .69268 L p 0 0 0 r
F P
0 g
s
.76619 .69268 m .78395 .66174 L .74962 .70625 L p 0 0 0 r
F P
0 g
s
.2456 .56434 m .24953 .6016 L .27265 .6525 L p .944 .659 .2 r
F P
0 g
s
.28295 .68505 m .27265 .6525 L .24953 .6016 L p .786 .445 0 r
F P
0 g
s
.28295 .68505 m .2995 .71398 L .34165 .75088 L p .841 .379 0 r
F P
0 g
s
.35926 .77155 m .34165 .75088 L .2995 .71398 L p .645 .129 0 r
F P
0 g
s
.58578 .28198 m .60375 .27865 L .54226 .26771 L p .175 .669 .918 r
F P
0 g
s
.54226 .26771 m .53855 .2736 L .58578 .28198 L p .175 .669 .918 r
F P
0 g
s
.79877 .59139 m .79502 .62769 L .80382 .57441 L p 0 0 0 r
F P
0 g
s
.80382 .57441 m .80782 .53613 L .79877 .59139 L p 0 0 0 r
F P
0 g
s
.34733 .33239 m .37711 .31856 L .4213 .28925 L p .537 .917 .777 r
F P
0 g
s
.53876 .82676 m .54125 .82272 L .48212 .82025 L p .266 0 0 r
F P
0 g
s
.54125 .82272 m .53876 .82676 L .58686 .82061 L p .109 0 0 r
F P
0 g
s
.58686 .82061 m .59906 .81531 L .54125 .82272 L p .109 0 0 r
F P
0 g
s
.47871 .27143 m .48979 .27645 L .53855 .2736 L p .282 .77 .909 r
F P
0 g
s
.48979 .27645 m .47871 .27143 L .4213 .28925 L p .477 .888 .932 r
F P
0 g
s
.6685 .78485 m .65034 .79854 L .6901 .77364 L p 0 0 0 r
F P
0 g
s
.6901 .77364 m .71456 .75597 L .6685 .78485 L p 0 0 0 r
F P
0 g
s
.48951 .82471 m .48212 .82025 L .42691 .80807 L p .316 0 0 r
F P
0 g
s
.48212 .82025 m .48951 .82471 L .53876 .82676 L p .266 0 0 r
F P
0 g
s
.53855 .2736 m .54226 .26771 L .47871 .27143 L p .282 .77 .909 r
F P
0 g
s
.26851 .43436 m .25608 .46992 L .24974 .52661 L p .884 .855 .402 r
F P
0 g
s
.2456 .56434 m .24974 .52661 L .25608 .46992 L p 0 0 0 r
F P
0 g
s
.72351 .35338 m .75 .37736 L .70268 .33243 L p 0 .056 .549 r
F P
0 g
s
.70268 .33243 m .68135 .31338 L .72351 .35338 L p 0 .056 .549 r
F P
0 g
s
.59906 .81531 m .58686 .82061 L .62935 .80673 L p 0 0 0 r
F P
0 g
s
.62935 .80673 m .65034 .79854 L .59906 .81531 L p 0 0 0 r
F P
0 g
s
.79104 .4619 m .8036 .4982 L .78145 .44209 L p .714 .386 0 r
F P
0 g
s
.78145 .44209 m .76953 .4073 L .79104 .4619 L p .714 .386 0 r
F P
0 g
s
.65534 .30263 m .68135 .31338 L .61959 .28466 L p 0 .329 .694 r
F P
0 g
s
.61959 .28466 m .60375 .27865 L .65534 .30263 L p 0 .329 .694 r
F P
0 g
s
.34733 .33239 m .32297 .35381 L .28893 .40268 L p .745 .964 .681 r
F P
0 g
s
.26851 .43436 m .28893 .40268 L .32297 .35381 L p 0 0 0 r
F P
0 g
s
.73462 .7334 m .71456 .75597 L .74252 .71982 L p .614 .869 .525 r
F P
0 g
s
.74252 .71982 m .76619 .69268 L .73462 .7334 L p .614 .869 .525 r
F P
0 g
s
.24953 .6016 m .26111 .63727 L .28295 .68505 L p .786 .445 0 r
F P
0 g
s
.2995 .71398 m .28295 .68505 L .26111 .63727 L p 0 0 .425 r
F P
0 g
s
.35926 .77155 m .38076 .78705 L .42691 .80807 L p .555 0 0 r
F P
0 g
s
.42691 .80807 m .44365 .81461 L .48951 .82471 L p .316 0 0 r
F P
0 g
s
.44365 .81461 m .42691 .80807 L .38076 .78705 L p 0 .335 .695 r
F P
0 g
s
.2995 .71398 m .3216 .73871 L .35926 .77155 L p .645 .129 0 r
F P
0 g
s
.38076 .78705 m .35926 .77155 L .3216 .73871 L p 0 .17 .645 r
F P
0 g
s
.79502 .62769 m .78395 .66174 L .79203 .6118 L p .829 .821 .341 r
F P
0 g
s
.79203 .6118 m .80382 .57441 L .79502 .62769 L p .829 .821 .341 r
F P
0 g
s
.4213 .28925 m .39995 .29737 L .34733 .33239 L p .537 .917 .777 r
F P
0 g
s
.39995 .29737 m .4213 .28925 L .47871 .27143 L p 0 0 0 r
F P
0 g
s
.25608 .46992 m .25189 .50804 L .2456 .56434 L p 0 0 0 r
F P
0 g
s
.24953 .6016 m .2456 .56434 L .25189 .50804 L p 0 0 .255 r
F P
0 g
s
.32297 .35381 m .34733 .33239 L .39995 .29737 L p 0 0 0 r
F P
0 g
s
.65034 .79854 m .62935 .80673 L .66198 .78622 L p .507 .905 .785 r
F P
0 g
s
.66198 .78622 m .6901 .77364 L .65034 .79854 L p .507 .905 .785 r
F P
0 g
s
.53597 .82494 m .53876 .82676 L .48951 .82471 L p .073 .631 .8 r
F P
0 g
s
.53876 .82676 m .53597 .82494 L .57324 .82017 L p .206 .732 .816 r
F P
0 g
s
.57324 .82017 m .58686 .82061 L .53876 .82676 L p .206 .732 .816 r
F P
0 g
s
.8036 .4982 m .80782 .53613 L .78546 .48037 L p .923 .643 .158 r
F P
0 g
s
.78546 .48037 m .78145 .44209 L .8036 .4982 L p .923 .643 .158 r
F P
0 g
s
.60375 .27865 m .61959 .28466 L .54555 .2715 L p .27 0 0 r
F P
0 g
s
.54555 .2715 m .54226 .26771 L .60375 .27865 L p .27 0 0 r
F P
0 g
s
.49777 .82335 m .48951 .82471 L .44365 .81461 L p .04 .583 .844 r
F P
0 g
s
.48951 .82471 m .49777 .82335 L .53597 .82494 L p .073 .631 .8 r
F P
0 g
s
.26111 .63727 m .27965 .67037 L .2995 .71398 L p 0 0 .425 r
F P
0 g
s
.3216 .73871 m .2995 .71398 L .27965 .67037 L p 0 .119 .669 r
F P
0 g
s
.75 .37736 m .76953 .4073 L .71848 .35914 L p .776 .291 0 r
F P
0 g
s
.71848 .35914 m .70268 .33243 L .75 .37736 L p .776 .291 0 r
F P
0 g
s
.71456 .75597 m .6901 .77364 L .71384 .74266 L p .729 .98 .758 r
F P
0 g
s
.71384 .74266 m .74252 .71982 L .71456 .75597 L p .729 .98 .758 r
F P
0 g
s
.32297 .35381 m .30498 .38209 L .26851 .43436 L p 0 0 0 r
F P
0 g
s
.25608 .46992 m .26851 .43436 L .30498 .38209 L p 0 0 .033 r
F P
0 g
s
.58686 .82061 m .57324 .82017 L .60599 .80943 L p .41 .86 .879 r
F P
0 g
s
.60599 .80943 m .62935 .80673 L .58686 .82061 L p .41 .86 .879 r
F P
0 g
s
.46893 .27597 m .47871 .27143 L .54226 .26771 L p .134 0 0 r
F P
0 g
s
.47871 .27143 m .46893 .27597 L .39995 .29737 L p 0 0 0 r
F P
0 g
s
.78395 .66174 m .76619 .69268 L .77317 .64719 L p .915 .942 .586 r
F P
0 g
s
.77317 .64719 m .79203 .6118 L .78395 .66174 L p .915 .942 .586 r
F P
0 g
s
.54226 .26771 m .54555 .2715 L .46893 .27597 L p .134 0 0 r
F P
0 g
s
.3216 .73871 m .34846 .75882 L .38076 .78705 L p 0 .17 .645 r
F P
0 g
s
.40557 .79726 m .38076 .78705 L .34846 .75882 L p 0 .419 .851 r
F P
0 g
s
.38076 .78705 m .40557 .79726 L .44365 .81461 L p 0 .335 .695 r
F P
0 g
s
.68135 .31338 m .70268 .33243 L .63264 .30001 L p .623 .056 0 r
F P
0 g
s
.63264 .30001 m .61959 .28466 L .68135 .31338 L p .623 .056 0 r
F P
0 g
s
.46231 .81552 m .44365 .81461 L .40557 .79726 L p .104 .575 .911 r
F P
0 g
s
.44365 .81461 m .46231 .81552 L .49777 .82335 L p .04 .583 .844 r
F P
0 g
s
.25189 .50804 m .25586 .54734 L .24953 .6016 L p 0 0 .255 r
F P
0 g
s
.26111 .63727 m .24953 .6016 L .25586 .54734 L p 0 0 .502 r
F P
0 g
s
.80782 .53613 m .80382 .57441 L .78165 .5207 L p .994 .781 .414 r
F P
0 g
s
.78165 .5207 m .78546 .48037 L .80782 .53613 L p .994 .781 .414 r
F P
0 g
s
.62935 .80673 m .60599 .80943 L .63089 .79365 L p .616 .948 .934 r
F P
0 g
s
.63089 .79365 m .66198 .78622 L .62935 .80673 L p .616 .948 .934 r
F P
0 g
s
.27965 .67037 m .3043 .70009 L .3216 .73871 L p 0 .119 .669 r
F P
0 g
s
.34846 .75882 m .3216 .73871 L .3043 .70009 L p .026 .331 .814 r
F P
0 g
s
.39995 .29737 m .38241 .31437 L .32297 .35381 L p 0 0 0 r
F P
0 g
s
.30498 .38209 m .32297 .35381 L .38241 .31437 L p .057 0 .021 r
F P
0 g
s
.6901 .77364 m .66198 .78622 L .68108 .76087 L p .762 .991 .884 r
F P
0 g
s
.68108 .76087 m .71384 .74266 L .6901 .77364 L p .762 .991 .884 r
F P
0 g
s
.38241 .31437 m .39995 .29737 L .46893 .27597 L p .194 0 0 r
F P
0 g
s
.76619 .69268 m .74252 .71982 L .74818 .67965 L p .922 .976 .738 r
F P
0 g
s
.74818 .67965 m .77317 .64719 L .76619 .69268 L p .922 .976 .738 r
F P
0 g
s
.30498 .38209 m .29398 .41612 L .25608 .46992 L p 0 0 .033 r
F P
0 g
s
.25189 .50804 m .25608 .46992 L .29398 .41612 L p 0 0 .314 r
F P
0 g
s
.53293 .81737 m .53597 .82494 L .49777 .82335 L p .363 .783 .976 r
F P
0 g
s
.53597 .82494 m .53293 .81737 L .55845 .81408 L p .443 .84 .978 r
F P
0 g
s
.55845 .81408 m .57324 .82017 L .53597 .82494 L p .443 .84 .978 r
F P
0 g
s
.76953 .4073 m .78145 .44209 L .72815 .39245 L p .914 .513 .192 r
F P
0 g
s
.72815 .39245 m .71848 .35914 L .76953 .4073 L p .914 .513 .192 r
F P
0 g
s
.50676 .81627 m .49777 .82335 L .46231 .81552 L p .332 .735 .981 r
F P
0 g
s
.49777 .82335 m .50676 .81627 L .53293 .81737 L p .363 .783 .976 r
F P
0 g
s
.25586 .54734 m .26753 .58648 L .26111 .63727 L p 0 0 .502 r
F P
0 g
s
.27965 .67037 m .26111 .63727 L .26753 .58648 L p .034 .154 .659 r
F P
0 g
s
.34846 .75882 m .37926 .77407 L .40557 .79726 L p 0 .419 .851 r
F P
0 g
s
.43308 .80213 m .40557 .79726 L .37926 .77407 L p .226 .579 .943 r
F P
0 g
s
.40557 .79726 m .43308 .80213 L .46231 .81552 L p .104 .575 .911 r
F P
0 g
s
.57324 .82017 m .55845 .81408 L .58075 .80671 L p .551 .891 .984 r
F P
0 g
s
.58075 .80671 m .60599 .80943 L .57324 .82017 L p .551 .891 .984 r
F P
0 g
s
.61959 .28466 m .63264 .30001 L .54826 .28512 L p .578 .042 0 r
F P
0 g
s
.54826 .28512 m .54555 .2715 L .61959 .28466 L p .578 .042 0 r
F P
0 g
s
.48253 .81089 m .46231 .81552 L .43308 .80213 L p .349 .698 .983 r
F P
0 g
s
.46231 .81552 m .48253 .81089 L .50676 .81627 L p .332 .735 .981 r
F P
0 g
s
.80382 .57441 m .79203 .6118 L .77047 .56159 L p .995 .841 .578 r
F P
0 g
s
.77047 .56159 m .78165 .5207 L .80382 .57441 L p .995 .841 .578 r
F P
0 g
s
.3043 .70009 m .33408 .72583 L .34846 .75882 L p .026 .331 .814 r
F P
0 g
s
.37926 .77407 m .34846 .75882 L .33408 .72583 L p .213 .478 .89 r
F P
0 g
s
.70268 .33243 m .71848 .35914 L .64234 .32425 L p .79 .323 .126 r
F P
0 g
s
.64234 .32425 m .63264 .30001 L .70268 .33243 L p .79 .323 .126 r
F P
0 g
s
.46086 .29019 m .46893 .27597 L .54555 .2715 L p .439 0 0 r
F P
0 g
s
.46893 .27597 m .46086 .29019 L .38241 .31437 L p .194 0 0 r
F P
0 g
s
.74252 .71982 m .71384 .74266 L .71808 .70846 L p .893 .967 .828 r
F P
0 g
s
.71808 .70846 m .74818 .67965 L .74252 .71982 L p .893 .967 .828 r
F P
0 g
s
.66198 .78622 m .63089 .79365 L .64515 .77429 L p .751 .956 .94 r
F P
0 g
s
.64515 .77429 m .68108 .76087 L .66198 .78622 L p .751 .956 .94 r
F P
0 g
s
.60599 .80943 m .58075 .80671 L .59751 .79595 L p .652 .914 .979 r
F P
0 g
s
.59751 .79595 m .63089 .79365 L .60599 .80943 L p .652 .914 .979 r
F P
0 g
s
.54555 .2715 m .54826 .28512 L .46086 .29019 L p .439 0 0 r
F P
0 g
s
.29398 .41612 m .29027 .45455 L .25189 .50804 L p 0 0 .314 r
F P
0 g
s
.25586 .54734 m .25189 .50804 L .29027 .45455 L p .151 .063 .493 r
F P
0 g
s
.26753 .58648 m .28616 .6242 L .27965 .67037 L p .034 .154 .659 r
F P
0 g
s
.3043 .70009 m .27965 .67037 L .28616 .6242 L p .184 .308 .757 r
F P
0 g
s
.38241 .31437 m .36938 .33972 L .30498 .38209 L p .057 0 .021 r
F P
0 g
s
.29398 .41612 m .30498 .38209 L .36938 .33972 L p .245 0 .287 r
F P
0 g
s
.78145 .44209 m .78546 .48037 L .73141 .43101 L p .946 .629 .401 r
F P
0 g
s
.73141 .43101 m .72815 .39245 L .78145 .44209 L p .946 .629 .401 r
F P
0 g
s
.37926 .77407 m .41317 .78435 L .43308 .80213 L p .226 .579 .943 r
F P
0 g
s
.46272 .80173 m .43308 .80213 L .41317 .78435 L p .396 .672 .971 r
F P
0 g
s
.43308 .80213 m .46272 .80173 L .48253 .81089 L p .349 .698 .983 r
F P
0 g
s
.5297 .80415 m .53293 .81737 L .50676 .81627 L p .526 .807 .997 r
F P
0 g
s
.53293 .81737 m .5297 .80415 L .54273 .80246 L p .564 .834 .996 r
F P
0 g
s
.54273 .80246 m .55845 .81408 L .53293 .81737 L p .564 .834 .996 r
F P
0 g
s
.51632 .80359 m .50676 .81627 L .48253 .81089 L p .505 .778 .993 r
F P
0 g
s
.50676 .81627 m .51632 .80359 L .5297 .80415 L p .526 .807 .997 r
F P
0 g
s
.36938 .33972 m .38241 .31437 L .46086 .29019 L p .389 .008 .189 r
F P
0 g
s
.79203 .6118 m .77317 .64719 L .75265 .60165 L p .967 .864 .683 r
F P
0 g
s
.75265 .60165 m .77047 .56159 L .79203 .6118 L p .967 .864 .683 r
F P
0 g
s
.33408 .72583 m .36797 .74718 L .37926 .77407 L p .213 .478 .89 r
F P
0 g
s
.41317 .78435 m .37926 .77407 L .36797 .74718 L p .351 .58 .928 r
F P
0 g
s
.71384 .74266 m .68108 .76087 L .68395 .7331 L p .851 .941 .88 r
F P
0 g
s
.68395 .7331 m .71808 .70846 L .71384 .74266 L p .851 .941 .88 r
F P
0 g
s
.55845 .81408 m .54273 .80246 L .55405 .79868 L p .61 .852 .99 r
F P
0 g
s
.55405 .79868 m .58075 .80671 L .55845 .81408 L p .61 .852 .99 r
F P
0 g
s
.50398 .80082 m .48253 .81089 L .46272 .80173 L p .502 .75 .984 r
F P
0 g
s
.48253 .81089 m .50398 .80082 L .51632 .80359 L p .505 .778 .993 r
F P
0 g
s
.63089 .79365 m .59751 .79595 L .60687 .78285 L p .723 .905 .959 r
F P
0 g
s
.60687 .78285 m .64515 .77429 L .63089 .79365 L p .723 .905 .959 r
F P
0 g
s
.28616 .6242 m .31079 .65943 L .3043 .70009 L p .184 .308 .757 r
F P
0 g
s
.33408 .72583 m .3043 .70009 L .31079 .65943 L p .296 .422 .82 r
F P
0 g
s
.29027 .45455 m .29379 .49584 L .25586 .54734 L p .151 .063 .493 r
F P
0 g
s
.26753 .58648 m .25586 .54734 L .29379 .49584 L p .264 .211 .609 r
F P
0 g
s
.58075 .80671 m .55405 .79868 L .56246 .79318 L p .655 .858 .977 r
F P
0 g
s
.56246 .79318 m .59751 .79595 L .58075 .80671 L p .655 .858 .977 r
F P
0 g
s
.63264 .30001 m .64234 .32425 L .55028 .30819 L p .697 .268 .226 r
F P
0 g
s
.55028 .30819 m .54826 .28512 L .63264 .30001 L p .697 .268 .226 r
F P
0 g
s
.71848 .35914 m .72815 .39245 L .64829 .35643 L p .84 .466 .343 r
F P
0 g
s
.64829 .35643 m .64234 .32425 L .71848 .35914 L p .84 .466 .343 r
F P
0 g
s
.77317 .64719 m .74818 .67965 L .72915 .63967 L p .931 .869 .755 r
F P
0 g
s
.72915 .63967 m .75265 .60165 L .77317 .64719 L p .931 .869 .755 r
F P
0 g
s
.68108 .76087 m .64515 .77429 L .64683 .75325 L p .805 .907 .911 r
F P
0 g
s
.64683 .75325 m .68395 .7331 L .68108 .76087 L p .805 .907 .911 r
F P
0 g
s
.78546 .48037 m .78165 .5207 L .72832 .47319 L p .94 .69 .532 r
F P
0 g
s
.72832 .47319 m .73141 .43101 L .78546 .48037 L p .94 .69 .532 r
F P
0 g
s
.41317 .78435 m .44945 .78965 L .46272 .80173 L p .396 .672 .971 r
F P
0 g
s
.49397 .79612 m .46272 .80173 L .44945 .78965 L p .515 .727 .969 r
F P
0 g
s
.46272 .80173 m .49397 .79612 L .50398 .80082 L p .502 .75 .984 r
F P
0 g
s
.36797 .74718 m .405 .76389 L .41317 .78435 L p .351 .58 .928 r
F P
0 g
s
.44945 .78965 m .41317 .78435 L .405 .76389 L p .455 .653 .945 r
F P
0 g
s
.36938 .33972 m .3614 .37241 L .29398 .41612 L p .245 0 .287 r
F P
0 g
s
.29027 .45455 m .29398 .41612 L .3614 .37241 L p .355 .144 .448 r
F P
0 g
s
.31079 .65943 m .34035 .69133 L .33408 .72583 L p .296 .422 .82 r
F P
0 g
s
.36797 .74718 m .33408 .72583 L .34035 .69133 L p .382 .511 .863 r
F P
0 g
s
.45485 .31366 m .46086 .29019 L .54826 .28512 L p .572 .17 .242 r
F P
0 g
s
.46086 .29019 m .45485 .31366 L .36938 .33972 L p .389 .008 .189 r
F P
0 g
s
.59751 .79595 m .56246 .79318 L .56703 .78655 L p .689 .851 .96 r
F P
0 g
s
.56703 .78655 m .60687 .78285 L .59751 .79595 L p .689 .851 .96 r
F P
0 g
s
.54826 .28512 m .55028 .30819 L .45485 .31366 L p .572 .17 .242 r
F P
0 g
s
.52632 .78542 m .5297 .80415 L .51632 .80359 L closepath p .61 .787 .966 r
F P
0 g
s
.52632 .78542 m .54273 .80246 L .5297 .80415 L closepath p .62 .794 .966 r
F P
0 g
s
.29379 .49584 m .30411 .5384 L .26753 .58648 L p .264 .211 .609 r
F P
0 g
s
.28616 .6242 m .26753 .58648 L .30411 .5384 L p .345 .32 .688 r
F P
0 g
s
.52632 .78542 m .51632 .80359 L .50398 .80082 L closepath p .603 .778 .964 r
F P
0 g
s
.52632 .78542 m .55405 .79868 L .54273 .80246 L closepath p .631 .799 .963 r
F P
0 g
s
.64515 .77429 m .60687 .78285 L .60764 .76873 L p .758 .871 .93 r
F P
0 g
s
.60764 .76873 m .64683 .75325 L .64515 .77429 L p .758 .871 .93 r
F P
0 g
s
.74818 .67965 m .71808 .70846 L .70103 .67465 L p .892 .865 .806 r
F P
0 g
s
.70103 .67465 m .72915 .63967 L .74818 .67965 L p .892 .865 .806 r
F P
0 g
s
.52632 .78542 m .50398 .80082 L .49397 .79612 L closepath p .6 .769 .961 r
F P
0 g
s
.405 .76389 m .44426 .77585 L .44945 .78965 L p .455 .653 .945 r
F P
0 g
s
.48738 .78998 m .44945 .78965 L .44426 .77585 L p .537 .709 .95 r
F P
0 g
s
.44945 .78965 m .48738 .78998 L .49397 .79612 L p .515 .727 .969 r
F P
0 g
s
.3614 .37241 m .36938 .33972 L .45485 .31366 L p .486 .182 .376 r
F P
0 g
s
.34035 .69133 m .37375 .71927 L .36797 .74718 L p .382 .511 .863 r
F P
0 g
s
.405 .76389 m .36797 .74718 L .37375 .71927 L p .453 .583 .893 r
F P
0 g
s
.52632 .78542 m .56246 .79318 L .55405 .79868 L closepath p .643 .8 .958 r
F P
0 g
s
.52632 .78542 m .49397 .79612 L .48738 .78998 L closepath p .601 .76 .955 r
F P
0 g
s
.78165 .5207 m .77047 .56159 L .71924 .51729 L p .922 .726 .621 r
F P
0 g
s
.71924 .51729 m .72832 .47319 L .78165 .5207 L p .922 .726 .621 r
F P
0 g
s
.52632 .78542 m .56703 .78655 L .56246 .79318 L closepath p .654 .798 .952 r
F P
0 g
s
.60687 .78285 m .56703 .78655 L .56722 .77946 L p .71 .833 .94 r
F P
0 g
s
.56722 .77946 m .60764 .76873 L .60687 .78285 L p .71 .833 .94 r
F P
0 g
s
.71808 .70846 m .68395 .7331 L .66938 .70586 L p .852 .856 .845 r
F P
0 g
s
.66938 .70586 m .70103 .67465 L .71808 .70846 L p .852 .856 .845 r
F P
0 g
s
.30411 .5384 m .32054 .58068 L .28616 .6242 L p .345 .32 .688 r
F P
0 g
s
.31079 .65943 m .28616 .6242 L .32054 .58068 L p .406 .405 .745 r
F P
0 g
s
.72815 .39245 m .73141 .43101 L .6503 .39515 L p .85 .547 .475 r
F P
0 g
s
.6503 .39515 m .64829 .35643 L .72815 .39245 L p .85 .547 .475 r
F P
0 g
s
.37375 .71927 m .40993 .74284 L .405 .76389 L p .453 .583 .893 r
F P
0 g
s
.44426 .77585 m .405 .76389 L .40993 .74284 L p .512 .644 .915 r
F P
0 g
s
.3614 .37241 m .3587 .41106 L .29027 .45455 L p .355 .144 .448 r
F P
0 g
s
.29379 .49584 m .29027 .45455 L .3587 .41106 L p .425 .26 .552 r
F P
0 g
s
.44426 .77585 m .48495 .78303 L .48738 .78998 L p .537 .709 .95 r
F P
0 g
s
.52632 .78542 m .48738 .78998 L .48495 .78303 L closepath p .605 .753 .949 r
F P
0 g
s
.64234 .32425 m .64829 .35643 L .55152 .33982 L p .74 .393 .394 r
F P
0 g
s
.55152 .33982 m .55028 .30819 L .64234 .32425 L p .74 .393 .394 r
F P
0 g
s
.52632 .78542 m .56722 .77946 L .56703 .78655 L closepath p .661 .793 .945 r
F P
0 g
s
.40993 .74284 m .44796 .7618 L .44426 .77585 L p .512 .644 .915 r
F P
0 g
s
.48495 .78303 m .44426 .77585 L .44796 .7618 L p .565 .698 .931 r
F P
0 g
s
.68395 .7331 m .64683 .75325 L .63522 .73279 L p .81 .843 .875 r
F P
0 g
s
.63522 .73279 m .66938 .70586 L .68395 .7331 L p .81 .843 .875 r
F P
0 g
s
.44796 .7618 m .48699 .77601 L .48495 .78303 L p .565 .698 .931 r
F P
0 g
s
.52632 .78542 m .48495 .78303 L .48699 .77601 L closepath p .612 .748 .942 r
F P
0 g
s
.32054 .58068 m .34215 .62134 L .31079 .65943 L p .406 .405 .745 r
F P
0 g
s
.34035 .69133 m .31079 .65943 L .34215 .62134 L p .455 .475 .791 r
F P
0 g
s
.77047 .56159 m .75265 .60165 L .70482 .56163 L p .899 .748 .685 r
F P
0 g
s
.70482 .56163 m .71924 .51729 L .77047 .56159 L p .899 .748 .685 r
F P
0 g
s
.52632 .78542 m .55463 .76701 L .56295 .7727 L closepath p .666 .778 .933 r
F P
0 g
s
.52632 .78542 m .54315 .76305 L .55463 .76701 L closepath p .663 .769 .928 r
F P
0 g
s
.52632 .78542 m .52977 .76126 L .54315 .76305 L closepath p .658 .761 .926 r
F P
0 g
s
.52632 .78542 m .516 .76187 L .52977 .76126 L closepath p .65 .754 .925 r
F P
0 g
s
.52632 .78542 m .50339 .76479 L .516 .76187 L closepath p .641 .749 .927 r
F P
0 g
s
.52632 .78542 m .49336 .76969 L .50339 .76479 L closepath p .631 .746 .93 r
F P
0 g
s
.52632 .78542 m .48699 .77601 L .49336 .76969 L closepath p .622 .746 .935 r
F P
0 g
s
.52632 .78542 m .56295 .7727 L .56722 .77946 L closepath p .665 .786 .939 r
F P
0 g
s
.64683 .75325 m .60764 .76873 L .59948 .75513 L p .766 .828 .9 r
F P
0 g
s
.59948 .75513 m .63522 .73279 L .64683 .75325 L p .766 .828 .9 r
F P
0 g
s
.45116 .34547 m .45485 .31366 L .55028 .30819 L p .63 .305 .402 r
F P
0 g
s
.45485 .31366 m .45116 .34547 L .3614 .37241 L p .486 .182 .376 r
F P
0 g
s
.60764 .76873 m .56722 .77946 L .56295 .7727 L p .719 .809 .921 r
F P
0 g
s
.56295 .7727 m .59948 .75513 L .60764 .76873 L p .719 .809 .921 r
F P
0 g
s
.46036 .74903 m .49336 .76969 L .48699 .77601 L p .593 .694 .913 r
F P
0 g
s
.48699 .77601 m .44796 .7618 L .46036 .74903 L p .593 .694 .913 r
F P
0 g
s
.3587 .41106 m .3614 .37241 L .45116 .34547 L p .54 .293 .49 r
F P
0 g
s
.34215 .62134 m .36793 .65923 L .34035 .69133 L p .455 .475 .791 r
F P
0 g
s
.37375 .71927 m .34035 .69133 L .36793 .65923 L p .496 .536 .828 r
F P
0 g
s
.55028 .30819 m .55152 .33982 L .45116 .34547 L p .63 .305 .402 r
F P
0 g
s
.3587 .41106 m .36126 .454 L .29379 .49584 L p .425 .26 .552 r
F P
0 g
s
.30411 .5384 m .29379 .49584 L .36126 .454 L p .472 .345 .625 r
F P
0 g
s
.59948 .75513 m .56295 .7727 L .55463 .76701 L p .716 .783 .905 r
F P
0 g
s
.42795 .72356 m .46036 .74903 L .44796 .7618 L p .563 .643 .887 r
F P
0 g
s
.44796 .7618 m .40993 .74284 L .42795 .72356 L p .563 .643 .887 r
F P
0 g
s
.36793 .65923 m .39685 .6935 L .37375 .71927 L p .496 .536 .828 r
F P
0 g
s
.40993 .74284 m .37375 .71927 L .39685 .6935 L p .531 .591 .859 r
F P
0 g
s
.73141 .43101 m .72832 .47319 L .6484 .4387 L p .846 .597 .563 r
F P
0 g
s
.6484 .4387 m .6503 .39515 L .73141 .43101 L p .846 .597 .563 r
F P
0 g
s
.75265 .60165 m .72915 .63967 L .68588 .60472 L p .874 .762 .735 r
F P
0 g
s
.68588 .60472 m .70482 .56163 L .75265 .60165 L p .874 .762 .735 r
F P
0 g
s
.39685 .6935 m .42795 .72356 L .40993 .74284 L p .531 .591 .859 r
F P
0 g
s
.48029 .73905 m .50339 .76479 L .49336 .76969 L p .621 .696 .898 r
F P
0 g
s
.49336 .76969 m .46036 .74903 L .48029 .73905 L p .621 .696 .898 r
F P
0 g
s
.55463 .76701 m .58308 .74359 L .59948 .75513 L p .716 .783 .905 r
F P
0 g
s
.58308 .74359 m .55463 .76701 L .54315 .76305 L p .706 .758 .893 r
F P
0 g
s
.63522 .73279 m .59948 .75513 L .58308 .74359 L p .757 .785 .876 r
F P
0 g
s
.50556 .73306 m .516 .76187 L .50339 .76479 L p .647 .704 .889 r
F P
0 g
s
.50339 .76479 m .48029 .73905 L .50556 .73306 L p .647 .704 .889 r
F P
0 g
s
.72915 .63967 m .70103 .67465 L .66335 .64529 L p .849 .772 .777 r
F P
0 g
s
.66335 .64529 m .68588 .60472 L .72915 .63967 L p .849 .772 .777 r
F P
0 g
s
.64829 .35643 m .6503 .39515 L .55194 .37861 L p .755 .469 .499 r
F P
0 g
s
.55194 .37861 m .55152 .33982 L .64829 .35643 L p .755 .469 .499 r
F P
0 g
s
.54315 .76305 m .56015 .73548 L .58308 .74359 L p .706 .758 .893 r
F P
0 g
s
.56015 .73548 m .54315 .76305 L .52977 .76126 L p .69 .736 .886 r
F P
0 g
s
.53326 .73182 m .52977 .76126 L .516 .76187 L p .67 .718 .885 r
F P
0 g
s
.516 .76187 m .50556 .73306 L .53326 .73182 L p .67 .718 .885 r
F P
0 g
s
.36126 .454 m .36875 .49942 L .30411 .5384 L p .472 .345 .625 r
F P
0 g
s
.32054 .58068 m .30411 .5384 L .36875 .49942 L p .507 .411 .681 r
F P
0 g
s
.52977 .76126 m .53326 .73182 L .56015 .73548 L p .69 .736 .886 r
F P
0 g
s
.66938 .70586 m .63522 .73279 L .61114 .71528 L p .791 .783 .845 r
F P
0 g
s
.58308 .74359 m .61114 .71528 L .63522 .73279 L p .757 .785 .876 r
F P
0 g
s
.70103 .67465 m .66938 .70586 L .63814 .68237 L p .821 .779 .813 r
F P
0 g
s
.63814 .68237 m .66335 .64529 L .70103 .67465 L p .821 .779 .813 r
F P
0 g
s
.45744 .70837 m .48029 .73905 L .46036 .74903 L p .608 .65 .866 r
F P
0 g
s
.46036 .74903 m .42795 .72356 L .45744 .70837 L p .608 .65 .866 r
F P
0 g
s
.61114 .71528 m .63814 .68237 L .66938 .70586 L p .791 .783 .845 r
F P
0 g
s
.72832 .47319 m .71924 .51729 L .64281 .4852 L p .837 .633 .626 r
F P
0 g
s
.64281 .4852 m .6484 .4387 L .72832 .47319 L p .837 .633 .626 r
F P
0 g
s
.45116 .34547 m .44992 .38424 L .3587 .41106 L p .54 .293 .49 r
F P
0 g
s
.36126 .454 m .3587 .41106 L .44992 .38424 L p .572 .37 .568 r
F P
0 g
s
.44992 .38424 m .45116 .34547 L .55152 .33982 L p .658 .39 .503 r
F P
0 g
s
.61114 .71528 m .58308 .74359 L .56015 .73548 L p .737 .746 .859 r
F P
0 g
s
.36875 .49942 m .38064 .54554 L .32054 .58068 L p .507 .411 .681 r
F P
0 g
s
.34215 .62134 m .32054 .58068 L .38064 .54554 L p .535 .467 .726 r
F P
0 g
s
.43538 .67305 m .45744 .70837 L .42795 .72356 L p .593 .606 .834 r
F P
0 g
s
.42795 .72356 m .39685 .6935 L .43538 .67305 L p .593 .606 .834 r
F P
0 g
s
.55152 .33982 m .55194 .37861 L .44992 .38424 L p .658 .39 .503 r
F P
0 g
s
.49519 .69921 m .50556 .73306 L .48029 .73905 L p .647 .664 .853 r
F P
0 g
s
.48029 .73905 m .45744 .70837 L .49519 .69921 L p .647 .664 .853 r
F P
0 g
s
.38064 .54554 m .39623 .59072 L .34215 .62134 L p .535 .467 .726 r
F P
0 g
s
.36793 .65923 m .34215 .62134 L .39623 .59072 L p .557 .516 .765 r
F P
0 g
s
.41473 .63358 m .43538 .67305 L .39685 .6935 L p .576 .562 .801 r
F P
0 g
s
.39685 .6935 m .36793 .65923 L .41473 .63358 L p .576 .562 .801 r
F P
0 g
s
.56015 .73548 m .57701 .70292 L .61114 .71528 L p .737 .746 .859 r
F P
0 g
s
.57701 .70292 m .56015 .73548 L .53326 .73182 L p .712 .712 .849 r
F P
0 g
s
.39623 .59072 m .41473 .63358 L .36793 .65923 L p .557 .516 .765 r
F P
0 g
s
.63814 .68237 m .61114 .71528 L .57701 .70292 L p .762 .732 .825 r
F P
0 g
s
.53674 .69731 m .53326 .73182 L .50556 .73306 L p .681 .685 .847 r
F P
0 g
s
.50556 .73306 m .49519 .69921 L .53674 .69731 L p .681 .685 .847 r
F P
0 g
s
.71924 .51729 m .70482 .56163 L .63395 .53274 L p .826 .66 .677 r
F P
0 g
s
.63395 .53274 m .64281 .4852 L .71924 .51729 L p .826 .66 .677 r
F P
0 g
s
.6503 .39515 m .6484 .4387 L .55154 .4228 L p .76 .521 .571 r
F P
0 g
s
.55154 .4228 m .55194 .37861 L .6503 .39515 L p .76 .521 .571 r
F P
0 g
s
.53326 .73182 m .53674 .69731 L .57701 .70292 L p .712 .712 .849 r
F P
0 g
s
.44992 .38424 m .4511 .42821 L .36126 .454 L p .572 .37 .568 r
F P
0 g
s
.36875 .49942 m .36126 .454 L .4511 .42821 L p .594 .428 .627 r
F P
0 g
s
.48514 .66065 m .49519 .69921 L .45744 .70837 L p .644 .627 .818 r
F P
0 g
s
.45744 .70837 m .43538 .67305 L .48514 .66065 L p .644 .627 .818 r
F P
0 g
s
.66335 .64529 m .63814 .68237 L .59332 .66568 L p .781 .717 .791 r
F P
0 g
s
.57701 .70292 m .59332 .66568 L .63814 .68237 L p .762 .732 .825 r
F P
0 g
s
.70482 .56163 m .68588 .60472 L .62236 .5796 L p .813 .681 .719 r
F P
0 g
s
.62236 .5796 m .63395 .53274 L .70482 .56163 L p .813 .681 .719 r
F P
0 g
s
.4511 .42821 m .44992 .38424 L .55194 .37861 L p .674 .45 .573 r
F P
0 g
s
.68588 .60472 m .66335 .64529 L .60862 .6243 L p .798 .7 .757 r
F P
0 g
s
.59332 .66568 m .60862 .6243 L .66335 .64529 L p .781 .717 .791 r
F P
0 g
s
.60862 .6243 m .62236 .5796 L .68588 .60472 L p .798 .7 .757 r
F P
0 g
s
.59332 .66568 m .57701 .70292 L .53674 .69731 L p .727 .689 .814 r
F P
0 g
s
.55194 .37861 m .55154 .4228 L .4511 .42821 L p .674 .45 .573 r
F P
0 g
s
.5401 .65807 m .53674 .69731 L .49519 .69921 L p .688 .655 .812 r
F P
0 g
s
.49519 .69921 m .48514 .66065 L .5401 .65807 L p .688 .655 .812 r
F P
0 g
s
.4511 .42821 m .45456 .47545 L .36875 .49942 L p .594 .428 .627 r
F P
0 g
s
.38064 .54554 m .36875 .49942 L .45456 .47545 L p .61 .476 .674 r
F P
0 g
s
.4757 .61796 m .48514 .66065 L .43538 .67305 L p .639 .591 .785 r
F P
0 g
s
.43538 .67305 m .41473 .63358 L .4757 .61796 L p .639 .591 .785 r
F P
0 g
s
.6484 .4387 m .64281 .4852 L .55037 .47042 L p .76 .56 .627 r
F P
0 g
s
.55037 .47042 m .55154 .4228 L .6484 .4387 L p .76 .56 .627 r
F P
0 g
s
.53674 .69731 m .5401 .65807 L .59332 .66568 L p .727 .689 .814 r
F P
0 g
s
.46722 .572 m .4757 .61796 L .41473 .63358 L p .631 .555 .75 r
F P
0 g
s
.41473 .63358 m .39623 .59072 L .46722 .572 L p .631 .555 .75 r
F P
0 g
s
.45456 .47545 m .46004 .52398 L .38064 .54554 L p .61 .476 .674 r
F P
0 g
s
.39623 .59072 m .38064 .54554 L .46004 .52398 L p .622 .517 .714 r
F P
0 g
s
.60862 .6243 m .59332 .66568 L .5401 .65807 L p .738 .666 .78 r
F P
0 g
s
.46004 .52398 m .46722 .572 L .39623 .59072 L p .622 .517 .714 r
F P
0 g
s
.45456 .47545 m .4511 .42821 L .55154 .4228 L p .683 .495 .626 r
F P
0 g
s
.64281 .4852 m .63395 .53274 L .54853 .51947 L p .757 .592 .671 r
F P
0 g
s
.54853 .51947 m .55037 .47042 L .64281 .4852 L p .757 .592 .671 r
F P
0 g
s
.54327 .6147 m .5401 .65807 L .48514 .66065 L p .691 .625 .778 r
F P
0 g
s
.48514 .66065 m .4757 .61796 L .54327 .6147 L p .691 .625 .778 r
F P
0 g
s
.55154 .4228 m .55037 .47042 L .45456 .47545 L p .683 .495 .626 r
F P
0 g
s
.5401 .65807 m .54327 .6147 L .60862 .6243 L p .738 .666 .78 r
F P
0 g
s
.62236 .5796 m .60862 .6243 L .54327 .6147 L p .746 .643 .746 r
F P
0 g
s
.63395 .53274 m .62236 .5796 L .54612 .56809 L p .753 .619 .71 r
F P
0 g
s
.54612 .56809 m .54853 .51947 L .63395 .53274 L p .753 .619 .71 r
F P
0 g
s
.54327 .6147 m .54612 .56809 L .62236 .5796 L p .746 .643 .746 r
F P
0 g
s
.46004 .52398 m .45456 .47545 L .55037 .47042 L p .688 .533 .67 r
F P
0 g
s
.54612 .56809 m .54327 .6147 L .4757 .61796 L p .692 .596 .744 r
F P
0 g
s
.4757 .61796 m .46722 .572 L .54612 .56809 L p .692 .596 .744 r
F P
0 g
s
.55037 .47042 m .54853 .51947 L .46004 .52398 L p .688 .533 .67 r
F P
0 g
s
.46722 .572 m .46004 .52398 L .54853 .51947 L p .691 .566 .709 r
F P
0 g
s
.54853 .51947 m .54612 .56809 L .46722 .572 L p .691 .566 .709 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48347 .50205 m .47603 .54826 L .5433 .5516 L p .718 .598 .721 r
F P
0 g
s
.5433 .5516 m .54079 .50497 L .48347 .50205 L p .718 .598 .721 r
F P
0 g
s
.54525 .59719 m .5433 .5516 L .47603 .54826 L p .72 .571 .686 r
F P
0 g
s
.54079 .50497 m .5433 .5516 L .60912 .54156 L p .671 .561 .722 r
F P
0 g
s
.5433 .5516 m .54525 .59719 L .61868 .5863 L p .665 .528 .687 r
F P
0 g
s
.61868 .5863 m .60912 .54156 L .5433 .5516 L p .665 .528 .687 r
F P
0 g
s
.49243 .45621 m .48347 .50205 L .54079 .50497 L p .715 .624 .754 r
F P
0 g
s
.54079 .50497 m .53777 .45858 L .49243 .45621 L p .715 .624 .754 r
F P
0 g
s
.53777 .45858 m .54079 .50497 L .59683 .49619 L p .675 .593 .756 r
F P
0 g
s
.60912 .54156 m .59683 .49619 L .54079 .50497 L p .671 .561 .722 r
F P
0 g
s
.42997 .48761 m .41308 .53174 L .47603 .54826 L p .763 .64 .726 r
F P
0 g
s
.47603 .54826 m .48347 .50205 L .42997 .48761 L p .763 .64 .726 r
F P
0 g
s
.47025 .59357 m .47603 .54826 L .41308 .53174 L p .771 .619 .69 r
F P
0 g
s
.47603 .54826 m .47025 .59357 L .54525 .59719 L p .72 .571 .686 r
F P
0 g
s
.54661 .64058 m .54525 .59719 L .47025 .59357 L p .72 .542 .649 r
F P
0 g
s
.54525 .59719 m .54661 .64058 L .62538 .6292 L p .658 .494 .65 r
F P
0 g
s
.62538 .6292 m .61868 .5863 L .54525 .59719 L p .658 .494 .65 r
F P
0 g
s
.45026 .44451 m .42997 .48761 L .48347 .50205 L p .752 .66 .76 r
F P
0 g
s
.48347 .50205 m .49243 .45621 L .45026 .44451 L p .752 .66 .76 r
F P
0 g
s
.41308 .53174 m .39992 .57563 L .47025 .59357 L p .771 .619 .69 r
F P
0 g
s
.4662 .6368 m .47025 .59357 L .39992 .57563 L p .778 .595 .652 r
F P
0 g
s
.47025 .59357 m .4662 .6368 L .54661 .64058 L p .72 .542 .649 r
F P
0 g
s
.59683 .49619 m .60912 .54156 L .66773 .51879 L p .618 .529 .731 r
F P
0 g
s
.60912 .54156 m .61868 .5863 L .68431 .56152 L p .603 .488 .694 r
F P
0 g
s
.68431 .56152 m .66773 .51879 L .60912 .54156 L p .603 .488 .694 r
F P
0 g
s
.59683 .49619 m .58204 .45146 L .53777 .45858 L p .675 .593 .756 r
F P
0 g
s
.58204 .45146 m .59683 .49619 L .6465 .47632 L p .632 .568 .765 r
F P
0 g
s
.66773 .51879 m .6465 .47632 L .59683 .49619 L p .618 .529 .731 r
F P
0 g
s
.50273 .4121 m .49243 .45621 L .53777 .45858 L p .709 .65 .789 r
F P
0 g
s
.53777 .45858 m .53429 .4138 L .50273 .4121 L p .709 .65 .789 r
F P
0 g
s
.53429 .4138 m .53777 .45858 L .58204 .45146 L p .678 .627 .791 r
F P
0 g
s
.54738 .68073 m .54661 .64058 L .4662 .6368 L p .717 .51 .608 r
F P
0 g
s
.54661 .64058 m .54738 .68073 L .62915 .66922 L p .649 .455 .608 r
F P
0 g
s
.62915 .66922 m .62538 .6292 L .54661 .64058 L p .649 .455 .608 r
F P
0 g
s
.47348 .40378 m .45026 .44451 L .49243 .45621 L p .738 .68 .794 r
F P
0 g
s
.49243 .45621 m .50273 .4121 L .47348 .40378 L p .738 .68 .794 r
F P
0 g
s
.61868 .5863 m .62538 .6292 L .69594 .60329 L p .587 .444 .654 r
F P
0 g
s
.69594 .60329 m .68431 .56152 L .61868 .5863 L p .587 .444 .654 r
F P
0 g
s
.39992 .57563 m .3907 .61805 L .4662 .6368 L p .778 .595 .652 r
F P
0 g
s
.46393 .6769 m .4662 .6368 L .3907 .61805 L p .782 .566 .608 r
F P
0 g
s
.4662 .6368 m .46393 .6769 L .54738 .68073 L p .717 .51 .608 r
F P
0 g
s
.58204 .45146 m .56507 .40872 L .53429 .4138 L p .678 .627 .791 r
F P
0 g
s
.56507 .40872 m .58204 .45146 L .62107 .43539 L p .644 .609 .799 r
F P
0 g
s
.6465 .47632 m .62107 .43539 L .58204 .45146 L p .632 .568 .765 r
F P
0 g
s
.41532 .42444 m .3853 .46272 L .42997 .48761 L p .787 .704 .773 r
F P
0 g
s
.42997 .48761 m .45026 .44451 L .41532 .42444 L p .787 .704 .773 r
F P
0 g
s
.41308 .53174 m .42997 .48761 L .3853 .46272 L p .807 .692 .738 r
F P
0 g
s
.3853 .46272 m .36017 .50315 L .41308 .53174 L p .807 .692 .738 r
F P
0 g
s
.39992 .57563 m .41308 .53174 L .36017 .50315 L p .823 .676 .7 r
F P
0 g
s
.44948 .38957 m .41532 .42444 L .45026 .44451 L p .764 .714 .806 r
F P
0 g
s
.45026 .44451 m .47348 .40378 L .44948 .38957 L p .764 .714 .806 r
F P
0 g
s
.62538 .6292 m .62915 .66922 L .70251 .64296 L p .566 .394 .607 r
F P
0 g
s
.70251 .64296 m .69594 .60329 L .62538 .6292 L p .566 .394 .607 r
F P
0 g
s
.36017 .50315 m .3405 .54446 L .39992 .57563 L p .823 .676 .7 r
F P
0 g
s
.3907 .61805 m .39992 .57563 L .3405 .54446 L p .838 .657 .658 r
F P
0 g
s
.51413 .37117 m .50273 .4121 L .53429 .4138 L p .7 .679 .826 r
F P
0 g
s
.53429 .4138 m .53044 .37207 L .51413 .37117 L p .7 .679 .826 r
F P
0 g
s
.53044 .37207 m .53429 .4138 L .56507 .40872 L p .679 .663 .827 r
F P
0 g
s
.54756 .71675 m .54738 .68073 L .46393 .6769 L p .712 .471 .559 r
F P
0 g
s
.54738 .68073 m .54756 .71675 L .63003 .7054 L p .636 .409 .557 r
F P
0 g
s
.63003 .7054 m .62915 .66922 L .54738 .68073 L p .636 .409 .557 r
F P
0 g
s
.49907 .36678 m .47348 .40378 L .50273 .4121 L p .719 .699 .83 r
F P
0 g
s
.50273 .4121 m .51413 .37117 L .49907 .36678 L p .719 .699 .83 r
F P
0 g
s
.62107 .43539 m .6465 .47632 L .68495 .44684 L p .582 .548 .783 r
F P
0 g
s
.6465 .47632 m .66773 .51879 L .71351 .48484 L p .555 .499 .748 r
F P
0 g
s
.71351 .48484 m .68495 .44684 L .6465 .47632 L p .555 .499 .748 r
F P
0 g
s
.66773 .51879 m .68431 .56152 L .73594 .52444 L p .525 .446 .708 r
F P
0 g
s
.73594 .52444 m .71351 .48484 L .66773 .51879 L p .525 .446 .708 r
F P
0 g
s
.3907 .61805 m .3855 .65792 L .46393 .6769 L p .782 .566 .608 r
F P
0 g
s
.4634 .71297 m .46393 .6769 L .3855 .65792 L p .784 .531 .555 r
F P
0 g
s
.46393 .6769 m .4634 .71297 L .54756 .71675 L p .712 .471 .559 r
F P
0 g
s
.56507 .40872 m .54633 .36939 L .53044 .37207 L p .679 .663 .827 r
F P
0 g
s
.54633 .36939 m .56507 .40872 L .59203 .39731 L p .656 .652 .834 r
F P
0 g
s
.62107 .43539 m .59203 .39731 L .56507 .40872 L p .644 .609 .799 r
F P
0 g
s
.59203 .39731 m .62107 .43539 L .65094 .4117 L p .607 .597 .815 r
F P
0 g
s
.68495 .44684 m .65094 .4117 L .62107 .43539 L p .582 .548 .783 r
F P
0 g
s
.3405 .54446 m .32667 .58542 L .3907 .61805 L p .838 .657 .658 r
F P
0 g
s
.3855 .65792 m .3907 .61805 L .32667 .58542 L p .85 .632 .607 r
F P
0 g
s
.48684 .35934 m .44948 .38957 L .47348 .40378 L p .735 .722 .839 r
F P
0 g
s
.47348 .40378 m .49907 .36678 L .48684 .35934 L p .735 .722 .839 r
F P
0 g
s
.68431 .56152 m .69594 .60329 L .75174 .56441 L p .492 .386 .662 r
F P
0 g
s
.75174 .56441 m .73594 .52444 L .68431 .56152 L p .492 .386 .662 r
F P
0 g
s
.62915 .66922 m .63003 .7054 L .70403 .67953 L p .541 .335 .551 r
F P
0 g
s
.70403 .67953 m .70251 .64296 L .62915 .66922 L p .541 .335 .551 r
F P
0 g
s
.59203 .39731 m .56015 .36339 L .54633 .36939 L p .656 .652 .834 r
F P
0 g
s
.56015 .36339 m .59203 .39731 L .6124 .3806 L p .633 .646 .846 r
F P
0 g
s
.65094 .4117 m .6124 .3806 L .59203 .39731 L p .607 .597 .815 r
F P
0 g
s
.39131 .39769 m .35412 .42931 L .3853 .46272 L p .818 .757 .795 r
F P
0 g
s
.3853 .46272 m .41532 .42444 L .39131 .39769 L p .818 .757 .795 r
F P
0 g
s
.36017 .50315 m .3853 .46272 L .35412 .42931 L p .849 .756 .76 r
F P
0 g
s
.43328 .37078 m .39131 .39769 L .41532 .42444 L p .785 .755 .826 r
F P
0 g
s
.41532 .42444 m .44948 .38957 L .43328 .37078 L p .785 .755 .826 r
F P
0 g
s
.35412 .42931 m .32275 .46455 L .36017 .50315 L p .849 .756 .76 r
F P
0 g
s
.3405 .54446 m .36017 .50315 L .32275 .46455 L p .877 .75 .718 r
F P
0 g
s
.54717 .74791 m .54756 .71675 L .4634 .71297 L p .703 .423 .497 r
F P
0 g
s
.54756 .71675 m .54717 .74791 L .62812 .737 L p .617 .353 .494 r
F P
0 g
s
.62812 .737 m .63003 .7054 L .54756 .71675 L p .617 .353 .494 r
F P
0 g
s
.53044 .37207 m .52632 .33487 L .51413 .37117 L closepath p .684 .71 .867 r
F P
0 g
s
.54633 .36939 m .52632 .33487 L .53044 .37207 L closepath p .676 .704 .868 r
F P
0 g
s
.47875 .34958 m .43328 .37078 L .44948 .38957 L p .746 .748 .853 r
F P
0 g
s
.44948 .38957 m .48684 .35934 L .47875 .34958 L p .746 .748 .853 r
F P
0 g
s
.51413 .37117 m .52632 .33487 L .49907 .36678 L closepath p .692 .718 .869 r
F P
0 g
s
.69594 .60329 m .70251 .64296 L .76068 .60351 L p .452 .316 .605 r
F P
0 g
s
.76068 .60351 m .75174 .56441 L .69594 .60329 L p .452 .316 .605 r
F P
0 g
s
.3855 .65792 m .38429 .69427 L .4634 .71297 L p .784 .531 .555 r
F P
0 g
s
.46455 .74428 m .4634 .71297 L .38429 .69427 L p .781 .486 .488 r
F P
0 g
s
.4634 .71297 m .46455 .74428 L .54717 .74791 L p .703 .423 .497 r
F P
0 g
s
.56015 .36339 m .52632 .33487 L .54633 .36939 L closepath p .668 .7 .871 r
F P
0 g
s
.32667 .58542 m .31886 .62484 L .3855 .65792 L p .85 .632 .607 r
F P
0 g
s
.38429 .69427 m .3855 .65792 L .31886 .62484 L p .859 .599 .543 r
F P
0 g
s
.49907 .36678 m .52632 .33487 L .48684 .35934 L closepath p .697 .726 .873 r
F P
0 g
s
.6124 .3806 m .65094 .4117 L .66829 .38248 L p .567 .593 .839 r
F P
0 g
s
.65094 .4117 m .68495 .44684 L .70782 .41021 L p .522 .535 .81 r
F P
0 g
s
.70782 .41021 m .66829 .38248 L .65094 .4117 L p .522 .535 .81 r
F P
0 g
s
.32275 .46455 m .29805 .50221 L .3405 .54446 L p .877 .75 .718 r
F P
0 g
s
.32667 .58542 m .3405 .54446 L .29805 .50221 L p .903 .738 .666 r
F P
0 g
s
.57044 .35467 m .52632 .33487 L .56015 .36339 L closepath p .659 .699 .876 r
F P
0 g
s
.6124 .3806 m .57044 .35467 L .56015 .36339 L p .633 .646 .846 r
F P
0 g
s
.68495 .44684 m .71351 .48484 L .74129 .44236 L p .473 .471 .774 r
F P
0 g
s
.74129 .44236 m .70782 .41021 L .68495 .44684 L p .473 .471 .774 r
F P
0 g
s
.57044 .35467 m .6124 .3806 L .62391 .36018 L p .61 .647 .862 r
F P
0 g
s
.66829 .38248 m .62391 .36018 L .6124 .3806 L p .567 .593 .839 r
F P
0 g
s
.63003 .7054 m .62812 .737 L .70071 .71213 L p .506 .261 .477 r
F P
0 g
s
.70071 .71213 m .70403 .67953 L .63003 .7054 L p .506 .261 .477 r
F P
0 g
s
.48684 .35934 m .52632 .33487 L .47875 .34958 L closepath p .7 .736 .879 r
F P
0 g
s
.71351 .48484 m .73594 .52444 L .76774 .47781 L p .415 .396 .729 r
F P
0 g
s
.76774 .47781 m .74129 .44236 L .71351 .48484 L p .415 .396 .729 r
F P
0 g
s
.57607 .34411 m .52632 .33487 L .57044 .35467 L closepath p .652 .7 .882 r
F P
0 g
s
.62391 .36018 m .57607 .34411 L .57044 .35467 L p .61 .647 .862 r
F P
0 g
s
.47573 .33851 m .42681 .34925 L .43328 .37078 L p .75 .774 .873 r
F P
0 g
s
.43328 .37078 m .47875 .34958 L .47573 .33851 L p .75 .774 .873 r
F P
0 g
s
.39131 .39769 m .43328 .37078 L .42681 .34925 L p .797 .799 .854 r
F P
0 g
s
.42681 .34925 m .38117 .36673 L .39131 .39769 L p .797 .799 .854 r
F P
0 g
s
.35412 .42931 m .39131 .39769 L .38117 .36673 L p .842 .82 .828 r
F P
0 g
s
.70251 .64296 m .70403 .67953 L .76276 .64063 L p .401 .229 .531 r
F P
0 g
s
.76276 .64063 m .76068 .60351 L .70251 .64296 L p .401 .229 .531 r
F P
0 g
s
.47875 .34958 m .52632 .33487 L .47573 .33851 L closepath p .7 .744 .886 r
F P
0 g
s
.29805 .50221 m .2806 .54103 L .32667 .58542 L p .903 .738 .666 r
F P
0 g
s
.31886 .62484 m .32667 .58542 L .2806 .54103 L p .926 .717 .6 r
F P
0 g
s
.54625 .77368 m .54717 .74791 L .46455 .74428 L p .685 .358 .416 r
F P
0 g
s
.54717 .74791 m .54625 .77368 L .6236 .76343 L p .588 .278 .41 r
F P
0 g
s
.6236 .76343 m .62812 .737 L .54717 .74791 L p .588 .278 .41 r
F P
0 g
s
.31886 .62484 m .31704 .66166 L .38429 .69427 L p .859 .599 .543 r
F P
0 g
s
.38692 .7263 m .38429 .69427 L .31704 .66166 L p .862 .551 .459 r
F P
0 g
s
.38429 .69427 m .38692 .7263 L .46455 .74428 L p .781 .486 .488 r
F P
0 g
s
.38117 .36673 m .34032 .39033 L .35412 .42931 L p .842 .82 .828 r
F P
0 g
s
.32275 .46455 m .35412 .42931 L .34032 .39033 L p .886 .837 .792 r
F P
0 g
s
.57636 .33282 m .52632 .33487 L .57607 .34411 L closepath p .646 .705 .89 r
F P
0 g
s
.57607 .34411 m .62391 .36018 L .62504 .3381 L p .589 .656 .884 r
F P
0 g
s
.62504 .3381 m .57636 .33282 L .57607 .34411 L p .589 .656 .884 r
F P
0 g
s
.46727 .77027 m .46455 .74428 L .38692 .7263 L p .77 .423 .398 r
F P
0 g
s
.46455 .74428 m .46727 .77027 L .54625 .77368 L p .685 .358 .416 r
F P
0 g
s
.73594 .52444 m .75174 .56441 L .78647 .51532 L p .346 .306 .67 r
F P
0 g
s
.78647 .51532 m .76774 .47781 L .73594 .52444 L p .346 .306 .67 r
F P
0 g
s
.62391 .36018 m .66829 .38248 L .6707 .35057 L p .525 .599 .871 r
F P
0 g
s
.6707 .35057 m .62504 .3381 L .62391 .36018 L p .525 .599 .871 r
F P
0 g
s
.56102 .31292 m .52632 .33487 L .57118 .32202 L closepath p .643 .721 .905 r
F P
0 g
s
.54696 .30656 m .52632 .33487 L .56102 .31292 L closepath p .646 .731 .91 r
F P
0 g
s
.47818 .3273 m .52632 .33487 L .48594 .3172 L closepath p .691 .756 .901 r
F P
0 g
s
.47573 .33851 m .52632 .33487 L .47818 .3273 L closepath p .697 .751 .893 r
F P
0 g
s
.57118 .32202 m .52632 .33487 L .57636 .33282 L closepath p .643 .712 .897 r
F P
0 g
s
.53055 .30369 m .52632 .33487 L .54696 .30656 L closepath p .653 .74 .914 r
F P
0 g
s
.51366 .30466 m .52632 .33487 L .53055 .30369 L closepath p .662 .749 .915 r
F P
0 g
s
.49821 .30935 m .52632 .33487 L .51366 .30466 L closepath p .672 .754 .913 r
F P
0 g
s
.48594 .3172 m .52632 .33487 L .49821 .30935 L closepath p .682 .757 .908 r
F P
0 g
s
.42681 .34925 m .47573 .33851 L .47818 .3273 L p .745 .798 .895 r
F P
0 g
s
.66829 .38248 m .70782 .41021 L .71179 .36982 L p .449 .53 .848 r
F P
0 g
s
.71179 .36982 m .6707 .35057 L .66829 .38248 L p .449 .53 .848 r
F P
0 g
s
.62812 .737 m .6236 .76343 L .69285 .74009 L p .456 .162 .376 r
F P
0 g
s
.69285 .74009 m .70071 .71213 L .62812 .737 L p .456 .162 .376 r
F P
0 g
s
.34032 .39033 m .30558 .41918 L .32275 .46455 L p .886 .837 .792 r
F P
0 g
s
.29805 .50221 m .32275 .46455 L .30558 .41918 L p .928 .847 .742 r
F P
0 g
s
.57636 .33282 m .62504 .3381 L .61531 .31673 L p .573 .673 .907 r
F P
0 g
s
.61531 .31673 m .57118 .32202 L .57636 .33282 L p .573 .673 .907 r
F P
0 g
s
.47818 .3273 m .43109 .32722 L .42681 .34925 L p .745 .798 .895 r
F P
0 g
s
.38117 .36673 m .42681 .34925 L .43109 .32722 L p .795 .845 .889 r
F P
0 g
s
.2806 .54103 m .27072 .57976 L .31886 .62484 L p .926 .717 .6 r
F P
0 g
s
.31704 .66166 m .31886 .62484 L .27072 .57976 L p .943 .681 .51 r
F P
0 g
s
.70403 .67953 m .70071 .71213 L .75823 .67477 L p .331 .117 .43 r
F P
0 g
s
.75823 .67477 m .76276 .64063 L .70403 .67953 L p .331 .117 .43 r
F P
0 g
s
.43109 .32722 m .47818 .3273 L .48594 .3172 L p .728 .817 .92 r
F P
0 g
s
.75174 .56441 m .76068 .60351 L .7971 .55361 L p .258 .191 .588 r
F P
0 g
s
.7971 .55361 m .78647 .51532 L .75174 .56441 L p .258 .191 .588 r
F P
0 g
s
.70782 .41021 m .74129 .44236 L .74689 .39517 L p .356 .442 .812 r
F P
0 g
s
.74689 .39517 m .71179 .36982 L .70782 .41021 L p .356 .442 .812 r
F P
0 g
s
.57118 .32202 m .61531 .31673 L .59548 .29854 L p .564 .699 .931 r
F P
0 g
s
.59548 .29854 m .56102 .31292 L .57118 .32202 L p .564 .699 .931 r
F P
0 g
s
.31704 .66166 m .321 .69496 L .38692 .7263 L p .862 .551 .459 r
F P
0 g
s
.39314 .75338 m .38692 .7263 L .321 .69496 L p .853 .479 .341 r
F P
0 g
s
.38692 .7263 m .39314 .75338 L .46727 .77027 L p .77 .423 .398 r
F P
0 g
s
.62504 .3381 m .6707 .35057 L .65715 .31937 L p .481 .619 .909 r
F P
0 g
s
.65715 .31937 m .61531 .31673 L .62504 .3381 L p .481 .619 .909 r
F P
0 g
s
.43109 .32722 m .38668 .33472 L .38117 .36673 L p .795 .845 .889 r
F P
0 g
s
.34032 .39033 m .38117 .36673 L .38668 .33472 L p .846 .891 .871 r
F P
0 g
s
.54485 .7937 m .54625 .77368 L .46727 .77027 L p .652 .266 .3 r
F P
0 g
s
.54625 .77368 m .54485 .7937 L .61673 .7843 L p .541 .172 .289 r
F P
0 g
s
.61673 .7843 m .6236 .76343 L .54625 .77368 L p .541 .172 .289 r
F P
0 g
s
.30558 .41918 m .27803 .45225 L .29805 .50221 L p .928 .847 .742 r
F P
0 g
s
.2806 .54103 m .29805 .50221 L .27803 .45225 L p .967 .846 .669 r
F P
0 g
s
.44602 .30714 m .48594 .3172 L .49821 .30935 L p .699 .824 .942 r
F P
0 g
s
.48594 .3172 m .44602 .30714 L .43109 .32722 L p .728 .817 .92 r
F P
0 g
s
.47143 .79057 m .46727 .77027 L .39314 .75338 L p .741 .329 .267 r
F P
0 g
s
.46727 .77027 m .47143 .79057 L .54485 .7937 L p .652 .266 .3 r
F P
0 g
s
.56102 .31292 m .59548 .29854 L .56759 .28574 L p .568 .731 .951 r
F P
0 g
s
.56759 .28574 m .54696 .30656 L .56102 .31292 L p .568 .731 .951 r
F P
0 g
s
.74129 .44236 m .76774 .47781 L .77482 .42569 L p .236 .326 .753 r
F P
0 g
s
.77482 .42569 m .74689 .39517 L .74129 .44236 L p .236 .326 .753 r
F P
0 g
s
.4702 .29138 m .49821 .30935 L .51366 .30466 L p .661 .817 .959 r
F P
0 g
s
.49821 .30935 m .4702 .29138 L .44602 .30714 L p .699 .824 .942 r
F P
0 g
s
.38668 .33472 m .43109 .32722 L .44602 .30714 L p .767 .883 .929 r
F P
0 g
s
.27072 .57976 m .26841 .61721 L .31704 .66166 L p .943 .681 .51 r
F P
0 g
s
.321 .69496 m .31704 .66166 L .26841 .61721 L p .945 .619 .381 r
F P
0 g
s
.54696 .30656 m .56759 .28574 L .53479 .27994 L p .588 .765 .964 r
F P
0 g
s
.53479 .27994 m .53055 .30369 L .54696 .30656 L p .588 .765 .964 r
F P
0 g
s
.6236 .76343 m .61673 .7843 L .68091 .76295 L p .379 .022 .229 r
F P
0 g
s
.68091 .76295 m .69285 .74009 L .6236 .76343 L p .379 .022 .229 r
F P
0 g
s
.50098 .2819 m .51366 .30466 L .53055 .30369 L p .621 .796 .966 r
F P
0 g
s
.51366 .30466 m .50098 .2819 L .4702 .29138 L p .661 .817 .959 r
F P
0 g
s
.76068 .60351 m .76276 .64063 L .79958 .59141 L p .141 .04 .47 r
F P
0 g
s
.79958 .59141 m .7971 .55361 L .76068 .60351 L p .141 .04 .47 r
F P
0 g
s
.38668 .33472 m .34652 .34962 L .34032 .39033 L p .846 .891 .871 r
F P
0 g
s
.30558 .41918 m .34032 .39033 L .34652 .34962 L p .896 .932 .832 r
F P
0 g
s
.53055 .30369 m .53479 .27994 L .50098 .2819 L p .621 .796 .966 r
F P
0 g
s
.6707 .35057 m .71179 .36982 L .69517 .32996 L p .357 .537 .895 r
F P
0 g
s
.69517 .32996 m .65715 .31937 L .6707 .35057 L p .357 .537 .895 r
F P
0 g
s
.70071 .71213 m .69285 .74009 L .74754 .70511 L p .232 0 .285 r
F P
0 g
s
.74754 .70511 m .75823 .67477 L .70071 .71213 L p .232 0 .285 r
F P
0 g
s
.27803 .45225 m .25847 .48833 L .2806 .54103 L p .967 .846 .669 r
F P
0 g
s
.27072 .57976 m .2806 .54103 L .25847 .48833 L p .995 .824 .56 r
F P
0 g
s
.61531 .31673 m .65715 .31937 L .62845 .29254 L p .445 .653 .948 r
F P
0 g
s
.62845 .29254 m .59548 .29854 L .61531 .31673 L p .445 .653 .948 r
F P
0 g
s
.321 .69496 m .33034 .72401 L .39314 .75338 L p .853 .479 .341 r
F P
0 g
s
.40262 .7751 m .39314 .75338 L .33034 .72401 L p .814 .364 .167 r
F P
0 g
s
.39314 .75338 m .40262 .7751 L .47143 .79057 L p .741 .329 .267 r
F P
0 g
s
.76774 .47781 m .78647 .51532 L .79471 .46022 L p .076 .166 .656 r
F P
0 g
s
.79471 .46022 m .77482 .42569 L .76774 .47781 L p .076 .166 .656 r
F P
0 g
s
.408 .30524 m .44602 .30714 L .4702 .29138 L p .706 .9 .966 r
F P
0 g
s
.44602 .30714 m .408 .30524 L .38668 .33472 L p .767 .883 .929 r
F P
0 g
s
.34652 .34962 m .38668 .33472 L .408 .30524 L p .802 .952 .917 r
F P
0 g
s
.54303 .80782 m .54485 .7937 L .47143 .79057 L p .586 .124 .123 r
F P
0 g
s
.54485 .7937 m .54303 .80782 L .60777 .79944 L p .457 .014 .106 r
F P
0 g
s
.60777 .79944 m .61673 .7843 L .54485 .7937 L p .457 .014 .106 r
F P
0 g
s
.34652 .34962 m .31206 .37143 L .30558 .41918 L p .896 .932 .832 r
F P
0 g
s
.27803 .45225 m .30558 .41918 L .31206 .37143 L p .937 .959 .755 r
F P
0 g
s
.71179 .36982 m .74689 .39517 L .72794 .34822 L p .177 .408 .847 r
F P
0 g
s
.72794 .34822 m .69517 .32996 L .71179 .36982 L p .177 .408 .847 r
F P
0 g
s
.47685 .80503 m .47143 .79057 L .40262 .7751 L p .674 .18 .068 r
F P
0 g
s
.47143 .79057 m .47685 .80503 L .54303 .80782 L p .586 .124 .123 r
F P
0 g
s
.76276 .64063 m .75823 .67477 L .79419 .62755 L p 0 0 .294 r
F P
0 g
s
.79419 .62755 m .79958 .59141 L .76276 .64063 L p 0 0 .294 r
F P
0 g
s
.26841 .61721 m .27343 .65229 L .321 .69496 L p .945 .619 .381 r
F P
0 g
s
.33034 .72401 m .321 .69496 L .27343 .65229 L p .913 .511 .191 r
F P
0 g
s
.59548 .29854 m .62845 .29254 L .58746 .27351 L p .429 .704 .98 r
F P
0 g
s
.58746 .27351 m .56759 .28574 L .59548 .29854 L p .429 .704 .98 r
F P
0 g
s
.25847 .48833 m .24735 .52612 L .27072 .57976 L p .995 .824 .56 r
F P
0 g
s
.26841 .61721 m .27072 .57976 L .24735 .52612 L p .992 .76 .392 r
F P
0 g
s
.69285 .74009 m .68091 .76295 L .73133 .73102 L p .085 0 .068 r
F P
0 g
s
.73133 .73102 m .74754 .70511 L .69285 .74009 L p .085 0 .068 r
F P
0 g
s
.61673 .7843 m .60777 .79944 L .66539 .78043 L p .25 0 .004 r
F P
0 g
s
.66539 .78043 m .68091 .76295 L .61673 .7843 L p .25 0 .004 r
F P
0 g
s
.4433 .28191 m .4702 .29138 L .50098 .2819 L p .615 .882 .99 r
F P
0 g
s
.4702 .29138 m .4433 .28191 L .408 .30524 L p .706 .9 .966 r
F P
0 g
s
.65715 .31937 m .69517 .32996 L .65867 .29539 L p .25 .558 .933 r
F P
0 g
s
.65867 .29539 m .62845 .29254 L .65715 .31937 L p .25 .558 .933 r
F P
0 g
s
.78647 .51532 m .7971 .55361 L .80604 .49745 L p 0 0 .494 r
F P
0 g
s
.80604 .49745 m .79471 .46022 L .78647 .51532 L p 0 0 .494 r
F P
0 g
s
.56759 .28574 m .58746 .27351 L .53889 .26486 L p .451 .767 .997 r
F P
0 g
s
.53889 .26486 m .53479 .27994 L .56759 .28574 L p .451 .767 .997 r
F P
0 g
s
.48875 .26779 m .50098 .2819 L .53479 .27994 L p .519 .832 1 r
F P
0 g
s
.50098 .2819 m .48875 .26779 L .4433 .28191 L p .615 .882 .99 r
F P
0 g
s
.31206 .37143 m .28453 .39934 L .27803 .45225 L p .937 .959 .755 r
F P
0 g
s
.25847 .48833 m .27803 .45225 L .28453 .39934 L p .944 .942 .608 r
F P
0 g
s
.53479 .27994 m .53889 .26486 L .48875 .26779 L p .519 .832 1 r
F P
0 g
s
.408 .30524 m .37329 .31179 L .34652 .34962 L p .802 .952 .917 r
F P
0 g
s
.31206 .37143 m .34652 .34962 L .37329 .31179 L p .81 .998 .847 r
F P
0 g
s
.33034 .72401 m .34454 .74825 L .40262 .7751 L p .814 .364 .167 r
F P
0 g
s
.41495 .79124 m .40262 .7751 L .34454 .74825 L p .709 .176 0 r
F P
0 g
s
.40262 .7751 m .41495 .79124 L .47685 .80503 L p .674 .18 .068 r
F P
0 g
s
.74689 .39517 m .77482 .42569 L .75421 .37349 L p 0 .203 .73 r
F P
0 g
s
.75421 .37349 m .72794 .34822 L .74689 .39517 L p 0 .203 .73 r
F P
0 g
s
.37329 .31179 m .408 .30524 L .4433 .28191 L p .673 .961 .94 r
F P
0 g
s
.75823 .67477 m .74754 .70511 L .78149 .66099 L p 0 0 .037 r
F P
0 g
s
.78149 .66099 m .79419 .62755 L .75823 .67477 L p 0 0 .037 r
F P
0 g
s
.27343 .65229 m .28524 .68409 L .33034 .72401 L p .913 .511 .191 r
F P
0 g
s
.34454 .74825 m .33034 .72401 L .28524 .68409 L p .804 .325 0 r
F P
0 g
s
.24735 .52612 m .24475 .56428 L .26841 .61721 L p .992 .76 .392 r
F P
0 g
s
.27343 .65229 m .26841 .61721 L .24475 .56428 L p .92 .621 .14 r
F P
0 g
s
.54083 .81607 m .54303 .80782 L .47685 .80503 L p .449 0 0 r
F P
0 g
s
.54303 .80782 m .54083 .81607 L .59703 .80883 L p .299 0 0 r
F P
0 g
s
.59703 .80883 m .60777 .79944 L .54303 .80782 L p .299 0 0 r
F P
0 g
s
.48335 .81366 m .47685 .80503 L .41495 .79124 L p .521 0 0 r
F P
0 g
s
.47685 .80503 m .48335 .81366 L .54083 .81607 L p .449 0 0 r
F P
0 g
s
.7971 .55361 m .79958 .59141 L .80869 .53599 L p 0 0 .24 r
F P
0 g
s
.80869 .53599 m .80604 .49745 L .7971 .55361 L p 0 0 .24 r
F P
0 g
s
.68091 .76295 m .66539 .78043 L .71035 .75211 L p 0 0 0 r
F P
0 g
s
.71035 .75211 m .73133 .73102 L .68091 .76295 L p 0 0 0 r
F P
0 g
s
.62845 .29254 m .65867 .29539 L .60577 .27069 L p .16 .594 .935 r
F P
0 g
s
.60577 .27069 m .58746 .27351 L .62845 .29254 L p .16 .594 .935 r
F P
0 g
s
.69517 .32996 m .72794 .34822 L .68491 .30719 L p 0 .356 .818 r
F P
0 g
s
.68491 .30719 m .65867 .29539 L .69517 .32996 L p 0 .356 .818 r
F P
0 g
s
.60777 .79944 m .59703 .80883 L .64685 .79246 L p .04 0 0 r
F P
0 g
s
.64685 .79246 m .66539 .78043 L .60777 .79944 L p .04 0 0 r
F P
0 g
s
.28453 .39934 m .26488 .43227 L .25847 .48833 L p .944 .942 .608 r
F P
0 g
s
.24735 .52612 m .25847 .48833 L .26488 .43227 L p .863 .828 .353 r
F P
0 g
s
.37329 .31179 m .34326 .32669 L .31206 .37143 L p .81 .998 .847 r
F P
0 g
s
.28453 .39934 m .31206 .37143 L .34326 .32669 L p .731 .951 .65 r
F P
0 g
s
.77482 .42569 m .79471 .46022 L .77301 .40479 L p 0 0 .488 r
F P
0 g
s
.77301 .40479 m .75421 .37349 L .77482 .42569 L p 0 0 .488 r
F P
0 g
s
.41857 .28161 m .4433 .28191 L .48875 .26779 L p .463 .883 .921 r
F P
0 g
s
.4433 .28191 m .41857 .28161 L .37329 .31179 L p .673 .961 .94 r
F P
0 g
s
.34454 .74825 m .36295 .76738 L .41495 .79124 L p .709 .176 0 r
F P
0 g
s
.4297 .80177 m .41495 .79124 L .36295 .76738 L p .483 0 0 r
F P
0 g
s
.41495 .79124 m .4297 .80177 L .48335 .81366 L p .521 0 0 r
F P
0 g
s
.74754 .70511 m .73133 .73102 L .7623 .6909 L p 0 0 0 r
F P
0 g
s
.7623 .6909 m .78149 .66099 L .74754 .70511 L p 0 0 0 r
F P
0 g
s
.24475 .56428 m .2504 .60154 L .27343 .65229 L p .92 .621 .14 r
F P
0 g
s
.28524 .68409 m .27343 .65229 L .2504 .60154 L p .731 .382 0 r
F P
0 g
s
.28524 .68409 m .30313 .71189 L .34454 .74825 L p .804 .325 0 r
F P
0 g
s
.36295 .76738 m .34454 .74825 L .30313 .71189 L p .574 .053 0 r
F P
0 g
s
.58746 .27351 m .60577 .27069 L .54268 .25942 L p .15 .656 .905 r
F P
0 g
s
.54268 .25942 m .53889 .26486 L .58746 .27351 L p .15 .656 .905 r
F P
0 g
s
.34326 .32669 m .37329 .31179 L .41857 .28161 L p .518 .904 .751 r
F P
0 g
s
.79958 .59141 m .79419 .62755 L .80293 .57444 L p 0 0 0 r
F P
0 g
s
.80293 .57444 m .80869 .53599 L .79958 .59141 L p 0 0 0 r
F P
0 g
s
.47746 .26325 m .48875 .26779 L .53889 .26486 L p .259 .758 .894 r
F P
0 g
s
.48875 .26779 m .47746 .26325 L .41857 .28161 L p .463 .883 .921 r
F P
0 g
s
.53834 .81858 m .54083 .81607 L .48335 .81366 L p .189 0 0 r
F P
0 g
s
.54083 .81607 m .53834 .81858 L .58482 .8126 L p .033 0 0 r
F P
0 g
s
.58482 .8126 m .59703 .80883 L .54083 .81607 L p .033 0 0 r
F P
0 g
s
.53889 .26486 m .54268 .25942 L .47746 .26325 L p .259 .758 .894 r
F P
0 g
s
.66539 .78043 m .64685 .79246 L .68541 .76818 L p 0 0 0 r
F P
0 g
s
.68541 .76818 m .71035 .75211 L .66539 .78043 L p 0 0 0 r
F P
0 g
s
.26488 .43227 m .25366 .46891 L .24735 .52612 L p .863 .828 .353 r
F P
0 g
s
.24475 .56428 m .24735 .52612 L .25366 .46891 L p 0 0 0 r
F P
0 g
s
.49075 .81659 m .48335 .81366 L .4297 .80177 L p .232 0 0 r
F P
0 g
s
.48335 .81366 m .49075 .81659 L .53834 .81858 L p .189 0 0 r
F P
0 g
s
.72794 .34822 m .75421 .37349 L .70607 .32761 L p .495 0 0 r
F P
0 g
s
.70607 .32761 m .68491 .30719 L .72794 .34822 L p .495 0 0 r
F P
0 g
s
.79471 .46022 m .80604 .49745 L .78376 .44081 L p .759 .437 0 r
F P
0 g
s
.78376 .44081 m .77301 .40479 L .79471 .46022 L p .759 .437 0 r
F P
0 g
s
.59703 .80883 m .58482 .8126 L .62584 .79912 L p .232 .738 .685 r
F P
0 g
s
.62584 .79912 m .64685 .79246 L .59703 .80883 L p .232 .738 .685 r
F P
0 g
s
.65867 .29539 m .68491 .30719 L .62176 .27771 L p 0 .295 .658 r
F P
0 g
s
.62176 .27771 m .60577 .27069 L .65867 .29539 L p 0 .295 .658 r
F P
0 g
s
.34326 .32669 m .31911 .34945 L .28453 .39934 L p .731 .951 .65 r
F P
0 g
s
.26488 .43227 m .28453 .39934 L .31911 .34945 L p 0 0 0 r
F P
0 g
s
.73133 .73102 m .71035 .75211 L .73757 .71669 L p .655 .911 .596 r
F P
0 g
s
.73757 .71669 m .7623 .6909 L .73133 .73102 L p .655 .911 .596 r
F P
0 g
s
.2504 .60154 m .26368 .63675 L .28524 .68409 L p .731 .382 0 r
F P
0 g
s
.30313 .71189 m .28524 .68409 L .26368 .63675 L p 0 0 .496 r
F P
0 g
s
.36295 .76738 m .3849 .78126 L .4297 .80177 L p .483 0 0 r
F P
0 g
s
.4297 .80177 m .44645 .80678 L .49075 .81659 L p .232 0 0 r
F P
0 g
s
.44645 .80678 m .4297 .80177 L .3849 .78126 L p 0 .405 .765 r
F P
0 g
s
.30313 .71189 m .32623 .73519 L .36295 .76738 L p .574 .053 0 r
F P
0 g
s
.3849 .78126 m .36295 .76738 L .32623 .73519 L p 0 .242 .712 r
F P
0 g
s
.79419 .62755 m .78149 .66099 L .78941 .61152 L p .859 .86 .408 r
F P
0 g
s
.78941 .61152 m .80293 .57444 L .79419 .62755 L p .859 .86 .408 r
F P
0 g
s
.41857 .28161 m .39703 .29075 L .34326 .32669 L p .518 .904 .751 r
F P
0 g
s
.39703 .29075 m .41857 .28161 L .47746 .26325 L p 0 0 0 r
F P
0 g
s
.25366 .46891 m .25104 .5078 L .24475 .56428 L p 0 0 0 r
F P
0 g
s
.2504 .60154 m .24475 .56428 L .25104 .5078 L p 0 0 .316 r
F P
0 g
s
.31911 .34945 m .34326 .32669 L .39703 .29075 L p 0 0 0 r
F P
0 g
s
.64685 .79246 m .62584 .79912 L .6573 .77922 L p .546 .928 .836 r
F P
0 g
s
.6573 .77922 m .68541 .76818 L .64685 .79246 L p .546 .928 .836 r
F P
0 g
s
.53559 .81558 m .53834 .81858 L .49075 .81659 L p .148 .68 .858 r
F P
0 g
s
.53834 .81858 m .53559 .81558 L .57142 .81097 L p .27 .772 .87 r
F P
0 g
s
.57142 .81097 m .58482 .8126 L .53834 .81858 L p .27 .772 .87 r
F P
0 g
s
.80604 .49745 m .80869 .53599 L .78628 .48005 L p .945 .677 .215 r
F P
0 g
s
.78628 .48005 m .78376 .44081 L .80604 .49745 L p .945 .677 .215 r
F P
0 g
s
.60577 .27069 m .62176 .27771 L .546 .26419 L p .307 0 0 r
F P
0 g
s
.546 .26419 m .54268 .25942 L .60577 .27069 L p .307 0 0 r
F P
0 g
s
.49888 .81404 m .49075 .81659 L .44645 .80678 L p .115 .629 .891 r
F P
0 g
s
.49075 .81659 m .49888 .81404 L .53559 .81558 L p .148 .68 .858 r
F P
0 g
s
.26368 .63675 m .28371 .66893 L .30313 .71189 L p 0 0 .496 r
F P
0 g
s
.32623 .73519 m .30313 .71189 L .28371 .66893 L p 0 .18 .715 r
F P
0 g
s
.75421 .37349 m .77301 .40479 L .7213 .35585 L p .806 .331 0 r
F P
0 g
s
.7213 .35585 m .70607 .32761 L .75421 .37349 L p .806 .331 0 r
F P
0 g
s
.71035 .75211 m .68541 .76818 L .70836 .73799 L p .746 .991 .8 r
F P
0 g
s
.70836 .73799 m .73757 .71669 L .71035 .75211 L p .746 .991 .8 r
F P
0 g
s
.31911 .34945 m .30177 .37917 L .26488 .43227 L p 0 0 0 r
F P
0 g
s
.25366 .46891 m .26488 .43227 L .30177 .37917 L p 0 0 .088 r
F P
0 g
s
.58482 .8126 m .57142 .81097 L .60288 .80058 L p .452 .878 .916 r
F P
0 g
s
.60288 .80058 m .62584 .79912 L .58482 .8126 L p .452 .878 .916 r
F P
0 g
s
.78149 .66099 m .7623 .6909 L .76905 .64612 L p .923 .957 .631 r
F P
0 g
s
.76905 .64612 m .78941 .61152 L .78149 .66099 L p .923 .957 .631 r
F P
0 g
s
.46758 .26879 m .47746 .26325 L .54268 .25942 L p .169 0 0 r
F P
0 g
s
.47746 .26325 m .46758 .26879 L .39703 .29075 L p 0 0 0 r
F P
0 g
s
.32623 .73519 m .35361 .75373 L .3849 .78126 L p 0 .242 .712 r
F P
0 g
s
.4097 .78992 m .3849 .78126 L .35361 .75373 L p .049 .465 .883 r
F P
0 g
s
.3849 .78126 m .4097 .78992 L .44645 .80678 L p 0 .405 .765 r
F P
0 g
s
.54268 .25942 m .546 .26419 L .46758 .26879 L p .169 0 0 r
F P
0 g
s
.68491 .30719 m .70607 .32761 L .63472 .29447 L p .652 .096 0 r
F P
0 g
s
.63472 .29447 m .62176 .27771 L .68491 .30719 L p .652 .096 0 r
F P
0 g
s
.4648 .80648 m .44645 .80678 L .4097 .78992 L p .167 .61 .937 r
F P
0 g
s
.44645 .80678 m .4648 .80648 L .49888 .81404 L p .115 .629 .891 r
F P
0 g
s
.25104 .5078 m .25674 .54746 L .2504 .60154 L p 0 0 .316 r
F P
0 g
s
.26368 .63675 m .2504 .60154 L .25674 .54746 L p 0 0 .545 r
F P
0 g
s
.80869 .53599 m .80293 .57444 L .78081 .52091 L p .999 .799 .456 r
F P
0 g
s
.78081 .52091 m .78628 .48005 L .80869 .53599 L p .999 .799 .456 r
F P
0 g
s
.62584 .79912 m .60288 .80058 L .62676 .78534 L p .631 .946 .95 r
F P
0 g
s
.62676 .78534 m .6573 .77922 L .62584 .79912 L p .631 .946 .95 r
F P
0 g
s
.28371 .66893 m .30945 .69738 L .32623 .73519 L p 0 .18 .715 r
F P
0 g
s
.35361 .75373 m .32623 .73519 L .30945 .69738 L p .081 .374 .838 r
F P
0 g
s
.39703 .29075 m .37961 .30915 L .31911 .34945 L p 0 0 0 r
F P
0 g
s
.30177 .37917 m .31911 .34945 L .37961 .30915 L p .088 0 .067 r
F P
0 g
s
.68541 .76818 m .6573 .77922 L .67566 .75464 L p .764 .985 .903 r
F P
0 g
s
.67566 .75464 m .70836 .73799 L .68541 .76818 L p .764 .985 .903 r
F P
0 g
s
.7623 .6909 m .73757 .71669 L .74297 .67738 L p .918 .976 .766 r
F P
0 g
s
.74297 .67738 m .76905 .64612 L .7623 .6909 L p .918 .976 .766 r
F P
0 g
s
.37961 .30915 m .39703 .29075 L .46758 .26879 L p .223 0 0 r
F P
0 g
s
.53265 .80734 m .53559 .81558 L .49888 .81404 L p .401 .794 .988 r
F P
0 g
s
.53559 .81558 m .53265 .80734 L .55707 .80417 L p .473 .845 .989 r
F P
0 g
s
.55707 .80417 m .57142 .81097 L .53559 .81558 L p .473 .845 .989 r
F P
0 g
s
.30177 .37917 m .29184 .41458 L .25366 .46891 L p 0 0 .088 r
F P
0 g
s
.25104 .5078 m .25366 .46891 L .29184 .41458 L p .022 0 .355 r
F P
0 g
s
.50759 .80628 m .49888 .81404 L .4648 .80648 L p .371 .748 .99 r
F P
0 g
s
.49888 .81404 m .50759 .80628 L .53265 .80734 L p .401 .794 .988 r
F P
0 g
s
.77301 .40479 m .78376 .44081 L .73004 .39067 L p .924 .539 .235 r
F P
0 g
s
.73004 .39067 m .7213 .35585 L .77301 .40479 L p .924 .539 .235 r
F P
0 g
s
.35361 .75373 m .38437 .76743 L .4097 .78992 L p .049 .465 .883 r
F P
0 g
s
.43674 .79353 m .4097 .78992 L .38437 .76743 L p .27 .603 .953 r
F P
0 g
s
.4097 .78992 m .43674 .79353 L .4648 .80648 L p .167 .61 .937 r
F P
0 g
s
.25674 .54746 m .27012 .58644 L .26368 .63675 L p 0 0 .545 r
F P
0 g
s
.28371 .66893 m .26368 .63675 L .27012 .58644 L p .077 .197 .688 r
F P
0 g
s
.57142 .81097 m .55707 .80417 L .5784 .79707 L p .567 .887 .989 r
F P
0 g
s
.5784 .79707 m .60288 .80058 L .57142 .81097 L p .567 .887 .989 r
F P
0 g
s
.62176 .27771 m .63472 .29447 L .54869 .27924 L p .599 .076 0 r
F P
0 g
s
.54869 .27924 m .546 .26419 L .62176 .27771 L p .599 .076 0 r
F P
0 g
s
.48441 .8011 m .4648 .80648 L .43674 .79353 L p .382 .711 .986 r
F P
0 g
s
.4648 .80648 m .48441 .8011 L .50759 .80628 L p .371 .748 .99 r
F P
0 g
s
.80293 .57444 m .78941 .61152 L .76799 .56181 L p .99 .849 .607 r
F P
0 g
s
.76799 .56181 m .78081 .52091 L .80293 .57444 L p .99 .849 .607 r
F P
0 g
s
.30945 .69738 m .33977 .7216 L .35361 .75373 L p .081 .374 .838 r
F P
0 g
s
.38437 .76743 m .35361 .75373 L .33977 .7216 L p .252 .505 .901 r
F P
0 g
s
.73757 .71669 m .70836 .73799 L .71235 .70471 L p .884 .961 .843 r
F P
0 g
s
.71235 .70471 m .74297 .67738 L .73757 .71669 L p .884 .961 .843 r
F P
0 g
s
.70607 .32761 m .7213 .35585 L .64408 .32038 L p .802 .349 .164 r
F P
0 g
s
.64408 .32038 m .63472 .29447 L .70607 .32761 L p .802 .349 .164 r
F P
0 g
s
.6573 .77922 m .62676 .78534 L .64039 .76664 L p .748 .945 .946 r
F P
0 g
s
.64039 .76664 m .67566 .75464 L .6573 .77922 L p .748 .945 .946 r
F P
0 g
s
.60288 .80058 m .5784 .79707 L .59442 .78671 L p .657 .906 .98 r
F P
0 g
s
.59442 .78671 m .62676 .78534 L .60288 .80058 L p .657 .906 .98 r
F P
0 g
s
.45957 .28442 m .46758 .26879 L .546 .26419 L p .46 0 .001 r
F P
0 g
s
.46758 .26879 m .45957 .28442 L .37961 .30915 L p .223 0 0 r
F P
0 g
s
.29184 .41458 m .28951 .45414 L .25104 .5078 L p .022 0 .355 r
F P
0 g
s
.25674 .54746 m .25104 .5078 L .28951 .45414 L p .179 .099 .522 r
F P
0 g
s
.546 .26419 m .54869 .27924 L .45957 .28442 L p .46 0 .001 r
F P
0 g
s
.27012 .58644 m .29022 .6235 L .28371 .66893 L p .077 .197 .688 r
F P
0 g
s
.30945 .69738 m .28371 .66893 L .29022 .6235 L p .217 .34 .776 r
F P
0 g
s
.37961 .30915 m .36705 .33611 L .30177 .37917 L p .088 0 .067 r
F P
0 g
s
.29184 .41458 m .30177 .37917 L .36705 .33611 L p .267 .006 .32 r
F P
0 g
s
.38437 .76743 m .41767 .77636 L .43674 .79353 L p .27 .603 .953 r
F P
0 g
s
.46547 .79227 m .43674 .79353 L .41767 .77636 L p .421 .683 .971 r
F P
0 g
s
.43674 .79353 m .46547 .79227 L .48441 .8011 L p .382 .711 .986 r
F P
0 g
s
.78376 .44081 m .78628 .48005 L .73208 .43051 L p .947 .644 .431 r
F P
0 g
s
.73208 .43051 m .73004 .39067 L .78376 .44081 L p .947 .644 .431 r
F P
0 g
s
.52954 .79406 m .53265 .80734 L .50759 .80628 L p .54 .806 .995 r
F P
0 g
s
.53265 .80734 m .52954 .79406 L .54198 .79243 L p .574 .83 .994 r
F P
0 g
s
.54198 .79243 m .55707 .80417 L .53265 .80734 L p .574 .83 .994 r
F P
0 g
s
.51677 .79351 m .50759 .80628 L .48441 .8011 L p .52 .779 .991 r
F P
0 g
s
.50759 .80628 m .51677 .79351 L .52954 .79406 L p .54 .806 .995 r
F P
0 g
s
.33977 .7216 m .37357 .74137 L .38437 .76743 L p .252 .505 .901 r
F P
0 g
s
.41767 .77636 m .38437 .76743 L .37357 .74137 L p .377 .597 .932 r
F P
0 g
s
.55707 .80417 m .54198 .79243 L .55278 .78879 L p .616 .846 .987 r
F P
0 g
s
.55278 .78879 m .5784 .79707 L .55707 .80417 L p .616 .846 .987 r
F P
0 g
s
.78941 .61152 m .76905 .64612 L .74877 .60133 L p .959 .866 .703 r
F P
0 g
s
.74877 .60133 m .76799 .56181 L .78941 .61152 L p .959 .866 .703 r
F P
0 g
s
.70836 .73799 m .67566 .75464 L .67833 .72774 L p .841 .932 .888 r
F P
0 g
s
.67833 .72774 m .71235 .70471 L .70836 .73799 L p .841 .932 .888 r
F P
0 g
s
.36705 .33611 m .37961 .30915 L .45957 .28442 L p .407 .038 .222 r
F P
0 g
s
.505 .79085 m .48441 .8011 L .46547 .79227 L p .517 .753 .982 r
F P
0 g
s
.48441 .8011 m .505 .79085 L .51677 .79351 L p .52 .779 .991 r
F P
0 g
s
.62676 .78534 m .59442 .78671 L .60334 .7741 L p .719 .895 .959 r
F P
0 g
s
.60334 .7741 m .64039 .76664 L .62676 .78534 L p .719 .895 .959 r
F P
0 g
s
.29022 .6235 m .31591 .65762 L .30945 .69738 L p .217 .34 .776 r
F P
0 g
s
.33977 .7216 m .30945 .69738 L .31591 .65762 L p .321 .446 .832 r
F P
0 g
s
.5784 .79707 m .55278 .78879 L .56079 .78352 L p .656 .851 .975 r
F P
0 g
s
.56079 .78352 m .59442 .78671 L .5784 .79707 L p .656 .851 .975 r
F P
0 g
s
.28951 .45414 m .29457 .49613 L .25674 .54746 L p .179 .099 .522 r
F P
0 g
s
.27012 .58644 m .25674 .54746 L .29457 .49613 L p .286 .24 .63 r
F P
0 g
s
.41767 .77636 m .4528 .78064 L .46547 .79227 L p .421 .683 .971 r
F P
0 g
s
.49545 .78634 m .46547 .79227 L .4528 .78064 L p .527 .73 .967 r
F P
0 g
s
.46547 .79227 m .49545 .78634 L .505 .79085 L p .517 .753 .982 r
F P
0 g
s
.67566 .75464 m .64039 .76664 L .64194 .74635 L p .796 .899 .915 r
F P
0 g
s
.64194 .74635 m .67833 .72774 L .67566 .75464 L p .796 .899 .915 r
F P
0 g
s
.63472 .29447 m .64408 .32038 L .55064 .30404 L p .706 .291 .255 r
F P
0 g
s
.55064 .30404 m .54869 .27924 L .63472 .29447 L p .706 .291 .255 r
F P
0 g
s
.37357 .74137 m .40989 .75661 L .41767 .77636 L p .377 .597 .932 r
F P
0 g
s
.4528 .78064 m .41767 .77636 L .40989 .75661 L p .471 .663 .946 r
F P
0 g
s
.7213 .35585 m .73004 .39067 L .64945 .35427 L p .844 .483 .37 r
F P
0 g
s
.64945 .35427 m .64408 .32038 L .7213 .35585 L p .844 .483 .37 r
F P
0 g
s
.76905 .64612 m .74297 .67738 L .72427 .63831 L p .921 .867 .769 r
F P
0 g
s
.72427 .63831 m .74877 .60133 L .76905 .64612 L p .921 .867 .769 r
F P
0 g
s
.78628 .48005 m .78081 .52091 L .72763 .47356 L p .937 .7 .554 r
F P
0 g
s
.72763 .47356 m .73208 .43051 L .78628 .48005 L p .937 .7 .554 r
F P
0 g
s
.31591 .65762 m .34597 .68806 L .33977 .7216 L p .321 .446 .832 r
F P
0 g
s
.37357 .74137 m .33977 .7216 L .34597 .68806 L p .402 .529 .87 r
F P
0 g
s
.36705 .33611 m .35984 .37042 L .29184 .41458 L p .267 .006 .32 r
F P
0 g
s
.28951 .45414 m .29184 .41458 L .35984 .37042 L p .371 .169 .471 r
F P
0 g
s
.59442 .78671 m .56079 .78352 L .56515 .77714 L p .687 .844 .959 r
F P
0 g
s
.56515 .77714 m .60334 .7741 L .59442 .78671 L p .687 .844 .959 r
F P
0 g
s
.52632 .77588 m .52954 .79406 L .51677 .79351 L closepath p .613 .785 .964 r
F P
0 g
s
.52632 .77588 m .54198 .79243 L .52954 .79406 L closepath p .622 .792 .963 r
F P
0 g
s
.45378 .3096 m .45957 .28442 L .54869 .27924 L p .583 .194 .27 r
F P
0 g
s
.45957 .28442 m .45378 .3096 L .36705 .33611 L p .407 .038 .222 r
F P
0 g
s
.52632 .77588 m .51677 .79351 L .505 .79085 L closepath p .607 .777 .962 r
F P
0 g
s
.52632 .77588 m .55278 .78879 L .54198 .79243 L closepath p .633 .796 .961 r
F P
0 g
s
.64039 .76664 m .60334 .7741 L .60404 .76052 L p .751 .864 .931 r
F P
0 g
s
.60404 .76052 m .64194 .74635 L .64039 .76664 L p .751 .864 .931 r
F P
0 g
s
.29457 .49613 m .3064 .53886 L .27012 .58644 L p .286 .24 .63 r
F P
0 g
s
.29022 .6235 m .27012 .58644 L .3064 .53886 L p .362 .343 .703 r
F P
0 g
s
.52632 .77588 m .505 .79085 L .49545 .78634 L closepath p .604 .768 .959 r
F P
0 g
s
.40989 .75661 m .44787 .76737 L .4528 .78064 L p .471 .663 .946 r
F P
0 g
s
.48917 .78044 m .4528 .78064 L .44787 .76737 L p .546 .713 .949 r
F P
0 g
s
.4528 .78064 m .48917 .78044 L .49545 .78634 L p .527 .73 .967 r
F P
0 g
s
.54869 .27924 m .55064 .30404 L .45378 .3096 L p .583 .194 .27 r
F P
0 g
s
.74297 .67738 m .71235 .70471 L .69569 .67185 L p .882 .862 .816 r
F P
0 g
s
.69569 .67185 m .72427 .63831 L .74297 .67738 L p .882 .862 .816 r
F P
0 g
s
.52632 .77588 m .56079 .78352 L .55278 .78879 L closepath p .644 .797 .956 r
F P
0 g
s
.34597 .68806 m .37924 .71437 L .37357 .74137 L p .402 .529 .87 r
F P
0 g
s
.40989 .75661 m .37357 .74137 L .37924 .71437 L p .467 .595 .897 r
F P
0 g
s
.52632 .77588 m .49545 .78634 L .48917 .78044 L closepath p .605 .76 .953 r
F P
0 g
s
.35984 .37042 m .36705 .33611 L .45378 .3096 L p .497 .204 .399 r
F P
0 g
s
.52632 .77588 m .56515 .77714 L .56079 .78352 L closepath p .653 .795 .95 r
F P
0 g
s
.60334 .7741 m .56515 .77714 L .56532 .77035 L p .706 .828 .94 r
F P
0 g
s
.56532 .77035 m .60404 .76052 L .60334 .7741 L p .706 .828 .94 r
F P
0 g
s
.78081 .52091 m .76799 .56181 L .71723 .51797 L p .916 .731 .637 r
F P
0 g
s
.71723 .51797 m .72763 .47356 L .78081 .52091 L p .916 .731 .637 r
F P
0 g
s
.37924 .71437 m .41468 .73632 L .40989 .75661 L p .467 .595 .897 r
F P
0 g
s
.44787 .76737 m .40989 .75661 L .41468 .73632 L p .522 .652 .917 r
F P
0 g
s
.71235 .70471 m .67833 .72774 L .66418 .7014 L p .842 .852 .852 r
F P
0 g
s
.66418 .7014 m .69569 .67185 L .71235 .70471 L p .842 .852 .852 r
F P
0 g
s
.44787 .76737 m .48686 .77377 L .48917 .78044 L p .546 .713 .949 r
F P
0 g
s
.52632 .77588 m .48917 .78044 L .48686 .77377 L closepath p .609 .754 .947 r
F P
0 g
s
.3064 .53886 m .32411 .58073 L .29022 .6235 L p .362 .343 .703 r
F P
0 g
s
.31591 .65762 m .29022 .6235 L .32411 .58073 L p .42 .424 .757 r
F P
0 g
s
.73004 .39067 m .73208 .43051 L .65072 .39452 L p .85 .558 .494 r
F P
0 g
s
.65072 .39452 m .64945 .35427 L .73004 .39067 L p .85 .558 .494 r
F P
0 g
s
.35984 .37042 m .35815 .41049 L .28951 .45414 L p .371 .169 .471 r
F P
0 g
s
.29457 .49613 m .28951 .45414 L .35815 .41049 L p .437 .28 .57 r
F P
0 g
s
.52632 .77588 m .56532 .77035 L .56515 .77714 L closepath p .66 .791 .944 r
F P
0 g
s
.41468 .73632 m .45143 .75386 L .44787 .76737 L p .522 .652 .917 r
F P
0 g
s
.48686 .77377 m .44787 .76737 L .45143 .75386 L p .571 .703 .931 r
F P
0 g
s
.67833 .72774 m .64194 .74635 L .63075 .72664 L p .801 .839 .88 r
F P
0 g
s
.63075 .72664 m .66418 .7014 L .67833 .72774 L p .801 .839 .88 r
F P
0 g
s
.45143 .75386 m .48882 .76703 L .48686 .77377 L p .571 .703 .931 r
F P
0 g
s
.52632 .77588 m .48686 .77377 L .48882 .76703 L closepath p .615 .749 .941 r
F P
0 g
s
.64408 .32038 m .64945 .35427 L .55176 .33748 L p .744 .408 .415 r
F P
0 g
s
.55176 .33748 m .55064 .30404 L .64408 .32038 L p .744 .408 .415 r
F P
0 g
s
.52632 .77588 m .55331 .75841 L .56124 .76386 L closepath p .665 .776 .932 r
F P
0 g
s
.52632 .77588 m .54236 .7546 L .55331 .75841 L closepath p .662 .768 .928 r
F P
0 g
s
.52632 .77588 m .5296 .75289 L .54236 .7546 L closepath p .657 .76 .926 r
F P
0 g
s
.52632 .77588 m .51648 .75347 L .5296 .75289 L closepath p .65 .754 .925 r
F P
0 g
s
.52632 .77588 m .50447 .75627 L .51648 .75347 L closepath p .642 .749 .927 r
F P
0 g
s
.52632 .77588 m .4949 .76098 L .50447 .75627 L closepath p .633 .747 .93 r
F P
0 g
s
.52632 .77588 m .48882 .76703 L .4949 .76098 L closepath p .624 .747 .935 r
F P
0 g
s
.52632 .77588 m .56124 .76386 L .56532 .77035 L closepath p .664 .784 .938 r
F P
0 g
s
.64194 .74635 m .60404 .76052 L .59622 .74746 L p .759 .824 .903 r
F P
0 g
s
.59622 .74746 m .63075 .72664 L .64194 .74635 L p .759 .824 .903 r
F P
0 g
s
.32411 .58073 m .34663 .6204 L .31591 .65762 L p .42 .424 .757 r
F P
0 g
s
.34597 .68806 m .31591 .65762 L .34663 .6204 L p .466 .491 .8 r
F P
0 g
s
.60404 .76052 m .56532 .77035 L .56124 .76386 L p .714 .806 .922 r
F P
0 g
s
.56124 .76386 m .59622 .74746 L .60404 .76052 L p .714 .806 .922 r
F P
0 g
s
.76799 .56181 m .74877 .60133 L .70168 .56201 L p .893 .751 .698 r
F P
0 g
s
.70168 .56201 m .71723 .51797 L .76799 .56181 L p .893 .751 .698 r
F P
0 g
s
.46332 .74161 m .4949 .76098 L .48882 .76703 L p .597 .698 .914 r
F P
0 g
s
.48882 .76703 m .45143 .75386 L .46332 .74161 L p .597 .698 .914 r
F P
0 g
s
.34663 .6204 m .37281 .65688 L .34597 .68806 L p .466 .491 .8 r
F P
0 g
s
.37924 .71437 m .34597 .68806 L .37281 .65688 L p .505 .549 .835 r
F P
0 g
s
.45044 .3432 m .45378 .3096 L .55064 .30404 L p .636 .322 .422 r
F P
0 g
s
.45378 .3096 m .45044 .3432 L .35984 .37042 L p .497 .204 .399 r
F P
0 g
s
.59622 .74746 m .56124 .76386 L .55331 .75841 L p .712 .782 .907 r
F P
0 g
s
.43201 .71776 m .46332 .74161 L .45143 .75386 L p .569 .65 .89 r
F P
0 g
s
.45143 .75386 m .41468 .73632 L .43201 .71776 L p .569 .65 .89 r
F P
0 g
s
.37281 .65688 m .40159 .68946 L .37924 .71437 L p .505 .549 .835 r
F P
0 g
s
.41468 .73632 m .37924 .71437 L .40159 .68946 L p .539 .601 .864 r
F P
0 g
s
.35815 .41049 m .36182 .45444 L .29457 .49613 L p .437 .28 .57 r
F P
0 g
s
.3064 .53886 m .29457 .49613 L .36182 .45444 L p .482 .361 .639 r
F P
0 g
s
.40159 .68946 m .43201 .71776 L .41468 .73632 L p .539 .601 .864 r
F P
0 g
s
.35815 .41049 m .35984 .37042 L .45044 .3432 L p .547 .31 .507 r
F P
0 g
s
.48236 .73203 m .50447 .75627 L .4949 .76098 L p .623 .7 .9 r
F P
0 g
s
.4949 .76098 m .46332 .74161 L .48236 .73203 L p .623 .7 .9 r
F P
0 g
s
.55064 .30404 m .55176 .33748 L .45044 .3432 L p .636 .322 .422 r
F P
0 g
s
.74877 .60133 m .72427 .63831 L .68196 .60419 L p .868 .764 .746 r
F P
0 g
s
.68196 .60419 m .70168 .56201 L .74877 .60133 L p .868 .764 .746 r
F P
0 g
s
.55331 .75841 m .58054 .73638 L .59622 .74746 L p .712 .782 .907 r
F P
0 g
s
.58054 .73638 m .55331 .75841 L .54236 .7546 L p .703 .759 .895 r
F P
0 g
s
.73208 .43051 m .72763 .47356 L .64797 .4392 L p .845 .606 .578 r
F P
0 g
s
.64797 .4392 m .65072 .39452 L .73208 .43051 L p .845 .606 .578 r
F P
0 g
s
.63075 .72664 m .59622 .74746 L .58054 .73638 L p .751 .784 .879 r
F P
0 g
s
.50649 .72628 m .51648 .75347 L .50447 .75627 L p .647 .708 .892 r
F P
0 g
s
.50447 .75627 m .48236 .73203 L .50649 .72628 L p .647 .708 .892 r
F P
0 g
s
.54236 .7546 m .55862 .7286 L .58054 .73638 L p .703 .759 .895 r
F P
0 g
s
.55862 .7286 m .54236 .7546 L .5296 .75289 L p .688 .738 .889 r
F P
0 g
s
.53295 .72509 m .5296 .75289 L .51648 .75347 L p .669 .721 .888 r
F P
0 g
s
.51648 .75347 m .50649 .72628 L .53295 .72509 L p .669 .721 .888 r
F P
0 g
s
.72427 .63831 m .69569 .67185 L .65909 .64335 L p .842 .773 .786 r
F P
0 g
s
.65909 .64335 m .68196 .60419 L .72427 .63831 L p .842 .773 .786 r
F P
0 g
s
.5296 .75289 m .53295 .72509 L .55862 .7286 L p .688 .738 .889 r
F P
0 g
s
.66418 .7014 m .63075 .72664 L .60761 .70979 L p .785 .783 .851 r
F P
0 g
s
.58054 .73638 m .60761 .70979 L .63075 .72664 L p .751 .784 .879 r
F P
0 g
s
.46031 .70314 m .48236 .73203 L .46332 .74161 L p .611 .657 .87 r
F P
0 g
s
.46332 .74161 m .43201 .71776 L .46031 .70314 L p .611 .657 .87 r
F P
0 g
s
.69569 .67185 m .66418 .7014 L .63402 .67871 L p .814 .779 .82 r
F P
0 g
s
.63402 .67871 m .65909 .64335 L .69569 .67185 L p .814 .779 .82 r
F P
0 g
s
.60761 .70979 m .63402 .67871 L .66418 .7014 L p .785 .783 .851 r
F P
0 g
s
.36182 .45444 m .37041 .5003 L .3064 .53886 L p .482 .361 .639 r
F P
0 g
s
.32411 .58073 m .3064 .53886 L .37041 .5003 L p .515 .426 .693 r
F P
0 g
s
.64945 .35427 m .65072 .39452 L .55202 .37792 L p .757 .481 .515 r
F P
0 g
s
.55202 .37792 m .55176 .33748 L .64945 .35427 L p .757 .481 .515 r
F P
0 g
s
.60761 .70979 m .58054 .73638 L .55862 .7286 L p .733 .747 .863 r
F P
0 g
s
.43875 .66971 m .46031 .70314 L .43201 .71776 L p .597 .614 .84 r
F P
0 g
s
.43201 .71776 m .40159 .68946 L .43875 .66971 L p .597 .614 .84 r
F P
0 g
s
.72763 .47356 m .71723 .51797 L .64157 .48623 L p .835 .64 .639 r
F P
0 g
s
.64157 .48623 m .64797 .4392 L .72763 .47356 L p .835 .64 .639 r
F P
0 g
s
.45044 .3432 m .44966 .38357 L .35815 .41049 L p .547 .31 .507 r
F P
0 g
s
.36182 .45444 m .35815 .41049 L .44966 .38357 L p .578 .384 .582 r
F P
0 g
s
.4965 .69434 m .50649 .72628 L .48236 .73203 L p .648 .67 .858 r
F P
0 g
s
.48236 .73203 m .46031 .70314 L .4965 .69434 L p .648 .67 .858 r
F P
0 g
s
.37041 .5003 m .38323 .54621 L .32411 .58073 L p .515 .426 .693 r
F P
0 g
s
.34663 .6204 m .32411 .58073 L .38323 .54621 L p .541 .48 .736 r
F P
0 g
s
.44966 .38357 m .45044 .3432 L .55176 .33748 L p .662 .403 .518 r
F P
0 g
s
.55862 .7286 m .57488 .6979 L .60761 .70979 L p .733 .747 .863 r
F P
0 g
s
.57488 .6979 m .55862 .7286 L .53295 .72509 L p .709 .715 .854 r
F P
0 g
s
.41823 .63199 m .43875 .66971 L .40159 .68946 L p .581 .572 .808 r
F P
0 g
s
.40159 .68946 m .37281 .65688 L .41823 .63199 L p .581 .572 .808 r
F P
0 g
s
.38323 .54621 m .39945 .59053 L .34663 .6204 L p .541 .48 .736 r
F P
0 g
s
.37281 .65688 m .34663 .6204 L .39945 .59053 L p .562 .527 .774 r
F P
0 g
s
.5363 .69251 m .53295 .72509 L .50649 .72628 L p .68 .69 .852 r
F P
0 g
s
.50649 .72628 m .4965 .69434 L .5363 .69251 L p .68 .69 .852 r
F P
0 g
s
.39945 .59053 m .41823 .63199 L .37281 .65688 L p .562 .527 .774 r
F P
0 g
s
.63402 .67871 m .60761 .70979 L .57488 .6979 L p .757 .734 .831 r
F P
0 g
s
.55176 .33748 m .55202 .37792 L .44966 .38357 L p .662 .403 .518 r
F P
0 g
s
.53295 .72509 m .5363 .69251 L .57488 .6979 L p .709 .715 .854 r
F P
0 g
s
.71723 .51797 m .70168 .56201 L .63203 .53364 L p .823 .665 .688 r
F P
0 g
s
.63203 .53364 m .64157 .48623 L .71723 .51797 L p .823 .665 .688 r
F P
0 g
s
.48668 .65776 m .4965 .69434 L .46031 .70314 L p .645 .634 .825 r
F P
0 g
s
.46031 .70314 m .43875 .66971 L .48668 .65776 L p .645 .634 .825 r
F P
0 g
s
.65072 .39452 m .64797 .4392 L .55145 .42335 L p .76 .53 .584 r
F P
0 g
s
.55145 .42335 m .55202 .37792 L .65072 .39452 L p .76 .53 .584 r
F P
0 g
s
.65909 .64335 m .63402 .67871 L .59082 .6626 L p .777 .719 .799 r
F P
0 g
s
.57488 .6979 m .59082 .6626 L .63402 .67871 L p .757 .734 .831 r
F P
0 g
s
.44966 .38357 m .45136 .42875 L .36182 .45444 L p .578 .384 .582 r
F P
0 g
s
.37041 .5003 m .36182 .45444 L .45136 .42875 L p .598 .44 .638 r
F P
0 g
s
.70168 .56201 m .68196 .60419 L .61996 .57969 L p .809 .686 .729 r
F P
0 g
s
.61996 .57969 m .63203 .53364 L .70168 .56201 L p .809 .686 .729 r
F P
0 g
s
.59082 .6626 m .57488 .6979 L .5363 .69251 L p .724 .693 .82 r
F P
0 g
s
.68196 .60419 m .65909 .64335 L .60602 .623 L p .794 .704 .765 r
F P
0 g
s
.59082 .6626 m .60602 .623 L .65909 .64335 L p .777 .719 .799 r
F P
0 g
s
.60602 .623 m .61996 .57969 L .68196 .60419 L p .794 .704 .765 r
F P
0 g
s
.53959 .65527 m .5363 .69251 L .4965 .69434 L p .687 .66 .818 r
F P
0 g
s
.4965 .69434 m .48668 .65776 L .53959 .65527 L p .687 .66 .818 r
F P
0 g
s
.45136 .42875 m .44966 .38357 L .55202 .37792 L p .676 .46 .585 r
F P
0 g
s
.4773 .61686 m .48668 .65776 L .43875 .66971 L p .64 .599 .792 r
F P
0 g
s
.43875 .66971 m .41823 .63199 L .4773 .61686 L p .64 .599 .792 r
F P
0 g
s
.5363 .69251 m .53959 .65527 L .59082 .6626 L p .724 .693 .82 r
F P
0 g
s
.45136 .42875 m .45533 .47659 L .37041 .5003 L p .598 .44 .638 r
F P
0 g
s
.38323 .54621 m .37041 .5003 L .45533 .47659 L p .613 .487 .684 r
F P
0 g
s
.55202 .37792 m .55145 .42335 L .45136 .42875 L p .676 .46 .585 r
F P
0 g
s
.64797 .4392 m .64157 .48623 L .55012 .47162 L p .76 .568 .638 r
F P
0 g
s
.55012 .47162 m .55145 .42335 L .64797 .4392 L p .76 .568 .638 r
F P
0 g
s
.4687 .57228 m .4773 .61686 L .41823 .63199 L p .633 .564 .758 r
F P
0 g
s
.41823 .63199 m .39945 .59053 L .4687 .57228 L p .633 .564 .758 r
F P
0 g
s
.60602 .623 m .59082 .6626 L .53959 .65527 L p .736 .671 .787 r
F P
0 g
s
.45533 .47659 m .46123 .52504 L .38323 .54621 L p .613 .487 .684 r
F P
0 g
s
.39945 .59053 m .38323 .54621 L .46123 .52504 L p .625 .527 .723 r
F P
0 g
s
.46123 .52504 m .4687 .57228 L .39945 .59053 L p .625 .527 .723 r
F P
0 g
s
.54273 .6137 m .53959 .65527 L .48668 .65776 L p .691 .632 .785 r
F P
0 g
s
.48668 .65776 m .4773 .61686 L .54273 .6137 L p .691 .632 .785 r
F P
0 g
s
.53959 .65527 m .54273 .6137 L .60602 .623 L p .736 .671 .787 r
F P
0 g
s
.45533 .47659 m .45136 .42875 L .55145 .42335 L p .685 .505 .637 r
F P
0 g
s
.61996 .57969 m .60602 .623 L .54273 .6137 L p .744 .649 .754 r
F P
0 g
s
.64157 .48623 m .63203 .53364 L .54813 .52061 L p .756 .598 .681 r
F P
0 g
s
.54813 .52061 m .55012 .47162 L .64157 .48623 L p .756 .598 .681 r
F P
0 g
s
.55145 .42335 m .55012 .47162 L .45533 .47659 L p .685 .505 .637 r
F P
0 g
s
.63203 .53364 m .61996 .57969 L .54562 .56846 L p .751 .625 .719 r
F P
0 g
s
.54273 .6137 m .54562 .56846 L .61996 .57969 L p .744 .649 .754 r
F P
0 g
s
.54562 .56846 m .54813 .52061 L .63203 .53364 L p .751 .625 .719 r
F P
0 g
s
.54562 .56846 m .54273 .6137 L .4773 .61686 L p .692 .603 .752 r
F P
0 g
s
.4773 .61686 m .4687 .57228 L .54562 .56846 L p .692 .603 .752 r
F P
0 g
s
.46123 .52504 m .45533 .47659 L .55012 .47162 L p .689 .541 .68 r
F P
0 g
s
.54813 .52061 m .54562 .56846 L .4687 .57228 L p .692 .573 .717 r
F P
0 g
s
.4687 .57228 m .46123 .52504 L .54813 .52061 L p .692 .573 .717 r
F P
0 g
s
.55012 .47162 m .54813 .52061 L .46123 .52504 L p .689 .541 .68 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48443 .50387 m .47702 .54894 L .54297 .55222 L p .718 .601 .724 r
F P
0 g
s
.54297 .55222 m .54047 .50673 L .48443 .50387 L p .718 .601 .724 r
F P
0 g
s
.54494 .59696 m .54297 .55222 L .47702 .54894 L p .72 .574 .69 r
F P
0 g
s
.54047 .50673 m .54297 .55222 L .60748 .54238 L p .671 .564 .726 r
F P
0 g
s
.54297 .55222 m .54494 .59696 L .61717 .58624 L p .666 .533 .692 r
F P
0 g
s
.61717 .58624 m .60748 .54238 L .54297 .55222 L p .666 .533 .692 r
F P
0 g
s
.47702 .54894 m .47116 .5934 L .54494 .59696 L p .72 .574 .69 r
F P
0 g
s
.54636 .63987 m .54494 .59696 L .47116 .5934 L p .72 .547 .655 r
F P
0 g
s
.54494 .59696 m .54636 .63987 L .62415 .62863 L p .659 .499 .656 r
F P
0 g
s
.62415 .62863 m .61717 .58624 L .54494 .59696 L p .659 .499 .656 r
F P
0 g
s
.43216 .48978 m .41534 .53277 L .47702 .54894 L p .762 .643 .729 r
F P
0 g
s
.47702 .54894 m .48443 .50387 L .43216 .48978 L p .762 .643 .729 r
F P
0 g
s
.47116 .5934 m .47702 .54894 L .41534 .53277 L p .771 .622 .695 r
F P
0 g
s
.49328 .45936 m .48443 .50387 L .54047 .50673 L p .715 .626 .757 r
F P
0 g
s
.54047 .50673 m .53748 .46168 L .49328 .45936 L p .715 .626 .757 r
F P
0 g
s
.53748 .46168 m .54047 .50673 L .59524 .49815 L p .675 .596 .759 r
F P
0 g
s
.60748 .54238 m .59524 .49815 L .54047 .50673 L p .671 .564 .726 r
F P
0 g
s
.45216 .44798 m .43216 .48978 L .48443 .50387 L p .751 .662 .763 r
F P
0 g
s
.48443 .50387 m .49328 .45936 L .45216 .44798 L p .751 .662 .763 r
F P
0 g
s
.41534 .53277 m .40201 .57575 L .47116 .5934 L p .771 .622 .695 r
F P
0 g
s
.46695 .63613 m .47116 .5934 L .40201 .57575 L p .777 .599 .657 r
F P
0 g
s
.47116 .5934 m .46695 .63613 L .54636 .63987 L p .72 .547 .655 r
F P
0 g
s
.59524 .49815 m .60748 .54238 L .6649 .52007 L p .619 .533 .735 r
F P
0 g
s
.60748 .54238 m .61717 .58624 L .68168 .56188 L p .605 .493 .699 r
F P
0 g
s
.68168 .56188 m .6649 .52007 L .60748 .54238 L p .605 .493 .699 r
F P
0 g
s
.54722 .67997 m .54636 .63987 L .46695 .63613 L p .718 .515 .615 r
F P
0 g
s
.54636 .63987 m .54722 .67997 L .62834 .66854 L p .65 .462 .615 r
F P
0 g
s
.62834 .66854 m .62415 .62863 L .54636 .63987 L p .65 .462 .615 r
F P
0 g
s
.59524 .49815 m .58065 .45474 L .53748 .46168 L p .675 .596 .759 r
F P
0 g
s
.58065 .45474 m .59524 .49815 L .64375 .47876 L p .632 .571 .768 r
F P
0 g
s
.6649 .52007 m .64375 .47876 L .59524 .49815 L p .619 .533 .735 r
F P
0 g
s
.50336 .41667 m .49328 .45936 L .53748 .46168 L p .709 .652 .791 r
F P
0 g
s
.53748 .46168 m .53408 .41832 L .50336 .41667 L p .709 .652 .791 r
F P
0 g
s
.53408 .41832 m .53748 .46168 L .58065 .45474 L p .678 .629 .793 r
F P
0 g
s
.61717 .58624 m .62415 .62863 L .6938 .60303 L p .589 .45 .66 r
F P
0 g
s
.6938 .60303 m .68168 .56188 L .61717 .58624 L p .589 .45 .66 r
F P
0 g
s
.4749 .40859 m .45216 .44798 L .49328 .45936 L p .737 .681 .796 r
F P
0 g
s
.49328 .45936 m .50336 .41667 L .4749 .40859 L p .737 .681 .796 r
F P
0 g
s
.40201 .57575 m .39239 .61761 L .46695 .63613 L p .777 .599 .657 r
F P
0 g
s
.46441 .67616 m .46695 .63613 L .39239 .61761 L p .782 .572 .616 r
F P
0 g
s
.46695 .63613 m .46441 .67616 L .54722 .67997 L p .718 .515 .615 r
F P
0 g
s
.38856 .46549 m .36353 .50476 L .41534 .53277 L p .805 .693 .742 r
F P
0 g
s
.41534 .53277 m .43216 .48978 L .38856 .46549 L p .805 .693 .742 r
F P
0 g
s
.40201 .57575 m .41534 .53277 L .36353 .50476 L p .822 .679 .705 r
F P
0 g
s
.58065 .45474 m .56403 .41339 L .53408 .41832 L p .678 .629 .793 r
F P
0 g
s
.56403 .41339 m .58065 .45474 L .61868 .43911 L p .645 .611 .801 r
F P
0 g
s
.64375 .47876 m .61868 .43911 L .58065 .45474 L p .632 .571 .768 r
F P
0 g
s
.41814 .42845 m .38856 .46549 L .43216 .48978 L p .786 .706 .776 r
F P
0 g
s
.43216 .48978 m .45216 .44798 L .41814 .42845 L p .786 .706 .776 r
F P
0 g
s
.62415 .62863 m .62834 .66854 L .7011 .64248 L p .57 .403 .616 r
F P
0 g
s
.7011 .64248 m .6938 .60303 L .62415 .62863 L p .57 .403 .616 r
F P
0 g
s
.36353 .50476 m .34362 .54511 L .40201 .57575 L p .822 .679 .705 r
F P
0 g
s
.39239 .61761 m .40201 .57575 L .34362 .54511 L p .836 .66 .664 r
F P
0 g
s
.5475 .71638 m .54722 .67997 L .46441 .67616 L p .713 .479 .569 r
F P
0 g
s
.54722 .67997 m .5475 .71638 L .62974 .70506 L p .638 .418 .568 r
F P
0 g
s
.62974 .70506 m .62834 .66854 L .54722 .67997 L p .638 .418 .568 r
F P
0 g
s
.45156 .3948 m .41814 .42845 L .45216 .44798 L p .762 .715 .808 r
F P
0 g
s
.45216 .44798 m .4749 .40859 L .45156 .3948 L p .762 .715 .808 r
F P
0 g
s
.51447 .37711 m .50336 .41667 L .53408 .41832 L p .699 .68 .828 r
F P
0 g
s
.53408 .41832 m .53032 .37798 L .51447 .37711 L p .699 .68 .828 r
F P
0 g
s
.53032 .37798 m .53408 .41832 L .56403 .41339 L p .679 .665 .829 r
F P
0 g
s
.39239 .61761 m .38662 .65732 L .46441 .67616 L p .782 .572 .616 r
F P
0 g
s
.46357 .71262 m .46441 .67616 L .38662 .65732 L p .784 .539 .566 r
F P
0 g
s
.46441 .67616 m .46357 .71262 L .5475 .71638 L p .713 .479 .569 r
F P
0 g
s
.49984 .37286 m .4749 .40859 L .50336 .41667 L p .718 .7 .832 r
F P
0 g
s
.50336 .41667 m .51447 .37711 L .49984 .37286 L p .718 .7 .832 r
F P
0 g
s
.61868 .43911 m .64375 .47876 L .68126 .45001 L p .583 .552 .786 r
F P
0 g
s
.64375 .47876 m .6649 .52007 L .70969 .48685 L p .557 .504 .751 r
F P
0 g
s
.70969 .48685 m .68126 .45001 L .64375 .47876 L p .557 .504 .751 r
F P
0 g
s
.6649 .52007 m .68168 .56188 L .73238 .52544 L p .529 .452 .713 r
F P
0 g
s
.73238 .52544 m .70969 .48685 L .6649 .52007 L p .529 .452 .713 r
F P
0 g
s
.56403 .41339 m .54576 .37538 L .53032 .37798 L p .679 .665 .829 r
F P
0 g
s
.54576 .37538 m .56403 .41339 L .59026 .40231 L p .656 .654 .836 r
F P
0 g
s
.61868 .43911 m .59026 .40231 L .56403 .41339 L p .645 .611 .801 r
F P
0 g
s
.59026 .40231 m .61868 .43911 L .64776 .41607 L p .608 .6 .817 r
F P
0 g
s
.68126 .45001 m .64776 .41607 L .61868 .43911 L p .583 .552 .786 r
F P
0 g
s
.34362 .54511 m .32922 .58539 L .39239 .61761 L p .836 .66 .664 r
F P
0 g
s
.38662 .65732 m .39239 .61761 L .32922 .58539 L p .849 .637 .616 r
F P
0 g
s
.48795 .36565 m .45156 .3948 L .4749 .40859 L p .734 .723 .841 r
F P
0 g
s
.4749 .40859 m .49984 .37286 L .48795 .36565 L p .734 .723 .841 r
F P
0 g
s
.62834 .66854 m .62974 .70506 L .70353 .67925 L p .546 .347 .562 r
F P
0 g
s
.70353 .67925 m .7011 .64248 L .62834 .66854 L p .546 .347 .562 r
F P
0 g
s
.68168 .56188 m .6938 .60303 L .74883 .56465 L p .497 .395 .669 r
F P
0 g
s
.74883 .56465 m .73238 .52544 L .68168 .56188 L p .497 .395 .669 r
F P
0 g
s
.39478 .40245 m .35816 .43292 L .38856 .46549 L p .816 .758 .798 r
F P
0 g
s
.38856 .46549 m .41814 .42845 L .39478 .40245 L p .816 .758 .798 r
F P
0 g
s
.36353 .50476 m .38856 .46549 L .35816 .43292 L p .847 .757 .764 r
F P
0 g
s
.59026 .40231 m .55919 .36957 L .54576 .37538 L p .656 .654 .836 r
F P
0 g
s
.55919 .36957 m .59026 .40231 L .61006 .3861 L p .633 .648 .847 r
F P
0 g
s
.64776 .41607 m .61006 .3861 L .59026 .40231 L p .608 .6 .817 r
F P
0 g
s
.54723 .74838 m .5475 .71638 L .46357 .71262 L p .705 .434 .512 r
F P
0 g
s
.5475 .71638 m .54723 .74838 L .62841 .73744 L p .622 .366 .509 r
F P
0 g
s
.62841 .73744 m .62974 .70506 L .5475 .71638 L p .622 .366 .509 r
F P
0 g
s
.43582 .37658 m .39478 .40245 L .41814 .42845 L p .783 .755 .828 r
F P
0 g
s
.41814 .42845 m .45156 .3948 L .43582 .37658 L p .783 .755 .828 r
F P
0 g
s
.35816 .43292 m .32695 .467 L .36353 .50476 L p .847 .757 .764 r
F P
0 g
s
.34362 .54511 m .36353 .50476 L .32695 .467 L p .874 .751 .723 r
F P
0 g
s
.38662 .65732 m .38468 .69396 L .46357 .71262 L p .784 .539 .566 r
F P
0 g
s
.46437 .74474 m .46357 .71262 L .38468 .69396 L p .782 .497 .504 r
F P
0 g
s
.46357 .71262 m .46437 .74474 L .54723 .74838 L p .705 .434 .512 r
F P
0 g
s
.32922 .58539 m .32054 .6245 L .38662 .65732 L p .849 .637 .616 r
F P
0 g
s
.38468 .69396 m .38662 .65732 L .32054 .6245 L p .858 .606 .556 r
F P
0 g
s
.6938 .60303 m .7011 .64248 L .75876 .60334 L p .459 .328 .615 r
F P
0 g
s
.75876 .60334 m .74883 .56465 L .6938 .60303 L p .459 .328 .615 r
F P
0 g
s
.4801 .35619 m .43582 .37658 L .45156 .3948 L p .744 .748 .855 r
F P
0 g
s
.45156 .3948 m .48795 .36565 L .4801 .35619 L p .744 .748 .855 r
F P
0 g
s
.53032 .37798 m .52632 .34202 L .51447 .37711 L closepath p .684 .711 .869 r
F P
0 g
s
.54576 .37538 m .52632 .34202 L .53032 .37798 L closepath p .676 .705 .869 r
F P
0 g
s
.51447 .37711 m .52632 .34202 L .49984 .37286 L closepath p .691 .718 .87 r
F P
0 g
s
.55919 .36957 m .52632 .34202 L .54576 .37538 L closepath p .667 .701 .872 r
F P
0 g
s
.49984 .37286 m .52632 .34202 L .48795 .36565 L closepath p .696 .727 .874 r
F P
0 g
s
.32695 .467 m .30197 .5036 L .34362 .54511 L p .874 .751 .723 r
F P
0 g
s
.32922 .58539 m .34362 .54511 L .30197 .5036 L p .9 .74 .674 r
F P
0 g
s
.61006 .3861 m .64776 .41607 L .66461 .38768 L p .569 .596 .841 r
F P
0 g
s
.64776 .41607 m .68126 .45001 L .70351 .41431 L p .525 .54 .813 r
F P
0 g
s
.70351 .41431 m .66461 .38768 L .64776 .41607 L p .525 .54 .813 r
F P
0 g
s
.62974 .70506 m .62841 .73744 L .70122 .71251 L p .515 .278 .494 r
F P
0 g
s
.70122 .71251 m .70353 .67925 L .62974 .70506 L p .515 .278 .494 r
F P
0 g
s
.68126 .45001 m .70969 .48685 L .7368 .4453 L p .477 .477 .779 r
F P
0 g
s
.7368 .4453 m .70351 .41431 L .68126 .45001 L p .477 .477 .779 r
F P
0 g
s
.56919 .36112 m .52632 .34202 L .55919 .36957 L closepath p .659 .7 .877 r
F P
0 g
s
.61006 .3861 m .56919 .36112 L .55919 .36957 L p .633 .648 .847 r
F P
0 g
s
.56919 .36112 m .61006 .3861 L .62123 .3663 L p .611 .65 .864 r
F P
0 g
s
.66461 .38768 m .62123 .3663 L .61006 .3861 L p .569 .596 .841 r
F P
0 g
s
.48795 .36565 m .52632 .34202 L .4801 .35619 L closepath p .699 .736 .88 r
F P
0 g
s
.70969 .48685 m .73238 .52544 L .76353 .47965 L p .422 .405 .736 r
F P
0 g
s
.76353 .47965 m .7368 .4453 L .70969 .48685 L p .422 .405 .736 r
F P
0 g
s
.7011 .64248 m .70353 .67925 L .76208 .64047 L p .411 .247 .546 r
F P
0 g
s
.76208 .64047 m .75876 .60334 L .7011 .64248 L p .411 .247 .546 r
F P
0 g
s
.57466 .3509 m .52632 .34202 L .56919 .36112 L closepath p .652 .702 .883 r
F P
0 g
s
.62123 .3663 m .57466 .3509 L .56919 .36112 L p .611 .65 .864 r
F P
0 g
s
.54643 .77538 m .54723 .74838 L .46437 .74474 L p .69 .375 .437 r
F P
0 g
s
.54723 .74838 m .54643 .77538 L .62448 .76505 L p .596 .297 .432 r
F P
0 g
s
.62448 .76505 m .62841 .73744 L .54723 .74838 L p .596 .297 .432 r
F P
0 g
s
.47717 .34548 m .42955 .35571 L .43582 .37658 L p .748 .774 .874 r
F P
0 g
s
.43582 .37658 m .4801 .35619 L .47717 .34548 L p .748 .774 .874 r
F P
0 g
s
.39478 .40245 m .43582 .37658 L .42955 .35571 L p .795 .799 .856 r
F P
0 g
s
.30197 .5036 m .28382 .54158 L .32922 .58539 L p .9 .74 .674 r
F P
0 g
s
.32054 .6245 m .32922 .58539 L .28382 .54158 L p .923 .721 .612 r
F P
0 g
s
.42955 .35571 m .38496 .37238 L .39478 .40245 L p .795 .799 .856 r
F P
0 g
s
.35816 .43292 m .39478 .40245 L .38496 .37238 L p .839 .82 .831 r
F P
0 g
s
.32054 .6245 m .31763 .66144 L .38468 .69396 L p .858 .606 .556 r
F P
0 g
s
.38652 .72671 m .38468 .69396 L .31763 .66144 L p .862 .562 .479 r
F P
0 g
s
.38468 .69396 m .38652 .72671 L .46437 .74474 L p .782 .497 .504 r
F P
0 g
s
.4801 .35619 m .52632 .34202 L .47717 .34548 L closepath p .699 .744 .887 r
F P
0 g
s
.46675 .77195 m .46437 .74474 L .38652 .72671 L p .773 .439 .421 r
F P
0 g
s
.46437 .74474 m .46675 .77195 L .54643 .77538 L p .69 .375 .437 r
F P
0 g
s
.38496 .37238 m .34478 .39495 L .35816 .43292 L p .839 .82 .831 r
F P
0 g
s
.32695 .467 m .35816 .43292 L .34478 .39495 L p .882 .836 .796 r
F P
0 g
s
.73238 .52544 m .74883 .56465 L .78302 .51622 L p .356 .319 .68 r
F P
0 g
s
.78302 .51622 m .76353 .47965 L .73238 .52544 L p .356 .319 .68 r
F P
0 g
s
.57493 .33997 m .52632 .34202 L .57466 .3509 L closepath p .646 .706 .89 r
F P
0 g
s
.57466 .3509 m .62123 .3663 L .6223 .3449 L p .59 .658 .885 r
F P
0 g
s
.6223 .3449 m .57493 .33997 L .57466 .3509 L p .59 .658 .885 r
F P
0 g
s
.62123 .3663 m .66461 .38768 L .6669 .35669 L p .527 .603 .872 r
F P
0 g
s
.6669 .35669 m .6223 .3449 L .62123 .3663 L p .527 .603 .872 r
F P
0 g
s
.56002 .32071 m .52632 .34202 L .56989 .32952 L closepath p .643 .722 .905 r
F P
0 g
s
.54636 .31456 m .52632 .34202 L .56002 .32071 L closepath p .646 .731 .911 r
F P
0 g
s
.53043 .31179 m .52632 .34202 L .54636 .31456 L closepath p .653 .741 .914 r
F P
0 g
s
.51402 .31273 m .52632 .34202 L .53043 .31179 L closepath p .662 .749 .915 r
F P
0 g
s
.49902 .31727 m .52632 .34202 L .51402 .31273 L closepath p .672 .755 .913 r
F P
0 g
s
.4871 .32486 m .52632 .34202 L .49902 .31727 L closepath p .682 .757 .908 r
F P
0 g
s
.47956 .33464 m .52632 .34202 L .4871 .32486 L closepath p .69 .756 .902 r
F P
0 g
s
.47717 .34548 m .52632 .34202 L .47956 .33464 L closepath p .696 .751 .894 r
F P
0 g
s
.56989 .32952 m .52632 .34202 L .57493 .33997 L closepath p .643 .713 .898 r
F P
0 g
s
.62841 .73744 m .62448 .76505 L .69438 .74153 L p .47 .188 .402 r
F P
0 g
s
.69438 .74153 m .70122 .71251 L .62841 .73744 L p .47 .188 .402 r
F P
0 g
s
.42955 .35571 m .47717 .34548 L .47956 .33464 L p .743 .798 .896 r
F P
0 g
s
.66461 .38768 m .70351 .41431 L .70729 .37499 L p .454 .536 .851 r
F P
0 g
s
.70729 .37499 m .6669 .35669 L .66461 .38768 L p .454 .536 .851 r
F P
0 g
s
.34478 .39495 m .31025 .42265 L .32695 .467 L p .882 .836 .796 r
F P
0 g
s
.30197 .5036 m .32695 .467 L .31025 .42265 L p .924 .847 .749 r
F P
0 g
s
.28382 .54158 m .27284 .57979 L .32054 .6245 L p .923 .721 .612 r
F P
0 g
s
.31763 .66144 m .32054 .6245 L .27284 .57979 L p .941 .689 .529 r
F P
0 g
s
.57493 .33997 m .6223 .3449 L .61281 .32421 L p .574 .675 .908 r
F P
0 g
s
.61281 .32421 m .56989 .32952 L .57493 .33997 L p .574 .675 .908 r
F P
0 g
s
.70353 .67925 m .70122 .71251 L .75893 .67505 L p .348 .143 .454 r
F P
0 g
s
.75893 .67505 m .76208 .64047 L .70353 .67925 L p .348 .143 .454 r
F P
0 g
s
.47956 .33464 m .43375 .33436 L .42955 .35571 L p .743 .798 .896 r
F P
0 g
s
.38496 .37238 m .42955 .35571 L .43375 .33436 L p .792 .844 .891 r
F P
0 g
s
.74883 .56465 m .75876 .60334 L .79481 .55386 L p .274 .212 .604 r
F P
0 g
s
.79481 .55386 m .78302 .51622 L .74883 .56465 L p .274 .212 .604 r
F P
0 g
s
.43375 .33436 m .47956 .33464 L .4871 .32486 L p .727 .816 .92 r
F P
0 g
s
.31763 .66144 m .32039 .6953 L .38652 .72671 L p .862 .562 .479 r
F P
0 g
s
.39194 .75493 m .38652 .72671 L .32039 .6953 L p .856 .498 .372 r
F P
0 g
s
.38652 .72671 m .39194 .75493 L .46675 .77195 L p .773 .439 .421 r
F P
0 g
s
.70351 .41431 m .7368 .4453 L .74216 .3992 L p .364 .451 .817 r
F P
0 g
s
.74216 .3992 m .70729 .37499 L .70351 .41431 L p .364 .451 .817 r
F P
0 g
s
.54514 .79694 m .54643 .77538 L .46675 .77195 L p .662 .292 .333 r
F P
0 g
s
.54643 .77538 m .54514 .79694 L .61813 .78742 L p .556 .202 .324 r
F P
0 g
s
.61813 .78742 m .62448 .76505 L .54643 .77538 L p .556 .202 .324 r
F P
0 g
s
.56989 .32952 m .61281 .32421 L .59352 .3066 L p .566 .7 .931 r
F P
0 g
s
.59352 .3066 m .56002 .32071 L .56989 .32952 L p .566 .7 .931 r
F P
0 g
s
.6223 .3449 m .6669 .35669 L .65365 .32642 L p .486 .622 .91 r
F P
0 g
s
.65365 .32642 m .61281 .32421 L .6223 .3449 L p .486 .622 .91 r
F P
0 g
s
.43375 .33436 m .39039 .34131 L .38496 .37238 L p .792 .844 .891 r
F P
0 g
s
.34478 .39495 m .38496 .37238 L .39039 .34131 L p .842 .889 .874 r
F P
0 g
s
.31025 .42265 m .28242 .45456 L .30197 .5036 L p .924 .847 .749 r
F P
0 g
s
.28382 .54158 m .30197 .5036 L .28242 .45456 L p .962 .847 .682 r
F P
0 g
s
.47059 .79377 m .46675 .77195 L .39194 .75493 L p .751 .356 .304 r
F P
0 g
s
.46675 .77195 m .47059 .79377 L .54514 .79694 L p .662 .292 .333 r
F P
0 g
s
.44829 .31492 m .4871 .32486 L .49902 .31727 L p .698 .823 .942 r
F P
0 g
s
.4871 .32486 m .44829 .31492 L .43375 .33436 L p .727 .816 .92 r
F P
0 g
s
.56002 .32071 m .59352 .3066 L .56641 .29421 L p .57 .732 .951 r
F P
0 g
s
.56641 .29421 m .54636 .31456 L .56002 .32071 L p .57 .732 .951 r
F P
0 g
s
.7368 .4453 m .76353 .47965 L .77036 .42851 L p .25 .341 .762 r
F P
0 g
s
.77036 .42851 m .74216 .3992 L .7368 .4453 L p .25 .341 .762 r
F P
0 g
s
.27284 .57979 m .26917 .61711 L .31763 .66144 L p .941 .689 .529 r
F P
0 g
s
.32039 .6953 m .31763 .66144 L .26917 .61711 L p .947 .635 .412 r
F P
0 g
s
.62448 .76505 m .61813 .78742 L .68334 .76577 L p .402 .062 .271 r
F P
0 g
s
.68334 .76577 m .69438 .74153 L .62448 .76505 L p .402 .062 .271 r
F P
0 g
s
.47179 .29967 m .49902 .31727 L .51402 .31273 L p .661 .816 .958 r
F P
0 g
s
.49902 .31727 m .47179 .29967 L .44829 .31492 L p .698 .823 .942 r
F P
0 g
s
.39039 .34131 m .43375 .33436 L .44829 .31492 L p .765 .881 .93 r
F P
0 g
s
.75876 .60334 m .76208 .64047 L .79877 .59139 L p .165 .072 .495 r
F P
0 g
s
.79877 .59139 m .79481 .55386 L .75876 .60334 L p .165 .072 .495 r
F P
0 g
s
.70122 .71251 m .69438 .74153 L .74962 .70625 L p .259 .003 .323 r
F P
0 g
s
.74962 .70625 m .75893 .67505 L .70122 .71251 L p .259 .003 .323 r
F P
0 g
s
.54636 .31456 m .56641 .29421 L .53455 .2886 L p .589 .765 .963 r
F P
0 g
s
.53455 .2886 m .53043 .31179 L .54636 .31456 L p .589 .765 .963 r
F P
0 g
s
.50171 .29051 m .51402 .31273 L .53043 .31179 L p .621 .796 .966 r
F P
0 g
s
.51402 .31273 m .50171 .29051 L .47179 .29967 L p .661 .816 .958 r
F P
0 g
s
.39039 .34131 m .35092 .35534 L .34478 .39495 L p .842 .889 .874 r
F P
0 g
s
.31025 .42265 m .34478 .39495 L .35092 .35534 L p .891 .93 .838 r
F P
0 g
s
.53043 .31179 m .53455 .2886 L .50171 .29051 L p .621 .796 .966 r
F P
0 g
s
.6669 .35669 m .70729 .37499 L .691 .33622 L p .366 .544 .897 r
F P
0 g
s
.691 .33622 m .65365 .32642 L .6669 .35669 L p .366 .544 .897 r
F P
0 g
s
.28242 .45456 m .26208 .48961 L .28382 .54158 L p .962 .847 .682 r
F P
0 g
s
.27284 .57979 m .28382 .54158 L .26208 .48961 L p .992 .83 .581 r
F P
0 g
s
.61281 .32421 m .65365 .32642 L .62568 .30042 L p .451 .657 .949 r
F P
0 g
s
.62568 .30042 m .59352 .3066 L .61281 .32421 L p .451 .657 .949 r
F P
0 g
s
.32039 .6953 m .32853 .72531 L .39194 .75493 L p .856 .498 .372 r
F P
0 g
s
.40069 .7781 m .39194 .75493 L .32853 .72531 L p .827 .397 .217 r
F P
0 g
s
.39194 .75493 m .40069 .7781 L .47059 .79377 L p .751 .356 .304 r
F P
0 g
s
.76353 .47965 m .78302 .51622 L .79104 .4619 L p .1 .191 .673 r
F P
0 g
s
.79104 .4619 m .77036 .42851 L .76353 .47965 L p .1 .191 .673 r
F P
0 g
s
.54339 .81277 m .54514 .79694 L .47059 .79377 L p .608 .167 .176 r
F P
0 g
s
.54514 .79694 m .54339 .81277 L .60957 .80423 L p .484 .061 .161 r
F P
0 g
s
.60957 .80423 m .61813 .78742 L .54514 .79694 L p .484 .061 .161 r
F P
0 g
s
.41119 .31272 m .44829 .31492 L .47179 .29967 L p .705 .897 .966 r
F P
0 g
s
.44829 .31492 m .41119 .31272 L .39039 .34131 L p .765 .881 .93 r
F P
0 g
s
.35092 .35534 m .39039 .34131 L .41119 .31272 L p .799 .948 .919 r
F P
0 g
s
.47576 .80992 m .47059 .79377 L .40069 .7781 L p .697 .225 .128 r
F P
0 g
s
.47059 .79377 m .47576 .80992 L .54339 .81277 L p .608 .167 .176 r
F P
0 g
s
.35092 .35534 m .31671 .37602 L .31025 .42265 L p .891 .93 .838 r
F P
0 g
s
.28242 .45456 m .31025 .42265 L .31671 .37602 L p .933 .958 .767 r
F P
0 g
s
.26917 .61711 m .27265 .6525 L .32039 .6953 L p .947 .635 .412 r
F P
0 g
s
.32853 .72531 m .32039 .6953 L .27265 .6525 L p .925 .541 .242 r
F P
0 g
s
.76208 .64047 m .75893 .67505 L .79502 .62769 L p .019 0 .337 r
F P
0 g
s
.79502 .62769 m .79877 .59139 L .76208 .64047 L p .019 0 .337 r
F P
0 g
s
.70729 .37499 m .74216 .3992 L .72351 .35338 L p .195 .423 .854 r
F P
0 g
s
.72351 .35338 m .691 .33622 L .70729 .37499 L p .195 .423 .854 r
F P
0 g
s
.59352 .3066 m .62568 .30042 L .58578 .28198 L p .437 .707 .98 r
F P
0 g
s
.58578 .28198 m .56641 .29421 L .59352 .3066 L p .437 .707 .98 r
F P
0 g
s
.26208 .48961 m .24974 .52661 L .27284 .57979 L p .992 .83 .581 r
F P
0 g
s
.26917 .61711 m .27284 .57979 L .24974 .52661 L p .997 .777 .429 r
F P
0 g
s
.69438 .74153 m .68334 .76577 L .73462 .7334 L p .127 0 .13 r
F P
0 g
s
.73462 .7334 m .74962 .70625 L .69438 .74153 L p .127 0 .13 r
F P
0 g
s
.61813 .78742 m .60957 .80423 L .6685 .78485 L p .29 0 .071 r
F P
0 g
s
.6685 .78485 m .68334 .76577 L .61813 .78742 L p .29 0 .071 r
F P
0 g
s
.44556 .29011 m .47179 .29967 L .50171 .29051 L p .617 .88 .99 r
F P
0 g
s
.47179 .29967 m .44556 .29011 L .41119 .31272 L p .705 .897 .966 r
F P
0 g
s
.65365 .32642 m .691 .33622 L .65534 .30263 L p .265 .567 .936 r
F P
0 g
s
.65534 .30263 m .62568 .30042 L .65365 .32642 L p .265 .567 .936 r
F P
0 g
s
.78302 .51622 m .79481 .55386 L .8036 .4982 L p 0 0 .526 r
F P
0 g
s
.8036 .4982 m .79104 .4619 L .78302 .51622 L p 0 0 .526 r
F P
0 g
s
.56641 .29421 m .58578 .28198 L .53855 .2736 L p .459 .769 .996 r
F P
0 g
s
.53855 .2736 m .53455 .2886 L .56641 .29421 L p .459 .769 .996 r
F P
0 g
s
.32853 .72531 m .34165 .75088 L .40069 .7781 L p .827 .397 .217 r
F P
0 g
s
.41247 .79588 m .40069 .7781 L .34165 .75088 L p .745 .232 0 r
F P
0 g
s
.40069 .7781 m .41247 .79588 L .47576 .80992 L p .697 .225 .128 r
F P
0 g
s
.31671 .37602 m .28893 .40268 L .28242 .45456 L p .933 .958 .767 r
F P
0 g
s
.26208 .48961 m .28242 .45456 L .28893 .40268 L p .946 .949 .634 r
F P
0 g
s
.48979 .27645 m .50171 .29051 L .53455 .2886 L p .525 .832 1 r
F P
0 g
s
.50171 .29051 m .48979 .27645 L .44556 .29011 L p .617 .88 .99 r
F P
0 g
s
.41119 .31272 m .37711 .31856 L .35092 .35534 L p .799 .948 .919 r
F P
0 g
s
.31671 .37602 m .35092 .35534 L .37711 .31856 L p .81 .996 .857 r
F P
0 g
s
.53455 .2886 m .53855 .2736 L .48979 .27645 L p .525 .832 1 r
F P
0 g
s
.74216 .3992 m .77036 .42851 L .75 .37736 L p 0 .231 .748 r
F P
0 g
s
.75 .37736 m .72351 .35338 L .74216 .3992 L p 0 .231 .748 r
F P
0 g
s
.75893 .67505 m .74962 .70625 L .78395 .66174 L p 0 0 .104 r
F P
0 g
s
.78395 .66174 m .79502 .62769 L .75893 .67505 L p 0 0 .104 r
F P
0 g
s
.37711 .31856 m .41119 .31272 L .44556 .29011 L p .676 .958 .945 r
F P
0 g
s
.27265 .6525 m .28295 .68505 L .32853 .72531 L p .925 .541 .242 r
F P
0 g
s
.34165 .75088 m .32853 .72531 L .28295 .68505 L p .841 .379 0 r
F P
0 g
s
.54125 .82272 m .54339 .81277 L .47576 .80992 L p .495 0 0 r
F P
0 g
s
.54339 .81277 m .54125 .82272 L .59906 .81531 L p .35 0 0 r
F P
0 g
s
.59906 .81531 m .60957 .80423 L .54339 .81277 L p .35 0 0 r
F P
0 g
s
.24974 .52661 m .2456 .56434 L .26917 .61711 L p .997 .777 .429 r
F P
0 g
s
.27265 .6525 m .26917 .61711 L .2456 .56434 L p .944 .659 .2 r
F P
0 g
s
.48212 .82025 m .47576 .80992 L .41247 .79588 L p .572 .015 0 r
F P
0 g
s
.47576 .80992 m .48212 .82025 L .54125 .82272 L p .495 0 0 r
F P
0 g
s
.68334 .76577 m .6685 .78485 L .71456 .75597 L p 0 0 0 r
F P
0 g
s
.71456 .75597 m .73462 .7334 L .68334 .76577 L p 0 0 0 r
F P
0 g
s
.79481 .55386 m .79877 .59139 L .80782 .53613 L p 0 0 .295 r
F P
0 g
s
.80782 .53613 m .8036 .4982 L .79481 .55386 L p 0 0 .295 r
F P
0 g
s
.62568 .30042 m .65534 .30263 L .60375 .27865 L p .182 .606 .942 r
F P
0 g
s
.60375 .27865 m .58578 .28198 L .62568 .30042 L p .182 .606 .942 r
F P
0 g
s
.60957 .80423 m .59906 .81531 L .65034 .79854 L p .104 0 0 r
F P
0 g
s
.65034 .79854 m .6685 .78485 L .60957 .80423 L p .104 0 0 r
F P
0 g
s
.691 .33622 m .72351 .35338 L .68135 .31338 L p 0 .38 .835 r
F P
0 g
s
.68135 .31338 m .65534 .30263 L .691 .33622 L p 0 .38 .835 r
F P
0 g
s
.28893 .40268 m .26851 .43436 L .26208 .48961 L p .946 .949 .634 r
F P
0 g
s
.24974 .52661 m .26208 .48961 L .26851 .43436 L p .884 .855 .402 r
F P
0 g
s
.77036 .42851 m .79104 .4619 L .76953 .4073 L p 0 0 .529 r
F P
0 g
s
.76953 .4073 m .75 .37736 L .77036 .42851 L p 0 0 .529 r
F P
0 g
s
.37711 .31856 m .34733 .33239 L .31671 .37602 L p .81 .996 .857 r
F P
0 g
s
.28893 .40268 m .31671 .37602 L .34733 .33239 L p .745 .964 .681 r
F P
0 g
s
.4213 .28925 m .44556 .29011 L .48979 .27645 L p .477 .888 .932 r
F P
0 g
s
.44556 .29011 m .4213 .28925 L .37711 .31856 L p .676 .958 .945 r
F P
0 g
s
.34165 .75088 m .35926 .77155 L .41247 .79588 L p .745 .232 0 r
F P
0 g
s
.42691 .80807 m .41247 .79588 L .35926 .77155 L p .555 0 0 r
F P
0 g
s
.41247 .79588 m .42691 .80807 L .48212 .82025 L p .572 .015 0 r
F P
0 g
s
.74962 .70625 m .73462 .7334 L .76619 .69268 L p 0 0 0 r
F P
0 g
s
.76619 .69268 m .78395 .66174 L .74962 .70625 L p 0 0 0 r
F P
0 g
s
.2456 .56434 m .24953 .6016 L .27265 .6525 L p .944 .659 .2 r
F P
0 g
s
.28295 .68505 m .27265 .6525 L .24953 .6016 L p .786 .445 0 r
F P
0 g
s
.28295 .68505 m .2995 .71398 L .34165 .75088 L p .841 .379 0 r
F P
0 g
s
.35926 .77155 m .34165 .75088 L .2995 .71398 L p .645 .129 0 r
F P
0 g
s
.58578 .28198 m .60375 .27865 L .54226 .26771 L p .175 .669 .918 r
F P
0 g
s
.54226 .26771 m .53855 .2736 L .58578 .28198 L p .175 .669 .918 r
F P
0 g
s
.79877 .59139 m .79502 .62769 L .80382 .57441 L p 0 0 0 r
F P
0 g
s
.80382 .57441 m .80782 .53613 L .79877 .59139 L p 0 0 0 r
F P
0 g
s
.34733 .33239 m .37711 .31856 L .4213 .28925 L p .537 .917 .777 r
F P
0 g
s
.53876 .82676 m .54125 .82272 L .48212 .82025 L p .266 0 0 r
F P
0 g
s
.54125 .82272 m .53876 .82676 L .58686 .82061 L p .109 0 0 r
F P
0 g
s
.58686 .82061 m .59906 .81531 L .54125 .82272 L p .109 0 0 r
F P
0 g
s
.47871 .27143 m .48979 .27645 L .53855 .2736 L p .282 .77 .909 r
F P
0 g
s
.48979 .27645 m .47871 .27143 L .4213 .28925 L p .477 .888 .932 r
F P
0 g
s
.6685 .78485 m .65034 .79854 L .6901 .77364 L p 0 0 0 r
F P
0 g
s
.6901 .77364 m .71456 .75597 L .6685 .78485 L p 0 0 0 r
F P
0 g
s
.48951 .82471 m .48212 .82025 L .42691 .80807 L p .316 0 0 r
F P
0 g
s
.48212 .82025 m .48951 .82471 L .53876 .82676 L p .266 0 0 r
F P
0 g
s
.53855 .2736 m .54226 .26771 L .47871 .27143 L p .282 .77 .909 r
F P
0 g
s
.26851 .43436 m .25608 .46992 L .24974 .52661 L p .884 .855 .402 r
F P
0 g
s
.2456 .56434 m .24974 .52661 L .25608 .46992 L p 0 0 0 r
F P
0 g
s
.72351 .35338 m .75 .37736 L .70268 .33243 L p 0 .056 .549 r
F P
0 g
s
.70268 .33243 m .68135 .31338 L .72351 .35338 L p 0 .056 .549 r
F P
0 g
s
.59906 .81531 m .58686 .82061 L .62935 .80673 L p 0 0 0 r
F P
0 g
s
.62935 .80673 m .65034 .79854 L .59906 .81531 L p 0 0 0 r
F P
0 g
s
.79104 .4619 m .8036 .4982 L .78145 .44209 L p .714 .386 0 r
F P
0 g
s
.78145 .44209 m .76953 .4073 L .79104 .4619 L p .714 .386 0 r
F P
0 g
s
.65534 .30263 m .68135 .31338 L .61959 .28466 L p 0 .329 .694 r
F P
0 g
s
.61959 .28466 m .60375 .27865 L .65534 .30263 L p 0 .329 .694 r
F P
0 g
s
.34733 .33239 m .32297 .35381 L .28893 .40268 L p .745 .964 .681 r
F P
0 g
s
.26851 .43436 m .28893 .40268 L .32297 .35381 L p 0 0 0 r
F P
0 g
s
.73462 .7334 m .71456 .75597 L .74252 .71982 L p .614 .869 .525 r
F P
0 g
s
.74252 .71982 m .76619 .69268 L .73462 .7334 L p .614 .869 .525 r
F P
0 g
s
.24953 .6016 m .26111 .63727 L .28295 .68505 L p .786 .445 0 r
F P
0 g
s
.2995 .71398 m .28295 .68505 L .26111 .63727 L p 0 0 .425 r
F P
0 g
s
.35926 .77155 m .38076 .78705 L .42691 .80807 L p .555 0 0 r
F P
0 g
s
.42691 .80807 m .44365 .81461 L .48951 .82471 L p .316 0 0 r
F P
0 g
s
.44365 .81461 m .42691 .80807 L .38076 .78705 L p 0 .335 .695 r
F P
0 g
s
.2995 .71398 m .3216 .73871 L .35926 .77155 L p .645 .129 0 r
F P
0 g
s
.38076 .78705 m .35926 .77155 L .3216 .73871 L p 0 .17 .645 r
F P
0 g
s
.79502 .62769 m .78395 .66174 L .79203 .6118 L p .829 .821 .341 r
F P
0 g
s
.79203 .6118 m .80382 .57441 L .79502 .62769 L p .829 .821 .341 r
F P
0 g
s
.4213 .28925 m .39995 .29737 L .34733 .33239 L p .537 .917 .777 r
F P
0 g
s
.39995 .29737 m .4213 .28925 L .47871 .27143 L p 0 0 0 r
F P
0 g
s
.25608 .46992 m .25189 .50804 L .2456 .56434 L p 0 0 0 r
F P
0 g
s
.24953 .6016 m .2456 .56434 L .25189 .50804 L p 0 0 .255 r
F P
0 g
s
.32297 .35381 m .34733 .33239 L .39995 .29737 L p 0 0 0 r
F P
0 g
s
.65034 .79854 m .62935 .80673 L .66198 .78622 L p .507 .905 .785 r
F P
0 g
s
.66198 .78622 m .6901 .77364 L .65034 .79854 L p .507 .905 .785 r
F P
0 g
s
.53597 .82494 m .53876 .82676 L .48951 .82471 L p .073 .631 .8 r
F P
0 g
s
.53876 .82676 m .53597 .82494 L .57324 .82017 L p .206 .732 .816 r
F P
0 g
s
.57324 .82017 m .58686 .82061 L .53876 .82676 L p .206 .732 .816 r
F P
0 g
s
.8036 .4982 m .80782 .53613 L .78546 .48037 L p .923 .643 .158 r
F P
0 g
s
.78546 .48037 m .78145 .44209 L .8036 .4982 L p .923 .643 .158 r
F P
0 g
s
.60375 .27865 m .61959 .28466 L .54555 .2715 L p .27 0 0 r
F P
0 g
s
.54555 .2715 m .54226 .26771 L .60375 .27865 L p .27 0 0 r
F P
0 g
s
.49777 .82335 m .48951 .82471 L .44365 .81461 L p .04 .583 .844 r
F P
0 g
s
.48951 .82471 m .49777 .82335 L .53597 .82494 L p .073 .631 .8 r
F P
0 g
s
.26111 .63727 m .27965 .67037 L .2995 .71398 L p 0 0 .425 r
F P
0 g
s
.3216 .73871 m .2995 .71398 L .27965 .67037 L p 0 .119 .669 r
F P
0 g
s
.75 .37736 m .76953 .4073 L .71848 .35914 L p .776 .291 0 r
F P
0 g
s
.71848 .35914 m .70268 .33243 L .75 .37736 L p .776 .291 0 r
F P
0 g
s
.71456 .75597 m .6901 .77364 L .71384 .74266 L p .729 .98 .758 r
F P
0 g
s
.71384 .74266 m .74252 .71982 L .71456 .75597 L p .729 .98 .758 r
F P
0 g
s
.32297 .35381 m .30498 .38209 L .26851 .43436 L p 0 0 0 r
F P
0 g
s
.25608 .46992 m .26851 .43436 L .30498 .38209 L p 0 0 .033 r
F P
0 g
s
.58686 .82061 m .57324 .82017 L .60599 .80943 L p .41 .86 .879 r
F P
0 g
s
.60599 .80943 m .62935 .80673 L .58686 .82061 L p .41 .86 .879 r
F P
0 g
s
.46893 .27597 m .47871 .27143 L .54226 .26771 L p .134 0 0 r
F P
0 g
s
.47871 .27143 m .46893 .27597 L .39995 .29737 L p 0 0 0 r
F P
0 g
s
.78395 .66174 m .76619 .69268 L .77317 .64719 L p .915 .942 .586 r
F P
0 g
s
.77317 .64719 m .79203 .6118 L .78395 .66174 L p .915 .942 .586 r
F P
0 g
s
.54226 .26771 m .54555 .2715 L .46893 .27597 L p .134 0 0 r
F P
0 g
s
.3216 .73871 m .34846 .75882 L .38076 .78705 L p 0 .17 .645 r
F P
0 g
s
.40557 .79726 m .38076 .78705 L .34846 .75882 L p 0 .419 .851 r
F P
0 g
s
.38076 .78705 m .40557 .79726 L .44365 .81461 L p 0 .335 .695 r
F P
0 g
s
.68135 .31338 m .70268 .33243 L .63264 .30001 L p .623 .056 0 r
F P
0 g
s
.63264 .30001 m .61959 .28466 L .68135 .31338 L p .623 .056 0 r
F P
0 g
s
.46231 .81552 m .44365 .81461 L .40557 .79726 L p .104 .575 .911 r
F P
0 g
s
.44365 .81461 m .46231 .81552 L .49777 .82335 L p .04 .583 .844 r
F P
0 g
s
.25189 .50804 m .25586 .54734 L .24953 .6016 L p 0 0 .255 r
F P
0 g
s
.26111 .63727 m .24953 .6016 L .25586 .54734 L p 0 0 .502 r
F P
0 g
s
.80782 .53613 m .80382 .57441 L .78165 .5207 L p .994 .781 .414 r
F P
0 g
s
.78165 .5207 m .78546 .48037 L .80782 .53613 L p .994 .781 .414 r
F P
0 g
s
.62935 .80673 m .60599 .80943 L .63089 .79365 L p .616 .948 .934 r
F P
0 g
s
.63089 .79365 m .66198 .78622 L .62935 .80673 L p .616 .948 .934 r
F P
0 g
s
.27965 .67037 m .3043 .70009 L .3216 .73871 L p 0 .119 .669 r
F P
0 g
s
.34846 .75882 m .3216 .73871 L .3043 .70009 L p .026 .331 .814 r
F P
0 g
s
.39995 .29737 m .38241 .31437 L .32297 .35381 L p 0 0 0 r
F P
0 g
s
.30498 .38209 m .32297 .35381 L .38241 .31437 L p .057 0 .021 r
F P
0 g
s
.6901 .77364 m .66198 .78622 L .68108 .76087 L p .762 .991 .884 r
F P
0 g
s
.68108 .76087 m .71384 .74266 L .6901 .77364 L p .762 .991 .884 r
F P
0 g
s
.38241 .31437 m .39995 .29737 L .46893 .27597 L p .194 0 0 r
F P
0 g
s
.76619 .69268 m .74252 .71982 L .74818 .67965 L p .922 .976 .738 r
F P
0 g
s
.74818 .67965 m .77317 .64719 L .76619 .69268 L p .922 .976 .738 r
F P
0 g
s
.30498 .38209 m .29398 .41612 L .25608 .46992 L p 0 0 .033 r
F P
0 g
s
.25189 .50804 m .25608 .46992 L .29398 .41612 L p 0 0 .314 r
F P
0 g
s
.53293 .81737 m .53597 .82494 L .49777 .82335 L p .363 .783 .976 r
F P
0 g
s
.53597 .82494 m .53293 .81737 L .55845 .81408 L p .443 .84 .978 r
F P
0 g
s
.55845 .81408 m .57324 .82017 L .53597 .82494 L p .443 .84 .978 r
F P
0 g
s
.76953 .4073 m .78145 .44209 L .72815 .39245 L p .914 .513 .192 r
F P
0 g
s
.72815 .39245 m .71848 .35914 L .76953 .4073 L p .914 .513 .192 r
F P
0 g
s
.50676 .81627 m .49777 .82335 L .46231 .81552 L p .332 .735 .981 r
F P
0 g
s
.49777 .82335 m .50676 .81627 L .53293 .81737 L p .363 .783 .976 r
F P
0 g
s
.25586 .54734 m .26753 .58648 L .26111 .63727 L p 0 0 .502 r
F P
0 g
s
.27965 .67037 m .26111 .63727 L .26753 .58648 L p .034 .154 .659 r
F P
0 g
s
.34846 .75882 m .37926 .77407 L .40557 .79726 L p 0 .419 .851 r
F P
0 g
s
.43308 .80213 m .40557 .79726 L .37926 .77407 L p .226 .579 .943 r
F P
0 g
s
.40557 .79726 m .43308 .80213 L .46231 .81552 L p .104 .575 .911 r
F P
0 g
s
.57324 .82017 m .55845 .81408 L .58075 .80671 L p .551 .891 .984 r
F P
0 g
s
.58075 .80671 m .60599 .80943 L .57324 .82017 L p .551 .891 .984 r
F P
0 g
s
.61959 .28466 m .63264 .30001 L .54826 .28512 L p .578 .042 0 r
F P
0 g
s
.54826 .28512 m .54555 .2715 L .61959 .28466 L p .578 .042 0 r
F P
0 g
s
.48253 .81089 m .46231 .81552 L .43308 .80213 L p .349 .698 .983 r
F P
0 g
s
.46231 .81552 m .48253 .81089 L .50676 .81627 L p .332 .735 .981 r
F P
0 g
s
.80382 .57441 m .79203 .6118 L .77047 .56159 L p .995 .841 .578 r
F P
0 g
s
.77047 .56159 m .78165 .5207 L .80382 .57441 L p .995 .841 .578 r
F P
0 g
s
.3043 .70009 m .33408 .72583 L .34846 .75882 L p .026 .331 .814 r
F P
0 g
s
.37926 .77407 m .34846 .75882 L .33408 .72583 L p .213 .478 .89 r
F P
0 g
s
.70268 .33243 m .71848 .35914 L .64234 .32425 L p .79 .323 .126 r
F P
0 g
s
.64234 .32425 m .63264 .30001 L .70268 .33243 L p .79 .323 .126 r
F P
0 g
s
.46086 .29019 m .46893 .27597 L .54555 .2715 L p .439 0 0 r
F P
0 g
s
.46893 .27597 m .46086 .29019 L .38241 .31437 L p .194 0 0 r
F P
0 g
s
.74252 .71982 m .71384 .74266 L .71808 .70846 L p .893 .967 .828 r
F P
0 g
s
.71808 .70846 m .74818 .67965 L .74252 .71982 L p .893 .967 .828 r
F P
0 g
s
.66198 .78622 m .63089 .79365 L .64515 .77429 L p .751 .956 .94 r
F P
0 g
s
.64515 .77429 m .68108 .76087 L .66198 .78622 L p .751 .956 .94 r
F P
0 g
s
.60599 .80943 m .58075 .80671 L .59751 .79595 L p .652 .914 .979 r
F P
0 g
s
.59751 .79595 m .63089 .79365 L .60599 .80943 L p .652 .914 .979 r
F P
0 g
s
.54555 .2715 m .54826 .28512 L .46086 .29019 L p .439 0 0 r
F P
0 g
s
.29398 .41612 m .29027 .45455 L .25189 .50804 L p 0 0 .314 r
F P
0 g
s
.25586 .54734 m .25189 .50804 L .29027 .45455 L p .151 .063 .493 r
F P
0 g
s
.26753 .58648 m .28616 .6242 L .27965 .67037 L p .034 .154 .659 r
F P
0 g
s
.3043 .70009 m .27965 .67037 L .28616 .6242 L p .184 .308 .757 r
F P
0 g
s
.38241 .31437 m .36938 .33972 L .30498 .38209 L p .057 0 .021 r
F P
0 g
s
.29398 .41612 m .30498 .38209 L .36938 .33972 L p .245 0 .287 r
F P
0 g
s
.78145 .44209 m .78546 .48037 L .73141 .43101 L p .946 .629 .401 r
F P
0 g
s
.73141 .43101 m .72815 .39245 L .78145 .44209 L p .946 .629 .401 r
F P
0 g
s
.37926 .77407 m .41317 .78435 L .43308 .80213 L p .226 .579 .943 r
F P
0 g
s
.46272 .80173 m .43308 .80213 L .41317 .78435 L p .396 .672 .971 r
F P
0 g
s
.43308 .80213 m .46272 .80173 L .48253 .81089 L p .349 .698 .983 r
F P
0 g
s
.5297 .80415 m .53293 .81737 L .50676 .81627 L p .526 .807 .997 r
F P
0 g
s
.53293 .81737 m .5297 .80415 L .54273 .80246 L p .564 .834 .996 r
F P
0 g
s
.54273 .80246 m .55845 .81408 L .53293 .81737 L p .564 .834 .996 r
F P
0 g
s
.51632 .80359 m .50676 .81627 L .48253 .81089 L p .505 .778 .993 r
F P
0 g
s
.50676 .81627 m .51632 .80359 L .5297 .80415 L p .526 .807 .997 r
F P
0 g
s
.36938 .33972 m .38241 .31437 L .46086 .29019 L p .389 .008 .189 r
F P
0 g
s
.79203 .6118 m .77317 .64719 L .75265 .60165 L p .967 .864 .683 r
F P
0 g
s
.75265 .60165 m .77047 .56159 L .79203 .6118 L p .967 .864 .683 r
F P
0 g
s
.33408 .72583 m .36797 .74718 L .37926 .77407 L p .213 .478 .89 r
F P
0 g
s
.41317 .78435 m .37926 .77407 L .36797 .74718 L p .351 .58 .928 r
F P
0 g
s
.71384 .74266 m .68108 .76087 L .68395 .7331 L p .851 .941 .88 r
F P
0 g
s
.68395 .7331 m .71808 .70846 L .71384 .74266 L p .851 .941 .88 r
F P
0 g
s
.55845 .81408 m .54273 .80246 L .55405 .79868 L p .61 .852 .99 r
F P
0 g
s
.55405 .79868 m .58075 .80671 L .55845 .81408 L p .61 .852 .99 r
F P
0 g
s
.50398 .80082 m .48253 .81089 L .46272 .80173 L p .502 .75 .984 r
F P
0 g
s
.48253 .81089 m .50398 .80082 L .51632 .80359 L p .505 .778 .993 r
F P
0 g
s
.63089 .79365 m .59751 .79595 L .60687 .78285 L p .723 .905 .959 r
F P
0 g
s
.60687 .78285 m .64515 .77429 L .63089 .79365 L p .723 .905 .959 r
F P
0 g
s
.28616 .6242 m .31079 .65943 L .3043 .70009 L p .184 .308 .757 r
F P
0 g
s
.33408 .72583 m .3043 .70009 L .31079 .65943 L p .296 .422 .82 r
F P
0 g
s
.29027 .45455 m .29379 .49584 L .25586 .54734 L p .151 .063 .493 r
F P
0 g
s
.26753 .58648 m .25586 .54734 L .29379 .49584 L p .264 .211 .609 r
F P
0 g
s
.58075 .80671 m .55405 .79868 L .56246 .79318 L p .655 .858 .977 r
F P
0 g
s
.56246 .79318 m .59751 .79595 L .58075 .80671 L p .655 .858 .977 r
F P
0 g
s
.63264 .30001 m .64234 .32425 L .55028 .30819 L p .697 .268 .226 r
F P
0 g
s
.55028 .30819 m .54826 .28512 L .63264 .30001 L p .697 .268 .226 r
F P
0 g
s
.71848 .35914 m .72815 .39245 L .64829 .35643 L p .84 .466 .343 r
F P
0 g
s
.64829 .35643 m .64234 .32425 L .71848 .35914 L p .84 .466 .343 r
F P
0 g
s
.77317 .64719 m .74818 .67965 L .72915 .63967 L p .931 .869 .755 r
F P
0 g
s
.72915 .63967 m .75265 .60165 L .77317 .64719 L p .931 .869 .755 r
F P
0 g
s
.68108 .76087 m .64515 .77429 L .64683 .75325 L p .805 .907 .911 r
F P
0 g
s
.64683 .75325 m .68395 .7331 L .68108 .76087 L p .805 .907 .911 r
F P
0 g
s
.78546 .48037 m .78165 .5207 L .72832 .47319 L p .94 .69 .532 r
F P
0 g
s
.72832 .47319 m .73141 .43101 L .78546 .48037 L p .94 .69 .532 r
F P
0 g
s
.41317 .78435 m .44945 .78965 L .46272 .80173 L p .396 .672 .971 r
F P
0 g
s
.49397 .79612 m .46272 .80173 L .44945 .78965 L p .515 .727 .969 r
F P
0 g
s
.46272 .80173 m .49397 .79612 L .50398 .80082 L p .502 .75 .984 r
F P
0 g
s
.36797 .74718 m .405 .76389 L .41317 .78435 L p .351 .58 .928 r
F P
0 g
s
.44945 .78965 m .41317 .78435 L .405 .76389 L p .455 .653 .945 r
F P
0 g
s
.36938 .33972 m .3614 .37241 L .29398 .41612 L p .245 0 .287 r
F P
0 g
s
.29027 .45455 m .29398 .41612 L .3614 .37241 L p .355 .144 .448 r
F P
0 g
s
.31079 .65943 m .34035 .69133 L .33408 .72583 L p .296 .422 .82 r
F P
0 g
s
.36797 .74718 m .33408 .72583 L .34035 .69133 L p .382 .511 .863 r
F P
0 g
s
.45485 .31366 m .46086 .29019 L .54826 .28512 L p .572 .17 .242 r
F P
0 g
s
.46086 .29019 m .45485 .31366 L .36938 .33972 L p .389 .008 .189 r
F P
0 g
s
.59751 .79595 m .56246 .79318 L .56703 .78655 L p .689 .851 .96 r
F P
0 g
s
.56703 .78655 m .60687 .78285 L .59751 .79595 L p .689 .851 .96 r
F P
0 g
s
.54826 .28512 m .55028 .30819 L .45485 .31366 L p .572 .17 .242 r
F P
0 g
s
.52632 .78542 m .5297 .80415 L .51632 .80359 L closepath p .61 .787 .966 r
F P
0 g
s
.52632 .78542 m .54273 .80246 L .5297 .80415 L closepath p .62 .794 .966 r
F P
0 g
s
.29379 .49584 m .30411 .5384 L .26753 .58648 L p .264 .211 .609 r
F P
0 g
s
.28616 .6242 m .26753 .58648 L .30411 .5384 L p .345 .32 .688 r
F P
0 g
s
.52632 .78542 m .51632 .80359 L .50398 .80082 L closepath p .603 .778 .964 r
F P
0 g
s
.52632 .78542 m .55405 .79868 L .54273 .80246 L closepath p .631 .799 .963 r
F P
0 g
s
.64515 .77429 m .60687 .78285 L .60764 .76873 L p .758 .871 .93 r
F P
0 g
s
.60764 .76873 m .64683 .75325 L .64515 .77429 L p .758 .871 .93 r
F P
0 g
s
.74818 .67965 m .71808 .70846 L .70103 .67465 L p .892 .865 .806 r
F P
0 g
s
.70103 .67465 m .72915 .63967 L .74818 .67965 L p .892 .865 .806 r
F P
0 g
s
.52632 .78542 m .50398 .80082 L .49397 .79612 L closepath p .6 .769 .961 r
F P
0 g
s
.405 .76389 m .44426 .77585 L .44945 .78965 L p .455 .653 .945 r
F P
0 g
s
.48738 .78998 m .44945 .78965 L .44426 .77585 L p .537 .709 .95 r
F P
0 g
s
.44945 .78965 m .48738 .78998 L .49397 .79612 L p .515 .727 .969 r
F P
0 g
s
.3614 .37241 m .36938 .33972 L .45485 .31366 L p .486 .182 .376 r
F P
0 g
s
.34035 .69133 m .37375 .71927 L .36797 .74718 L p .382 .511 .863 r
F P
0 g
s
.405 .76389 m .36797 .74718 L .37375 .71927 L p .453 .583 .893 r
F P
0 g
s
.52632 .78542 m .56246 .79318 L .55405 .79868 L closepath p .643 .8 .958 r
F P
0 g
s
.52632 .78542 m .49397 .79612 L .48738 .78998 L closepath p .601 .76 .955 r
F P
0 g
s
.78165 .5207 m .77047 .56159 L .71924 .51729 L p .922 .726 .621 r
F P
0 g
s
.71924 .51729 m .72832 .47319 L .78165 .5207 L p .922 .726 .621 r
F P
0 g
s
.52632 .78542 m .56703 .78655 L .56246 .79318 L closepath p .654 .798 .952 r
F P
0 g
s
.60687 .78285 m .56703 .78655 L .56722 .77946 L p .71 .833 .94 r
F P
0 g
s
.56722 .77946 m .60764 .76873 L .60687 .78285 L p .71 .833 .94 r
F P
0 g
s
.71808 .70846 m .68395 .7331 L .66938 .70586 L p .852 .856 .845 r
F P
0 g
s
.66938 .70586 m .70103 .67465 L .71808 .70846 L p .852 .856 .845 r
F P
0 g
s
.30411 .5384 m .32054 .58068 L .28616 .6242 L p .345 .32 .688 r
F P
0 g
s
.31079 .65943 m .28616 .6242 L .32054 .58068 L p .406 .405 .745 r
F P
0 g
s
.72815 .39245 m .73141 .43101 L .6503 .39515 L p .85 .547 .475 r
F P
0 g
s
.6503 .39515 m .64829 .35643 L .72815 .39245 L p .85 .547 .475 r
F P
0 g
s
.37375 .71927 m .40993 .74284 L .405 .76389 L p .453 .583 .893 r
F P
0 g
s
.44426 .77585 m .405 .76389 L .40993 .74284 L p .512 .644 .915 r
F P
0 g
s
.3614 .37241 m .3587 .41106 L .29027 .45455 L p .355 .144 .448 r
F P
0 g
s
.29379 .49584 m .29027 .45455 L .3587 .41106 L p .425 .26 .552 r
F P
0 g
s
.44426 .77585 m .48495 .78303 L .48738 .78998 L p .537 .709 .95 r
F P
0 g
s
.52632 .78542 m .48738 .78998 L .48495 .78303 L closepath p .605 .753 .949 r
F P
0 g
s
.64234 .32425 m .64829 .35643 L .55152 .33982 L p .74 .393 .394 r
F P
0 g
s
.55152 .33982 m .55028 .30819 L .64234 .32425 L p .74 .393 .394 r
F P
0 g
s
.52632 .78542 m .56722 .77946 L .56703 .78655 L closepath p .661 .793 .945 r
F P
0 g
s
.40993 .74284 m .44796 .7618 L .44426 .77585 L p .512 .644 .915 r
F P
0 g
s
.48495 .78303 m .44426 .77585 L .44796 .7618 L p .565 .698 .931 r
F P
0 g
s
.68395 .7331 m .64683 .75325 L .63522 .73279 L p .81 .843 .875 r
F P
0 g
s
.63522 .73279 m .66938 .70586 L .68395 .7331 L p .81 .843 .875 r
F P
0 g
s
.44796 .7618 m .48699 .77601 L .48495 .78303 L p .565 .698 .931 r
F P
0 g
s
.52632 .78542 m .48495 .78303 L .48699 .77601 L closepath p .612 .748 .942 r
F P
0 g
s
.32054 .58068 m .34215 .62134 L .31079 .65943 L p .406 .405 .745 r
F P
0 g
s
.34035 .69133 m .31079 .65943 L .34215 .62134 L p .455 .475 .791 r
F P
0 g
s
.77047 .56159 m .75265 .60165 L .70482 .56163 L p .899 .748 .685 r
F P
0 g
s
.70482 .56163 m .71924 .51729 L .77047 .56159 L p .899 .748 .685 r
F P
0 g
s
.52632 .78542 m .55463 .76701 L .56295 .7727 L closepath p .666 .778 .933 r
F P
0 g
s
.52632 .78542 m .54315 .76305 L .55463 .76701 L closepath p .663 .769 .928 r
F P
0 g
s
.52632 .78542 m .52977 .76126 L .54315 .76305 L closepath p .658 .761 .926 r
F P
0 g
s
.52632 .78542 m .516 .76187 L .52977 .76126 L closepath p .65 .754 .925 r
F P
0 g
s
.52632 .78542 m .50339 .76479 L .516 .76187 L closepath p .641 .749 .927 r
F P
0 g
s
.52632 .78542 m .49336 .76969 L .50339 .76479 L closepath p .631 .746 .93 r
F P
0 g
s
.52632 .78542 m .48699 .77601 L .49336 .76969 L closepath p .622 .746 .935 r
F P
0 g
s
.52632 .78542 m .56295 .7727 L .56722 .77946 L closepath p .665 .786 .939 r
F P
0 g
s
.64683 .75325 m .60764 .76873 L .59948 .75513 L p .766 .828 .9 r
F P
0 g
s
.59948 .75513 m .63522 .73279 L .64683 .75325 L p .766 .828 .9 r
F P
0 g
s
.45116 .34547 m .45485 .31366 L .55028 .30819 L p .63 .305 .402 r
F P
0 g
s
.45485 .31366 m .45116 .34547 L .3614 .37241 L p .486 .182 .376 r
F P
0 g
s
.60764 .76873 m .56722 .77946 L .56295 .7727 L p .719 .809 .921 r
F P
0 g
s
.56295 .7727 m .59948 .75513 L .60764 .76873 L p .719 .809 .921 r
F P
0 g
s
.46036 .74903 m .49336 .76969 L .48699 .77601 L p .593 .694 .913 r
F P
0 g
s
.48699 .77601 m .44796 .7618 L .46036 .74903 L p .593 .694 .913 r
F P
0 g
s
.3587 .41106 m .3614 .37241 L .45116 .34547 L p .54 .293 .49 r
F P
0 g
s
.34215 .62134 m .36793 .65923 L .34035 .69133 L p .455 .475 .791 r
F P
0 g
s
.37375 .71927 m .34035 .69133 L .36793 .65923 L p .496 .536 .828 r
F P
0 g
s
.55028 .30819 m .55152 .33982 L .45116 .34547 L p .63 .305 .402 r
F P
0 g
s
.3587 .41106 m .36126 .454 L .29379 .49584 L p .425 .26 .552 r
F P
0 g
s
.30411 .5384 m .29379 .49584 L .36126 .454 L p .472 .345 .625 r
F P
0 g
s
.59948 .75513 m .56295 .7727 L .55463 .76701 L p .716 .783 .905 r
F P
0 g
s
.42795 .72356 m .46036 .74903 L .44796 .7618 L p .563 .643 .887 r
F P
0 g
s
.44796 .7618 m .40993 .74284 L .42795 .72356 L p .563 .643 .887 r
F P
0 g
s
.36793 .65923 m .39685 .6935 L .37375 .71927 L p .496 .536 .828 r
F P
0 g
s
.40993 .74284 m .37375 .71927 L .39685 .6935 L p .531 .591 .859 r
F P
0 g
s
.73141 .43101 m .72832 .47319 L .6484 .4387 L p .846 .597 .563 r
F P
0 g
s
.6484 .4387 m .6503 .39515 L .73141 .43101 L p .846 .597 .563 r
F P
0 g
s
.75265 .60165 m .72915 .63967 L .68588 .60472 L p .874 .762 .735 r
F P
0 g
s
.68588 .60472 m .70482 .56163 L .75265 .60165 L p .874 .762 .735 r
F P
0 g
s
.39685 .6935 m .42795 .72356 L .40993 .74284 L p .531 .591 .859 r
F P
0 g
s
.48029 .73905 m .50339 .76479 L .49336 .76969 L p .621 .696 .898 r
F P
0 g
s
.49336 .76969 m .46036 .74903 L .48029 .73905 L p .621 .696 .898 r
F P
0 g
s
.55463 .76701 m .58308 .74359 L .59948 .75513 L p .716 .783 .905 r
F P
0 g
s
.58308 .74359 m .55463 .76701 L .54315 .76305 L p .706 .758 .893 r
F P
0 g
s
.63522 .73279 m .59948 .75513 L .58308 .74359 L p .757 .785 .876 r
F P
0 g
s
.50556 .73306 m .516 .76187 L .50339 .76479 L p .647 .704 .889 r
F P
0 g
s
.50339 .76479 m .48029 .73905 L .50556 .73306 L p .647 .704 .889 r
F P
0 g
s
.72915 .63967 m .70103 .67465 L .66335 .64529 L p .849 .772 .777 r
F P
0 g
s
.66335 .64529 m .68588 .60472 L .72915 .63967 L p .849 .772 .777 r
F P
0 g
s
.64829 .35643 m .6503 .39515 L .55194 .37861 L p .755 .469 .499 r
F P
0 g
s
.55194 .37861 m .55152 .33982 L .64829 .35643 L p .755 .469 .499 r
F P
0 g
s
.54315 .76305 m .56015 .73548 L .58308 .74359 L p .706 .758 .893 r
F P
0 g
s
.56015 .73548 m .54315 .76305 L .52977 .76126 L p .69 .736 .886 r
F P
0 g
s
.53326 .73182 m .52977 .76126 L .516 .76187 L p .67 .718 .885 r
F P
0 g
s
.516 .76187 m .50556 .73306 L .53326 .73182 L p .67 .718 .885 r
F P
0 g
s
.36126 .454 m .36875 .49942 L .30411 .5384 L p .472 .345 .625 r
F P
0 g
s
.32054 .58068 m .30411 .5384 L .36875 .49942 L p .507 .411 .681 r
F P
0 g
s
.52977 .76126 m .53326 .73182 L .56015 .73548 L p .69 .736 .886 r
F P
0 g
s
.66938 .70586 m .63522 .73279 L .61114 .71528 L p .791 .783 .845 r
F P
0 g
s
.58308 .74359 m .61114 .71528 L .63522 .73279 L p .757 .785 .876 r
F P
0 g
s
.70103 .67465 m .66938 .70586 L .63814 .68237 L p .821 .779 .813 r
F P
0 g
s
.63814 .68237 m .66335 .64529 L .70103 .67465 L p .821 .779 .813 r
F P
0 g
s
.45744 .70837 m .48029 .73905 L .46036 .74903 L p .608 .65 .866 r
F P
0 g
s
.46036 .74903 m .42795 .72356 L .45744 .70837 L p .608 .65 .866 r
F P
0 g
s
.61114 .71528 m .63814 .68237 L .66938 .70586 L p .791 .783 .845 r
F P
0 g
s
.72832 .47319 m .71924 .51729 L .64281 .4852 L p .837 .633 .626 r
F P
0 g
s
.64281 .4852 m .6484 .4387 L .72832 .47319 L p .837 .633 .626 r
F P
0 g
s
.45116 .34547 m .44992 .38424 L .3587 .41106 L p .54 .293 .49 r
F P
0 g
s
.36126 .454 m .3587 .41106 L .44992 .38424 L p .572 .37 .568 r
F P
0 g
s
.44992 .38424 m .45116 .34547 L .55152 .33982 L p .658 .39 .503 r
F P
0 g
s
.61114 .71528 m .58308 .74359 L .56015 .73548 L p .737 .746 .859 r
F P
0 g
s
.36875 .49942 m .38064 .54554 L .32054 .58068 L p .507 .411 .681 r
F P
0 g
s
.34215 .62134 m .32054 .58068 L .38064 .54554 L p .535 .467 .726 r
F P
0 g
s
.43538 .67305 m .45744 .70837 L .42795 .72356 L p .593 .606 .834 r
F P
0 g
s
.42795 .72356 m .39685 .6935 L .43538 .67305 L p .593 .606 .834 r
F P
0 g
s
.55152 .33982 m .55194 .37861 L .44992 .38424 L p .658 .39 .503 r
F P
0 g
s
.49519 .69921 m .50556 .73306 L .48029 .73905 L p .647 .664 .853 r
F P
0 g
s
.48029 .73905 m .45744 .70837 L .49519 .69921 L p .647 .664 .853 r
F P
0 g
s
.38064 .54554 m .39623 .59072 L .34215 .62134 L p .535 .467 .726 r
F P
0 g
s
.36793 .65923 m .34215 .62134 L .39623 .59072 L p .557 .516 .765 r
F P
0 g
s
.41473 .63358 m .43538 .67305 L .39685 .6935 L p .576 .562 .801 r
F P
0 g
s
.39685 .6935 m .36793 .65923 L .41473 .63358 L p .576 .562 .801 r
F P
0 g
s
.56015 .73548 m .57701 .70292 L .61114 .71528 L p .737 .746 .859 r
F P
0 g
s
.57701 .70292 m .56015 .73548 L .53326 .73182 L p .712 .712 .849 r
F P
0 g
s
.39623 .59072 m .41473 .63358 L .36793 .65923 L p .557 .516 .765 r
F P
0 g
s
.63814 .68237 m .61114 .71528 L .57701 .70292 L p .762 .732 .825 r
F P
0 g
s
.53674 .69731 m .53326 .73182 L .50556 .73306 L p .681 .685 .847 r
F P
0 g
s
.50556 .73306 m .49519 .69921 L .53674 .69731 L p .681 .685 .847 r
F P
0 g
s
.71924 .51729 m .70482 .56163 L .63395 .53274 L p .826 .66 .677 r
F P
0 g
s
.63395 .53274 m .64281 .4852 L .71924 .51729 L p .826 .66 .677 r
F P
0 g
s
.6503 .39515 m .6484 .4387 L .55154 .4228 L p .76 .521 .571 r
F P
0 g
s
.55154 .4228 m .55194 .37861 L .6503 .39515 L p .76 .521 .571 r
F P
0 g
s
.53326 .73182 m .53674 .69731 L .57701 .70292 L p .712 .712 .849 r
F P
0 g
s
.44992 .38424 m .4511 .42821 L .36126 .454 L p .572 .37 .568 r
F P
0 g
s
.36875 .49942 m .36126 .454 L .4511 .42821 L p .594 .428 .627 r
F P
0 g
s
.48514 .66065 m .49519 .69921 L .45744 .70837 L p .644 .627 .818 r
F P
0 g
s
.45744 .70837 m .43538 .67305 L .48514 .66065 L p .644 .627 .818 r
F P
0 g
s
.66335 .64529 m .63814 .68237 L .59332 .66568 L p .781 .717 .791 r
F P
0 g
s
.57701 .70292 m .59332 .66568 L .63814 .68237 L p .762 .732 .825 r
F P
0 g
s
.70482 .56163 m .68588 .60472 L .62236 .5796 L p .813 .681 .719 r
F P
0 g
s
.62236 .5796 m .63395 .53274 L .70482 .56163 L p .813 .681 .719 r
F P
0 g
s
.4511 .42821 m .44992 .38424 L .55194 .37861 L p .674 .45 .573 r
F P
0 g
s
.68588 .60472 m .66335 .64529 L .60862 .6243 L p .798 .7 .757 r
F P
0 g
s
.59332 .66568 m .60862 .6243 L .66335 .64529 L p .781 .717 .791 r
F P
0 g
s
.60862 .6243 m .62236 .5796 L .68588 .60472 L p .798 .7 .757 r
F P
0 g
s
.59332 .66568 m .57701 .70292 L .53674 .69731 L p .727 .689 .814 r
F P
0 g
s
.55194 .37861 m .55154 .4228 L .4511 .42821 L p .674 .45 .573 r
F P
0 g
s
.5401 .65807 m .53674 .69731 L .49519 .69921 L p .688 .655 .812 r
F P
0 g
s
.49519 .69921 m .48514 .66065 L .5401 .65807 L p .688 .655 .812 r
F P
0 g
s
.4511 .42821 m .45456 .47545 L .36875 .49942 L p .594 .428 .627 r
F P
0 g
s
.38064 .54554 m .36875 .49942 L .45456 .47545 L p .61 .476 .674 r
F P
0 g
s
.4757 .61796 m .48514 .66065 L .43538 .67305 L p .639 .591 .785 r
F P
0 g
s
.43538 .67305 m .41473 .63358 L .4757 .61796 L p .639 .591 .785 r
F P
0 g
s
.6484 .4387 m .64281 .4852 L .55037 .47042 L p .76 .56 .627 r
F P
0 g
s
.55037 .47042 m .55154 .4228 L .6484 .4387 L p .76 .56 .627 r
F P
0 g
s
.53674 .69731 m .5401 .65807 L .59332 .66568 L p .727 .689 .814 r
F P
0 g
s
.46722 .572 m .4757 .61796 L .41473 .63358 L p .631 .555 .75 r
F P
0 g
s
.41473 .63358 m .39623 .59072 L .46722 .572 L p .631 .555 .75 r
F P
0 g
s
.45456 .47545 m .46004 .52398 L .38064 .54554 L p .61 .476 .674 r
F P
0 g
s
.39623 .59072 m .38064 .54554 L .46004 .52398 L p .622 .517 .714 r
F P
0 g
s
.60862 .6243 m .59332 .66568 L .5401 .65807 L p .738 .666 .78 r
F P
0 g
s
.46004 .52398 m .46722 .572 L .39623 .59072 L p .622 .517 .714 r
F P
0 g
s
.45456 .47545 m .4511 .42821 L .55154 .4228 L p .683 .495 .626 r
F P
0 g
s
.64281 .4852 m .63395 .53274 L .54853 .51947 L p .757 .592 .671 r
F P
0 g
s
.54853 .51947 m .55037 .47042 L .64281 .4852 L p .757 .592 .671 r
F P
0 g
s
.54327 .6147 m .5401 .65807 L .48514 .66065 L p .691 .625 .778 r
F P
0 g
s
.48514 .66065 m .4757 .61796 L .54327 .6147 L p .691 .625 .778 r
F P
0 g
s
.55154 .4228 m .55037 .47042 L .45456 .47545 L p .683 .495 .626 r
F P
0 g
s
.5401 .65807 m .54327 .6147 L .60862 .6243 L p .738 .666 .78 r
F P
0 g
s
.62236 .5796 m .60862 .6243 L .54327 .6147 L p .746 .643 .746 r
F P
0 g
s
.63395 .53274 m .62236 .5796 L .54612 .56809 L p .753 .619 .71 r
F P
0 g
s
.54612 .56809 m .54853 .51947 L .63395 .53274 L p .753 .619 .71 r
F P
0 g
s
.54327 .6147 m .54612 .56809 L .62236 .5796 L p .746 .643 .746 r
F P
0 g
s
.46004 .52398 m .45456 .47545 L .55037 .47042 L p .688 .533 .67 r
F P
0 g
s
.54612 .56809 m .54327 .6147 L .4757 .61796 L p .692 .596 .744 r
F P
0 g
s
.4757 .61796 m .46722 .572 L .54612 .56809 L p .692 .596 .744 r
F P
0 g
s
.55037 .47042 m .54853 .51947 L .46004 .52398 L p .688 .533 .67 r
F P
0 g
s
.46722 .572 m .46004 .52398 L .54853 .51947 L p .691 .566 .709 r
F P
0 g
s
.54853 .51947 m .54612 .56809 L .46722 .572 L p .691 .566 .709 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48699 .50871 m .47964 .55076 L .54208 .55385 L p .717 .609 .734 r
F P
0 g
s
.54208 .55385 m .5396 .51139 L .48699 .50871 L p .717 .609 .734 r
F P
0 g
s
.54413 .59636 m .54208 .55385 L .47964 .55076 L p .72 .584 .703 r
F P
0 g
s
.5396 .51139 m .54208 .55385 L .60316 .54455 L p .673 .574 .736 r
F P
0 g
s
.54208 .55385 m .54413 .59636 L .61318 .5861 L p .668 .544 .705 r
F P
0 g
s
.61318 .5861 m .60316 .54455 L .54208 .55385 L p .668 .544 .705 r
F P
0 g
s
.47964 .55076 m .47357 .59294 L .54413 .59636 L p .72 .584 .703 r
F P
0 g
s
.5457 .63801 m .54413 .59636 L .47357 .59294 L p .72 .559 .67 r
F P
0 g
s
.54413 .59636 m .5457 .63801 L .62091 .62712 L p .662 .513 .671 r
F P
0 g
s
.62091 .62712 m .61318 .5861 L .54413 .59636 L p .662 .513 .671 r
F P
0 g
s
.43796 .49552 m .42129 .53546 L .47964 .55076 L p .76 .649 .74 r
F P
0 g
s
.47964 .55076 m .48699 .50871 L .43796 .49552 L p .76 .649 .74 r
F P
0 g
s
.47357 .59294 m .47964 .55076 L .42129 .53546 L p .768 .63 .708 r
F P
0 g
s
.42129 .53546 m .4075 .57607 L .47357 .59294 L p .768 .63 .708 r
F P
0 g
s
.4689 .63438 m .47357 .59294 L .4075 .57607 L p .775 .609 .674 r
F P
0 g
s
.47357 .59294 m .4689 .63438 L .5457 .63801 L p .72 .559 .67 r
F P
0 g
s
.49551 .46773 m .48699 .50871 L .5396 .51139 L p .714 .633 .766 r
F P
0 g
s
.5396 .51139 m .53673 .46987 L .49551 .46773 L p .714 .633 .766 r
F P
0 g
s
.53673 .46987 m .5396 .51139 L .59101 .50336 L p .676 .604 .768 r
F P
0 g
s
.60316 .54455 m .59101 .50336 L .5396 .51139 L p .673 .574 .736 r
F P
0 g
s
.54678 .67796 m .5457 .63801 L .4689 .63438 L p .719 .531 .634 r
F P
0 g
s
.5457 .63801 m .54678 .67796 L .62621 .66675 L p .655 .48 .635 r
F P
0 g
s
.62621 .66675 m .62091 .62712 L .5457 .63801 L p .655 .48 .635 r
F P
0 g
s
.45721 .45717 m .43796 .49552 L .48699 .50871 L p .749 .668 .771 r
F P
0 g
s
.48699 .50871 m .49551 .46773 L .45721 .45717 L p .749 .668 .771 r
F P
0 g
s
.59101 .50336 m .60316 .54455 L .65741 .52347 L p .623 .544 .745 r
F P
0 g
s
.60316 .54455 m .61318 .5861 L .67476 .56282 L p .61 .507 .712 r
F P
0 g
s
.67476 .56282 m .65741 .52347 L .60316 .54455 L p .61 .507 .712 r
F P
0 g
s
.4075 .57607 m .39686 .61646 L .4689 .63438 L p .775 .609 .674 r
F P
0 g
s
.4657 .67423 m .4689 .63438 L .39686 .61646 L p .78 .585 .636 r
F P
0 g
s
.4689 .63438 m .4657 .67423 L .54678 .67796 L p .719 .531 .634 r
F P
0 g
s
.61318 .5861 m .62091 .62712 L .68817 .60236 L p .595 .468 .677 r
F P
0 g
s
.68817 .60236 m .67476 .56282 L .61318 .5861 L p .595 .468 .677 r
F P
0 g
s
.59101 .50336 m .57697 .46344 L .53673 .46987 L p .676 .604 .768 r
F P
0 g
s
.57697 .46344 m .59101 .50336 L .63648 .48522 L p .634 .581 .777 r
F P
0 g
s
.65741 .52347 m .63648 .48522 L .59101 .50336 L p .623 .544 .745 r
F P
0 g
s
.50503 .42877 m .49551 .46773 L .53673 .46987 L p .707 .658 .798 r
F P
0 g
s
.53673 .46987 m .53351 .43028 L .50503 .42877 L p .707 .658 .798 r
F P
0 g
s
.53351 .43028 m .53673 .46987 L .57697 .46344 L p .678 .635 .8 r
F P
0 g
s
.47866 .42133 m .45721 .45717 L .49551 .46773 L p .734 .685 .803 r
F P
0 g
s
.49551 .46773 m .50503 .42877 L .47866 .42133 L p .734 .685 .803 r
F P
0 g
s
.54735 .71542 m .54678 .67796 L .4657 .67423 L p .716 .499 .594 r
F P
0 g
s
.54678 .67796 m .54735 .71542 L .62899 .70418 L p .645 .442 .593 r
F P
0 g
s
.62899 .70418 m .62621 .66675 L .54678 .67796 L p .645 .442 .593 r
F P
0 g
s
.62091 .62712 m .62621 .66675 L .69739 .64122 L p .579 .426 .638 r
F P
0 g
s
.69739 .64122 m .68817 .60236 L .62091 .62712 L p .579 .426 .638 r
F P
0 g
s
.39715 .47282 m .37239 .50903 L .42129 .53546 L p .8 .698 .753 r
F P
0 g
s
.42129 .53546 m .43796 .49552 L .39715 .47282 L p .8 .698 .753 r
F P
0 g
s
.4075 .57607 m .42129 .53546 L .37239 .50903 L p .817 .685 .719 r
F P
0 g
s
.42557 .43908 m .39715 .47282 L .43796 .49552 L p .781 .709 .784 r
F P
0 g
s
.43796 .49552 m .45721 .45717 L .42557 .43908 L p .781 .709 .784 r
F P
0 g
s
.37239 .50903 m .35184 .54681 L .4075 .57607 L p .817 .685 .719 r
F P
0 g
s
.39686 .61646 m .4075 .57607 L .35184 .54681 L p .831 .669 .682 r
F P
0 g
s
.57697 .46344 m .56129 .42574 L .53351 .43028 L p .678 .635 .8 r
F P
0 g
s
.56129 .42574 m .57697 .46344 L .61237 .44894 L p .646 .619 .808 r
F P
0 g
s
.63648 .48522 m .61237 .44894 L .57697 .46344 L p .634 .581 .777 r
F P
0 g
s
.39686 .61646 m .38955 .65576 L .4657 .67423 L p .78 .585 .636 r
F P
0 g
s
.46402 .71168 m .4657 .67423 L .38955 .65576 L p .783 .557 .593 r
F P
0 g
s
.4657 .67423 m .46402 .71168 L .54735 .71542 L p .716 .499 .594 r
F P
0 g
s
.45705 .40864 m .42557 .43908 L .45721 .45717 L p .758 .718 .815 r
F P
0 g
s
.45721 .45717 m .47866 .42133 L .45705 .40864 L p .758 .718 .815 r
F P
0 g
s
.35184 .54681 m .33591 .58531 L .39686 .61646 L p .831 .669 .682 r
F P
0 g
s
.38955 .65576 m .39686 .61646 L .33591 .58531 L p .843 .649 .64 r
F P
0 g
s
.62621 .66675 m .62899 .70418 L .70223 .67854 L p .559 .377 .592 r
F P
0 g
s
.70223 .67854 m .69739 .64122 L .62621 .66675 L p .559 .377 .592 r
F P
0 g
s
.63648 .48522 m .65741 .52347 L .69961 .49213 L p .564 .518 .763 r
F P
0 g
s
.65741 .52347 m .67476 .56282 L .72301 .52806 L p .538 .471 .728 r
F P
0 g
s
.72301 .52806 m .69961 .49213 L .65741 .52347 L p .538 .471 .728 r
F P
0 g
s
.61237 .44894 m .63648 .48522 L .67152 .45837 L p .588 .563 .794 r
F P
0 g
s
.69961 .49213 m .67152 .45837 L .63648 .48522 L p .564 .518 .763 r
F P
0 g
s
.51537 .39282 m .50503 .42877 L .53351 .43028 L p .698 .684 .833 r
F P
0 g
s
.53351 .43028 m .53002 .39362 L .51537 .39282 L p .698 .684 .833 r
F P
0 g
s
.53002 .39362 m .53351 .43028 L .56129 .42574 L p .678 .67 .835 r
F P
0 g
s
.50186 .38893 m .47866 .42133 L .50503 .42877 L p .716 .703 .837 r
F P
0 g
s
.50503 .42877 m .51537 .39282 L .50186 .38893 L p .716 .703 .837 r
F P
0 g
s
.54739 .74962 m .54735 .71542 L .46402 .71168 L p .71 .461 .545 r
F P
0 g
s
.54735 .71542 m .54739 .74962 L .62918 .73861 L p .632 .397 .544 r
F P
0 g
s
.62918 .73861 m .62899 .70418 L .54735 .71542 L p .632 .397 .544 r
F P
0 g
s
.67476 .56282 m .68817 .60236 L .74119 .56528 L p .51 .419 .689 r
F P
0 g
s
.74119 .56528 m .72301 .52806 L .67476 .56282 L p .51 .419 .689 r
F P
0 g
s
.61237 .44894 m .58558 .41555 L .56129 .42574 L p .646 .619 .808 r
F P
0 g
s
.58558 .41555 m .61237 .44894 L .63936 .42761 L p .611 .608 .824 r
F P
0 g
s
.67152 .45837 m .63936 .42761 L .61237 .44894 L p .588 .563 .794 r
F P
0 g
s
.56129 .42574 m .54428 .39124 L .53002 .39362 L p .678 .67 .835 r
F P
0 g
s
.54428 .39124 m .56129 .42574 L .58558 .41555 L p .657 .659 .841 r
F P
0 g
s
.38955 .65576 m .38572 .69315 L .46402 .71168 L p .783 .557 .593 r
F P
0 g
s
.46391 .74596 m .46402 .71168 L .38572 .69315 L p .784 .522 .54 r
F P
0 g
s
.46402 .71168 m .46391 .74596 L .54739 .74962 L p .71 .461 .545 r
F P
0 g
s
.4909 .38233 m .45705 .40864 L .47866 .42133 L p .73 .725 .846 r
F P
0 g
s
.47866 .42133 m .50186 .38893 L .4909 .38233 L p .73 .725 .846 r
F P
0 g
s
.33591 .58531 m .32494 .62361 L .38955 .65576 L p .843 .649 .64 r
F P
0 g
s
.38572 .69315 m .38955 .65576 L .32494 .62361 L p .854 .623 .589 r
F P
0 g
s
.40394 .41502 m .36882 .44244 L .39715 .47282 L p .809 .759 .806 r
F P
0 g
s
.39715 .47282 m .42557 .43908 L .40394 .41502 L p .809 .759 .806 r
F P
0 g
s
.37239 .50903 m .39715 .47282 L .36882 .44244 L p .839 .759 .775 r
F P
0 g
s
.68817 .60236 m .69739 .64122 L .75372 .6029 L p .477 .36 .642 r
F P
0 g
s
.75372 .6029 m .74119 .56528 L .68817 .60236 L p .477 .36 .642 r
F P
0 g
s
.36882 .44244 m .33803 .47345 L .37239 .50903 L p .839 .759 .775 r
F P
0 g
s
.35184 .54681 m .37239 .50903 L .33803 .47345 L p .866 .755 .739 r
F P
0 g
s
.44253 .39189 m .40394 .41502 L .42557 .43908 L p .777 .756 .834 r
F P
0 g
s
.42557 .43908 m .45705 .40864 L .44253 .39189 L p .777 .756 .834 r
F P
0 g
s
.58558 .41555 m .55668 .38592 L .54428 .39124 L p .657 .659 .841 r
F P
0 g
s
.55668 .38592 m .58558 .41555 L .60388 .40064 L p .635 .654 .852 r
F P
0 g
s
.63936 .42761 m .60388 .40064 L .58558 .41555 L p .611 .608 .824 r
F P
0 g
s
.62899 .70418 m .62918 .73861 L .70256 .7135 L p .533 .319 .535 r
F P
0 g
s
.70256 .7135 m .70223 .67854 L .62899 .70418 L p .533 .319 .535 r
F P
0 g
s
.33803 .47345 m .3123 .50725 L .35184 .54681 L p .866 .755 .739 r
F P
0 g
s
.33591 .58531 m .35184 .54681 L .3123 .50725 L p .89 .747 .696 r
F P
0 g
s
.48366 .37368 m .44253 .39189 L .45705 .40864 L p .74 .749 .859 r
F P
0 g
s
.45705 .40864 m .4909 .38233 L .48366 .37368 L p .74 .749 .859 r
F P
0 g
s
.53002 .39362 m .52632 .3609 L .51537 .39282 L closepath p .683 .714 .872 r
F P
0 g
s
.54428 .39124 m .52632 .3609 L .53002 .39362 L closepath p .675 .708 .873 r
F P
0 g
s
.51537 .39282 m .52632 .3609 L .50186 .38893 L closepath p .689 .721 .874 r
F P
0 g
s
.5469 .77984 m .54739 .74962 L .46391 .74596 L p .7 .412 .484 r
F P
0 g
s
.54739 .74962 m .5469 .77984 L .62677 .7693 L p .613 .34 .481 r
F P
0 g
s
.62677 .7693 m .62918 .73861 L .54739 .74962 L p .613 .34 .481 r
F P
0 g
s
.55668 .38592 m .52632 .3609 L .54428 .39124 L closepath p .667 .704 .875 r
F P
0 g
s
.60388 .40064 m .63936 .42761 L .65491 .40138 L p .574 .606 .846 r
F P
0 g
s
.63936 .42761 m .67152 .45837 L .69217 .42511 L p .534 .553 .821 r
F P
0 g
s
.69217 .42511 m .65491 .40138 L .63936 .42761 L p .534 .553 .821 r
F P
0 g
s
.67152 .45837 m .69961 .49213 L .72497 .45304 L p .49 .496 .79 r
F P
0 g
s
.72497 .45304 m .69217 .42511 L .67152 .45837 L p .49 .496 .79 r
F P
0 g
s
.50186 .38893 m .52632 .3609 L .4909 .38233 L closepath p .694 .729 .877 r
F P
0 g
s
.69739 .64122 m .70223 .67854 L .7603 .64003 L p .437 .291 .584 r
F P
0 g
s
.7603 .64003 m .75372 .6029 L .69739 .64122 L p .437 .291 .584 r
F P
0 g
s
.38572 .69315 m .38545 .7278 L .46391 .74596 L p .784 .522 .54 r
F P
0 g
s
.46536 .77633 m .46391 .74596 L .38545 .7278 L p .78 .476 .473 r
F P
0 g
s
.46391 .74596 m .46536 .77633 L .5469 .77984 L p .7 .412 .484 r
F P
0 g
s
.32494 .62361 m .31919 .66085 L .38572 .69315 L p .854 .623 .589 r
F P
0 g
s
.38545 .7278 m .38572 .69315 L .31919 .66085 L p .861 .589 .525 r
F P
0 g
s
.60388 .40064 m .5659 .37819 L .55668 .38592 L p .635 .654 .852 r
F P
0 g
s
.5659 .37819 m .60388 .40064 L .61415 .38246 L p .613 .656 .868 r
F P
0 g
s
.65491 .40138 m .61415 .38246 L .60388 .40064 L p .574 .606 .846 r
F P
0 g
s
.5659 .37819 m .52632 .3609 L .55668 .38592 L closepath p .659 .703 .88 r
F P
0 g
s
.69961 .49213 m .72301 .52806 L .75248 .48447 L p .44 .431 .753 r
F P
0 g
s
.75248 .48447 m .72497 .45304 L .69961 .49213 L p .44 .431 .753 r
F P
0 g
s
.3123 .50725 m .29226 .54302 L .33591 .58531 L p .89 .747 .696 r
F P
0 g
s
.32494 .62361 m .33591 .58531 L .29226 .54302 L p .913 .732 .643 r
F P
0 g
s
.4909 .38233 m .52632 .3609 L .48366 .37368 L closepath p .697 .737 .883 r
F P
0 g
s
.57092 .36884 m .52632 .3609 L .5659 .37819 L closepath p .652 .705 .886 r
F P
0 g
s
.61415 .38246 m .57092 .36884 L .5659 .37819 L p .613 .656 .868 r
F P
0 g
s
.62918 .73861 m .62677 .7693 L .69837 .74529 L p .499 .245 .461 r
F P
0 g
s
.69837 .74529 m .70256 .7135 L .62918 .73861 L p .499 .245 .461 r
F P
0 g
s
.48098 .36388 m .43681 .37275 L .44253 .39189 L p .744 .774 .877 r
F P
0 g
s
.44253 .39189 m .48366 .37368 L .48098 .36388 L p .744 .774 .877 r
F P
0 g
s
.40394 .41502 m .44253 .39189 L .43681 .37275 L p .787 .798 .861 r
F P
0 g
s
.43681 .37275 m .39495 .38727 L .40394 .41502 L p .787 .798 .861 r
F P
0 g
s
.36882 .44244 m .40394 .41502 L .39495 .38727 L p .829 .818 .838 r
F P
0 g
s
.72301 .52806 m .74119 .56528 L .77395 .51858 L p .383 .356 .705 r
F P
0 g
s
.77395 .51858 m .75248 .48447 L .72301 .52806 L p .383 .356 .705 r
F P
0 g
s
.48366 .37368 m .52632 .3609 L .48098 .36388 L closepath p .697 .745 .889 r
F P
0 g
s
.39495 .38727 m .35652 .40711 L .36882 .44244 L p .829 .818 .838 r
F P
0 g
s
.33803 .47345 m .36882 .44244 L .35652 .40711 L p .87 .834 .809 r
F P
0 g
s
.70223 .67854 m .70256 .7135 L .76076 .67577 L p .386 .205 .51 r
F P
0 g
s
.76076 .67577 m .7603 .64003 L .70223 .67854 L p .386 .205 .51 r
F P
0 g
s
.57115 .35886 m .52632 .3609 L .57092 .36884 L closepath p .647 .709 .893 r
F P
0 g
s
.57092 .36884 m .61415 .38246 L .61506 .36284 L p .594 .664 .888 r
F P
0 g
s
.61506 .36284 m .57115 .35886 L .57092 .36884 L p .594 .664 .888 r
F P
0 g
s
.61415 .38246 m .65491 .40138 L .65688 .37281 L p .536 .613 .877 r
F P
0 g
s
.65688 .37281 m .61506 .36284 L .61415 .38246 L p .536 .613 .877 r
F P
0 g
s
.29226 .54302 m .27842 .57986 L .32494 .62361 L p .913 .732 .643 r
F P
0 g
s
.31919 .66085 m .32494 .62361 L .27842 .57986 L p .933 .708 .575 r
F P
0 g
s
.48098 .36388 m .52632 .3609 L .4832 .35398 L closepath p .694 .752 .896 r
F P
0 g
s
.56649 .34932 m .52632 .3609 L .57115 .35886 L closepath p .644 .715 .9 r
F P
0 g
s
.55738 .34129 m .52632 .3609 L .56649 .34932 L closepath p .644 .724 .907 r
F P
0 g
s
.54479 .33568 m .52632 .3609 L .55738 .34129 L closepath p .647 .733 .912 r
F P
0 g
s
.5301 .33316 m .52632 .3609 L .54479 .33568 L closepath p .653 .742 .915 r
F P
0 g
s
.51499 .33401 m .52632 .3609 L .5301 .33316 L closepath p .661 .75 .916 r
F P
0 g
s
.50116 .33814 m .52632 .3609 L .51499 .33401 L closepath p .67 .755 .914 r
F P
0 g
s
.49017 .34507 m .52632 .3609 L .50116 .33814 L closepath p .68 .757 .91 r
F P
0 g
s
.4832 .35398 m .52632 .3609 L .49017 .34507 L closepath p .688 .756 .903 r
F P
0 g
s
.54588 .8054 m .5469 .77984 L .46536 .77633 L p .681 .347 .402 r
F P
0 g
s
.5469 .77984 m .54588 .8054 L .62178 .79556 L p .583 .265 .395 r
F P
0 g
s
.62178 .79556 m .62677 .7693 L .5469 .77984 L p .583 .265 .395 r
F P
0 g
s
.31919 .66085 m .31879 .69617 L .38545 .7278 L p .861 .589 .525 r
F P
0 g
s
.38878 .75897 m .38545 .7278 L .31879 .69617 L p .861 .539 .441 r
F P
0 g
s
.38545 .7278 m .38878 .75897 L .46536 .77633 L p .78 .476 .473 r
F P
0 g
s
.43681 .37275 m .48098 .36388 L .4832 .35398 L p .738 .796 .898 r
F P
0 g
s
.35652 .40711 m .32254 .43177 L .33803 .47345 L p .87 .834 .809 r
F P
0 g
s
.3123 .50725 m .33803 .47345 L .32254 .43177 L p .91 .846 .768 r
F P
0 g
s
.65491 .40138 m .69217 .42511 L .69547 .38858 L p .469 .552 .858 r
F P
0 g
s
.69547 .38858 m .65688 .37281 L .65491 .40138 L p .469 .552 .858 r
F P
0 g
s
.46838 .80212 m .46536 .77633 L .38878 .75897 L p .767 .411 .382 r
F P
0 g
s
.46536 .77633 m .46838 .80212 L .54588 .8054 L p .681 .347 .402 r
F P
0 g
s
.74119 .56528 m .75372 .6029 L .78882 .55451 L p .313 .264 .642 r
F P
0 g
s
.78882 .55451 m .77395 .51858 L .74119 .56528 L p .313 .264 .642 r
F P
0 g
s
.57115 .35886 m .61506 .36284 L .60623 .34391 L p .579 .681 .91 r
F P
0 g
s
.60623 .34391 m .56649 .34932 L .57115 .35886 L p .579 .681 .91 r
F P
0 g
s
.4832 .35398 m .44076 .35319 L .43681 .37275 L p .738 .796 .898 r
F P
0 g
s
.39495 .38727 m .43681 .37275 L .44076 .35319 L p .784 .839 .894 r
F P
0 g
s
.69217 .42511 m .72497 .45304 L .72973 .40978 L p .389 .477 .83 r
F P
0 g
s
.72973 .40978 m .69547 .38858 L .69217 .42511 L p .389 .477 .83 r
F P
0 g
s
.44076 .35319 m .4832 .35398 L .49017 .34507 L p .722 .812 .921 r
F P
0 g
s
.62677 .7693 m .62178 .79556 L .68968 .77316 L p .448 .146 .358 r
F P
0 g
s
.68968 .77316 m .69837 .74529 L .62677 .7693 L p .448 .146 .358 r
F P
0 g
s
.32254 .43177 m .29394 .46063 L .3123 .50725 L p .91 .846 .768 r
F P
0 g
s
.29226 .54302 m .3123 .50725 L .29394 .46063 L p .948 .85 .713 r
F P
0 g
s
.56649 .34932 m .60623 .34391 L .58837 .32782 L p .572 .704 .931 r
F P
0 g
s
.58837 .32782 m .55738 .34129 L .56649 .34932 L p .572 .704 .931 r
F P
0 g
s
.44076 .35319 m .40014 .35866 L .39495 .38727 L p .784 .839 .894 r
F P
0 g
s
.35652 .40711 m .39495 .38727 L .40014 .35866 L p .83 .881 .88 r
F P
0 g
s
.27842 .57986 m .27114 .61685 L .31919 .66085 L p .933 .708 .575 r
F P
0 g
s
.31879 .69617 m .31919 .66085 L .27114 .61685 L p .946 .669 .483 r
F P
0 g
s
.61506 .36284 m .65688 .37281 L .64445 .34497 L p .498 .633 .913 r
F P
0 g
s
.64445 .34497 m .60623 .34391 L .61506 .36284 L p .498 .633 .913 r
F P
0 g
s
.70256 .7135 m .69837 .74529 L .75504 .70925 L p .316 .093 .407 r
F P
0 g
s
.75504 .70925 m .76076 .67577 L .70256 .7135 L p .316 .093 .407 r
F P
0 g
s
.45425 .33541 m .49017 .34507 L .50116 .33814 L p .695 .818 .941 r
F P
0 g
s
.49017 .34507 m .45425 .33541 L .44076 .35319 L p .722 .812 .921 r
F P
0 g
s
.75372 .6029 m .7603 .64003 L .79665 .59132 L p .224 .148 .556 r
F P
0 g
s
.79665 .59132 m .78882 .55451 L .75372 .6029 L p .224 .148 .556 r
F P
0 g
s
.72497 .45304 m .75248 .48447 L .75867 .43592 L p .29 .382 .785 r
F P
0 g
s
.75867 .43592 m .72973 .40978 L .72497 .45304 L p .29 .382 .785 r
F P
0 g
s
.55738 .34129 m .58837 .32782 L .56332 .31651 L p .577 .734 .95 r
F P
0 g
s
.56332 .31651 m .54479 .33568 L .55738 .34129 L p .577 .734 .95 r
F P
0 g
s
.31879 .69617 m .32379 .72872 L .38878 .75897 L p .861 .539 .441 r
F P
0 g
s
.39566 .78591 m .38878 .75897 L .32379 .72872 L p .849 .465 .321 r
F P
0 g
s
.38878 .75897 m .39566 .78591 L .46838 .80212 L p .767 .411 .382 r
F P
0 g
s
.40014 .35866 m .44076 .35319 L .45425 .33541 L p .758 .873 .931 r
F P
0 g
s
.47599 .32149 m .50116 .33814 L .51499 .33401 L p .66 .812 .956 r
F P
0 g
s
.50116 .33814 m .47599 .32149 L .45425 .33541 L p .695 .818 .941 r
F P
0 g
s
.29394 .46063 m .27155 .49296 L .29226 .54302 L p .948 .85 .713 r
F P
0 g
s
.27842 .57986 m .29226 .54302 L .27155 .49296 L p .98 .842 .633 r
F P
0 g
s
.54479 .33568 m .56332 .31651 L .53391 .31139 L p .594 .765 .961 r
F P
0 g
s
.53391 .31139 m .5301 .33316 L .54479 .33568 L p .594 .765 .961 r
F P
0 g
s
.40014 .35866 m .36249 .37036 L .35652 .40711 L p .83 .881 .88 r
F P
0 g
s
.32254 .43177 m .35652 .40711 L .36249 .37036 L p .877 .921 .852 r
F P
0 g
s
.54435 .82567 m .54588 .8054 L .46838 .80212 L p .646 .251 .282 r
F P
0 g
s
.54588 .8054 m .54435 .82567 L .61427 .81673 L p .534 .156 .271 r
F P
0 g
s
.61427 .81673 m .62178 .79556 L .54588 .8054 L p .534 .156 .271 r
F P
0 g
s
.50361 .31313 m .51499 .33401 L .5301 .33316 L p .624 .793 .963 r
F P
0 g
s
.51499 .33401 m .50361 .31313 L .47599 .32149 L p .66 .812 .956 r
F P
0 g
s
.65688 .37281 m .69547 .38858 L .68003 .35265 L p .391 .564 .904 r
F P
0 g
s
.68003 .35265 m .64445 .34497 L .65688 .37281 L p .391 .564 .904 r
F P
0 g
s
.5301 .33316 m .53391 .31139 L .50361 .31313 L p .624 .793 .963 r
F P
0 g
s
.47291 .8227 m .46838 .80212 L .39566 .78591 L p .735 .314 .247 r
F P
0 g
s
.46838 .80212 m .47291 .8227 L .54435 .82567 L p .646 .251 .282 r
F P
0 g
s
.60623 .34391 m .64445 .34497 L .61841 .3211 L p .469 .667 .949 r
F P
0 g
s
.61841 .3211 m .58837 .32782 L .60623 .34391 L p .469 .667 .949 r
F P
0 g
s
.75248 .48447 m .77395 .51858 L .78141 .46631 L p .162 .256 .715 r
F P
0 g
s
.78141 .46631 m .75867 .43592 L .75248 .48447 L p .162 .256 .715 r
F P
0 g
s
.27114 .61685 m .27063 .65306 L .31879 .69617 L p .946 .669 .483 r
F P
0 g
s
.32379 .72872 m .31879 .69617 L .27063 .65306 L p .942 .603 .352 r
F P
0 g
s
.7603 .64003 m .76076 .67577 L .79719 .62805 L p .106 0 .433 r
F P
0 g
s
.79719 .62805 m .79665 .59132 L .7603 .64003 L p .106 0 .433 r
F P
0 g
s
.62178 .79556 m .61427 .81673 L .67665 .79642 L p .368 .003 .206 r
F P
0 g
s
.67665 .79642 m .68968 .77316 L .62178 .79556 L p .368 .003 .206 r
F P
0 g
s
.69837 .74529 m .68968 .77316 L .74324 .73961 L p .217 0 .259 r
F P
0 g
s
.74324 .73961 m .75504 .70925 L .69837 .74529 L p .217 0 .259 r
F P
0 g
s
.41956 .3324 m .45425 .33541 L .47599 .32149 L p .703 .887 .965 r
F P
0 g
s
.45425 .33541 m .41956 .3324 L .40014 .35866 L p .758 .873 .931 r
F P
0 g
s
.36249 .37036 m .32892 .38808 L .32254 .43177 L p .877 .921 .852 r
F P
0 g
s
.29394 .46063 m .32254 .43177 L .32892 .38808 L p .919 .953 .797 r
F P
0 g
s
.36249 .37036 m .40014 .35866 L .41956 .3324 L p .79 .936 .926 r
F P
0 g
s
.27155 .49296 m .25602 .52789 L .27842 .57986 L p .98 .842 .633 r
F P
0 g
s
.27114 .61685 m .27842 .57986 L .25602 .52789 L p .999 .811 .515 r
F P
0 g
s
.69547 .38858 m .72973 .40978 L .7119 .3669 L p .244 .462 .872 r
F P
0 g
s
.7119 .3669 m .68003 .35265 L .69547 .38858 L p .244 .462 .872 r
F P
0 g
s
.58837 .32782 m .61841 .3211 L .58139 .30421 L p .458 .714 .979 r
F P
0 g
s
.58139 .30421 m .56332 .31651 L .58837 .32782 L p .458 .714 .979 r
F P
0 g
s
.32379 .72872 m .33411 .75773 L .39566 .78591 L p .849 .465 .321 r
F P
0 g
s
.406 .80798 m .39566 .78591 L .33411 .75773 L p .805 .345 .141 r
F P
0 g
s
.39566 .78591 m .406 .80798 L .47291 .8227 L p .735 .314 .247 r
F P
0 g
s
.77395 .51858 m .78882 .55451 L .79721 .50015 L p 0 .086 .602 r
F P
0 g
s
.79721 .50015 m .78141 .46631 L .77395 .51858 L p 0 .086 .602 r
F P
0 g
s
.4515 .31166 m .47599 .32149 L .50361 .31313 L p .624 .872 .989 r
F P
0 g
s
.47599 .32149 m .4515 .31166 L .41956 .3324 L p .703 .887 .965 r
F P
0 g
s
.64445 .34497 m .68003 .35265 L .64661 .3216 L p .308 .592 .944 r
F P
0 g
s
.64661 .3216 m .61841 .3211 L .64445 .34497 L p .308 .592 .944 r
F P
0 g
s
.54233 .84009 m .54435 .82567 L .47291 .8227 L p .574 .101 .095 r
F P
0 g
s
.54435 .82567 m .54233 .84009 L .60436 .83224 L p .443 0 .076 r
F P
0 g
s
.60436 .83224 m .61427 .81673 L .54435 .82567 L p .443 0 .076 r
F P
0 g
s
.56332 .31651 m .58139 .30421 L .53764 .29654 L p .481 .772 .995 r
F P
0 g
s
.53764 .29654 m .53391 .31139 L .56332 .31651 L p .481 .772 .995 r
F P
0 g
s
.32892 .38808 m .30046 .41144 L .29394 .46063 L p .919 .953 .797 r
F P
0 g
s
.27155 .49296 m .29394 .46063 L .30046 .41144 L p .945 .96 .697 r
F P
0 g
s
.76076 .67577 m .75504 .70925 L .79039 .66371 L p 0 0 .253 r
F P
0 g
s
.79039 .66371 m .79719 .62805 L .76076 .67577 L p 0 0 .253 r
F P
0 g
s
.27063 .65306 m .27695 .68756 L .32379 .72872 L p .942 .603 .352 r
F P
0 g
s
.33411 .75773 m .32379 .72872 L .27695 .68756 L p .903 .489 .159 r
F P
0 g
s
.49249 .29914 m .50361 .31313 L .53391 .31139 L p .541 .829 .998 r
F P
0 g
s
.50361 .31313 m .49249 .29914 L .4515 .31166 L p .624 .872 .989 r
F P
0 g
s
.47891 .83748 m .47291 .8227 L .406 .80798 L p .66 .155 .037 r
F P
0 g
s
.47291 .8227 m .47891 .83748 L .54233 .84009 L p .574 .101 .095 r
F P
0 g
s
.41956 .3324 m .38713 .33632 L .36249 .37036 L p .79 .936 .926 r
F P
0 g
s
.32892 .38808 m .36249 .37036 L .38713 .33632 L p .808 .988 .883 r
F P
0 g
s
.53391 .31139 m .53764 .29654 L .49249 .29914 L p .541 .829 .998 r
F P
0 g
s
.72973 .40978 m .75867 .43592 L .739 .38747 L p .037 .304 .794 r
F P
0 g
s
.739 .38747 m .7119 .3669 L .72973 .40978 L p .037 .304 .794 r
F P
0 g
s
.25602 .52789 m .24782 .56449 L .27114 .61685 L p .999 .811 .515 r
F P
0 g
s
.27063 .65306 m .27114 .61685 L .24782 .56449 L p .983 .735 .339 r
F P
0 g
s
.38713 .33632 m .41956 .3324 L .4515 .31166 L p .684 .95 .956 r
F P
0 g
s
.68968 .77316 m .67665 .79642 L .72557 .76609 L p .067 0 .038 r
F P
0 g
s
.72557 .76609 m .74324 .73961 L .68968 .77316 L p .067 0 .038 r
F P
0 g
s
.61427 .81673 m .60436 .83224 L .6595 .81444 L p .232 0 0 r
F P
0 g
s
.6595 .81444 m .67665 .79642 L .61427 .81673 L p .232 0 0 r
F P
0 g
s
.78882 .55451 m .79665 .59132 L .80556 .53651 L p 0 0 .425 r
F P
0 g
s
.80556 .53651 m .79721 .50015 L .78882 .55451 L p 0 0 .425 r
F P
0 g
s
.61841 .3211 m .64661 .3216 L .59845 .29949 L p .244 .637 .96 r
F P
0 g
s
.59845 .29949 m .58139 .30421 L .61841 .3211 L p .244 .637 .96 r
F P
0 g
s
.30046 .41144 m .27803 .43985 L .27155 .49296 L p .945 .96 .697 r
F P
0 g
s
.25602 .52789 m .27155 .49296 L .27803 .43985 L p .923 .912 .521 r
F P
0 g
s
.68003 .35265 m .7119 .3669 L .67204 .32958 L p .051 .443 .876 r
F P
0 g
s
.67204 .32958 m .64661 .3216 L .68003 .35265 L p .051 .443 .876 r
F P
0 g
s
.33411 .75773 m .34959 .78246 L .406 .80798 L p .805 .345 .141 r
F P
0 g
s
.41963 .82456 m .406 .80798 L .34959 .78246 L p .688 .144 0 r
F P
0 g
s
.406 .80798 m .41963 .82456 L .47891 .83748 L p .66 .155 .037 r
F P
0 g
s
.75504 .70925 m .74324 .73961 L .77638 .69734 L p 0 0 0 r
F P
0 g
s
.77638 .69734 m .79039 .66371 L .75504 .70925 L p 0 0 0 r
F P
0 g
s
.75867 .43592 m .78141 .46631 L .76042 .41389 L p 0 .068 .631 r
F P
0 g
s
.76042 .41389 m .739 .38747 L .75867 .43592 L p 0 .068 .631 r
F P
0 g
s
.38713 .33632 m .35798 .3473 L .32892 .38808 L p .808 .988 .883 r
F P
0 g
s
.30046 .41144 m .32892 .38808 L .35798 .3473 L p .775 .989 .756 r
F P
0 g
s
.24782 .56449 m .24725 .60175 L .27063 .65306 L p .983 .735 .339 r
F P
0 g
s
.27695 .68756 m .27063 .65306 L .24725 .60175 L p .895 .585 .086 r
F P
0 g
s
.27695 .68756 m .28999 .71947 L .33411 .75773 L p .903 .489 .159 r
F P
0 g
s
.34959 .78246 m .33411 .75773 L .28999 .71947 L p .784 .297 0 r
F P
0 g
s
.42845 .30925 m .4515 .31166 L .49249 .29914 L p .513 .896 .957 r
F P
0 g
s
.4515 .31166 m .42845 .30925 L .38713 .33632 L p .684 .95 .956 r
F P
0 g
s
.53985 .84816 m .54233 .84009 L .47891 .83748 L p .416 0 0 r
F P
0 g
s
.54233 .84009 m .53985 .84816 L .5922 .84157 L p .265 0 0 r
F P
0 g
s
.5922 .84157 m .60436 .83224 L .54233 .84009 L p .265 0 0 r
F P
0 g
s
.79665 .59132 m .79719 .62805 L .80614 .57434 L p 0 0 .164 r
F P
0 g
s
.80614 .57434 m .80556 .53651 L .79665 .59132 L p 0 0 .164 r
F P
0 g
s
.58139 .30421 m .59845 .29949 L .54117 .2894 L p .246 .704 .951 r
F P
0 g
s
.54117 .2894 m .53764 .29654 L .58139 .30421 L p .246 .704 .951 r
F P
0 g
s
.35798 .3473 m .38713 .33632 L .42845 .30925 L p .584 .945 .843 r
F P
0 g
s
.48627 .84597 m .47891 .83748 L .41963 .82456 L p .482 0 0 r
F P
0 g
s
.47891 .83748 m .48627 .84597 L .53985 .84816 L p .416 0 0 r
F P
0 g
s
.67665 .79642 m .6595 .81444 L .70242 .78797 L p 0 0 0 r
F P
0 g
s
.70242 .78797 m .72557 .76609 L .67665 .79642 L p 0 0 0 r
F P
0 g
s
.48198 .29283 m .49249 .29914 L .53764 .29654 L p .343 .797 .946 r
F P
0 g
s
.49249 .29914 m .48198 .29283 L .42845 .30925 L p .513 .896 .957 r
F P
0 g
s
.27803 .43985 m .2624 .47257 L .25602 .52789 L p .923 .912 .521 r
F P
0 g
s
.24782 .56449 m .25602 .52789 L .2624 .47257 L p .808 .763 .25 r
F P
0 g
s
.53764 .29654 m .54117 .2894 L .48198 .29283 L p .343 .797 .946 r
F P
0 g
s
.60436 .83224 m .5922 .84157 L .63853 .82667 L p .003 0 0 r
F P
0 g
s
.63853 .82667 m .6595 .81444 L .60436 .83224 L p .003 0 0 r
F P
0 g
s
.7119 .3669 m .739 .38747 L .69381 .34504 L p 0 .175 .664 r
F P
0 g
s
.69381 .34504 m .67204 .32958 L .7119 .3669 L p 0 .175 .664 r
F P
0 g
s
.78141 .46631 m .79721 .50015 L .77538 .44544 L p 0 0 .353 r
F P
0 g
s
.77538 .44544 m .76042 .41389 L .78141 .46631 L p 0 0 .353 r
F P
0 g
s
.74324 .73961 m .72557 .76609 L .7555 .72803 L p 0 0 0 r
F P
0 g
s
.7555 .72803 m .77638 .69734 L .74324 .73961 L p 0 0 0 r
F P
0 g
s
.35798 .3473 m .3331 .36522 L .30046 .41144 L p .775 .989 .756 r
F P
0 g
s
.27803 .43985 m .30046 .41144 L .3331 .36522 L p .632 .861 .491 r
F P
0 g
s
.24725 .60175 m .25437 .63865 L .27695 .68756 L p .895 .585 .086 r
F P
0 g
s
.28999 .71947 m .27695 .68756 L .25437 .63865 L p .698 .343 0 r
F P
0 g
s
.64661 .3216 m .67204 .32958 L .61391 .30283 L p 0 .422 .785 r
F P
0 g
s
.61391 .30283 m .59845 .29949 L .64661 .3216 L p 0 .422 .785 r
F P
0 g
s
.34959 .78246 m .36993 .80224 L .41963 .82456 L p .688 .144 0 r
F P
0 g
s
.43632 .83514 m .41963 .82456 L .36993 .80224 L p .434 0 0 r
F P
0 g
s
.41963 .82456 m .43632 .83514 L .48627 .84597 L p .482 0 0 r
F P
0 g
s
.28999 .71947 m .30947 .74793 L .34959 .78246 L p .784 .297 0 r
F P
0 g
s
.36993 .80224 m .34959 .78246 L .30947 .74793 L p .54 .015 0 r
F P
0 g
s
.79719 .62805 m .79039 .66371 L .79889 .61254 L p .721 .692 .153 r
F P
0 g
s
.79889 .61254 m .80614 .57434 L .79719 .62805 L p .721 .692 .153 r
F P
0 g
s
.4076 .31466 m .42845 .30925 L .48198 .29283 L p .247 .754 .721 r
F P
0 g
s
.42845 .30925 m .4076 .31466 L .35798 .3473 L p .584 .945 .843 r
F P
0 g
s
.2624 .47257 m .25414 .50865 L .24782 .56449 L p .808 .763 .25 r
F P
0 g
s
.24725 .60175 m .24782 .56449 L .25414 .50865 L p 0 0 .077 r
F P
0 g
s
.3331 .36522 m .35798 .3473 L .4076 .31466 L p 0 0 0 r
F P
0 g
s
.6595 .81444 m .63853 .82667 L .67426 .80462 L p .391 .813 .629 r
F P
0 g
s
.67426 .80462 m .70242 .78797 L .6595 .81444 L p .391 .813 .629 r
F P
0 g
s
.53694 .84948 m .53985 .84816 L .48627 .84597 L p .108 0 0 r
F P
0 g
s
.53985 .84816 m .53694 .84948 L .57802 .84431 L p 0 0 0 r
F P
0 g
s
.57802 .84431 m .5922 .84157 L .53985 .84816 L p 0 0 0 r
F P
0 g
s
.79721 .50015 m .80556 .53651 L .7833 .48123 L p .837 .526 0 r
F P
0 g
s
.7833 .48123 m .77538 .44544 L .79721 .50015 L p .837 .526 0 r
F P
0 g
s
.48627 .84597 m .49487 .84776 L .53694 .84948 L p .108 0 0 r
F P
0 g
s
.49487 .84776 m .48627 .84597 L .43632 .83514 L p 0 .445 .695 r
F P
0 g
s
.59845 .29949 m .61391 .30283 L .54437 .29059 L p .154 0 0 r
F P
0 g
s
.54437 .29059 m .54117 .2894 L .59845 .29949 L p .154 0 0 r
F P
0 g
s
.25437 .63865 m .26901 .67414 L .28999 .71947 L p .698 .343 0 r
F P
0 g
s
.30947 .74793 m .28999 .71947 L .26901 .67414 L p 0 0 .526 r
F P
0 g
s
.739 .38747 m .76042 .41389 L .7111 .36773 L p .671 .164 0 r
F P
0 g
s
.7111 .36773 m .69381 .34504 L .739 .38747 L p .671 .164 0 r
F P
0 g
s
.72557 .76609 m .70242 .78797 L .72826 .75493 L p .662 .924 .625 r
F P
0 g
s
.72826 .75493 m .7555 .72803 L .72557 .76609 L p .662 .924 .625 r
F P
0 g
s
.3331 .36522 m .31338 .38971 L .27803 .43985 L p .632 .861 .491 r
F P
0 g
s
.2624 .47257 m .27803 .43985 L .31338 .38971 L p 0 0 0 r
F P
0 g
s
.5922 .84157 m .57802 .84431 L .61417 .83267 L p .287 .783 .756 r
F P
0 g
s
.61417 .83267 m .63853 .82667 L .5922 .84157 L p .287 .783 .756 r
F P
0 g
s
.48198 .29283 m .47244 .29475 L .4076 .31466 L p .247 .754 .721 r
F P
0 g
s
.47244 .29475 m .48198 .29283 L .54117 .2894 L p .025 0 0 r
F P
0 g
s
.79039 .66371 m .77638 .69734 L .78399 .65 L p .871 .88 .444 r
F P
0 g
s
.78399 .65 m .79889 .61254 L .79039 .66371 L p .871 .88 .444 r
F P
0 g
s
.54117 .2894 m .54437 .29059 L .47244 .29475 L p .025 0 0 r
F P
0 g
s
.30947 .74793 m .33495 .77218 L .36993 .80224 L p .54 .015 0 r
F P
0 g
s
.36993 .80224 m .39472 .8165 L .43632 .83514 L p .434 0 0 r
F P
0 g
s
.39472 .8165 m .36993 .80224 L .33495 .77218 L p 0 .285 .746 r
F P
0 g
s
.67204 .32958 m .69381 .34504 L .6272 .31448 L p .52 0 0 r
F P
0 g
s
.6272 .31448 m .61391 .30283 L .67204 .32958 L p .52 0 0 r
F P
0 g
s
.25414 .50865 m .25356 .54704 L .24725 .60175 L p 0 0 .077 r
F P
0 g
s
.25437 .63865 m .24725 .60175 L .25356 .54704 L p 0 0 .366 r
F P
0 g
s
.45577 .83928 m .43632 .83514 L .39472 .8165 L p 0 .468 .82 r
F P
0 g
s
.43632 .83514 m .45577 .83928 L .49487 .84776 L p 0 .445 .695 r
F P
0 g
s
.80556 .53651 m .80614 .57434 L .78386 .52016 L p .967 .716 .284 r
F P
0 g
s
.78386 .52016 m .7833 .48123 L .80556 .53651 L p .967 .716 .284 r
F P
0 g
s
.4076 .31466 m .38971 .32801 L .3331 .36522 L p 0 0 0 r
F P
0 g
s
.31338 .38971 m .3331 .36522 L .38971 .32801 L p 0 0 0 r
F P
0 g
s
.63853 .82667 m .61417 .83267 L .64176 .81554 L p .565 .937 .874 r
F P
0 g
s
.64176 .81554 m .67426 .80462 L .63853 .82667 L p .565 .937 .874 r
F P
0 g
s
.38971 .32801 m .4076 .31466 L .47244 .29475 L p .098 0 0 r
F P
0 g
s
.26901 .67414 m .2908 .70721 L .30947 .74793 L p 0 0 .526 r
F P
0 g
s
.33495 .77218 m .30947 .74793 L .2908 .70721 L p 0 .208 .734 r
F P
0 g
s
.31338 .38971 m .29958 .42014 L .2624 .47257 L p 0 0 0 r
F P
0 g
s
.25414 .50865 m .2624 .47257 L .29958 .42014 L p 0 0 .185 r
F P
0 g
s
.70242 .78797 m .67426 .80462 L .69537 .77728 L p .744 .993 .822 r
F P
0 g
s
.69537 .77728 m .72826 .75493 L .70242 .78797 L p .744 .993 .822 r
F P
0 g
s
.77638 .69734 m .7555 .72803 L .76187 .68561 L p .922 .963 .651 r
F P
0 g
s
.76187 .68561 m .78399 .65 L .77638 .69734 L p .922 .963 .651 r
F P
0 g
s
.76042 .41389 m .77538 .44544 L .72322 .3971 L p .87 .428 .059 r
F P
0 g
s
.72322 .3971 m .7111 .36773 L .76042 .41389 L p .87 .428 .059 r
F P
0 g
s
.53368 .84374 m .53694 .84948 L .49487 .84776 L p .257 .74 .928 r
F P
0 g
s
.53694 .84948 m .53368 .84374 L .56207 .84016 L p .357 .814 .934 r
F P
0 g
s
.56207 .84016 m .57802 .84431 L .53694 .84948 L p .357 .814 .934 r
F P
0 g
s
.50455 .84255 m .49487 .84776 L .45577 .83928 L p .225 .69 .945 r
F P
0 g
s
.49487 .84776 m .50455 .84255 L .53368 .84374 L p .257 .74 .928 r
F P
0 g
s
.25356 .54704 m .26074 .58657 L .25437 .63865 L p 0 0 .366 r
F P
0 g
s
.26901 .67414 m .25437 .63865 L .26074 .58657 L p 0 .029 .57 r
F P
0 g
s
.61391 .30283 m .6272 .31448 L .54713 .30046 L p .503 0 0 r
F P
0 g
s
.54713 .30046 m .54437 .29059 L .61391 .30283 L p .503 0 0 r
F P
0 g
s
.33495 .77218 m .36582 .79153 L .39472 .8165 L p 0 .285 .746 r
F P
0 g
s
.42345 .82475 m .39472 .8165 L .36582 .79153 L p .107 .509 .907 r
F P
0 g
s
.39472 .8165 m .42345 .82475 L .45577 .83928 L p 0 .468 .82 r
F P
0 g
s
.57802 .84431 m .56207 .84016 L .58692 .8321 L p .499 .889 .957 r
F P
0 g
s
.58692 .8321 m .61417 .83267 L .57802 .84431 L p .499 .889 .957 r
F P
0 g
s
.69381 .34504 m .7111 .36773 L .63781 .33437 L p .744 .235 .003 r
F P
0 g
s
.63781 .33437 m .6272 .31448 L .69381 .34504 L p .744 .235 .003 r
F P
0 g
s
.80614 .57434 m .79889 .61254 L .77697 .56102 L p 1 .812 .489 r
F P
0 g
s
.77697 .56102 m .78386 .52016 L .80614 .57434 L p 1 .812 .489 r
F P
0 g
s
.46422 .30523 m .47244 .29475 L .54437 .29059 L p .363 0 0 r
F P
0 g
s
.47244 .29475 m .46422 .30523 L .38971 .32801 L p .098 0 0 r
F P
0 g
s
.47758 .83667 m .45577 .83928 L .42345 .82475 L p .259 .661 .966 r
F P
0 g
s
.45577 .83928 m .47758 .83667 L .50455 .84255 L p .225 .69 .945 r
F P
0 g
s
.2908 .70721 m .31913 .73694 L .33495 .77218 L p 0 .208 .734 r
F P
0 g
s
.36582 .79153 m .33495 .77218 L .31913 .73694 L p .108 .4 .854 r
F P
0 g
s
.54437 .29059 m .54713 .30046 L .46422 .30523 L p .363 0 0 r
F P
0 g
s
.7555 .72803 m .72826 .75493 L .73318 .71833 L p .911 .978 .779 r
F P
0 g
s
.73318 .71833 m .76187 .68561 L .7555 .72803 L p .911 .978 .779 r
F P
0 g
s
.29958 .42014 m .29226 .45563 L .25414 .50865 L p 0 0 .185 r
F P
0 g
s
.25356 .54704 m .25414 .50865 L .29226 .45563 L p .067 0 .403 r
F P
0 g
s
.67426 .80462 m .64176 .81554 L .65767 .79445 L p .754 .977 .919 r
F P
0 g
s
.65767 .79445 m .69537 .77728 L .67426 .80462 L p .754 .977 .919 r
F P
0 g
s
.38971 .32801 m .37547 .34915 L .31338 .38971 L p 0 0 0 r
F P
0 g
s
.29958 .42014 m .31338 .38971 L .37547 .34915 L p .173 0 .183 r
F P
0 g
s
.61417 .83267 m .58692 .8321 L .60566 .82032 L p .637 .932 .969 r
F P
0 g
s
.60566 .82032 m .64176 .81554 L .61417 .83267 L p .637 .932 .969 r
F P
0 g
s
.77538 .44544 m .7833 .48123 L .72966 .4323 L p .937 .579 .307 r
F P
0 g
s
.72966 .4323 m .72322 .3971 L .77538 .44544 L p .937 .579 .307 r
F P
0 g
s
.26074 .58657 m .27548 .62603 L .26901 .67414 L p 0 .029 .57 r
F P
0 g
s
.2908 .70721 m .26901 .67414 L .27548 .62603 L p .091 .216 .702 r
F P
0 g
s
.37547 .34915 m .38971 .32801 L .46422 .30523 L p .329 0 .082 r
F P
0 g
s
.36582 .79153 m .40133 .80542 L .42345 .82475 L p .107 .509 .907 r
F P
0 g
s
.45547 .82664 m .42345 .82475 L .40133 .80542 L p .332 .642 .966 r
F P
0 g
s
.42345 .82475 m .45547 .82664 L .47758 .83667 L p .259 .661 .966 r
F P
0 g
s
.79889 .61254 m .78399 .65 L .76286 .60249 L p .986 .854 .624 r
F P
0 g
s
.76286 .60249 m .77697 .56102 L .79889 .61254 L p .986 .854 .624 r
F P
0 g
s
.53011 .83079 m .53368 .84374 L .50455 .84255 L p .489 .808 1 r
F P
0 g
s
.53368 .84374 m .53011 .83079 L .54471 .82893 L p .535 .841 .999 r
F P
0 g
s
.54471 .82893 m .56207 .84016 L .53368 .84374 L p .535 .841 .999 r
F P
0 g
s
.51511 .83017 m .50455 .84255 L .47758 .83667 L p .465 .774 .997 r
F P
0 g
s
.50455 .84255 m .51511 .83017 L .53011 .83079 L p .489 .808 1 r
F P
0 g
s
.72826 .75493 m .69537 .77728 L .6988 .74722 L p .874 .96 .855 r
F P
0 g
s
.6988 .74722 m .73318 .71833 L .72826 .75493 L p .874 .96 .855 r
F P
0 g
s
.31913 .73694 m .35321 .76247 L .36582 .79153 L p .108 .4 .854 r
F P
0 g
s
.40133 .80542 m .36582 .79153 L .35321 .76247 L p .283 .535 .914 r
F P
0 g
s
.56207 .84016 m .54471 .82893 L .5574 .82477 L p .594 .865 .994 r
F P
0 g
s
.5574 .82477 m .58692 .8321 L .56207 .84016 L p .594 .865 .994 r
F P
0 g
s
.6272 .31448 m .63781 .33437 L .54933 .31902 L p .664 .195 .129 r
F P
0 g
s
.54933 .31902 m .54713 .30046 L .6272 .31448 L p .664 .195 .129 r
F P
0 g
s
.29226 .45563 m .29175 .49508 L .25356 .54704 L p .067 0 .403 r
F P
0 g
s
.26074 .58657 m .25356 .54704 L .29175 .49508 L p .201 .128 .546 r
F P
0 g
s
.27548 .62603 m .29731 .66421 L .2908 .70721 L p .091 .216 .702 r
F P
0 g
s
.31913 .73694 m .2908 .70721 L .29731 .66421 L p .227 .356 .786 r
F P
0 g
s
.7111 .36773 m .72322 .3971 L .64526 .36206 L p .825 .41 .258 r
F P
0 g
s
.64526 .36206 m .63781 .33437 L .7111 .36773 L p .825 .41 .258 r
F P
0 g
s
.64176 .81554 m .60566 .82032 L .61618 .80594 L p .731 .927 .956 r
F P
0 g
s
.61618 .80594 m .65767 .79445 L .64176 .81554 L p .731 .927 .956 r
F P
0 g
s
.50128 .82713 m .47758 .83667 L .45547 .82664 L p .465 .743 .989 r
F P
0 g
s
.47758 .83667 m .50128 .82713 L .51511 .83017 L p .465 .774 .997 r
F P
0 g
s
.7833 .48123 m .78386 .52016 L .73011 .47221 L p .946 .66 .466 r
F P
0 g
s
.73011 .47221 m .72966 .4323 L .7833 .48123 L p .946 .66 .466 r
F P
0 g
s
.37547 .34915 m .36546 .3776 L .29958 .42014 L p .173 0 .183 r
F P
0 g
s
.29226 .45563 m .29958 .42014 L .36546 .3776 L p .306 .065 .375 r
F P
0 g
s
.45766 .32424 m .46422 .30523 L .54713 .30046 L p .533 .093 .15 r
F P
0 g
s
.46422 .30523 m .45766 .32424 L .37547 .34915 L p .329 0 .082 r
F P
0 g
s
.58692 .8321 m .5574 .82477 L .56685 .81872 L p .651 .874 .982 r
F P
0 g
s
.56685 .81872 m .60566 .82032 L .58692 .8321 L p .651 .874 .982 r
F P
0 g
s
.78399 .65 m .76187 .68561 L .742 .64326 L p .955 .869 .714 r
F P
0 g
s
.742 .64326 m .76286 .60249 L .78399 .65 L p .955 .869 .714 r
F P
0 g
s
.54713 .30046 m .54933 .31902 L .45766 .32424 L p .533 .093 .15 r
F P
0 g
s
.69537 .77728 m .65767 .79445 L .65973 .77148 L p .826 .927 .9 r
F P
0 g
s
.65973 .77148 m .6988 .74722 L .69537 .77728 L p .826 .927 .9 r
F P
0 g
s
.35321 .76247 m .39211 .78311 L .40133 .80542 L p .283 .535 .914 r
F P
0 g
s
.4406 .81341 m .40133 .80542 L .39211 .78311 L p .414 .629 .943 r
F P
0 g
s
.40133 .80542 m .4406 .81341 L .45547 .82664 L p .332 .642 .966 r
F P
0 g
s
.49005 .82196 m .45547 .82664 L .4406 .81341 L p .485 .717 .973 r
F P
0 g
s
.45547 .82664 m .49005 .82196 L .50128 .82713 L p .465 .743 .989 r
F P
0 g
s
.29731 .66421 m .32553 .69996 L .31913 .73694 L p .227 .356 .786 r
F P
0 g
s
.35321 .76247 m .31913 .73694 L .32553 .69996 L p .332 .464 .843 r
F P
0 g
s
.36546 .3776 m .37547 .34915 L .45766 .32424 L p .45 .113 .302 r
F P
0 g
s
.29175 .49508 m .29811 .53719 L .26074 .58657 L p .201 .128 .546 r
F P
0 g
s
.27548 .62603 m .26074 .58657 L .29811 .53719 L p .297 .256 .642 r
F P
0 g
s
.60566 .82032 m .56685 .81872 L .572 .8114 L p .694 .866 .963 r
F P
0 g
s
.572 .8114 m .61618 .80594 L .60566 .82032 L p .694 .866 .963 r
F P
0 g
s
.76187 .68561 m .73318 .71833 L .71512 .68203 L p .916 .87 .778 r
F P
0 g
s
.71512 .68203 m .742 .64326 L .76187 .68561 L p .916 .87 .778 r
F P
0 g
s
.52632 .81063 m .53011 .83079 L .51511 .83017 L closepath p .6 .791 .972 r
F P
0 g
s
.52632 .81063 m .54471 .82893 L .53011 .83079 L closepath p .612 .8 .971 r
F P
0 g
s
.52632 .81063 m .51511 .83017 L .50128 .82713 L closepath p .592 .781 .97 r
F P
0 g
s
.78386 .52016 m .77697 .56102 L .72452 .51549 L p .934 .707 .572 r
F P
0 g
s
.72452 .51549 m .73011 .47221 L .78386 .52016 L p .934 .707 .572 r
F P
0 g
s
.65767 .79445 m .61618 .80594 L .61714 .79043 L p .774 .888 .927 r
F P
0 g
s
.61714 .79043 m .65973 .77148 L .65767 .79445 L p .774 .888 .927 r
F P
0 g
s
.52632 .81063 m .5574 .82477 L .54471 .82893 L closepath p .627 .806 .968 r
F P
0 g
s
.72322 .3971 m .72966 .4323 L .64922 .39678 L p .847 .51 .415 r
F P
0 g
s
.64922 .39678 m .64526 .36206 L .72322 .3971 L p .847 .51 .415 r
F P
0 g
s
.52632 .81063 m .50128 .82713 L .49005 .82196 L closepath p .589 .77 .966 r
F P
0 g
s
.32553 .69996 m .35924 .73223 L .35321 .76247 L p .332 .464 .843 r
F P
0 g
s
.39211 .78311 m .35321 .76247 L .35924 .73223 L p .416 .55 .882 r
F P
0 g
s
.39211 .78311 m .43473 .79826 L .4406 .81341 L p .414 .629 .943 r
F P
0 g
s
.48263 .81519 m .4406 .81341 L .43473 .79826 L p .515 .699 .953 r
F P
0 g
s
.4406 .81341 m .48263 .81519 L .49005 .82196 L p .485 .717 .973 r
F P
0 g
s
.36546 .3776 m .36015 .41254 L .29226 .45563 L p .306 .065 .375 r
F P
0 g
s
.29175 .49508 m .29226 .45563 L .36015 .41254 L p .39 .2 .499 r
F P
0 g
s
.63781 .33437 m .64526 .36206 L .55088 .34592 L p .725 .344 .328 r
F P
0 g
s
.55088 .34592 m .54933 .31902 L .63781 .33437 L p .725 .344 .328 r
F P
0 g
s
.52632 .81063 m .56685 .81872 L .5574 .82477 L closepath p .641 .807 .963 r
F P
0 g
s
.29811 .53719 m .31113 .58058 L .27548 .62603 L p .297 .256 .642 r
F P
0 g
s
.29731 .66421 m .27548 .62603 L .31113 .58058 L p .368 .354 .712 r
F P
0 g
s
.52632 .81063 m .49005 .82196 L .48263 .81519 L closepath p .591 .76 .96 r
F P
0 g
s
.73318 .71833 m .6988 .74722 L .68312 .71765 L p .874 .864 .826 r
F P
0 g
s
.68312 .71765 m .71512 .68203 L .73318 .71833 L p .874 .864 .826 r
F P
0 g
s
.61618 .80594 m .572 .8114 L .57224 .80358 L p .72 .845 .941 r
F P
0 g
s
.57224 .80358 m .61714 .79043 L .61618 .80594 L p .72 .845 .941 r
F P
0 g
s
.52632 .81063 m .572 .8114 L .56685 .81872 L closepath p .653 .805 .956 r
F P
0 g
s
.45304 .35141 m .45766 .32424 L .54933 .31902 L p .609 .252 .339 r
F P
0 g
s
.45766 .32424 m .45304 .35141 L .36546 .3776 L p .45 .113 .302 r
F P
0 g
s
.35924 .73223 m .39737 .76009 L .39211 .78311 L p .416 .55 .882 r
F P
0 g
s
.43473 .79826 m .39211 .78311 L .39737 .76009 L p .487 .623 .91 r
F P
0 g
s
.43473 .79826 m .47988 .80752 L .48263 .81519 L p .515 .699 .953 r
F P
0 g
s
.52632 .81063 m .48263 .81519 L .47988 .80752 L closepath p .596 .752 .952 r
F P
0 g
s
.77697 .56102 m .76286 .60249 L .71307 .56064 L p .914 .736 .648 r
F P
0 g
s
.71307 .56064 m .72452 .51549 L .77697 .56102 L p .914 .736 .648 r
F P
0 g
s
.54933 .31902 m .55088 .34592 L .45304 .35141 L p .609 .252 .339 r
F P
0 g
s
.36015 .41254 m .36546 .3776 L .45304 .35141 L p .516 .242 .437 r
F P
0 g
s
.6988 .74722 m .65973 .77148 L .64706 .74907 L p .83 .853 .864 r
F P
0 g
s
.64706 .74907 m .68312 .71765 L .6988 .74722 L p .83 .853 .864 r
F P
0 g
s
.31113 .58058 m .33033 .62379 L .29731 .66421 L p .368 .354 .712 r
F P
0 g
s
.32553 .69996 m .29731 .66421 L .33033 .62379 L p .425 .434 .766 r
F P
0 g
s
.39737 .76009 m .43875 .78279 L .43473 .79826 L p .487 .623 .91 r
F P
0 g
s
.47988 .80752 m .43473 .79826 L .43875 .78279 L p .549 .687 .93 r
F P
0 g
s
.52632 .81063 m .57224 .80358 L .572 .8114 L closepath p .662 .799 .948 r
F P
0 g
s
.36015 .41254 m .35978 .45284 L .29175 .49508 L p .39 .2 .499 r
F P
0 g
s
.29811 .53719 m .29175 .49508 L .35978 .45284 L p .446 .297 .584 r
F P
0 g
s
.72966 .4323 m .73011 .47221 L .6495 .43739 L p .849 .571 .517 r
F P
0 g
s
.6495 .43739 m .64922 .39678 L .72966 .4323 L p .849 .571 .517 r
F P
0 g
s
.43875 .78279 m .48215 .79977 L .47988 .80752 L p .549 .687 .93 r
F P
0 g
s
.52632 .81063 m .47988 .80752 L .48215 .79977 L closepath p .605 .746 .944 r
F P
0 g
s
.65973 .77148 m .61714 .79043 L .60812 .77544 L p .782 .837 .894 r
F P
0 g
s
.60812 .77544 m .64706 .74907 L .65973 .77148 L p .782 .837 .894 r
F P
0 g
s
.52632 .81063 m .55814 .78982 L .56747 .79611 L closepath p .668 .781 .934 r
F P
0 g
s
.52632 .81063 m .54524 .78543 L .55814 .78982 L closepath p .665 .771 .928 r
F P
0 g
s
.52632 .81063 m .5302 .78345 L .54524 .78543 L closepath p .659 .761 .925 r
F P
0 g
s
.52632 .81063 m .51471 .78412 L .5302 .78345 L closepath p .65 .753 .925 r
F P
0 g
s
.52632 .81063 m .50055 .78736 L .51471 .78412 L closepath p .64 .747 .927 r
F P
0 g
s
.52632 .81063 m .48928 .79279 L .50055 .78736 L closepath p .628 .744 .931 r
F P
0 g
s
.52632 .81063 m .48215 .79977 L .48928 .79279 L closepath p .616 .744 .937 r
F P
0 g
s
.52632 .81063 m .56747 .79611 L .57224 .80358 L closepath p .667 .791 .94 r
F P
0 g
s
.61714 .79043 m .57224 .80358 L .56747 .79611 L p .729 .817 .92 r
F P
0 g
s
.56747 .79611 m .60812 .77544 L .61714 .79043 L p .729 .817 .92 r
F P
0 g
s
.33033 .62379 m .35502 .66543 L .32553 .69996 L p .425 .434 .766 r
F P
0 g
s
.35924 .73223 m .32553 .69996 L .35502 .66543 L p .471 .503 .81 r
F P
0 g
s
.76286 .60249 m .742 .64326 L .69623 .60613 L p .89 .755 .706 r
F P
0 g
s
.69623 .60613 m .71307 .56064 L .76286 .60249 L p .89 .755 .706 r
F P
0 g
s
.64526 .36206 m .64922 .39678 L .55171 .3804 L p .749 .434 .45 r
F P
0 g
s
.55171 .3804 m .55088 .34592 L .64526 .36206 L p .749 .434 .45 r
F P
0 g
s
.45254 .76872 m .48928 .79279 L .48215 .79977 L p .583 .684 .91 r
F P
0 g
s
.48215 .79977 m .43875 .78279 L .45254 .76872 L p .583 .684 .91 r
F P
0 g
s
.35502 .66543 m .38431 .7042 L .35924 .73223 L p .471 .503 .81 r
F P
0 g
s
.39737 .76009 m .35924 .73223 L .38431 .7042 L p .512 .566 .847 r
F P
0 g
s
.41718 .73894 m .45254 .76872 L .43875 .78279 L p .549 .625 .88 r
F P
0 g
s
.43875 .78279 m .39737 .76009 L .41718 .73894 L p .549 .625 .88 r
F P
0 g
s
.60812 .77544 m .56747 .79611 L .55814 .78982 L p .725 .787 .901 r
F P
0 g
s
.38431 .7042 m .41718 .73894 L .39737 .76009 L p .512 .566 .847 r
F P
0 g
s
.35978 .45284 m .3644 .49711 L .29811 .53719 L p .446 .297 .584 r
F P
0 g
s
.31113 .58058 m .29811 .53719 L .3644 .49711 L p .486 .372 .648 r
F P
0 g
s
.45059 .38598 m .45304 .35141 L .55088 .34592 L p .646 .351 .456 r
F P
0 g
s
.45304 .35141 m .45059 .38598 L .36015 .41254 L p .516 .242 .437 r
F P
0 g
s
.742 .64326 m .71512 .68203 L .67462 .65041 L p .865 .768 .754 r
F P
0 g
s
.67462 .65041 m .69623 .60613 L .742 .64326 L p .865 .768 .754 r
F P
0 g
s
.47479 .75769 m .50055 .78736 L .48928 .79279 L p .616 .687 .894 r
F P
0 g
s
.48928 .79279 m .45254 .76872 L .47479 .75769 L p .616 .687 .894 r
F P
0 g
s
.35978 .45284 m .36015 .41254 L .45059 .38598 L p .556 .33 .528 r
F P
0 g
s
.73011 .47221 m .72452 .51549 L .64605 .48247 L p .843 .613 .591 r
F P
0 g
s
.64605 .48247 m .6495 .43739 L .73011 .47221 L p .843 .613 .591 r
F P
0 g
s
.55814 .78982 m .58984 .7627 L .60812 .77544 L p .725 .787 .901 r
F P
0 g
s
.58984 .7627 m .55814 .78982 L .54524 .78543 L p .713 .758 .888 r
F P
0 g
s
.55088 .34592 m .55171 .3804 L .45059 .38598 L p .646 .351 .456 r
F P
0 g
s
.64706 .74907 m .60812 .77544 L .58984 .7627 L p .77 .787 .867 r
F P
0 g
s
.50306 .75107 m .51471 .78412 L .50055 .78736 L p .646 .697 .883 r
F P
0 g
s
.50055 .78736 m .47479 .75769 L .50306 .75107 L p .646 .697 .883 r
F P
0 g
s
.71512 .68203 m .68312 .71765 L .64906 .69207 L p .837 .778 .795 r
F P
0 g
s
.64906 .69207 m .67462 .65041 L .71512 .68203 L p .837 .778 .795 r
F P
0 g
s
.54524 .78543 m .5642 .75375 L .58984 .7627 L p .713 .758 .888 r
F P
0 g
s
.5642 .75375 m .54524 .78543 L .5302 .78345 L p .695 .733 .88 r
F P
0 g
s
.68312 .71765 m .64706 .74907 L .62048 .72985 L p .806 .784 .832 r
F P
0 g
s
.58984 .7627 m .62048 .72985 L .64706 .74907 L p .77 .787 .867 r
F P
0 g
s
.62048 .72985 m .64906 .69207 L .68312 .71765 L p .806 .784 .832 r
F P
0 g
s
.5341 .74969 m .5302 .78345 L .51471 .78412 L p .672 .712 .879 r
F P
0 g
s
.51471 .78412 m .50306 .75107 L .5341 .74969 L p .672 .712 .879 r
F P
0 g
s
.5302 .78345 m .5341 .74969 L .5642 .75375 L p .695 .733 .88 r
F P
0 g
s
.3644 .49711 m .37384 .54379 L .31113 .58058 L p .486 .372 .648 r
F P
0 g
s
.33033 .62379 m .31113 .58058 L .37384 .54379 L p .517 .433 .7 r
F P
0 g
s
.44982 .72224 m .47479 .75769 L .45254 .76872 L p .601 .635 .857 r
F P
0 g
s
.45254 .76872 m .41718 .73894 L .44982 .72224 L p .601 .635 .857 r
F P
0 g
s
.64922 .39678 m .6495 .43739 L .55177 .42133 L p .758 .494 .534 r
F P
0 g
s
.55177 .42133 m .55171 .3804 L .64922 .39678 L p .758 .494 .534 r
F P
0 g
s
.62048 .72985 m .58984 .7627 L .5642 .75375 L p .747 .743 .849 r
F P
0 g
s
.72452 .51549 m .71307 .56064 L .63902 .53038 L p .833 .645 .647 r
F P
0 g
s
.63902 .53038 m .64605 .48247 L .72452 .51549 L p .833 .645 .647 r
F P
0 g
s
.37384 .54379 m .38772 .59122 L .33033 .62379 L p .517 .433 .7 r
F P
0 g
s
.35502 .66543 m .33033 .62379 L .38772 .59122 L p .543 .488 .744 r
F P
0 g
s
.42644 .68189 m .44982 .72224 L .41718 .73894 L p .584 .586 .82 r
F P
0 g
s
.41718 .73894 m .38431 .7042 L .42644 .68189 L p .584 .586 .82 r
F P
0 g
s
.45059 .38598 m .45041 .4268 L .35978 .45284 L p .556 .33 .528 r
F P
0 g
s
.3644 .49711 m .35978 .45284 L .45041 .4268 L p .582 .395 .594 r
F P
0 g
s
.38772 .59122 m .40548 .63777 L .35502 .66543 L p .543 .488 .744 r
F P
0 g
s
.38431 .7042 m .35502 .66543 L .40548 .63777 L p .565 .537 .783 r
F P
0 g
s
.49172 .71215 m .50306 .75107 L .47479 .75769 L p .645 .652 .842 r
F P
0 g
s
.47479 .75769 m .44982 .72224 L .49172 .71215 L p .645 .652 .842 r
F P
0 g
s
.40548 .63777 m .42644 .68189 L .38431 .7042 L p .565 .537 .783 r
F P
0 g
s
.45041 .4268 m .45059 .38598 L .55171 .3804 L p .666 .419 .536 r
F P
0 g
s
.5642 .75375 m .58264 .71624 L .62048 .72985 L p .747 .743 .849 r
F P
0 g
s
.58264 .71624 m .5642 .75375 L .5341 .74969 L p .717 .706 .838 r
F P
0 g
s
.55171 .3804 m .55177 .42133 L .45041 .4268 L p .666 .419 .536 r
F P
0 g
s
.64906 .69207 m .62048 .72985 L .58264 .71624 L p .772 .727 .811 r
F P
0 g
s
.71307 .56064 m .69623 .60613 L .62868 .57938 L p .821 .669 .694 r
F P
0 g
s
.62868 .57938 m .63902 .53038 L .71307 .56064 L p .821 .669 .694 r
F P
0 g
s
.5379 .71006 m .5341 .74969 L .50306 .75107 L p .683 .676 .836 r
F P
0 g
s
.50306 .75107 m .49172 .71215 L .5379 .71006 L p .683 .676 .836 r
F P
0 g
s
.5341 .74969 m .5379 .71006 L .58264 .71624 L p .717 .706 .838 r
F P
0 g
s
.6495 .43739 m .64605 .48247 L .55105 .46725 L p .761 .538 .595 r
F P
0 g
s
.55105 .46725 m .55177 .42133 L .6495 .43739 L p .761 .538 .595 r
F P
0 g
s
.45041 .4268 m .45255 .47243 L .3644 .49711 L p .582 .395 .594 r
F P
0 g
s
.37384 .54379 m .3644 .49711 L .45255 .47243 L p .601 .448 .646 r
F P
0 g
s
.67462 .65041 m .64906 .69207 L .59994 .67384 L p .791 .709 .774 r
F P
0 g
s
.58264 .71624 m .59994 .67384 L .64906 .69207 L p .772 .727 .811 r
F P
0 g
s
.69623 .60613 m .67462 .65041 L .61548 .62774 L p .808 .691 .736 r
F P
0 g
s
.61548 .62774 m .62868 .57938 L .69623 .60613 L p .808 .691 .736 r
F P
0 g
s
.48106 .66835 m .49172 .71215 L .44982 .72224 L p .641 .611 .804 r
F P
0 g
s
.44982 .72224 m .42644 .68189 L .48106 .66835 L p .641 .611 .804 r
F P
0 g
s
.59994 .67384 m .61548 .62774 L .67462 .65041 L p .791 .709 .774 r
F P
0 g
s
.45255 .47243 m .45041 .4268 L .55177 .42133 L p .678 .47 .596 r
F P
0 g
s
.59994 .67384 m .58264 .71624 L .5379 .71006 L p .732 .68 .8 r
F P
0 g
s
.45255 .47243 m .45691 .52119 L .37384 .54379 L p .601 .448 .646 r
F P
0 g
s
.38772 .59122 m .37384 .54379 L .45691 .52119 L p .615 .493 .69 r
F P
0 g
s
.47146 .62089 m .48106 .66835 L .42644 .68189 L p .634 .572 .767 r
F P
0 g
s
.42644 .68189 m .40548 .63777 L .47146 .62089 L p .634 .572 .767 r
F P
0 g
s
.54147 .66552 m .5379 .71006 L .49172 .71215 L p .689 .642 .798 r
F P
0 g
s
.49172 .71215 m .48106 .66835 L .54147 .66552 L p .689 .642 .798 r
F P
0 g
s
.55177 .42133 m .55105 .46725 L .45255 .47243 L p .678 .47 .596 r
F P
0 g
s
.64605 .48247 m .63902 .53038 L .54959 .51645 L p .759 .573 .645 r
F P
0 g
s
.54959 .51645 m .55105 .46725 L .64605 .48247 L p .759 .573 .645 r
F P
0 g
s
.5379 .71006 m .54147 .66552 L .59994 .67384 L p .732 .68 .8 r
F P
0 g
s
.45691 .52119 m .4633 .57127 L .38772 .59122 L p .615 .493 .69 r
F P
0 g
s
.40548 .63777 m .38772 .59122 L .4633 .57127 L p .626 .533 .73 r
F P
0 g
s
.4633 .57127 m .47146 .62089 L .40548 .63777 L p .626 .533 .73 r
F P
0 g
s
.61548 .62774 m .59994 .67384 L .54147 .66552 L p .743 .655 .763 r
F P
0 g
s
.45691 .52119 m .45255 .47243 L .55105 .46725 L p .685 .511 .644 r
F P
0 g
s
.63902 .53038 m .62868 .57938 L .54744 .56709 L p .756 .603 .687 r
F P
0 g
s
.54744 .56709 m .54959 .51645 L .63902 .53038 L p .756 .603 .687 r
F P
0 g
s
.54469 .61736 m .54147 .66552 L .48106 .66835 L p .692 .61 .761 r
F P
0 g
s
.48106 .66835 m .47146 .62089 L .54469 .61736 L p .692 .61 .761 r
F P
0 g
s
.62868 .57938 m .61548 .62774 L .54469 .61736 L p .751 .63 .726 r
F P
0 g
s
.54147 .66552 m .54469 .61736 L .61548 .62774 L p .743 .655 .763 r
F P
0 g
s
.54469 .61736 m .54744 .56709 L .62868 .57938 L p .751 .63 .726 r
F P
0 g
s
.55105 .46725 m .54959 .51645 L .45691 .52119 L p .685 .511 .644 r
F P
0 g
s
.4633 .57127 m .45691 .52119 L .54959 .51645 L p .69 .546 .686 r
F P
0 g
s
.54744 .56709 m .54469 .61736 L .47146 .62089 L p .692 .579 .724 r
F P
0 g
s
.47146 .62089 m .4633 .57127 L .54744 .56709 L p .692 .579 .724 r
F P
0 g
s
.54959 .51645 m .54744 .56709 L .4633 .57127 L p .69 .546 .686 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48293 .55303 m .4766 .59237 L .54311 .59559 L p .719 .598 .721 r
F P
0 g
s
.54311 .59559 m .54098 .55591 L .48293 .55303 L p .719 .598 .721 r
F P
0 g
s
.54488 .63567 m .54311 .59559 L .4766 .59237 L p .72 .575 .691 r
F P
0 g
s
.54098 .55591 m .54311 .59559 L .60819 .58593 L p .67 .561 .722 r
F P
0 g
s
.54311 .59559 m .54488 .63567 L .61687 .62524 L p .666 .532 .692 r
F P
0 g
s
.61687 .62524 m .60819 .58593 L .54311 .59559 L p .666 .532 .692 r
F P
0 g
s
.49021 .5148 m .48293 .55303 L .54098 .55591 L p .716 .62 .75 r
F P
0 g
s
.54098 .55591 m .53852 .51725 L .49021 .5148 L p .716 .62 .75 r
F P
0 g
s
.53852 .51725 m .54098 .55591 L .59772 .54727 L p .674 .588 .751 r
F P
0 g
s
.60819 .58593 m .59772 .54727 L .54098 .55591 L p .67 .561 .722 r
F P
0 g
s
.4766 .59237 m .47134 .6322 L .54488 .63567 L p .72 .575 .691 r
F P
0 g
s
.54625 .67547 m .54488 .63567 L .47134 .6322 L p .72 .55 .659 r
F P
0 g
s
.54488 .63567 m .54625 .67547 L .62357 .66454 L p .66 .502 .66 r
F P
0 g
s
.62357 .66454 m .61687 .62524 L .54488 .63567 L p .66 .502 .66 r
F P
0 g
s
.42875 .53884 m .41437 .57647 L .4766 .59237 L p .764 .641 .726 r
F P
0 g
s
.4766 .59237 m .48293 .55303 L .42875 .53884 L p .764 .641 .726 r
F P
0 g
s
.47134 .6322 m .4766 .59237 L .41437 .57647 L p .771 .623 .695 r
F P
0 g
s
.44525 .50274 m .42875 .53884 L .48293 .55303 L p .755 .659 .755 r
F P
0 g
s
.48293 .55303 m .49021 .5148 L .44525 .50274 L p .755 .659 .755 r
F P
0 g
s
.41437 .57647 m .40242 .61502 L .47134 .6322 L p .771 .623 .695 r
F P
0 g
s
.4673 .67183 m .47134 .6322 L .40242 .61502 L p .777 .602 .661 r
F P
0 g
s
.47134 .6322 m .4673 .67183 L .54625 .67547 L p .72 .55 .659 r
F P
0 g
s
.49832 .47826 m .49021 .5148 L .53852 .51725 L p .712 .643 .779 r
F P
0 g
s
.53852 .51725 m .53578 .4802 L .49832 .47826 L p .712 .643 .779 r
F P
0 g
s
.53578 .4802 m .53852 .51725 L .5857 .5099 L p .676 .616 .781 r
F P
0 g
s
.59772 .54727 m .5857 .5099 L .53852 .51725 L p .674 .588 .751 r
F P
0 g
s
.54716 .71423 m .54625 .67547 L .4673 .67183 L p .719 .522 .623 r
F P
0 g
s
.54625 .67547 m .54716 .71423 L .62806 .70308 L p .652 .469 .623 r
F P
0 g
s
.62806 .70308 m .62357 .66454 L .54625 .67547 L p .652 .469 .623 r
F P
0 g
s
.59772 .54727 m .60819 .58593 L .66611 .564 L p .616 .527 .731 r
F P
0 g
s
.60819 .58593 m .61687 .62524 L .68116 .60152 L p .604 .492 .699 r
F P
0 g
s
.68116 .60152 m .66611 .564 L .60819 .58593 L p .604 .492 .699 r
F P
0 g
s
.5857 .5099 m .59772 .54727 L .64804 .52773 L p .627 .561 .761 r
F P
0 g
s
.66611 .564 m .64804 .52773 L .59772 .54727 L p .616 .527 .731 r
F P
0 g
s
.46356 .46873 m .44525 .50274 L .49021 .5148 L p .744 .676 .784 r
F P
0 g
s
.49021 .5148 m .49832 .47826 L .46356 .46873 L p .744 .676 .784 r
F P
0 g
s
.61687 .62524 m .62357 .66454 L .6928 .63966 L p .59 .454 .665 r
F P
0 g
s
.6928 .63966 m .68116 .60152 L .61687 .62524 L p .59 .454 .665 r
F P
0 g
s
.40242 .61502 m .39319 .65383 L .4673 .67183 L p .777 .602 .661 r
F P
0 g
s
.46458 .71052 m .4673 .67183 L .39319 .65383 L p .781 .577 .624 r
F P
0 g
s
.4673 .67183 m .46458 .71052 L .54716 .71423 L p .719 .522 .623 r
F P
0 g
s
.5857 .5099 m .57233 .47439 L .53578 .4802 L p .676 .616 .781 r
F P
0 g
s
.57233 .47439 m .5857 .5099 L .62735 .49333 L p .638 .595 .79 r
F P
0 g
s
.64804 .52773 m .62735 .49333 L .5857 .5099 L p .627 .561 .761 r
F P
0 g
s
.40792 .48202 m .38349 .51436 L .42875 .53884 L p .792 .705 .768 r
F P
0 g
s
.42875 .53884 m .44525 .50274 L .40792 .48202 L p .792 .705 .768 r
F P
0 g
s
.41437 .57647 m .42875 .53884 L .38349 .51436 L p .809 .694 .738 r
F P
0 g
s
.38349 .51436 m .36209 .54894 L .41437 .57647 L p .809 .694 .738 r
F P
0 g
s
.40242 .61502 m .41437 .57647 L .36209 .54894 L p .823 .68 .705 r
F P
0 g
s
.50713 .444 m .49832 .47826 L .53578 .4802 L p .705 .666 .809 r
F P
0 g
s
.53578 .4802 m .5328 .44536 L .50713 .444 L p .705 .666 .809 r
F P
0 g
s
.5328 .44536 m .53578 .4802 L .57233 .47439 L p .678 .645 .811 r
F P
0 g
s
.62357 .66454 m .62806 .70308 L .70061 .67766 L p .573 .412 .625 r
F P
0 g
s
.70061 .67766 m .6928 .63966 L .62357 .66454 L p .573 .412 .625 r
F P
0 g
s
.54758 .75115 m .54716 .71423 L .46458 .71052 L p .715 .489 .581 r
F P
0 g
s
.54716 .71423 m .54758 .75115 L .63013 .74005 L p .642 .43 .581 r
F P
0 g
s
.63013 .74005 m .62806 .70308 L .54716 .71423 L p .642 .43 .581 r
F P
0 g
s
.48338 .43736 m .46356 .46873 L .49832 .47826 L p .73 .692 .814 r
F P
0 g
s
.49832 .47826 m .50713 .444 L .48338 .43736 L p .73 .692 .814 r
F P
0 g
s
.43491 .45242 m .40792 .48202 L .44525 .50274 L p .774 .715 .797 r
F P
0 g
s
.44525 .50274 m .46356 .46873 L .43491 .45242 L p .774 .715 .797 r
F P
0 g
s
.36209 .54894 m .34424 .58521 L .40242 .61502 L p .823 .68 .705 r
F P
0 g
s
.39319 .65383 m .40242 .61502 L .34424 .58521 L p .836 .664 .669 r
F P
0 g
s
.57233 .47439 m .55783 .4413 L .5328 .44536 L p .678 .645 .811 r
F P
0 g
s
.55783 .4413 m .57233 .47439 L .60443 .46131 L p .648 .63 .819 r
F P
0 g
s
.62735 .49333 m .60443 .46131 L .57233 .47439 L p .638 .595 .79 r
F P
0 g
s
.39319 .65383 m .387 .69214 L .46458 .71052 L p .781 .577 .624 r
F P
0 g
s
.46333 .74746 m .46458 .71052 L .387 .69214 L p .784 .548 .579 r
F P
0 g
s
.46458 .71052 m .46333 .74746 L .54758 .75115 L p .715 .489 .581 r
F P
0 g
s
.62735 .49333 m .64804 .52773 L .68701 .49874 L p .573 .539 .778 r
F P
0 g
s
.64804 .52773 m .66611 .564 L .71133 .53132 L p .551 .496 .748 r
F P
0 g
s
.71133 .53132 m .68701 .49874 L .64804 .52773 L p .551 .496 .748 r
F P
0 g
s
.46396 .42603 m .43491 .45242 L .46356 .46873 L p .751 .722 .825 r
F P
0 g
s
.46356 .46873 m .48338 .43736 L .46396 .42603 L p .751 .722 .825 r
F P
0 g
s
.66611 .564 m .68116 .60152 L .73168 .56606 L p .526 .45 .714 r
F P
0 g
s
.73168 .56606 m .71133 .53132 L .66611 .564 L p .526 .45 .714 r
F P
0 g
s
.60443 .46131 m .62735 .49333 L .65931 .46885 L p .595 .58 .807 r
F P
0 g
s
.68701 .49874 m .65931 .46885 L .62735 .49333 L p .573 .539 .778 r
F P
0 g
s
.34424 .58521 m .33041 .62251 L .39319 .65383 L p .836 .664 .669 r
F P
0 g
s
.387 .69214 m .39319 .65383 L .33041 .62251 L p .847 .643 .626 r
F P
0 g
s
.62806 .70308 m .63013 .74005 L .70422 .71472 L p .552 .362 .577 r
F P
0 g
s
.70422 .71472 m .70061 .67766 L .62806 .70308 L p .552 .362 .577 r
F P
0 g
s
.51651 .41258 m .50713 .444 L .5328 .44536 L p .695 .691 .841 r
F P
0 g
s
.5328 .44536 m .52963 .41329 L .51651 .41258 L p .695 .691 .841 r
F P
0 g
s
.52963 .41329 m .5328 .44536 L .55783 .4413 L p .677 .677 .843 r
F P
0 g
s
.50441 .40913 m .48338 .43736 L .50713 .444 L p .712 .708 .845 r
F P
0 g
s
.50713 .444 m .51651 .41258 L .50441 .40913 L p .712 .708 .845 r
F P
0 g
s
.68116 .60152 m .6928 .63966 L .74746 .60236 L p .498 .399 .674 r
F P
0 g
s
.74746 .60236 m .73168 .56606 L .68116 .60152 L p .498 .399 .674 r
F P
0 g
s
.60443 .46131 m .57969 .4322 L .55783 .4413 L p .648 .63 .819 r
F P
0 g
s
.57969 .4322 m .60443 .46131 L .62882 .44211 L p .616 .621 .833 r
F P
0 g
s
.65931 .46885 m .62882 .44211 L .60443 .46131 L p .595 .58 .807 r
F P
0 g
s
.54747 .78533 m .54758 .75115 L .46333 .74746 L p .708 .449 .53 r
F P
0 g
s
.54758 .75115 m .54747 .78533 L .6296 .77453 L p .627 .383 .528 r
F P
0 g
s
.6296 .77453 m .63013 .74005 L .54758 .75115 L p .627 .383 .528 r
F P
0 g
s
.55783 .4413 m .54241 .41118 L .52963 .41329 L p .677 .677 .843 r
F P
0 g
s
.54241 .41118 m .55783 .4413 L .57969 .4322 L p .657 .668 .848 r
F P
0 g
s
.387 .69214 m .38414 .72915 L .46333 .74746 L p .784 .548 .579 r
F P
0 g
s
.46366 .78174 m .46333 .74746 L .38414 .72915 L p .783 .51 .524 r
F P
0 g
s
.46333 .74746 m .46366 .78174 L .54747 .78533 L p .708 .449 .53 r
F P
0 g
s
.41542 .43079 m .38217 .45436 L .40792 .48202 L p .799 .761 .818 r
F P
0 g
s
.40792 .48202 m .43491 .45242 L .41542 .43079 L p .799 .761 .818 r
F P
0 g
s
.38349 .51436 m .40792 .48202 L .38217 .45436 L p .826 .762 .791 r
F P
0 g
s
.4946 .40328 m .46396 .42603 L .48338 .43736 L p .725 .728 .853 r
F P
0 g
s
.48338 .43736 m .50441 .40913 L .4946 .40328 L p .725 .728 .853 r
F P
0 g
s
.38217 .45436 m .35186 .4815 L .38349 .51436 L p .826 .762 .791 r
F P
0 g
s
.36209 .54894 m .38349 .51436 L .35186 .4815 L p .852 .76 .76 r
F P
0 g
s
.33041 .62251 m .32112 .66013 L .387 .69214 L p .847 .643 .626 r
F P
0 g
s
.38414 .72915 m .387 .69214 L .32112 .66013 L p .856 .615 .573 r
F P
0 g
s
.45096 .41111 m .41542 .43079 L .43491 .45242 L p .768 .757 .843 r
F P
0 g
s
.43491 .45242 m .46396 .42603 L .45096 .41111 L p .768 .757 .843 r
F P
0 g
s
.35186 .4815 m .32515 .51181 L .36209 .54894 L p .852 .76 .76 r
F P
0 g
s
.34424 .58521 m .36209 .54894 L .32515 .51181 L p .877 .754 .724 r
F P
0 g
s
.6928 .63966 m .70061 .67766 L .75809 .6395 L p .465 .34 .626 r
F P
0 g
s
.75809 .6395 m .74746 .60236 L .6928 .63966 L p .465 .34 .626 r
F P
0 g
s
.57969 .4322 m .55351 .40646 L .54241 .41118 L p .657 .668 .848 r
F P
0 g
s
.55351 .40646 m .57969 .4322 L .59612 .4189 L p .637 .664 .859 r
F P
0 g
s
.62882 .44211 m .59612 .4189 L .57969 .4322 L p .616 .621 .833 r
F P
0 g
s
.63013 .74005 m .6296 .77453 L .70328 .74992 L p .525 .301 .516 r
F P
0 g
s
.70328 .74992 m .70422 .71472 L .63013 .74005 L p .525 .301 .516 r
F P
0 g
s
.48813 .39563 m .45096 .41111 L .46396 .42603 L p .733 .75 .866 r
F P
0 g
s
.46396 .42603 m .4946 .40328 L .48813 .39563 L p .733 .75 .866 r
F P
0 g
s
.32515 .51181 m .30275 .54481 L .34424 .58521 L p .877 .754 .724 r
F P
0 g
s
.33041 .62251 m .34424 .58521 L .30275 .54481 L p .899 .744 .68 r
F P
0 g
s
.52963 .41329 m .52632 .38458 L .51651 .41258 L closepath p .68 .717 .877 r
F P
0 g
s
.54241 .41118 m .52632 .38458 L .52963 .41329 L closepath p .674 .712 .877 r
F P
0 g
s
.51651 .41258 m .52632 .38458 L .50441 .40913 L closepath p .686 .724 .878 r
F P
0 g
s
.62882 .44211 m .65931 .46885 L .67799 .43861 L p .546 .573 .833 r
F P
0 g
s
.65931 .46885 m .68701 .49874 L .71023 .46269 L p .508 .522 .807 r
F P
0 g
s
.71023 .46269 m .67799 .43861 L .65931 .46885 L p .508 .522 .807 r
F P
0 g
s
.59612 .4189 m .62882 .44211 L .64276 .41854 L p .583 .62 .855 r
F P
0 g
s
.67799 .43861 m .64276 .41854 L .62882 .44211 L p .546 .573 .833 r
F P
0 g
s
.55351 .40646 m .52632 .38458 L .54241 .41118 L closepath p .666 .709 .88 r
F P
0 g
s
.68701 .49874 m .71133 .53132 L .73872 .49046 L p .465 .466 .775 r
F P
0 g
s
.73872 .49046 m .71023 .46269 L .68701 .49874 L p .465 .466 .775 r
F P
0 g
s
.50441 .40913 m .52632 .38458 L .4946 .40328 L closepath p .691 .731 .882 r
F P
0 g
s
.59612 .4189 m .56176 .39962 L .55351 .40646 L p .637 .664 .859 r
F P
0 g
s
.56176 .39962 m .59612 .4189 L .60528 .40272 L p .618 .665 .873 r
F P
0 g
s
.64276 .41854 m .60528 .40272 L .59612 .4189 L p .583 .62 .855 r
F P
0 g
s
.5468 .8158 m .54747 .78533 L .46366 .78174 L p .696 .396 .463 r
F P
0 g
s
.54747 .78533 m .5468 .8158 L .62628 .80557 L p .606 .321 .459 r
F P
0 g
s
.62628 .80557 m .6296 .77453 L .54747 .78533 L p .606 .321 .459 r
F P
0 g
s
.56176 .39962 m .52632 .38458 L .55351 .40646 L closepath p .659 .708 .884 r
F P
0 g
s
.70061 .67766 m .70422 .71472 L .76301 .67667 L p .423 .269 .565 r
F P
0 g
s
.76301 .67667 m .75809 .6395 L .70061 .67766 L p .423 .269 .565 r
F P
0 g
s
.32112 .66013 m .31682 .69724 L .38414 .72915 L p .856 .615 .573 r
F P
0 g
s
.38489 .76394 m .38414 .72915 L .31682 .69724 L p .862 .577 .505 r
F P
0 g
s
.38414 .72915 m .38489 .76394 L .46366 .78174 L p .783 .51 .524 r
F P
0 g
s
.4946 .40328 m .52632 .38458 L .48813 .39563 L closepath p .693 .739 .886 r
F P
0 g
s
.71133 .53132 m .73168 .56606 L .76271 .52151 L p .416 .402 .736 r
F P
0 g
s
.76271 .52151 m .73872 .49046 L .71133 .53132 L p .416 .402 .736 r
F P
0 g
s
.46566 .8124 m .46366 .78174 L .38489 .76394 L p .777 .459 .45 r
F P
0 g
s
.46366 .78174 m .46566 .8124 L .5468 .8158 L p .696 .396 .463 r
F P
0 g
s
.30275 .54481 m .28533 .57995 L .33041 .62251 L p .899 .744 .68 r
F P
0 g
s
.32112 .66013 m .33041 .62251 L .28533 .57995 L p .92 .727 .625 r
F P
0 g
s
.44589 .39409 m .40745 .40589 L .41542 .43079 L p .776 .794 .868 r
F P
0 g
s
.41542 .43079 m .45096 .41111 L .44589 .39409 L p .776 .794 .868 r
F P
0 g
s
.38217 .45436 m .41542 .43079 L .40745 .40589 L p .815 .814 .849 r
F P
0 g
s
.56623 .39135 m .52632 .38458 L .56176 .39962 L closepath p .653 .709 .889 r
F P
0 g
s
.60528 .40272 m .56623 .39135 L .56176 .39962 L p .618 .665 .873 r
F P
0 g
s
.48575 .38697 m .44589 .39409 L .45096 .41111 L p .736 .772 .882 r
F P
0 g
s
.45096 .41111 m .48813 .39563 L .48575 .38697 L p .736 .772 .882 r
F P
0 g
s
.40745 .40589 m .37117 .42229 L .38217 .45436 L p .815 .814 .849 r
F P
0 g
s
.35186 .4815 m .38217 .45436 L .37117 .42229 L p .852 .83 .825 r
F P
0 g
s
.48813 .39563 m .52632 .38458 L .48575 .38697 L closepath p .693 .746 .892 r
F P
0 g
s
.6296 .77453 m .62628 .80557 L .69751 .78226 L p .487 .221 .435 r
F P
0 g
s
.69751 .78226 m .70328 .74992 L .6296 .77453 L p .487 .221 .435 r
F P
0 g
s
.73168 .56606 m .74746 .60236 L .7814 .55532 L p .358 .326 .686 r
F P
0 g
s
.7814 .55532 m .76271 .52151 L .73168 .56606 L p .358 .326 .686 r
F P
0 g
s
.37117 .42229 m .33783 .44312 L .35186 .4815 L p .852 .83 .825 r
F P
0 g
s
.32515 .51181 m .35186 .4815 L .33783 .44312 L p .89 .843 .793 r
F P
0 g
s
.56642 .38253 m .52632 .38458 L .56623 .39135 L closepath p .648 .713 .896 r
F P
0 g
s
.56623 .39135 m .60528 .40272 L .60602 .38529 L p .601 .673 .891 r
F P
0 g
s
.60602 .38529 m .56642 .38253 L .56623 .39135 L p .601 .673 .891 r
F P
0 g
s
.60528 .40272 m .64276 .41854 L .64438 .39295 L p .549 .628 .883 r
F P
0 g
s
.64438 .39295 m .60602 .38529 L .60528 .40272 L p .549 .628 .883 r
F P
0 g
s
.55407 .36702 m .52632 .38458 L .56223 .37411 L closepath p .645 .727 .908 r
F P
0 g
s
.54281 .36208 m .52632 .38458 L .55407 .36702 L closepath p .648 .735 .913 r
F P
0 g
s
.48776 .37822 m .52632 .38458 L .49401 .37036 L closepath p .685 .755 .905 r
F P
0 g
s
.48575 .38697 m .52632 .38458 L .48776 .37822 L closepath p .69 .752 .899 r
F P
0 g
s
.56223 .37411 m .52632 .38458 L .56642 .38253 L closepath p .645 .719 .902 r
F P
0 g
s
.5297 .35986 m .52632 .38458 L .54281 .36208 L closepath p .653 .743 .916 r
F P
0 g
s
.5162 .36061 m .52632 .38458 L .5297 .35986 L closepath p .66 .75 .916 r
F P
0 g
s
.50385 .36425 m .52632 .38458 L .5162 .36061 L closepath p .669 .754 .915 r
F P
0 g
s
.49401 .37036 m .52632 .38458 L .50385 .36425 L closepath p .677 .756 .911 r
F P
0 g
s
.64276 .41854 m .67799 .43861 L .68074 .40551 L p .491 .576 .868 r
F P
0 g
s
.68074 .40551 m .64438 .39295 L .64276 .41854 L p .491 .576 .868 r
F P
0 g
s
.44589 .39409 m .48575 .38697 L .48776 .37822 L p .73 .792 .901 r
F P
0 g
s
.70422 .71472 m .70328 .74992 L .76173 .71294 L p .369 .178 .485 r
F P
0 g
s
.76173 .71294 m .76301 .67667 L .70422 .71472 L p .369 .178 .485 r
F P
0 g
s
.28533 .57995 m .27358 .61652 L .32112 .66013 L p .92 .727 .625 r
F P
0 g
s
.31682 .69724 m .32112 .66013 L .27358 .61652 L p .938 .699 .552 r
F P
0 g
s
.56642 .38253 m .60602 .38529 L .59801 .36851 L p .588 .689 .911 r
F P
0 g
s
.59801 .36851 m .56223 .37411 L .56642 .38253 L p .588 .689 .911 r
F P
0 g
s
.48776 .37822 m .44953 .37674 L .44589 .39409 L p .73 .792 .901 r
F P
0 g
s
.40745 .40589 m .44589 .39409 L .44953 .37674 L p .771 .831 .899 r
F P
0 g
s
.33783 .44312 m .30825 .46817 L .32515 .51181 L p .89 .843 .793 r
F P
0 g
s
.30275 .54481 m .32515 .51181 L .30825 .46817 L p .926 .851 .749 r
F P
0 g
s
.67799 .43861 m .71023 .46269 L .7143 .42293 L p .423 .513 .846 r
F P
0 g
s
.7143 .42293 m .68074 .40551 L .67799 .43861 L p .423 .513 .846 r
F P
0 g
s
.31682 .69724 m .31793 .73293 L .38489 .76394 L p .862 .577 .505 r
F P
0 g
s
.38946 .79554 m .38489 .76394 L .31793 .73293 L p .859 .521 .411 r
F P
0 g
s
.38489 .76394 m .38946 .79554 L .46566 .8124 L p .777 .459 .45 r
F P
0 g
s
.54553 .84154 m .5468 .8158 L .46566 .8124 L p .673 .321 .369 r
F P
0 g
s
.5468 .8158 m .54553 .84154 L .62007 .83212 L p .571 .236 .362 r
F P
0 g
s
.62007 .83212 m .62628 .80557 L .5468 .8158 L p .571 .236 .362 r
F P
0 g
s
.74746 .60236 m .75809 .6395 L .79402 .59124 L p .286 .231 .619 r
F P
0 g
s
.79402 .59124 m .7814 .55532 L .74746 .60236 L p .286 .231 .619 r
F P
0 g
s
.44953 .37674 m .48776 .37822 L .49401 .37036 L p .715 .806 .921 r
F P
0 g
s
.44953 .37674 m .41231 .3803 L .40745 .40589 L p .771 .831 .899 r
F P
0 g
s
.37117 .42229 m .40745 .40589 L .41231 .3803 L p .813 .87 .889 r
F P
0 g
s
.46941 .83841 m .46566 .8124 L .38946 .79554 L p .759 .385 .346 r
F P
0 g
s
.46566 .8124 m .46941 .83841 L .54553 .84154 L p .673 .321 .369 r
F P
0 g
s
.56223 .37411 m .59801 .36851 L .58193 .35427 L p .582 .71 .931 r
F P
0 g
s
.58193 .35427 m .55407 .36702 L .56223 .37411 L p .582 .71 .931 r
F P
0 g
s
.60602 .38529 m .64438 .39295 L .63298 .36808 L p .518 .648 .915 r
F P
0 g
s
.63298 .36808 m .59801 .36851 L .60602 .38529 L p .518 .648 .915 r
F P
0 g
s
.71023 .46269 m .73872 .49046 L .74418 .44509 L p .341 .435 .812 r
F P
0 g
s
.74418 .44509 m .7143 .42293 L .71023 .46269 L p .341 .435 .812 r
F P
0 g
s
.4617 .36099 m .49401 .37036 L .50385 .36425 L p .691 .811 .939 r
F P
0 g
s
.49401 .37036 m .4617 .36099 L .44953 .37674 L p .715 .806 .921 r
F P
0 g
s
.30825 .46817 m .28328 .4971 L .30275 .54481 L p .926 .851 .749 r
F P
0 g
s
.28533 .57995 m .30275 .54481 L .28328 .4971 L p .961 .851 .689 r
F P
0 g
s
.55407 .36702 m .58193 .35427 L .55946 .34428 L p .587 .736 .947 r
F P
0 g
s
.55946 .34428 m .54281 .36208 L .55407 .36702 L p .587 .736 .947 r
F P
0 g
s
.62628 .80557 m .62007 .83212 L .6867 .81069 L p .429 .108 .318 r
F P
0 g
s
.6867 .81069 m .69751 .78226 L .62628 .80557 L p .429 .108 .318 r
F P
0 g
s
.27358 .61652 m .26814 .65374 L .31682 .69724 L p .938 .699 .552 r
F P
0 g
s
.31793 .73293 m .31682 .69724 L .26814 .65374 L p .947 .654 .452 r
F P
0 g
s
.41231 .3803 m .44953 .37674 L .4617 .36099 L p .747 .86 .932 r
F P
0 g
s
.41231 .3803 m .37688 .38904 L .37117 .42229 L p .813 .87 .889 r
F P
0 g
s
.33783 .44312 m .37117 .42229 L .37688 .38904 L p .856 .907 .869 r
F P
0 g
s
.48122 .34868 m .50385 .36425 L .5162 .36061 L p .66 .805 .952 r
F P
0 g
s
.50385 .36425 m .48122 .34868 L .4617 .36099 L p .691 .811 .939 r
F P
0 g
s
.70328 .74992 m .69751 .78226 L .75387 .74729 L p .294 .055 .371 r
F P
0 g
s
.75387 .74729 m .76173 .71294 L .70328 .74992 L p .294 .055 .371 r
F P
0 g
s
.54281 .36208 m .55946 .34428 L .53312 .33977 L p .603 .764 .956 r
F P
0 g
s
.53312 .33977 m .5297 .35986 L .54281 .36208 L p .603 .764 .956 r
F P
0 g
s
.64438 .39295 m .68074 .40551 L .66641 .37306 L p .428 .592 .911 r
F P
0 g
s
.66641 .37306 m .63298 .36808 L .64438 .39295 L p .428 .592 .911 r
F P
0 g
s
.75809 .6395 m .76301 .67667 L .79988 .62849 L p .194 .11 .526 r
F P
0 g
s
.79988 .62849 m .79402 .59124 L .75809 .6395 L p .194 .11 .526 r
F P
0 g
s
.50598 .3413 m .5162 .36061 L .5297 .35986 L p .629 .788 .959 r
F P
0 g
s
.5162 .36061 m .50598 .3413 L .48122 .34868 L p .66 .805 .952 r
F P
0 g
s
.5297 .35986 m .53312 .33977 L .50598 .3413 L p .629 .788 .959 r
F P
0 g
s
.73872 .49046 m .76271 .52151 L .76949 .47176 L p .238 .334 .761 r
F P
0 g
s
.76949 .47176 m .74418 .44509 L .73872 .49046 L p .238 .334 .761 r
F P
0 g
s
.59801 .36851 m .63298 .36808 L .60937 .34681 L p .495 .68 .948 r
F P
0 g
s
.60937 .34681 m .58193 .35427 L .59801 .36851 L p .495 .68 .948 r
F P
0 g
s
.28328 .4971 m .26378 .52947 L .28533 .57995 L p .961 .851 .689 r
F P
0 g
s
.27358 .61652 m .28533 .57995 L .26378 .52947 L p .989 .837 .602 r
F P
0 g
s
.31793 .73293 m .32481 .76619 L .38946 .79554 L p .859 .521 .411 r
F P
0 g
s
.39802 .82289 m .38946 .79554 L .32481 .76619 L p .839 .433 .273 r
F P
0 g
s
.38946 .79554 m .39802 .82289 L .46941 .83841 L p .759 .385 .346 r
F P
0 g
s
.37688 .38904 m .34406 .40303 L .33783 .44312 L p .856 .907 .869 r
F P
0 g
s
.30825 .46817 m .33783 .44312 L .34406 .40303 L p .897 .941 .831 r
F P
0 g
s
.42999 .35687 m .4617 .36099 L .48122 .34868 L p .699 .872 .963 r
F P
0 g
s
.4617 .36099 m .42999 .35687 L .41231 .3803 L p .747 .86 .932 r
F P
0 g
s
.37688 .38904 m .41231 .3803 L .42999 .35687 L p .777 .917 .932 r
F P
0 g
s
.68074 .40551 m .7143 .42293 L .69751 .38366 L p .31 .512 .891 r
F P
0 g
s
.69751 .38366 m .66641 .37306 L .68074 .40551 L p .31 .512 .891 r
F P
0 g
s
.54366 .86149 m .54553 .84154 L .46941 .83841 L p .626 .206 .225 r
F P
0 g
s
.54553 .84154 m .54366 .86149 L .6109 .85311 L p .509 .106 .212 r
F P
0 g
s
.6109 .85311 m .62007 .83212 L .54553 .84154 L p .509 .106 .212 r
F P
0 g
s
.76271 .52151 m .7814 .55532 L .78931 .50257 L p .104 .201 .681 r
F P
0 g
s
.78931 .50257 m .76949 .47176 L .76271 .52151 L p .104 .201 .681 r
F P
0 g
s
.58193 .35427 m .60937 .34681 L .57594 .3318 L p .49 .724 .975 r
F P
0 g
s
.57594 .3318 m .55946 .34428 L .58193 .35427 L p .49 .724 .975 r
F P
0 g
s
.47496 .8587 m .46941 .83841 L .39802 .82289 L p .715 .265 .183 r
F P
0 g
s
.46941 .83841 m .47496 .8587 L .54366 .86149 L p .626 .206 .225 r
F P
0 g
s
.26814 .65374 m .26955 .69066 L .31793 .73293 L p .947 .654 .452 r
F P
0 g
s
.32481 .76619 m .31793 .73293 L .26955 .69066 L p .936 .576 .305 r
F P
0 g
s
.76301 .67667 m .76173 .71294 L .79836 .66614 L p .069 0 .391 r
F P
0 g
s
.79836 .66614 m .79988 .62849 L .76301 .67667 L p .069 0 .391 r
F P
0 g
s
.45888 .33842 m .48122 .34868 L .50598 .3413 L p .633 .859 .985 r
F P
0 g
s
.48122 .34868 m .45888 .33842 L .42999 .35687 L p .699 .872 .963 r
F P
0 g
s
.63298 .36808 m .66641 .37306 L .63579 .34511 L p .367 .624 .952 r
F P
0 g
s
.63579 .34511 m .60937 .34681 L .63298 .36808 L p .367 .624 .952 r
F P
0 g
s
.69751 .78226 m .6867 .81069 L .73919 .7786 L p .18 0 .201 r
F P
0 g
s
.73919 .7786 m .75387 .74729 L .69751 .78226 L p .18 0 .201 r
F P
0 g
s
.34406 .40303 m .31472 .42228 L .30825 .46817 L p .897 .941 .831 r
F P
0 g
s
.28328 .4971 m .30825 .46817 L .31472 .42228 L p .932 .962 .763 r
F P
0 g
s
.26378 .52947 m .25057 .56467 L .27358 .61652 L p .989 .837 .602 r
F P
0 g
s
.26814 .65374 m .27358 .61652 L .25057 .56467 L p .999 .795 .472 r
F P
0 g
s
.62007 .83212 m .6109 .85311 L .67081 .83409 L p .33 0 .135 r
F P
0 g
s
.67081 .83409 m .6867 .81069 L .62007 .83212 L p .33 0 .135 r
F P
0 g
s
.55946 .34428 m .57594 .3318 L .53652 .32499 L p .512 .775 .991 r
F P
0 g
s
.53652 .32499 m .53312 .33977 L .55946 .34428 L p .512 .775 .991 r
F P
0 g
s
.42999 .35687 m .39956 .35835 L .37688 .38904 L p .777 .917 .932 r
F P
0 g
s
.34406 .40303 m .37688 .38904 L .39956 .35835 L p .8 .97 .909 r
F P
0 g
s
.7143 .42293 m .74418 .44509 L .7254 .39998 L p .147 .393 .842 r
F P
0 g
s
.7254 .39998 m .69751 .38366 L .7143 .42293 L p .147 .393 .842 r
F P
0 g
s
.49584 .3273 m .50598 .3413 L .53312 .33977 L p .564 .824 .994 r
F P
0 g
s
.50598 .3413 m .49584 .3273 L .45888 .33842 L p .633 .859 .985 r
F P
0 g
s
.53312 .33977 m .53652 .32499 L .49584 .3273 L p .564 .824 .994 r
F P
0 g
s
.7814 .55532 m .79402 .59124 L .80276 .53698 L p 0 .021 .555 r
F P
0 g
s
.80276 .53698 m .78931 .50257 L .7814 .55532 L p 0 .021 .555 r
F P
0 g
s
.39956 .35835 m .42999 .35687 L .45888 .33842 L p .691 .932 .967 r
F P
0 g
s
.32481 .76619 m .33765 .79593 L .39802 .82289 L p .839 .433 .273 r
F P
0 g
s
.41064 .84491 m .39802 .82289 L .33765 .79593 L p .774 .283 .058 r
F P
0 g
s
.39802 .82289 m .41064 .84491 L .47496 .8587 L p .715 .265 .183 r
F P
0 g
s
.31472 .42228 m .28979 .44664 L .28328 .4971 L p .932 .962 .763 r
F P
0 g
s
.26378 .52947 m .28328 .4971 L .28979 .44664 L p .943 .953 .644 r
F P
0 g
s
.76173 .71294 m .75387 .74729 L .789 .70311 L p 0 0 .191 r
F P
0 g
s
.789 .70311 m .79836 .66614 L .76173 .71294 L p 0 0 .191 r
F P
0 g
s
.60937 .34681 m .63579 .34511 L .59189 .32525 L p .326 .674 .977 r
F P
0 g
s
.59189 .32525 m .57594 .3318 L .60937 .34681 L p .326 .674 .977 r
F P
0 g
s
.26955 .69066 m .27825 .72625 L .32481 .76619 L p .936 .576 .305 r
F P
0 g
s
.33765 .79593 m .32481 .76619 L .27825 .72625 L p .877 .439 .085 r
F P
0 g
s
.66641 .37306 m .69751 .38366 L .66053 .34958 L p .17 .519 .917 r
F P
0 g
s
.66053 .34958 m .63579 .34511 L .66641 .37306 L p .17 .519 .917 r
F P
0 g
s
.25057 .56467 m .24444 .60194 L .26814 .65374 L p .999 .795 .472 r
F P
0 g
s
.26955 .69066 m .26814 .65374 L .24444 .60194 L p .969 .703 .279 r
F P
0 g
s
.74418 .44509 m .76949 .47176 L .74918 .42201 L p 0 .215 .739 r
F P
0 g
s
.74918 .42201 m .7254 .39998 L .74418 .44509 L p 0 .215 .739 r
F P
0 g
s
.39956 .35835 m .37115 .36575 L .34406 .40303 L p .8 .97 .909 r
F P
0 g
s
.31472 .42228 m .34406 .40303 L .37115 .36575 L p .796 .999 .835 r
F P
0 g
s
.5412 .87461 m .54366 .86149 L .47496 .8587 L p .521 .011 0 r
F P
0 g
s
.54366 .86149 m .5412 .87461 L .59881 .86749 L p .384 0 0 r
F P
0 g
s
.59881 .86749 m .6109 .85311 L .54366 .86149 L p .384 0 0 r
F P
0 g
s
.4373 .33401 m .45888 .33842 L .49584 .3273 L p .558 .897 .981 r
F P
0 g
s
.45888 .33842 m .4373 .33401 L .39956 .35835 L p .691 .932 .967 r
F P
0 g
s
.48227 .87223 m .47496 .8587 L .41064 .84491 L p .601 .059 0 r
F P
0 g
s
.47496 .8587 m .48227 .87223 L .5412 .87461 L p .521 .011 0 r
F P
0 g
s
.79402 .59124 m .79988 .62849 L .80901 .57425 L p 0 0 .36 r
F P
0 g
s
.80901 .57425 m .80276 .53698 L .79402 .59124 L p 0 0 .36 r
F P
0 g
s
.6867 .81069 m .67081 .83409 L .71767 .80572 L p .005 0 0 r
F P
0 g
s
.71767 .80572 m .73919 .7786 L .6867 .81069 L p .005 0 0 r
F P
0 g
s
.57594 .3318 m .59189 .32525 L .53981 .31621 L p .338 .741 .982 r
F P
0 g
s
.53981 .31621 m .53652 .32499 L .57594 .3318 L p .338 .741 .982 r
F P
0 g
s
.37115 .36575 m .39956 .35835 L .4373 .33401 L p .634 .96 .91 r
F P
0 g
s
.6109 .85311 m .59881 .86749 L .64991 .85139 L p .153 0 0 r
F P
0 g
s
.64991 .85139 m .67081 .83409 L .6109 .85311 L p .153 0 0 r
F P
0 g
s
.28979 .44664 m .27022 .47584 L .26378 .52947 L p .943 .953 .644 r
F P
0 g
s
.25057 .56467 m .26378 .52947 L .27022 .47584 L p .897 .878 .446 r
F P
0 g
s
.48602 .31927 m .49584 .3273 L .53652 .32499 L p .422 .822 .981 r
F P
0 g
s
.49584 .3273 m .48602 .31927 L .4373 .33401 L p .558 .897 .981 r
F P
0 g
s
.53652 .32499 m .53981 .31621 L .48602 .31927 L p .422 .822 .981 r
F P
0 g
s
.75387 .74729 m .73919 .7786 L .77159 .73821 L p 0 0 0 r
F P
0 g
s
.77159 .73821 m .789 .70311 L .75387 .74729 L p 0 0 0 r
F P
0 g
s
.69751 .38366 m .7254 .39998 L .68287 .36058 L p 0 .325 .792 r
F P
0 g
s
.68287 .36058 m .66053 .34958 L .69751 .38366 L p 0 .325 .792 r
F P
0 g
s
.76949 .47176 m .78931 .50257 L .7679 .44957 L p 0 0 .543 r
F P
0 g
s
.7679 .44957 m .74918 .42201 L .76949 .47176 L p 0 0 .543 r
F P
0 g
s
.24444 .60194 m .24603 .64035 L .26955 .69066 L p .969 .703 .279 r
F P
0 g
s
.27825 .72625 m .26955 .69066 L .24603 .64035 L p .854 .526 .003 r
F P
0 g
s
.37115 .36575 m .34559 .37931 L .31472 .42228 L p .796 .999 .835 r
F P
0 g
s
.28979 .44664 m .31472 .42228 L .34559 .37931 L p .724 .953 .661 r
F P
0 g
s
.33765 .79593 m .35653 .82102 L .41064 .84491 L p .774 .283 .058 r
F P
0 g
s
.42726 .86054 m .41064 .84491 L .35653 .82102 L p .6 .028 0 r
F P
0 g
s
.41064 .84491 m .42726 .86054 L .48227 .87223 L p .601 .059 0 r
F P
0 g
s
.63579 .34511 m .66053 .34958 L .60691 .32523 L p .046 .534 .885 r
F P
0 g
s
.60691 .32523 m .59189 .32525 L .63579 .34511 L p .046 .534 .885 r
F P
0 g
s
.27825 .72625 m .29446 .75935 L .33765 .79593 L p .877 .439 .085 r
F P
0 g
s
.35653 .82102 m .33765 .79593 L .29446 .75935 L p .714 .205 0 r
F P
0 g
s
.79988 .62849 m .79836 .66614 L .80738 .61346 L p 0 0 .082 r
F P
0 g
s
.80738 .61346 m .80901 .57425 L .79988 .62849 L p 0 0 .082 r
F P
0 g
s
.41704 .33599 m .4373 .33401 L .48602 .31927 L p .373 .84 .851 r
F P
0 g
s
.4373 .33401 m .41704 .33599 L .37115 .36575 L p .634 .96 .91 r
F P
0 g
s
.27022 .47584 m .25691 .50941 L .25057 .56467 L p .897 .878 .446 r
F P
0 g
s
.24444 .60194 m .25057 .56467 L .25691 .50941 L p .754 .699 .159 r
F P
0 g
s
.67081 .83409 m .64991 .85139 L .68953 .82748 L p 0 0 0 r
F P
0 g
s
.68953 .82748 m .71767 .80572 L .67081 .83409 L p 0 0 0 r
F P
0 g
s
.34559 .37931 m .37115 .36575 L .41704 .33599 L p .474 .874 .709 r
F P
0 g
s
.53816 .87991 m .5412 .87461 L .48227 .87223 L p .28 0 0 r
F P
0 g
s
.5412 .87461 m .53816 .87991 L .58395 .87428 L p .127 0 0 r
F P
0 g
s
.58395 .87428 m .59881 .86749 L .5412 .87461 L p .127 0 0 r
F P
0 g
s
.78931 .50257 m .80276 .53698 L .78065 .48228 L p .671 .336 0 r
F P
0 g
s
.78065 .48228 m .7679 .44957 L .78931 .50257 L p .671 .336 0 r
F P
0 g
s
.49128 .87803 m .48227 .87223 L .42726 .86054 L p .33 0 0 r
F P
0 g
s
.48227 .87223 m .49128 .87803 L .53816 .87991 L p .28 0 0 r
F P
0 g
s
.59189 .32525 m .60691 .32523 L .54292 .31411 L p .023 .578 .819 r
F P
0 g
s
.54292 .31411 m .53981 .31621 L .59189 .32525 L p .023 .578 .819 r
F P
0 g
s
.24603 .64035 m .25582 .67881 L .27825 .72625 L p .854 .526 .003 r
F P
0 g
s
.29446 .75935 m .27825 .72625 L .25582 .67881 L p 0 0 .323 r
F P
0 g
s
.7254 .39998 m .74918 .42201 L .70201 .37832 L p .481 0 0 r
F P
0 g
s
.70201 .37832 m .68287 .36058 L .7254 .39998 L p .481 0 0 r
F P
0 g
s
.34559 .37931 m .32373 .39911 L .28979 .44664 L p .724 .953 .661 r
F P
0 g
s
.27022 .47584 m .28979 .44664 L .32373 .39911 L p 0 0 0 r
F P
0 g
s
.73919 .7786 m .71767 .80572 L .74618 .77018 L p 0 0 0 r
F P
0 g
s
.74618 .77018 m .77159 .73821 L .73919 .7786 L p 0 0 0 r
F P
0 g
s
.47676 .31789 m .48602 .31927 L .53981 .31621 L p .139 .684 .8 r
F P
0 g
s
.48602 .31927 m .47676 .31789 L .41704 .33599 L p .373 .84 .851 r
F P
0 g
s
.59881 .86749 m .58395 .87428 L .62434 .86157 L p 0 0 0 r
F P
0 g
s
.62434 .86157 m .64991 .85139 L .59881 .86749 L p 0 0 0 r
F P
0 g
s
.79836 .66614 m .789 .70311 L .79741 .65349 L p .77 .754 .239 r
F P
0 g
s
.79741 .65349 m .80738 .61346 L .79836 .66614 L p .77 .754 .239 r
F P
0 g
s
.53981 .31621 m .54292 .31411 L .47676 .31789 L p .139 .684 .8 r
F P
0 g
s
.66053 .34958 m .68287 .36058 L .62052 .33228 L p .334 0 0 r
F P
0 g
s
.62052 .33228 m .60691 .32523 L .66053 .34958 L p .334 0 0 r
F P
0 g
s
.29446 .75935 m .31818 .78875 L .35653 .82102 L p .714 .205 0 r
F P
0 g
s
.35653 .82102 m .38127 .84036 L .42726 .86054 L p .6 .028 0 r
F P
0 g
s
.38127 .84036 m .35653 .82102 L .31818 .78875 L p 0 .115 .586 r
F P
0 g
s
.25691 .50941 m .25072 .54666 L .24444 .60194 L p .754 .699 .159 r
F P
0 g
s
.24603 .64035 m .24444 .60194 L .25072 .54666 L p 0 0 .162 r
F P
0 g
s
.42726 .86054 m .44764 .86879 L .49128 .87803 L p .33 0 0 r
F P
0 g
s
.44764 .86879 m .42726 .86054 L .38127 .84036 L p 0 .323 .675 r
F P
0 g
s
.80276 .53698 m .80901 .57425 L .78658 .5195 L p .887 .591 .081 r
F P
0 g
s
.78658 .5195 m .78065 .48228 L .80276 .53698 L p .887 .591 .081 r
F P
0 g
s
.41704 .33599 m .3987 .3448 L .34559 .37931 L p .474 .874 .709 r
F P
0 g
s
.32373 .39911 m .34559 .37931 L .3987 .3448 L p 0 0 0 r
F P
0 g
s
.3987 .3448 m .41704 .33599 L .47676 .31789 L p 0 0 0 r
F P
0 g
s
.64991 .85139 m .62434 .86157 L .6553 .84282 L p .481 .891 .77 r
F P
0 g
s
.6553 .84282 m .68953 .82748 L .64991 .85139 L p .481 .891 .77 r
F P
0 g
s
.32373 .39911 m .30649 .4251 L .27022 .47584 L p 0 0 0 r
F P
0 g
s
.25691 .50941 m .27022 .47584 L .30649 .4251 L p 0 0 0 r
F P
0 g
s
.25582 .67881 m .27401 .71606 L .29446 .75935 L p 0 0 .323 r
F P
0 g
s
.31818 .78875 m .29446 .75935 L .27401 .71606 L p 0 .045 .609 r
F P
0 g
s
.74918 .42201 m .7679 .44957 L .71715 .40284 L p .763 .273 0 r
F P
0 g
s
.71715 .40284 m .70201 .37832 L .74918 .42201 L p .763 .273 0 r
F P
0 g
s
.789 .70311 m .77159 .73821 L .7789 .69303 L p .891 .915 .516 r
F P
0 g
s
.7789 .69303 m .79741 .65349 L .789 .70311 L p .891 .915 .516 r
F P
0 g
s
.71767 .80572 m .68953 .82748 L .71317 .79774 L p .698 .963 .72 r
F P
0 g
s
.71317 .79774 m .74618 .77018 L .71767 .80572 L p .698 .963 .72 r
F P
0 g
s
.60691 .32523 m .62052 .33228 L .54574 .31931 L p .353 0 0 r
F P
0 g
s
.54574 .31931 m .54292 .31411 L .60691 .32523 L p .353 0 0 r
F P
0 g
s
.5346 .87661 m .53816 .87991 L .49128 .87803 L p .122 .664 .838 r
F P
0 g
s
.53816 .87991 m .5346 .87661 L .5666 .87266 L p .242 .755 .851 r
F P
0 g
s
.5666 .87266 m .58395 .87428 L .53816 .87991 L p .242 .755 .851 r
F P
0 g
s
.25072 .54666 m .25233 .58668 L .24603 .64035 L p 0 0 .162 r
F P
0 g
s
.25582 .67881 m .24603 .64035 L .25233 .58668 L p 0 0 .431 r
F P
0 g
s
.50181 .87529 m .49128 .87803 L .44764 .86879 L p .091 .617 .874 r
F P
0 g
s
.49128 .87803 m .50181 .87529 L .5346 .87661 L p .122 .664 .838 r
F P
0 g
s
.46835 .32372 m .47676 .31789 L .54292 .31411 L p .216 0 0 r
F P
0 g
s
.47676 .31789 m .46835 .32372 L .3987 .3448 L p 0 0 0 r
F P
0 g
s
.68287 .36058 m .70201 .37832 L .63223 .3468 L p .639 .078 0 r
F P
0 g
s
.63223 .3468 m .62052 .33228 L .68287 .36058 L p .639 .078 0 r
F P
0 g
s
.31818 .78875 m .34909 .81326 L .38127 .84036 L p 0 .115 .586 r
F P
0 g
s
.41147 .8529 m .38127 .84036 L .34909 .81326 L p 0 .412 .842 r
F P
0 g
s
.38127 .84036 m .41147 .8529 L .44764 .86879 L p 0 .323 .675 r
F P
0 g
s
.58395 .87428 m .5666 .87266 L .59464 .86379 L p .425 .866 .902 r
F P
0 g
s
.59464 .86379 m .62434 .86157 L .58395 .87428 L p .425 .866 .902 r
F P
0 g
s
.80901 .57425 m .80738 .61346 L .78504 .56031 L p .983 .75 .348 r
F P
0 g
s
.78504 .56031 m .78658 .5195 L .80901 .57425 L p .983 .75 .348 r
F P
0 g
s
.54292 .31411 m .54574 .31931 L .46835 .32372 L p .216 0 0 r
F P
0 g
s
.4714 .86882 m .44764 .86879 L .41147 .8529 L p .145 .604 .928 r
F P
0 g
s
.44764 .86879 m .4714 .86882 L .50181 .87529 L p .091 .617 .874 r
F P
0 g
s
.3987 .3448 m .38295 .36076 L .32373 .39911 L p 0 0 0 r
F P
0 g
s
.30649 .4251 m .32373 .39911 L .38295 .36076 L p .049 0 .003 r
F P
0 g
s
.30649 .4251 m .29472 .45697 L .25691 .50941 L p 0 0 0 r
F P
0 g
s
.25072 .54666 m .25691 .50941 L .29472 .45697 L p 0 0 .257 r
F P
0 g
s
.27401 .71606 m .3005 .75077 L .31818 .78875 L p 0 .045 .609 r
F P
0 g
s
.34909 .81326 m .31818 .78875 L .3005 .75077 L p 0 .298 .794 r
F P
0 g
s
.77159 .73821 m .74618 .77018 L .75203 .73066 L p .919 .975 .705 r
F P
0 g
s
.75203 .73066 m .7789 .69303 L .77159 .73821 L p .919 .975 .705 r
F P
0 g
s
.7679 .44957 m .78065 .48228 L .7275 .43391 L p .901 .484 .149 r
F P
0 g
s
.7275 .43391 m .71715 .40284 L .7679 .44957 L p .901 .484 .149 r
F P
0 g
s
.38295 .36076 m .3987 .3448 L .46835 .32372 L p .216 0 0 r
F P
0 g
s
.68953 .82748 m .6553 .84282 L .67334 .81966 L p .747 .991 .882 r
F P
0 g
s
.67334 .81966 m .71317 .79774 L .68953 .82748 L p .747 .991 .882 r
F P
0 g
s
.25233 .58668 m .26221 .6283 L .25582 .67881 L p 0 0 .431 r
F P
0 g
s
.27401 .71606 m .25582 .67881 L .26221 .6283 L p 0 .091 .617 r
F P
0 g
s
.62434 .86157 m .59464 .86379 L .61585 .8508 L p .61 .941 .946 r
F P
0 g
s
.61585 .8508 m .6553 .84282 L .62434 .86157 L p .61 .941 .946 r
F P
0 g
s
.80738 .61346 m .79741 .65349 L .77557 .60354 L p .999 .829 .533 r
F P
0 g
s
.77557 .60354 m .78504 .56031 L .80738 .61346 L p .999 .829 .533 r
F P
0 g
s
.62052 .33228 m .63223 .3468 L .54817 .33232 L p .589 .061 0 r
F P
0 g
s
.54817 .33232 m .54574 .31931 L .62052 .33228 L p .589 .061 0 r
F P
0 g
s
.70201 .37832 m .71715 .40284 L .64153 .369 L p .783 .31 .11 r
F P
0 g
s
.64153 .369 m .63223 .3468 L .70201 .37832 L p .783 .31 .11 r
F P
0 g
s
.34909 .81326 m .38655 .83172 L .41147 .8529 L p 0 .412 .842 r
F P
0 g
s
.44642 .85777 m .41147 .8529 L .38655 .83172 L p .252 .602 .952 r
F P
0 g
s
.41147 .8529 m .44642 .85777 L .4714 .86882 L p .145 .604 .928 r
F P
0 g
s
.29472 .45697 m .28923 .49413 L .25072 .54666 L p 0 0 .257 r
F P
0 g
s
.25233 .58668 m .25072 .54666 L .28923 .49413 L p .107 .008 .448 r
F P
0 g
s
.53062 .86414 m .5346 .87661 L .50181 .87529 L p .44 .803 .996 r
F P
0 g
s
.5346 .87661 m .53062 .86414 L .54719 .86208 L p .497 .843 .996 r
F P
0 g
s
.54719 .86208 m .5666 .87266 L .5346 .87661 L p .497 .843 .996 r
F P
0 g
s
.74618 .77018 m .71317 .79774 L .71738 .76491 L p .894 .975 .818 r
F P
0 g
s
.71738 .76491 m .75203 .73066 L .74618 .77018 L p .894 .975 .818 r
F P
0 g
s
.3005 .75077 m .33478 .78158 L .34909 .81326 L p 0 .298 .794 r
F P
0 g
s
.38655 .83172 m .34909 .81326 L .33478 .78158 L p .198 .477 .892 r
F P
0 g
s
.46111 .33725 m .46835 .32372 L .54574 .31931 L p .452 0 0 r
F P
0 g
s
.46835 .32372 m .46111 .33725 L .38295 .36076 L p .216 0 0 r
F P
0 g
s
.5136 .86345 m .50181 .87529 L .4714 .86882 L p .414 .764 .995 r
F P
0 g
s
.50181 .87529 m .5136 .86345 L .53062 .86414 L p .44 .803 .996 r
F P
0 g
s
.38295 .36076 m .37047 .384 L .30649 .4251 L p .049 0 .003 r
F P
0 g
s
.29472 .45697 m .30649 .4251 L .37047 .384 L p .224 0 .253 r
F P
0 g
s
.78065 .48228 m .78658 .5195 L .73233 .471 L p .943 .607 .359 r
F P
0 g
s
.73233 .471 m .7275 .43391 L .78065 .48228 L p .943 .607 .359 r
F P
0 g
s
.26221 .6283 m .2805 .67017 L .27401 .71606 L p 0 .091 .617 r
F P
0 g
s
.3005 .75077 m .27401 .71606 L .2805 .67017 L p .139 .27 .738 r
F P
0 g
s
.5666 .87266 m .54719 .86208 L .56161 .85746 L p .572 .876 .994 r
F P
0 g
s
.56161 .85746 m .59464 .86379 L .5666 .87266 L p .572 .876 .994 r
F P
0 g
s
.54574 .31931 m .54817 .33232 L .46111 .33725 L p .452 0 0 r
F P
0 g
s
.6553 .84282 m .61585 .8508 L .62786 .8349 L p .735 .948 .949 r
F P
0 g
s
.62786 .8349 m .67334 .81966 L .6553 .84282 L p .735 .948 .949 r
F P
0 g
s
.4979 .86008 m .4714 .86882 L .44642 .85777 L p .419 .731 .99 r
F P
0 g
s
.4714 .86882 m .4979 .86008 L .5136 .86345 L p .414 .764 .995 r
F P
0 g
s
.79741 .65349 m .7789 .69303 L .75806 .64774 L p .978 .863 .656 r
F P
0 g
s
.75806 .64774 m .77557 .60354 L .79741 .65349 L p .978 .863 .656 r
F P
0 g
s
.37047 .384 m .38295 .36076 L .46111 .33725 L p .383 0 .175 r
F P
0 g
s
.59464 .86379 m .56161 .85746 L .57236 .85075 L p .644 .89 .985 r
F P
0 g
s
.57236 .85075 m .61585 .8508 L .59464 .86379 L p .644 .89 .985 r
F P
0 g
s
.71317 .79774 m .67334 .81966 L .67593 .79435 L p .846 .947 .884 r
F P
0 g
s
.67593 .79435 m .71738 .76491 L .71317 .79774 L p .846 .947 .884 r
F P
0 g
s
.28923 .49413 m .29066 .5357 L .25233 .58668 L p .107 .008 .448 r
F P
0 g
s
.26221 .6283 m .25233 .58668 L .29066 .5357 L p .229 .167 .577 r
F P
0 g
s
.33478 .78158 m .37597 .80717 L .38655 .83172 L p .198 .477 .892 r
F P
0 g
s
.42954 .84315 m .38655 .83172 L .37597 .80717 L p .364 .6 .938 r
F P
0 g
s
.38655 .83172 m .42954 .84315 L .44642 .85777 L p .252 .602 .952 r
F P
0 g
s
.2805 .67017 m .307 .71076 L .3005 .75077 L p .139 .27 .738 r
F P
0 g
s
.33478 .78158 m .3005 .75077 L .307 .71076 L p .271 .406 .816 r
F P
0 g
s
.48513 .85435 m .44642 .85777 L .42954 .84315 L p .448 .705 .977 r
F P
0 g
s
.44642 .85777 m .48513 .85435 L .4979 .86008 L p .419 .731 .99 r
F P
0 g
s
.71715 .40284 m .7275 .43391 L .64789 .3988 L p .835 .447 .315 r
F P
0 g
s
.64789 .3988 m .64153 .369 L .71715 .40284 L p .835 .447 .315 r
F P
0 g
s
.63223 .3468 m .64153 .369 L .55011 .35342 L p .692 .257 .212 r
F P
0 g
s
.55011 .35342 m .54817 .33232 L .63223 .3468 L p .692 .257 .212 r
F P
0 g
s
.78658 .5195 m .78504 .56031 L .73107 .51325 L p .944 .676 .499 r
F P
0 g
s
.73107 .51325 m .73233 .471 L .78658 .5195 L p .944 .676 .499 r
F P
0 g
s
.37047 .384 m .36193 .41437 L .29472 .45697 L p .224 0 .253 r
F P
0 g
s
.28923 .49413 m .29472 .45697 L .36193 .41437 L p .334 .109 .415 r
F P
0 g
s
.7789 .69303 m .75203 .73066 L .73277 .69129 L p .941 .874 .741 r
F P
0 g
s
.73277 .69129 m .75806 .64774 L .7789 .69303 L p .941 .874 .741 r
F P
0 g
s
.61585 .8508 m .57236 .85075 L .57824 .84262 L p .698 .883 .966 r
F P
0 g
s
.57824 .84262 m .62786 .8349 L .61585 .8508 L p .698 .883 .966 r
F P
0 g
s
.45535 .35872 m .46111 .33725 L .54817 .33232 L p .567 .16 .229 r
F P
0 g
s
.46111 .33725 m .45535 .35872 L .37047 .384 L p .383 0 .175 r
F P
0 g
s
.52632 .84233 m .53062 .86414 L .5136 .86345 L closepath p .589 .796 .979 r
F P
0 g
s
.52632 .84233 m .54719 .86208 L .53062 .86414 L closepath p .603 .806 .978 r
F P
0 g
s
.67334 .81966 m .62786 .8349 L .62908 .81769 L p .79 .906 .922 r
F P
0 g
s
.62908 .81769 m .67593 .79435 L .67334 .81966 L p .79 .906 .922 r
F P
0 g
s
.52632 .84233 m .5136 .86345 L .4979 .86008 L closepath p .58 .784 .976 r
F P
0 g
s
.54817 .33232 m .55011 .35342 L .45535 .35872 L p .567 .16 .229 r
F P
0 g
s
.307 .71076 m .34104 .74847 L .33478 .78158 L p .271 .406 .816 r
F P
0 g
s
.37597 .80717 m .33478 .78158 L .34104 .74847 L p .374 .513 .868 r
F P
0 g
s
.29066 .5357 m .29941 .58044 L .26221 .6283 L p .229 .167 .577 r
F P
0 g
s
.2805 .67017 m .26221 .6283 L .29941 .58044 L p .319 .289 .668 r
F P
0 g
s
.52632 .84233 m .56161 .85746 L .54719 .86208 L closepath p .62 .813 .974 r
F P
0 g
s
.52632 .84233 m .4979 .86008 L .48513 .85435 L closepath p .576 .772 .972 r
F P
0 g
s
.37597 .80717 m .42276 .82639 L .42954 .84315 L p .364 .6 .938 r
F P
0 g
s
.47668 .84683 m .42954 .84315 L .42276 .82639 L p .489 .687 .955 r
F P
0 g
s
.42954 .84315 m .47668 .84683 L .48513 .85435 L p .448 .705 .977 r
F P
0 g
s
.36193 .41437 m .37047 .384 L .45535 .35872 L p .475 .16 .351 r
F P
0 g
s
.52632 .84233 m .57236 .85075 L .56161 .85746 L closepath p .637 .815 .968 r
F P
0 g
s
.75203 .73066 m .71738 .76491 L .70037 .73246 L p .898 .872 .803 r
F P
0 g
s
.70037 .73246 m .73277 .69129 L .75203 .73066 L p .898 .872 .803 r
F P
0 g
s
.78504 .56031 m .77557 .60354 L .72338 .55941 L p .929 .718 .596 r
F P
0 g
s
.72338 .55941 m .73107 .51325 L .78504 .56031 L p .929 .718 .596 r
F P
0 g
s
.52632 .84233 m .48513 .85435 L .47668 .84683 L closepath p .579 .761 .965 r
F P
0 g
s
.7275 .43391 m .73233 .471 L .65087 .43578 L p .849 .53 .448 r
F P
0 g
s
.65087 .43578 m .64789 .3988 L .7275 .43391 L p .849 .53 .448 r
F P
0 g
s
.36193 .41437 m .35794 .45141 L .28923 .49413 L p .334 .109 .415 r
F P
0 g
s
.29066 .5357 m .28923 .49413 L .35794 .45141 L p .407 .229 .525 r
F P
0 g
s
.62786 .8349 m .57824 .84262 L .57856 .83392 L p .728 .859 .943 r
F P
0 g
s
.57856 .83392 m .62908 .81769 L .62786 .8349 L p .728 .859 .943 r
F P
0 g
s
.34104 .74847 m .38158 .78176 L .37597 .80717 L p .374 .513 .868 r
F P
0 g
s
.42276 .82639 m .37597 .80717 L .38158 .78176 L p .459 .6 .905 r
F P
0 g
s
.52632 .84233 m .57824 .84262 L .57236 .85075 L closepath p .652 .813 .961 r
F P
0 g
s
.29941 .58044 m .31556 .62686 L .2805 .67017 L p .319 .289 .668 r
F P
0 g
s
.307 .71076 m .2805 .67017 L .31556 .62686 L p .387 .385 .735 r
F P
0 g
s
.64153 .369 m .64789 .3988 L .55143 .38262 L p .735 .376 .372 r
F P
0 g
s
.55143 .38262 m .55011 .35342 L .64153 .369 L p .735 .376 .372 r
F P
0 g
s
.42276 .82639 m .47351 .8383 L .47668 .84683 L p .489 .687 .955 r
F P
0 g
s
.52632 .84233 m .47668 .84683 L .47351 .8383 L closepath p .586 .751 .956 r
F P
0 g
s
.71738 .76491 m .67593 .79435 L .66197 .76956 L p .85 .862 .85 r
F P
0 g
s
.66197 .76956 m .70037 .73246 L .71738 .76491 L p .85 .862 .85 r
F P
0 g
s
.38158 .78176 m .42717 .80921 L .42276 .82639 L p .459 .6 .905 r
F P
0 g
s
.47351 .8383 m .42276 .82639 L .42717 .80921 L p .532 .676 .93 r
F P
0 g
s
.52632 .84233 m .57856 .83392 L .57824 .84262 L closepath p .663 .806 .952 r
F P
0 g
s
.77557 .60354 m .75806 .64774 L .70919 .60789 L p .907 .745 .669 r
F P
0 g
s
.70919 .60789 m .72338 .55941 L .77557 .60354 L p .907 .745 .669 r
F P
0 g
s
.45141 .38813 m .45535 .35872 L .55011 .35342 L p .623 .287 .381 r
F P
0 g
s
.45535 .35872 m .45141 .38813 L .36193 .41437 L p .475 .16 .351 r
F P
0 g
s
.67593 .79435 m .62908 .81769 L .619 .80103 L p .798 .847 .888 r
F P
0 g
s
.619 .80103 m .66197 .76956 L .67593 .79435 L p .798 .847 .888 r
F P
0 g
s
.31556 .62686 m .33883 .67322 L .307 .71076 L p .387 .385 .735 r
F P
0 g
s
.34104 .74847 m .307 .71076 L .33883 .67322 L p .443 .466 .789 r
F P
0 g
s
.42717 .80921 m .47606 .82967 L .47351 .8383 L p .532 .676 .93 r
F P
0 g
s
.52632 .84233 m .47351 .8383 L .47606 .82967 L closepath p .597 .745 .947 r
F P
0 g
s
.35794 .45141 m .36193 .41437 L .45141 .38813 L p .529 .27 .466 r
F P
0 g
s
.55011 .35342 m .55143 .38262 L .45141 .38813 L p .623 .287 .381 r
F P
0 g
s
.52632 .84233 m .56256 .81857 L .57317 .82559 L closepath p .67 .785 .935 r
F P
0 g
s
.52632 .84233 m .54788 .81367 L .56256 .81857 L closepath p .667 .774 .93 r
F P
0 g
s
.52632 .84233 m .53074 .81146 L .54788 .81367 L closepath p .659 .763 .926 r
F P
0 g
s
.52632 .84233 m .51309 .8122 L .53074 .81146 L closepath p .649 .753 .925 r
F P
0 g
s
.52632 .84233 m .49696 .81582 L .51309 .8122 L closepath p .637 .747 .928 r
F P
0 g
s
.52632 .84233 m .48415 .82188 L .49696 .81582 L closepath p .624 .743 .932 r
F P
0 g
s
.52632 .84233 m .47606 .82967 L .48415 .82188 L closepath p .61 .742 .939 r
F P
0 g
s
.52632 .84233 m .57317 .82559 L .57856 .83392 L closepath p .669 .797 .943 r
F P
0 g
s
.35794 .45141 m .35898 .49424 L .29066 .5357 L p .407 .229 .525 r
F P
0 g
s
.29941 .58044 m .29066 .5357 L .35898 .49424 L p .458 .32 .605 r
F P
0 g
s
.62908 .81769 m .57856 .83392 L .57317 .82559 L p .739 .826 .918 r
F P
0 g
s
.57317 .82559 m .619 .80103 L .62908 .81769 L p .739 .826 .918 r
F P
0 g
s
.73233 .471 m .73107 .51325 L .65009 .47908 L p .848 .585 .54 r
F P
0 g
s
.65009 .47908 m .65087 .43578 L .73233 .471 L p .848 .585 .54 r
F P
0 g
s
.33883 .67322 m .36853 .71766 L .34104 .74847 L p .443 .466 .789 r
F P
0 g
s
.38158 .78176 m .34104 .74847 L .36853 .71766 L p .491 .539 .833 r
F P
0 g
s
.44268 .79354 m .48415 .82188 L .47606 .82967 L p .573 .674 .908 r
F P
0 g
s
.47606 .82967 m .42717 .80921 L .44268 .79354 L p .573 .674 .908 r
F P
0 g
s
.75806 .64774 m .73277 .69129 L .68879 .65685 L p .882 .763 .726 r
F P
0 g
s
.68879 .65685 m .70919 .60789 L .75806 .64774 L p .882 .763 .726 r
F P
0 g
s
.36853 .71766 m .40361 .75833 L .38158 .78176 L p .491 .539 .833 r
F P
0 g
s
.42717 .80921 m .38158 .78176 L .40361 .75833 L p .533 .607 .872 r
F P
0 g
s
.40361 .75833 m .44268 .79354 L .42717 .80921 L p .533 .607 .872 r
F P
0 g
s
.64789 .3988 m .65087 .43578 L .55205 .41952 L p .752 .453 .477 r
F P
0 g
s
.55205 .41952 m .55143 .38262 L .64789 .3988 L p .752 .453 .477 r
F P
0 g
s
.619 .80103 m .57317 .82559 L .56256 .81857 L p .734 .791 .898 r
F P
0 g
s
.46784 .78124 m .49696 .81582 L .48415 .82188 L p .61 .678 .89 r
F P
0 g
s
.48415 .82188 m .44268 .79354 L .46784 .78124 L p .61 .678 .89 r
F P
0 g
s
.35898 .49424 m .36534 .5416 L .29941 .58044 L p .458 .32 .605 r
F P
0 g
s
.31556 .62686 m .29941 .58044 L .36534 .5416 L p .496 .392 .667 r
F P
0 g
s
.73277 .69129 m .70037 .73246 L .66282 .70429 L p .853 .776 .775 r
F P
0 g
s
.66282 .70429 m .68879 .65685 L .73277 .69129 L p .853 .776 .775 r
F P
0 g
s
.56256 .81857 m .59838 .78683 L .619 .80103 L p .734 .791 .898 r
F P
0 g
s
.59838 .78683 m .56256 .81857 L .54788 .81367 L p .72 .759 .883 r
F P
0 g
s
.66197 .76956 m .619 .80103 L .59838 .78683 L p .782 .79 .859 r
F P
0 g
s
.45141 .38813 m .44957 .42506 L .35794 .45141 L p .529 .27 .466 r
F P
0 g
s
.35898 .49424 m .35794 .45141 L .44957 .42506 L p .564 .349 .548 r
F P
0 g
s
.44957 .42506 m .45141 .38813 L .55143 .38262 L p .653 .372 .481 r
F P
0 g
s
.73107 .51325 m .72338 .55941 L .64535 .52742 L p .841 .624 .608 r
F P
0 g
s
.64535 .52742 m .65009 .47908 L .73107 .51325 L p .841 .624 .608 r
F P
0 g
s
.49991 .77384 m .51309 .8122 L .49696 .81582 L p .644 .69 .878 r
F P
0 g
s
.49696 .81582 m .46784 .78124 L .49991 .77384 L p .644 .69 .878 r
F P
0 g
s
.70037 .73246 m .66197 .76956 L .63227 .74823 L p .821 .785 .818 r
F P
0 g
s
.63227 .74823 m .66282 .70429 L .70037 .73246 L p .821 .785 .818 r
F P
0 g
s
.59838 .78683 m .63227 .74823 L .66197 .76956 L p .782 .79 .859 r
F P
0 g
s
.54788 .81367 m .56933 .77683 L .59838 .78683 L p .72 .759 .883 r
F P
0 g
s
.56933 .77683 m .54788 .81367 L .53074 .81146 L p .699 .73 .875 r
F P
0 g
s
.55143 .38262 m .55205 .41952 L .44957 .42506 L p .653 .372 .481 r
F P
0 g
s
.53515 .7723 m .53074 .81146 L .51309 .8122 L p .674 .707 .873 r
F P
0 g
s
.51309 .8122 m .49991 .77384 L .53515 .7723 L p .674 .707 .873 r
F P
0 g
s
.53074 .81146 m .53515 .7723 L .56933 .77683 L p .699 .73 .875 r
F P
0 g
s
.44018 .73977 m .46784 .78124 L .44268 .79354 L p .593 .62 .848 r
F P
0 g
s
.44268 .79354 m .40361 .75833 L .44018 .73977 L p .593 .62 .848 r
F P
0 g
s
.36534 .5416 m .37704 .59185 L .31556 .62686 L p .496 .392 .667 r
F P
0 g
s
.33883 .67322 m .31556 .62686 L .37704 .59185 L p .526 .454 .718 r
F P
0 g
s
.65087 .43578 m .65009 .47908 L .55189 .46331 L p .759 .507 .552 r
F P
0 g
s
.55189 .46331 m .55205 .41952 L .65087 .43578 L p .759 .507 .552 r
F P
0 g
s
.63227 .74823 m .59838 .78683 L .56933 .77683 L p .756 .741 .839 r
F P
0 g
s
.41517 .69305 m .44018 .73977 L .40361 .75833 L p .573 .565 .806 r
F P
0 g
s
.40361 .75833 m .36853 .71766 L .41517 .69305 L p .573 .565 .806 r
F P
0 g
s
.37704 .59185 m .39384 .64304 L .33883 .67322 L p .526 .454 .718 r
F P
0 g
s
.36853 .71766 m .33883 .67322 L .39384 .64304 L p .551 .511 .764 r
F P
0 g
s
.72338 .55941 m .70919 .60789 L .63663 .57909 L p .83 .654 .664 r
F P
0 g
s
.63663 .57909 m .64535 .52742 L .72338 .55941 L p .83 .654 .664 r
F P
0 g
s
.39384 .64304 m .41517 .69305 L .36853 .71766 L p .551 .511 .764 r
F P
0 g
s
.44957 .42506 m .45005 .46868 L .35898 .49424 L p .564 .349 .548 r
F P
0 g
s
.36534 .5416 m .35898 .49424 L .45005 .46868 L p .588 .411 .61 r
F P
0 g
s
.48733 .72853 m .49991 .77384 L .46784 .78124 L p .642 .64 .832 r
F P
0 g
s
.46784 .78124 m .44018 .73977 L .48733 .72853 L p .642 .64 .832 r
F P
0 g
s
.45005 .46868 m .44957 .42506 L .55205 .41952 L p .67 .434 .554 r
F P
0 g
s
.56933 .77683 m .58976 .73309 L .63227 .74823 L p .756 .741 .839 r
F P
0 g
s
.58976 .73309 m .56933 .77683 L .53515 .7723 L p .723 .7 .828 r
F P
0 g
s
.66282 .70429 m .63227 .74823 L .58976 .73309 L p .781 .722 .797 r
F P
0 g
s
.70919 .60789 m .68879 .65685 L .62413 .63208 L p .817 .679 .712 r
F P
0 g
s
.62413 .63208 m .63663 .57909 L .70919 .60789 L p .817 .679 .712 r
F P
0 g
s
.55205 .41952 m .55189 .46331 L .45005 .46868 L p .67 .434 .554 r
F P
0 g
s
.53937 .7262 m .53515 .7723 L .49991 .77384 L p .685 .666 .826 r
F P
0 g
s
.49991 .77384 m .48733 .72853 L .53937 .7262 L p .685 .666 .826 r
F P
0 g
s
.53515 .7723 m .53937 .7262 L .58976 .73309 L p .723 .7 .828 r
F P
0 g
s
.68879 .65685 m .66282 .70429 L .6083 .68415 L p .801 .701 .755 r
F P
0 g
s
.58976 .73309 m .6083 .68415 L .66282 .70429 L p .781 .722 .797 r
F P
0 g
s
.6083 .68415 m .62413 .63208 L .68879 .65685 L p .801 .701 .755 r
F P
0 g
s
.65009 .47908 m .64535 .52742 L .5509 .51267 L p .761 .549 .611 r
F P
0 g
s
.5509 .51267 m .55189 .46331 L .65009 .47908 L p .761 .549 .611 r
F P
0 g
s
.45005 .46868 m .45298 .51769 L .36534 .5416 L p .588 .411 .61 r
F P
0 g
s
.37704 .59185 m .36534 .5416 L .45298 .51769 L p .605 .463 .662 r
F P
0 g
s
.4759 .67807 m .48733 .72853 L .44018 .73977 L p .637 .595 .79 r
F P
0 g
s
.44018 .73977 m .41517 .69305 L .4759 .67807 L p .637 .595 .79 r
F P
0 g
s
.45298 .51769 m .45005 .46868 L .55189 .46331 L p .681 .482 .611 r
F P
0 g
s
.6083 .68415 m .58976 .73309 L .53937 .7262 L p .738 .671 .785 r
F P
0 g
s
.45298 .51769 m .45839 .57035 L .37704 .59185 L p .605 .463 .662 r
F P
0 g
s
.39384 .64304 m .37704 .59185 L .45839 .57035 L p .618 .509 .707 r
F P
0 g
s
.46612 .62458 m .4759 .67807 L .41517 .69305 L p .629 .552 .749 r
F P
0 g
s
.41517 .69305 m .39384 .64304 L .46612 .62458 L p .629 .552 .749 r
F P
0 g
s
.45839 .57035 m .46612 .62458 L .39384 .64304 L p .618 .509 .707 r
F P
0 g
s
.64535 .52742 m .63663 .57909 L .54909 .56585 L p .759 .584 .66 r
F P
0 g
s
.54909 .56585 m .5509 .51267 L .64535 .52742 L p .759 .584 .66 r
F P
0 g
s
.55189 .46331 m .5509 .51267 L .45298 .51769 L p .681 .482 .611 r
F P
0 g
s
.5432 .67495 m .53937 .7262 L .48733 .72853 L p .69 .629 .783 r
F P
0 g
s
.48733 .72853 m .4759 .67807 L .5432 .67495 L p .69 .629 .783 r
F P
0 g
s
.53937 .7262 m .5432 .67495 L .6083 .68415 L p .738 .671 .785 r
F P
0 g
s
.62413 .63208 m .6083 .68415 L .5432 .67495 L p .748 .643 .744 r
F P
0 g
s
.63663 .57909 m .62413 .63208 L .54649 .62071 L p .754 .614 .703 r
F P
0 g
s
.54649 .62071 m .54909 .56585 L .63663 .57909 L p .754 .614 .703 r
F P
0 g
s
.45839 .57035 m .45298 .51769 L .5509 .51267 L p .687 .523 .659 r
F P
0 g
s
.5432 .67495 m .54649 .62071 L .62413 .63208 L p .748 .643 .744 r
F P
0 g
s
.54649 .62071 m .5432 .67495 L .4759 .67807 L p .692 .594 .742 r
F P
0 g
s
.4759 .67807 m .46612 .62458 L .54649 .62071 L p .692 .594 .742 r
F P
0 g
s
.5509 .51267 m .54909 .56585 L .45839 .57035 L p .687 .523 .659 r
F P
0 g
s
.46612 .62458 m .45839 .57035 L .54909 .56585 L p .691 .56 .702 r
F P
0 g
s
.54909 .56585 m .54649 .62071 L .46612 .62458 L p .691 .56 .702 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47907 .59191 m .47333 .63042 L .54421 .63377 L p .719 .589 .708 r
F P
0 g
s
.54421 .63377 m .54228 .59497 L .47907 .59191 L p .719 .589 .708 r
F P
0 g
s
.54581 .67344 m .54421 .63377 L .47333 .63042 L p .72 .565 .678 r
F P
0 g
s
.54228 .59497 m .54421 .63377 L .61358 .6237 L p .668 .549 .71 r
F P
0 g
s
.54421 .63377 m .54581 .67344 L .62142 .66274 L p .663 .52 .679 r
F P
0 g
s
.62142 .66274 m .61358 .6237 L .54421 .63377 L p .663 .52 .679 r
F P
0 g
s
.48563 .5549 m .47907 .59191 L .54228 .59497 L p .717 .611 .737 r
F P
0 g
s
.54228 .59497 m .54006 .5576 L .48563 .5549 L p .717 .611 .737 r
F P
0 g
s
.54006 .5576 m .54228 .59497 L .60409 .58578 L p .672 .576 .739 r
F P
0 g
s
.61358 .6237 m .60409 .58578 L .54228 .59497 L p .668 .549 .71 r
F P
0 g
s
.43488 .54162 m .42 .5768 L .47907 .59191 L p .76 .652 .742 r
F P
0 g
s
.47907 .59191 m .48563 .5549 L .43488 .54162 L p .76 .652 .742 r
F P
0 g
s
.47333 .63042 m .47907 .59191 L .42 .5768 L p .768 .634 .713 r
F P
0 g
s
.42 .5768 m .40695 .61385 L .47333 .63042 L p .768 .634 .713 r
F P
0 g
s
.46859 .66988 m .47333 .63042 L .40695 .61385 L p .774 .615 .682 r
F P
0 g
s
.47333 .63042 m .46859 .66988 L .54581 .67344 L p .72 .565 .678 r
F P
0 g
s
.54701 .71327 m .54581 .67344 L .46859 .66988 L p .72 .539 .645 r
F P
0 g
s
.54581 .67344 m .54701 .71327 L .62731 .70219 L p .657 .489 .645 r
F P
0 g
s
.62731 .70219 m .62142 .66274 L .54581 .67344 L p .657 .489 .645 r
F P
0 g
s
.49287 .51981 m .48563 .5549 L .54006 .5576 L p .714 .632 .764 r
F P
0 g
s
.54006 .5576 m .53762 .52207 L .49287 .51981 L p .714 .632 .764 r
F P
0 g
s
.53762 .52207 m .54006 .5576 L .59326 .54951 L p .675 .602 .766 r
F P
0 g
s
.60409 .58578 m .59326 .54951 L .54006 .5576 L p .672 .576 .739 r
F P
0 g
s
.45124 .50868 m .43488 .54162 L .48563 .5549 L p .75 .668 .77 r
F P
0 g
s
.48563 .5549 m .49287 .51981 L .45124 .50868 L p .75 .668 .77 r
F P
0 g
s
.40695 .61385 m .39615 .65225 L .46859 .66988 L p .774 .615 .682 r
F P
0 g
s
.46504 .70958 m .46859 .66988 L .39615 .65225 L p .779 .592 .647 r
F P
0 g
s
.46859 .66988 m .46504 .70958 L .54701 .71327 L p .72 .539 .645 r
F P
0 g
s
.59326 .54951 m .60409 .58578 L .65904 .56496 L p .622 .546 .748 r
F P
0 g
s
.60409 .58578 m .61358 .6237 L .67545 .60084 L p .611 .512 .718 r
F P
0 g
s
.67545 .60084 m .65904 .56496 L .60409 .58578 L p .611 .512 .718 r
F P
0 g
s
.61358 .6237 m .62142 .66274 L .68906 .63839 L p .598 .477 .686 r
F P
0 g
s
.68906 .63839 m .67545 .60084 L .61358 .6237 L p .598 .477 .686 r
F P
0 g
s
.59326 .54951 m .58132 .51529 L .53762 .52207 L p .675 .602 .766 r
F P
0 g
s
.58132 .51529 m .59326 .54951 L .64035 .53123 L p .632 .578 .776 r
F P
0 g
s
.65904 .56496 m .64035 .53123 L .59326 .54951 L p .622 .546 .748 r
F P
0 g
s
.50065 .48695 m .49287 .51981 L .53762 .52207 L p .709 .653 .792 r
F P
0 g
s
.53762 .52207 m .535 .48872 L .50065 .48695 L p .709 .653 .792 r
F P
0 g
s
.535 .48872 m .53762 .52207 L .58132 .51529 L p .677 .628 .794 r
F P
0 g
s
.54774 .75238 m .54701 .71327 L .46504 .70958 L p .717 .509 .606 r
F P
0 g
s
.54701 .71327 m .54774 .75238 L .6309 .74121 L p .648 .453 .606 r
F P
0 g
s
.6309 .74121 m .62731 .70219 L .54701 .71327 L p .648 .453 .606 r
F P
0 g
s
.46879 .47826 m .45124 .50868 L .49287 .51981 L p .739 .683 .797 r
F P
0 g
s
.49287 .51981 m .50065 .48695 L .46879 .47826 L p .739 .683 .797 r
F P
0 g
s
.62142 .66274 m .62731 .70219 L .6993 .67695 L p .583 .437 .649 r
F P
0 g
s
.6993 .67695 m .68906 .63839 L .62142 .66274 L p .583 .437 .649 r
F P
0 g
s
.39615 .65225 m .38804 .69133 L .46504 .70958 L p .779 .592 .647 r
F P
0 g
s
.46287 .74867 m .46504 .70958 L .38804 .69133 L p .783 .566 .606 r
F P
0 g
s
.46504 .70958 m .46287 .74867 L .54774 .75238 L p .717 .509 .606 r
F P
0 g
s
.39258 .51873 m .37048 .55068 L .42 .5768 L p .801 .701 .755 r
F P
0 g
s
.42 .5768 m .43488 .54162 L .39258 .51873 L p .801 .701 .755 r
F P
0 g
s
.40695 .61385 m .42 .5768 L .37048 .55068 L p .815 .689 .725 r
F P
0 g
s
.58132 .51529 m .56851 .48342 L .535 .48872 L p .677 .628 .794 r
F P
0 g
s
.56851 .48342 m .58132 .51529 L .61984 .49999 L p .641 .61 .802 r
F P
0 g
s
.64035 .53123 m .61984 .49999 L .58132 .51529 L p .632 .578 .776 r
F P
0 g
s
.37048 .55068 m .35102 .58513 L .40695 .61385 L p .815 .689 .725 r
F P
0 g
s
.39615 .65225 m .40695 .61385 L .35102 .58513 L p .829 .675 .691 r
F P
0 g
s
.41678 .48957 m .39258 .51873 L .43488 .54162 L p .784 .711 .783 r
F P
0 g
s
.43488 .54162 m .45124 .50868 L .41678 .48957 L p .784 .711 .783 r
F P
0 g
s
.50887 .45656 m .50065 .48695 L .535 .48872 L p .702 .674 .82 r
F P
0 g
s
.535 .48872 m .53222 .45779 L .50887 .45656 L p .702 .674 .82 r
F P
0 g
s
.53222 .45779 m .535 .48872 L .56851 .48342 L p .677 .656 .821 r
F P
0 g
s
.62731 .70219 m .6309 .74121 L .70556 .71571 L p .565 .392 .606 r
F P
0 g
s
.70556 .71571 m .6993 .67695 L .62731 .70219 L p .565 .392 .606 r
F P
0 g
s
.44259 .4634 m .41678 .48957 L .45124 .50868 L p .765 .719 .81 r
F P
0 g
s
.45124 .50868 m .46879 .47826 L .44259 .4634 L p .765 .719 .81 r
F P
0 g
s
.35102 .58513 m .33485 .62161 L .39615 .65225 L p .829 .675 .691 r
F P
0 g
s
.38804 .69133 m .39615 .65225 L .33485 .62161 L p .841 .656 .652 r
F P
0 g
s
.48727 .45056 m .46879 .47826 L .50065 .48695 L p .725 .698 .824 r
F P
0 g
s
.50065 .48695 m .50887 .45656 L .48727 .45056 L p .725 .698 .824 r
F P
0 g
s
.54793 .78975 m .54774 .75238 L .46287 .74867 L p .712 .472 .56 r
F P
0 g
s
.54774 .75238 m .54793 .78975 L .63187 .77875 L p .636 .41 .559 r
F P
0 g
s
.63187 .77875 m .6309 .74121 L .54774 .75238 L p .636 .41 .559 r
F P
0 g
s
.56851 .48342 m .55498 .45412 L .53222 .45779 L p .677 .656 .821 r
F P
0 g
s
.55498 .45412 m .56851 .48342 L .5979 .47149 L p .65 .642 .829 r
F P
0 g
s
.61984 .49999 m .5979 .47149 L .56851 .48342 L p .641 .61 .802 r
F P
0 g
s
.64035 .53123 m .65904 .56496 L .70179 .53399 L p .562 .52 .765 r
F P
0 g
s
.65904 .56496 m .67545 .60084 L .72394 .5667 L p .54 .477 .734 r
F P
0 g
s
.72394 .5667 m .70179 .53399 L .65904 .56496 L p .54 .477 .734 r
F P
0 g
s
.61984 .49999 m .64035 .53123 L .67669 .50416 L p .583 .559 .793 r
F P
0 g
s
.70179 .53399 m .67669 .50416 L .64035 .53123 L p .562 .52 .765 r
F P
0 g
s
.38804 .69133 m .38308 .73024 L .46287 .74867 L p .783 .566 .606 r
F P
0 g
s
.46228 .78609 m .46287 .74867 L .38308 .73024 L p .784 .532 .556 r
F P
0 g
s
.46287 .74867 m .46228 .78609 L .54793 .78975 L p .712 .472 .56 r
F P
0 g
s
.67545 .60084 m .68906 .63839 L .74239 .60191 L p .514 .43 .698 r
F P
0 g
s
.74239 .60191 m .72394 .5667 L .67545 .60084 L p .514 .43 .698 r
F P
0 g
s
.5979 .47149 m .61984 .49999 L .6493 .47745 L p .602 .597 .819 r
F P
0 g
s
.67669 .50416 m .6493 .47745 L .61984 .49999 L p .583 .559 .793 r
F P
0 g
s
.46965 .44034 m .44259 .4634 L .46879 .47826 L p .744 .726 .835 r
F P
0 g
s
.46879 .47826 m .48727 .45056 L .46965 .44034 L p .744 .726 .835 r
F P
0 g
s
.33485 .62161 m .32268 .65954 L .38804 .69133 L p .841 .656 .652 r
F P
0 g
s
.38308 .73024 m .38804 .69133 L .32268 .65954 L p .851 .632 .605 r
F P
0 g
s
.51745 .42885 m .50887 .45656 L .53222 .45779 L p .693 .697 .85 r
F P
0 g
s
.53222 .45779 m .52932 .42948 L .51745 .42885 L p .693 .697 .85 r
F P
0 g
s
.52932 .42948 m .53222 .45779 L .55498 .45412 L p .676 .685 .851 r
F P
0 g
s
.6309 .74121 m .63187 .77875 L .70724 .75366 L p .541 .337 .552 r
F P
0 g
s
.70724 .75366 m .70556 .71571 L .6309 .74121 L p .541 .337 .552 r
F P
0 g
s
.68906 .63839 m .6993 .67695 L .75631 .63906 L p .485 .376 .656 r
F P
0 g
s
.75631 .63906 m .74239 .60191 L .68906 .63839 L p .485 .376 .656 r
F P
0 g
s
.5065 .42576 m .48727 .45056 L .50887 .45656 L p .707 .713 .853 r
F P
0 g
s
.50887 .45656 m .51745 .42885 L .5065 .42576 L p .707 .713 .853 r
F P
0 g
s
.5979 .47149 m .57484 .4459 L .55498 .45412 L p .65 .642 .829 r
F P
0 g
s
.57484 .4459 m .5979 .47149 L .62016 .45401 L p .621 .635 .843 r
F P
0 g
s
.6493 .47745 m .62016 .45401 L .5979 .47149 L p .602 .597 .819 r
F P
0 g
s
.3931 .46412 m .36316 .48808 L .39258 .51873 L p .814 .763 .806 r
F P
0 g
s
.39258 .51873 m .41678 .48957 L .3931 .46412 L p .814 .763 .806 r
F P
0 g
s
.37048 .55068 m .39258 .51873 L .36316 .48808 L p .839 .763 .778 r
F P
0 g
s
.55498 .45412 m .54087 .42759 L .52932 .42948 L p .676 .685 .851 r
F P
0 g
s
.54087 .42759 m .55498 .45412 L .57484 .4459 L p .658 .676 .856 r
F P
0 g
s
.42484 .44372 m .3931 .46412 L .41678 .48957 L p .787 .762 .83 r
F P
0 g
s
.41678 .48957 m .44259 .4634 L .42484 .44372 L p .787 .762 .83 r
F P
0 g
s
.36316 .48808 m .33563 .51552 L .37048 .55068 L p .839 .763 .778 r
F P
0 g
s
.35102 .58513 m .37048 .55068 L .33563 .51552 L p .863 .759 .746 r
F P
0 g
s
.49764 .42052 m .46965 .44034 L .48727 .45056 L p .719 .731 .86 r
F P
0 g
s
.48727 .45056 m .5065 .42576 L .49764 .42052 L p .719 .731 .86 r
F P
0 g
s
.54753 .82418 m .54793 .78975 L .46228 .78609 L p .703 .425 .5 r
F P
0 g
s
.54793 .78975 m .54753 .82418 L .6299 .81364 L p .618 .356 .497 r
F P
0 g
s
.6299 .81364 m .63187 .77875 L .54793 .78975 L p .618 .356 .497 r
F P
0 g
s
.45788 .4269 m .42484 .44372 L .44259 .4634 L p .758 .757 .852 r
F P
0 g
s
.44259 .4634 m .46965 .44034 L .45788 .4269 L p .758 .757 .852 r
F P
0 g
s
.33563 .51552 m .31127 .54627 L .35102 .58513 L p .863 .759 .746 r
F P
0 g
s
.33485 .62161 m .35102 .58513 L .31127 .54627 L p .887 .751 .707 r
F P
0 g
s
.57484 .4459 m .55091 .42336 L .54087 .42759 L p .658 .676 .856 r
F P
0 g
s
.55091 .42336 m .57484 .4459 L .58973 .43392 L p .64 .673 .866 r
F P
0 g
s
.62016 .45401 m .58973 .43392 L .57484 .4459 L p .621 .635 .843 r
F P
0 g
s
.38308 .73024 m .38175 .76796 L .46228 .78609 L p .784 .532 .556 r
F P
0 g
s
.46347 .82067 m .46228 .78609 L .38175 .76796 L p .781 .488 .491 r
F P
0 g
s
.46228 .78609 m .46347 .82067 L .54753 .82418 L p .703 .425 .5 r
F P
0 g
s
.32268 .65954 m .31522 .69811 L .38308 .73024 L p .851 .632 .605 r
F P
0 g
s
.38175 .76796 m .38308 .73024 L .31522 .69811 L p .859 .599 .545 r
F P
0 g
s
.6993 .67695 m .70556 .71571 L .76484 .67739 L p .448 .312 .602 r
F P
0 g
s
.76484 .67739 m .75631 .63906 L .6993 .67695 L p .448 .312 .602 r
F P
0 g
s
.62016 .45401 m .6493 .47745 L .66639 .44966 L p .559 .593 .843 r
F P
0 g
s
.6493 .47745 m .67669 .50416 L .69819 .47057 L p .525 .547 .821 r
F P
0 g
s
.69819 .47057 m .66639 .44966 L .6493 .47745 L p .525 .547 .821 r
F P
0 g
s
.49181 .41366 m .45788 .4269 L .46965 .44034 L p .726 .75 .872 r
F P
0 g
s
.46965 .44034 m .49764 .42052 L .49181 .41366 L p .726 .75 .872 r
F P
0 g
s
.67669 .50416 m .70179 .53399 L .72753 .49534 L p .487 .497 .794 r
F P
0 g
s
.72753 .49534 m .69819 .47057 L .67669 .50416 L p .487 .497 .794 r
F P
0 g
s
.58973 .43392 m .62016 .45401 L .63281 .4326 L p .592 .635 .863 r
F P
0 g
s
.66639 .44966 m .63281 .4326 L .62016 .45401 L p .559 .593 .843 r
F P
0 g
s
.52932 .42948 m .52632 .40403 L .51745 .42885 L closepath p .678 .721 .881 r
F P
0 g
s
.54087 .42759 m .52632 .40403 L .52932 .42948 L closepath p .672 .716 .882 r
F P
0 g
s
.31127 .54627 m .29093 .58002 L .33485 .62161 L p .887 .751 .707 r
F P
0 g
s
.32268 .65954 m .33485 .62161 L .29093 .58002 L p .908 .738 .659 r
F P
0 g
s
.51745 .42885 m .52632 .40403 L .5065 .42576 L closepath p .684 .727 .883 r
F P
0 g
s
.55091 .42336 m .52632 .40403 L .54087 .42759 L closepath p .666 .714 .884 r
F P
0 g
s
.63187 .77875 m .6299 .81364 L .70381 .78961 L p .509 .266 .481 r
F P
0 g
s
.70381 .78961 m .70724 .75366 L .63187 .77875 L p .509 .266 .481 r
F P
0 g
s
.70179 .53399 m .72394 .5667 L .75357 .52389 L p .443 .44 .76 r
F P
0 g
s
.75357 .52389 m .72753 .49534 L .70179 .53399 L p .443 .44 .76 r
F P
0 g
s
.5065 .42576 m .52632 .40403 L .49764 .42052 L closepath p .687 .733 .886 r
F P
0 g
s
.58973 .43392 m .55835 .41723 L .55091 .42336 L p .64 .673 .866 r
F P
0 g
s
.55835 .41723 m .58973 .43392 L .598 .41935 L p .623 .675 .879 r
F P
0 g
s
.63281 .4326 m .598 .41935 L .58973 .43392 L p .592 .635 .863 r
F P
0 g
s
.55835 .41723 m .52632 .40403 L .55091 .42336 L closepath p .659 .713 .888 r
F P
0 g
s
.49764 .42052 m .52632 .40403 L .49181 .41366 L closepath p .689 .74 .89 r
F P
0 g
s
.45334 .41158 m .41767 .42113 L .42484 .44372 L p .764 .79 .875 r
F P
0 g
s
.42484 .44372 m .45788 .4269 L .45334 .41158 L p .764 .79 .875 r
F P
0 g
s
.3931 .46412 m .42484 .44372 L .41767 .42113 L p .8 .809 .859 r
F P
0 g
s
.72394 .5667 m .74239 .60191 L .77538 .55597 L p .392 .372 .717 r
F P
0 g
s
.77538 .55597 m .75357 .52389 L .72394 .5667 L p .392 .372 .717 r
F P
0 g
s
.70556 .71571 m .70724 .75366 L .76714 .71592 L p .402 .231 .533 r
F P
0 g
s
.76714 .71592 m .76484 .67739 L .70556 .71571 L p .402 .231 .533 r
F P
0 g
s
.41767 .42113 m .38313 .43468 L .3931 .46412 L p .8 .809 .859 r
F P
0 g
s
.36316 .48808 m .3931 .46412 L .38313 .43468 L p .835 .825 .839 r
F P
0 g
s
.48967 .40592 m .45334 .41158 L .45788 .4269 L p .727 .77 .886 r
F P
0 g
s
.45788 .4269 m .49181 .41366 L .48967 .40592 L p .727 .77 .886 r
F P
0 g
s
.56239 .40983 m .52632 .40403 L .55835 .41723 L closepath p .653 .714 .892 r
F P
0 g
s
.598 .41935 m .56239 .40983 L .55835 .41723 L p .623 .675 .879 r
F P
0 g
s
.29093 .58002 m .27555 .61626 L .32268 .65954 L p .908 .738 .659 r
F P
0 g
s
.31522 .69811 m .32268 .65954 L .27555 .61626 L p .928 .717 .597 r
F P
0 g
s
.54648 .85432 m .54753 .82418 L .46347 .82067 L p .686 .36 .418 r
F P
0 g
s
.54753 .82418 m .54648 .85432 L .62473 .84452 L p .59 .281 .413 r
F P
0 g
s
.62473 .84452 m .6299 .81364 L .54753 .82418 L p .59 .281 .413 r
F P
0 g
s
.38313 .43468 m .35029 .45237 L .36316 .48808 L p .835 .825 .839 r
F P
0 g
s
.33563 .51552 m .36316 .48808 L .35029 .45237 L p .87 .839 .812 r
F P
0 g
s
.31522 .69811 m .31321 .73633 L .38175 .76796 L p .859 .599 .545 r
F P
0 g
s
.38446 .8033 m .38175 .76796 L .31321 .73633 L p .861 .552 .464 r
F P
0 g
s
.38175 .76796 m .38446 .8033 L .46347 .82067 L p .781 .488 .491 r
F P
0 g
s
.49181 .41366 m .52632 .40403 L .48967 .40592 L closepath p .689 .746 .895 r
F P
0 g
s
.56239 .40983 m .598 .41935 L .5986 .40368 L p .608 .683 .895 r
F P
0 g
s
.598 .41935 m .63281 .4326 L .63416 .4094 L p .563 .643 .888 r
F P
0 g
s
.63416 .4094 m .5986 .40368 L .598 .41935 L p .563 .643 .888 r
F P
0 g
s
.56254 .40194 m .52632 .40403 L .56239 .40983 L closepath p .649 .717 .898 r
F P
0 g
s
.5986 .40368 m .56254 .40194 L .56239 .40983 L p .608 .683 .895 r
F P
0 g
s
.46659 .85106 m .46347 .82067 L .38446 .8033 L p .769 .424 .401 r
F P
0 g
s
.46347 .82067 m .46659 .85106 L .54648 .85432 L p .686 .36 .418 r
F P
0 g
s
.63281 .4326 m .66639 .44966 L .66874 .41931 L p .512 .598 .877 r
F P
0 g
s
.66874 .41931 m .63416 .4094 L .63281 .4326 L p .512 .598 .877 r
F P
0 g
s
.55136 .3881 m .52632 .40403 L .55874 .39442 L closepath p .647 .729 .909 r
F P
0 g
s
.5412 .38369 m .52632 .40403 L .55136 .3881 L closepath p .649 .736 .913 r
F P
0 g
s
.52937 .38171 m .52632 .40403 L .5412 .38369 L closepath p .654 .743 .916 r
F P
0 g
s
.51719 .38238 m .52632 .40403 L .52937 .38171 L closepath p .66 .749 .916 r
F P
0 g
s
.50604 .38563 m .52632 .40403 L .51719 .38238 L closepath p .668 .754 .915 r
F P
0 g
s
.49716 .39108 m .52632 .40403 L .50604 .38563 L closepath p .675 .755 .911 r
F P
0 g
s
.49151 .3981 m .52632 .40403 L .49716 .39108 L closepath p .682 .754 .906 r
F P
0 g
s
.48967 .40592 m .52632 .40403 L .49151 .3981 L closepath p .686 .751 .901 r
F P
0 g
s
.55874 .39442 m .52632 .40403 L .56254 .40194 L closepath p .647 .723 .904 r
F P
0 g
s
.74239 .60191 m .75631 .63906 L .7919 .59118 L p .33 .289 .661 r
F P
0 g
s
.7919 .59118 m .77538 .55597 L .74239 .60191 L p .33 .289 .661 r
F P
0 g
s
.35029 .45237 m .31988 .4743 L .33563 .51552 L p .87 .839 .812 r
F P
0 g
s
.31127 .54627 m .33563 .51552 L .31988 .4743 L p .906 .849 .776 r
F P
0 g
s
.45334 .41158 m .48967 .40592 L .49151 .3981 L p .722 .787 .903 r
F P
0 g
s
.66639 .44966 m .69819 .47057 L .70174 .43362 L p .454 .544 .859 r
F P
0 g
s
.70174 .43362 m .66874 .41931 L .66639 .44966 L p .454 .544 .859 r
F P
0 g
s
.49151 .3981 m .4567 .396 L .45334 .41158 L p .722 .787 .903 r
F P
0 g
s
.41767 .42113 m .45334 .41158 L .4567 .396 L p .758 .822 .902 r
F P
0 g
s
.56254 .40194 m .5986 .40368 L .59129 .38862 L p .597 .696 .912 r
F P
0 g
s
.59129 .38862 m .55874 .39442 L .56254 .40194 L p .597 .696 .912 r
F P
0 g
s
.6299 .81364 m .62473 .84452 L .69481 .8222 L p .461 .168 .38 r
F P
0 g
s
.69481 .8222 m .70381 .78961 L .6299 .81364 L p .461 .168 .38 r
F P
0 g
s
.4567 .396 m .49151 .3981 L .49716 .39108 L p .708 .798 .921 r
F P
0 g
s
.27555 .61626 m .26612 .65429 L .31522 .69811 L p .928 .717 .597 r
F P
0 g
s
.31321 .73633 m .31522 .69811 L .26612 .65429 L p .943 .682 .512 r
F P
0 g
s
.4567 .396 m .42224 .39796 L .41767 .42113 L p .758 .822 .902 r
F P
0 g
s
.38313 .43468 m .41767 .42113 L .42224 .39796 L p .796 .857 .896 r
F P
0 g
s
.31988 .4743 m .2928 .50047 L .31127 .54627 L p .906 .849 .776 r
F P
0 g
s
.29093 .58002 m .31127 .54627 L .2928 .50047 L p .941 .854 .727 r
F P
0 g
s
.70724 .75366 m .70381 .78961 L .76246 .75349 L p .338 .125 .436 r
F P
0 g
s
.76246 .75349 m .76714 .71592 L .70724 .75366 L p .338 .125 .436 r
F P
0 g
s
.69819 .47057 m .72753 .49534 L .73242 .45254 L p .383 .478 .833 r
F P
0 g
s
.73242 .45254 m .70174 .43362 L .69819 .47057 L p .383 .478 .833 r
F P
0 g
s
.55874 .39442 m .59129 .38862 L .57668 .37587 L p .593 .716 .929 r
F P
0 g
s
.57668 .37587 m .55136 .3881 L .55874 .39442 L p .593 .716 .929 r
F P
0 g
s
.5986 .40368 m .63416 .4094 L .62363 .38691 L p .537 .662 .917 r
F P
0 g
s
.62363 .38691 m .59129 .38862 L .5986 .40368 L p .537 .662 .917 r
F P
0 g
s
.75631 .63906 m .76484 .67739 L .80206 .62886 L p .25 .184 .584 r
F P
0 g
s
.80206 .62886 m .7919 .59118 L .75631 .63906 L p .25 .184 .584 r
F P
0 g
s
.46778 .38189 m .49716 .39108 L .50604 .38563 L p .687 .803 .936 r
F P
0 g
s
.49716 .39108 m .46778 .38189 L .4567 .396 L p .708 .798 .921 r
F P
0 g
s
.55136 .3881 m .57668 .37587 L .55632 .36693 L p .597 .739 .943 r
F P
0 g
s
.55632 .36693 m .5412 .38369 L .55136 .3881 L p .597 .739 .943 r
F P
0 g
s
.42224 .39796 m .3886 .40425 L .38313 .43468 L p .796 .857 .896 r
F P
0 g
s
.35029 .45237 m .38313 .43468 L .3886 .40425 L p .835 .892 .881 r
F P
0 g
s
.31321 .73633 m .3173 .77302 L .38446 .8033 L p .861 .552 .464 r
F P
0 g
s
.39159 .83491 m .38446 .8033 L .3173 .77302 L p .851 .48 .347 r
F P
0 g
s
.38446 .8033 m .39159 .83491 L .46659 .85106 L p .769 .424 .401 r
F P
0 g
s
.42224 .39796 m .4567 .396 L .46778 .38189 L p .736 .846 .932 r
F P
0 g
s
.48549 .37086 m .50604 .38563 L .51719 .38238 L p .661 .797 .948 r
F P
0 g
s
.50604 .38563 m .48549 .37086 L .46778 .38189 L p .687 .803 .936 r
F P
0 g
s
.72753 .49534 m .75357 .52389 L .75983 .47618 L p .296 .394 .793 r
F P
0 g
s
.75983 .47618 m .73242 .45254 L .72753 .49534 L p .296 .394 .793 r
F P
0 g
s
.63416 .4094 m .66874 .41931 L .65535 .38965 L p .463 .617 .916 r
F P
0 g
s
.65535 .38965 m .62363 .38691 L .63416 .4094 L p .463 .617 .916 r
F P
0 g
s
.5412 .38369 m .55632 .36693 L .53247 .36289 L p .611 .762 .951 r
F P
0 g
s
.53247 .36289 m .52937 .38171 L .5412 .38369 L p .611 .762 .951 r
F P
0 g
s
.2928 .50047 m .27006 .53075 L .29093 .58002 L p .941 .854 .727 r
F P
0 g
s
.27555 .61626 m .29093 .58002 L .27006 .53075 L p .973 .848 .657 r
F P
0 g
s
.50791 .36426 m .51719 .38238 L .52937 .38171 L p .634 .783 .953 r
F P
0 g
s
.51719 .38238 m .50791 .36426 L .48549 .37086 L p .661 .797 .948 r
F P
0 g
s
.52937 .38171 m .53247 .36289 L .50791 .36426 L p .634 .783 .953 r
F P
0 g
s
.54474 .87875 m .54648 .85432 L .46659 .85106 L p .65 .262 .295 r
F P
0 g
s
.54648 .85432 m .54474 .87875 L .61617 .86996 L p .541 .169 .285 r
F P
0 g
s
.61617 .86996 m .62473 .84452 L .54648 .85432 L p .541 .169 .285 r
F P
0 g
s
.59129 .38862 m .62363 .38691 L .60202 .36773 L p .521 .692 .946 r
F P
0 g
s
.60202 .36773 m .57668 .37587 L .59129 .38862 L p .521 .692 .946 r
F P
0 g
s
.47177 .87582 m .46659 .85106 L .39159 .83491 L p .738 .324 .263 r
F P
0 g
s
.46659 .85106 m .47177 .87582 L .54474 .87875 L p .65 .262 .295 r
F P
0 g
s
.3886 .40425 m .35636 .41518 L .35029 .45237 L p .835 .892 .881 r
F P
0 g
s
.31988 .4743 m .35029 .45237 L .35636 .41518 L p .875 .926 .855 r
F P
0 g
s
.26612 .65429 m .26356 .69317 L .31321 .73633 L p .943 .682 .512 r
F P
0 g
s
.3173 .77302 m .31321 .73633 L .26356 .69317 L p .945 .621 .389 r
F P
0 g
s
.46778 .38189 m .43847 .3768 L .42224 .39796 L p .736 .846 .932 r
F P
0 g
s
.3886 .40425 m .42224 .39796 L .43847 .3768 L p .764 .897 .936 r
F P
0 g
s
.43847 .3768 m .46778 .38189 L .48549 .37086 L p .695 .855 .959 r
F P
0 g
s
.76484 .67739 m .76714 .71592 L .8048 .66811 L p .144 .044 .473 r
F P
0 g
s
.8048 .66811 m .80206 .62886 L .76484 .67739 L p .144 .044 .473 r
F P
0 g
s
.66874 .41931 m .70174 .43362 L .68585 .39724 L p .366 .553 .904 r
F P
0 g
s
.68585 .39724 m .65535 .38965 L .66874 .41931 L p .366 .553 .904 r
F P
0 g
s
.75357 .52389 m .77538 .55597 L .78292 .50453 L p .184 .283 .732 r
F P
0 g
s
.78292 .50453 m .75983 .47618 L .75357 .52389 L p .184 .283 .732 r
F P
0 g
s
.70381 .78961 m .69481 .8222 L .75021 .78872 L p .243 0 .292 r
F P
0 g
s
.75021 .78872 m .76246 .75349 L .70381 .78961 L p .243 0 .292 r
F P
0 g
s
.62473 .84452 m .61617 .86996 L .67995 .84997 L p .381 .022 .225 r
F P
0 g
s
.67995 .84997 m .69481 .8222 L .62473 .84452 L p .381 .022 .225 r
F P
0 g
s
.57668 .37587 m .60202 .36773 L .57152 .3542 L p .52 .731 .97 r
F P
0 g
s
.57152 .3542 m .55632 .36693 L .57668 .37587 L p .52 .731 .97 r
F P
0 g
s
.27006 .53075 m .25279 .56482 L .27555 .61626 L p .973 .848 .657 r
F P
0 g
s
.26612 .65429 m .27555 .61626 L .25279 .56482 L p .996 .824 .554 r
F P
0 g
s
.35636 .41518 m .32628 .43106 L .31988 .4743 L p .875 .926 .855 r
F P
0 g
s
.2928 .50047 m .31988 .4743 L .32628 .43106 L p .913 .954 .806 r
F P
0 g
s
.62363 .38691 m .65535 .38965 L .62702 .36417 L p .418 .651 .955 r
F P
0 g
s
.62702 .36417 m .60202 .36773 L .62363 .38691 L p .418 .651 .955 r
F P
0 g
s
.46487 .36016 m .48549 .37086 L .50791 .36426 L p .641 .845 .979 r
F P
0 g
s
.48549 .37086 m .46487 .36016 L .43847 .3768 L p .695 .855 .959 r
F P
0 g
s
.55632 .36693 m .57152 .3542 L .5356 .34807 L p .541 .775 .985 r
F P
0 g
s
.5356 .34807 m .53247 .36289 L .55632 .36693 L p .541 .775 .985 r
F P
0 g
s
.70174 .43362 m .73242 .45254 L .7144 .4101 L p .234 .461 .873 r
F P
0 g
s
.7144 .4101 m .68585 .39724 L .70174 .43362 L p .234 .461 .873 r
F P
0 g
s
.43847 .3768 m .40964 .37623 L .3886 .40425 L p .764 .897 .936 r
F P
0 g
s
.35636 .41518 m .3886 .40425 L .40964 .37623 L p .789 .948 .925 r
F P
0 g
s
.3173 .77302 m .32801 .80681 L .39159 .83491 L p .851 .48 .347 r
F P
0 g
s
.40338 .86135 m .39159 .83491 L .32801 .80681 L p .809 .357 .164 r
F P
0 g
s
.39159 .83491 m .40338 .86135 L .47177 .87582 L p .738 .324 .263 r
F P
0 g
s
.77538 .55597 m .7919 .59118 L .80049 .53735 L p .036 .133 .636 r
F P
0 g
s
.80049 .53735 m .78292 .50453 L .77538 .55597 L p .036 .133 .636 r
F P
0 g
s
.49857 .35015 m .50791 .36426 L .53247 .36289 L p .584 .816 .987 r
F P
0 g
s
.50791 .36426 m .49857 .35015 L .46487 .36016 L p .641 .845 .979 r
F P
0 g
s
.53247 .36289 m .5356 .34807 L .49857 .35015 L p .584 .816 .987 r
F P
0 g
s
.40964 .37623 m .43847 .3768 L .46487 .36016 L p .694 .911 .97 r
F P
0 g
s
.76714 .71592 m .76246 .75349 L .79923 .70778 L p 0 0 .306 r
F P
0 g
s
.79923 .70778 m .8048 .66811 L .76714 .71592 L p 0 0 .306 r
F P
0 g
s
.26356 .69317 m .26874 .73174 L .3173 .77302 L p .945 .621 .389 r
F P
0 g
s
.32801 .80681 m .3173 .77302 L .26874 .73174 L p .913 .513 .203 r
F P
0 g
s
.32628 .43106 m .29931 .45213 L .2928 .50047 L p .913 .954 .806 r
F P
0 g
s
.27006 .53075 m .2928 .50047 L .29931 .45213 L p .94 .964 .721 r
F P
0 g
s
.25279 .56482 m .24216 .6021 L .26612 .65429 L p .996 .824 .554 r
F P
0 g
s
.26356 .69317 m .26612 .65429 L .24216 .6021 L p .993 .762 .396 r
F P
0 g
s
.54229 .89599 m .54474 .87875 L .47177 .87582 L p .571 .097 .09 r
F P
0 g
s
.54474 .87875 m .54229 .89599 L .60416 .88847 L p .443 0 .071 r
F P
0 g
s
.60416 .88847 m .61617 .86996 L .54474 .87875 L p .443 0 .071 r
F P
0 g
s
.60202 .36773 m .62702 .36417 L .58659 .34609 L p .395 .7 .983 r
F P
0 g
s
.58659 .34609 m .57152 .3542 L .60202 .36773 L p .395 .7 .983 r
F P
0 g
s
.65535 .38965 m .68585 .39724 L .65123 .36576 L p .266 .576 .941 r
F P
0 g
s
.65123 .36576 m .62702 .36417 L .65535 .38965 L p .266 .576 .941 r
F P
0 g
s
.47903 .89348 m .47177 .87582 L .40338 .86135 L p .655 .15 .032 r
F P
0 g
s
.47177 .87582 m .47903 .89348 L .54229 .89599 L p .571 .097 .09 r
F P
0 g
s
.73242 .45254 m .75983 .47618 L .74009 .42857 L p .052 .322 .805 r
F P
0 g
s
.74009 .42857 m .7144 .4101 L .73242 .45254 L p .052 .322 .805 r
F P
0 g
s
.69481 .8222 m .67995 .84997 L .73003 .82011 L p .094 0 .067 r
F P
0 g
s
.73003 .82011 m .75021 .78872 L .69481 .8222 L p .094 0 .067 r
F P
0 g
s
.40964 .37623 m .38182 .38069 L .35636 .41518 L p .789 .948 .925 r
F P
0 g
s
.32628 .43106 m .35636 .41518 L .38182 .38069 L p .8 .99 .882 r
F P
0 g
s
.7919 .59118 m .80206 .62886 L .81133 .57418 L p 0 0 .483 r
F P
0 g
s
.81133 .57418 m .80049 .53735 L .7919 .59118 L p 0 0 .483 r
F P
0 g
s
.44447 .35407 m .46487 .36016 L .49857 .35015 L p .59 .888 .991 r
F P
0 g
s
.46487 .36016 m .44447 .35407 L .40964 .37623 L p .694 .911 .97 r
F P
0 g
s
.61617 .86996 m .60416 .88847 L .65914 .87142 L p .235 0 0 r
F P
0 g
s
.65914 .87142 m .67995 .84997 L .61617 .86996 L p .235 0 0 r
F P
0 g
s
.57152 .3542 m .58659 .34609 L .53871 .33788 L p .413 .763 .995 r
F P
0 g
s
.53871 .33788 m .5356 .34807 L .57152 .3542 L p .413 .763 .995 r
F P
0 g
s
.38182 .38069 m .40964 .37623 L .44447 .35407 L p .664 .955 .947 r
F P
0 g
s
.29931 .45213 m .27653 .47848 L .27006 .53075 L p .94 .964 .721 r
F P
0 g
s
.25279 .56482 m .27006 .53075 L .27653 .47848 L p .932 .933 .573 r
F P
0 g
s
.48929 .34066 m .49857 .35015 L .5356 .34807 L p .484 .831 .997 r
F P
0 g
s
.49857 .35015 m .48929 .34066 L .44447 .35407 L p .59 .888 .991 r
F P
0 g
s
.76246 .75349 m .75021 .78872 L .78465 .74648 L p 0 0 .055 r
F P
0 g
s
.78465 .74648 m .79923 .70778 L .76246 .75349 L p 0 0 .055 r
F P
0 g
s
.5356 .34807 m .53871 .33788 L .48929 .34066 L p .484 .831 .997 r
F P
0 g
s
.24216 .6021 m .23928 .64174 L .26356 .69317 L p .993 .762 .396 r
F P
0 g
s
.26874 .73174 m .26356 .69317 L .23928 .64174 L p .928 .631 .159 r
F P
0 g
s
.75983 .47618 m .78292 .50453 L .76185 .45291 L p 0 .117 .669 r
F P
0 g
s
.76185 .45291 m .74009 .42857 L .75983 .47618 L p 0 .117 .669 r
F P
0 g
s
.32801 .80681 m .34568 .83623 L .40338 .86135 L p .809 .357 .164 r
F P
0 g
s
.41991 .88111 m .40338 .86135 L .34568 .83623 L p .683 .138 0 r
F P
0 g
s
.40338 .86135 m .41991 .88111 L .47903 .89348 L p .655 .15 .032 r
F P
0 g
s
.68585 .39724 m .7144 .4101 L .67404 .37312 L p .035 .438 .871 r
F P
0 g
s
.67404 .37312 m .65123 .36576 L .68585 .39724 L p .035 .438 .871 r
F P
0 g
s
.26874 .73174 m .2823 .7686 L .32801 .80681 L p .913 .513 .203 r
F P
0 g
s
.34568 .83623 m .32801 .80681 L .2823 .7686 L p .802 .319 0 r
F P
0 g
s
.38182 .38069 m .35568 .39068 L .32628 .43106 L p .8 .99 .882 r
F P
0 g
s
.29931 .45213 m .32628 .43106 L .35568 .39068 L p .772 .991 .772 r
F P
0 g
s
.62702 .36417 m .65123 .36576 L .60125 .34331 L p .185 .613 .944 r
F P
0 g
s
.60125 .34331 m .58659 .34609 L .62702 .36417 L p .185 .613 .944 r
F P
0 g
s
.80206 .62886 m .8048 .66811 L .81427 .61421 L p 0 0 .246 r
F P
0 g
s
.81427 .61421 m .81133 .57418 L .80206 .62886 L p 0 0 .246 r
F P
0 g
s
.27653 .47848 m .25915 .51002 L .25279 .56482 L p .932 .933 .573 r
F P
0 g
s
.24216 .6021 m .25279 .56482 L .25915 .51002 L p .85 .817 .334 r
F P
0 g
s
.42466 .35322 m .44447 .35407 L .48929 .34066 L p .469 .883 .932 r
F P
0 g
s
.44447 .35407 m .42466 .35322 L .38182 .38069 L p .664 .955 .947 r
F P
0 g
s
.67995 .84997 m .65914 .87142 L .70194 .84607 L p 0 0 0 r
F P
0 g
s
.70194 .84607 m .73003 .82011 L .67995 .84997 L p 0 0 0 r
F P
0 g
s
.35568 .39068 m .38182 .38069 L .42466 .35322 L p .566 .937 .833 r
F P
0 g
s
.53914 .90462 m .54229 .89599 L .47903 .89348 L p .376 0 0 r
F P
0 g
s
.54229 .89599 m .53914 .90462 L .58876 .89862 L p .228 0 0 r
F P
0 g
s
.58876 .89862 m .60416 .88847 L .54229 .89599 L p .228 0 0 r
F P
0 g
s
.48836 .90262 m .47903 .89348 L .41991 .88111 L p .436 0 0 r
F P
0 g
s
.47903 .89348 m .48836 .90262 L .53914 .90462 L p .376 0 0 r
F P
0 g
s
.78292 .50453 m .80049 .53735 L .7785 .48313 L p 0 0 .429 r
F P
0 g
s
.7785 .48313 m .76185 .45291 L .78292 .50453 L p 0 0 .429 r
F P
0 g
s
.58659 .34609 m .60125 .34331 L .54175 .33306 L p .179 .673 .918 r
F P
0 g
s
.54175 .33306 m .53871 .33788 L .58659 .34609 L p .179 .673 .918 r
F P
0 g
s
.23928 .64174 m .24512 .68259 L .26874 .73174 L p .928 .631 .159 r
F P
0 g
s
.2823 .7686 m .26874 .73174 L .24512 .68259 L p .751 .397 0 r
F P
0 g
s
.7144 .4101 m .74009 .42857 L .69469 .38686 L p 0 .203 .686 r
F P
0 g
s
.69469 .38686 m .67404 .37312 L .7144 .4101 L p 0 .203 .686 r
F P
0 g
s
.35568 .39068 m .33209 .4067 L .29931 .45213 L p .772 .991 .772 r
F P
0 g
s
.27653 .47848 m .29931 .45213 L .33209 .4067 L p .657 .892 .547 r
F P
0 g
s
.75021 .78872 m .73003 .82011 L .76076 .78259 L p 0 0 0 r
F P
0 g
s
.76076 .78259 m .78465 .74648 L .75021 .78872 L p 0 0 0 r
F P
0 g
s
.48025 .33654 m .48929 .34066 L .53871 .33788 L p .281 .769 .909 r
F P
0 g
s
.48929 .34066 m .48025 .33654 L .42466 .35322 L p .469 .883 .932 r
F P
0 g
s
.60416 .88847 m .58876 .89862 L .63262 .88508 L p 0 0 0 r
F P
0 g
s
.63262 .88508 m .65914 .87142 L .60416 .88847 L p 0 0 0 r
F P
0 g
s
.8048 .66811 m .79923 .70778 L .80831 .65632 L p 0 0 0 r
F P
0 g
s
.80831 .65632 m .81427 .61421 L .8048 .66811 L p 0 0 0 r
F P
0 g
s
.53871 .33788 m .54175 .33306 L .48025 .33654 L p .281 .769 .909 r
F P
0 g
s
.65123 .36576 m .67404 .37312 L .61513 .34662 L p 0 .411 .771 r
F P
0 g
s
.61513 .34662 m .60125 .34331 L .65123 .36576 L p 0 .411 .771 r
F P
0 g
s
.2823 .7686 m .30456 .80221 L .34568 .83623 L p .802 .319 0 r
F P
0 g
s
.37035 .85974 m .34568 .83623 L .30456 .80221 L p .54 .011 0 r
F P
0 g
s
.34568 .83623 m .37035 .85974 L .41991 .88111 L p .683 .138 0 r
F P
0 g
s
.25915 .51002 m .24842 .54636 L .24216 .6021 L p .85 .817 .334 r
F P
0 g
s
.23928 .64174 m .24216 .6021 L .24842 .54636 L p 0 0 0 r
F P
0 g
s
.44104 .89277 m .41991 .88111 L .37035 .85974 L p .379 0 0 r
F P
0 g
s
.41991 .88111 m .44104 .89277 L .48836 .90262 L p .436 0 0 r
F P
0 g
s
.80049 .53735 m .81133 .57418 L .78879 .51896 L p .778 .454 0 r
F P
0 g
s
.78879 .51896 m .7785 .48313 L .80049 .53735 L p .778 .454 0 r
F P
0 g
s
.42466 .35322 m .40596 .35834 L .35568 .39068 L p .566 .937 .833 r
F P
0 g
s
.33209 .4067 m .35568 .39068 L .40596 .35834 L p 0 0 0 r
F P
0 g
s
.40596 .35834 m .42466 .35322 L .48025 .33654 L p .226 .737 .702 r
F P
0 g
s
.33209 .4067 m .31206 .42911 L .27653 .47848 L p .657 .892 .547 r
F P
0 g
s
.25915 .51002 m .27653 .47848 L .31206 .42911 L p 0 0 0 r
F P
0 g
s
.74009 .42857 m .76185 .45291 L .71226 .40746 L p .619 .105 0 r
F P
0 g
s
.71226 .40746 m .69469 .38686 L .74009 .42857 L p .619 .105 0 r
F P
0 g
s
.24512 .68259 m .26037 .72325 L .2823 .7686 L p .751 .397 0 r
F P
0 g
s
.30456 .80221 m .2823 .7686 L .26037 .72325 L p 0 0 .493 r
F P
0 g
s
.65914 .87142 m .63262 .88508 L .66635 .86507 L p .405 .832 .673 r
F P
0 g
s
.66635 .86507 m .70194 .84607 L .65914 .87142 L p .405 .832 .673 r
F P
0 g
s
.79923 .70778 m .78465 .74648 L .79278 .69907 L p .842 .85 .39 r
F P
0 g
s
.79278 .69907 m .80831 .65632 L .79923 .70778 L p .842 .85 .39 r
F P
0 g
s
.60125 .34331 m .61513 .34662 L .54462 .33449 L p .171 0 0 r
F P
0 g
s
.54462 .33449 m .54175 .33306 L .60125 .34331 L p .171 0 0 r
F P
0 g
s
.73003 .82011 m .70194 .84607 L .7277 .81443 L p .645 .917 .623 r
F P
0 g
s
.7277 .81443 m .76076 .78259 L .73003 .82011 L p .645 .917 .623 r
F P
0 g
s
.24842 .54636 m .24551 .58677 L .23928 .64174 L p 0 0 0 r
F P
0 g
s
.24512 .68259 m .23928 .64174 L .24551 .58677 L p 0 0 .299 r
F P
0 g
s
.48025 .33654 m .47168 .33861 L .40596 .35834 L p .226 .737 .702 r
F P
0 g
s
.47168 .33861 m .48025 .33654 L .54175 .33306 L p .044 0 0 r
F P
0 g
s
.53536 .90341 m .53914 .90462 L .48836 .90262 L p .019 .591 .751 r
F P
0 g
s
.53914 .90462 m .53536 .90341 L .57028 .89918 L p .15 .693 .769 r
F P
0 g
s
.57028 .89918 m .58876 .89862 L .53914 .90462 L p .15 .693 .769 r
F P
0 g
s
.67404 .37312 m .69469 .38686 L .62774 .35681 L p .491 0 0 r
F P
0 g
s
.62774 .35681 m .61513 .34662 L .67404 .37312 L p .491 0 0 r
F P
0 g
s
.49957 .902 m .48836 .90262 L .44104 .89277 L p 0 .549 .802 r
F P
0 g
s
.48836 .90262 m .49957 .902 L .53536 .90341 L p .019 .591 .751 r
F P
0 g
s
.54175 .33306 m .54462 .33449 L .47168 .33861 L p .044 0 0 r
F P
0 g
s
.30456 .80221 m .33547 .83095 L .37035 .85974 L p .54 .011 0 r
F P
0 g
s
.37035 .85974 m .40171 .87584 L .44104 .89277 L p .379 0 0 r
F P
0 g
s
.40171 .87584 m .37035 .85974 L .33547 .83095 L p 0 .329 .777 r
F P
0 g
s
.81133 .57418 m .81427 .61421 L .79159 .55974 L p .943 .674 .209 r
F P
0 g
s
.79159 .55974 m .78879 .51896 L .81133 .57418 L p .943 .674 .209 r
F P
0 g
s
.58876 .89862 m .57028 .89918 L .60094 .88968 L p .359 .832 .844 r
F P
0 g
s
.60094 .88968 m .63262 .88508 L .58876 .89862 L p .359 .832 .844 r
F P
0 g
s
.40596 .35834 m .38899 .37012 L .33209 .4067 L p 0 0 0 r
F P
0 g
s
.31206 .42911 m .33209 .4067 L .38899 .37012 L p 0 0 0 r
F P
0 g
s
.31206 .42911 m .29671 .45805 L .25915 .51002 L p 0 0 0 r
F P
0 g
s
.24842 .54636 m .25915 .51002 L .29671 .45805 L p 0 0 .107 r
F P
0 g
s
.76185 .45291 m .7785 .48313 L .72575 .4352 L p .836 .373 0 r
F P
0 g
s
.72575 .4352 m .71226 .40746 L .76185 .45291 L p .836 .373 0 r
F P
0 g
s
.38899 .37012 m .40596 .35834 L .47168 .33861 L p .077 0 0 r
F P
0 g
s
.46635 .89507 m .44104 .89277 L .40171 .87584 L p .054 .552 .885 r
F P
0 g
s
.44104 .89277 m .46635 .89507 L .49957 .902 L p 0 .549 .802 r
F P
0 g
s
.26037 .72325 m .28531 .76205 L .30456 .80221 L p 0 0 .493 r
F P
0 g
s
.33547 .83095 m .30456 .80221 L .28531 .76205 L p 0 .211 .736 r
F P
0 g
s
.78465 .74648 m .76076 .78259 L .76743 .74073 L p .912 .96 .634 r
F P
0 g
s
.76743 .74073 m .79278 .69907 L .78465 .74648 L p .912 .96 .634 r
F P
0 g
s
.24551 .58677 m .25141 .63015 L .24512 .68259 L p 0 0 .299 r
F P
0 g
s
.26037 .72325 m .24512 .68259 L .25141 .63015 L p 0 0 .537 r
F P
0 g
s
.70194 .84607 m .66635 .86507 L .68616 .8403 L p .733 .991 .843 r
F P
0 g
s
.68616 .8403 m .7277 .81443 L .70194 .84607 L p .733 .991 .843 r
F P
0 g
s
.61513 .34662 m .62774 .35681 L .54724 .34302 L p .48 0 0 r
F P
0 g
s
.54724 .34302 m .54462 .33449 L .61513 .34662 L p .48 0 0 r
F P
0 g
s
.63262 .88508 m .60094 .88968 L .62419 .87574 L p .581 .94 .918 r
F P
0 g
s
.62419 .87574 m .66635 .86507 L .63262 .88508 L p .581 .94 .918 r
F P
0 g
s
.81427 .61421 m .80831 .65632 L .78592 .60439 L p .997 .796 .445 r
F P
0 g
s
.78592 .60439 m .79159 .55974 L .81427 .61421 L p .997 .796 .445 r
F P
0 g
s
.69469 .38686 m .71226 .40746 L .63852 .37459 L p .716 .189 0 r
F P
0 g
s
.63852 .37459 m .62774 .35681 L .69469 .38686 L p .716 .189 0 r
F P
0 g
s
.46389 .34771 m .47168 .33861 L .54462 .33449 L p .342 0 0 r
F P
0 g
s
.47168 .33861 m .46389 .34771 L .38899 .37012 L p .077 0 0 r
F P
0 g
s
.29671 .45805 m .28719 .49337 L .24842 .54636 L p 0 0 .107 r
F P
0 g
s
.24551 .58677 m .24842 .54636 L .28719 .49337 L p .018 0 .351 r
F P
0 g
s
.54462 .33449 m .54724 .34302 L .46389 .34771 L p .342 0 0 r
F P
0 g
s
.38899 .37012 m .37451 .38916 L .31206 .42911 L p 0 0 0 r
F P
0 g
s
.29671 .45805 m .31206 .42911 L .37451 .38916 L p .133 0 .12 r
F P
0 g
s
.33547 .83095 m .37448 .8532 L .40171 .87584 L p 0 .329 .777 r
F P
0 g
s
.43902 .88323 m .40171 .87584 L .37448 .8532 L p .187 .568 .937 r
F P
0 g
s
.40171 .87584 m .43902 .88323 L .46635 .89507 L p .054 .552 .885 r
F P
0 g
s
.7785 .48313 m .78879 .51896 L .73413 .47003 L p .926 .545 .248 r
F P
0 g
s
.73413 .47003 m .72575 .4352 L .7785 .48313 L p .926 .545 .248 r
F P
0 g
s
.76076 .78259 m .7277 .81443 L .73259 .7794 L p .904 .982 .784 r
F P
0 g
s
.73259 .7794 m .76743 .74073 L .76076 .78259 L p .904 .982 .784 r
F P
0 g
s
.53103 .89147 m .53536 .90341 L .49957 .902 L p .399 .794 .987 r
F P
0 g
s
.53536 .90341 m .53103 .89147 L .54922 .88925 L p .464 .841 .988 r
F P
0 g
s
.54922 .88925 m .57028 .89918 L .53536 .90341 L p .464 .841 .988 r
F P
0 g
s
.28531 .76205 m .31971 .79721 L .33547 .83095 L p 0 .211 .736 r
F P
0 g
s
.37448 .8532 m .33547 .83095 L .31971 .79721 L p .13 .43 .87 r
F P
0 g
s
.51237 .89073 m .49957 .902 L .46635 .89507 L p .371 .753 .989 r
F P
0 g
s
.49957 .902 m .51237 .89073 L .53103 .89147 L p .399 .794 .987 r
F P
0 g
s
.25141 .63015 m .26679 .67503 L .26037 .72325 L p 0 0 .537 r
F P
0 g
s
.28531 .76205 m .26037 .72325 L .26679 .67503 L p .066 .199 .693 r
F P
0 g
s
.37451 .38916 m .38899 .37012 L .46389 .34771 L p .3 0 .029 r
F P
0 g
s
.57028 .89918 m .54922 .88925 L .56506 .88428 L p .551 .881 .99 r
F P
0 g
s
.56506 .88428 m .60094 .88968 L .57028 .89918 L p .551 .881 .99 r
F P
0 g
s
.80831 .65632 m .79278 .69907 L .77118 .6514 L p .991 .853 .604 r
F P
0 g
s
.77118 .6514 m .78592 .60439 L .80831 .65632 L p .991 .853 .604 r
F P
0 g
s
.66635 .86507 m .62419 .87574 L .63743 .85865 L p .735 .962 .94 r
F P
0 g
s
.63743 .85865 m .68616 .8403 L .66635 .86507 L p .735 .962 .94 r
F P
0 g
s
.49513 .88709 m .46635 .89507 L .43902 .88323 L p .382 .72 .989 r
F P
0 g
s
.46635 .89507 m .49513 .88709 L .51237 .89073 L p .371 .753 .989 r
F P
0 g
s
.62774 .35681 m .63852 .37459 L .54948 .35947 L p .643 .156 .08 r
F P
0 g
s
.54948 .35947 m .54724 .34302 L .62774 .35681 L p .643 .156 .08 r
F P
0 g
s
.71226 .40746 m .72575 .4352 L .64682 .40043 L p .811 .375 .207 r
F P
0 g
s
.64682 .40043 m .63852 .37459 L .71226 .40746 L p .811 .375 .207 r
F P
0 g
s
.28719 .49337 m .28461 .53448 L .24551 .58677 L p .018 0 .351 r
F P
0 g
s
.25141 .63015 m .24551 .58677 L .28461 .53448 L p .168 .089 .516 r
F P
0 g
s
.60094 .88968 m .56506 .88428 L .57688 .87705 L p .636 .901 .985 r
F P
0 g
s
.57688 .87705 m .62419 .87574 L .60094 .88968 L p .636 .901 .985 r
F P
0 g
s
.7277 .81443 m .68616 .8403 L .68922 .81313 L p .859 .96 .87 r
F P
0 g
s
.68922 .81313 m .73259 .7794 L .7277 .81443 L p .859 .96 .87 r
F P
0 g
s
.78879 .51896 m .79159 .55974 L .7364 .51144 L p .947 .643 .428 r
F P
0 g
s
.7364 .51144 m .73413 .47003 L .78879 .51896 L p .947 .643 .428 r
F P
0 g
s
.37451 .38916 m .36338 .41585 L .29671 .45805 L p .133 0 .12 r
F P
0 g
s
.28719 .49337 m .29671 .45805 L .36338 .41585 L p .277 .018 .33 r
F P
0 g
s
.26679 .67503 m .29182 .71959 L .28531 .76205 L p .066 .199 .693 r
F P
0 g
s
.31971 .79721 m .28531 .76205 L .29182 .71959 L p .221 .36 .793 r
F P
0 g
s
.45722 .36461 m .46389 .34771 L .54724 .34302 L p .511 .054 .103 r
F P
0 g
s
.46389 .34771 m .45722 .36461 L .37451 .38916 L p .3 0 .029 r
F P
0 g
s
.31971 .79721 m .36273 .8269 L .37448 .8532 L p .13 .43 .87 r
F P
0 g
s
.42047 .86753 m .37448 .8532 L .36273 .8269 L p .326 .577 .933 r
F P
0 g
s
.37448 .8532 m .42047 .86753 L .43902 .88323 L p .187 .568 .937 r
F P
0 g
s
.4811 .88092 m .43902 .88323 L .42047 .86753 L p .42 .696 .978 r
F P
0 g
s
.43902 .88323 m .4811 .88092 L .49513 .88709 L p .382 .72 .989 r
F P
0 g
s
.54724 .34302 m .54948 .35947 L .45722 .36461 L p .511 .054 .103 r
F P
0 g
s
.79278 .69907 m .76743 .74073 L .74724 .69888 L p .958 .874 .71 r
F P
0 g
s
.74724 .69888 m .77118 .6514 L .79278 .69907 L p .958 .874 .71 r
F P
0 g
s
.36338 .41585 m .37451 .38916 L .45722 .36461 L p .428 .073 .258 r
F P
0 g
s
.62419 .87574 m .57688 .87705 L .58338 .86828 L p .699 .895 .968 r
F P
0 g
s
.58338 .86828 m .63743 .85865 L .62419 .87574 L p .699 .895 .968 r
F P
0 g
s
.28461 .53448 m .28985 .58033 L .25141 .63015 L p .168 .089 .516 r
F P
0 g
s
.26679 .67503 m .25141 .63015 L .28985 .58033 L p .277 .234 .629 r
F P
0 g
s
.68616 .8403 m .63743 .85865 L .6389 .84012 L p .8 .919 .918 r
F P
0 g
s
.6389 .84012 m .68922 .81313 L .68616 .8403 L p .8 .919 .918 r
F P
0 g
s
.52632 .86843 m .53103 .89147 L .51237 .89073 L closepath p .579 .8 .983 r
F P
0 g
s
.52632 .86843 m .54922 .88925 L .53103 .89147 L closepath p .595 .811 .982 r
F P
0 g
s
.29182 .71959 m .32611 .76181 L .31971 .79721 L p .221 .36 .793 r
F P
0 g
s
.36273 .8269 m .31971 .79721 L .32611 .76181 L p .341 .484 .857 r
F P
0 g
s
.52632 .86843 m .51237 .89073 L .49513 .88709 L closepath p .569 .787 .981 r
F P
0 g
s
.52632 .86843 m .56506 .88428 L .54922 .88925 L closepath p .614 .819 .979 r
F P
0 g
s
.72575 .4352 m .73413 .47003 L .65198 .43447 L p .844 .486 .377 r
F P
0 g
s
.65198 .43447 m .64682 .40043 L .72575 .4352 L p .844 .486 .377 r
F P
0 g
s
.79159 .55974 m .78592 .60439 L .73179 .5584 L p .939 .7 .55 r
F P
0 g
s
.73179 .5584 m .7364 .51144 L .79159 .55974 L p .939 .7 .55 r
F P
0 g
s
.36273 .8269 m .41293 .84949 L .42047 .86753 L p .326 .577 .933 r
F P
0 g
s
.47179 .87282 m .42047 .86753 L .41293 .84949 L p .469 .678 .956 r
F P
0 g
s
.42047 .86753 m .47179 .87282 L .4811 .88092 L p .42 .696 .978 r
F P
0 g
s
.52632 .86843 m .49513 .88709 L .4811 .88092 L closepath p .566 .773 .976 r
F P
0 g
s
.63852 .37459 m .64682 .40043 L .55121 .38441 L p .714 .313 .287 r
F P
0 g
s
.55121 .38441 m .54948 .35947 L .63852 .37459 L p .714 .313 .287 r
F P
0 g
s
.36338 .41585 m .35646 .45025 L .28719 .49337 L p .277 .018 .33 r
F P
0 g
s
.28461 .53448 m .28719 .49337 L .35646 .45025 L p .369 .166 .469 r
F P
0 g
s
.76743 .74073 m .73259 .7794 L .71457 .74465 L p .914 .877 .785 r
F P
0 g
s
.71457 .74465 m .74724 .69888 L .76743 .74073 L p .914 .877 .785 r
F P
0 g
s
.52632 .86843 m .57688 .87705 L .56506 .88428 L closepath p .634 .821 .972 r
F P
0 g
s
.52632 .86843 m .4811 .88092 L .47179 .87282 L closepath p .569 .761 .969 r
F P
0 g
s
.45208 .38986 m .45722 .36461 L .54948 .35947 L p .595 .219 .3 r
F P
0 g
s
.45722 .36461 m .45208 .38986 L .36338 .41585 L p .428 .073 .258 r
F P
0 g
s
.28985 .58033 m .30346 .62938 L .26679 .67503 L p .277 .234 .629 r
F P
0 g
s
.29182 .71959 m .26679 .67503 L .30346 .62938 L p .358 .346 .71 r
F P
0 g
s
.32611 .76181 m .3686 .79959 L .36273 .8269 L p .341 .484 .857 r
F P
0 g
s
.41293 .84949 m .36273 .8269 L .3686 .79959 L p .437 .584 .901 r
F P
0 g
s
.63743 .85865 m .58338 .86828 L .58376 .85889 L p .734 .868 .944 r
F P
0 g
s
.58376 .85889 m .6389 .84012 L .63743 .85865 L p .734 .868 .944 r
F P
0 g
s
.52632 .86843 m .58338 .86828 L .57688 .87705 L closepath p .65 .819 .964 r
F P
0 g
s
.54948 .35947 m .55121 .38441 L .45208 .38986 L p .595 .219 .3 r
F P
0 g
s
.35646 .45025 m .36338 .41585 L .45208 .38986 L p .501 .211 .405 r
F P
0 g
s
.73259 .7794 m .68922 .81313 L .67425 .78645 L p .864 .869 .84 r
F P
0 g
s
.67425 .78645 m .71457 .74465 L .73259 .7794 L p .864 .869 .84 r
F P
0 g
s
.41293 .84949 m .46827 .86362 L .47179 .87282 L p .469 .678 .956 r
F P
0 g
s
.52632 .86843 m .47179 .87282 L .46827 .86362 L closepath p .578 .751 .96 r
F P
0 g
s
.78592 .60439 m .77118 .6514 L .71981 .60933 L p .919 .735 .637 r
F P
0 g
s
.71981 .60933 m .73179 .5584 L .78592 .60439 L p .919 .735 .637 r
F P
0 g
s
.3686 .79959 m .41763 .83097 L .41293 .84949 L p .437 .584 .901 r
F P
0 g
s
.46827 .86362 m .41293 .84949 L .41763 .83097 L p .519 .669 .931 r
F P
0 g
s
.52632 .86843 m .58376 .85889 L .58338 .86828 L closepath p .663 .812 .955 r
F P
0 g
s
.73413 .47003 m .7364 .51144 L .65338 .47632 L p .85 .557 .492 r
F P
0 g
s
.65338 .47632 m .65198 .43447 L .73413 .47003 L p .85 .557 .492 r
F P
0 g
s
.35646 .45025 m .35458 .4919 L .28461 .53448 L p .369 .166 .469 r
F P
0 g
s
.28985 .58033 m .28461 .53448 L .35458 .4919 L p .432 .275 .566 r
F P
0 g
s
.30346 .62938 m .32552 .67963 L .29182 .71959 L p .358 .346 .71 r
F P
0 g
s
.32611 .76181 m .29182 .71959 L .32552 .67963 L p .422 .439 .772 r
F P
0 g
s
.68922 .81313 m .6389 .84012 L .62797 .82213 L p .809 .854 .883 r
F P
0 g
s
.62797 .82213 m .67425 .78645 L .68922 .81313 L p .809 .854 .883 r
F P
0 g
s
.41763 .83097 m .47104 .8543 L .46827 .86362 L p .519 .669 .931 r
F P
0 g
s
.52632 .86843 m .46827 .86362 L .47104 .8543 L closepath p .591 .745 .95 r
F P
0 g
s
.64682 .40043 m .65198 .43447 L .55229 .41805 L p .744 .412 .421 r
F P
0 g
s
.55229 .41805 m .55121 .38441 L .64682 .40043 L p .744 .412 .421 r
F P
0 g
s
.52632 .86843 m .56622 .8423 L .57786 .84989 L closepath p .671 .789 .937 r
F P
0 g
s
.52632 .86843 m .55006 .83698 L .56622 .8423 L closepath p .667 .776 .931 r
F P
0 g
s
.52632 .86843 m .53119 .83459 L .55006 .83698 L closepath p .659 .764 .927 r
F P
0 g
s
.52632 .86843 m .51175 .8354 L .53119 .83459 L closepath p .649 .754 .926 r
F P
0 g
s
.52632 .86843 m .49399 .83932 L .51175 .8354 L closepath p .635 .747 .929 r
F P
0 g
s
.52632 .86843 m .47991 .84588 L .49399 .83932 L closepath p .621 .742 .934 r
F P
0 g
s
.52632 .86843 m .47104 .8543 L .47991 .84588 L closepath p .605 .742 .941 r
F P
0 g
s
.52632 .86843 m .57786 .84989 L .58376 .85889 L closepath p .669 .801 .945 r
F P
0 g
s
.6389 .84012 m .58376 .85889 L .57786 .84989 L p .745 .832 .918 r
F P
0 g
s
.57786 .84989 m .62797 .82213 L .6389 .84012 L p .745 .832 .918 r
F P
0 g
s
.77118 .6514 m .74724 .69888 L .70045 .66214 L p .894 .758 .705 r
F P
0 g
s
.70045 .66214 m .71981 .60933 L .77118 .6514 L p .894 .758 .705 r
F P
0 g
s
.32552 .67963 m .35553 .72876 L .32611 .76181 L p .422 .439 .772 r
F P
0 g
s
.3686 .79959 m .32611 .76181 L .35553 .72876 L p .475 .519 .823 r
F P
0 g
s
.44888 .42364 m .45208 .38986 L .55121 .38441 L p .638 .327 .428 r
F P
0 g
s
.45208 .38986 m .44888 .42364 L .35646 .45025 L p .501 .211 .405 r
F P
0 g
s
.43454 .81403 m .47991 .84588 L .47104 .8543 L p .565 .667 .906 r
F P
0 g
s
.47104 .8543 m .41763 .83097 L .43454 .81403 L p .565 .667 .906 r
F P
0 g
s
.35458 .4919 m .35646 .45025 L .44888 .42364 L p .546 .308 .506 r
F P
0 g
s
.35553 .72876 m .39241 .77433 L .3686 .79959 L p .475 .519 .823 r
F P
0 g
s
.41763 .83097 m .3686 .79959 L .39241 .77433 L p .522 .594 .867 r
F P
0 g
s
.35458 .4919 m .35839 .53982 L .28985 .58033 L p .432 .275 .566 r
F P
0 g
s
.30346 .62938 m .28985 .58033 L .35839 .53982 L p .478 .359 .64 r
F P
0 g
s
.39241 .77433 m .43454 .81403 L .41763 .83097 L p .522 .594 .867 r
F P
0 g
s
.55121 .38441 m .55229 .41805 L .44888 .42364 L p .638 .327 .428 r
F P
0 g
s
.62797 .82213 m .57786 .84989 L .56622 .8423 L p .74 .794 .896 r
F P
0 g
s
.7364 .51144 m .73179 .5584 L .65053 .52499 L p .846 .606 .575 r
F P
0 g
s
.65053 .52499 m .65338 .47632 L .7364 .51144 L p .846 .606 .575 r
F P
0 g
s
.74724 .69888 m .71457 .74465 L .67418 .71438 L p .865 .774 .76 r
F P
0 g
s
.67418 .71438 m .70045 .66214 L .74724 .69888 L p .865 .774 .76 r
F P
0 g
s
.4621 .80071 m .49399 .83932 L .47991 .84588 L p .606 .673 .887 r
F P
0 g
s
.47991 .84588 m .43454 .81403 L .4621 .80071 L p .606 .673 .887 r
F P
0 g
s
.67425 .78645 m .62797 .82213 L .60543 .80677 L p .791 .792 .853 r
F P
0 g
s
.56622 .8423 m .60543 .80677 L .62797 .82213 L p .74 .794 .896 r
F P
0 g
s
.60543 .80677 m .56622 .8423 L .55006 .83698 L p .725 .759 .88 r
F P
0 g
s
.71457 .74465 m .67425 .78645 L .64201 .76342 L p .831 .785 .809 r
F P
0 g
s
.64201 .76342 m .67418 .71438 L .71457 .74465 L p .831 .785 .809 r
F P
0 g
s
.65198 .43447 m .65338 .47632 L .55258 .4601 L p .757 .479 .513 r
F P
0 g
s
.55258 .4601 m .55229 .41805 L .65198 .43447 L p .757 .479 .513 r
F P
0 g
s
.60543 .80677 m .64201 .76342 L .67425 .78645 L p .791 .792 .853 r
F P
0 g
s
.35839 .53982 m .36828 .59237 L .30346 .62938 L p .478 .359 .64 r
F P
0 g
s
.32552 .67963 m .30346 .62938 L .36828 .59237 L p .513 .429 .699 r
F P
0 g
s
.49731 .79269 m .51175 .8354 L .49399 .83932 L p .642 .685 .875 r
F P
0 g
s
.49399 .83932 m .4621 .80071 L .49731 .79269 L p .642 .685 .875 r
F P
0 g
s
.55006 .83698 m .57357 .79593 L .60543 .80677 L p .725 .759 .88 r
F P
0 g
s
.57357 .79593 m .55006 .83698 L .53119 .83459 L p .702 .729 .871 r
F P
0 g
s
.53603 .79102 m .53119 .83459 L .51175 .8354 L p .674 .704 .87 r
F P
0 g
s
.51175 .8354 m .49731 .79269 L .53603 .79102 L p .674 .704 .87 r
F P
0 g
s
.53119 .83459 m .53603 .79102 L .57357 .79593 L p .702 .729 .871 r
F P
0 g
s
.43221 .75427 m .4621 .80071 L .43454 .81403 L p .587 .61 .842 r
F P
0 g
s
.43454 .81403 m .39241 .77433 L .43221 .75427 L p .587 .61 .842 r
F P
0 g
s
.44888 .42364 m .44801 .46562 L .35458 .4919 L p .546 .308 .506 r
F P
0 g
s
.35839 .53982 m .35458 .4919 L .44801 .46562 L p .576 .381 .58 r
F P
0 g
s
.73179 .5584 m .71981 .60933 L .64316 .57886 L p .836 .642 .64 r
F P
0 g
s
.64316 .57886 m .65053 .52499 L .73179 .5584 L p .836 .642 .64 r
F P
0 g
s
.44801 .46562 m .44888 .42364 L .55229 .41805 L p .662 .402 .516 r
F P
0 g
s
.36828 .59237 m .38424 .64739 L .32552 .67963 L p .513 .429 .699 r
F P
0 g
s
.35553 .72876 m .32552 .67963 L .38424 .64739 L p .541 .492 .75 r
F P
0 g
s
.40585 .70228 m .43221 .75427 L .39241 .77433 L p .566 .551 .796 r
F P
0 g
s
.39241 .77433 m .35553 .72876 L .40585 .70228 L p .566 .551 .796 r
F P
0 g
s
.55229 .41805 m .55258 .4601 L .44801 .46562 L p .662 .402 .516 r
F P
0 g
s
.64201 .76342 m .60543 .80677 L .57357 .79593 L p .762 .739 .832 r
F P
0 g
s
.38424 .64739 m .40585 .70228 L .35553 .72876 L p .541 .492 .75 r
F P
0 g
s
.71981 .60933 m .70045 .66214 L .63127 .63565 L p .823 .671 .693 r
F P
0 g
s
.63127 .63565 m .64316 .57886 L .71981 .60933 L p .823 .671 .693 r
F P
0 g
s
.4837 .74211 m .49731 .79269 L .4621 .80071 L p .641 .632 .826 r
F P
0 g
s
.4621 .80071 m .43221 .75427 L .4837 .74211 L p .641 .632 .826 r
F P
0 g
s
.65338 .47632 m .65053 .52499 L .55198 .50958 L p .761 .529 .582 r
F P
0 g
s
.55198 .50958 m .55258 .4601 L .65338 .47632 L p .761 .529 .582 r
F P
0 g
s
.44801 .46562 m .44977 .51483 L .35839 .53982 L p .576 .381 .58 r
F P
0 g
s
.36828 .59237 m .35839 .53982 L .44977 .51483 L p .597 .44 .639 r
F P
0 g
s
.67418 .71438 m .64201 .76342 L .59566 .74704 L p .788 .718 .787 r
F P
0 g
s
.57357 .79593 m .59566 .74704 L .64201 .76342 L p .762 .739 .832 r
F P
0 g
s
.59566 .74704 m .57357 .79593 L .53603 .79102 L p .726 .696 .821 r
F P
0 g
s
.70045 .66214 m .67418 .71438 L .61521 .69268 L p .808 .696 .741 r
F P
0 g
s
.61521 .69268 m .63127 .63565 L .70045 .66214 L p .808 .696 .741 r
F P
0 g
s
.54059 .73957 m .53603 .79102 L .49731 .79269 L p .686 .66 .819 r
F P
0 g
s
.49731 .79269 m .4837 .74211 L .54059 .73957 L p .686 .66 .819 r
F P
0 g
s
.59566 .74704 m .61521 .69268 L .67418 .71438 L p .788 .718 .787 r
F P
0 g
s
.44977 .51483 m .44801 .46562 L .55258 .4601 L p .676 .459 .583 r
F P
0 g
s
.53603 .79102 m .54059 .73957 L .59566 .74704 L p .726 .696 .821 r
F P
0 g
s
.47163 .68612 m .4837 .74211 L .43221 .75427 L p .634 .583 .78 r
F P
0 g
s
.43221 .75427 m .40585 .70228 L .47163 .68612 L p .634 .583 .78 r
F P
0 g
s
.55258 .4601 m .55198 .50958 L .44977 .51483 L p .676 .459 .583 r
F P
0 g
s
.44977 .51483 m .45434 .5696 L .36828 .59237 L p .597 .44 .639 r
F P
0 g
s
.38424 .64739 m .36828 .59237 L .45434 .5696 L p .613 .49 .689 r
F P
0 g
s
.65053 .52499 m .64316 .57886 L .55045 .56482 L p .76 .569 .638 r
F P
0 g
s
.55045 .56482 m .55198 .50958 L .65053 .52499 L p .76 .569 .638 r
F P
0 g
s
.4617 .62762 m .47163 .68612 L .40585 .70228 L p .625 .537 .735 r
F P
0 g
s
.40585 .70228 m .38424 .64739 L .4617 .62762 L p .625 .537 .735 r
F P
0 g
s
.61521 .69268 m .59566 .74704 L .54059 .73957 L p .741 .665 .775 r
F P
0 g
s
.45434 .5696 m .4617 .62762 L .38424 .64739 L p .613 .49 .689 r
F P
0 g
s
.45434 .5696 m .44977 .51483 L .55198 .50958 L p .684 .505 .638 r
F P
0 g
s
.54464 .68275 m .54059 .73957 L .4837 .74211 L p .691 .621 .773 r
F P
0 g
s
.4837 .74211 m .47163 .68612 L .54464 .68275 L p .691 .621 .773 r
F P
0 g
s
.64316 .57886 m .63127 .63565 L .54797 .62348 L p .757 .603 .687 r
F P
0 g
s
.54797 .62348 m .55045 .56482 L .64316 .57886 L p .757 .603 .687 r
F P
0 g
s
.54059 .73957 m .54464 .68275 L .61521 .69268 L p .741 .665 .775 r
F P
0 g
s
.63127 .63565 m .61521 .69268 L .54464 .68275 L p .751 .634 .731 r
F P
0 g
s
.55198 .50958 m .55045 .56482 L .45434 .5696 L p .684 .505 .638 r
F P
0 g
s
.54464 .68275 m .54797 .62348 L .63127 .63565 L p .751 .634 .731 r
F P
0 g
s
.4617 .62762 m .45434 .5696 L .55045 .56482 L p .689 .545 .685 r
F P
0 g
s
.54797 .62348 m .54464 .68275 L .47163 .68612 L p .691 .583 .729 r
F P
0 g
s
.47163 .68612 m .4617 .62762 L .54797 .62348 L p .691 .583 .729 r
F P
0 g
s
.55045 .56482 m .54797 .62348 L .4617 .62762 L p .689 .545 .685 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{266.25, 289},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 331.812}, {360.25, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 1, m = 0\)]],
  " mode, water moves from pole to pole, with the result that the center of \
mass of the water oscillates axially. Such motions could actually only occur \
if there were a time-dependent force acting to accelerate the water with \
respect to the solid portion of the earth, such as an undersea earthquake, or \
a meteor impact (see the exercises). Of course, such events also excite other \
modes."
}], "Text"],

Cell[TextData[{
  "\t The next azimuthally-symmetric mode has ",
  Cell[BoxData[
      \(TraditionalForm\`l = 2\)]],
  ",  and is showin in Cell ",
  ButtonBox["4.46",
    ButtonData:>"Cell 4.46",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(l = 2; \ m = 0;\), "\n", 
    \(\(Table[
        ParametricPlot3D[\((1\  +  .2  Cos[t] 
                  SphericalHarmonicY[l, 
                    m, \[Theta], \[Phi]])\) {Sin[\[Theta]] Cos[\[Phi]], 
              Sin[\[Theta]] Sin[\[Phi]], Cos[\[Theta]]}, {\[Theta], 0, 
            Pi}, {\[Phi], 0, 2  Pi}, 
          PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}, {\(-1.2\), 
                1.2}}], {t, 0, 2  Pi - 0.2  Pi,  .2\ Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.46"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48676 .50826 m .48033 .55123 L .54185 .55428 L p .719 .589 .709 r
F P
0 g
s
.54185 .55428 m .53968 .51095 L .48676 .50826 L p .719 .589 .709 r
F P
0 g
s
.54352 .5959 m .54185 .55428 L .48033 .55123 L p .72 .564 .678 r
F P
0 g
s
.53968 .51095 m .54185 .55428 L .60202 .54512 L p .669 .55 .711 r
F P
0 g
s
.54185 .55428 m .54352 .5959 L .6102 .586 L p .663 .52 .679 r
F P
0 g
s
.6102 .586 m .60202 .54512 L .54185 .55428 L p .663 .52 .679 r
F P
0 g
s
.49472 .46477 m .48676 .50826 L .53968 .51095 L p .717 .615 .743 r
F P
0 g
s
.53968 .51095 m .537 .46698 L .49472 .46477 L p .717 .615 .743 r
F P
0 g
s
.537 .46698 m .53968 .51095 L .5914 .50287 L p .674 .582 .744 r
F P
0 g
s
.60202 .54512 m .5914 .50287 L .53968 .51095 L p .669 .55 .711 r
F P
0 g
s
.43742 .49499 m .42284 .53617 L .48033 .55123 L p .767 .634 .714 r
F P
0 g
s
.48033 .55123 m .48676 .50826 L .43742 .49499 L p .767 .634 .714 r
F P
0 g
s
.47538 .5926 m .48033 .55123 L .42284 .53617 L p .774 .614 .681 r
F P
0 g
s
.48033 .55123 m .47538 .5926 L .54352 .5959 L p .72 .564 .678 r
F P
0 g
s
.45543 .45393 m .43742 .49499 L .48676 .50826 L p .757 .654 .748 r
F P
0 g
s
.48676 .50826 m .49472 .46477 L .45543 .45393 L p .757 .654 .748 r
F P
0 g
s
.54474 .63527 m .54352 .5959 L .47538 .5926 L p .72 .541 .648 r
F P
0 g
s
.54352 .5959 m .54474 .63527 L .61618 .62492 L p .657 .492 .648 r
F P
0 g
s
.61618 .62492 m .6102 .586 L .54352 .5959 L p .657 .492 .648 r
F P
0 g
s
.50414 .42232 m .49472 .46477 L .537 .46698 L p .711 .643 .779 r
F P
0 g
s
.537 .46698 m .53381 .4239 L .50414 .42232 L p .711 .643 .779 r
F P
0 g
s
.53381 .4239 m .537 .46698 L .57827 .46037 L p .677 .617 .78 r
F P
0 g
s
.5914 .50287 m .57827 .46037 L .537 .46698 L p .674 .582 .744 r
F P
0 g
s
.42284 .53617 m .4116 .57631 L .47538 .5926 L p .774 .614 .681 r
F P
0 g
s
.47176 .63183 m .47538 .5926 L .4116 .57631 L p .779 .594 .65 r
F P
0 g
s
.47538 .5926 m .47176 .63183 L .54474 .63527 L p .72 .541 .648 r
F P
0 g
s
.57827 .46037 m .5914 .50287 L .63715 .48462 L p .626 .554 .753 r
F P
0 g
s
.5914 .50287 m .60202 .54512 L .65546 .52436 L p .612 .514 .719 r
F P
0 g
s
.65546 .52436 m .63715 .48462 L .5914 .50287 L p .612 .514 .719 r
F P
0 g
s
.47665 .41454 m .45543 .45393 L .49472 .46477 L p .743 .675 .784 r
F P
0 g
s
.49472 .46477 m .50414 .42232 L .47665 .41454 L p .743 .675 .784 r
F P
0 g
s
.60202 .54512 m .6102 .586 L .6696 .56352 L p .598 .477 .685 r
F P
0 g
s
.6696 .56352 m .65546 .52436 L .60202 .54512 L p .598 .477 .685 r
F P
0 g
s
.57827 .46037 m .56275 .41915 L .53381 .4239 L p .677 .617 .78 r
F P
0 g
s
.56275 .41915 m .57827 .46037 L .6146 .44547 L p .639 .596 .789 r
F P
0 g
s
.63715 .48462 m .6146 .44547 L .57827 .46037 L p .626 .554 .753 r
F P
0 g
s
.54557 .67235 m .54474 .63527 L .47176 .63183 L p .718 .519 .619 r
F P
0 g
s
.54474 .63527 m .54557 .67235 L .62027 .66177 L p .651 .465 .619 r
F P
0 g
s
.62027 .66177 m .61618 .62492 L .54474 .63527 L p .651 .465 .619 r
F P
0 g
s
.6102 .586 m .61618 .62492 L .67996 .60138 L p .584 .441 .652 r
F P
0 g
s
.67996 .60138 m .6696 .56352 L .6102 .586 L p .584 .441 .652 r
F P
0 g
s
.42295 .43533 m .39635 .47214 L .43742 .49499 L p .795 .701 .761 r
F P
0 g
s
.43742 .49499 m .45543 .45393 L .42295 .43533 L p .795 .701 .761 r
F P
0 g
s
.42284 .53617 m .43742 .49499 L .39635 .47214 L p .814 .688 .726 r
F P
0 g
s
.4116 .57631 m .40337 .61478 L .47176 .63183 L p .779 .594 .65 r
F P
0 g
s
.46929 .66883 m .47176 .63183 L .40337 .61478 L p .782 .575 .62 r
F P
0 g
s
.47176 .63183 m .46929 .66883 L .54557 .67235 L p .718 .519 .619 r
F P
0 g
s
.39635 .47214 m .37471 .51014 L .42284 .53617 L p .814 .688 .726 r
F P
0 g
s
.4116 .57631 m .42284 .53617 L .37471 .51014 L p .828 .674 .691 r
F P
0 g
s
.45412 .40127 m .42295 .43533 L .45543 .45393 L p .772 .713 .797 r
F P
0 g
s
.45543 .45393 m .47665 .41454 L .45412 .40127 L p .772 .713 .797 r
F P
0 g
s
.5148 .38278 m .50414 .42232 L .53381 .4239 L p .702 .673 .819 r
F P
0 g
s
.53381 .4239 m .53021 .38362 L .5148 .38278 L p .702 .673 .819 r
F P
0 g
s
.53021 .38362 m .53381 .4239 L .56275 .41915 L p .678 .656 .82 r
F P
0 g
s
.50057 .37865 m .47665 .41454 L .50414 .42232 L p .723 .696 .823 r
F P
0 g
s
.50414 .42232 m .5148 .38278 L .50057 .37865 L p .723 .696 .823 r
F P
0 g
s
.61618 .62492 m .62027 .66177 L .68705 .6377 L p .571 .407 .62 r
F P
0 g
s
.68705 .6377 m .67996 .60138 L .61618 .62492 L p .571 .407 .62 r
F P
0 g
s
.56275 .41915 m .54523 .3811 L .53021 .38362 L p .678 .656 .82 r
F P
0 g
s
.54523 .3811 m .56275 .41915 L .58808 .40849 L p .653 .643 .828 r
F P
0 g
s
.6146 .44547 m .58808 .40849 L .56275 .41915 L p .639 .596 .789 r
F P
0 g
s
.37471 .51014 m .35796 .54809 L .4116 .57631 L p .828 .674 .691 r
F P
0 g
s
.40337 .61478 m .4116 .57631 L .35796 .54809 L p .84 .658 .656 r
F P
0 g
s
.54608 .70741 m .54557 .67235 L .46929 .66883 L p .716 .497 .591 r
F P
0 g
s
.54557 .67235 m .54608 .70741 L .62274 .6968 L p .644 .439 .591 r
F P
0 g
s
.62274 .6968 m .62027 .66177 L .54557 .67235 L p .644 .439 .591 r
F P
0 g
s
.6146 .44547 m .63715 .48462 L .67242 .4576 L p .57 .53 .771 r
F P
0 g
s
.63715 .48462 m .65546 .52436 L .69698 .49351 L p .543 .48 .735 r
F P
0 g
s
.69698 .49351 m .67242 .4576 L .63715 .48462 L p .543 .48 .735 r
F P
0 g
s
.58808 .40849 m .6146 .44547 L .64232 .42354 L p .598 .582 .806 r
F P
0 g
s
.67242 .4576 m .64232 .42354 L .6146 .44547 L p .57 .53 .771 r
F P
0 g
s
.48902 .37166 m .45412 .40127 L .47665 .41454 L p .741 .722 .833 r
F P
0 g
s
.47665 .41454 m .50057 .37865 L .48902 .37166 L p .741 .722 .833 r
F P
0 g
s
.65546 .52436 m .6696 .56352 L .71604 .53001 L p .515 .43 .698 r
F P
0 g
s
.71604 .53001 m .69698 .49351 L .65546 .52436 L p .515 .43 .698 r
F P
0 g
s
.40337 .61478 m .39774 .65141 L .46929 .66883 L p .782 .575 .62 r
F P
0 g
s
.4678 .70388 m .46929 .66883 L .39774 .65141 L p .784 .555 .59 r
F P
0 g
s
.46929 .66883 m .4678 .70388 L .54608 .70741 L p .716 .497 .591 r
F P
0 g
s
.58808 .40849 m .55829 .37546 L .54523 .3811 L p .653 .643 .828 r
F P
0 g
s
.55829 .37546 m .58808 .40849 L .60718 .39289 L p .627 .636 .841 r
F P
0 g
s
.64232 .42354 m .60718 .39289 L .58808 .40849 L p .598 .582 .806 r
F P
0 g
s
.35796 .54809 m .34566 .58519 L .40337 .61478 L p .84 .658 .656 r
F P
0 g
s
.39774 .65141 m .40337 .61478 L .34566 .58519 L p .849 .641 .621 r
F P
0 g
s
.43896 .38374 m .40071 .41059 L .42295 .43533 L p .796 .758 .818 r
F P
0 g
s
.42295 .43533 m .45412 .40127 L .43896 .38374 L p .796 .758 .818 r
F P
0 g
s
.39635 .47214 m .42295 .43533 L .40071 .41059 L p .831 .759 .783 r
F P
0 g
s
.62027 .66177 m .62274 .6968 L .69134 .67264 L p .557 .373 .589 r
F P
0 g
s
.69134 .67264 m .68705 .6377 L .62027 .66177 L p .557 .373 .589 r
F P
0 g
s
.6696 .56352 m .67996 .60138 L .73005 .5662 L p .487 .381 .66 r
F P
0 g
s
.73005 .5662 m .71604 .53001 L .6696 .56352 L p .487 .381 .66 r
F P
0 g
s
.40071 .41059 m .36784 .44156 L .39635 .47214 L p .831 .759 .783 r
F P
0 g
s
.37471 .51014 m .39635 .47214 L .36784 .44156 L p .861 .757 .746 r
F P
0 g
s
.53021 .38362 m .52632 .34817 L .5148 .38278 L closepath p .685 .709 .866 r
F P
0 g
s
.54523 .3811 m .52632 .34817 L .53021 .38362 L closepath p .676 .702 .866 r
F P
0 g
s
.5148 .38278 m .52632 .34817 L .50057 .37865 L closepath p .694 .717 .867 r
F P
0 g
s
.54628 .74087 m .54608 .70741 L .4678 .70388 L p .713 .474 .563 r
F P
0 g
s
.54608 .70741 m .54628 .74087 L .62374 .73038 L p .636 .413 .562 r
F P
0 g
s
.62374 .73038 m .62274 .6968 L .54608 .70741 L p .636 .413 .562 r
F P
0 g
s
.48138 .3625 m .43896 .38374 L .45412 .40127 L p .755 .751 .849 r
F P
0 g
s
.45412 .40127 m .48902 .37166 L .48138 .3625 L p .755 .751 .849 r
F P
0 g
s
.55829 .37546 m .52632 .34817 L .54523 .3811 L closepath p .666 .697 .869 r
F P
0 g
s
.36784 .44156 m .34092 .47513 L .37471 .51014 L p .861 .757 .746 r
F P
0 g
s
.35796 .54809 m .37471 .51014 L .34092 .47513 L p .886 .75 .706 r
F P
0 g
s
.50057 .37865 m .52632 .34817 L .48902 .37166 L closepath p .7 .727 .872 r
F P
0 g
s
.39774 .65141 m .39434 .68639 L .4678 .70388 L p .784 .555 .59 r
F P
0 g
s
.46719 .73738 m .4678 .70388 L .39434 .68639 L p .784 .535 .559 r
F P
0 g
s
.4678 .70388 m .46719 .73738 L .54628 .74087 L p .713 .474 .563 r
F P
0 g
s
.568 .36728 m .52632 .34817 L .55829 .37546 L closepath p .656 .696 .875 r
F P
0 g
s
.60718 .39289 m .568 .36728 L .55829 .37546 L p .627 .636 .841 r
F P
0 g
s
.60718 .39289 m .64232 .42354 L .65833 .39655 L p .551 .575 .832 r
F P
0 g
s
.64232 .42354 m .67242 .4576 L .69322 .42411 L p .502 .511 .799 r
F P
0 g
s
.69322 .42411 m .65833 .39655 L .64232 .42354 L p .502 .511 .799 r
F P
0 g
s
.34566 .58519 m .33724 .62113 L .39774 .65141 L p .849 .641 .621 r
F P
0 g
s
.39434 .68639 m .39774 .65141 L .33724 .62113 L p .855 .623 .586 r
F P
0 g
s
.568 .36728 m .60718 .39289 L .61792 .37385 L p .6 .637 .859 r
F P
0 g
s
.65833 .39655 m .61792 .37385 L .60718 .39289 L p .551 .575 .832 r
F P
0 g
s
.67996 .60138 m .68705 .6377 L .73966 .60168 L p .46 .333 .62 r
F P
0 g
s
.73966 .60168 m .73005 .5662 L .67996 .60138 L p .46 .333 .62 r
F P
0 g
s
.48902 .37166 m .52632 .34817 L .48138 .3625 L closepath p .703 .738 .878 r
F P
0 g
s
.67242 .4576 m .69698 .49351 L .72189 .45506 L p .449 .444 .761 r
F P
0 g
s
.72189 .45506 m .69322 .42411 L .67242 .4576 L p .449 .444 .761 r
F P
0 g
s
.62274 .6968 m .62374 .73038 L .69309 .70649 L p .542 .339 .555 r
F P
0 g
s
.69309 .70649 m .69134 .67264 L .62274 .6968 L p .542 .339 .555 r
F P
0 g
s
.34092 .47513 m .31997 .50997 L .35796 .54809 L p .886 .75 .706 r
F P
0 g
s
.34566 .58519 m .35796 .54809 L .31997 .50997 L p .907 .74 .664 r
F P
0 g
s
.57331 .35737 m .52632 .34817 L .568 .36728 L closepath p .648 .698 .882 r
F P
0 g
s
.61792 .37385 m .57331 .35737 L .568 .36728 L p .6 .637 .859 r
F P
0 g
s
.47854 .35212 m .43294 .36367 L .43896 .38374 L p .76 .782 .871 r
F P
0 g
s
.43896 .38374 m .48138 .3625 L .47854 .35212 L p .76 .782 .871 r
F P
0 g
s
.40071 .41059 m .43896 .38374 L .43294 .36367 L p .812 .809 .848 r
F P
0 g
s
.54618 .77299 m .54628 .74087 L .46719 .73738 L p .708 .449 .53 r
F P
0 g
s
.54628 .74087 m .54618 .77299 L .62325 .76277 L p .627 .383 .528 r
F P
0 g
s
.62325 .76277 m .62374 .73038 L .54628 .74087 L p .627 .383 .528 r
F P
0 g
s
.48138 .3625 m .52632 .34817 L .47854 .35212 L closepath p .703 .748 .886 r
F P
0 g
s
.69698 .49351 m .71604 .53001 L .74426 .48805 L p .394 .372 .716 r
F P
0 g
s
.74426 .48805 m .72189 .45506 L .69698 .49351 L p .394 .372 .716 r
F P
0 g
s
.43294 .36367 m .39143 .38203 L .40071 .41059 L p .812 .809 .848 r
F P
0 g
s
.36784 .44156 m .40071 .41059 L .39143 .38203 L p .86 .83 .817 r
F P
0 g
s
.39434 .68639 m .39295 .7201 L .46719 .73738 L p .784 .535 .559 r
F P
0 g
s
.46749 .76959 m .46719 .73738 L .39295 .7201 L p .784 .511 .524 r
F P
0 g
s
.46719 .73738 m .46749 .76959 L .54618 .77299 L p .708 .449 .53 r
F P
0 g
s
.68705 .6377 m .69134 .67264 L .74549 .63643 L p .432 .285 .58 r
F P
0 g
s
.74549 .63643 m .73966 .60168 L .68705 .6377 L p .432 .285 .58 r
F P
0 g
s
.57357 .34679 m .52632 .34817 L .57331 .35737 L closepath p .641 .703 .891 r
F P
0 g
s
.57331 .35737 m .61792 .37385 L .61891 .35329 L p .574 .645 .883 r
F P
0 g
s
.61891 .35329 m .57357 .34679 L .57331 .35737 L p .574 .645 .883 r
F P
0 g
s
.33724 .62113 m .33214 .65599 L .39434 .68639 L p .855 .623 .586 r
F P
0 g
s
.39295 .7201 m .39434 .68639 L .33214 .65599 L p .86 .603 .548 r
F P
0 g
s
.31997 .50997 m .30454 .54512 L .34566 .58519 L p .907 .74 .664 r
F P
0 g
s
.33724 .62113 m .34566 .58519 L .30454 .54512 L p .923 .726 .618 r
F P
0 g
s
.61792 .37385 m .65833 .39655 L .66041 .36713 L p .499 .579 .866 r
F P
0 g
s
.66041 .36713 m .61891 .35329 L .61792 .37385 L p .499 .579 .866 r
F P
0 g
s
.47854 .35212 m .52632 .34817 L .48087 .34162 L closepath p .7 .756 .895 r
F P
0 g
s
.56866 .33667 m .52632 .34817 L .57357 .34679 L closepath p .637 .71 .9 r
F P
0 g
s
.55907 .32814 m .52632 .34817 L .56866 .33667 L closepath p .637 .721 .908 r
F P
0 g
s
.54579 .32219 m .52632 .34817 L .55907 .32814 L closepath p .64 .732 .915 r
F P
0 g
s
.53031 .31951 m .52632 .34817 L .54579 .32219 L closepath p .648 .744 .919 r
F P
0 g
s
.51437 .32042 m .52632 .34817 L .53031 .31951 L closepath p .659 .754 .92 r
F P
0 g
s
.49979 .32481 m .52632 .34817 L .51437 .32042 L closepath p .671 .76 .918 r
F P
0 g
s
.48821 .33216 m .52632 .34817 L .49979 .32481 L closepath p .683 .763 .912 r
F P
0 g
s
.48087 .34162 m .52632 .34817 L .48821 .33216 L closepath p .693 .761 .904 r
F P
0 g
s
.39143 .38203 m .35544 .40598 L .36784 .44156 L p .86 .83 .817 r
F P
0 g
s
.34092 .47513 m .36784 .44156 L .35544 .40598 L p .903 .845 .777 r
F P
0 g
s
.43294 .36367 m .47854 .35212 L .48087 .34162 L p .755 .811 .896 r
F P
0 g
s
.62374 .73038 m .62325 .76277 L .69224 .73951 L p .524 .3 .517 r
F P
0 g
s
.69224 .73951 m .69309 .70649 L .62374 .73038 L p .524 .3 .517 r
F P
0 g
s
.71604 .53001 m .73005 .5662 L .76078 .52201 L p .336 .297 .666 r
F P
0 g
s
.76078 .52201 m .74426 .48805 L .71604 .53001 L p .336 .297 .666 r
F P
0 g
s
.65833 .39655 m .69322 .42411 L .69656 .38732 L p .412 .499 .838 r
F P
0 g
s
.69656 .38732 m .66041 .36713 L .65833 .39655 L p .412 .499 .838 r
F P
0 g
s
.57357 .34679 m .61891 .35329 L .60973 .33342 L p .553 .664 .911 r
F P
0 g
s
.60973 .33342 m .56866 .33667 L .57357 .34679 L p .553 .664 .911 r
F P
0 g
s
.48087 .34162 m .43703 .34317 L .43294 .36367 L p .755 .811 .896 r
F P
0 g
s
.39143 .38203 m .43294 .36367 L .43703 .34317 L p .811 .863 .887 r
F P
0 g
s
.35544 .40598 m .32574 .43415 L .34092 .47513 L p .903 .845 .777 r
F P
0 g
s
.31997 .50997 m .34092 .47513 L .32574 .43415 L p .941 .852 .726 r
F P
0 g
s
.43703 .34317 m .48087 .34162 L .48821 .33216 L p .736 .833 .924 r
F P
0 g
s
.54572 .80362 m .54618 .77299 L .46749 .76959 L p .701 .416 .489 r
F P
0 g
s
.54618 .77299 m .54572 .80362 L .62101 .79384 L p .614 .345 .486 r
F P
0 g
s
.62101 .79384 m .62325 .76277 L .54618 .77299 L p .614 .345 .486 r
F P
0 g
s
.69134 .67264 m .69309 .70649 L .74787 .67068 L p .402 .234 .537 r
F P
0 g
s
.74787 .67068 m .74549 .63643 L .69134 .67264 L p .402 .234 .537 r
F P
0 g
s
.30454 .54512 m .29394 .58006 L .33724 .62113 L p .923 .726 .618 r
F P
0 g
s
.33214 .65599 m .33724 .62113 L .29394 .58006 L p .935 .708 .57 r
F P
0 g
s
.33214 .65599 m .33006 .69002 L .39295 .7201 L p .86 .603 .548 r
F P
0 g
s
.39363 .75276 m .39295 .7201 L .33006 .69002 L p .863 .578 .505 r
F P
0 g
s
.39295 .7201 m .39363 .75276 L .46749 .76959 L p .784 .511 .524 r
F P
0 g
s
.56866 .33667 m .60973 .33342 L .59111 .31653 L p .54 .692 .938 r
F P
0 g
s
.59111 .31653 m .55907 .32814 L .56866 .33667 L p .54 .692 .938 r
F P
0 g
s
.46884 .80036 m .46749 .76959 L .39363 .75276 L p .78 .48 .479 r
F P
0 g
s
.46749 .76959 m .46884 .80036 L .54572 .80362 L p .701 .416 .489 r
F P
0 g
s
.69322 .42411 m .72189 .45506 L .7265 .41254 L p .309 .402 .795 r
F P
0 g
s
.7265 .41254 m .69656 .38732 L .69322 .42411 L p .309 .402 .795 r
F P
0 g
s
.61891 .35329 m .66041 .36713 L .64769 .33844 L p .441 .596 .909 r
F P
0 g
s
.64769 .33844 m .60973 .33342 L .61891 .35329 L p .441 .596 .909 r
F P
0 g
s
.73005 .5662 m .73966 .60168 L .77215 .55632 L p .275 .219 .611 r
F P
0 g
s
.77215 .55632 m .76078 .52201 L .73005 .5662 L p .275 .219 .611 r
F P
0 g
s
.43703 .34317 m .39671 .35255 L .39143 .38203 L p .811 .863 .887 r
F P
0 g
s
.35544 .40598 m .39143 .38203 L .39671 .35255 L p .865 .911 .861 r
F P
0 g
s
.45108 .32451 m .48821 .33216 L .49979 .32481 L p .701 .842 .95 r
F P
0 g
s
.48821 .33216 m .45108 .32451 L .43703 .34317 L p .736 .833 .924 r
F P
0 g
s
.55907 .32814 m .59111 .31653 L .56496 .30465 L p .542 .729 .961 r
F P
0 g
s
.56496 .30465 m .54579 .32219 L .55907 .32814 L p .542 .729 .961 r
F P
0 g
s
.62325 .76277 m .62101 .79384 L .68835 .7716 L p .501 .25 .466 r
F P
0 g
s
.68835 .7716 m .69224 .73951 L .62325 .76277 L p .501 .25 .466 r
F P
0 g
s
.32574 .43415 m .30249 .46513 L .31997 .50997 L p .941 .852 .726 r
F P
0 g
s
.30454 .54512 m .31997 .50997 L .30249 .46513 L p .971 .849 .664 r
F P
0 g
s
.47376 .30988 m .49979 .32481 L .51437 .32042 L p .653 .834 .97 r
F P
0 g
s
.49979 .32481 m .47376 .30988 L .45108 .32451 L p .701 .842 .95 r
F P
0 g
s
.39671 .35255 m .43703 .34317 L .45108 .32451 L p .778 .909 .93 r
F P
0 g
s
.54579 .32219 m .56496 .30465 L .53425 .29927 L p .563 .77 .975 r
F P
0 g
s
.53425 .29927 m .53031 .31951 L .54579 .32219 L p .563 .77 .975 r
F P
0 g
s
.72189 .45506 m .74426 .48805 L .75001 .4414 L p .189 .285 .732 r
F P
0 g
s
.75001 .4414 m .7265 .41254 L .72189 .45506 L p .189 .285 .732 r
F P
0 g
s
.5026 .30109 m .51437 .32042 L .53031 .31951 L p .603 .808 .978 r
F P
0 g
s
.51437 .32042 m .5026 .30109 L .47376 .30988 L p .653 .834 .97 r
F P
0 g
s
.29394 .58006 m .28751 .61468 L .33214 .65599 L p .935 .708 .57 r
F P
0 g
s
.33006 .69002 m .33214 .65599 L .28751 .61468 L p .944 .686 .516 r
F P
0 g
s
.69309 .70649 m .69224 .73951 L .74671 .70465 L p .367 .176 .485 r
F P
0 g
s
.74671 .70465 m .74787 .67068 L .69309 .70649 L p .367 .176 .485 r
F P
0 g
s
.53031 .31951 m .53425 .29927 L .5026 .30109 L p .603 .808 .978 r
F P
0 g
s
.66041 .36713 m .69656 .38732 L .68104 .35113 L p .289 .493 .883 r
F P
0 g
s
.68104 .35113 m .64769 .33844 L .66041 .36713 L p .289 .493 .883 r
F P
0 g
s
.39671 .35255 m .36142 .36897 L .35544 .40598 L p .865 .911 .861 r
F P
0 g
s
.32574 .43415 m .35544 .40598 L .36142 .36897 L p .912 .948 .81 r
F P
0 g
s
.73966 .60168 m .74549 .63643 L .77905 .59078 L p .212 .137 .549 r
F P
0 g
s
.77905 .59078 m .77215 .55632 L .73966 .60168 L p .212 .137 .549 r
F P
0 g
s
.33006 .69002 m .33107 .72348 L .39363 .75276 L p .863 .578 .505 r
F P
0 g
s
.39672 .78427 m .39363 .75276 L .33107 .72348 L p .862 .544 .447 r
F P
0 g
s
.39363 .75276 m .39672 .78427 L .46884 .80036 L p .78 .48 .479 r
F P
0 g
s
.54483 .83206 m .54572 .80362 L .46884 .80036 L p .689 .369 .43 r
F P
0 g
s
.54572 .80362 m .54483 .83206 L .61661 .82293 L p .594 .291 .425 r
F P
0 g
s
.61661 .82293 m .62101 .79384 L .54572 .80362 L p .594 .291 .425 r
F P
0 g
s
.60973 .33342 m .64769 .33844 L .62097 .31383 L p .386 .63 .95 r
F P
0 g
s
.62097 .31383 m .59111 .31653 L .60973 .33342 L p .386 .63 .95 r
F P
0 g
s
.4715 .82902 m .46884 .80036 L .39672 .78427 L p .772 .434 .414 r
F P
0 g
s
.46884 .80036 m .4715 .82902 L .54483 .83206 L p .689 .369 .43 r
F P
0 g
s
.30249 .46513 m .28529 .49781 L .30454 .54512 L p .971 .849 .664 r
F P
0 g
s
.29394 .58006 m .30454 .54512 L .28529 .49781 L p .991 .835 .59 r
F P
0 g
s
.41662 .32548 m .45108 .32451 L .47376 .30988 L p .699 .926 .967 r
F P
0 g
s
.45108 .32451 m .41662 .32548 L .39671 .35255 L p .778 .909 .93 r
F P
0 g
s
.74426 .48805 m .76078 .52201 L .76745 .4727 L p .051 .148 .646 r
F P
0 g
s
.76745 .4727 m .75001 .4414 L .74426 .48805 L p .051 .148 .646 r
F P
0 g
s
.36142 .36897 m .39671 .35255 L .41662 .32548 L p .807 .977 .9 r
F P
0 g
s
.62101 .79384 m .61661 .82293 L .6807 .80216 L p .466 .18 .394 r
F P
0 g
s
.6807 .80216 m .68835 .7716 L .62101 .79384 L p .466 .18 .394 r
F P
0 g
s
.28751 .61468 m .28488 .64915 L .33006 .69002 L p .944 .686 .516 r
F P
0 g
s
.33107 .72348 m .33006 .69002 L .28488 .64915 L p .948 .656 .451 r
F P
0 g
s
.36142 .36897 m .33209 .39121 L .32574 .43415 L p .912 .948 .81 r
F P
0 g
s
.30249 .46513 m .32574 .43415 L .33209 .39121 L p .941 .963 .722 r
F P
0 g
s
.69224 .73951 m .68835 .7716 L .74142 .7383 L p .32 .1 .415 r
F P
0 g
s
.74142 .7383 m .74671 .70465 L .69224 .73951 L p .32 .1 .415 r
F P
0 g
s
.69656 .38732 m .7265 .41254 L .70888 .37042 L p .079 .338 .813 r
F P
0 g
s
.70888 .37042 m .68104 .35113 L .69656 .38732 L p .079 .338 .813 r
F P
0 g
s
.59111 .31653 m .62097 .31383 L .58293 .2964 L p .352 .681 .979 r
F P
0 g
s
.58293 .2964 m .56496 .30465 L .59111 .31653 L p .352 .681 .979 r
F P
0 g
s
.74549 .63643 m .74787 .67068 L .78188 .6255 L p .143 .048 .478 r
F P
0 g
s
.78188 .6255 m .77905 .59078 L .74549 .63643 L p .143 .048 .478 r
F P
0 g
s
.28529 .49781 m .27343 .53144 L .29394 .58006 L p .991 .835 .59 r
F P
0 g
s
.28751 .61468 m .29394 .58006 L .27343 .53144 L p 1 .809 .504 r
F P
0 g
s
.44942 .30409 m .47376 .30988 L .5026 .30109 L p .576 .896 .986 r
F P
0 g
s
.47376 .30988 m .44942 .30409 L .41662 .32548 L p .699 .926 .967 r
F P
0 g
s
.33107 .72348 m .3357 .75629 L .39672 .78427 L p .862 .544 .447 r
F P
0 g
s
.40278 .81398 m .39672 .78427 L .3357 .75629 L p .855 .492 .363 r
F P
0 g
s
.39672 .78427 m .40278 .81398 L .4715 .82902 L p .772 .434 .414 r
F P
0 g
s
.64769 .33844 m .68104 .35113 L .64741 .31985 L p .131 .492 .904 r
F P
0 g
s
.64741 .31985 m .62097 .31383 L .64769 .33844 L p .131 .492 .904 r
F P
0 g
s
.56496 .30465 m .58293 .2964 L .53796 .28848 L p .368 .749 .989 r
F P
0 g
s
.53796 .28848 m .53425 .29927 L .56496 .30465 L p .368 .749 .989 r
F P
0 g
s
.54338 .85701 m .54483 .83206 L .4715 .82902 L p .664 .297 .34 r
F P
0 g
s
.54483 .83206 m .54338 .85701 L .60953 .84873 L p .559 .209 .331 r
F P
0 g
s
.60953 .84873 m .61661 .82293 L .54483 .83206 L p .559 .209 .331 r
F P
0 g
s
.76078 .52201 m .77215 .55632 L .77949 .50558 L p 0 0 .537 r
F P
0 g
s
.77949 .50558 m .76745 .4727 L .76078 .52201 L p 0 0 .537 r
F P
0 g
s
.49154 .29117 m .5026 .30109 L .53425 .29927 L p .449 .828 .99 r
F P
0 g
s
.5026 .30109 m .49154 .29117 L .44942 .30409 L p .576 .896 .986 r
F P
0 g
s
.53425 .29927 m .53796 .28848 L .49154 .29117 L p .449 .828 .99 r
F P
0 g
s
.47578 .85425 m .4715 .82902 L .40278 .81398 L p .752 .361 .313 r
F P
0 g
s
.4715 .82902 m .47578 .85425 L .54338 .85701 L p .664 .297 .34 r
F P
0 g
s
.41662 .32548 m .3862 .33468 L .36142 .36897 L p .807 .977 .9 r
F P
0 g
s
.33209 .39121 m .36142 .36897 L .3862 .33468 L p .786 .996 .788 r
F P
0 g
s
.33209 .39121 m .30898 .41792 L .30249 .46513 L p .941 .963 .722 r
F P
0 g
s
.28529 .49781 m .30249 .46513 L .30898 .41792 L p .936 .938 .589 r
F P
0 g
s
.28488 .64915 m .28616 .6837 L .33107 .72348 L p .948 .656 .451 r
F P
0 g
s
.3357 .75629 m .33107 .72348 L .28616 .6837 L p .944 .609 .361 r
F P
0 g
s
.74787 .67068 m .74671 .70465 L .7805 .66069 L p .062 0 .389 r
F P
0 g
s
.7805 .66069 m .78188 .6255 L .74787 .67068 L p .062 0 .389 r
F P
0 g
s
.7265 .41254 m .75001 .4414 L .73087 .39495 L p 0 .121 .672 r
F P
0 g
s
.73087 .39495 m .70888 .37042 L .7265 .41254 L p 0 .121 .672 r
F P
0 g
s
.3862 .33468 m .41662 .32548 L .44942 .30409 L p .624 .959 .89 r
F P
0 g
s
.68835 .7716 m .6807 .80216 L .73105 .77112 L p .251 0 .311 r
F P
0 g
s
.73105 .77112 m .74142 .7383 L .68835 .7716 L p .251 0 .311 r
F P
0 g
s
.61661 .82293 m .60953 .84873 L .66843 .82996 L p .408 .072 .28 r
F P
0 g
s
.66843 .82996 m .6807 .80216 L .61661 .82293 L p .408 .072 .28 r
F P
0 g
s
.27343 .53144 m .26622 .56571 L .28751 .61468 L p 1 .809 .504 r
F P
0 g
s
.28488 .64915 m .28751 .61468 L .26622 .56571 L p .994 .768 .402 r
F P
0 g
s
.77215 .55632 m .77905 .59078 L .78682 .53963 L p 0 0 .406 r
F P
0 g
s
.78682 .53963 m .77949 .50558 L .77215 .55632 L p 0 0 .406 r
F P
0 g
s
.62097 .31383 m .64741 .31985 L .59894 .29757 L p 0 .497 .856 r
F P
0 g
s
.59894 .29757 m .58293 .2964 L .62097 .31383 L p 0 .497 .856 r
F P
0 g
s
.68104 .35113 m .70888 .37042 L .66962 .33378 L p 0 .232 .716 r
F P
0 g
s
.66962 .33378 m .64741 .31985 L .68104 .35113 L p 0 .232 .716 r
F P
0 g
s
.3357 .75629 m .34479 .78788 L .40278 .81398 L p .855 .492 .363 r
F P
0 g
s
.41253 .84064 m .40278 .81398 L .34479 .78788 L p .829 .404 .229 r
F P
0 g
s
.40278 .81398 m .41253 .84064 L .47578 .85425 L p .752 .361 .313 r
F P
0 g
s
.30898 .41792 m .2918 .4478 L .28529 .49781 L p .936 .938 .589 r
F P
0 g
s
.27343 .53144 m .28529 .49781 L .2918 .4478 L p .883 .863 .416 r
F P
0 g
s
.74671 .70465 m .74142 .7383 L .77423 .69636 L p 0 0 .266 r
F P
0 g
s
.77423 .69636 m .7805 .66069 L .74671 .70465 L p 0 0 .266 r
F P
0 g
s
.42779 .30741 m .44942 .30409 L .49154 .29117 L p .335 .817 .812 r
F P
0 g
s
.44942 .30409 m .42779 .30741 L .3862 .33468 L p .624 .959 .89 r
F P
0 g
s
.3862 .33468 m .36074 .35118 L .33209 .39121 L p .786 .996 .788 r
F P
0 g
s
.30898 .41792 m .33209 .39121 L .36074 .35118 L p .666 .898 .554 r
F P
0 g
s
.75001 .4414 m .76745 .4727 L .74726 .4234 L p 0 0 .455 r
F P
0 g
s
.74726 .4234 m .73087 .39495 L .75001 .4414 L p 0 0 .455 r
F P
0 g
s
.28616 .6837 m .292 .71831 L .3357 .75629 L p .944 .609 .361 r
F P
0 g
s
.34479 .78788 m .3357 .75629 L .292 .71831 L p .921 .531 .226 r
F P
0 g
s
.26622 .56571 m .26327 .60068 L .28488 .64915 L p .994 .768 .402 r
F P
0 g
s
.28616 .6837 m .28488 .64915 L .26327 .60068 L p .967 .703 .274 r
F P
0 g
s
.5413 .87658 m .54338 .85701 L .47578 .85425 L p .612 .175 .186 r
F P
0 g
s
.54338 .85701 m .5413 .87658 L .5993 .86942 L p .49 .071 .172 r
F P
0 g
s
.5993 .86942 m .60953 .84873 L .54338 .85701 L p .49 .071 .172 r
F P
0 g
s
.58293 .2964 m .59894 .29757 L .54127 .2874 L p 0 .534 .771 r
F P
0 g
s
.54127 .2874 m .53796 .28848 L .58293 .2964 L p 0 .534 .771 r
F P
0 g
s
.48197 .87419 m .47578 .85425 L .41253 .84064 L p .7 .233 .14 r
F P
0 g
s
.47578 .85425 m .48197 .87419 L .5413 .87658 L p .612 .175 .186 r
F P
0 g
s
.6807 .80216 m .66843 .82996 L .71446 .80199 L p .141 0 .145 r
F P
0 g
s
.71446 .80199 m .73105 .77112 L .6807 .80216 L p .141 0 .145 r
F P
0 g
s
.36074 .35118 m .3862 .33468 L .42779 .30741 L p .394 .805 .599 r
F P
0 g
s
.77905 .59078 m .78188 .6255 L .78982 .57485 L p 0 0 .253 r
F P
0 g
s
.78982 .57485 m .78682 .53963 L .77905 .59078 L p 0 0 .253 r
F P
0 g
s
.48168 .29086 m .49154 .29117 L .53796 .28848 L p .083 .643 .748 r
F P
0 g
s
.49154 .29117 m .48168 .29086 L .42779 .30741 L p .335 .817 .812 r
F P
0 g
s
.53796 .28848 m .54127 .2874 L .48168 .29086 L p .083 .643 .748 r
F P
0 g
s
.60953 .84873 m .5993 .86942 L .65076 .85323 L p .302 0 .086 r
F P
0 g
s
.65076 .85323 m .66843 .82996 L .60953 .84873 L p .302 0 .086 r
F P
0 g
s
.2918 .4478 m .27992 .4799 L .27343 .53144 L p .883 .863 .416 r
F P
0 g
s
.26622 .56571 m .27343 .53144 L .27992 .4799 L p .786 .743 .221 r
F P
0 g
s
.70888 .37042 m .73087 .39495 L .68726 .35434 L p .612 .099 0 r
F P
0 g
s
.68726 .35434 m .66962 .33378 L .70888 .37042 L p .612 .099 0 r
F P
0 g
s
.76745 .4727 m .77949 .50558 L .75862 .4547 L p .705 .37 0 r
F P
0 g
s
.75862 .4547 m .74726 .4234 L .76745 .4727 L p .705 .37 0 r
F P
0 g
s
.74142 .7383 m .73105 .77112 L .76196 .73212 L p 0 0 .083 r
F P
0 g
s
.76196 .73212 m .77423 .69636 L .74142 .7383 L p 0 0 .083 r
F P
0 g
s
.64741 .31985 m .66962 .33378 L .61244 .30754 L p .458 0 0 r
F P
0 g
s
.61244 .30754 m .59894 .29757 L .64741 .31985 L p .458 0 0 r
F P
0 g
s
.36074 .35118 m .34057 .37365 L .30898 .41792 L p .666 .898 .554 r
F P
0 g
s
.2918 .4478 m .30898 .41792 L .34057 .37365 L p 0 0 0 r
F P
0 g
s
.26327 .60068 m .26472 .63653 L .28616 .6837 L p .967 .703 .274 r
F P
0 g
s
.292 .71831 m .28616 .6837 L .26472 .63653 L p .902 .597 .101 r
F P
0 g
s
.34479 .78788 m .35934 .81708 L .41253 .84064 L p .829 .404 .229 r
F P
0 g
s
.42658 .86244 m .41253 .84064 L .35934 .81708 L p .75 .242 .001 r
F P
0 g
s
.41253 .84064 m .42658 .86244 L .48197 .87419 L p .7 .233 .14 r
F P
0 g
s
.292 .71831 m .30344 .75252 L .34479 .78788 L p .921 .531 .226 r
F P
0 g
s
.35934 .81708 m .34479 .78788 L .30344 .75252 L p .849 .391 .014 r
F P
0 g
s
.78188 .6255 m .7805 .66069 L .78836 .6114 L p 0 0 .074 r
F P
0 g
s
.78836 .6114 m .78982 .57485 L .78188 .6255 L p 0 0 .074 r
F P
0 g
s
.42779 .30741 m .40959 .31914 L .36074 .35118 L p .394 .805 .599 r
F P
0 g
s
.40959 .31914 m .42779 .30741 L .48168 .29086 L p .042 0 0 r
F P
0 g
s
.27992 .4799 m .27268 .51372 L .26622 .56571 L p .786 .743 .221 r
F P
0 g
s
.26327 .60068 m .26622 .56571 L .27268 .51372 L p 0 0 0 r
F P
0 g
s
.66843 .82996 m .65076 .85323 L .69067 .82919 L p 0 0 0 r
F P
0 g
s
.69067 .82919 m .71446 .80199 L .66843 .82996 L p 0 0 0 r
F P
0 g
s
.34057 .37365 m .36074 .35118 L .40959 .31914 L p 0 0 0 r
F P
0 g
s
.5385 .88858 m .5413 .87658 L .48197 .87419 L p .478 0 0 r
F P
0 g
s
.5413 .87658 m .5385 .88858 L .58564 .88282 L p .335 0 0 r
F P
0 g
s
.58564 .88282 m .5993 .86942 L .5413 .87658 L p .335 0 0 r
F P
0 g
s
.77949 .50558 m .78682 .53963 L .76554 .48826 L p .856 .546 .019 r
F P
0 g
s
.76554 .48826 m .75862 .4547 L .77949 .50558 L p .856 .546 .019 r
F P
0 g
s
.49025 .88666 m .48197 .87419 L .42658 .86244 L p .551 0 0 r
F P
0 g
s
.48197 .87419 m .49025 .88666 L .5385 .88858 L p .478 0 0 r
F P
0 g
s
.59894 .29757 m .61244 .30754 L .54406 .29554 L p .455 0 0 r
F P
0 g
s
.54406 .29554 m .54127 .2874 L .59894 .29757 L p .455 0 0 r
F P
0 g
s
.26472 .63653 m .27126 .67334 L .292 .71831 L p .902 .597 .101 r
F P
0 g
s
.30344 .75252 m .292 .71831 L .27126 .67334 L p .77 .426 0 r
F P
0 g
s
.73087 .39495 m .74726 .4234 L .70046 .38012 L p .823 .354 0 r
F P
0 g
s
.70046 .38012 m .68726 .35434 L .73087 .39495 L p .823 .354 0 r
F P
0 g
s
.73105 .77112 m .71446 .80199 L .74241 .76697 L p 0 0 0 r
F P
0 g
s
.74241 .76697 m .76196 .73212 L .73105 .77112 L p 0 0 0 r
F P
0 g
s
.34057 .37365 m .3255 .40072 L .2918 .4478 L p 0 0 0 r
F P
0 g
s
.27992 .4799 m .2918 .4478 L .3255 .40072 L p 0 0 .017 r
F P
0 g
s
.5993 .86942 m .58564 .88282 L .62724 .86981 L p .09 0 0 r
F P
0 g
s
.62724 .86981 m .65076 .85323 L .5993 .86942 L p .09 0 0 r
F P
0 g
s
.47335 .29962 m .48168 .29086 L .54127 .2874 L p .315 0 0 r
F P
0 g
s
.48168 .29086 m .47335 .29962 L .40959 .31914 L p .042 0 0 r
F P
0 g
s
.7805 .66069 m .77423 .69636 L .7817 .64941 L p .714 .68 .136 r
F P
0 g
s
.7817 .64941 m .78836 .6114 L .7805 .66069 L p .714 .68 .136 r
F P
0 g
s
.54127 .2874 m .54406 .29554 L .47335 .29962 L p .315 0 0 r
F P
0 g
s
.30344 .75252 m .32171 .78527 L .35934 .81708 L p .849 .391 .014 r
F P
0 g
s
.38026 .84214 m .35934 .81708 L .32171 .78527 L p .663 .146 0 r
F P
0 g
s
.35934 .81708 m .38026 .84214 L .42658 .86244 L p .75 .242 .001 r
F P
0 g
s
.66962 .33378 m .68726 .35434 L .6232 .32513 L p .714 .186 0 r
F P
0 g
s
.6232 .32513 m .61244 .30754 L .66962 .33378 L p .714 .186 0 r
F P
0 g
s
.27268 .51372 m .26971 .54917 L .26327 .60068 L p 0 0 0 r
F P
0 g
s
.26472 .63653 m .26327 .60068 L .26971 .54917 L p 0 0 .169 r
F P
0 g
s
.44533 .8772 m .42658 .86244 L .38026 .84214 L p .529 0 0 r
F P
0 g
s
.42658 .86244 m .44533 .8772 L .49025 .88666 L p .551 0 0 r
F P
0 g
s
.78682 .53963 m .78982 .57485 L .76838 .52394 L p .941 .667 .202 r
F P
0 g
s
.76838 .52394 m .76554 .48826 L .78682 .53963 L p .941 .667 .202 r
F P
0 g
s
.40959 .31914 m .39509 .33806 L .34057 .37365 L p 0 0 0 r
F P
0 g
s
.3255 .40072 m .34057 .37365 L .39509 .33806 L p .116 0 .097 r
F P
0 g
s
.39509 .33806 m .40959 .31914 L .47335 .29962 L p .295 0 .024 r
F P
0 g
s
.3255 .40072 m .31504 .43125 L .27992 .4799 L p 0 0 .017 r
F P
0 g
s
.27268 .51372 m .27992 .4799 L .31504 .43125 L p 0 0 .208 r
F P
0 g
s
.27126 .67334 m .28406 .71076 L .30344 .75252 L p .77 .426 0 r
F P
0 g
s
.32171 .78527 m .30344 .75252 L .28406 .71076 L p 0 0 .404 r
F P
0 g
s
.65076 .85323 m .62724 .86981 L .65917 .85061 L p 0 0 0 r
F P
0 g
s
.65917 .85061 m .69067 .82919 L .65076 .85323 L p 0 0 0 r
F P
0 g
s
.74726 .4234 m .75862 .4547 L .70964 .40993 L p .908 .501 .179 r
F P
0 g
s
.70964 .40993 m .70046 .38012 L .74726 .4234 L p .908 .501 .179 r
F P
0 g
s
.77423 .69636 m .76196 .73212 L .7687 .68859 L p .838 .834 .363 r
F P
0 g
s
.7687 .68859 m .7817 .64941 L .77423 .69636 L p .838 .834 .363 r
F P
0 g
s
.71446 .80199 m .69067 .82919 L .7145 .79927 L p .588 .851 .502 r
F P
0 g
s
.7145 .79927 m .74241 .76697 L .71446 .80199 L p .588 .851 .502 r
F P
0 g
s
.26971 .54917 m .27116 .58643 L .26472 .63653 L p 0 0 .169 r
F P
0 g
s
.27126 .67334 m .26472 .63653 L .27116 .58643 L p 0 0 .352 r
F P
0 g
s
.61244 .30754 m .6232 .32513 L .5463 .31175 L p .642 .153 .075 r
F P
0 g
s
.5463 .31175 m .54406 .29554 L .61244 .30754 L p .642 .153 .075 r
F P
0 g
s
.535 .89082 m .5385 .88858 L .49025 .88666 L p .135 0 0 r
F P
0 g
s
.5385 .88858 m .535 .89082 L .56855 .88672 L p 0 0 0 r
F P
0 g
s
.56855 .88672 m .58564 .88282 L .5385 .88858 L p 0 0 0 r
F P
0 g
s
.50062 .88945 m .49025 .88666 L .44533 .8772 L p .173 0 0 r
F P
0 g
s
.49025 .88666 m .50062 .88945 L .535 .89082 L p .135 0 0 r
F P
0 g
s
.78982 .57485 m .78836 .6114 L .76699 .5619 L p .985 .749 .352 r
F P
0 g
s
.76699 .5619 m .76838 .52394 L .78982 .57485 L p .985 .749 .352 r
F P
0 g
s
.32171 .78527 m .34784 .81488 L .38026 .84214 L p .663 .146 0 r
F P
0 g
s
.38026 .84214 m .40805 .86094 L .44533 .8772 L p .529 0 0 r
F P
0 g
s
.40805 .86094 m .38026 .84214 L .34784 .81488 L p 0 .197 .665 r
F P
0 g
s
.68726 .35434 m .70046 .38012 L .63128 .34892 L p .807 .363 .188 r
F P
0 g
s
.63128 .34892 m .6232 .32513 L .68726 .35434 L p .807 .363 .188 r
F P
0 g
s
.46669 .3163 m .47335 .29962 L .54406 .29554 L p .509 .05 .099 r
F P
0 g
s
.47335 .29962 m .46669 .3163 L .39509 .33806 L p .295 0 .024 r
F P
0 g
s
.58564 .88282 m .56855 .88672 L .59798 .87751 L p .257 .761 .73 r
F P
0 g
s
.59798 .87751 m .62724 .86981 L .58564 .88282 L p .257 .761 .73 r
F P
0 g
s
.54406 .29554 m .5463 .31175 L .46669 .3163 L p .509 .05 .099 r
F P
0 g
s
.31504 .43125 m .30866 .46456 L .27268 .51372 L p 0 0 .208 r
F P
0 g
s
.26971 .54917 m .27268 .51372 L .30866 .46456 L p .019 0 .344 r
F P
0 g
s
.39509 .33806 m .38423 .36274 L .3255 .40072 L p .116 0 .097 r
F P
0 g
s
.31504 .43125 m .3255 .40072 L .38423 .36274 L p .241 0 .275 r
F P
0 g
s
.76196 .73212 m .74241 .76697 L .74806 .72806 L p .908 .938 .572 r
F P
0 g
s
.74806 .72806 m .7687 .68859 L .76196 .73212 L p .908 .938 .572 r
F P
0 g
s
.28406 .71076 m .30442 .74786 L .32171 .78527 L p 0 0 .404 r
F P
0 g
s
.34784 .81488 m .32171 .78527 L .30442 .74786 L p 0 .102 .655 r
F P
0 g
s
.44533 .8772 m .46872 .88274 L .50062 .88945 L p .173 0 0 r
F P
0 g
s
.46872 .88274 m .44533 .8772 L .40805 .86094 L p 0 .45 .799 r
F P
0 g
s
.75862 .4547 m .76554 .48826 L .71525 .44299 L p .938 .585 .323 r
F P
0 g
s
.71525 .44299 m .70964 .40993 L .75862 .4547 L p .938 .585 .323 r
F P
0 g
s
.27116 .58643 m .27774 .62564 L .27126 .67334 L p 0 0 .352 r
F P
0 g
s
.28406 .71076 m .27126 .67334 L .27774 .62564 L p 0 0 .516 r
F P
0 g
s
.38423 .36274 m .39509 .33806 L .46669 .3163 L p .42 .058 .242 r
F P
0 g
s
.69067 .82919 m .65917 .85061 L .67783 .82688 L p .718 .98 .772 r
F P
0 g
s
.67783 .82688 m .7145 .79927 L .69067 .82919 L p .718 .98 .772 r
F P
0 g
s
.62724 .86981 m .59798 .87751 L .62027 .86401 L p .542 .928 .859 r
F P
0 g
s
.62027 .86401 m .65917 .85061 L .62724 .86981 L p .542 .928 .859 r
F P
0 g
s
.78836 .6114 m .7817 .64941 L .7607 .60231 L p 1 .807 .479 r
F P
0 g
s
.7607 .60231 m .76699 .5619 L .78836 .6114 L p 1 .807 .479 r
F P
0 g
s
.30866 .46456 m .30604 .50044 L .26971 .54917 L p .019 0 .344 r
F P
0 g
s
.27116 .58643 m .26971 .54917 L .30604 .50044 L p .114 .012 .45 r
F P
0 g
s
.6232 .32513 m .63128 .34892 L .54798 .33458 L p .71 .302 .273 r
F P
0 g
s
.54798 .33458 m .5463 .31175 L .6232 .32513 L p .71 .302 .273 r
F P
0 g
s
.70046 .38012 m .70964 .40993 L .63691 .37758 L p .837 .458 .333 r
F P
0 g
s
.63691 .37758 m .63128 .34892 L .70046 .38012 L p .837 .458 .333 r
F P
0 g
s
.34784 .81488 m .38233 .83924 L .40805 .86094 L p 0 .197 .665 r
F P
0 g
s
.4425 .87126 m .40805 .86094 L .38233 .83924 L p .083 .499 .899 r
F P
0 g
s
.40805 .86094 m .4425 .87126 L .46872 .88274 L p 0 .45 .799 r
F P
0 g
s
.74241 .76697 m .7145 .79927 L .71877 .76624 L p .918 .979 .733 r
F P
0 g
s
.71877 .76624 m .74806 .72806 L .74241 .76697 L p .918 .979 .733 r
F P
0 g
s
.76554 .48826 m .76838 .52394 L .71755 .47904 L p .945 .637 .422 r
F P
0 g
s
.71755 .47904 m .71525 .44299 L .76554 .48826 L p .945 .637 .422 r
F P
0 g
s
.38423 .36274 m .37667 .39192 L .31504 .43125 L p .241 0 .275 r
F P
0 g
s
.30866 .46456 m .31504 .43125 L .37667 .39192 L p .317 .079 .387 r
F P
0 g
s
.27774 .62564 m .29057 .6666 L .28406 .71076 L p 0 0 .516 r
F P
0 g
s
.30442 .74786 m .28406 .71076 L .29057 .6666 L p .018 .141 .652 r
F P
0 g
s
.30442 .74786 m .3334 .78302 L .34784 .81488 L p 0 .102 .655 r
F P
0 g
s
.38233 .83924 m .34784 .81488 L .3334 .78302 L p .036 .349 .826 r
F P
0 g
s
.4617 .33946 m .46669 .3163 L .5463 .31175 L p .59 .208 .286 r
F P
0 g
s
.46669 .3163 m .4617 .33946 L .38423 .36274 L p .42 .058 .242 r
F P
0 g
s
.53088 .88153 m .535 .89082 L .50062 .88945 L p .332 .773 .964 r
F P
0 g
s
.535 .89082 m .53088 .88153 L .54848 .87937 L p .413 .831 .967 r
F P
0 g
s
.54848 .87937 m .56855 .88672 L .535 .89082 L p .413 .831 .967 r
F P
0 g
s
.51282 .88081 m .50062 .88945 L .46872 .88274 L p .303 .727 .972 r
F P
0 g
s
.50062 .88945 m .51282 .88081 L .53088 .88153 L p .332 .773 .964 r
F P
0 g
s
.5463 .31175 m .54798 .33458 L .4617 .33946 L p .59 .208 .286 r
F P
0 g
s
.7817 .64941 m .7687 .68859 L .74844 .64505 L p .993 .844 .588 r
F P
0 g
s
.74844 .64505 m .7607 .60231 L .7817 .64941 L p .993 .844 .588 r
F P
0 g
s
.56855 .88672 m .54848 .87937 L .5638 .87452 L p .525 .887 .977 r
F P
0 g
s
.5638 .87452 m .59798 .87751 L .56855 .88672 L p .525 .887 .977 r
F P
0 g
s
.65917 .85061 m .62027 .86401 L .63293 .84748 L p .745 .979 .917 r
F P
0 g
s
.63293 .84748 m .67783 .82688 L .65917 .85061 L p .745 .979 .917 r
F P
0 g
s
.37667 .39192 m .38423 .36274 L .4617 .33946 L p .484 .175 .366 r
F P
0 g
s
.49613 .87727 m .46872 .88274 L .4425 .87126 L p .323 .695 .98 r
F P
0 g
s
.46872 .88274 m .49613 .87727 L .51282 .88081 L p .303 .727 .972 r
F P
0 g
s
.30604 .50044 m .30732 .53904 L .27116 .58643 L p .114 .012 .45 r
F P
0 g
s
.27774 .62564 m .27116 .58643 L .30732 .53904 L p .196 .12 .538 r
F P
0 g
s
.76838 .52394 m .76699 .5619 L .71642 .51825 L p .943 .674 .499 r
F P
0 g
s
.71642 .51825 m .71755 .47904 L .76838 .52394 L p .943 .674 .499 r
F P
0 g
s
.59798 .87751 m .5638 .87452 L .57523 .86748 L p .633 .916 .979 r
F P
0 g
s
.57523 .86748 m .62027 .86401 L .59798 .87751 L p .633 .916 .979 r
F P
0 g
s
.7145 .79927 m .67783 .82688 L .68058 .80091 L p .883 .97 .839 r
F P
0 g
s
.68058 .80091 m .71877 .76624 L .7145 .79927 L p .883 .97 .839 r
F P
0 g
s
.70964 .40993 m .71525 .44299 L .64035 .41023 L p .847 .514 .424 r
F P
0 g
s
.64035 .41023 m .63691 .37758 L .70964 .40993 L p .847 .514 .424 r
F P
0 g
s
.29057 .6666 m .31091 .70848 L .30442 .74786 L p .018 .141 .652 r
F P
0 g
s
.3334 .78302 m .30442 .74786 L .31091 .70848 L p .169 .301 .756 r
F P
0 g
s
.37667 .39192 m .37205 .42475 L .30866 .46456 L p .317 .079 .387 r
F P
0 g
s
.30604 .50044 m .30866 .46456 L .37205 .42475 L p .369 .163 .464 r
F P
0 g
s
.63128 .34892 m .63691 .37758 L .54915 .3627 L p .737 .386 .385 r
F P
0 g
s
.54915 .3627 m .54798 .33458 L .63128 .34892 L p .737 .386 .385 r
F P
0 g
s
.3334 .78302 m .37134 .81408 L .38233 .83924 L p .036 .349 .826 r
F P
0 g
s
.42473 .85607 m .38233 .83924 L .37134 .81408 L p .267 .531 .915 r
F P
0 g
s
.38233 .83924 m .42473 .85607 L .4425 .87126 L p .083 .499 .899 r
F P
0 g
s
.7687 .68859 m .74806 .72806 L .72904 .68933 L p .97 .866 .679 r
F P
0 g
s
.72904 .68933 m .74844 .64505 L .7687 .68859 L p .97 .866 .679 r
F P
0 g
s
.48257 .87125 m .4425 .87126 L .42473 .85607 L p .376 .673 .974 r
F P
0 g
s
.4425 .87126 m .48257 .87125 L .49613 .87727 L p .323 .695 .98 r
F P
0 g
s
.30732 .53904 m .31312 .5806 L .27774 .62564 L p .196 .12 .538 r
F P
0 g
s
.29057 .6666 m .27774 .62564 L .31312 .5806 L p .271 .221 .616 r
F P
0 g
s
.45821 .36776 m .4617 .33946 L .54798 .33458 L p .627 .298 .394 r
F P
0 g
s
.4617 .33946 m .45821 .36776 L .37667 .39192 L p .484 .175 .366 r
F P
0 g
s
.62027 .86401 m .57523 .86748 L .58151 .85894 L p .711 .911 .964 r
F P
0 g
s
.58151 .85894 m .63293 .84748 L .62027 .86401 L p .711 .911 .964 r
F P
0 g
s
.54798 .33458 m .54915 .3627 L .45821 .36776 L p .627 .298 .394 r
F P
0 g
s
.37205 .42475 m .37667 .39192 L .45821 .36776 L p .521 .25 .445 r
F P
0 g
s
.76699 .5619 m .7607 .60231 L .71133 .56085 L p .934 .704 .566 r
F P
0 g
s
.71133 .56085 m .71642 .51825 L .76699 .5619 L p .934 .704 .566 r
F P
0 g
s
.31091 .70848 m .33967 .7497 L .3334 .78302 L p .169 .301 .756 r
F P
0 g
s
.37134 .81408 m .3334 .78302 L .33967 .7497 L p .298 .435 .832 r
F P
0 g
s
.67783 .82688 m .63293 .84748 L .63428 .82956 L p .824 .933 .903 r
F P
0 g
s
.63428 .82956 m .68058 .80091 L .67783 .82688 L p .824 .933 .903 r
F P
0 g
s
.52632 .85985 m .53088 .88153 L .51282 .88081 L closepath p .572 .802 .986 r
F P
0 g
s
.52632 .85985 m .54848 .87937 L .53088 .88153 L closepath p .591 .815 .985 r
F P
0 g
s
.37205 .42475 m .37015 .46095 L .30604 .50044 L p .369 .163 .464 r
F P
0 g
s
.30732 .53904 m .30604 .50044 L .37015 .46095 L p .409 .23 .525 r
F P
0 g
s
.52632 .85985 m .51282 .88081 L .49613 .87727 L closepath p .56 .786 .984 r
F P
0 g
s
.71525 .44299 m .71755 .47904 L .64177 .44654 L p .849 .553 .488 r
F P
0 g
s
.64177 .44654 m .64035 .41023 L .71525 .44299 L p .849 .553 .488 r
F P
0 g
s
.74806 .72806 m .71877 .76624 L .70167 .73358 L p .933 .874 .755 r
F P
0 g
s
.70167 .73358 m .72904 .68933 L .74806 .72806 L p .933 .874 .755 r
F P
0 g
s
.52632 .85985 m .5638 .87452 L .54848 .87937 L closepath p .613 .824 .981 r
F P
0 g
s
.37134 .81408 m .41755 .83862 L .42473 .85607 L p .267 .531 .915 r
F P
0 g
s
.47357 .86336 m .42473 .85607 L .41755 .83862 L p .441 .657 .952 r
F P
0 g
s
.42473 .85607 m .47357 .86336 L .48257 .87125 L p .376 .673 .974 r
F P
0 g
s
.52632 .85985 m .49613 .87727 L .48257 .87125 L closepath p .556 .77 .978 r
F P
0 g
s
.31312 .5806 m .32442 .62502 L .29057 .6666 L p .271 .221 .616 r
F P
0 g
s
.31091 .70848 m .29057 .6666 L .32442 .62502 L p .339 .314 .685 r
F P
0 g
s
.63691 .37758 m .64035 .41023 L .54986 .39515 L p .749 .438 .457 r
F P
0 g
s
.54986 .39515 m .54915 .3627 L .63691 .37758 L p .749 .438 .457 r
F P
0 g
s
.52632 .85985 m .57523 .86748 L .5638 .87452 L closepath p .636 .827 .974 r
F P
0 g
s
.52632 .85985 m .48257 .87125 L .47357 .86336 L closepath p .561 .756 .969 r
F P
0 g
s
.33967 .7497 m .37705 .78799 L .37134 .81408 L p .298 .435 .832 r
F P
0 g
s
.41755 .83862 m .37134 .81408 L .37705 .78799 L p .408 .55 .886 r
F P
0 g
s
.7607 .60231 m .74844 .64505 L .70141 .60683 L p .92 .728 .626 r
F P
0 g
s
.70141 .60683 m .71133 .56085 L .7607 .60231 L p .92 .728 .626 r
F P
0 g
s
.63293 .84748 m .58151 .85894 L .58187 .8498 L p .751 .88 .938 r
F P
0 g
s
.58187 .8498 m .63428 .82956 L .63293 .84748 L p .751 .88 .938 r
F P
0 g
s
.71877 .76624 m .68058 .80091 L .66626 .77546 L p .886 .871 .817 r
F P
0 g
s
.66626 .77546 m .70167 .73358 L .71877 .76624 L p .886 .871 .817 r
F P
0 g
s
.45608 .40028 m .45821 .36776 L .54915 .3627 L p .648 .356 .463 r
F P
0 g
s
.45821 .36776 m .45608 .40028 L .37205 .42475 L p .521 .25 .445 r
F P
0 g
s
.52632 .85985 m .58151 .85894 L .57523 .86748 L closepath p .656 .824 .964 r
F P
0 g
s
.37015 .46095 m .37205 .42475 L .45608 .40028 L p .546 .305 .501 r
F P
0 g
s
.37015 .46095 m .37108 .50066 L .30732 .53904 L p .409 .23 .525 r
F P
0 g
s
.31312 .5806 m .30732 .53904 L .37108 .50066 L p .444 .291 .579 r
F P
0 g
s
.71755 .47904 m .71642 .51825 L .64107 .48665 L p .847 .583 .539 r
F P
0 g
s
.64107 .48665 m .64177 .44654 L .71755 .47904 L p .847 .583 .539 r
F P
0 g
s
.54915 .3627 m .54986 .39515 L .45608 .40028 L p .648 .356 .463 r
F P
0 g
s
.41755 .83862 m .47018 .8544 L .47357 .86336 L p .441 .657 .952 r
F P
0 g
s
.52632 .85985 m .47357 .86336 L .47018 .8544 L closepath p .571 .745 .959 r
F P
0 g
s
.32442 .62502 m .34225 .67158 L .31091 .70848 L p .339 .314 .685 r
F P
0 g
s
.33967 .7497 m .31091 .70848 L .34225 .67158 L p .4 .402 .746 r
F P
0 g
s
.37705 .78799 m .42213 .82072 L .41755 .83862 L p .408 .55 .886 r
F P
0 g
s
.47018 .8544 m .41755 .83862 L .42213 .82072 L p .502 .649 .923 r
F P
0 g
s
.52632 .85985 m .58187 .8498 L .58151 .85894 L closepath p .67 .816 .953 r
F P
0 g
s
.68058 .80091 m .63428 .82956 L .62374 .81219 L p .83 .858 .867 r
F P
0 g
s
.62374 .81219 m .66626 .77546 L .68058 .80091 L p .83 .858 .867 r
F P
0 g
s
.74844 .64505 m .72904 .68933 L .68579 .65549 L p .901 .749 .683 r
F P
0 g
s
.68579 .65549 m .70141 .60683 L .74844 .64505 L p .901 .749 .683 r
F P
0 g
s
.64035 .41023 m .64177 .44654 L .55016 .43157 L p .756 .476 .509 r
F P
0 g
s
.55016 .43157 m .54986 .39515 L .64035 .41023 L p .756 .476 .509 r
F P
0 g
s
.42213 .82072 m .47287 .84533 L .47018 .8544 L p .502 .649 .923 r
F P
0 g
s
.52632 .85985 m .47018 .8544 L .47287 .84533 L closepath p .586 .738 .948 r
F P
0 g
s
.34225 .67158 m .36734 .71868 L .33967 .7497 L p .4 .402 .746 r
F P
0 g
s
.37705 .78799 m .33967 .7497 L .36734 .71868 L p .456 .486 .801 r
F P
0 g
s
.52632 .85985 m .56489 .83365 L .57615 .84104 L closepath p .678 .789 .933 r
F P
0 g
s
.52632 .85985 m .54926 .82848 L .56489 .83365 L closepath p .674 .774 .925 r
F P
0 g
s
.52632 .85985 m .53102 .82616 L .54926 .82848 L closepath p .665 .76 .921 r
F P
0 g
s
.52632 .85985 m .51224 .82694 L .53102 .82616 L closepath p .652 .749 .92 r
F P
0 g
s
.52632 .85985 m .49507 .83076 L .51224 .82694 L closepath p .637 .74 .923 r
F P
0 g
s
.52632 .85985 m .48145 .83713 L .49507 .83076 L closepath p .621 .735 .929 r
F P
0 g
s
.52632 .85985 m .47287 .84533 L .48145 .83713 L closepath p .603 .734 .937 r
F P
0 g
s
.52632 .85985 m .57615 .84104 L .58187 .8498 L closepath p .677 .803 .942 r
F P
0 g
s
.63428 .82956 m .58187 .8498 L .57615 .84104 L p .762 .837 .909 r
F P
0 g
s
.57615 .84104 m .62374 .81219 L .63428 .82956 L p .762 .837 .909 r
F P
0 g
s
.37108 .50066 m .37528 .54416 L .31312 .5806 L p .444 .291 .579 r
F P
0 g
s
.32442 .62502 m .31312 .5806 L .37528 .54416 L p .475 .35 .63 r
F P
0 g
s
.45608 .40028 m .45521 .43666 L .37015 .46095 L p .546 .305 .501 r
F P
0 g
s
.37108 .50066 m .37015 .46095 L .45521 .43666 L p .565 .35 .547 r
F P
0 g
s
.71642 .51825 m .71133 .56085 L .63794 .53088 L p .843 .61 .586 r
F P
0 g
s
.63794 .53088 m .64107 .48665 L .71642 .51825 L p .843 .61 .586 r
F P
0 g
s
.45521 .43666 m .45608 .40028 L .54986 .39515 L p .661 .399 .512 r
F P
0 g
s
.36734 .71868 m .3997 .76392 L .37705 .78799 L p .456 .486 .801 r
F P
0 g
s
.42213 .82072 m .37705 .78799 L .3997 .76392 L p .507 .567 .851 r
F P
0 g
s
.72904 .68933 m .70167 .73358 L .66386 .70521 L p .876 .765 .736 r
F P
0 g
s
.66386 .70521 m .68579 .65549 L .72904 .68933 L p .876 .765 .736 r
F P
0 g
s
.43838 .80438 m .48145 .83713 L .47287 .84533 L p .556 .648 .896 r
F P
0 g
s
.47287 .84533 m .42213 .82072 L .43838 .80438 L p .556 .648 .896 r
F P
0 g
s
.54986 .39515 m .55016 .43157 L .45521 .43666 L p .661 .399 .512 r
F P
0 g
s
.3997 .76392 m .43838 .80438 L .42213 .82072 L p .507 .567 .851 r
F P
0 g
s
.62374 .81219 m .57615 .84104 L .56489 .83365 L p .754 .793 .885 r
F P
0 g
s
.37528 .54416 m .38345 .59147 L .32442 .62502 L p .475 .35 .63 r
F P
0 g
s
.34225 .67158 m .32442 .62502 L .38345 .59147 L p .504 .408 .679 r
F P
0 g
s
.64177 .44654 m .64107 .48665 L .55001 .47211 L p .759 .507 .552 r
F P
0 g
s
.55001 .47211 m .55016 .43157 L .64177 .44654 L p .759 .507 .552 r
F P
0 g
s
.70167 .73358 m .66626 .77546 L .63567 .75353 L p .846 .779 .787 r
F P
0 g
s
.63567 .75353 m .66386 .70521 L .70167 .73358 L p .846 .779 .787 r
F P
0 g
s
.4648 .79153 m .49507 .83076 L .48145 .83713 L p .603 .656 .875 r
F P
0 g
s
.48145 .83713 m .43838 .80438 L .4648 .79153 L p .603 .656 .875 r
F P
0 g
s
.71133 .56085 m .70141 .60683 L .63186 .57926 L p .836 .635 .631 r
F P
0 g
s
.63186 .57926 m .63794 .53088 L .71133 .56085 L p .836 .635 .631 r
F P
0 g
s
.66626 .77546 m .62374 .81219 L .6021 .79737 L p .806 .789 .836 r
F P
0 g
s
.56489 .83365 m .6021 .79737 L .62374 .81219 L p .754 .793 .885 r
F P
0 g
s
.45521 .43666 m .45563 .47706 L .37108 .50066 L p .565 .35 .547 r
F P
0 g
s
.37528 .54416 m .37108 .50066 L .45563 .47706 L p .581 .391 .589 r
F P
0 g
s
.6021 .79737 m .63567 .75353 L .66626 .77546 L p .806 .789 .836 r
F P
0 g
s
.6021 .79737 m .56489 .83365 L .54926 .82848 L p .735 .753 .867 r
F P
0 g
s
.45563 .47706 m .45521 .43666 L .55016 .43157 L p .67 .434 .554 r
F P
0 g
s
.49854 .7838 m .51224 .82694 L .49507 .83076 L p .643 .671 .861 r
F P
0 g
s
.49507 .83076 m .4648 .79153 L .49854 .7838 L p .643 .671 .861 r
F P
0 g
s
.38345 .59147 m .3963 .64192 L .34225 .67158 L p .504 .408 .679 r
F P
0 g
s
.36734 .71868 m .34225 .67158 L .3963 .64192 L p .532 .466 .727 r
F P
0 g
s
.54926 .82848 m .57157 .78693 L .6021 .79737 L p .735 .753 .867 r
F P
0 g
s
.57157 .78693 m .54926 .82848 L .53102 .82616 L p .709 .72 .857 r
F P
0 g
s
.4374 .74483 m .4648 .79153 L .43838 .80438 L p .581 .587 .824 r
F P
0 g
s
.43838 .80438 m .3997 .76392 L .4374 .74483 L p .581 .587 .824 r
F P
0 g
s
.55016 .43157 m .55001 .47211 L .45563 .47706 L p .67 .434 .554 r
F P
0 g
s
.53561 .78219 m .53102 .82616 L .51224 .82694 L p .679 .692 .856 r
F P
0 g
s
.51224 .82694 m .49854 .7838 L .53561 .78219 L p .679 .692 .856 r
F P
0 g
s
.53102 .82616 m .53561 .78219 L .57157 .78693 L p .709 .72 .857 r
F P
0 g
s
.3963 .64192 m .41431 .6939 L .36734 .71868 L p .532 .466 .727 r
F P
0 g
s
.3997 .76392 m .36734 .71868 L .41431 .6939 L p .557 .525 .775 r
F P
0 g
s
.70141 .60683 m .68579 .65549 L .6223 .63116 L p .827 .66 .675 r
F P
0 g
s
.6223 .63116 m .63186 .57926 L .70141 .60683 L p .827 .66 .675 r
F P
0 g
s
.64107 .48665 m .63794 .53088 L .54936 .51709 L p .76 .535 .591 r
F P
0 g
s
.54936 .51709 m .55001 .47211 L .64107 .48665 L p .76 .535 .591 r
F P
0 g
s
.41431 .6939 m .4374 .74483 L .3997 .76392 L p .557 .525 .775 r
F P
0 g
s
.45563 .47706 m .45757 .52178 L .37528 .54416 L p .581 .391 .589 r
F P
0 g
s
.38345 .59147 m .37528 .54416 L .45757 .52178 L p .596 .432 .631 r
F P
0 g
s
.63567 .75353 m .6021 .79737 L .57157 .78693 L p .772 .73 .814 r
F P
0 g
s
.45757 .52178 m .45563 .47706 L .55001 .47211 L p .678 .466 .592 r
F P
0 g
s
.68579 .65549 m .66386 .70521 L .60893 .68493 L p .814 .684 .72 r
F P
0 g
s
.60893 .68493 m .6223 .63116 L .68579 .65549 L p .814 .684 .72 r
F P
0 g
s
.48607 .73327 m .49854 .7838 L .4648 .79153 L p .639 .613 .807 r
F P
0 g
s
.4648 .79153 m .4374 .74483 L .48607 .73327 L p .639 .613 .807 r
F P
0 g
s
.66386 .70521 m .63567 .75353 L .59182 .73795 L p .796 .707 .766 r
F P
0 g
s
.57157 .78693 m .59182 .73795 L .63567 .75353 L p .772 .73 .814 r
F P
0 g
s
.59182 .73795 m .60893 .68493 L .66386 .70521 L p .796 .707 .766 r
F P
0 g
s
.55001 .47211 m .54936 .51709 L .45757 .52178 L p .678 .466 .592 r
F P
0 g
s
.45757 .52178 m .46134 .5709 L .38345 .59147 L p .596 .432 .631 r
F P
0 g
s
.3963 .64192 m .38345 .59147 L .46134 .5709 L p .609 .474 .672 r
F P
0 g
s
.59182 .73795 m .57157 .78693 L .53561 .78219 L p .732 .683 .803 r
F P
0 g
s
.63794 .53088 m .63186 .57926 L .5481 .5666 L p .76 .563 .63 r
F P
0 g
s
.5481 .5666 m .54936 .51709 L .63794 .53088 L p .76 .563 .63 r
F P
0 g
s
.53979 .73086 m .53561 .78219 L .49854 .7838 L p .689 .644 .801 r
F P
0 g
s
.49854 .7838 m .48607 .73327 L .53979 .73086 L p .689 .644 .801 r
F P
0 g
s
.53561 .78219 m .53979 .73086 L .59182 .73795 L p .732 .683 .803 r
F P
0 g
s
.47551 .67881 m .48607 .73327 L .4374 .74483 L p .631 .563 .759 r
F P
0 g
s
.4374 .74483 m .41431 .6939 L .47551 .67881 L p .631 .563 .759 r
F P
0 g
s
.46134 .5709 m .46725 .6238 L .3963 .64192 L p .609 .474 .672 r
F P
0 g
s
.41431 .6939 m .3963 .64192 L .46725 .6238 L p .621 .517 .715 r
F P
0 g
s
.46134 .5709 m .45757 .52178 L .54936 .51709 L p .684 .499 .63 r
F P
0 g
s
.46725 .6238 m .47551 .67881 L .41431 .6939 L p .621 .517 .715 r
F P
0 g
s
.63186 .57926 m .6223 .63116 L .54611 .62 L p .758 .591 .67 r
F P
0 g
s
.54611 .62 m .5481 .5666 L .63186 .57926 L p .758 .591 .67 r
F P
0 g
s
.54936 .51709 m .5481 .5666 L .46134 .5709 L p .684 .499 .63 r
F P
0 g
s
.60893 .68493 m .59182 .73795 L .53979 .73086 L p .745 .65 .755 r
F P
0 g
s
.54334 .67566 m .53979 .73086 L .48607 .73327 L p .692 .603 .753 r
F P
0 g
s
.48607 .73327 m .47551 .67881 L .54334 .67566 L p .692 .603 .753 r
F P
0 g
s
.6223 .63116 m .60893 .68493 L .54334 .67566 L p .753 .62 .711 r
F P
0 g
s
.54334 .67566 m .54611 .62 L .6223 .63116 L p .753 .62 .711 r
F P
0 g
s
.53979 .73086 m .54334 .67566 L .60893 .68493 L p .745 .65 .755 r
F P
0 g
s
.46725 .6238 m .46134 .5709 L .5481 .5666 L p .688 .532 .669 r
F P
0 g
s
.5481 .5666 m .54611 .62 L .46725 .6238 L p .688 .532 .669 r
F P
0 g
s
.54611 .62 m .54334 .67566 L .47551 .67881 L p .691 .566 .71 r
F P
0 g
s
.47551 .67881 m .46725 .6238 L .54611 .62 L p .691 .566 .71 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1fooooo`go0000:_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo000Qooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06Wooooo3?l00009oe000004o`000?md003oM000og@0
00Ko00009?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02gooooo000Sooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Uooooo`?o
000000?o2P00o`000?m@00004_m@00000ol0003oM000og@00007og@000Ko00007_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02cooooo000Hooooo`Ko00001Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0H?ooool4o`0000?o2P00
00?o0000oe000?m@00001om@000?o`0000coM0001?l0000Jooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;?ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo05cooooo0ol00004o`X000go00002on231T01?l0003oY2LCoj@W
4onT9a<5o`0000[oM0000ol0000Hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
:oooool002?ooooo00?o0000ooooooooool01?ooool2o`0001;ooooo00?o0000ooooooooool0F?oo
ool3o`0000Co2P000ol00002od/01P03o`000?n231WoPP`I01?oPP`I00?o0000oj@W4onT9a<01_nT
9a<6o`0000GoM00000Co0000ogD00?l0003o00005_ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1Dooooo`?o00001?l:0003o`0000CoB`0600?o0000oh8<6On231T05On2
31T00ol0003oY2LCoj@W4`0;oj@W4`Go000000CoM000o`000?me003oM@000ol0000Cooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0:_ooool002?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05;ooooo00Co0000o`X00?l:003o2P00
1?l00007od/01P03o`000?n231WoPP`I01GoPP`I00?o0000oj@W4onT9a<04?nT9a<4o`0000?oM@00
0_l0000Aooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04oooooo0_l0
00001?l:003o0000o`000?l0000;od/01P03o`000?n231WoPP`I00WoPP`I4?l0000Aoj@W4`04o`00
0?nf;`3o0000o`0000?oM@000_l0000?ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=ooooo`Co0000
2om;00H?o`0000coUcE900Co0000okE=AOneCDGo]De51_l0000<oj@W4`03o`000?nf;`3o]Rl000?o
00000_me0002o`0000gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`00
:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04[ooooo0ol0000;od/01P?o0000
0_m[3Sd00ol0003oUcE9oiLeB@0FoiLeB@03o`000?neCDGo]De500Oo]De51_l00007oj@W4`03o`00
0?nf;`3o]Rl000;o]Rl00_l00002ogD000;o00002oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?oo
ool3o`0000WoB`060ol00005of/>?@03o`000?nG=DWoUcE901KoUcE900?o0000okE=AOneCDD03One
CDD6o`000003oj@W4ol0003o]Rl000Go]Rl00_l00002ogD00003o`000?oooooooooo00Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`0001[ooooo00?o0000
ooooooooool0AOooool4o`0000OoB`060ol00008of/>?@03o`000?nG=DWoUcE901OoUcE900?o0000
okE=AOneCDD04_neCDD4o`0000Ko]Rl00_l000000ome003o0000o`000009ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`13ooooo`Co00001Om;00H3o`0000_oJ`hm00?o0000oiLeBOnG=DT05onG=DT00ol0
003o]De5okE=A@0DokE=A@04o`000?o>G33o0000o`0000Ko]Rl01?l00008ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`10ooooo`Ko00000_m;00H3o`0000goJ`hm00?o0000oiLeBOnG=DT06?nG=DT00ol0
003o]De5okE=A@0EokE=A@03o`000?o>G33ocU``00?o00001_nf;`02o`0000Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Uooooo`00:Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo03kooooo2Ol0000@of/>?@03o`000?nG=DWoUcE9017oUcE92ol0000DokE=A@03
o`000?o>G33ocU``00?ocU``0_l00006okH_00;o00001Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02Cooooo000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
>oooool8o`0001?oJ`hm00?o0000oiLeBOnG=DT01?nG=DT=o`0000OoX4aT00Co0000okaRH_nlHV;o
_69R1ol0000>okE=A@03o`000?o>G33ocU``00CocU``0_l00004okH_0003o`000?nL6@3o000000Co
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03Wooooo1_l000000olM01So0000of/>?@0Aof/>?@Wo0000
5?nPC6@00ol0003o_69RokaRHP08okaRHPKo00002?neCDD00ol0003ocU``oliL<006oliL<0;o0000
0onf;`000ol0003oW1T0o`000003ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
8oooool002Sooooo0_l0000Qooooo`03o`000?oooooooooo03Kooooo1ol000000olM01So0000of/>
?@0?of/>?@?o00000_mk;5d00ol0003oX4aToj1<I00Hoj1<I003o`000?nlHV;o_69R00ko_69R1ol0
00000oneCDGo0000oliL<009oliL<0;o00000_nf;`000ol0003oW1T0o`000002ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0dooooo`Ko00000olM01P00ol0003oJ`hmof/>?@0:of/>?@Co00001Omk;5d0
0ol0003oX4aToj1<I00Hoj1<I003o`000?nlHV;o_69R01Go_69R1?l0000:oliL<0Co000000CoW1T0
o`000?oooooo0000>oooool00ol0003oooooooooo`0Rooooo`00:?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03;ooooo1_l00003oad06003o`000?m[3SgoJ`hm00OoJ`hm1?l00009
og//G@03o`000?nPC6CoX4aT01SoX4aT00?o0000okaRH_nlHV805onlHV801?l0003oeWEEo`000?l0
000;oliL<0;o000000?oW1T0o`000?l00000??ooool00ol0003oooooooooo`0Qooooo`00:?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo1?l00005oad06003o`000?m[3Sgo
J`hm00CoJ`hm0ol0000=og//G@03o`000?nPC6CoX4aT01SoX4aT00?o0000okaRH_nlHV805onlHV80
1?l0003oeWEEomIeEOoFMED2o`0000_ocU``0ol0000looooo`03o`000?oooooooooo027ooooo000W
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;oooool3o`0000Ko7@0H00Co0000
of/>?Om[3SgoJ`hm1?l0000?og//G@03o`000?nPC6CoX4aT01WoX4aT00?o0000okaRH_nlHV805onl
HV800ol0003oeWEEomIeE@03omIeE@;o00002Oo>G3001?l0003odUX0o`000?l0000looooo`03o`00
0?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Ooo
ool3o`0000Oo7@0H1?l0000Cog//G@03o`000?nPC6CoX4aT01WoX4aT00?o0000okaRH_nlHV805onl
HV800ol0003oeWEEomIeE@05omIeE@;o00002?o>G304o`0003_ooooo00?o0000ooooooooool08?oo
ool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0[ooooo`;o00001olM01P3
o`0001KoNbaM00?o0000oj1<I?nPC6@02onPC6@Bo`0001Oo_69R00?o0000omIeEOoFMED01_oFMED3
o`0000GocU``0_l000000ooBFP3o0000o`00000kooooo`03o`000?oooooooooo01oooooo000Woooo
o`;o0000:Oooool00ol0003oooooooooo`0Yooooo`;o00001olM01P00ol0003o?@16o`00000Eog//
GA3o00003_nUFgH01?l0003o_g1dokm`M?noL7@7o`00013o_69R00?o0000omIeEOoFMED02OoFMED2
o`0000CocU``00?o0000om9J0?oBFP000_l0000kooooo`03o`000?oooooooooo01kooooo000Woooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003o7@0Hoad06005oad0
60;o00000_lm04H00ol0003oNbaMog//G@0@og//G@?o00000_n5?g400ol0003oYE]fojEKMP0IojEK
MP03o`000?noL7Co_g1d00So_g1d1ol00009okaRHP03o`000?oFMEGoeWEE00_oeWEE0_l00002oliL
<004o`000?oBFP3odUX0om9J00;o0000>_ooool00ol0003oooooooooo`0Nooooo`009oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo02Gooooo00?o0000oad06?lM01P01OlM01P01Ol0
003o?@16ocd0A_lm04Ko0000013oNbaM0ol00005ohDoL@03o`000?nUFgKoYE]f01WoYE]f00?o0000
okm`M?noL7@03onoL7@7o`0000;o_69R00?o0000omIeEOoFMED03OoFMED4o`0000?odUX000?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo02Cooooo00?o0000oad06?lM01P00olM01P2o`0000Co?@1600?o0000og//
GOmk;5d02omk;5d3o`0000SoQCma00?o0000ojEKM_nUFgH06OnUFgH00ol0003o_g1dokm`M00Fokm`
M0Co00004?oFMED2o`0000CodUX000?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Moooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02;ooooo00?o0000oad06?lM
01P00olM01P00ol0003o?@16ocd0AP04ocd0AP03o`000?mk;5goNbaM00OoNbaM1?l0000;ohDoL@03
o`000?nUFgKoYE]f01WoYE]f00?o0000okm`M?noL7@06?noL7@01?l0003of8=/o`000?l0000>omIe
E@04o`000?oFMEGo0000o`0000?odUX000?o0000ooooooooool0>?ooool00ol0003oooooooooo`0L
ooooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo023ooooo0_l00003oad0
60;o00001olm04H00ol0003oNbaMog//G@04og//G@?o00003on5?g400ol0003oYE]fojEKMP0IojEK
MP03o`000?noL7Co_g1d01So_g1d00Co0000omR3K?oHPfcof8=/0_l0000<omIeE@05o`000?oFMEGo
0000onR0;Ol000000ooBFP000ol0003oooooooooo`0hooooo`03o`000?oooooooooo01_ooooo000V
ooooo`?o0000;oooool00ol0003oooooooooo`0Nooooo`;o00000olM01P00ol0003o?@16ocd0AP07
ocd0AP04o`000?mk;5goNbaMog//G@?o00004On5?g400ol0003oYE]fojEKMP0JojEKMP03o`000?no
L7Co_g1d01So_g1d00?o0000omR3K?oHPf`00ooHPf`2o`0000_oeWEE0_l00002onR0;@05o`000?oB
FP3odUX0om9J0?l00000>Oooool00ol0003oooooooooo`0Kooooo`009_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01gooooo00?o0000oad06?lM01P00_l00009ocd0AP03o`000?mk
;5go000000;o00005?n5?g400ol0003oYE]fojEKMP0JojEKMP03o`000?noL7Co_g1d01Wo_g1d00?o
0000omR3K?oHPf`01?oHPf`2o`0000WoeWEE00?o0000omIeEOl000000_oXP2d01Ol0003odUX0om9J
0?oBFP3o000003Wooooo00?o0000ooooooooool06_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Kooooo`;o000000?o7@0Ho`000?lm04H02Olm04H3o`0001Oo
QCma00?o0000ojEKM_nUFgH06_nUFgH00ol0003o_g1dokm`M00Iokm`M003o`000?oHPfcof8=/00Ko
f8=/0ol00006omIeE@03o`000?oFMEGo000000?oj80]00Go0000om9J0?oBFP3odUX0o`00000hoooo
o`03o`000?oooooooooo01[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
01Wooooo1?l0000:ocd0AP03o`000?mA56?o000001SoQCma00?o0000ojEKM_nUFgH04onUFgH;o`00
01So_g1d00?o0000omR3K?oHPf`02OoHPf`2o`0000CoeWEE00?o0000omIeEOl000001?oXP2d01Ol0
003odUX0om9J0?oBFP3o000003Sooooo00?o0000ooooooooool06Oooool000?ooooo1_l00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool06?ooool2o`0000[o?@160_l00002oe4DH`03o`000?n5?g7o
QCma01KoQCma00?o0000ojEKM_nUFgH01?nUFgH?o`0000OoZFJ300Co0000ol5iP_o1NH;o`GV21_l0
000Bokm`M003o`000?oHPfcof8=/00_of8=/0_l00002omIeE@04o`000?oFMEGoeWEEo`0000Coj80]
00Co0000om9J0?oBFP3o0000>Oooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo01Kooooo0_l00009ocd0AP;o00001?mA56<00ol0003oQCmaohDoL@0DohDoL@Wo
00005_nYIX<00ol0003o`GV2ol5iPP07ol5iPPKo00003?noL7@00ol0003of8=/omR3K00=omR3K0?o
00000_oFMED00ol0003oj80]onR0;@03onR0;@04o`000?oBFP3odUX0o`0003Sooooo00?o0000oooo
ooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo0ol00008
ocd0AP03o`000?mA56?oDAAS00CoDAAS00?o0000ohDoLOn5?g404?n5?g44o`0000;oRdj000?o0000
ojUVPonYIX<06_nYIX<00ol0003o`GV2ol5iPP0=ol5iPPGo00002?noL7@00ol0003of8=/omR3K00>
omR3K0;o000000?oeWEEo`000?oXP2d01OoXP2d00ol0003odUX0o`00000iooooo`03o`000?oooooo
oooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06
ooooo`;o0000>?ooool00ol0003oooooooooo`0Booooo`?o00001olm04H2o`0000OoDAAS00?o0000
ohDoLOn5?g403On5?g43o`0000KoRdj000?o0000ojUVPonYIX<06_nYIX<00ol0003o`GV2ol5iPP0B
ol5iPPKo00000_noL7@00ol0003of8=/omR3K00>omR3K003o`000?oHPfco000000;o00001_oXP2d0
0ol0003odUX0o`00000hooooo`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool04Oooool3o`0000Ko?@1600?o0000oe4DHomA56<01_mA56<00ol0003oQCmaohDoL@0:
ohDoL@Co00002On;CX000ol0003oZFJ3ojUVP`0JojUVP`03o`000?o1NH;o`GV201So`GV21?l0000?
omR3K004o`000?oHPfcof8=/omR3K0;o00001_oXP2d00ol0003odUX0o`00000hooooo`03o`000?oo
oooooooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0?ooooo`;o000000?o0004o`000?lm04H00olm
04H2o`0000WoDAAS00?o0000ohDoLOn5?g401_n5?g44o`0000goRdj000?o0000ojUVPonYIX<06_nY
IX<00ol0003o`GV2ol5iPP0Jol5iPP04o`000?oISGco0000o`0000gof8=/00Oo0000omR3K?oHPfco
f8=/o`000?o`UE;o000000Koj80]0_l0000gooooo`?o00005oooool002Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0>ooooo`;o000000?o0004o`000?lm04H00olm04H00ol0003o
DAASoe4DH`09oe4DH`03o`000?n5?g7oQCma00?oQCma0ol0000Aoh]>P003o`000?nYIX?oZFJ301[o
ZFJ300?o0000ol5iP_o1NH806_o1NH801?l0003ofHelomV=O?oISG`3o`0000[of8=/00Go0000omR3
K?oHPfcof8=/o`000002oo2EDP03o`000?oXP2goj80]00Coj80]0_l0000cooooo`?o00000_ooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00gooooo0_l000001?l000Co0000ocd0A_lm04H2o`0000coDAAS00?o0000ohDoLOl000000ol0000D
oh]>P003o`000?nYIX?oZFJ301[oZFJ300?o0000ol5iP_o1NH806_o1NH800ol0003ofHelomV=O004
omV=O0;o00002?oHPf`00ol0003of8=/omR3K002omR3K004o`000?o`UE;ol9EBo`0000Koj80]00?o
0000ooooooooool0;_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`;o00000_l000@3o`0000goDAAS0ol0000H
oh]>P003o`000?nYIX?oZFJ301[oZFJ300?o0000ol5iP_o1NH806_o1NH800ol0003ofHelomV=O006
omV=O0;o00001_oHPf`00ol0003of8=/omR3K002omR3K005o`000?o`UE;ol9EBoo2ED_l000001_oX
P2d00ol0003oooooooooo`0Zooooo`?o00002?ooool00ol0003oooooooooo`0Eooooo`009?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo0_l00002o`0010;o00003_mA56<0
0ol0003oGRUfo`00000Ioh]>P003o`000?nYIX?oZFJ301[oZFJ300?o0000ol5iP_o1NH806_o1NH80
0ol0003ofHelomV=O008omV=O0?o00000ooHPf`00ol0003of8=/omR3K002omR3K003o`000?o`UE;o
l9EB00;ol9EB00?o0000onR0;OoXP2d00ooXP2d00ol0003oooooooooo`0Wooooo`?o00002oooool0
0ol0003oooooooooo`0Eooooo`009?ooool2o`0003oooooo00?o0000ooooooooool02?ooool01Ol0
003o0004o`001?l000Co000000goDAAS0_l00002oehYMP03o`000?n;CX3oRdj001OoRdj000?o0000
ojUVPonYIX<04onYIX<;o`0001Wo`GV200?o0000omV=O?oISG`02ooISG`2o`000003omR3K?l0003o
f8=/00?of8=/00?o0000oo2ED_o`UE800oo`UE800ol0003oj80]onR0;@03onR0;@03o`000?oooooo
oooo02?ooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool01_ooool2o`0000?o000400?o0000oe4DHomA56<02_mA56<00ol0
003oGRUfoehYMP02oehYMP03o`000?n;CX3oRdj001OoRdj000?o0000ojUVPonYIX<01?nYIX<?o`00
00OoZfn=00Co0000ol:1SOo2PHgo`X6=1_l0000Col5iPP03o`000?oISGcofHel00gofHel0_l00004
omR3K003o`000?o`UE;ol9EB00Col9EB0_l00003onR0;@03o`000?oooooooooo023ooooo0ol0000B
ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool01?ooool2o`0000?o00040_l0000:oe4DH`;o00001OmN:GH00ol0003oRdj0oh]>P00Eoh]>
P0Wo00005_n[Khd00ol0003o`X6=ol:1S@07ol:1S@Ko00003Oo1NH800ol0003ofHelomV=O00>omV=
O0Co00000_oHPf`00ol0003ol9EBoo2EDP05oo2EDP04o`000?oXP2goj80]o`0001oooooo0ol0000E
ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04;ooooo00?o0000oooo
ooooool00oooool01ol0003o0004o`001?l000Co0000o`00=Ol000002OmA56<00ol0003oGRUfoehY
MP05oehYMP03o`000?n;CX3oRdj001;oRdj00ol00002oi1IS003o`000?n[KhgoZfn=01[oZfn=00?o
0000ol:1SOo2PHd03Oo2PHd5o`0000So`GV200?o0000omV=O?oISG`03_oISG`01?l0003ofHelomV=
O?oISG`3o`0000Sol9EB00Co0000onR0;OoXP2go00006oooool3o`0001Sooooo00?o0000oooooooo
ool05?ooool002?ooooo00?o0000ooooooooool0@oooool01Ol0003ooooooooooooooooo000000?o
000400?o0000o`00=Ol000002?mA56<2o`0000SoGRUf00?o0000oh]>P?n;CX003on;CX03o`0000Go
T5V<00?o0000oj]_SOn[Khd06_n[Khd00ol0003o`X6=ol:1S@0Bol:1S@Ko00000_o1NH800ol0003o
fHelomV=O00?omV=O003o`000?oISGcofHel00;ofHel0_l00008oo2EDP03o`000?oXP2go000001So
oooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooool000001?l000@00ol0003o000eo`000006oe4DH`;o00002OmN:GH00ol0003oRdj0
oh]>P00<oh]>P0Co00002?n@FH`00ol0003oZfn=oj]_S@0Joj]_S@03o`000?o2PHgo`X6=01So`X6=
1?l0000@omV=O003o`000?oISGcofHel00;ofHel00?o0000oo6SK?l000002?o`UE800ol0003oj80]
o`00000Dooooo`?o00007_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003ooooooooo
o`15ooooo`;o00000ol000@01?l0003o000eo`00=Ol00005oe4DH`03o`000?mN:GKoGRUf00WoGRUf
00?o0000oh]>P?n;CX002On;CX03o`0000coT5V<00?o0000oj]_SOn[Khd06_n[Khd00ol0003o`X6=
ol:1S@0Jol:1S@03o`000?oHUHWo000000;o00003OoISG`00ol0003ofHelomV=O002omV=O004o`00
0?oaXfcolJ=/o`0000Sol9EB0_l0000Aooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`00
8oooool2o`0004Oooooo00Co0000o`001?l000Co00000ol003D01?l0003oDAASoe4DHomA56<2o`00
00coGRUf00?o0000oh]>P?n;CX001On;CX04o`0000ooT5V<00?o0000oj]_SOn[Khd06_n[Khd00ol0
003o`X6=ol:1S@0Jol:1S@03o`000?oHUHWof9F900;of9F90_l0000;omV=O003o`000?oISGcofHel
00;ofHel00Go0000oo6SK?oaXfcolJ=/o`000008oo2EDP03o`000?oooooooooo00cooooo0ol0000U
ooooo`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo04Gooooo00Co0000o`00
1?l000Co00001?l003D01?l0003oDAASoe4DHol0000>oehYMP03o`000?n;CX3oRdj000;oRdj00ol0
000Coi1IS003o`000?n[KhgoZfn=01[oZfn=00?o0000ol:1SOo2PHd06_o2PHd00ol0003of9F9omRE
R@04omRER@;o00002OoISG`00ol0003ofHelomV=O002omV=O003o`000?oaXfcolJ=/00;olJ=/00?o
0000oo2ED_o`UE801_o`UE800ol0003oooooooooo`08ooooo`?o0000:?ooool00ol0003ooooooooo
o`0Cooooo`008_ooool00ol0003oooooooooo`16ooooo`04o`000?l000Co0004o`0000?o000e00Co
0000oe4DHol0003o00003omN:GH00ol0003oRdj0o`000002o`0001KoT5V<00?o0000oj]_SOn[Khd0
6_n[Khd00ol0003o`X6=ol:1S@0Jol:1S@03o`000?oHUHWof9F900Kof9F90ol00006omV=O003o`00
0?oISGcofHel00;ofHel00?o0000oo6SK?oaXf`00ooaXf`00ol0003ol9EBoo2EDP05oo2EDP03o`00
0?oooooooooo00Gooooo0ol0000[ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oo
oooooooo04Kooooo00?o0000o`001?l000001?l003D2o`00013oGRUf0ol0000Ioi1IS003o`000?n[
KhgoZfn=01[oZfn=00?o0000ol:1SOo2PHd06_o2PHd00ol0003of9F9omRER@09omRER@;o00001?oI
SG`00ol0003ofHelomV=O003omV=O003o`000?oaXfcolJ=/00?olJ=/00?o0000oo2ED_o`UE801?o`
UE82o`0000?ooooo0ol0000^ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooo
oooo04Gooooo00?o0000o`001?l000001Ol003D00ol0003oGRUfoehYMP0=oehYMP;o000000?oJ3Z6
o`000?n@FH`06On@FH`00ol0003oZfn=oj]_S@0Joj]_S@03o`000?o2PHgo`X6=01[o`X6=00?o0000
omREROoHUHT02ooHUHT3o`000003omV=O?l0003ofHel00CofHel00?o0000oo6SK?oaXf`01?oaXf`2
o`0000Gol9EB1?l0000aooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
04Gooooo00?o0000o`001?l000001Ol003D00ol0003oGRUfoehYMP0<oehYMP05o`000?mX>XKoJ3Z6
ofPjQ_l000006_n@FH`00ol0003oZfn=oj]_S@0Joj]_S@03o`000?o2PHgo`X6=01[o`X6=00?o0000
omREROoHUHT03_oHUHT2o`0000GofHel00?o0000oo6SK?oaXf`01_oaXf`00ol0003ol9EBoo2EDP02
oo2EDP03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooo
ooooool0AOooool2o`0000Go000e0_l0000<oehYMP;o00001?mX>XH00ol0003oT5V<oi1IS00Hoi1I
S003o`000?n[KhgoZfn=01?oZfn=2ol0000Iol:1S@03o`000?oHUHWof9F900oof9F90ol00003omV=
O003o`000?oaXfcolJ=/00OolJ=/00Co0000oo2ED_o`UE;ol9EB0_l0000cooooo`03o`000?oooooo
oooo01?ooooo000Qooooo`?o0000AOooool2o`0000Go000e00?o0000o`@0F?l000002_mN:GH2o`00
00KoJ3Z600?o0000oi1IS?n@FH`06?n@FH`00ol0003oZfn=oj]_S@04oj]_S@oo00001on]MiL01?l0
003o`XRGol:8Uoo2R9L6o`0001?o`X6=00?o0000omREROoHUHT03ooHUHT00ol0003of9F9omRER@04
o`0000[olJ=/00?o0000oo2ED_o`UE800_l0000dooooo`03o`000?oooooooooo01;ooooo000Qoooo
o`03o`000?oooooooooo04Gooooo00?o0000o`00=Ol003D00ol003D01?l0003o101Ho`@0F?l00009
oehYMP03o`000?mX>XKoJ3Z600KoJ3Z600?o0000oi1IS?n@FH`05_n@FH`9o`0001Ko[GNG00?o0000
ol:8Uoo2R9L01oo2R9L6o`0000go`X6=00?o0000omREROoHUHT03ooHUHT00ol0003of9F9omRER@03
omRER@;o00002_oaXf`00ol0003ol9EBo`000002o`0003?ooooo00?o0000ooooooooool04_ooool0
027ooooo00?o0000ooooooooool0AOooool00ol0003o000eo`00=@02o`00=@05o`000?l405So101H
o`@0F?l000001omN:GH2o`0000WoJ3Z600?o0000oi1IS?n@FH`04_n@FH`4o`0000;oU6BF00?o0000
ojegUon]MiL06_n]MiL00ol0003o`XRGol:8U`0=ol:8U`Go00002?o2PHd00ol0003of9F9omRER@0?
omRER@03o`000?oHUHWof9F900?of9F900?o0000oo6/Ool000002_oaXf`01?l0003ol9EBo`000?l0
000cooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000
o`00=Ol003D00_l003D01?l0003o101Ho`@0F?l00006oehYMP;o00002omX>XH00ol0003oT5V<oi1I
S00>oi1IS0Co00001_nDI9H00ol0003o[GNGojegU`0JojegU`03o`000?o2R9Oo`XRG01;o`XRG1_l0
0002ol:1S@03o`000?oHUHWof9F900oof9F900?o0000omREROoHUHT00ooHUHT01?l0003olJaooo6/
Ool0000:oo6SK0?o0000<oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`14ooooo`03o`000?l003Go000e00;o000e00Go0000o`@0F?l405So101Ho`000005oehYMP03o`00
0?mX>XKoJ3Z600_oJ3Z600?o0000oi1IS?n@FH`02_n@FH`4o`0000[oU6BF00?o0000ojegUon]MiL0
6_n]MiL00ol0003o`XRGol:8U`0Hol:8U`Co00004?oHUHT00ol0003of9F9omRER@03omRER@05o`00
0?oa[7oolJaooo6/Ool000002_oaXf`00ol0003ofh/4o`00000booooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo04Cooooo00Go0000o`00=Ol003Go000eo`000004o`@0F004
o`000?mN:GKoGRUfoehYMP;o00003_mX>XH00ol0003oT5V<oi1IS007oi1IS0?o00003_nDI9H00ol0
003o[GNGojegU`0JojegU`03o`000?o2R9Oo`XRG01[o`XRG00?o0000omNLU_l000000_l0000=omRE
R@03o`000?oHUHWof9F900?of9F900?o0000oo6/Oooa[7l00_oa[7l00ol0003olJ=/oo6SK007oo6S
K003o`000?oKR`Co000003;ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooooooo
ool0A?ooool01?l0003o000eo`00=Ol00005o`@0F004o`000?mN:GKo0000o`00013oJ3Z600?o0000
oi1IS?n@FH`00on@FH`4o`00017oU6BF00?o0000ojegUon]MiL06_n]MiL00ol0003o`XRGol:8U`0J
ol:8U`03o`000?oGW9KoeibF00;oeibF0_l0000;omRER@03o`000?oHUHWof9F900?of9F900?o0000
oo6/Oooa[7l00ooa[7l00ol0003olJ=/oo6SK006oo6SK0?o0000<_ooool00ol0003oooooooooo`0B
ooooo`008?ooool3o`0004Cooooo00Co0000o`00=Ol003Go00001_l405P2o`0001;oJ3Z600?o0000
oi1IS?l000000ol0000EoiATUP03o`000?n]MiOo[GNG01[o[GNG00?o0000ol:8Uoo2R9L06_o2R9L0
0ol0003oeibFomNLUP04omNLUP?o00002?oHUHT00ol0003of9F9omRER@03omRER@03o`000?oa[7oo
lJao00ColJao00?o0000oo6SK?oaXf`01OoaXf`2o`000003om^;1?l0003ooooo037ooooo00?o0000
ooooooooool04Oooool0023ooooo00?o0000ooooooooool0A?ooool01?l0003o000eo`00=Ol00006
o`@0F003o`000?mX>XKoJ3Z6013oJ3Z60ol0000IoiATUP03o`000?n]MiOo[GNG01[o[GNG00?o0000
ol:8Uoo2R9L06_o2R9L00ol0003oeibFomNLUP07omNLUP?o00001_oHUHT01Ol0003of9F9omREROoH
UHWo000000SolJao0_l00005oo6SK0;o000000?ofh/4o`000?ooool0<Oooool00ol0003ooooooooo
o`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A?oo
ool00ol0003o000eo`000007o`@0F003o`000?mX>XKoJ3Z600koJ3Z60_l000000omaBYCo0000oiAT
UP0IoiATUP03o`000?n]MiOo[GNG01[o[GNG00?o0000ol:8Uoo2R9L06_o2R9L00ol0003oeibFomNL
UP0:omNLUP;o00001?oHUHT01Ol0003of9F9omREROoHUHWo000000[olJao00?o0000oo6SK?oaXf`0
0_oaXf`01?l0003ol:Xco`000?l0000booooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`14ooooo`;o00001ol405P2o`0000oo
J3Z600Go0000og5:U?maBYCoLDZDo`00000JoiATUP03o`000?n]MiOo[GNG01[o[GNG00?o0000ol:8
Uoo2R9L06_o2R9L00ol0003oeibFomNLUP0<omNLUP?o000000?of9F9o`000?oHUHT00_oHUHT00ol0
003olJaooo6/O`09oo6/O`03o`000?oaXfcolJ=/00;olJ=/0_l000000ooKR`Co0000ooooo`0`oooo
o`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`13ooooo`;o00001ol405P00ol0003o7@=co`00000=ofPjQP;o00001?maBY@00ol0
003oU6BFoiATUP0HoiATUP03o`000?n]MiOo[GNG01[o[GNG00?o0000ol:8Uoo2R9L06Oo2R9L00ol0
003oeibFomNLUP0@omNLUP;o00000ooHUHT00ol0003olJaooo6/O`0:oo6/O`04o`000?oaXfcolJ=/
oo6SK0;o000000?ofh/4o`000?ooool0<?ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0@oooool00ol0003o101Ho`@0F005
o`@0F004o`000?lM0g?o7@=co`0000_oJ3Z60_l00007og5:U003o`000?nDI9KoU6BF01OoU6BF00?o
0000ojegUon]MiL06_n]MiL00ol0003o`XRGol:8U`0Iol:8U`03o`000?oGW9KoeibF017oeibF1Ol0
000=oo6/O`05o`000?oaXfcolJ=/o`000?o`ZS<00_l0000aooooo`03o`000?oooooooooo017ooooo
000Eooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`14ooooo`03o`00
0?l405So101H00Go101H00Co0000oad3LolM0g?o00002_mX>XH00ol0003oLDZDog5:U007og5:U003
o`000?nDI9KoU6BF01OoU6BF00?o0000ojegUon]MiL04on]MiL<o`0001Oo`XRG00?o0000omNLU_oG
W9H04OoGW9H01?l0003oeibFomNLU_oGW9H2o`0000golJao00Oo0000oo6SK?l0003ol:Xco`000?oK
R`Co0000033ooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@
4005ooooo`;o0000AOooool00ol0003o101Ho`@0F004o`@0F005o`000?lM0g?o7@=coad3Lol00000
2?mX>XH2o`0000[oLDZD00?o0000oiATU_nDI9H05onDI9H00ol0003o[GNGojegU`04ojegU`oo0000
1on_Oj400ol0003o`Y2Qol:@X@02ol:@X@Oo00004?o2R9L00ol0003oeibFomNLUP0AomNLUP07o`00
0?oGW9KoeibFomNLU_l0003okkB@o`00000=oo6/O`;o00000_o`ZS<2o`00033ooooo00?o0000oooo
ooooool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
04Cooooo00?o0000o`@0F?l405P00ol405P00ol0003o7@=coad3L`02oad3L`03o`000?mX>XKoJ3Z6
00CoJ3Z60_l0000<og5:U003o`000?nDI9KoU6BF01GoU6BF2Ol0000FojmoX@03o`000?o2T:7o`Y2Q
00Wo`Y2Q1ol00009ol:8U`03o`000?oGW9KoeibF017oeibF00Go0000omNLU_oGW9KoeibFo`000002
onndT003o`000?oa[7oolJao00_olJao00?o0000oo2Z<oo`ZS<00_l0000aooooo`03o`000?oooooo
oooo013ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`14
ooooo`03o`000?l405So101H00;o101H00?o0000oad3LolM0g<00olM0g<00ol0003oJ3Z6ofPjQP03
ofPjQP03o`000?maBYCoLDZD00coLDZD00?o0000oiATU_nDI9H04_nDI9H3o`0000;oV6jQ00?o0000
ojmoXOn_Oj406_n_Oj400ol0003o`Y2Qol:@X@0@ol:@X@Oo00000_o2R9L00ol0003oeibFomNLUP0A
omNLUP05o`000?oGW9KoeibFomNLU_l000000oo_]9000ol0003olJaooo6/O`0:oo6/O`03o`000?o`
ZS?ol:Xc00;o0000<Oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`13
ooooo`;o00001?l405P00ol0003o7@=coad3L`03oad3L`04o`000?mX>XKoJ3Z6ofPjQP;o00003oma
BY@00ol0003oU6BFoiATUP0>oiATUPCo00001OnHKZ400ol0003o[gnQojmoX@0JojmoX@03o`000?o2
T:7o`Y2Q01Oo`Y2Q1?l0000BomNLUP05o`000?oGW9KoeibFomNLU_l000001?o_]9000ol0003olJao
oo6/O`09oo6/O`;o00000_o`ZS<00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo
000Oooooo`03o`000?oooooooooo04?ooooo0_l00003o`@0F003o`000?lM0g?o7@=c00Co7@=c00Co
0000ofPjQ_l0003o00004OmaBY@00ol0003oU6BFoiATUP0:oiATUPCo00002OnHKZ400ol0003o[gnQ
ojmoX@0JojmoX@03o`000?o2T:7o`Y2Q01Wo`Y2Q00Co0000omJRXOl0003o00004?oGW9H01Ol0003o
eibFomNLU_oGW9Ko000000GokkB@00?o0000oo6/Oooa[7l02?oa[7l2o`0000;ol:Xc0_l0000`oooo
o`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo04?ooooo0_l00002o`@0F003
o`000?lM0g?o7@=c00Go7@=c0_l0000Dog5:U003o`000?nDI9KoU6BF00KoU6BF0ol0000=oiQ^X@03
o`000?n_Oj7o[gnQ01[o[gnQ00?o0000ol:@XOo2T:406Oo2T:401?l0003oeZ:QomJRXOoFXZ43o`00
00goeibF00Go0000omNLU_oGW9KoeibFo`000006onndT003o`000?oa[7oolJao00OolJao0_l00002
oo2Z<`;o0000<?ooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`14oooo
o`;o00000_l405P00ol0003o7@=coad3L`05oad3L`03o`000?maBYCoLDZD01?oLDZD00?o0000oiAT
U_nDI9H00_nDI9H4o`00017oV6jQ00?o0000ojmoXOn_Oj406On_Oj400ol0003o`Y2Qol:@X@0Iol:@
X@03o`000?oFXZ7oeZ:Q00CoeZ:Q0_l0000;omNLUP05o`000?oGW9KoeibFomNLU_l000001oo_]902
o`0000OolJao00?o0000ooboF_l000000_o`ZS<00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo013ooooo000Nooooo`03o`000?oooooooooo04Cooooo0_l000000ol405So0000oad3L`07oad3
L`03o`000?maBYCoLDZD01?oLDZD00?o0000oiATU_l000000_l0000EoiQ^X@03o`000?n_Oj7o[gnQ
01Wo[gnQ00?o0000ol:@XOo2T:406Oo2T:400ol0003oeZ:QomJRX@06omJRX@;o00002OoGW9H01?l0
003oeibFomNLU_l0000:onndT003o`000?oa[7oolJao00ColJao00?o0000ooboF_l000000_o`ZS<0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo000Nooooo`;o0000AOooool3o`00
00So7@=c0_l0000Dog5:U0?o00006?nHKZ400ol0003o[gnQojmoX@0IojmoX@03o`000?o2T:7o`Y2Q
01So`Y2Q00?o0000omJRXOoFXZ402OoFXZ43o`0000KoeibF00Co0000omNLU_oGW9Ko00002oo_]900
0ol0003olJaooo6/O`02oo6/O`04o`000?ol_e[oo;mJo`0000;ol:Xc00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00002?lM0g<0
0ol0003o<Qj9o`00000Bog5:U0;o000000?oNEVQo`000?nHKZ406?nHKZ400ol0003o[gnQojmoX@0I
ojmoX@03o`000?o2T:7o`Y2Q01So`Y2Q00?o0000omJRXOoFXZ403?oFXZ42o`0000CoeibF00Co0000
omNLU_oGW9Ko00003?o_]9001Ol0003olJaooo6/Oooa[7oo000000?oo;mJ00?o0000oo2Z<ol00000
<Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`14ooooo`;o00001olM
0g<01Ol0003o<Qj9oc8NROlb7XWo000000ooLDZD0_l00003ogUIX@03o`000?nHKZ7oV6jQ01OoV6jQ
00?o0000ojmoXOn_Oj406On_Oj400ol0003o`Y2Qol:@X@0Hol:@X@03o`000?oFXZ7oeZ:Q00koeZ:Q
0_l00002omNLUP04o`000?oGW9KoeibFo`0000gokkB@00Co0000oo6/Oooa[7oo00000ool_eX00ol0
003ol:Xco`00000aooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04?o
oooo0ol00007oad3L`05o`000?lb7XWo<Qj9oc8NROl000003_maBY@00ol0003oNEVQogUIX@03ogUI
X@03o`000?nHKZ7oV6jQ01OoV6jQ00?o0000ojmoXOn_Oj406On_Oj400ol0003o`Y2Qol:@X@0Hol:@
X@03o`000?oFXZ7oeZ:Q013oeZ:Q0ol00002omNLUP03o`000?o_]93okkB@00cokkB@00?o0000oo6/
Ool000001?ol_eX2o`00037ooooo00?o0000ooooooooool03oooool001gooooo00?o0000oooooooo
ool0A?ooool3o`0000Ko7@=c00?o0000oc8NROlb7XT00_lb7XT00ol0003oLDZDog5:U00:og5:U0;o
00001omiFJ400ol0003oV6jQoiQ^X@0FoiQ^X@03o`000?n_Oj7o[gnQ01Wo[gnQ00?o0000ol:@XOo2
T:406?o2T:400ol0003oeZ:QomJRX@0BomJRX@Co00003oo_]902o`0000Coo;mJ00?o0000oo2Z<ol0
0000<?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`14ooooo`?o0000
1OlM0g<00ol0003o<Qj9oc8NR@03oc8NR@03o`000?maBYCoLDZD00SoLDZD0_l00009ogUIX@03o`00
0?nHKZ7oV6jQ01OoV6jQ00?o0000ojmoXOn_Oj406?n_Oj400ol0003o`Y2Qol:@X@0Hol:@X@03o`00
0?oFXZ7oeZ:Q01?oeZ:Q00Co0000omJRXOl0003o00003oo_]9000ol0003oo;mJooboFP02ooboFP03
o`000?o`ZS?o0000033ooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0
A?ooool3o`0000Co7@=c00?o0000oc8NROlb7XT01?lb7XT00ol0003oLDZDog5:U006og5:U0;o0000
2omiFJ400ol0003oV6jQoiQ^X@0GoiQ^X@03o`000?n_Oj7o[gnQ01So[gnQ00?o0000ol:@XOo2T:40
6?o2T:400ol0003oeZ:QomJRX@0ComJRX@05o`000?oFXZ7o0000on^jX?l000003_o_]9000ol0003o
o;mJooboFP03ooboFP;o0000<?ooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0004Gooooo
0ol00004oad3L`03o`000?lb7XWo<Qj900Co<Qj900?o0000og5:U?maBY@01?maBY@2o`0000goNEVQ
00?o0000oiQ^XOnHKZ405onHKZ400ol0003o[gnQojmoX@0;ojmoXA7o00005oo2T:400ol0003oeZ:Q
omJRX@0ComJRX@03o`000?oFXZ7o000000;ojkZP00?o0000onndT?o_]9002oo_]902o`0000Coo;mJ
0_l0000aooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo04Cooooo0ol0
0003oad3L`03o`000?lb7XWo<Qj900Go<Qj900?o0000og5:U?maBY@00omaBY@00ol0003oNEVQogUI
X@0=ogUIX@03o`000?nHKZ7oV6jQ01GoV6jQ4?l0000=ok28Z`04o`000?o2Uj_o`YN[ol:GZ`Oo0000
3oo2T:400ol0003oeZ:QomJRX@0DomJRX@;o00001?o[^Z000ol0003okkB@onndT00:onndT0;o0000
1?ol_eX2o`00037ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0A?oo
ool3o`0000;o7@=c00?o0000oc8NROlb7XT01olb7XT00ol0003oLDZDog5:U002o`00013oNEVQ00?o
0000oiQ^XOnHKZ404OnHKZ44o`0000;oVgV/00?o0000ok28Zon`R:/06?n`R:/00ol0003o`YN[ol:G
Z`08ol:GZ`Ko00002Oo2T:400ol0003oeZ:QomJRX@0DomJRX@;o00001Oo[^Z000ol0003okkB@onnd
T008onndT004o`000?oocW[oolijo`0000Coo;mJ00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0>ooooo`007?ooool00ol0003oooooooooo`15ooooo`03o`000?l002_o000000;o7@=c00?o
0000oc8NROlb7XT01olb7XT3o`0001;oNEVQ00?o0000oiQ^XOnHKZ403OnHKZ44o`0000KoVgV/00?o
0000ok28Zon`R:/06?n`R:/00ol0003o`YN[ol:GZ`0>ol:GZ`Oo00000_o2T:400ol0003oeZ:QomJR
X@0DomJRX@;o00001_o[^Z000ol0003okkB@onndT007onndT004o`000?oocW[oolijo`0000Coo;mJ
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003ooooooooo
o`15ooooo`05o`000?l002_o0000oad3Lol000002_lb7XT00ol0003oNEVQogUIX@0CogUIX@03o`00
0?nHKZ7oV6jQ00OoV6jQ1Ol0000:oi]i[003o`000?n`R:_o/8R[01So/8R[00?o0000ol:GZoo2Uj/0
5Oo2Uj/4o`0001GoeZ:Q0_l00007on^jX0;o00001oo_]9001?l0003oolijooo>N_l00004ooboFP03
o`000?oooooooooo02oooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0
AOooool01?l0003o000[o`000?l0000;oc8NR@03o`000?miFJ7oNEVQ01?oNEVQ00?o0000oiQ^XOnH
KZ400onHKZ44o`0000ooVgV/00?o0000ok28Zon`R:/06?n`R:/00ol0003o`YN[ol:GZ`0Gol:GZ`03
o`000?oCZ:co000000;o00004_oFXZ42o`0000WojkZP00?o0000onndT?o_]9001?o_]9001Ol0003o
olijooo>N_oocW[o000000?oo;mJ00?o0000ooooooooool0;oooool00ol0003oooooooooo`0>oooo
o`007?ooool00ol0003oooooooooo`15ooooo`03o`000?l002_o000000_o<Qj90_l0000EogUIX@03
o`000?nHKZ7o000000?o00004onKNJ`00ol0003o/8R[ok28Z`0Hok28Z`03o`000?o2Uj_o`YN[01Oo
`YN[00?o0000om>X[?oCZ:`00_oCZ:`3o`0000goeZ:Q0ol0000;on^jX003o`000?o_]93okkB@00?o
kkB@00Go0000ooo>N_oocW[oolijo`000003ooboFP03o`000?oooooooooo02oooooo00?o0000oooo
ooooool03_ooool001cooooo00?o0000ooooooooool0AOooool00ol0003o000[o`00000:oc8NR@04
o`000?m5>9goACRMo`0001?oNEVQ0ol0000Goi]i[003o`000?n`R:_o/8R[01So/8R[00?o0000ol:G
Zoo2Uj/05oo2Uj/00ol0003odjR/om>X[005om>X[0?o00001ooFXZ43o`0000;oeZ:Q00?o0000on^j
X?o[^Z002_o[^Z000ol0003okkB@onndT002onndT003o`000?oocW[oolij00;oolij00Co0000oobo
F_ol_e[o0000<_ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0004Kooooo00?o0000o`00
:ol000002Olb7XT01Ol0003oACRModDhWOm5>9go000001;oNEVQ00?o0000oh5X[Ol000006?nKNJ`0
0ol0003o/8R[ok28Z`0Hok28Z`03o`000?o2Uj_o`YN[01Ko`YN[00?o0000om>X[?oCZ:`02OoCZ:`2
o`0000;oeZ:Q0ol00005omJRX@;o00003?o[^Z001Ol0003okkB@onndT?o_]93o000000Coolij00Co
0000ooboF_ol_e[o0000<_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003ooooooooo
o`16ooooo`03o`000?l002_o000000So<Qj900?o0000odDhWOm5>9d00_m5>9d00ol0003oNEVQogUI
X@0>ogUIX@;o00000_n1J:d00ol0003oVgV/oi]i[00Foi]i[003o`000?n`R:_o/8R[01Oo/8R[00?o
0000ol:GZoo2Uj/05oo2Uj/00ol0003odjR/om>X[00:om>X[0Co00001ooFXZ400ol0003ojkZPo`00
000<on^jX003o`000?o_]93o000000Koolij00?o0000ooboF_l00000<_ooool00ol0003ooooooooo
o`0=ooooo`006oooool00ol0003oooooooooo`16ooooo`04o`000?l002_o001Jo`0000Oo<Qj900?o
0000odDhWOm5>9d00om5>9d00ol0003oNEVQogUIX@0;ogUIX@;o00001On1J:d00ol0003oVgV/oi]i
[00Foi]i[003o`000?n`R:_o/8R[01Ko/8R[00?o0000ol:GZoo2Uj/05oo2Uj/00ol0003odjR/om>X
[006om>X[0Co00001?oCZ:`3o`0000CoeZ:Q00Co0000on^jX?o[^Z3o00003?o[^Z02o`0000Koolij
00?o0000ooboF_l00000<_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003ooooooooo
o`16ooooo`;o000000?o001Jo`000?lb7XT01Olb7XT00ol0003oACRModDhW@04odDhW@03o`000?mi
FJ7oNEVQ00[oNEVQ00?o0000oh5X[On1J:d01On1J:d00ol0003oVgV/oi]i[00Foi]i[003o`000?n`
R:_o/8R[01Ko/8R[00?o0000ol:GZoo2Uj/05oo2Uj/00ol0003odjR/om>X[003om>X[0?o00002ooC
Z:`4o`0000CojkZP00?o0000on^jX?o[^Z002_o[^Z000ol0003oolijooo>NP04ooo>NP03o`000?ol
_e[o000003;ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0A_ooool2
o`000003o`00F_l0003o<Qj900Co<Qj900?o0000odDhWOm5>9d01Om5>9d00ol0003oNEVQogUIX@08
ogUIX@;o00002?n1J:d00ol0003oVgV/oi]i[00Foi]i[003o`000?n`R:_o/8R[01Ko/8R[00?o0000
ol:GZoo2Uj/05oo2Uj/00ol0003odjR/om>X[003o`00017odjR/0_l00003on^jX003o`000?o[^Z3o
jkZP00[ojkZP00?o0000ooo>N_oocWX01OoocWX2o`0003;ooooo00?o0000ooooooooool03Oooool0
01_ooooo00?o0000ooooooooool0A_ooool2o`000003o`00F_l0003o<Qj900?o<Qj900?o0000odDh
WOm5>9d01_m5>9d00ol0003oNEVQogUIX@06ogUIX@;o00002_n1J:d00ol0003oVgV/oi]i[00Foi]i
[003o`000?n`R:_o/8R[01Ko/8R[00?o0000ol:GZoo2Uj/05_o2Uj/4o`0001CodjR/00?o0000onJo
[_l000000oo[^Z000ol0003ojkZPon^jX009on^jX0;o00001_oocWX2o`0003;ooooo00?o0000oooo
ooooool03Oooool001_ooooo00?o0000ooooooooool0A_ooool2o`000003o`00F_l0003o<Qj900?o
<Qj900?o0000odDhWOm5>9d01om5>9d00ol0003oNEVQogUIX@04ogUIX@03o`000?n1J:goPFR]00_o
PFR]00?o0000oi]i[?nKNJ`05OnKNJ`00ol0003o/8R[ok28Z`0Fok28Z`03o`000?o2Uj_o`YN[01?o
`YN[1?l0000Fom>X[005o`000?oV_jkoi[n^onJo[_l000000oo[^Z000ol0003ojkZPon^jX007on^j
X003o`000?onf9Ko000000Ooolij00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=oooo
o`006oooool2o`0004Oooooo0_l000000ol005[o0000oc8NR@02oc8NR@03o`000?m5>9goACRM00So
ACRM00?o0000ogUIXOmiFJ400_miFJ42o`0000koPFR]00?o0000oi]i[?nKNJ`05OnKNJ`00ol0003o
/8R[ok28Z`0Fok28Z`03o`000?o2Uj_o`YN[013o`YN[0ol00003ol:GZ`03o`000?oCZ:codjR/01Co
djR/00?o0000onJo[_oV_jh00_oV_jh01Ol0003ojkZPon^jX?o[^Z3o000000SojkZP00Co0000ookH
U_onf9Ko00001_oocWX00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo000Joooo
o`03o`000?oooooooooo04Oooooo00Oo000[o`000?l005[o001Jo`000?lb7XWo000000_oACRM00?o
0000ogUIXOmiFJ400_l0000@oh5X[@03o`000?nKNJcoVgV/01GoVgV/00?o0000ok28Zon`R:/04?n`
R:/:o`0000co`YN[0ol00006ol:GZ`03o`000?oCZ:codjR/01CodjR/00?o0000onJo[_oV_jh00ooV
_jh01Ol0003ojkZPon^jX?o[^Z3o000000OojkZP00Co0000ookHU_onf9Ko00001_oocWX00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00cooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0Aoooool01?l0
02_o0000o`00F_l005X2o`0000goACRM0_l0000Boh5X[@03o`000?nKNJcoVgV/01GoVgV/00?o0000
ok28Zon`R:/00on`R:/=o`0000Ko/92e00Co0000ol2N]_o0W[Ko`9jf1_l00003ol:GZ`?o00002Oo2
Uj/00ol0003odjR/om>X[00Com>X[003o`000?oV_jkoi[n^00Goi[n^00Go0000on^jX?o[^Z3ojkZP
o`000005on^jX003o`000?onf9Koo]RF00;oo]RF00?o0000ooo>N_oocWX00ooocWX00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00cooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04Oooooo00Go0000o`00F_l005[o
001Jo`00000>odDhW@03o`000?n1J:goPFR]01;oPFR]00?o0000oi]i[?nKNJ`04_nKNJ`8o`0001?o
/92e00?o0000ol2N]_o0W[H01_o0W[H7o`0000So`YN[00?o0000om>X[?oCZ:`05?oCZ:`00ol0003o
i[n^onJo[P06onJo[P;o000000?ojkZPo`000?o[^Z001?o[^Z000ol0003oo]RFookHUP02ookHUP03
o`000?oocW[oolij00;oolij00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<ooooo`00
0oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Aoooool01Ol0003o001Jo`00F_l005[o000000koACRM00?o0000oh5X[On1J:d04_n1J:d00ol0003o
VgV/oi]i[00=oi]i[0Go00000_nNQ;L00ol0003o/92eok2@]@0Fok2@]@03o`000?o0W[Ko`9jf00?o
`9jf0ol00007ol2N]PKo00000_o2Uj/00ol0003odjR/om>X[00Dom>X[003o`000?oV_jkoi[n^00So
i[n^00?o0000on^jX?l000001?o[^Z000ol0003oo]RFookHUP03ookHUP05o`000?oocW[oolijooo>
N_l00000=?ooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0=ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0Aoooool01Ol0003o001Jo`00F_l005[o0000
00goACRM00?o0000oeI@[ol000004on1J:d00ol0003oVgV/oi]i[009oi]i[0Co00001onNQ;L00ol0
003o/92eok2@]@0Fok2@]@03o`000?o0W[Ko`9jf00?o00004?o0W[H4o`0001CodjR/00?o0000onJo
[_oV_jh02_oV_jh00ol0003ojkZPo`000002on^jX003o`000?onf9Koo]RF00Coo]RF00Go0000ooo>
N_oocW[oolijo`00000dooooo`03o`000?oooooooooo00cooooo0003ooooo`03o`000?oooooooooo
00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo04Oooooo00Ko0000
o`00F_l005[o001Jo`00Q?l0000;odDhW@04o`000?mFD:ooEU2_o`0001?oPFR]00?o0000oi]i[?nK
NJ`01OnKNJ`4o`0000_oWXBg00?o0000ok2@]On`T;D05_n`T;D3o`0001Go`9jf00?o0000om2_^?l0
00000_l0000Aom>X[003o`000?oV_jkoi[n^00_oi[n^00Go0000on^jX?l0003ojkZPo`000006ookH
UP05o`000?oocW[oolijooo>N_l00000=?ooool00ol0003oooooooooo`0<ooooo`000oooool00ol@
413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0B?ooool01_l0
003o001Jo`00F_l005[o0024o`0000[oACRM00Go0000oeI@[omFD:ooEU2_o`00000Doh5X[@03o`00
0?nKNJco000000Co00004?nNQ;L00ol0003o/92eok2@]@0Aok2@]@Go00005oo0W[H00ol0003od:nh
om2_^002om2_^0?o00003_oCZ:`00ol0003oi[n^onJo[P0<onJo[P04o`000?o[^Z3o0000o`0000Oo
o]RF00Co0000ooo>N_oocW[o0000=Oooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonH
V9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`;o0000BOooool01_l0003o001Jo`00F_l0003o
0024o`0000WoACRM00?o0000oeI@[omFD:l00omFD:l00ol0003oPFR]oh5X[@0@oh5X[@?o00005OnN
Q;L00ol0003o/92eok2@]@0>ok2@]@?o00001?n`T;D00ol0003o`9jfol2N]P0Dol2N]P03o`000?o@
[kSod:nh00Kod:nh0ol0000:om>X[003o`000?oV_jkoi[n^00koi[n^0_l00008ookHUP04o`000?oo
cW[oolijo`0003Gooooo00?o0000ooooooooool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo
1?l00005ooooo`03o`000?oooooooooo04Sooooo00Co0000o`00F_l005[o00000_l008@00ol0003o
ACRModDhW@05odDhW@03o`000?mFD:ooEU2_00CoEU2_00?o0000oh5X[On1J:d03_n1J:d2o`000003
ohQg^_l0003oWXBg01GoWXBg00?o0000ok2@]On`T;D02on`T;D3o`0000Oo/92e00?o0000ol2N]_o0
W[H05?o0W[H00ol0003od:nhom2_^009om2_^0?o00001ooCZ:`00ol0003oi[n^onJo[P0?onJo[P;o
00002?onf9H2o`0003Kooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
BOooool00ol0003o001Jo`000002o`00Q003o`000?m5>9goACRM00CoACRM00?o0000oeI@[omFD:l0
1OmFD:l00ol0003oPFR]oh5X[@0<oh5X[@;o00001?n8MkX00ol0003oWXBgoij4]`0Coij4]`03o`00
0?n`T;Go/92e00So/92e0ol0000:ok2@]@03o`000?o0W[Ko`9jf01Co`9jf00?o0000om2_^?o@[kP0
3?o@[kP3o`0000CodjR/00?o0000onJo[_oV_jh03ooV_jh00ol0003oo]RFo`000007ookHUP;o0000
=_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`19ooooo`03o`000?l0
05[o000000;o002400?o0000odDhWOm5>9d01?m5>9d00ol0003oEU2_oeI@[`06oeI@[`03o`000?n1
J:goPFR]00WoPFR]0_l00006ohQg^P03o`000?nNQ;OoWXBg01?oWXBg00?o0000ok2@]On`T;D01?n`
T;D4o`0000co/92e00?o0000ol2N]_o0W[H05Oo0W[H00ol0003od:nhom2_^00?om2_^0Co00004OoV
_jh01Ol0003on=f]o`000?onf9Ko000000Ooo]RF00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0;ooooo`006Oooool00ol0003oooooooooo`19ooooo`03o`000?l005[o000000?o002400?o
0000odDhWOm5>9d00_m5>9d00ol0003oEU2_oeI@[`07oeI@[`03o`000?n1J:goPFR]00OoPFR]0_l0
0008ohQg^P03o`000?nNQ;OoWXBg01CoWXBg00?o0000ok2@]On`T;D00ol0000@ok2@]@03o`000?o0
W[Ko`9jf01Co`9jf00?o0000om2_^?o@[kP04oo@[kP2o`00013oi[n^00?o0000ooSM[Ol000000_on
f9H00ol0003oo]RFookHUP04ookHUP03o`000?oooooooooo03Cooooo00?o0000ooooooooool02ooo
ool001Sooooo00?o0000ooooooooool0B_ooool00ol0003o001Jo`000003o`00Q005o`000?m5>9go
ACRModDhWOl000002_mFD:l00ol0003oPFR]oh5X[@06oh5X[@03o`000?n8Mk[oR7Nj00WoR7Nj00?o
0000oij4]onNQ;L04onNQ;L3o`0001?o/92e00?o0000ol2N]_o0W[H05?o0W[H00ol0003od:nhom2_
^00Com2_^003o`000?oP`kco000000koi[n^00Go0000ooSM[OohgJgon=f]o`000002ookHUP03o`00
0?onf9Koo]RF00;oo]RF0_l0000fooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`000?oo
oooooooo04[ooooo00?o0000o`00F_l000000ol008@01?l0003oACRModDhWOl0000<oeI@[`03o`00
0?n1J:goPFR]00?oPFR]0_l0000<ohQg^P03o`000?nNQ;OoWXBg013oWXBg1?l0000Eok2@]@03o`00
0?o0W[Ko`9jf01Co`9jf00?o0000om2_^?o@[kP04_o@[kP01Ol0003oh<>lon33_?oP`kco000000go
i[n^00Go0000ooSM[OohgJgon=f]o`000002ookHUP03o`000?onf9Koo]RF00;oo]RF00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`1:ooooo`;o
00001Ol008@2o`0000goEU2_00Co0000oh5X[On1J:goPFR]0_l0000>ohQg^P03o`000?nNQ;OoWXBg
00coWXBg1?l00003oij4]`03o`000?n`T;Go/92e01?o/92e00?o0000ol2N]_o0W[H05?o0W[H00ol0
003od:nhom2_^00Bom2_^003o`000?oP`kcoh<>l00;oh<>l00?o0000onJo[_oV_jh02_oV_jh00ol0
003on=f]ooSM[@02ooSM[@04o`000?onf9Koo]RFo`0000?oo]RF00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0:ooooo`006?ooool2o`0004cooooo00?o0000o`00Q?l008@00ol008@00ol0
003oEU2_oeI@[`0<oeI@[`04o`000?n1J:go0000o`00017oR7Nj00?o0000oij4]onNQ;L02?nNQ;L3
o`0000OoWXBg00?o0000ok2@]On`T;D04on`T;D00ol0003o`9jfol2N]P0Dol2N]P03o`000?o@[kSo
d:nh017od:nh00?o0000on33_?oP`k`01?oP`k`00ol0003oi[n^onJo[P08onJo[P03o`000?ohgJgo
n=f]00?on=f]00Ko0000ookHU_onf9Koo]RFo`000?onf9H2o`0003Sooooo00?o0000ooooooooool0
2_ooool001Sooooo00?o0000ooooooooool0Boooool00ol0003o0024o`00Q003o`00Q003o`000?mF
D:ooEU2_00goEU2_00?o0000ohQg^_n8MkX04On8MkX00ol0003oWXBgoij4]`05oij4]`?o00002_nN
Q;L00ol0003o/92eok2@]@0Cok2@]@03o`000?o0W[Ko`9jf01?o`9jf00?o0000om2_^?o@[kP04_o@
[kP00ol0003oh<>lon33_005on33_0;o00002?oV_jh00ol0003on=f]ooSM[@04ooSM[@04o`000?on
f9Koo]RFookHUP?o0000>?ooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?l008Co002400?o002400?o12BVo`000?mFD:l03OmFD:l00ol0003oR7NjohQg
^P0BohQg^P04o`000?nNQ;OoWXBgoij4]`?o00003_nNQ;L00ol0003o/92eok2@]@0Bok2@]@03o`00
0?o0W[Ko`9jf01?o`9jf00?o0000om2_^?o@[kP04_o@[kP00ol0003oh<>lon33_007on33_003o`00
0?oV_jkoi[n^00Coi[n^00?o0000ooSM[OohgJd01OohgJd00ol0003oo]RFookHUP02ookHUP;o0000
>?ooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1<ooooo`03o`000?l0
08Co002400?o002400?o12BVo`000?mFD:l03?mFD:l00ol0003oIVJno`00000CohQg^PCo00004OnN
Q;L00ol0003o/92eok2@]@08ok2@]@oo00004Oo0W[H00ol0003od:nhom2_^00Aom2_^003o`000?oP
`kcoh<>l00Woh<>l00?o0000onJo[_oV_jh00ooV_jh00ol0003on=f]ooSM[@06ooSM[@03o`000?on
f9Koo]RF00;o0000>Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1=
ooooo`05o`000?l008Co0024o`00Q?l000000_l49:H00ol0003oEU2_oeI@[`09oeI@[`04o`000?mV
I[koIVJno`00013oR7Nj1?l0000Boij4]`go00002_naV/000ol0003o_ZK1okjV`@02okjV`@Oo0000
2_o0W[H00ol0003od:nhom2_^00Aom2_^003o`000?oP`kcoh<>l00[oh<>l00Go0000onJo[_oV_jko
i[n^o`000009ooSM[@03o`000?onf9Koo]RF00?o0000>?ooool00ol0003oooooooooo`0:ooooo`00
5oooool00ol0003oooooooooo`1=ooooo`05o`000?l008Co0024o`00Q?l000000_l49:H00ol0003o
EU2_oeI@[`08oeI@[`03o`000?mVI[koIVJn00;oIVJn00?o0000ohQg^_n8MkX02_n8MkX3o`0000Co
R7Nj00?o0000oij4]onNQ;L02_nNQ;L5o`0000;oXI3200?o0000ok6J`?naV/004_naV/000ol0003o
_ZK1okjV`@09okjV`@Oo00000_o0W[H00ol0003od:nhom2_^00Aom2_^003o`000?oP`kcoh<>l00co
h<>l00Co0000onJo[_oV_jko00002_ohgJd01_l0003oo]RFo`000?l0003oooooo`0003Sooooo00?o
0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0COooool01Ol0003o0024o`00Q?l0
08Co000000?o12BV00?o0000oeI@[omFD:l01_mFD:l00ol0003oIVJnofIV_P03ofIV_P03o`000?n8
Mk[oR7Nj00OoR7Nj0ol00007ohQg^P03o`000?nNQ;OoWXBg00GoWXBg1Ol00007oj6@`P03o`000?na
V/3o/I[001;o/I[000?o0000okjV`OnnY/404?nnY/44o`0001;od:nh00?o0000on33_?oP`k`03OoP
`k`00ol0003oi[n^o`00000:ooSM[@;o000000Goe]ELo`000?ooooooooooo`00000gooooo`03o`00
0?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo04kooooo00Co0000o`00Q?l008Co0000
0ol49:H00ol0003oEU2_oeI@[`05oeI@[`03o`000?mVI[koIVJn00GoIVJn00?o0000ohQg^_n8MkX0
0_n8MkX4o`0000[oR7Nj00?o0000oij4]onNQ;L01Ol0000<oj6@`P03o`000?naV/3o/I[001;o/I[0
00?o0000okjV`OnnY/404_nnY/400ol0003obkC4o`000002o`0000kod:nh00?o0000on33_?oP`k`0
3ooP`k`00ol0003on=f]ooSM[@0:ooSM[@03o`000?oFeEco000000?ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1>ooooo`04o`000?l0
08Co0024o`0000?o12BV00?o0000oeI@[omFD:l01OmFD:l00ol0003oIVJnofIV_P05ofIV_P03o`00
0?n8Mk[o000000;o00003_n8MkX3o`0001;oXI3200?o0000ok6J`?naV/004OnaV/000ol0003o_ZK1
okjV`@0AokjV`@03o`000?o;]<CobkC400?obkC40ol0000;om2_^003o`000?oP`kcoh<>l00ooh<>l
00?o0000ooSM[OohgJd02_ohgJd2o`0000Cooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`09ooooo`005oooool2o`0004oooooo00Co0000o`00Q?l008Co00001?l49:H00ol0003oEU2_
oeI@[`03oeI@[`03o`000?mVI[koIVJn00GoIVJn0ol0000?ohQg^P;o000000?oSXK6o`000?nQT<80
4_nQT<800ol0003o/I[0ok6J`00Aok6J`003o`000?nnY/7o_ZK1017o_ZK100?o0000ol^da?o;]<@0
1_o;]<@3o`0000Sod:nh00?o0000on33_?oP`k`03_oP`k`00ol0003ok]o1o`00000:ooSM[@?o0000
1Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oo
oooooooo053ooooo00?o0000o`00Q?l000001?l49:H00ol0003oEU2_oeI@[`02oeI@[`03o`000?mV
I[koIVJn00?oIVJn0ol00003ofIV_P03o`000?n8Mk[oR7Nj00[oR7Nj0_l00004ohj6aP03o`000?nQ
T<;oXI32013oXI3200?o0000ok6J`?naV/004OnaV/000ol0003o_ZK1okjV`@0AokjV`@03o`000?o;
]<CobkC400WobkC40ol00004om2_^003o`000?oP`kcoh<>l00ooh<>l00?o0000onkO`Ol000002_oh
gJd3o`0000Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`09ooooo`005_ooool0
0ol0003oooooooooo`1@ooooo`;o00001_l49:H01?l0003oEU2_oeI@[ol00002ofIV_PCo00001_mV
I[h00ol0003oR7NjohQg^P08ohQg^P;o00001_n>Q/H00ol0003oXI32oj6@`P0@oj6@`P03o`000?na
V/3o/I[0017o/I[000?o0000okjV`OnnY/404?nnY/400ol0003obkC4ol^da00=ol^da0?o000000?o
d:nho`000?oP`k`03ooP`k`01Ol0003ok]o1onkO`Oo^gl7o000000Son=f]0_l000000ooFeEco0000
ooooo`06ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool001Kooooo00?o
0000ooooooooool0D?ooool2o`0000Ko12BV00?o0000oeI@[ol000000ol0000;ofIV_P03o`000?n8
Mk[oR7Nj00KoR7Nj00?o0000ohj6a_n>Q/H01on>Q/H00ol0003oXI32oj6@`P0?oj6@`P03o`000?na
V/3o/I[0013o/I[000?o0000okjV`OnnY/404OnnY/400ol0003obkC4ol^da00@ol^da0;o00003ooP
`k`00ol0003ok]o1onkO`@02onkO`@03o`000?ohgJgon=f]00Gon=f]00Co0000onS`T_l0003o0000
2Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oo
oooooooo057ooooo00?o0000o`@TY_l49:H01?l49:H3o`0000koIVJn00?o0000ohQg^_n8MkX01?n8
MkX2o`0000[oSXK600?o0000oj6@`_nQT<804?nQT<800ol0003o/I[0ok6J`00?ok6J`003o`000?nn
Y/7o_ZK1017o_ZK100?o0000ol^da?o;]<@04?o;]<@00ol0003of<O9o`00000>on33_003o`000?o^
gl7ok]o100?ok]o100?o0000ooSM[OohgJd01?ohgJd01?l0003oj?2Bo`000?l0000:ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool02?ooool001Kooooo00?o0000ooooooooool0DOoo
ool01?l0003o12BVo`@TY_l49:H3o`000003o`@TY_l0003oIVJn00ooIVJn00Co0000ohQg^_n8Mk[o
R7Nj0_l0000<ohj6aP03o`000?nQT<;oXI32013oXI3200?o0000ok6J`?naV/003onaV/000ol0003o
_ZK1okjV`@0@okjV`@03o`000?o;]<CobkC4013obkC400Go0000omS7bOoHalWof<O9o`00000<on33
_003o`000?o^gl7ok]o100Cok]o100?o0000ooSM[OohgJd00oohgJd00ol0003oj?2BonS`TP02o`00
00[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003o
ooooooooo`1Aooooo`Co00001?l49:H00ol[CL7o0000ofIV_P0>ofIV_P04o`000?n8Mk[o0000o`00
00ooSXK600?o0000oj6@`_nQT<803onQT<800ol0003o/I[0ok6J`00?ok6J`003o`000?nnY/7o_ZK1
013o_ZK100?o0000ol^da?o;]<@03oo;]<@00ol0003of<O9omS7b@03omS7b@;o00002_oP`k`00ol0
003ok]o1onkO`@05onkO`@03o`000?ohgJgon=f]00;on=f]00Co0000onS`T_oXl9;o00003?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
04oooooo0ol000000ooooooo0000o`@TYP05o`@TYP03o`000?l[CL7o000000ooIVJn00?o0000ohj6
a_n>Q/H03on>Q/H00ol0003oXI32oj6@`P0?oj6@`P03o`000?naV/3o/I[000oo/I[000?o0000okjV
`OnnY/403onnY/400ol0003obkC4ol^da00@ol^da003o`000?oHalWof<O900Gof<O900?o0000on33
_?oP`k`01_oP`k`00ol0003ok]o1onkO`@06onkO`@05o`000?ohgJgon=f]ooSM[Ol000000ooXl980
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool0
01Gooooo0ol0001<ooooo`?o00001?ooool00ol0003o12BVo`@TYP03o`@TYP04o`000?l[CL7o:dg1
o`0000ooIVJn00?o0000ohj6a_n>Q/H04?n>Q/H00ol0003oXI32oj6@`P0>oj6@`P03o`000?naV/3o
/I[000oo/I[000?o0000okjV`OnnY/403onnY/400ol0003obkC4ol^da00?ol^da003o`000?oHalWo
f<O900Oof<O900?o0000on33_?oP`k`01OoP`k`00ol0003ok]o1onkO`@07onkO`@03o`000?ohgJgo
000000Coj?2B00?o0000ooooooooool03?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo000Eooooo`03o`000?oooooooooo04Wooooo0ol00008ooooo`03o`000?l49:Ko12BV
00;o12BV00Go0000ob]=`Ol[CL7o:dg1o`00000=ofIV_P03o`000?mdO<go0000017oSXK600?o0000
oj6@`_nQT<803_nQT<800ol0003o/I[0ok6J`00?ok6J`003o`000?nnY/7o_ZK100oo_ZK100?o0000
ol^da?o;]<@03oo;]<@00ol0003of<O9omS7b@08omS7b@;o00001?oP`k`00ol0003ok]o1onkO`@08
onkO`@03o`000?ohgJgo000000?oj?2B0_l0000?ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool02?ooool001Gooooo00?o0000ooooooooool0AOooool4o`0000_ooooo00?o0000o`@T
Y_l49:H00_l49:H00ol0003o:dg1ob]=`@02ob]=`@03o`000?mVI[koIVJn00WoIVJn00Go0000ogAl
cOmdO<goM7c=o`00000Aohj6aP03o`000?nQT<;oXI3200koXI3200?o0000ok6J`?naV/003_naV/00
0ol0003o_ZK1okjV`@0>okjV`@03o`000?o;]<CobkC400oobkC400?o0000omS7bOoHalT02ooHalT0
1?l0003oh<>lon33_?l0000<onkO`@03o`000?oXl9;oj?2B00;oj?2B00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooo
oooo04;ooooo0ol0000@ooooo`05o`000?l49:Ko12BVo`@TY_l000001Ol[CL400ol0003oIVJnofIV
_P07ofIV_P03o`000?mdO<goM7c=00?oM7c=00?o0000ohj6a_n>Q/H03_n>Q/H00ol0003oXI32oj6@
`P0>oj6@`P03o`000?naV/3o/I[000Ko/I[03Ol0000<okjV`@03o`000?o;]<CobkC400kobkC400?o
0000omS7bOoHalT03OoHalT00ol0003oh<>lo`00000<onkO`@03o`000?oXl9;oj?2B00;oj?2B00?o
0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo000E
ooooo`03o`000?oooooooooo03oooooo0ol0000Cooooo`05o`00Iol0003o12BVo`@TY_l000001Ol[
CL400ol0003oIVJnofIV_P06ofIV_P03o`000?mdO<goM7c=00CoM7c=00?o0000ohj6a_n>Q/H03_n>
Q/H00ol0003oXI32oj6@`P0<oj6@`P_o00002?n`Y<d00ol0003o^jk=ok^^c@02ok^^c@So00001?nn
Y/400ol0003obkC4ol^da00>ol^da003o`000?oHalWof<O900kof<O900?o0000onkO`Oo^gl402_o^
gl42o`0000Coj?2B00?o0000ooooooooool04?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`03o`000?oooooooooo03gooooo0ol0000Fooooo`;o00000_l49:H0
0ol0003o:dg1ob]=`@04ob]=`@03o`000?mVI[koIVJn00CoIVJn00?o0000ogAlcOmdO<d01_mdO<d0
0ol0003oSXK6ohj6aP0>ohj6aP03o`000?nQT<;oXI3200KoXI321Ol00002oj>LcP03o`000?n`Y<go
/:C=00ko/:C=00?o0000ok^^cOnk[/d02_nk[/d5o`0000oobkC400?o0000omS7bOoHalT03ooHalT0
0ol0003ok]o1onkO`@09onkO`@03o`000?o[n[_o000000?oj?2B00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo
03Wooooo1?l0000Jooooo`03o`00Iol0003o000000So:dg100?o0000ofIV__mVI[h00_mVI[h00ol0
003oM7c=ogAlc@08ogAlc@03o`000?n>Q/KoSXK600goSXK600Co0000oj6@`_nQT<;oXI321Ol00007
oj>LcP03o`000?n`Y<go/:C=00ko/:C=00?o0000ok^^cOnk[/d03Onk[/d00ol0003oaK[@o`000002
o`0000cobkC400?o0000omS7bOoHalT03_oHalT00ol0003oh]kAo`000009onkO`@04o`000?o[n[_o
joZko`0000?oj?2B00?o0000ooooooooool04oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Kooooo0ol0000Nooooo`?o00002?l[CL40
1Ol0003oIVJnofIV__mVI[ko000000_oM7c=00?o0000ohj6a_n>Q/H03On>Q/H4o`0000goXic>00?o
0000ok2TcOn`Y<d03On`Y<d00ol0003o^jk=ok^^c@0<ok^^c@03o`000?o5^]3oaK[@00?oaK[@0ol0
0008ol^da003o`000?oHalWof<O900kof<O900Co0000on;NdOoRg]7o00002Oo^gl401?l0003ojoZk
on_j^ol00002onS`TP03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Rooooo`03o`00Iol0003o:dg100So:dg1
00?o0000ofIV__l000003OmdO<d00ol0003oSXK6ohj6aP0:ohj6aP;o000000?oU9KBo`000?nSW<h0
3_nSW<h00ol0003o/:C=ok2Tc@0=ok2Tc@03o`000?nk[/go^jk=00co^jk=00?o0000olFjd?o5^]00
1_o5^]03o`0000CobkC400?o0000omS7bOoHalT03_oHalT00ol0003oh]kAon;Nd@02on;Nd@03o`00
0?o^gl7ok]o100Gok]o100Go0000on_j^oo[n[_ojoZko`000002onS`TP03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0`ooooo`?o00009Oooool2o`0000[o:dg100?o0000ogAlcOmdO<d03OmdO<d00ol0003oSXK6
ohj6aP07ohj6aP;o00001?nDU]800ol0003oXic>oj>LcP0<oj>LcP03o`000?n`Y<go/:C=00go/:C=
00?o0000ok^^cOnk[/d03?nk[/d00ol0003oaK[@olFjd009olFjd0?o000000?obkC4o`000?oHalT0
3_oHalT00ol0003oh]kAon;Nd@03on;Nd@03o`000?o^gl7ok]o100Cok]o100Go0000on_j^oo[n[_o
joZko`000002onS`TP03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0
;?ooool4o`0002Wooooo0_l00009ob]=`@03oda_e?l0003oM7c=00koM7c=00?o0000ohj6a_n>Q/H0
1?n>Q/H2o`0000OoU9KB00?o0000oj>Lc_nSW<h02onSW<h00ol0003o/:C=ok2Tc@0=ok2Tc@03o`00
0?nk[/go^jk=00_o^jk=00?o0000olFjd?o5^]003Oo5^]02o`0000kof<O900?o0000on;NdOoRg]40
1OoRg]400ol0003ok]o1onkO`@02onkO`@03o`000?o[n[_ojoZk00;ojoZk00?o0000onS`T_l00000
6oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:_ooool3o`0002gooooo0ol00008ob]=`@03o`000?m<
KmCo000000koM7c=00?o0000ohj6a_n>Q/H00_n>Q/H2o`0000WoU9KB00?o0000oj>Lc_nSW<h03?nS
W<h00ol0003o/:C=ok2Tc@0<ok2Tc@03o`000?nk[/go^jk=00_o^jk=00?o0000olFjd?o5^]003Oo5
^]000ol0003oc/WFo`00000<omS7b@03o`000?oRg]7oh]kA00Koh]kA00?o0000onkO`Oo^gl400_o^
gl400ol0003ojoZkon_j^`02on_j^`03o`000?oXl9;o000001cooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Oooooo0ol0000aooooo`03o`000?l06ZOo000000Ko:dg100Go0000oda_e?m<KmCoC6oDo`00
000>ogAlc@04o`000?n>Q/Ko0000o`0000coU9KB00?o0000oj>Lc_nSW<h02onSW<h00ol0003o/:C=
ok2Tc@0;ok2Tc@03o`000?nk[/go^jk=00co^jk=00?o0000olFjd?o5^]003?o5^]001?l0003oc/WF
olk9e_o>bMH2o`0000[of<O900?o0000on;NdOoRg]401ooRg]401?l0003ok]o1onkO`Ol00005on_j
^`;o00007_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool3o`0003Gooooo00?o0000o`0JYol0
00001Ol[CL400ol0003oC6oDoda_e002oda_e003o`000?mdO<goM7c=00coM7c=00?o0000oiBFd_nD
U]803?nDU]800ol0003oXic>oj>LcP0;oj>LcP03o`000?n`Y<go/:C=00_o/:C=00?o0000ok^^cOnk
[/d02onk[/d00ol0003oaK[@olFjd00<olFjd003o`000?o>bMKoc/WF00Coc/WF00?o0000omS7bOoH
alT01_oHalT00ol0003oh]kAon;Nd@08on;Nd@03o`000?o^gl7o000000KojoZk0_l0000Nooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`Co0000>?ooool2o`000003o`0JYol0003o:dg100?o:dg1
00?o0000oda_e?m<Km@00om<Km@00ol0003oM7c=ogAlc@0;ogAlc@03o`000?nDU];oU9KB00goU9KB
00?o0000oj>Lc_nSW<h02_nSW<h00ol0003o/:C=ok2Tc@0;ok2Tc@03o`000?nk[/go^jk=00_o^jk=
00?o0000olFjd?o5^]002oo5^]000ol0003oc/WFolk9eP06olk9eP03o`000?oHalWof<O900Cof<O9
00?o0000on;NdOoRg]402_oRg]400ol0003ojoZkon_j^`05on_j^`03o`000?oooooooooo01kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01gooooo0ol0000mooooo`03o`000?l06ZOo000000Co:dg100?o
0000oda_e?m<Km@01?m<Km@00ol0003oM7c=ogAlc@09ogAlc@03o`000?n1TMWo000000ooU9KB00?o
0000oj>Lc_nSW<h02_nSW<h00ol0003o/:C=ok2Tc@0:ok2Tc@03o`000?nk[/go^jk=00[o^jk=00?o
0000olFjd?o5^]003?o5^]000ol0003oc/WFolk9eP07olk9eP;o00000ooHalT00ol0003oh]kAon;N
d@09on;Nd@03o`000?oRn=Ko000000OojoZk00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06_ooool3o`00043ooooo0_l000000ol06ZOo0000ob]=`@02ob]=`@03o`000?m<KmCo
C6oD00GoC6oD00?o0000ogAlcOmdO<d01omdO<d01Ol0003oPI7Ioh6AfOn1TMWo000000koU9KB00?o
0000oj>Lc_nSW<h02_nSW<h00ol0003o/:C=ok2Tc@0:ok2Tc@03o`000?nk[/go^jk=00[o^jk=00?o
0000olFjd?o5^]002oo5^]000ol0003oc/WFolk9eP0:olk9eP03o`000?oHalWo000000_oh]kA00Co
0000on;he_oRn=Ko00001_o[n[/00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool01_ooool000[ooooo00?oEEEEofIVI_l000001_ooool2o`0001Sooooo0ol0
0014ooooo`06o`000?l06ZOo01ZWo`000?l[CL7o00002Om<Km@00ol0003oM7c=ogAlc@05ogAlc@03
o`000?n1TMWoPI7I00?oPI7I00?o0000oiBFd_nDU]803?nDU]800ol0003oXic>oj>LcP09oj>LcP03
o`000?n`Y<go/:C=00[o/:C=00?o0000ok^^cOnk[/d02_nk[/d00ol0003oaK[@olFjd00:olFjd003
o`000?o>bMKoc/WF00coc/WF00?o0000on;NdOoRg]402OoRg]401Ol0003oh_SFon;he_oRn=Ko0000
00GojoZk00?o0000ooooooooool08oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Kooooo000Booooo`03o`000?oooooooooo01Cooooo1?l00018ooooo`03o`000?l06ZOo01ZW00;o
00002_m<Km@00ol0003oM7c=ogAlc@03ogAlc@03o`000?n1TMWoPI7I00GoPI7I00?o0000oiBFd_nD
U]802onDU]800ol0003oXic>oj>LcP09oj>LcP03o`000?n`Y<go/:C=00[o/:C=00?o0000ok^^cOnk
[/d02Onk[/d00ol0003oaK[@olFjd00;olFjd003o`000?o>bMKoc/WF00_oc/WF00?oe=_Mo`000?oR
g]402OoRg]400ol0003oh_SFon;heP02on;heP03o`000?o[n[_ojoZk00;ojoZk00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`00
0?oooooooooo017ooooo0ol0001<ooooo`04o`000?l06ZOo01ZWo`0JY`;o00002_m<Km@01Ol0003o
M7c=ogAlcOmdO<go000000WoPI7I00?o0000oiBFd_nDU]802onDU]800ol0003oXic>oj>LcP09oj>L
cP03o`000?n`Y<go/:C=00?o/:C=2_l00008ok^^c@03o`000?o5^]3oaK[@00[oaK[@00?o0000olk9
e_o>bMH02_o>bMH01Ol0003oe=_MomCKgOoDfmgo000000Soh]kA00?o0000on;he_oRn=H00ooRn=H0
1Ol0003ojoZkon_j^oo[n[_o000002Sooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000D?ooool00ol0003o01ZWo`0JY`02
o`UId`03o`000?m<KmCoC6oD00SoC6oD00?o0000ogAlcOl000002on1TMT00ol0003oU9KBoiBFdP0;
oiBFdP03o`000?nSW<koXic>00KoXic>2?l00006ojfaf`04o`000?ne^=_o]KSKokFhf`Go00000onk
[/d00ol0003oaK[@olFjd009olFjd003o`000?o>bMKoc/WF00[oc/WF00?o0000omCKgOoDfmd00_oD
fmd00ol0003oh]kAon;Nd@05on;Nd@03o`000?oRn=Koh_SF00?oh_SF00Go0000on_j^oo[n[_ojoZk
o`00000Zooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o
0000ooooooooool02oooool3o`0005?ooooo00Co0000o`0JYol06ZOo01ZW0_l9FM<00ol0003oC6oD
oda_e008oda_e0;o00003?n1TMT00ol0003oU9KBoiBFdP0:oiBFdP04o`000?nSW<koXic>oj>LcPGo
00000_nTZm`00ol0003o[K7Kojfaf`09ojfaf`03o`000?ne^=_o]KSK00Ko]KSK1Ol00009olFjd003
o`000?o>bMKoc/WF00Woc/WF0_l00006omCKg@03o`000?oRg]7oh]kA00?oh]kA00?o0000on;he_oR
n=H01?oRn=H00ol0003ojoZkon_j^`02o`0002_ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`07ooooo`Co0000Eoooool01?l0003o01ZW
o`0JYol00002o`UId`03o`000?m<KmCoC6oD00OoC6oD0_mXS>800ol0003oPI7Ioh6Af@0:oh6Af@03
o`000?nDU];oU9KB00WoU9KB1?l00007ojB[g003o`000?n]/M_o[K7K00Wo[K7K00?o0000okFhfone
^=/02?ne^=/00ol0003o_<3Mokc0g@03o`0000KoaK[@00?o0000olk9e_o>bMH02?o>bMH00ol0003o
e=_MomCKg@06omCKg@03o`000?oRg]7oh]kA00;oh]kA00?o0000on;he_oRn=H01OoRn=H01?l0003o
joZko`000?l0000]ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool001;o
oooo00?o0000ooooooooool01?ooool3o`0005cooooo00Co0000o`0JYol06ZOo00000_l9FM<00ol0
003oC6oDoda_e006oda_e003o`000?mXS>;oJ8cR00;o00002on1TMT00ol0003oU9KBoiBFdP06oiBF
dP;o000000?oVZOOo`000?nTZm`02OnTZm`00ol0003o[K7Kojfaf`07ojfaf`03o`000?ne^=_o]KSK
00So]KSK00?o0000okc0gOnl`=d01?nl`=d3o`0000;oaK[@00?o0000olk9e_o>bMH02?o>bMH00ol0
003oe=_MomCKg@08omCKg@04o`000?oRg]7oh]kAo`0000Soh_SF0ol0000_ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01Oooool0017ooooo00?o0000ooooooooool00_ooool3o`00
063ooooo00?o0000o`0JYol000000ol9FM<2o`0000GoC6oD00?o0000ofR<h_mXS>800omXS>800ol0
003oPI7Ioh6Af@09oh6Af@03o`000?nDU];oU9KB00;oU9KB0ol00004oiZWg`03o`000?nTZmcoY:_L
00OoY:_L00?o0000ojfafon]/M/01on]/M/00ol0003o]KSKokFhf`08okFhf`03o`000?nl`=go_<3M
00Oo_<3M0ol00008olk9eP;o00002ooDfmd00ol0003oh]kAo`000009on;heP;o0000<?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooo000000;o
0000I?ooool00ol0003o01ZWo`000004o`UId`03o`000?m<KmCoC6oD00;oC6oD00?o0000ofR<h_mX
S>801?mXS>800ol0003oPI7Ioh6Af@09oh6Af@04o`000?nDU];o0000o`0000SoVZOO00?o0000ojB[
g?nTZm`01_nTZm`00ol0003o[K7Kojfaf`07ojfaf`03o`000?ne^=_o]KSK00Oo]KSK00?o0000okc0
gOnl`=d02?nl`=d3ol7;hP03o`000?o>bMKoc/WF00Coc/WF00?o0000omCKgOoDfmd03?oDfmd00ol0
003oh_SFon;heP06on;heP03o`000?ngn/Go000003;ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`04ooooo`004Oooool2o`0006Sooooo0_l00005o`UId`05o`000?m<KmCoC6oDoda_
e?l000001omXS>82o`0000[oPI7I0_l0000:oiZWg`03o`000?nTZmcoY:_L00KoY:_L00?o0000ojfa
fon]/M/01_n]/M/00ol0003o]KSKokFhf`07okFhf`03o`000?nl`=go_<3M00Ko_<3M00?o0000ol7;
h_o1bn800oo1bn82o`0000?oc/WF00?o0000omCKgOoDfmd02ooDfmd00ol0003od^kWo`000007on;h
eP04o`000?ngn/Go0000o`0003?ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04
ooooo`004oooool00ol0003oooooooooo`1Vooooo`03o`0JYol0003o2EWC00Co2EWC00Co0000oda_
e?m<KmCo00002OmXS>800ol0003oPI7Ioh6Af@06oh6Af@04o`000?n>YNGoSZGUo`0000WoVZOO00?o
0000ojB[g?nTZm`01_nTZm`00ol0003o[K7Kojfaf`06ojfaf`03o`000?ne^=_o]KSK00Ko]KSK00?o
0000okc0gOnl`=d01_nl`=d00ol0003o`L_Rol7;hP06ol7;hP03o`000?o>bMKo000000coe=_M0_l0
0002om;^i`03o`000?oRn=Koh_SF00?oh_SF0_l000000ongn/Go0000o`00000eooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01?ooool001Cooooo0_l0001Wooooo`03o`000?l9FM?o
2EWC00Co2EWC00?oC6oDo`000?mXS>802_mXS>82o`0000GoPI7I00?o0000ohjUiOn>YND00_n>YND2
o`0000SoVZOO00?o0000ojB[g?nTZm`01OnTZm`00ol0003o[K7Kojfaf`06ojfaf`03o`000?ne^=_o
]KSK00Go]KSK00?o0000okc0gOnl`=d01_nl`=d00ol0003o`L_Rol7;hP08ol7;hP03o`000?oDfmgo
e=_M00[oe=_M00?o0000om;^iooBk^L00_oBk^L00ol0003oh_SFon;heP02on;heP03o`000?ngn/Go
]o[500;o0000=oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo000Foooo
o`03o`000?oooooo000006Gooooo0_l00005o`UId`;o00003?mXS>801Ol0003oPI7Ioh6AfOn1TMWo
000000OoSZGU00?o0000oiZWgonJYml01_nJYml00ol0003oY:_LojB[g005ojB[g003o`000?n]/M_o
[K7K00Go[K7K00?o0000okFhfone^=/01One^=/00ol0003o_<3Mokc0g@05okc0g@03o`000?o1bn;o
`L_R00So`L_R00?o`mKXo`000?oDfmd02OoDfmd2o`0000God^kW00Go0000on;he_oRn=Koh_SFo`00
0002okOja@;o0000>?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo000G
ooooo`;o0000Ioooool00ol0003o2EWCo`UId`02o`UId`04o`000?m4Qn[o0000o`0000_oJ8cR0_n1
TMT00ol0003oSZGUohjUi@07ohjUi@03o`000?nJYmooVZOO00KoVZOO00?o0000ojB[g?nTZm`01?nT
Zm`00ol0003o[K7Kojfaf`04ojfaf`03o`000?ne^=_o]KSK00Go]KSK00?o0000okc0gOnl`=d01Onl
`=d00ol0003o`L_Rol7;hP06ol7;hP;o00000oo3e^P00ol0003oe=_MomCKg@05omCKg@;o00001_oB
k^L00ol0003oh_SFon;heP02o`0000?o]o[500?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o0000Ioooool00ol0003o2EWCo`UId`02
o`UId`03o`000?m4Qn[oA8OZ00;o00002_mXS>82o`0000[oSZGU0_l00006oiZWg`03o`000?nTZmco
Y:_L00CoY:_L00?o0000ojfafon]/M/01?n]/M/00ol0003o]KSKokFhf`05okFhf`03o`000?nl`=go
_<3M00Co_<3M00?o0000ol7;h_o1bn801_o1bn800ol0003o`mKXol?Fj004ol?Fj003o`000?oDfmgo
e=_M00?oe=_M00?o0000om;^iooBk^L01_oBk^L00ol0003oh_SFo`000004okOja@03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_ooool00ol0
003oooooooooo`1Uooooo`;o00000_l9FM<00ol0003oA8OZodB7jP02odB7jP;o00002?mXS>801?l0
003oP:K/o`000?l0000:ohjUi@03o`000?nJYmooVZOO00CoVZOO00?o0000ojB[g?nTZm`01?nTZm`0
0ol0003o[K7Kojfaf`03ojfaf`03o`000?ne^=_o]KSK00Co]KSK00?o0000okc0gOnl`=d01?nl`=d0
0ol0003o`L_Rol7;hP05ol7;hP;o00001oo3e^P01?l0003oe=_MomCKgOoDfmd2o`0000Wod^kW0_l0
0004okOja@03o`000?oooooooooo03cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`006oooool2o`000003ooooool0003ooooo06?ooooo00Go03:Zo`000?l9FM?o2EWCo`00
0005odB7jP03o`000?mXS>;oJ8cR00GoJ8cR00Co0000oh2Vk?n0Y^coP:K/0_l00009ohjUi@;o0000
1OnJYml01?l0003oY:_LojB[g?nTZm`<o`0000?o]KSK00?o0000okc0gOnl`=d00onl`=d00ol0003o
`L_Rol7;hP05ol7;hP03o`000?o3e^So`mKX00So`mKX00?o0000omCKgOl000002ooBk^L00ol0003o
]o[5okOja@02okOja@03o`000?oooooooooo03kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`03ooooo`007Oooool2o`0006Gooooo0_l000000ol9FM?o0000odB7jP05odB7jP;o0000
1OmXS>800ol0003oP:K/oh2Vk003oh2Vk0;o00002On>YND00ol0003oVZOOoiZWg`02oiZWg`Co0000
0_nS_N`00ol0003oY[o[ojJoj`03ojJoj`04o`000?nZ`^_oZ/;[oj[2j`Ko00000_nl`=d00ol0003o
`L_Rol7;hP04ol7;hP;o00003?o3e^P00ol0003od^kWom;^i`07om;^i`;o000000?o__[Zo`000?ng
n/D00_ngn/D00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool001kooooo00?o0000ooooooooool0I?ooool01?l0003o03:Zo`UIdol00007odB7jP;o
00000_mXS>800ol0003oP:K/oh2Vk006oh2Vk0;o00002?n>YND01?l0003oVZOOo`000?l00003oijl
k@05o`000?nS_NcoXkg/oj>mk?l000001?nV_n/00ol0003oZ/;[oj[2j`03oj[2j`04o`000?n/a^co
[<K/ojc6k0;o00001_o1bn800ol0003o`mKXol?Fj00:ol?Fj003o`000?o0hO3o000000Ood^kW0_l0
0002okkjjP04o`000?ngn/Go0000o`0004Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`03ooooo`007oooool2o`0006Gooooo00?o0000o`0bZ_l000002Om4QnX00ol0003oJ8cRo`00
000:oh2Vk0;o00001on>YND2o`0000GoW[c]00Co0000oj>mk?nS_Nco00001?nV_n/00ol0003oZ/;[
oj[2j`02oj[2j`05o`000?n/a^co[<K/ojc6k?l000000_n]bNh01?l0003o`L_Rol7;h_o1bn82o`00
00So`mKX0ol00004ol3Ql003o`000?oBk^Ood^kW00?od^kW0_l00003okkjjP03o`000?ngn/Go0000
04Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`008Oooool00ol0003o
ooooooooo`1Sooooo`04o`000?l0<Z[o0000o`0000WoA8OZ0ol0000:oh2Vk0;o00001?n>YND00ol0
003oV[__oiZkk`02o`0000CoW[c]00Co0000oj>mk?nS_Nco00000onV_n/01Ol0003oZ/;[oj[2jonZ
`^_o000000;o[<K/0_l00004ojg9kP03o`000?o1bn;o000000Oo`mKX0ol00007ol3Ql004o`000?oB
k^Ood^kWom;^i`;o00001?nnn^X3o`0004Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`03ooooo`008_ooool3o`0006?ooooo0_l000001?l0<Z[o0000o`000?l00006odB7jP03o`00
0?m`Z??oL:Sc00?o00002On0Y^`2o`000003ohjUiOl0003oV[__00CoV[__0_l00003oijlk@03o`00
0?nS_Nco000000?oY[o[00Co0000oj[2jonZ`^_o00000_n/a^`00ol0003o[LW^ojg9kP04ojg9kP;o
00001Oo3e^P3o`0000Wo`>7`00?o0000om;^iooBk^L00_l00005okkjjP;o0000C?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Tooooo`03o`000?oooooooooo06?ooooo
00Co0000o`0bZ_l0003o5GoV0ol00004odB7jP03o`000?m`Z??oL:Sc00;oL:Sc0ol00008oh2Vk0?o
00001_nJ^nl2o`0000;oW[c]00Go0000oj>mk?l0003oY[o[o`000002oj[2j`04o`000?n/a^co0000
o`0000Co[LW^0ol00002ojg=l@03o`000?o3e^So000000;o00003?o0hO03o`0000Ko__[Z00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uoooo
o`;o0000I?ooool00ol0003o03:Zo`000003oaEoiP;o00000_m4QnX00ol0003oL:Scog2Xl`05og2X
l`?o00001On0Y^`00ol0003oU[cboiJllP04o`0000CoV[__0_l000001OnN_>go0000o`000?nV_n_o
000000;oZ/;[0_l00003ojg9kP?o00000on]cO44o`0000oo`>7`00?o0000okkjj_nnn^X01Onnn^X0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
02Oooooo00?o0000ooooooooool0Hoooool2o`0000Co5GoV0ol0000:og2Xl`?o000000?oP:K/o`00
0?nF_?801_nF_?85o`000003oiZkkol0003o000000?o000000CoZ/;[o`000?l0003o[LW^2Ol00003
oj_@l`03o`000?o0hO3o`>7`00Go`>7`1Ol00003okKYmP04o`000?nnn^[o__[ZokkjjP?o0000Dooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo000Xooooo`03o`000?oooooo
000006?ooooo0_l00006oaEoiPGo00002?m`Z?<;o`0000?oU[cb3Ol00009oj_@l`03o`000?o0hO3o
`>7`00Go00001onfjOH00ol0003o__[ZokkjjP04o`0005Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001Uoooo
o`03o`000?lEOnKo5GoV00Go5GoV00?o0000of2/nOmP[?T01ol00002og2Xl`03o`000?nB__GoT[ke
00OoT[ke7?l0000;okKYmP06o`000?nnn^[o0000o`000?n:kM_o0000F?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Hoooool3o`0000Go5GoV00?o0000of2/nOmP[?T01_mP[?T<o`0000?oSl7h1?l00000
0on?bO_o0000o`000007o`0000SoYm;f00?o0000okKYm_nfjOH02_nfjOH3o`0000;oR^gK00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Eoooo
o`Ko00001Oooool00ol0003oooooooooo`09ooooo`;o0000Hoooool00ol0003oooooo`1cc004o`00
00;o5GoV00?o0000of2/nOmP[?T02OmP[?T00ol0003oSl7hoho1n004oho1n0Co000000CoS/Gjo`00
0?n?bO_oSlWk0_l000001?nGd?co0000oicBnonLd_/2o`0000;oX]?i1Ol00002ojOBmP03o`000?nf
jOKo]^Wf00?o]^Wf1Ol00002okKYmP04o`000?n:kM_oR^gKoh[]f`;o0000Foooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool00000H?ooool00ol0003oooooooooo`02ooooo`;o07?<0_l000000olEOnKo0000of2/
n@0:of2/n@03o`000?n?`OSoSl7h00?o00000on>aOX2o`0000?oSlWk0_l00002oiO@o004o`000?nL
d__oW=;koicBn`;o00001OnRdoT8o`0000CoX^[j0_l00004oh[]f`03o`000?oooooooooo05cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`008?ooool00ol0003ooooooooo
o`0<ooooo`;o0000H?ooool00ol0003oooooooooo`04ooooo`03o`000?l0Llco07?<00co000000?o
H:cio`000?l000001?n>aOX2o`0000CoSlWk00Co0000oi;=o?nBcOco00000_nGd?`00ol0003oW=;k
oicBn`02oicBn`?o000000?oX]?io`000?nRj_X02_nRj_X01?l0003oR^gKoh[]fon:kM/3o`00063o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003ooooo
ooooo`0=ooooo`;o0000Goooool00ol0003oooooooooo`06ooooo`;o00000_l0Ll`2o`0000[oD[7j
0_l000000on>aO[o0000oho9n`04oho9n`05o`000?nBcOcoT/gloi;=o?l000000onGd?`00ol0003o
W=;koicBn`03oicBn`Oo00001OnRj_X6o`0006Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`01ooooo`008?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool02_ooool00ol0003o07?<o`1cc002o`0000[oD[7j1?l00003oho9n`05o`00
0?nBcOcoT/gloi;=o?l000001?nGd?`00ol0003oW=;ko`000002o`0000OoQ^?j2?l0001Xooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool001kooooo00?oEEEEofIVI_l00000
4_ooool2o`000003ooooool0003ooooo05Sooooo00?o0000ooooooooool03Oooool01?l0003o07?<
o`000?l00002oe:anPCo00001_m=^_P@o`0000SoQ^?j1Ol0001[ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00Oooool003Gooooo0_l0001Iooooo`03o`000?oooooooooo013ooooo
0ol0000:odfjn003o`000?mDaOKoE<Gf00CoE<Gf00?o0000ofWDmomYe?L01_mYe?L3o`0000;oQ^?j
1Ol0001_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003Kooooo0_l0
001Hooooo`03o`000?oooooooooo01Gooooo1Ol00002odfjn003o`000?mDaOKoE<Gf00KoE<Gf00?o
0000ofWDmomYe?L00omYe?L8o`0007Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`01ooooo`00>?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool06_oo
ool2o`000003oeC5m_l0003o000000co0000OOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo007ooooo000iooooo`04o`000?ooooooooooo`0005?ooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00>_ooool3o`0005?ooooo00?o0000
ooooooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00??ooool00ol0
003oooooooooo`1Aooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool02?ooool1o`00
007ooooo0Oooool003gooooo0_l0001Aooooo`03o`000?oooooooooo0:_ooooo00?o0000oooooooo
ool01oooool1o`00007ooooo0Oooool003oooooo00?o0000ooooool00000C_ooool00ol0003ooooo
ooooo`2/ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0010ooooo`;o0000C_oo
ool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0011
ooooo`;o0000COooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`7ooooo0013ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[_ooool00ol0
003oooooooooo`05ooooo`7o00000Oooool004Cooooo0_l000000ooooooo0000ooooo`17ooooo`03
o`000?oooooooooo0:oooooo00?o0000ooooooooool01?ooool1o`00007ooooo0016ooooo`;o0000
B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00<_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o
0000Aoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00
<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`00
04Kooooo00?o0000ooooooooool0/_ooool01Ol0003ooooooooooooooooo0000007ooooo000Zoooo
o`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ol00013
ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`2cooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo007o0000000booooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`;o0000@?ooool00ol0003o
ooooooooo`2eooooo`7o00000Oooool1o`000000<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool02_ooool2o`0003kooooo00?o0000ooooooooool0]_ooool2o`000000
<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o0000?Oooool00ol0003o
ooooooooo`2eooooo`?o0000001Cooooo`05o`000?ooooooooooooooool00000>?ooool00ol0003o
ooooooooo`2`ooooo`Go00000oooool005Cooooo00Co0000oooooooooooo0000>?ooool00ol0003o
ooooooooo`2/ooooo`Co00002?ooool005Gooooo0ol0000hooooo`03o`000?oooooooooo0:Sooooo
1?l0000<ooooo`00Eoooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:Cooooo1Ol0
000@ooooo`00F?ooool2o`0003Gooooo00?o0000ooooooooool0X?ooool4o`0001Gooooo001Joooo
o`03o`000?oooooo000003;ooooo00?o0000ooooooooool0W?ooool4o`0001Wooooo001Kooooo`;o
0000<_ooool00ol0003oooooooooo`2Gooooo`Go00007Oooool005gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`2Cooooo`Co00008_ooool005kooooo00Co0000oooooooooooo0000
;Oooool00ol0003oooooooooo`2>ooooo`Go00009_ooool005oooooo0ol0000]ooooo`03o`000?oo
oooooooo08[ooooo1?l0000[ooooo`00HOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo08Kooooo1?l0000_ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000[
ooooo`03o`000?oooooooooo087ooooo1Ol0000cooooo`00Doooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`1mooooo`Co0000>?ooool0
05?ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000:?ooool00ol0003oooooooooo`1i
ooooo`Co0000??ooool005?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0M?ooool5o`00043ooooo001Cooooo`05o`000?oooooooooo
ooooool000004?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo073ooooo1?l0
0015ooooo`00Doooool01Ol@413ooooooooooooooooo410@017ooooo0ol0000Sooooo`03o`000?oo
oooooooo06_ooooo1Ol00019ooooo`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0_l0
000Sooooo`03o`000?oooooooooo06Oooooo1?l0001>ooooo`00Doooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^01Cooooo0_l000000ooooooo0000ooooo`0Nooooo`03o`000?oooooooooo06?ooooo1?l0
001Booooo`00K_ooool2o`0001oooooo00?o0000ooooooooool0G_ooool5o`0005Kooooo001_oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F_ooool4o`0005_ooooo001`ooooo`;o
00007Oooool00ol0003oooooooooo`1Fooooo`Co0000Goooool007;ooooo00?o0000ooooool00000
6_ooool00ol0003oooooooooo`1Aooooo`Go0000Hoooool007?ooooo0_l0000Jooooo`03o`000?oo
oooooooo04gooooo1?l0001Xooooo`00MOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04Wooooo1?l0001/ooooo`00M_ooool2o`000003ooooool0003ooooo01Cooooo00?o0000oooo
ooooool0A?ooool5o`00073ooooo001hooooo`;o00005Oooool00ol0003oooooooooo`10ooooo`Co
0000MOooool007Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`Go0000
NOooool007[ooooo0_l000000ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0
001nooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00oooool2o`00017ooooo00?o0000ooooooooool0<oooool4o`0008;ooooo
001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
0oooool2o`0000oooooo00?o0000ooooooooool0;oooool5o`0008Kooooo001Sooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:oooool4o`0008_ooooo001Sooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`06ooooo`?o00002oooool00ol0003oooooooooo`0Wooooo`Co0000
Soooool006?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1Ol0002Cooooo`00
Hoooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03?ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo01kooooo1?l0002Hooooo`00Hoooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool3o`0000Oooooo00?o0000oooo
ooooool06Oooool5o`0009cooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000XOooool008Oo
oooo0_l00005ooooo`03o`000?oooooooooo017ooooo1?l0002Uooooo`00ROooool2o`0000?ooooo
00?o0000ooooooooool03?ooool5o`000:Wooooo002:ooooo`05o`000?ooooooooooooooool00000
2_ooool4o`000:kooooo002;ooooo`;o000000?oooooo`000?ooool01Oooool4o`000;;ooooo002=
ooooo`;o000000?oooooo`000?l000000ol0002fooooo`00S_ooool2o`000;_ooooo003oooooodco
oooo003oooooodcooooo0024ooooo`Co000000?o410@ooooooooool0`?ooool008Kooooo00?o0000
ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000oooooooo
ool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_oo
ool008Kooooo00?o0000ooooooooool0`_ooool008Cooooo00?oEEEEofIVI_l00000a?ooool00001
\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48711 .50892 m .48051 .55136 L .54179 .5544 L p .719 .594 .715 r
F P
0 g
s
.54179 .5544 m .53957 .51159 L .48711 .50892 L p .719 .594 .715 r
F P
0 g
s
.54354 .59592 m .54179 .5544 L .48051 .55136 L p .72 .57 .684 r
F P
0 g
s
.53957 .51159 m .54179 .5544 L .60172 .54527 L p .67 .556 .717 r
F P
0 g
s
.54179 .5544 m .54354 .59592 L .6103 .586 L p .665 .526 .685 r
F P
0 g
s
.6103 .586 m .60172 .54527 L .54179 .5544 L p .665 .526 .685 r
F P
0 g
s
.49514 .46633 m .48711 .50892 L .53957 .51159 L p .716 .619 .748 r
F P
0 g
s
.53957 .51159 m .53686 .4685 L .49514 .46633 L p .716 .619 .748 r
F P
0 g
s
.53686 .4685 m .53957 .51159 L .59083 .50358 L p .674 .587 .749 r
F P
0 g
s
.60172 .54527 m .59083 .50358 L .53957 .51159 L p .67 .556 .717 r
F P
0 g
s
.43821 .49578 m .42325 .53635 L .48051 .55136 L p .765 .638 .72 r
F P
0 g
s
.48051 .55136 m .48711 .50892 L .43821 .49578 L p .765 .638 .72 r
F P
0 g
s
.47532 .59261 m .48051 .55136 L .42325 .53635 L p .773 .618 .688 r
F P
0 g
s
.48051 .55136 m .47532 .59261 L .54354 .59592 L p .72 .57 .684 r
F P
0 g
s
.54485 .63557 m .54354 .59592 L .47532 .59261 L p .72 .546 .654 r
F P
0 g
s
.54354 .59592 m .54485 .63557 L .6167 .62516 L p .659 .498 .655 r
F P
0 g
s
.6167 .62516 m .6103 .586 L .54354 .59592 L p .659 .498 .655 r
F P
0 g
s
.45636 .45563 m .43821 .49578 L .48711 .50892 L p .755 .657 .753 r
F P
0 g
s
.48711 .50892 m .49514 .46633 L .45636 .45563 L p .755 .657 .753 r
F P
0 g
s
.42325 .53635 m .41147 .5763 L .47532 .59261 L p .773 .618 .688 r
F P
0 g
s
.47145 .63211 m .47532 .59261 L .41147 .5763 L p .778 .599 .657 r
F P
0 g
s
.47532 .59261 m .47145 .63211 L .54485 .63557 L p .72 .546 .654 r
F P
0 g
s
.50451 .42498 m .49514 .46633 L .53686 .4685 L p .711 .646 .783 r
F P
0 g
s
.53686 .4685 m .53369 .42653 L .50451 .42498 L p .711 .646 .783 r
F P
0 g
s
.53369 .42653 m .53686 .4685 L .57758 .46198 L p .677 .621 .785 r
F P
0 g
s
.59083 .50358 m .57758 .46198 L .53686 .4685 L p .674 .587 .749 r
F P
0 g
s
.59083 .50358 m .60172 .54527 L .65494 .5246 L p .615 .521 .725 r
F P
0 g
s
.60172 .54527 m .6103 .586 L .66976 .5635 L p .601 .484 .692 r
F P
0 g
s
.66976 .5635 m .65494 .5246 L .60172 .54527 L p .601 .484 .692 r
F P
0 g
s
.57758 .46198 m .59083 .50358 L .63616 .4855 L p .628 .56 .759 r
F P
0 g
s
.65494 .5246 m .63616 .4855 L .59083 .50358 L p .615 .521 .725 r
F P
0 g
s
.47748 .41734 m .45636 .45563 L .49514 .46633 L p .741 .677 .788 r
F P
0 g
s
.49514 .46633 m .50451 .42498 L .47748 .41734 L p .741 .677 .788 r
F P
0 g
s
.54575 .67319 m .54485 .63557 L .47145 .63211 L p .719 .523 .625 r
F P
0 g
s
.54485 .63557 m .54575 .67319 L .62115 .66251 L p .652 .47 .625 r
F P
0 g
s
.62115 .66251 m .6167 .62516 L .54485 .63557 L p .652 .47 .625 r
F P
0 g
s
.6103 .586 m .6167 .62516 L .68086 .60149 L p .588 .449 .66 r
F P
0 g
s
.68086 .60149 m .66976 .5635 L .6103 .586 L p .588 .449 .66 r
F P
0 g
s
.57758 .46198 m .56215 .42187 L .53369 .42653 L p .677 .621 .785 r
F P
0 g
s
.56215 .42187 m .57758 .46198 L .61343 .4473 L p .641 .601 .793 r
F P
0 g
s
.63616 .4855 m .61343 .4473 L .57758 .46198 L p .628 .56 .759 r
F P
0 g
s
.41147 .5763 m .40265 .61496 L .47145 .63211 L p .778 .599 .657 r
F P
0 g
s
.46876 .66963 m .47145 .63211 L .40265 .61496 L p .781 .579 .626 r
F P
0 g
s
.47145 .63211 m .46876 .66963 L .54575 .67319 L p .719 .523 .625 r
F P
0 g
s
.42433 .4373 m .39752 .47314 L .43821 .49578 L p .792 .703 .766 r
F P
0 g
s
.43821 .49578 m .45636 .45563 L .42433 .4373 L p .792 .703 .766 r
F P
0 g
s
.42325 .53635 m .43821 .49578 L .39752 .47314 L p .811 .691 .732 r
F P
0 g
s
.39752 .47314 m .37532 .51043 L .42325 .53635 L p .811 .691 .732 r
F P
0 g
s
.41147 .5763 m .42325 .53635 L .37532 .51043 L p .826 .677 .698 r
F P
0 g
s
.45533 .40431 m .42433 .4373 L .45636 .45563 L p .769 .714 .801 r
F P
0 g
s
.45636 .45563 m .47748 .41734 L .45533 .40431 L p .769 .714 .801 r
F P
0 g
s
.51501 .38654 m .50451 .42498 L .53369 .42653 L p .701 .676 .822 r
F P
0 g
s
.53369 .42653 m .53014 .38737 L .51501 .38654 L p .701 .676 .822 r
F P
0 g
s
.53014 .38737 m .53369 .42653 L .56215 .42187 L p .678 .659 .823 r
F P
0 g
s
.6167 .62516 m .62115 .66251 L .68859 .63823 L p .573 .414 .627 r
F P
0 g
s
.68859 .63823 m .68086 .60149 L .6167 .62516 L p .573 .414 .627 r
F P
0 g
s
.5463 .70884 m .54575 .67319 L .46876 .66963 L p .716 .5 .595 r
F P
0 g
s
.54575 .67319 m .5463 .70884 L .62385 .69811 L p .645 .443 .595 r
F P
0 g
s
.62385 .69811 m .62115 .66251 L .54575 .67319 L p .645 .443 .595 r
F P
0 g
s
.37532 .51043 m .35776 .54805 L .41147 .5763 L p .826 .677 .698 r
F P
0 g
s
.40265 .61496 m .41147 .5763 L .35776 .54805 L p .838 .661 .663 r
F P
0 g
s
.50105 .38251 m .47748 .41734 L .50451 .42498 L p .722 .697 .826 r
F P
0 g
s
.50451 .42498 m .51501 .38654 L .50105 .38251 L p .722 .697 .826 r
F P
0 g
s
.61343 .4473 m .63616 .4855 L .67109 .45874 L p .574 .537 .776 r
F P
0 g
s
.63616 .4855 m .65494 .5246 L .69628 .49388 L p .548 .489 .742 r
F P
0 g
s
.69628 .49388 m .67109 .45874 L .63616 .4855 L p .548 .489 .742 r
F P
0 g
s
.56215 .42187 m .54487 .3849 L .53014 .38737 L p .678 .659 .823 r
F P
0 g
s
.54487 .3849 m .56215 .42187 L .58705 .4114 L p .654 .647 .83 r
F P
0 g
s
.61343 .4473 m .58705 .4114 L .56215 .42187 L p .641 .601 .793 r
F P
0 g
s
.40265 .61496 m .39652 .65206 L .46876 .66963 L p .781 .579 .626 r
F P
0 g
s
.46713 .70527 m .46876 .66963 L .39652 .65206 L p .784 .558 .594 r
F P
0 g
s
.46876 .66963 m .46713 .70527 L .5463 .70884 L p .716 .5 .595 r
F P
0 g
s
.58705 .4114 m .61343 .4473 L .64077 .42569 L p .601 .587 .81 r
F P
0 g
s
.67109 .45874 m .64077 .42569 L .61343 .4473 L p .574 .537 .776 r
F P
0 g
s
.65494 .5246 m .66976 .5635 L .71626 .52995 L p .521 .441 .706 r
F P
0 g
s
.71626 .52995 m .69628 .49388 L .65494 .5246 L p .521 .441 .706 r
F P
0 g
s
.48972 .37566 m .45533 .40431 L .47748 .41734 L p .739 .723 .836 r
F P
0 g
s
.47748 .41734 m .50105 .38251 L .48972 .37566 L p .739 .723 .836 r
F P
0 g
s
.35776 .54805 m .34459 .5852 L .40265 .61496 L p .838 .661 .663 r
F P
0 g
s
.39652 .65206 m .40265 .61496 L .34459 .5852 L p .847 .644 .628 r
F P
0 g
s
.62115 .66251 m .62385 .69811 L .69327 .67368 L p .559 .378 .593 r
F P
0 g
s
.69327 .67368 m .68859 .63823 L .62115 .66251 L p .559 .378 .593 r
F P
0 g
s
.58705 .4114 m .55768 .37938 L .54487 .3849 L p .654 .647 .83 r
F P
0 g
s
.55768 .37938 m .58705 .4114 L .60582 .39609 L p .628 .64 .843 r
F P
0 g
s
.64077 .42569 m .60582 .39609 L .58705 .4114 L p .601 .587 .81 r
F P
0 g
s
.66976 .5635 m .68086 .60149 L .73127 .5661 L p .494 .392 .668 r
F P
0 g
s
.73127 .5661 m .71626 .52995 L .66976 .5635 L p .494 .392 .668 r
F P
0 g
s
.54651 .7427 m .5463 .70884 L .46713 .70527 L p .713 .475 .563 r
F P
0 g
s
.5463 .70884 m .54651 .7427 L .62488 .7321 L p .637 .413 .562 r
F P
0 g
s
.62488 .7321 m .62385 .69811 L .5463 .70884 L p .637 .413 .562 r
F P
0 g
s
.44043 .3871 m .40241 .41293 L .42433 .4373 L p .792 .758 .821 r
F P
0 g
s
.42433 .4373 m .45533 .40431 L .44043 .3871 L p .792 .758 .821 r
F P
0 g
s
.39752 .47314 m .42433 .4373 L .40241 .41293 L p .827 .76 .789 r
F P
0 g
s
.40241 .41293 m .36929 .44286 L .39752 .47314 L p .827 .76 .789 r
F P
0 g
s
.37532 .51043 m .39752 .47314 L .36929 .44286 L p .856 .758 .753 r
F P
0 g
s
.39652 .65206 m .39281 .68759 L .46713 .70527 L p .784 .558 .594 r
F P
0 g
s
.46651 .73917 m .46713 .70527 L .39281 .68759 L p .784 .535 .56 r
F P
0 g
s
.46713 .70527 m .46651 .73917 L .54651 .7427 L p .713 .475 .563 r
F P
0 g
s
.53014 .38737 m .52632 .35282 L .51501 .38654 L closepath p .685 .71 .867 r
F P
0 g
s
.54487 .3849 m .52632 .35282 L .53014 .38737 L closepath p .676 .703 .868 r
F P
0 g
s
.48224 .36669 m .44043 .3871 L .45533 .40431 L p .752 .751 .851 r
F P
0 g
s
.45533 .40431 m .48972 .37566 L .48224 .36669 L p .752 .751 .851 r
F P
0 g
s
.51501 .38654 m .52632 .35282 L .50105 .38251 L closepath p .693 .718 .869 r
F P
0 g
s
.36929 .44286 m .34168 .47558 L .37532 .51043 L p .856 .758 .753 r
F P
0 g
s
.35776 .54805 m .37532 .51043 L .34168 .47558 L p .881 .752 .715 r
F P
0 g
s
.55768 .37938 m .52632 .35282 L .54487 .3849 L closepath p .666 .699 .871 r
F P
0 g
s
.34459 .5852 m .33541 .6215 L .39652 .65206 L p .847 .644 .628 r
F P
0 g
s
.39281 .68759 m .39652 .65206 L .33541 .6215 L p .854 .625 .59 r
F P
0 g
s
.50105 .38251 m .52632 .35282 L .48972 .37566 L closepath p .698 .728 .873 r
F P
0 g
s
.68086 .60149 m .68859 .63823 L .74176 .60186 L p .466 .343 .628 r
F P
0 g
s
.74176 .60186 m .73127 .5661 L .68086 .60149 L p .466 .343 .628 r
F P
0 g
s
.60582 .39609 m .64077 .42569 L .65653 .39909 L p .556 .582 .835 r
F P
0 g
s
.64077 .42569 m .67109 .45874 L .69167 .42558 L p .509 .521 .804 r
F P
0 g
s
.69167 .42558 m .65653 .39909 L .64077 .42569 L p .509 .521 .804 r
F P
0 g
s
.56721 .37137 m .52632 .35282 L .55768 .37938 L closepath p .657 .698 .876 r
F P
0 g
s
.60582 .39609 m .56721 .37137 L .55768 .37938 L p .628 .64 .843 r
F P
0 g
s
.62385 .69811 m .62488 .7321 L .69507 .70795 L p .542 .34 .556 r
F P
0 g
s
.69507 .70795 m .69327 .67368 L .62385 .69811 L p .542 .34 .556 r
F P
0 g
s
.56721 .37137 m .60582 .39609 L .61637 .3774 L p .602 .641 .861 r
F P
0 g
s
.65653 .39909 m .61637 .3774 L .60582 .39609 L p .556 .582 .835 r
F P
0 g
s
.34168 .47558 m .31973 .50989 L .35776 .54805 L p .881 .752 .715 r
F P
0 g
s
.34459 .5852 m .35776 .54805 L .31973 .50989 L p .902 .742 .673 r
F P
0 g
s
.67109 .45874 m .69628 .49388 L .72107 .4556 L p .459 .456 .768 r
F P
0 g
s
.72107 .4556 m .69167 .42558 L .67109 .45874 L p .459 .456 .768 r
F P
0 g
s
.48972 .37566 m .52632 .35282 L .48224 .36669 L closepath p .702 .738 .879 r
F P
0 g
s
.54637 .77483 m .54651 .7427 L .46651 .73917 L p .708 .446 .526 r
F P
0 g
s
.54651 .7427 m .54637 .77483 L .6242 .76452 L p .626 .379 .524 r
F P
0 g
s
.6242 .76452 m .62488 .7321 L .54651 .7427 L p .626 .379 .524 r
F P
0 g
s
.57241 .36167 m .52632 .35282 L .56721 .37137 L closepath p .649 .699 .883 r
F P
0 g
s
.61637 .3774 m .57241 .36167 L .56721 .37137 L p .602 .641 .861 r
F P
0 g
s
.47946 .35653 m .43454 .36741 L .44043 .3871 L p .757 .78 .872 r
F P
0 g
s
.44043 .3871 m .48224 .36669 L .47946 .35653 L p .757 .78 .872 r
F P
0 g
s
.40241 .41293 m .44043 .3871 L .43454 .36741 L p .807 .807 .851 r
F P
0 g
s
.69628 .49388 m .71626 .52995 L .74452 .48793 L p .406 .388 .726 r
F P
0 g
s
.74452 .48793 m .72107 .4556 L .69628 .49388 L p .406 .388 .726 r
F P
0 g
s
.39281 .68759 m .39139 .7217 L .46651 .73917 L p .784 .535 .56 r
F P
0 g
s
.46692 .7714 m .46651 .73917 L .39139 .7217 L p .783 .508 .519 r
F P
0 g
s
.46651 .73917 m .46692 .7714 L .54637 .77483 L p .708 .446 .526 r
F P
0 g
s
.68859 .63823 m .69327 .67368 L .74811 .63707 L p .436 .291 .586 r
F P
0 g
s
.74811 .63707 m .74176 .60186 L .68859 .63823 L p .436 .291 .586 r
F P
0 g
s
.43454 .36741 m .39329 .38479 L .40241 .41293 L p .807 .807 .851 r
F P
0 g
s
.36929 .44286 m .40241 .41293 L .39329 .38479 L p .853 .828 .822 r
F P
0 g
s
.48224 .36669 m .52632 .35282 L .47946 .35653 L closepath p .702 .748 .887 r
F P
0 g
s
.33541 .6215 m .32984 .65685 L .39281 .68759 L p .854 .625 .59 r
F P
0 g
s
.39139 .7217 m .39281 .68759 L .32984 .65685 L p .86 .603 .549 r
F P
0 g
s
.31973 .50989 m .30319 .54489 L .34459 .5852 L p .902 .742 .673 r
F P
0 g
s
.33541 .6215 m .34459 .5852 L .30319 .54489 L p .92 .729 .628 r
F P
0 g
s
.57266 .35132 m .52632 .35282 L .57241 .36167 L closepath p .642 .704 .892 r
F P
0 g
s
.57241 .36167 m .61637 .3774 L .61733 .35723 L p .578 .65 .884 r
F P
0 g
s
.61733 .35723 m .57266 .35132 L .57241 .36167 L p .578 .65 .884 r
F P
0 g
s
.39329 .38479 m .35703 .40764 L .36929 .44286 L p .853 .828 .822 r
F P
0 g
s
.34168 .47558 m .36929 .44286 L .35703 .40764 L p .895 .843 .785 r
F P
0 g
s
.61637 .3774 m .65653 .39909 L .65855 .37012 L p .507 .586 .869 r
F P
0 g
s
.65855 .37012 m .61733 .35723 L .61637 .3774 L p .507 .586 .869 r
F P
0 g
s
.62488 .7321 m .6242 .76452 L .69388 .74106 L p .522 .295 .512 r
F P
0 g
s
.69388 .74106 m .69507 .70795 L .62488 .7321 L p .522 .295 .512 r
F P
0 g
s
.47946 .35653 m .52632 .35282 L .48175 .34626 L closepath p .698 .755 .896 r
F P
0 g
s
.56785 .34141 m .52632 .35282 L .57266 .35132 L closepath p .638 .712 .9 r
F P
0 g
s
.55843 .33308 m .52632 .35282 L .56785 .34141 L closepath p .638 .722 .908 r
F P
0 g
s
.54541 .32725 m .52632 .35282 L .55843 .33308 L closepath p .642 .733 .915 r
F P
0 g
s
.53023 .32463 m .52632 .35282 L .54541 .32725 L closepath p .649 .744 .919 r
F P
0 g
s
.51461 .32552 m .52632 .35282 L .53023 .32463 L closepath p .659 .753 .92 r
F P
0 g
s
.50031 .32981 m .52632 .35282 L .51461 .32552 L closepath p .671 .759 .917 r
F P
0 g
s
.48894 .337 m .52632 .35282 L .50031 .32981 L closepath p .682 .762 .912 r
F P
0 g
s
.48175 .34626 m .52632 .35282 L .48894 .337 L closepath p .692 .761 .904 r
F P
0 g
s
.71626 .52995 m .73127 .5661 L .76223 .52163 L p .349 .314 .678 r
F P
0 g
s
.76223 .52163 m .74452 .48793 L .71626 .52995 L p .349 .314 .678 r
F P
0 g
s
.43454 .36741 m .47946 .35653 L .48175 .34626 L p .752 .808 .897 r
F P
0 g
s
.65653 .39909 m .69167 .42558 L .69495 .38917 L p .425 .511 .843 r
F P
0 g
s
.69495 .38917 m .65855 .37012 L .65653 .39909 L p .425 .511 .843 r
F P
0 g
s
.57266 .35132 m .61733 .35723 L .60829 .33775 L p .558 .668 .911 r
F P
0 g
s
.60829 .33775 m .56785 .34141 L .57266 .35132 L p .558 .668 .911 r
F P
0 g
s
.69327 .67368 m .69507 .70795 L .75055 .67174 L p .403 .235 .537 r
F P
0 g
s
.75055 .67174 m .74811 .63707 L .69327 .67368 L p .403 .235 .537 r
F P
0 g
s
.54584 .80495 m .54637 .77483 L .46692 .7714 L p .699 .408 .479 r
F P
0 g
s
.54637 .77483 m .54584 .80495 L .62159 .79513 L p .611 .336 .476 r
F P
0 g
s
.62159 .79513 m .6242 .76452 L .54637 .77483 L p .611 .336 .476 r
F P
0 g
s
.48175 .34626 m .43857 .34731 L .43454 .36741 L p .752 .808 .897 r
F P
0 g
s
.39329 .38479 m .43454 .36741 L .43857 .34731 L p .805 .858 .889 r
F P
0 g
s
.35703 .40764 m .32659 .43477 L .34168 .47558 L p .895 .843 .785 r
F P
0 g
s
.31973 .50989 m .34168 .47558 L .32659 .43477 L p .933 .851 .738 r
F P
0 g
s
.30319 .54489 m .29163 .58003 L .33541 .6215 L p .92 .729 .628 r
F P
0 g
s
.32984 .65685 m .33541 .6215 L .29163 .58003 L p .934 .71 .577 r
F P
0 g
s
.32984 .65685 m .32771 .6913 L .39139 .7217 L p .86 .603 .549 r
F P
0 g
s
.39233 .75442 m .39139 .7217 L .32771 .6913 L p .863 .575 .499 r
F P
0 g
s
.39139 .7217 m .39233 .75442 L .46692 .7714 L p .783 .508 .519 r
F P
0 g
s
.43857 .34731 m .48175 .34626 L .48894 .337 L p .733 .829 .924 r
F P
0 g
s
.46849 .80168 m .46692 .7714 L .39233 .75442 L p .779 .472 .468 r
F P
0 g
s
.46692 .7714 m .46849 .80168 L .54584 .80495 L p .699 .408 .479 r
F P
0 g
s
.73127 .5661 m .74176 .60186 L .77463 .55605 L p .288 .235 .622 r
F P
0 g
s
.77463 .55605 m .76223 .52163 L .73127 .5661 L p .288 .235 .622 r
F P
0 g
s
.69167 .42558 m .72107 .4556 L .72565 .41326 L p .328 .42 .804 r
F P
0 g
s
.72565 .41326 m .69495 .38917 L .69167 .42558 L p .328 .42 .804 r
F P
0 g
s
.56785 .34141 m .60829 .33775 L .58998 .32119 L p .547 .695 .937 r
F P
0 g
s
.58998 .32119 m .55843 .33308 L .56785 .34141 L p .547 .695 .937 r
F P
0 g
s
.61733 .35723 m .65855 .37012 L .64598 .34188 L p .454 .604 .91 r
F P
0 g
s
.64598 .34188 m .60829 .33775 L .61733 .35723 L p .454 .604 .91 r
F P
0 g
s
.43857 .34731 m .39852 .35577 L .39329 .38479 L p .805 .858 .889 r
F P
0 g
s
.35703 .40764 m .39329 .38479 L .39852 .35577 L p .857 .905 .866 r
F P
0 g
s
.45239 .32901 m .48894 .337 L .50031 .32981 L p .699 .837 .949 r
F P
0 g
s
.48894 .337 m .45239 .32901 L .43857 .34731 L p .733 .829 .924 r
F P
0 g
s
.6242 .76452 m .62159 .79513 L .68935 .77277 L p .495 .239 .455 r
F P
0 g
s
.68935 .77277 m .69388 .74106 L .6242 .76452 L p .495 .239 .455 r
F P
0 g
s
.32659 .43477 m .30222 .46499 L .31973 .50989 L p .933 .851 .738 r
F P
0 g
s
.30319 .54489 m .31973 .50989 L .30222 .46499 L p .965 .85 .679 r
F P
0 g
s
.55843 .33308 m .58998 .32119 L .56428 .30954 L p .55 .731 .959 r
F P
0 g
s
.56428 .30954 m .54541 .32725 L .55843 .33308 L p .55 .731 .959 r
F P
0 g
s
.47468 .31467 m .50031 .32981 L .51461 .32552 L p .655 .829 .967 r
F P
0 g
s
.50031 .32981 m .47468 .31467 L .45239 .32901 L p .699 .837 .949 r
F P
0 g
s
.29163 .58003 m .28461 .61506 L .32984 .65685 L p .934 .71 .577 r
F P
0 g
s
.32771 .6913 m .32984 .65685 L .28461 .61506 L p .943 .686 .517 r
F P
0 g
s
.69507 .70795 m .69388 .74106 L .74894 .70588 L p .362 .169 .478 r
F P
0 g
s
.74894 .70588 m .75055 .67174 L .69507 .70795 L p .362 .169 .478 r
F P
0 g
s
.39852 .35577 m .43857 .34731 L .45239 .32901 L p .774 .901 .931 r
F P
0 g
s
.72107 .4556 m .74452 .48793 L .75028 .44123 L p .215 .311 .747 r
F P
0 g
s
.75028 .44123 m .72565 .41326 L .72107 .4556 L p .215 .311 .747 r
F P
0 g
s
.54541 .32725 m .56428 .30954 L .53411 .30428 L p .57 .77 .973 r
F P
0 g
s
.53411 .30428 m .53023 .32463 L .54541 .32725 L p .57 .77 .973 r
F P
0 g
s
.50302 .30606 m .51461 .32552 L .53023 .32463 L p .608 .805 .976 r
F P
0 g
s
.51461 .32552 m .50302 .30606 L .47468 .31467 L p .655 .829 .967 r
F P
0 g
s
.74176 .60186 m .74811 .63707 L .78217 .59088 L p .222 .148 .557 r
F P
0 g
s
.78217 .59088 m .77463 .55605 L .74176 .60186 L p .222 .148 .557 r
F P
0 g
s
.53023 .32463 m .53411 .30428 L .50302 .30606 L p .608 .805 .976 r
F P
0 g
s
.32771 .6913 m .32912 .72489 L .39233 .75442 L p .863 .575 .499 r
F P
0 g
s
.39592 .7855 m .39233 .75442 L .32912 .72489 L p .862 .536 .433 r
F P
0 g
s
.39233 .75442 m .39592 .7855 L .46849 .80168 L p .779 .472 .468 r
F P
0 g
s
.39852 .35577 m .363 .37101 L .35703 .40764 L p .857 .905 .866 r
F P
0 g
s
.32659 .43477 m .35703 .40764 L .363 .37101 L p .904 .943 .822 r
F P
0 g
s
.65855 .37012 m .69495 .38917 L .67955 .35337 L p .313 .51 .889 r
F P
0 g
s
.67955 .35337 m .64598 .34188 L .65855 .37012 L p .313 .51 .889 r
F P
0 g
s
.54485 .83236 m .54584 .80495 L .46849 .80168 L p .685 .356 .414 r
F P
0 g
s
.54584 .80495 m .54485 .83236 L .61671 .82322 L p .588 .276 .408 r
F P
0 g
s
.61671 .82322 m .62159 .79513 L .54584 .80495 L p .588 .276 .408 r
F P
0 g
s
.60829 .33775 m .64598 .34188 L .61962 .31766 L p .405 .639 .951 r
F P
0 g
s
.61962 .31766 m .58998 .32119 L .60829 .33775 L p .405 .639 .951 r
F P
0 g
s
.47144 .82932 m .46849 .80168 L .39592 .7855 L p .769 .421 .395 r
F P
0 g
s
.46849 .80168 m .47144 .82932 L .54485 .83236 L p .685 .356 .414 r
F P
0 g
s
.30222 .46499 m .28378 .49728 L .30319 .54489 L p .965 .85 .679 r
F P
0 g
s
.29163 .58003 m .30319 .54489 L .28378 .49728 L p .988 .839 .606 r
F P
0 g
s
.41817 .32912 m .45239 .32901 L .47468 .31467 L p .7 .918 .968 r
F P
0 g
s
.45239 .32901 m .41817 .32912 L .39852 .35577 L p .774 .901 .931 r
F P
0 g
s
.74452 .48793 m .76223 .52163 L .76898 .472 L p .083 .18 .667 r
F P
0 g
s
.76898 .472 m .75028 .44123 L .74452 .48793 L p .083 .18 .667 r
F P
0 g
s
.62159 .79513 m .61671 .82322 L .68089 .80243 L p .456 .16 .374 r
F P
0 g
s
.68089 .80243 m .68935 .77277 L .62159 .79513 L p .456 .16 .374 r
F P
0 g
s
.28461 .61506 m .28192 .64997 L .32771 .6913 L p .943 .686 .517 r
F P
0 g
s
.32912 .72489 m .32771 .6913 L .28192 .64997 L p .948 .651 .442 r
F P
0 g
s
.363 .37101 m .39852 .35577 L .41817 .32912 L p .804 .969 .908 r
F P
0 g
s
.69388 .74106 m .68935 .77277 L .74278 .73929 L p .309 .082 .398 r
F P
0 g
s
.74278 .73929 m .74894 .70588 L .69388 .74106 L p .309 .082 .398 r
F P
0 g
s
.74811 .63707 m .75055 .67174 L .78506 .62603 L p .145 .049 .479 r
F P
0 g
s
.78506 .62603 m .78217 .59088 L .74811 .63707 L p .145 .049 .479 r
F P
0 g
s
.363 .37101 m .33293 .39204 L .32659 .43477 L p .904 .943 .822 r
F P
0 g
s
.30222 .46499 m .32659 .43477 L .33293 .39204 L p .937 .963 .744 r
F P
0 g
s
.69495 .38917 m .72565 .41326 L .70808 .37135 L p .121 .371 .83 r
F P
0 g
s
.70808 .37135 m .67955 .35337 L .69495 .38917 L p .121 .371 .83 r
F P
0 g
s
.58998 .32119 m .61962 .31766 L .58212 .30052 L p .377 .69 .981 r
F P
0 g
s
.58212 .30052 m .56428 .30954 L .58998 .32119 L p .377 .69 .981 r
F P
0 g
s
.28378 .49728 m .27085 .53091 L .29163 .58003 L p .988 .839 .606 r
F P
0 g
s
.28461 .61506 m .29163 .58003 L .27085 .53091 L p .999 .813 .516 r
F P
0 g
s
.32912 .72489 m .33451 .75737 L .39592 .7855 L p .862 .536 .433 r
F P
0 g
s
.40264 .81426 m .39592 .7855 L .33451 .75737 L p .852 .476 .339 r
F P
0 g
s
.39592 .7855 m .40264 .81426 L .47144 .82932 L p .769 .421 .395 r
F P
0 g
s
.45052 .30808 m .47468 .31467 L .50302 .30606 L p .588 .893 .989 r
F P
0 g
s
.47468 .31467 m .45052 .30808 L .41817 .32912 L p .7 .918 .968 r
F P
0 g
s
.64598 .34188 m .67955 .35337 L .64623 .32243 L p .174 .519 .917 r
F P
0 g
s
.64623 .32243 m .61962 .31766 L .64598 .34188 L p .174 .519 .917 r
F P
0 g
s
.76223 .52163 m .77463 .55605 L .78212 .50477 L p 0 .028 .561 r
F P
0 g
s
.78212 .50477 m .76898 .472 L .76223 .52163 L p 0 .028 .561 r
F P
0 g
s
.54331 .85582 m .54485 .83236 L .47144 .82932 L p .656 .277 .314 r
F P
0 g
s
.54485 .83236 m .54331 .85582 L .60917 .84758 L p .548 .186 .304 r
F P
0 g
s
.60917 .84758 m .61671 .82322 L .54485 .83236 L p .548 .186 .304 r
F P
0 g
s
.56428 .30954 m .58212 .30052 L .53779 .29273 L p .395 .757 .993 r
F P
0 g
s
.53779 .29273 m .53411 .30428 L .56428 .30954 L p .395 .757 .993 r
F P
0 g
s
.49204 .29537 m .50302 .30606 L .53411 .30428 L p .472 .831 .995 r
F P
0 g
s
.50302 .30606 m .49204 .29537 L .45052 .30808 L p .588 .893 .989 r
F P
0 g
s
.476 .85308 m .47144 .82932 L .40264 .81426 L p .745 .34 .284 r
F P
0 g
s
.47144 .82932 m .476 .85308 L .54331 .85582 L p .656 .277 .314 r
F P
0 g
s
.53411 .30428 m .53779 .29273 L .49204 .29537 L p .472 .831 .995 r
F P
0 g
s
.33293 .39204 m .30872 .41771 L .30222 .46499 L p .937 .963 .744 r
F P
0 g
s
.28378 .49728 m .30222 .46499 L .30872 .41771 L p .941 .948 .623 r
F P
0 g
s
.28192 .64997 m .2837 .68473 L .32912 .72489 L p .948 .651 .442 r
F P
0 g
s
.33451 .75737 m .32912 .72489 L .2837 .68473 L p .942 .597 .34 r
F P
0 g
s
.41817 .32912 m .38757 .3371 L .363 .37101 L p .804 .969 .908 r
F P
0 g
s
.33293 .39204 m .363 .37101 L .38757 .3371 L p .795 .999 .817 r
F P
0 g
s
.75055 .67174 m .74894 .70588 L .78315 .66149 L p .052 0 .377 r
F P
0 g
s
.78315 .66149 m .78506 .62603 L .75055 .67174 L p .052 0 .377 r
F P
0 g
s
.72565 .41326 m .75028 .44123 L .73113 .39472 L p 0 .172 .709 r
F P
0 g
s
.73113 .39472 m .70808 .37135 L .72565 .41326 L p 0 .172 .709 r
F P
0 g
s
.38757 .3371 m .41817 .32912 L .45052 .30808 L p .641 .962 .911 r
F P
0 g
s
.68935 .77277 m .68089 .80243 L .7313 .77136 L p .231 0 .282 r
F P
0 g
s
.7313 .77136 m .74278 .73929 L .68935 .77277 L p .231 0 .282 r
F P
0 g
s
.27085 .53091 m .26297 .5655 L .28461 .61506 L p .999 .813 .516 r
F P
0 g
s
.28192 .64997 m .28461 .61506 L .26297 .5655 L p .994 .768 .404 r
F P
0 g
s
.61671 .82322 m .60917 .84758 L .66781 .82888 L p .391 .041 .248 r
F P
0 g
s
.66781 .82888 m .68089 .80243 L .61671 .82322 L p .391 .041 .248 r
F P
0 g
s
.77463 .55605 m .78217 .59088 L .79013 .53908 L p 0 0 .425 r
F P
0 g
s
.79013 .53908 m .78212 .50477 L .77463 .55605 L p 0 0 .425 r
F P
0 g
s
.61962 .31766 m .64623 .32243 L .59822 .30039 L p .052 .536 .888 r
F P
0 g
s
.59822 .30039 m .58212 .30052 L .61962 .31766 L p .052 .536 .888 r
F P
0 g
s
.33451 .75737 m .34456 .78813 L .40264 .81426 L p .852 .476 .339 r
F P
0 g
s
.41302 .83952 m .40264 .81426 L .34456 .78813 L p .819 .377 .19 r
F P
0 g
s
.40264 .81426 m .41302 .83952 L .476 .85308 L p .745 .34 .284 r
F P
0 g
s
.67955 .35337 m .70808 .37135 L .66898 .33489 L p 0 .288 .763 r
F P
0 g
s
.66898 .33489 m .64623 .32243 L .67955 .35337 L p 0 .288 .763 r
F P
0 g
s
.30872 .41771 m .2903 .44693 L .28378 .49728 L p .941 .948 .623 r
F P
0 g
s
.27085 .53091 m .28378 .49728 L .2903 .44693 L p .899 .883 .454 r
F P
0 g
s
.74894 .70588 m .74278 .73929 L .77585 .6971 L p 0 0 .237 r
F P
0 g
s
.77585 .6971 m .78315 .66149 L .74894 .70588 L p 0 0 .237 r
F P
0 g
s
.42876 .31013 m .45052 .30808 L .49204 .29537 L p .381 .845 .856 r
F P
0 g
s
.45052 .30808 m .42876 .31013 L .38757 .3371 L p .641 .962 .911 r
F P
0 g
s
.38757 .3371 m .36147 .3522 L .33293 .39204 L p .795 .999 .817 r
F P
0 g
s
.30872 .41771 m .33293 .39204 L .36147 .3522 L p .7 .93 .612 r
F P
0 g
s
.2837 .68473 m .2905 .71918 L .33451 .75737 L p .942 .597 .34 r
F P
0 g
s
.34456 .78813 m .33451 .75737 L .2905 .71918 L p .911 .507 .188 r
F P
0 g
s
.75028 .44123 m .76898 .472 L .7487 .42236 L p 0 0 .509 r
F P
0 g
s
.7487 .42236 m .73113 .39472 L .75028 .44123 L p 0 0 .509 r
F P
0 g
s
.26297 .5655 m .25995 .6009 L .28192 .64997 L p .994 .768 .404 r
F P
0 g
s
.2837 .68473 m .28192 .64997 L .25995 .6009 L p .962 .693 .258 r
F P
0 g
s
.54115 .87368 m .54331 .85582 L .476 .85308 L p .595 .142 .146 r
F P
0 g
s
.54331 .85582 m .54115 .87368 L .59858 .86658 L p .47 .035 .129 r
F P
0 g
s
.59858 .86658 m .60917 .84758 L .54331 .85582 L p .47 .035 .129 r
F P
0 g
s
.58212 .30052 m .59822 .30039 L .54112 .29035 L p .028 .582 .824 r
F P
0 g
s
.54112 .29035 m .53779 .29273 L .58212 .30052 L p .028 .582 .824 r
F P
0 g
s
.48241 .87131 m .476 .85308 L .41302 .83952 L p .682 .198 .094 r
F P
0 g
s
.476 .85308 m .48241 .87131 L .54115 .87368 L p .595 .142 .146 r
F P
0 g
s
.68089 .80243 m .66781 .82888 L .71362 .801 L p .109 0 .098 r
F P
0 g
s
.71362 .801 m .7313 .77136 L .68089 .80243 L p .109 0 .098 r
F P
0 g
s
.78217 .59088 m .78506 .62603 L .79321 .57474 L p 0 0 .256 r
F P
0 g
s
.79321 .57474 m .79013 .53908 L .78217 .59088 L p 0 0 .256 r
F P
0 g
s
.36147 .3522 m .38757 .3371 L .42876 .31013 L p .445 .85 .667 r
F P
0 g
s
.48212 .29376 m .49204 .29537 L .53779 .29273 L p .146 .689 .805 r
F P
0 g
s
.49204 .29537 m .48212 .29376 L .42876 .31013 L p .381 .845 .856 r
F P
0 g
s
.53779 .29273 m .54112 .29035 L .48212 .29376 L p .146 .689 .805 r
F P
0 g
s
.60917 .84758 m .59858 .86658 L .64951 .85052 L p .272 0 .034 r
F P
0 g
s
.64951 .85052 m .66781 .82888 L .60917 .84758 L p .272 0 .034 r
F P
0 g
s
.2903 .44693 m .27732 .47881 L .27085 .53091 L p .899 .883 .454 r
F P
0 g
s
.26297 .5655 m .27085 .53091 L .27732 .47881 L p .803 .762 .248 r
F P
0 g
s
.70808 .37135 m .73113 .39472 L .68747 .35405 L p .546 .032 0 r
F P
0 g
s
.68747 .35405 m .66898 .33489 L .70808 .37135 L p .546 .032 0 r
F P
0 g
s
.76898 .472 m .78212 .50477 L .7611 .45333 L p .664 .326 0 r
F P
0 g
s
.7611 .45333 m .7487 .42236 L .76898 .472 L p .664 .326 0 r
F P
0 g
s
.74278 .73929 m .7313 .77136 L .76226 .73231 L p 0 0 .033 r
F P
0 g
s
.76226 .73231 m .77585 .6971 L .74278 .73929 L p 0 0 .033 r
F P
0 g
s
.64623 .32243 m .66898 .33489 L .61205 .30878 L p .387 0 0 r
F P
0 g
s
.61205 .30878 m .59822 .30039 L .64623 .32243 L p .387 0 0 r
F P
0 g
s
.25995 .6009 m .26195 .6371 L .2837 .68473 L p .962 .693 .258 r
F P
0 g
s
.2905 .71918 m .2837 .68473 L .26195 .6371 L p .884 .57 .062 r
F P
0 g
s
.36147 .3522 m .34033 .37338 L .30872 .41771 L p .7 .93 .612 r
F P
0 g
s
.2903 .44693 m .30872 .41771 L .34033 .37338 L p 0 0 0 r
F P
0 g
s
.34456 .78813 m .36008 .81604 L .41302 .83952 L p .819 .377 .19 r
F P
0 g
s
.42757 .85965 m .41302 .83952 L .36008 .81604 L p .724 .198 0 r
F P
0 g
s
.41302 .83952 m .42757 .85965 L .48241 .87131 L p .682 .198 .094 r
F P
0 g
s
.2905 .71918 m .30316 .75273 L .34456 .78813 L p .911 .507 .188 r
F P
0 g
s
.36008 .81604 m .34456 .78813 L .30316 .75273 L p .821 .349 0 r
F P
0 g
s
.78506 .62603 m .78315 .66149 L .79117 .61171 L p 0 0 .053 r
F P
0 g
s
.79117 .61171 m .79321 .57474 L .78506 .62603 L p 0 0 .053 r
F P
0 g
s
.42876 .31013 m .41011 .32032 L .36147 .3522 L p .445 .85 .667 r
F P
0 g
s
.41011 .32032 m .42876 .31013 L .48212 .29376 L p 0 0 0 r
F P
0 g
s
.27732 .47881 m .26941 .51282 L .26297 .5655 L p .803 .762 .248 r
F P
0 g
s
.25995 .6009 m .26297 .5655 L .26941 .51282 L p 0 0 0 r
F P
0 g
s
.66781 .82888 m .64951 .85052 L .68899 .82668 L p 0 0 0 r
F P
0 g
s
.68899 .82668 m .71362 .801 L .66781 .82888 L p 0 0 0 r
F P
0 g
s
.34033 .37338 m .36147 .3522 L .41011 .32032 L p 0 0 0 r
F P
0 g
s
.53832 .88401 m .54115 .87368 L .48241 .87131 L p .442 0 0 r
F P
0 g
s
.54115 .87368 m .53832 .88401 L .58475 .87831 L p .296 0 0 r
F P
0 g
s
.58475 .87831 m .59858 .86658 L .54115 .87368 L p .296 0 0 r
F P
0 g
s
.78212 .50477 m .79013 .53908 L .76868 .48702 L p .84 .526 0 r
F P
0 g
s
.76868 .48702 m .7611 .45333 L .78212 .50477 L p .84 .526 0 r
F P
0 g
s
.49079 .88211 m .48241 .87131 L .42757 .85965 L p .511 0 0 r
F P
0 g
s
.48241 .87131 m .49079 .88211 L .53832 .88401 L p .442 0 0 r
F P
0 g
s
.59822 .30039 m .61205 .30878 L .54398 .29684 L p .398 0 0 r
F P
0 g
s
.54398 .29684 m .54112 .29035 L .59822 .30039 L p .398 0 0 r
F P
0 g
s
.26195 .6371 m .26957 .67394 L .2905 .71918 L p .884 .57 .062 r
F P
0 g
s
.30316 .75273 m .2905 .71918 L .26957 .67394 L p .729 .378 0 r
F P
0 g
s
.73113 .39472 m .7487 .42236 L .70163 .37877 L p .79 .307 0 r
F P
0 g
s
.70163 .37877 m .68747 .35405 L .73113 .39472 L p .79 .307 0 r
F P
0 g
s
.7313 .77136 m .71362 .801 L .74141 .76612 L p 0 0 0 r
F P
0 g
s
.74141 .76612 m .76226 .73231 L .7313 .77136 L p 0 0 0 r
F P
0 g
s
.34033 .37338 m .32417 .39951 L .2903 .44693 L p 0 0 0 r
F P
0 g
s
.27732 .47881 m .2903 .44693 L .32417 .39951 L p 0 0 0 r
F P
0 g
s
.59858 .86658 m .58475 .87831 L .62571 .86546 L p .042 0 0 r
F P
0 g
s
.62571 .86546 m .64951 .85052 L .59858 .86658 L p .042 0 0 r
F P
0 g
s
.47359 .3009 m .48212 .29376 L .54112 .29035 L p .259 0 0 r
F P
0 g
s
.48212 .29376 m .47359 .3009 L .41011 .32032 L p 0 0 0 r
F P
0 g
s
.78315 .66149 m .77585 .6971 L .78342 .64985 L p .74 .711 .178 r
F P
0 g
s
.78342 .64985 m .79117 .61171 L .78315 .66149 L p .74 .711 .178 r
F P
0 g
s
.54112 .29035 m .54398 .29684 L .47359 .3009 L p .259 0 0 r
F P
0 g
s
.30316 .75273 m .32264 .78435 L .36008 .81604 L p .821 .349 0 r
F P
0 g
s
.38174 .83952 m .36008 .81604 L .32264 .78435 L p .609 .086 0 r
F P
0 g
s
.36008 .81604 m .38174 .83952 L .42757 .85965 L p .724 .198 0 r
F P
0 g
s
.66898 .33489 m .68747 .35405 L .62333 .3248 L p .679 .133 0 r
F P
0 g
s
.62333 .3248 m .61205 .30878 L .66898 .33489 L p .679 .133 0 r
F P
0 g
s
.26941 .51282 m .26636 .54873 L .25995 .6009 L p 0 0 0 r
F P
0 g
s
.26195 .6371 m .25995 .6009 L .26636 .54873 L p 0 0 .189 r
F P
0 g
s
.44655 .87276 m .42757 .85965 L .38174 .83952 L p .474 0 0 r
F P
0 g
s
.42757 .85965 m .44655 .87276 L .49079 .88211 L p .511 0 0 r
F P
0 g
s
.79013 .53908 m .79321 .57474 L .77159 .52316 L p .94 .665 .199 r
F P
0 g
s
.77159 .52316 m .76868 .48702 L .79013 .53908 L p .94 .665 .199 r
F P
0 g
s
.41011 .32032 m .39492 .33775 L .34033 .37338 L p 0 0 0 r
F P
0 g
s
.32417 .39951 m .34033 .37338 L .39492 .33775 L p .078 0 .043 r
F P
0 g
s
.39492 .33775 m .41011 .32032 L .47359 .3009 L p .256 0 0 r
F P
0 g
s
.26957 .67394 m .28375 .71093 L .30316 .75273 L p .729 .378 0 r
F P
0 g
s
.32264 .78435 m .30316 .75273 L .28375 .71093 L p 0 0 .462 r
F P
0 g
s
.32417 .39951 m .31275 .42961 L .27732 .47881 L p 0 0 0 r
F P
0 g
s
.26941 .51282 m .27732 .47881 L .31275 .42961 L p 0 0 .186 r
F P
0 g
s
.64951 .85052 m .62571 .86546 L .65713 .8465 L p 0 0 0 r
F P
0 g
s
.65713 .8465 m .68899 .82668 L .64951 .85052 L p 0 0 0 r
F P
0 g
s
.7487 .42236 m .7611 .45333 L .71165 .40803 L p .897 .478 .14 r
F P
0 g
s
.71165 .40803 m .70163 .37877 L .7487 .42236 L p .897 .478 .14 r
F P
0 g
s
.77585 .6971 m .76226 .73231 L .76902 .68873 L p .858 .862 .411 r
F P
0 g
s
.76902 .68873 m .78342 .64985 L .77585 .6971 L p .858 .862 .411 r
F P
0 g
s
.71362 .801 m .68899 .82668 L .71254 .79702 L p .622 .886 .561 r
F P
0 g
s
.71254 .79702 m .74141 .76612 L .71362 .801 L p .622 .886 .561 r
F P
0 g
s
.26636 .54873 m .26838 .58647 L .26195 .6371 L p 0 0 .189 r
F P
0 g
s
.26957 .67394 m .26195 .6371 L .26838 .58647 L p 0 0 .385 r
F P
0 g
s
.61205 .30878 m .62333 .3248 L .54632 .31139 L p .617 .108 .016 r
F P
0 g
s
.54632 .31139 m .54398 .29684 L .61205 .30878 L p .617 .108 .016 r
F P
0 g
s
.53484 .88494 m .53832 .88401 L .49079 .88211 L p .078 0 0 r
F P
0 g
s
.53832 .88401 m .53484 .88494 L .56774 .8809 L p 0 0 0 r
F P
0 g
s
.56774 .8809 m .58475 .87831 L .53832 .88401 L p 0 0 0 r
F P
0 g
s
.49079 .88211 m .50111 .88359 L .53484 .88494 L p .078 0 0 r
F P
0 g
s
.50111 .88359 m .49079 .88211 L .44655 .87276 L p 0 .472 .721 r
F P
0 g
s
.32264 .78435 m .34968 .81249 L .38174 .83952 L p .609 .086 0 r
F P
0 g
s
.38174 .83952 m .40985 .8567 L .44655 .87276 L p .474 0 0 r
F P
0 g
s
.40985 .8567 m .38174 .83952 L .34968 .81249 L p 0 .251 .714 r
F P
0 g
s
.79321 .57474 m .79117 .61171 L .76966 .56166 L p .987 .757 .367 r
F P
0 g
s
.76966 .56166 m .77159 .52316 L .79321 .57474 L p .987 .757 .367 r
F P
0 g
s
.68747 .35405 m .70163 .37877 L .63199 .34733 L p .794 .332 .143 r
F P
0 g
s
.63199 .34733 m .62333 .3248 L .68747 .35405 L p .794 .332 .143 r
F P
0 g
s
.46662 .31595 m .47359 .3009 L .54398 .29684 L p .482 .003 .042 r
F P
0 g
s
.47359 .3009 m .46662 .31595 L .39492 .33775 L p .256 0 0 r
F P
0 g
s
.58475 .87831 m .56774 .8809 L .59659 .87183 L p .3 .793 .777 r
F P
0 g
s
.59659 .87183 m .62571 .86546 L .58475 .87831 L p .3 .793 .777 r
F P
0 g
s
.54398 .29684 m .54632 .31139 L .46662 .31595 L p .482 .003 .042 r
F P
0 g
s
.31275 .42961 m .30577 .46299 L .26941 .51282 L p 0 0 .186 r
F P
0 g
s
.26636 .54873 m .26941 .51282 L .30577 .46299 L p .016 0 .343 r
F P
0 g
s
.39492 .33775 m .38327 .36126 L .32417 .39951 L p .078 0 .043 r
F P
0 g
s
.31275 .42961 m .32417 .39951 L .38327 .36126 L p .22 0 .246 r
F P
0 g
s
.76226 .73231 m .74141 .76612 L .74701 .72738 L p .915 .951 .611 r
F P
0 g
s
.74701 .72738 m .76902 .68873 L .76226 .73231 L p .915 .951 .611 r
F P
0 g
s
.28375 .71093 m .30546 .74709 L .32264 .78435 L p 0 0 .462 r
F P
0 g
s
.34968 .81249 m .32264 .78435 L .30546 .74709 L p 0 .153 .694 r
F P
0 g
s
.46983 .87698 m .44655 .87276 L .40985 .8567 L p 0 .491 .836 r
F P
0 g
s
.44655 .87276 m .46983 .87698 L .50111 .88359 L p 0 .472 .721 r
F P
0 g
s
.7611 .45333 m .76868 .48702 L .71778 .44111 L p .936 .576 .306 r
F P
0 g
s
.71778 .44111 m .71165 .40803 L .7611 .45333 L p .936 .576 .306 r
F P
0 g
s
.26838 .58647 m .27604 .62593 L .26957 .67394 L p 0 0 .385 r
F P
0 g
s
.28375 .71093 m .26957 .67394 L .27604 .62593 L p 0 .001 .548 r
F P
0 g
s
.38327 .36126 m .39492 .33775 L .46662 .31595 L p .399 .022 .204 r
F P
0 g
s
.68899 .82668 m .65713 .8465 L .67546 .82308 L p .73 .988 .803 r
F P
0 g
s
.67546 .82308 m .71254 .79702 L .68899 .82668 L p .73 .988 .803 r
F P
0 g
s
.62571 .86546 m .59659 .87183 L .61844 .85854 L p .562 .936 .885 r
F P
0 g
s
.61844 .85854 m .65713 .8465 L .62571 .86546 L p .562 .936 .885 r
F P
0 g
s
.79117 .61171 m .78342 .64985 L .76232 .60245 L p 1 .816 .501 r
F P
0 g
s
.76232 .60245 m .76966 .56166 L .79117 .61171 L p 1 .816 .501 r
F P
0 g
s
.62333 .3248 m .63199 .34733 L .54812 .33289 L p .7 .277 .238 r
F P
0 g
s
.54812 .33289 m .54632 .31139 L .62333 .3248 L p .7 .277 .238 r
F P
0 g
s
.30577 .46299 m .30308 .49933 L .26636 .54873 L p .016 0 .343 r
F P
0 g
s
.26838 .58647 m .26636 .54873 L .30308 .49933 L p .123 .024 .46 r
F P
0 g
s
.70163 .37877 m .71165 .40803 L .63814 .37529 L p .833 .442 .309 r
F P
0 g
s
.63814 .37529 m .63199 .34733 L .70163 .37877 L p .833 .442 .309 r
F P
0 g
s
.34968 .81249 m .38456 .83527 L .40985 .8567 L p 0 .251 .714 r
F P
0 g
s
.44412 .86568 m .40985 .8567 L .38456 .83527 L p .125 .526 .915 r
F P
0 g
s
.40985 .8567 m .44412 .86568 L .46983 .87698 L p 0 .491 .836 r
F P
0 g
s
.74141 .76612 m .71254 .79702 L .71672 .76428 L p .914 .98 .757 r
F P
0 g
s
.71672 .76428 m .74701 .72738 L .74141 .76612 L p .914 .98 .757 r
F P
0 g
s
.76868 .48702 m .77159 .52316 L .72015 .47763 L p .945 .637 .421 r
F P
0 g
s
.72015 .47763 m .71778 .44111 L .76868 .48702 L p .945 .637 .421 r
F P
0 g
s
.30546 .74709 m .33543 .78091 L .34968 .81249 L p 0 .153 .694 r
F P
0 g
s
.38456 .83527 m .34968 .81249 L .33543 .78091 L p .077 .382 .844 r
F P
0 g
s
.38327 .36126 m .37501 .3898 L .31275 .42961 L p .22 0 .246 r
F P
0 g
s
.30577 .46299 m .31275 .42961 L .37501 .3898 L p .308 .066 .374 r
F P
0 g
s
.27604 .62593 m .29026 .66671 L .28375 .71093 L p 0 .001 .548 r
F P
0 g
s
.30546 .74709 m .28375 .71093 L .29026 .66671 L p .052 .177 .677 r
F P
0 g
s
.53078 .87498 m .53484 .88494 L .50111 .88359 L p .36 .782 .975 r
F P
0 g
s
.53484 .88494 m .53078 .87498 L .54799 .87285 L p .435 .837 .977 r
F P
0 g
s
.54799 .87285 m .56774 .8809 L .53484 .88494 L p .435 .837 .977 r
F P
0 g
s
.46126 .3378 m .46662 .31595 L .54632 .31139 L p .577 .18 .254 r
F P
0 g
s
.46662 .31595 m .46126 .3378 L .38327 .36126 L p .399 .022 .204 r
F P
0 g
s
.51311 .87427 m .50111 .88359 L .46983 .87698 L p .331 .738 .98 r
F P
0 g
s
.50111 .88359 m .51311 .87427 L .53078 .87498 L p .36 .782 .975 r
F P
0 g
s
.56774 .8809 m .54799 .87285 L .56297 .86809 L p .538 .886 .983 r
F P
0 g
s
.56297 .86809 m .59659 .87183 L .56774 .8809 L p .538 .886 .983 r
F P
0 g
s
.54632 .31139 m .54812 .33289 L .46126 .3378 L p .577 .18 .254 r
F P
0 g
s
.78342 .64985 m .76902 .68873 L .74874 .64514 L p .989 .85 .609 r
F P
0 g
s
.74874 .64514 m .76232 .60245 L .78342 .64985 L p .989 .85 .609 r
F P
0 g
s
.65713 .8465 m .61844 .85854 L .63083 .84227 L p .744 .973 .926 r
F P
0 g
s
.63083 .84227 m .67546 .82308 L .65713 .8465 L p .744 .973 .926 r
F P
0 g
s
.4968 .87079 m .46983 .87698 L .44412 .86568 L p .347 .705 .984 r
F P
0 g
s
.46983 .87698 m .4968 .87079 L .51311 .87427 L p .331 .738 .98 r
F P
0 g
s
.37501 .3898 m .38327 .36126 L .46126 .3378 L p .473 .155 .346 r
F P
0 g
s
.30308 .49933 m .30486 .53855 L .26838 .58647 L p .123 .024 .46 r
F P
0 g
s
.27604 .62593 m .26838 .58647 L .30486 .53855 L p .211 .14 .554 r
F P
0 g
s
.59659 .87183 m .56297 .86809 L .57415 .86117 L p .637 .911 .981 r
F P
0 g
s
.57415 .86117 m .61844 .85854 L .59659 .87183 L p .637 .911 .981 r
F P
0 g
s
.71254 .79702 m .67546 .82308 L .67812 .79745 L p .875 .966 .851 r
F P
0 g
s
.67812 .79745 m .71672 .76428 L .71254 .79702 L p .875 .966 .851 r
F P
0 g
s
.29026 .66671 m .31194 .70788 L .30546 .74709 L p .052 .177 .677 r
F P
0 g
s
.33543 .78091 m .30546 .74709 L .31194 .70788 L p .196 .328 .772 r
F P
0 g
s
.77159 .52316 m .76966 .56166 L .71858 .51751 L p .942 .678 .507 r
F P
0 g
s
.71858 .51751 m .72015 .47763 L .77159 .52316 L p .942 .678 .507 r
F P
0 g
s
.71165 .40803 m .71778 .44111 L .64191 .40786 L p .846 .508 .413 r
F P
0 g
s
.64191 .40786 m .63814 .37529 L .71165 .40803 L p .846 .508 .413 r
F P
0 g
s
.33543 .78091 m .37378 .81043 L .38456 .83527 L p .077 .382 .844 r
F P
0 g
s
.42672 .85072 m .38456 .83527 L .37378 .81043 L p .291 .548 .921 r
F P
0 g
s
.38456 .83527 m .42672 .85072 L .44412 .86568 L p .125 .526 .915 r
F P
0 g
s
.37501 .3898 m .36995 .4226 L .30577 .46299 L p .308 .066 .374 r
F P
0 g
s
.30308 .49933 m .30577 .46299 L .36995 .4226 L p .368 .162 .463 r
F P
0 g
s
.63199 .34733 m .63814 .37529 L .5494 .36022 L p .733 .372 .367 r
F P
0 g
s
.5494 .36022 m .54812 .33289 L .63199 .34733 L p .733 .372 .367 r
F P
0 g
s
.48353 .86488 m .44412 .86568 L .42672 .85072 L p .394 .681 .975 r
F P
0 g
s
.44412 .86568 m .48353 .86488 L .4968 .87079 L p .347 .705 .984 r
F P
0 g
s
.76902 .68873 m .74701 .72738 L .72806 .68882 L p .963 .868 .697 r
F P
0 g
s
.72806 .68882 m .74874 .64514 L .76902 .68873 L p .963 .868 .697 r
F P
0 g
s
.30486 .53855 m .31163 .58058 L .27604 .62593 L p .211 .14 .554 r
F P
0 g
s
.29026 .66671 m .27604 .62593 L .31163 .58058 L p .286 .242 .632 r
F P
0 g
s
.45745 .36535 m .46126 .3378 L .54812 .33289 L p .622 .283 .376 r
F P
0 g
s
.46126 .3378 m .45745 .36535 L .37501 .3898 L p .473 .155 .346 r
F P
0 g
s
.61844 .85854 m .57415 .86117 L .58028 .85278 L p .709 .905 .965 r
F P
0 g
s
.58028 .85278 m .63083 .84227 L .61844 .85854 L p .709 .905 .965 r
F P
0 g
s
.54812 .33289 m .5494 .36022 L .45745 .36535 L p .622 .283 .376 r
F P
0 g
s
.31194 .70788 m .34169 .7479 L .33543 .78091 L p .196 .328 .772 r
F P
0 g
s
.37378 .81043 m .33543 .78091 L .34169 .7479 L p .317 .454 .841 r
F P
0 g
s
.67546 .82308 m .63083 .84227 L .63212 .82464 L p .816 .927 .907 r
F P
0 g
s
.63212 .82464 m .67812 .79745 L .67546 .82308 L p .816 .927 .907 r
F P
0 g
s
.36995 .4226 m .37501 .3898 L .45745 .36535 L p .517 .242 .436 r
F P
0 g
s
.52632 .85341 m .53078 .87498 L .51311 .87427 L closepath p .576 .8 .984 r
F P
0 g
s
.52632 .85341 m .54799 .87285 L .53078 .87498 L closepath p .594 .813 .984 r
F P
0 g
s
.76966 .56166 m .76232 .60245 L .71264 .5607 L p .932 .709 .578 r
F P
0 g
s
.71264 .5607 m .71858 .51751 L .76966 .56166 L p .932 .709 .578 r
F P
0 g
s
.52632 .85341 m .51311 .87427 L .4968 .87079 L closepath p .565 .786 .982 r
F P
0 g
s
.52632 .85341 m .56297 .86809 L .54799 .87285 L closepath p .615 .821 .979 r
F P
0 g
s
.74701 .72738 m .71672 .76428 L .69976 .73194 L p .925 .873 .767 r
F P
0 g
s
.69976 .73194 m .72806 .68882 L .74701 .72738 L p .925 .873 .767 r
F P
0 g
s
.37378 .81043 m .41971 .83355 L .42672 .85072 L p .291 .548 .921 r
F P
0 g
s
.47474 .85713 m .42672 .85072 L .41971 .83355 L p .452 .664 .953 r
F P
0 g
s
.42672 .85072 m .47474 .85713 L .48353 .86488 L p .394 .681 .975 r
F P
0 g
s
.36995 .4226 m .368 .45927 L .30308 .49933 L p .368 .162 .463 r
F P
0 g
s
.30486 .53855 m .30308 .49933 L .368 .45927 L p .413 .237 .531 r
F P
0 g
s
.71778 .44111 m .72015 .47763 L .64337 .44465 L p .849 .553 .487 r
F P
0 g
s
.64337 .44465 m .64191 .40786 L .71778 .44111 L p .849 .553 .487 r
F P
0 g
s
.52632 .85341 m .4968 .87079 L .48353 .86488 L closepath p .561 .771 .976 r
F P
0 g
s
.52632 .85341 m .57415 .86117 L .56297 .86809 L closepath p .637 .824 .972 r
F P
0 g
s
.31163 .58058 m .32414 .62508 L .29026 .66671 L p .286 .242 .632 r
F P
0 g
s
.31194 .70788 m .29026 .66671 L .32414 .62508 L p .352 .334 .699 r
F P
0 g
s
.63814 .37529 m .64191 .40786 L .55019 .39256 L p .748 .433 .449 r
F P
0 g
s
.55019 .39256 m .5494 .36022 L .63814 .37529 L p .748 .433 .449 r
F P
0 g
s
.52632 .85341 m .48353 .86488 L .47474 .85713 L closepath p .565 .757 .968 r
F P
0 g
s
.34169 .7479 m .37944 .7847 L .37378 .81043 L p .317 .454 .841 r
F P
0 g
s
.41971 .83355 m .37378 .81043 L .37944 .7847 L p .42 .561 .89 r
F P
0 g
s
.63083 .84227 m .58028 .85278 L .58062 .84381 L p .747 .875 .939 r
F P
0 g
s
.58062 .84381 m .63212 .82464 L .63083 .84227 L p .747 .875 .939 r
F P
0 g
s
.52632 .85341 m .58028 .85278 L .57415 .86117 L closepath p .656 .821 .963 r
F P
0 g
s
.71672 .76428 m .67812 .79745 L .66399 .77235 L p .878 .869 .825 r
F P
0 g
s
.66399 .77235 m .69976 .73194 L .71672 .76428 L p .878 .869 .825 r
F P
0 g
s
.76232 .60245 m .74874 .64514 L .70166 .60687 L p .916 .733 .639 r
F P
0 g
s
.70166 .60687 m .71264 .5607 L .76232 .60245 L p .916 .733 .639 r
F P
0 g
s
.45512 .39776 m .45745 .36535 L .5494 .36022 L p .646 .35 .455 r
F P
0 g
s
.45745 .36535 m .45512 .39776 L .36995 .4226 L p .517 .242 .436 r
F P
0 g
s
.41971 .83355 m .47144 .84833 L .47474 .85713 L p .452 .664 .953 r
F P
0 g
s
.52632 .85341 m .47474 .85713 L .47144 .84833 L closepath p .575 .746 .958 r
F P
0 g
s
.368 .45927 m .36995 .4226 L .45512 .39776 L p .545 .304 .501 r
F P
0 g
s
.368 .45927 m .36929 .49971 L .30486 .53855 L p .413 .237 .531 r
F P
0 g
s
.31163 .58058 m .30486 .53855 L .36929 .49971 L p .45 .303 .589 r
F P
0 g
s
.32414 .62508 m .34315 .67114 L .31194 .70788 L p .352 .334 .699 r
F P
0 g
s
.34169 .7479 m .31194 .70788 L .34315 .67114 L p .411 .418 .757 r
F P
0 g
s
.37944 .7847 m .42422 .81595 L .41971 .83355 L p .42 .561 .89 r
F P
0 g
s
.47144 .84833 m .41971 .83355 L .42422 .81595 L p .509 .655 .925 r
F P
0 g
s
.5494 .36022 m .55019 .39256 L .45512 .39776 L p .646 .35 .455 r
F P
0 g
s
.72015 .47763 m .71858 .51751 L .6424 .48554 L p .847 .587 .545 r
F P
0 g
s
.6424 .48554 m .64337 .44465 L .72015 .47763 L p .847 .587 .545 r
F P
0 g
s
.52632 .85341 m .58062 .84381 L .58028 .85278 L closepath p .669 .813 .953 r
F P
0 g
s
.67812 .79745 m .63212 .82464 L .62178 .80757 L p .823 .856 .872 r
F P
0 g
s
.62178 .80757 m .66399 .77235 L .67812 .79745 L p .823 .856 .872 r
F P
0 g
s
.42422 .81595 m .47407 .83942 L .47144 .84833 L p .509 .655 .925 r
F P
0 g
s
.52632 .85341 m .47144 .84833 L .47407 .83942 L closepath p .589 .739 .947 r
F P
0 g
s
.74874 .64514 m .72806 .68882 L .685 .65513 L p .896 .752 .695 r
F P
0 g
s
.685 .65513 m .70166 .60687 L .74874 .64514 L p .896 .752 .695 r
F P
0 g
s
.52632 .85341 m .56401 .82796 L .57502 .83521 L closepath p .677 .788 .933 r
F P
0 g
s
.52632 .85341 m .54874 .82289 L .56401 .82796 L closepath p .673 .773 .926 r
F P
0 g
s
.52632 .85341 m .53092 .82061 L .54874 .82289 L closepath p .664 .76 .922 r
F P
0 g
s
.52632 .85341 m .51256 .82138 L .53092 .82061 L closepath p .652 .749 .921 r
F P
0 g
s
.52632 .85341 m .49578 .82512 L .51256 .82138 L closepath p .638 .741 .924 r
F P
0 g
s
.52632 .85341 m .48247 .83138 L .49578 .82512 L closepath p .622 .737 .929 r
F P
0 g
s
.52632 .85341 m .47407 .83942 L .48247 .83138 L closepath p .605 .736 .937 r
F P
0 g
s
.52632 .85341 m .57502 .83521 L .58062 .84381 L closepath p .676 .801 .942 r
F P
0 g
s
.64191 .40786 m .64337 .44465 L .55049 .42946 L p .756 .476 .509 r
F P
0 g
s
.55049 .42946 m .55019 .39256 L .64191 .40786 L p .756 .476 .509 r
F P
0 g
s
.63212 .82464 m .58062 .84381 L .57502 .83521 L p .757 .834 .911 r
F P
0 g
s
.57502 .83521 m .62178 .80757 L .63212 .82464 L p .757 .834 .911 r
F P
0 g
s
.34315 .67114 m .36909 .71719 L .34169 .7479 L p .411 .418 .757 r
F P
0 g
s
.37944 .7847 m .34169 .7479 L .36909 .71719 L p .464 .498 .808 r
F P
0 g
s
.36929 .49971 m .3742 .54388 L .31163 .58058 L p .45 .303 .589 r
F P
0 g
s
.32414 .62508 m .31163 .58058 L .3742 .54388 L p .482 .363 .641 r
F P
0 g
s
.45512 .39776 m .45421 .43463 L .368 .45927 L p .545 .304 .501 r
F P
0 g
s
.36929 .49971 m .368 .45927 L .45421 .43463 L p .566 .355 .552 r
F P
0 g
s
.44016 .79989 m .48247 .83138 L .47407 .83942 L p .56 .654 .898 r
F P
0 g
s
.47407 .83942 m .42422 .81595 L .44016 .79989 L p .56 .654 .898 r
F P
0 g
s
.36909 .71719 m .40176 .76097 L .37944 .7847 L p .464 .498 .808 r
F P
0 g
s
.42422 .81595 m .37944 .7847 L .40176 .76097 L p .513 .575 .855 r
F P
0 g
s
.71858 .51751 m .71264 .5607 L .63875 .5305 L p .842 .615 .595 r
F P
0 g
s
.63875 .5305 m .6424 .48554 L .71858 .51751 L p .842 .615 .595 r
F P
0 g
s
.45421 .43463 m .45512 .39776 L .55019 .39256 L p .661 .398 .512 r
F P
0 g
s
.72806 .68882 m .69976 .73194 L .66233 .70386 L p .871 .768 .746 r
F P
0 g
s
.66233 .70386 m .685 .65513 L .72806 .68882 L p .871 .768 .746 r
F P
0 g
s
.40176 .76097 m .44016 .79989 L .42422 .81595 L p .513 .575 .855 r
F P
0 g
s
.62178 .80757 m .57502 .83521 L .56401 .82796 L p .75 .792 .887 r
F P
0 g
s
.55019 .39256 m .55049 .42946 L .45421 .43463 L p .661 .398 .512 r
F P
0 g
s
.46606 .78726 m .49578 .82512 L .48247 .83138 L p .605 .661 .878 r
F P
0 g
s
.48247 .83138 m .44016 .79989 L .46606 .78726 L p .605 .661 .878 r
F P
0 g
s
.69976 .73194 m .66399 .77235 L .63387 .75073 L p .84 .78 .794 r
F P
0 g
s
.63387 .75073 m .66233 .70386 L .69976 .73194 L p .84 .78 .794 r
F P
0 g
s
.3742 .54388 m .38325 .59149 L .32414 .62508 L p .482 .363 .641 r
F P
0 g
s
.34315 .67114 m .32414 .62508 L .38325 .59149 L p .51 .42 .689 r
F P
0 g
s
.66399 .77235 m .62178 .80757 L .60056 .79301 L p .801 .789 .841 r
F P
0 g
s
.56401 .82796 m .60056 .79301 L .62178 .80757 L p .75 .792 .887 r
F P
0 g
s
.64337 .44465 m .6424 .48554 L .55029 .47081 L p .759 .51 .556 r
F P
0 g
s
.55029 .47081 m .55049 .42946 L .64337 .44465 L p .759 .51 .556 r
F P
0 g
s
.60056 .79301 m .56401 .82796 L .54874 .82289 L p .732 .754 .87 r
F P
0 g
s
.60056 .79301 m .63387 .75073 L .66399 .77235 L p .801 .789 .841 r
F P
0 g
s
.71264 .5607 m .70166 .60687 L .63201 .57926 L p .835 .641 .641 r
F P
0 g
s
.63201 .57926 m .63875 .5305 L .71264 .5607 L p .835 .641 .641 r
F P
0 g
s
.49911 .77967 m .51256 .82138 L .49578 .82512 L p .644 .675 .865 r
F P
0 g
s
.49578 .82512 m .46606 .78726 L .49911 .77967 L p .644 .675 .865 r
F P
0 g
s
.45421 .43463 m .45481 .47582 L .36929 .49971 L p .566 .355 .552 r
F P
0 g
s
.3742 .54388 m .36929 .49971 L .45481 .47582 L p .584 .399 .597 r
F P
0 g
s
.54874 .82289 m .57064 .78274 L .60056 .79301 L p .732 .754 .87 r
F P
0 g
s
.57064 .78274 m .54874 .82289 L .53092 .82061 L p .707 .722 .861 r
F P
0 g
s
.38325 .59149 m .39695 .64163 L .34315 .67114 L p .51 .42 .689 r
F P
0 g
s
.36909 .71719 m .34315 .67114 L .39695 .64163 L p .537 .477 .736 r
F P
0 g
s
.53542 .77809 m .53092 .82061 L .51256 .82138 L p .678 .695 .859 r
F P
0 g
s
.51256 .82138 m .49911 .77967 L .53542 .77809 L p .678 .695 .859 r
F P
0 g
s
.43887 .74216 m .46606 .78726 L .44016 .79989 L p .584 .594 .829 r
F P
0 g
s
.44016 .79989 m .40176 .76097 L .43887 .74216 L p .584 .594 .829 r
F P
0 g
s
.53092 .82061 m .53542 .77809 L .57064 .78274 L p .707 .722 .861 r
F P
0 g
s
.45481 .47582 m .45421 .43463 L .55049 .42946 L p .671 .437 .558 r
F P
0 g
s
.39695 .64163 m .41557 .69266 L .36909 .71719 L p .537 .477 .736 r
F P
0 g
s
.40176 .76097 m .36909 .71719 L .41557 .69266 L p .561 .534 .782 r
F P
0 g
s
.41557 .69266 m .43887 .74216 L .40176 .76097 L p .561 .534 .782 r
F P
0 g
s
.55049 .42946 m .55029 .47081 L .45481 .47582 L p .671 .437 .558 r
F P
0 g
s
.70166 .60687 m .685 .65513 L .62182 .63091 L p .825 .665 .685 r
F P
0 g
s
.62182 .63091 m .63201 .57926 L .70166 .60687 L p .825 .665 .685 r
F P
0 g
s
.63387 .75073 m .60056 .79301 L .57064 .78274 L p .769 .732 .819 r
F P
0 g
s
.6424 .48554 m .63875 .5305 L .54953 .51661 L p .76 .54 .599 r
F P
0 g
s
.54953 .51661 m .55029 .47081 L .6424 .48554 L p .76 .54 .599 r
F P
0 g
s
.45481 .47582 m .45707 .52133 L .3742 .54388 L p .584 .399 .597 r
F P
0 g
s
.38325 .59149 m .3742 .54388 L .45707 .52133 L p .599 .441 .64 r
F P
0 g
s
.48674 .73077 m .49911 .77967 L .46606 .78726 L p .64 .619 .813 r
F P
0 g
s
.46606 .78726 m .43887 .74216 L .48674 .73077 L p .64 .619 .813 r
F P
0 g
s
.685 .65513 m .66233 .70386 L .608 .68378 L p .811 .688 .728 r
F P
0 g
s
.608 .68378 m .62182 .63091 L .685 .65513 L p .811 .688 .728 r
F P
0 g
s
.66233 .70386 m .63387 .75073 L .59073 .73538 L p .793 .71 .773 r
F P
0 g
s
.57064 .78274 m .59073 .73538 L .63387 .75073 L p .769 .732 .819 r
F P
0 g
s
.45707 .52133 m .45481 .47582 L .55029 .47081 L p .679 .472 .599 r
F P
0 g
s
.59073 .73538 m .57064 .78274 L .53542 .77809 L p .73 .686 .808 r
F P
0 g
s
.59073 .73538 m .608 .68378 L .66233 .70386 L p .793 .71 .773 r
F P
0 g
s
.53957 .7284 m .53542 .77809 L .49911 .77967 L p .688 .649 .806 r
F P
0 g
s
.49911 .77967 m .48674 .73077 L .53957 .7284 L p .688 .649 .806 r
F P
0 g
s
.45707 .52133 m .46124 .57089 L .38325 .59149 L p .599 .441 .64 r
F P
0 g
s
.39695 .64163 m .38325 .59149 L .46124 .57089 L p .612 .483 .681 r
F P
0 g
s
.55029 .47081 m .54953 .51661 L .45707 .52133 L p .679 .472 .599 r
F P
0 g
s
.63875 .5305 m .63201 .57926 L .54813 .56657 L p .76 .569 .639 r
F P
0 g
s
.54813 .56657 m .54953 .51661 L .63875 .5305 L p .76 .569 .639 r
F P
0 g
s
.53542 .77809 m .53957 .7284 L .59073 .73538 L p .73 .686 .808 r
F P
0 g
s
.47608 .67773 m .48674 .73077 L .43887 .74216 L p .633 .57 .766 r
F P
0 g
s
.43887 .74216 m .41557 .69266 L .47608 .67773 L p .633 .57 .766 r
F P
0 g
s
.46124 .57089 m .46755 .62359 L .39695 .64163 L p .612 .483 .681 r
F P
0 g
s
.41557 .69266 m .39695 .64163 L .46755 .62359 L p .623 .525 .723 r
F P
0 g
s
.46755 .62359 m .47608 .67773 L .41557 .69266 L p .623 .525 .723 r
F P
0 g
s
.46124 .57089 m .45707 .52133 L .54953 .51661 L p .685 .506 .639 r
F P
0 g
s
.608 .68378 m .59073 .73538 L .53957 .7284 L p .744 .655 .762 r
F P
0 g
s
.63201 .57926 m .62182 .63091 L .54601 .61982 L p .757 .597 .679 r
F P
0 g
s
.54601 .61982 m .54813 .56657 L .63201 .57926 L p .757 .597 .679 r
F P
0 g
s
.54953 .51661 m .54813 .56657 L .46124 .57089 L p .685 .506 .639 r
F P
0 g
s
.54314 .67461 m .53957 .7284 L .48674 .73077 L p .691 .609 .759 r
F P
0 g
s
.48674 .73077 m .47608 .67773 L .54314 .67461 L p .691 .609 .759 r
F P
0 g
s
.62182 .63091 m .608 .68378 L .54314 .67461 L p .752 .625 .719 r
F P
0 g
s
.53957 .7284 m .54314 .67461 L .608 .68378 L p .744 .655 .762 r
F P
0 g
s
.54314 .67461 m .54601 .61982 L .62182 .63091 L p .752 .625 .719 r
F P
0 g
s
.46755 .62359 m .46124 .57089 L .54813 .56657 L p .689 .539 .677 r
F P
0 g
s
.54601 .61982 m .54314 .67461 L .47608 .67773 L p .691 .573 .717 r
F P
0 g
s
.47608 .67773 m .46755 .62359 L .54601 .61982 L p .691 .573 .717 r
F P
0 g
s
.54813 .56657 m .54601 .61982 L .46755 .62359 L p .689 .539 .677 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0MOooool=o`0002[ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0]ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0J?ooool<o`0000Wo@P0000Co0000ofD00?mU003oI@001_l0000Tooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Tooooo`Co0000
2Om2000?o`0000KoI@001Ol0000Oooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;?ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo4Ol0000;og/02P04o`000?nM6`CoWA/4oidK10Go00001_mU0004o`0001_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003ooooooooo
o`04ooooo`;o00004_ooool00ol0003oooooooooo`1Kooooo`So000000?o@@00o`000?mk00X05?mk
00X00ol0003oWA/4oidK1006oidK10Ko00001?mU0002o`0001Wooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Eoooool8o`0000?o@@0000?o0000og/02_mk00X05Omk00X0
0ol0003oWA/4oidK100;oidK10Go000000?oI@00o`000?l000005oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo02[ooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1Cooooo`So00001_m100000ol0003oN`0:og/02P0Eog/0
2P03o`000?nM6`CoWA/4013oWA/41_l0000Dooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0:Oooool0027ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo057ooooo1_l00009od400003o`000?mk00[oN`0:00WoN`0:4?l0000AoidK1003
o`000?n]8P3o000000?o00004_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wo
oooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool6o`0000So@@00
3ol0000<oi<^@@04o`000?ncASco/dHlok=6?0Ko00003?nM6`@00ol0003o[B80ojdR0004o`00013o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04cooooo1?l00008od4000?o00000_mV1C@00ol0003oTbi1
oi<^@@0Foi<^@@03o`000?ncASco/dHl00Oo/dHl1_l00007oidK1003o`000?n]8P3o[B8000;o[B80
0ol0000>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`19ooooo`?o00002?m10003o`0000GoIPDd00?o
0000oi<^@OnC;T405_nC;T400ol0003o/dHlok=6?00=ok=6?0Ko000000?oWA/4o`000?n]8P001On]
8P03o`0000cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2
o`0001[ooooo00?o0000ooooooooool0Aoooool3o`0000Ko@@000ol00008ofH5=003o`000?nC;T7o
Tbi101OoTbi100?o0000ok=6??ncAS`04_ncAS`4o`0000Ko[B800ol0000;ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`15ooooo`?o00001?m10003o`0000[oIPDd00?o0000oi<^@OnC;T406?nC;T400ol0
003o/dHlok=6?00Dok=6?004o`000?o;E2Co0000o`0000Ko[B800ol00009ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`Co00000_m10003o`0000goIPDd00?o0000oi<^@OnC;T404OnC;T4;o`00
01Co/dHl00?o0000ol]D9?o;E2@00ol00006ojdR00;o00001oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@?ooool7o`00013oIPDd00?o0000oi<^@OnC;T401?nC;T4=o`0000OoWdQP00Co0000ok]OGOnk
Gego^emM1Ol0000?ok=6?003o`000?o;E2Cobe@T00?obe@T0_l00006ojdR0003o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo03gooooo1_l0000AofH5=0Wo00005?nOB6000ol0003o
^emMok]OG@06ok]OG@Go00002oncAS`00ol0003obe@Tol]D9004ol]D90;o00001?n]8P02o`0000Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03_ooooo1?l000000olC00_o0000ofH5=00>ofH5=0?o0000
0_mi9eP00ol0003oWdQPoim8H00Hoim8H003o`000?nkGego^emM00_o^emM1Ol00006ok=6?003o`00
0?o;E2Cobe@T00Kobe@T0_l00003ojdR00;o00001?ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0003oooooooooo`0hooooo`Go000000?o
4`0;o`000?mV1C@02omV1C@4o`0000GoNBMH00?o0000oim8H?nOB6006?nOB6000ol0003o^emMok]O
G@0@ok]OG@Go000000?o/dHlo`000?o;E2@02Oo;E2@2o`0000;o[B800_l00003ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0eooooo`Go00000olC00/00ol0003oIPDdofH5=006ofH5=0Co00002?mi9eP0
0ol0003oWdQPoim8H00Ioim8H003o`000?nkGego^emM01Go^emM1?l0000:ol]D90Go00000_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0<oooool5o`0000?o4`0;00?o0000ofH5=?mV1C@01?mV1C@3o`00
00coNBMH00?o0000oim8H?nOB6006OnOB6000ol0003o^emMok]OG@0Gok]OG@04o`000?oELDoo0000
o`0000_obe@T0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo027ooooo000Xoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<Oooool4o`0000Co4`0;00Co0000ofH5
=?mV1CCoIPDd1?l0000?ogTWF003o`000?nOB63oWdQP01WoWdQP00?o0000ok]OGOnkGed05onkGed0
1?l0003oeG5?omEaCooELDl3o`0000[obe@T0ol0000looooo`03o`000?oooooooooo027ooooo000W
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;oooool3o`0000Ko4`0;1?l0000C
ogTWF003o`000?nOB63oWdQP01WoWdQP00?o0000ok]OGOnkGed06?nkGed00ol0003oeG5?omEaC`03
omEaC`;o00002?o;E2@00ol0003obTh0o`00000mooooo`03o`000?oooooooooo023ooooo000Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool3o`0000Go4`0;0ol0000FogTW
F003o`000?nOB63oWdQP01;oWdQP2ol0000Gok]OG@03o`000?oELDooeG5?00GoeG5?0_l00007ol]D
90?o0000??ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02_ooooo0_l00006oa<02`03o`000?lh03ko000001KoNBMH00?o0000oim8H?nO
B6001?nOB60?o`0000OoYEUd00Co0000okm^L_noKW;o_fib1Ol0000Bok]OG@03o`000?oELDooeG5?
00OoeG5?0_l00006ol]D9003o`000?o:CP3o000003cooooo00?o0000ooooooooool07oooool002Oo
oooo0_l0000Yooooo`03o`000?oooooooooo02Wooooo0_l00005oa<02`;o00000_lh03h00ol0003o
NBMHogTWF00BogTWF0Wo00005_nUFG@00ol0003o_fibokm^LP06okm^LPKo00003?nkGed00ol0003o
eG5?omEaC`09omEaC`;o00001?o;E2@01?l0003obTh0olY>0?l0000looooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003o
4`0;oa<02`04oa<02`05o`000?lh03ko>00nocP0?_l000004_mi9eP3o`0000;oQ3e_00?o0000ojEI
M?nUFG@06_nUFG@00ol0003o_fibokm^LP0<okm^LPKo00001_nkGed00ol0003oeG5?omEaC`0;omEa
C`?o000000?obe@To`000?l000000_o:CP000ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09Oooool00ol0003o
4`0;oa<02`03oa<02`;o00001?lh03h00ol0003oNBMHogTWF00<ogTWF0Co00001On4?Fl00ol0003o
YEUdojEIM00JojEIM003o`000?noKW;o_fib01;o_fib1Ol00002ok]OG@03o`000?oELDooeG5?00go
eG5?0ol00003olY>0003o`000?oooooooooo03Wooooo00?o0000ooooooooool07Oooool002Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`03o`000?lC00_o4`0;00;o4`0;
00?o0000ocP0?_lh03h01?lh03h00ol0003oNBMHogTWF008ogTWF0Co00002On4?Fl00ol0003oYEUd
ojEIM00JojEIM003o`000?noKW;o_fib01Oo_fib1?l0000?omEaC`?o00000oo:CP000ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08_ooool01?l0003o4`0;oa<02olC00/2o`0000Oo>00n00?o0000ogTWF?mi9eP0
1Omi9eP3o`0000goQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fibokm^LP0Iokm^LP04o`00
0?oHPVWo0000o`0000goeG5?00?o0000omEaCooELDl00_l00002olY>0003o`000?oooooooooo03So
oooo00?o0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Pooooo`05o`000?lC00_o4`0;oa<02ol000002Olh03h01?l0003oNBMHogTWF?mi9eP4o`00
013oQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fibokm^LP0Iokm^LP04o`000?oHPVWof89Y
omR2J@?o00002_oELDl01_l0003oeG5?omEaCol0003oiGXSo`0000;obTh000?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Kooooo`009_ooool3o`0002oooooo00?o0000ooooooooool07_oo
ool2o`000003oa<02ol0003o000000Wo>00n00?o0000ogTWF?l000000_l0000Doh@mK`03o`000?nU
FGCoYEUd01[oYEUd00?o0000okm^L_noKW806OnoKW800ol0003of89YomR2J@04omR2J@;o00002OoE
LDl01_l0003oeG5?omEaCol0003oiGXSo`0000;obTh000?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo
00?o0000oa<02ol000002_lh03h3o`0001OoQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fib
okm^LP0Iokm^LP03o`000?oHPVWof89Y00Kof89Y0_l00007omEaC`04o`000?oELDooeG5?o`0000;o
iGXS00Co0000olY>0?o:CP3o0000>Oooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01_ooooo0ol0000:ocP0?P03o`000?m>45oo
000001SoQ3e_00?o0000ojEIM?nUFG@04onUFG@;o`0001So_fib00?o0000omR2JOoHPVT02?oHPVT3
o`0000CoeG5?00Co0000omEaCooELDoo00000ooUNR<01?l0003obTh0olY>0?l0000hooooo`03o`00
0?oooooooooo01[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
0_l0000:ocP0?P;o00000_m>45l00ol0003oQ3e_oh@mK`0Foh@mK`03o`000?nUFGCoYEUd00CoYEUd
3ol00007ojUUP`04o`000?o1NH;o`GV2ol5iPPKo00004onoKW800ol0003of89YomR2J@0:omR2J@;o
00000_oELDl01Ol0003oeG5?omEaCooELDoo000000?oiGXS00Co0000olY>0?o:CP3o0000>?ooool0
0ol0003oooooooooo`0Iooooo`000oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0H
ooooo`03o`000?lh03ko>00n00So>00n00?o0000odh@Gom>45l00_m>45l00ol0003oQ3e_oh@mK`0D
oh@mK`Wo00005_nYIH<00ol0003o`GV2ol5iPP07ol5iPPKo00003OnoKW800ol0003of89YomR2J@0<
omR2J@?o00000ooELDl00ol0003oiGXSonEj8`02onEj8`03o`000?o:CP3o000003Wooooo00?o0000
ooooooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`;o00002?lh03h2
o`0000CoCQ1O00?o0000oh@mKon4?Fl04_n4?Fl3o`0000;oRdf000?o0000ojUUPonYIH<06_nYIH<0
0ol0003o`GV2ol5iPP0=ol5iPPGo00002?noKW800ol0003of89YomR2J@0>omR2J@?o000000?oeG5?
o`000?oUNR<01?oUNR<00ol0003obTh0o`00000hooooo`03o`000?oooooooooo01Sooooo000;oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`;o00002?lh03h00ol0003oCQ1Oodh@
G`04odh@G`03o`000?n4?FooQ3e_00ooQ3e_0ol00005oh]=P003o`000?nYIH?oZFF301[oZFF300?o
0000ol5iP_o1NH804_o1NH86o`0000;o_fib00?o0000omR2JOoHPVT03_oHPVT00ol0003of89YomR2
J@03o`0000GoiGXS00?o0000olY>0?l00000>?ooool00ol0003oooooooooo`0Gooooo`002oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o
0000ooooooooool04_ooool3o`0000Ko>00n0_l00007odh@G`03o`000?n4?FooQ3e_00_oQ3e_1?l0
0008oh]=P003o`000?nYIH?oZFF301[oZFF300?o0000ol5iP_o1NH806?o1NH84o`0000oof89Y00?o
0000omR2JOoHPVT00_oHPVT2o`0000GoiGXS0_l0000hooooo`03o`000?oooooooooo01Oooooo000;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool04Oooool3o`0000Co>00n0_l00009odh@G`03o`000?n4
?FooQ3e_00SoQ3e_0ol0000<oh]=P003o`000?nYIH?oZFF301[oZFF300?o0000ol5iP_o1NH806_o1
NH800ol0003ofHelo`000002o`0000cof89Y00?o0000omR2JOoHPVT00_oHPVT00ol0003oki=>o`00
0005onEj8`;o0000>?ooool00ol0003oooooooooo`0Fooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03ooo
ool3o`0000Co>00n00?o0000odh@Gom>45l02Om>45l00ol0003oQ3e_oh@mK`04oh@mK`Co00003on;
CH000ol0003oZFF3ojUUP`0JojUUP`03o`000?o1NH;o`GV201[o`GV200?o0000omV=O?oISG`00_oI
SG`2o`0000[of89Y00?o0000omR2JOoHPVT00_oHPVT01?l0003oki=>onnCC_l00005onEj8`03o`00
0?oooooooooo03Gooooo0ol0000Gooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo00kooooo1?l00002ocP0?P;o00002om>45l00ol0003oQ3e_oh@mK`02oh@mK`?o00004_n;
CH000ol0003oZFF3ojUUP`0KojUUP`03o`000?o1NH;o`GV201[o`GV200?o0000omV=O?oISG`01?oI
SG`2o`0000Sof89Y00?o0000omR2JOoHPVT00ooHPVT01?l0003oki=>onnCC_l00005onEj8`03o`00
0?oooooooooo037ooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03Oooool3o`0000;o>00n00?o0000odh@Gom>45l02om>
45l00ol0003oQ3e_o`000002o`0001GoRdf000?o0000ojUUPonYIH<06onYIH<00ol0003o`GV2ol5i
PP0Jol5iPP03o`000?oISGcofHel00KofHel0ol00005omR2J@03o`000?oHPVWof89Y00?of89Y00Go
0000onnCC_o_Tdkoki=>o`000005onEj8`03o`000?oooooooooo02gooooo0ol00005ooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02ooo
ool6o`0000goCQ1O0ol0000Hoh]=P003o`000?nYIH?oZFF301_oZFF300?o0000ol5iP_o1NH806_o1
NH800ol0003ofHelomV=O009omV=O0;o00000ooHPVT00ol0003of89YomR2J@03omR2J@03o`000?o_
Tdkoki=>00;oki=>00?o0000onEj8ooUNR<00_oUNR<00ol0003oooooooooo`0Zooooo`?o00002?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00Wooooo1Ol0000=odh@G`;o000000?oGRUfo`000?n;CH006?n;CH000ol0003oZFF3ojUUP`0K
ojUUP`03o`000?o1NH;o`GV201_o`GV200?o0000omV=O?oISG`02_oISG`4o`0000Gof89Y00?o0000
onnCC_o_Tdh00oo_Tdh00ol0003oiGXSonEj8`02onEj8`03o`000?oooooooooo02Kooooo0ol0000;
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool00ol0003oooooooooo`08oooo
o`Co00003Om>45l01Ol0003oGRUfoehYM_mN:GKo000001WoRdf000?o0000ojUUPonYIH<03?nYIH<D
o`0001Wo`GV200?o0000omV=O?oISG`03OoISG`2o`0000Cof89Y00?o0000onnCC_o_Tdh01?o_Tdh0
1Ol0003oiGXSonEj8ooUNR?o000002Gooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000T
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_ooool5o`0000_oCQ1O0_l00004
oehYMP03o`000?n;CH3oRdf001GoRdf04Ol0000?oj]_SP03o`000?o2PXko`X:>00;o`X:>1ol0000B
ol5iPP03o`000?oISGcofHel00gofHel00Co0000omV=O?l0003o00000ooHPVT00ol0003oki=>onnC
CP04onnCCP03o`000?oUNR?oiGXS00;o00008Oooool3o`0001;ooooo00?o0000ooooooooool05?oo
ool002?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`04ooooo`Ko00002Om>45l2
o`0000KoGRUf00?o0000oh]=P?n;CH004_n;CH03o`0000;oT5Z=00?o0000oj]_S_n[Khh06on[Khh0
0ol0003o`X:>ol:2SP09ol:2SPSo00002_o1NH800ol0003ofHelomV=O00=omV=O004o`000?oISGco
fHelomV=O0Co00001oo_Tdh01?l0003oiGXSonEj8ol0000Nooooo`?o00005Oooool00ol0003ooooo
ooooo`0Dooooo`008oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00?ooooo1Ol0
0009odh@G`03o`000?mN:GKoGRUf00KoGRUf00?o0000oh]=P?n;CH003on;CH03o`0000GoT5Z=00?o
0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Aol:2SPOo00000oo1NH800ol0003ofHelomV=
O00=omV=O003o`000?oISGcofHel00CofHel0_l00007onnCCP03o`000?oUNR?o000001_ooooo0ol0
000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04?ooooo00Co0000
oooooooooooooooo1?l000000ol002oo0000odh@G`06odh@G`;o00002?mN:GH00ol0003oRdf0oh]=
P00<oh]=P0Co00002?n@FXd00ol0003oZfn>oj]_SP0Koj]_SP03o`000?o2PXko`X:>01So`X:>1Ol0
000?omV=O003o`000?oISGcofHel00?ofHel00?o0000oo6SJol000001oo_Tdh00ol0003oiGXSo`00
000Gooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooo000000Co000000?o000_o`000?m>45l01?m>45l2o`0000[oGRUf00?o0000
oh]=P?n;CH002On;CH03o`0000coT5Z=00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0K
ol:2SP04o`000?oHUX_o0000o`0000gofHel00?o0000omV=O?oISG`00ooISG`01?l0003olJ=[oo6S
Jol00007onnCCP;o00005?ooool3o`0001kooooo00?o0000ooooooooool05?ooool002?ooooo00?o
0000ooooooooool0AOooool5o`0000;o000_00?o0000odh@Gom>45l00_m>45l00ol0003oGRUfoehY
MP0:oehYMP03o`000?n;CH3oRdf000GoRdf01?l0000?oi1JS@03o`000?n[KhkoZfn>01_oZfn>00?o
0000ol:2S_o2PXh06oo2PXh01?l0003of9J;omRFRooHUX/2o`0000_ofHel00?o0000omV=O?oISG`0
0ooISG`01Ol0003olJ=[oo6SJooaXf_o000000Ooki=>0_l0000@ooooo`?o00008Oooool00ol0003o
ooooooooo`0Dooooo`008oooool2o`0004Kooooo1?l00003o`00;`03o`000?m>45ooCQ1O00;o0000
3OmN:GH00ol0003oRdf0oh]=P002oh]=P0?o00004on@FXd00ol0003oZfn>oj]_SP0Koj]_SP03o`00
0?o2PXko`X:>01_o`X:>00?o0000omRFRooHUX/00ooHUX/3o`0000SofHel00?o0000omV=O?oISG`0
0ooISG`00ol0003olJ=[oo6SJ`02oo6SJ`03o`000?o_Tdkoki=>00Goki=>00?o0000ooooooooool0
2oooool3o`0002Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0AOoo
ool3o`0000?o000_00Co0000odh@Gol0003o00003omN:GH00ol0003oRdf0o`000002o`0001KoT5Z=
00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Kol:2SP03o`000?oHUX_of9J;00Kof9J;
0_l00006omV=O003o`000?oISGcofHel00?ofHel00?o0000oo6SJooaXf/00ooaXf/00ol0003oki=>
onnCCP04onnCCP;o00002Oooool3o`0002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o
0000ooooooooool0A_ooool3o`0000?o000_0_l0000@oehYMP?o00006On@FXd00ol0003oZfn>oj]_
SP0Koj]_SP03o`000?o2PXko`X:>01_o`X:>00?o0000omRFRooHUX/02?oHUX/2o`0000CofHel00?o
0000omV=O?oISG`00ooISG`00ol0003olJ=[oo6SJ`04oo6SJ`03o`000?o_Tdkoki=>00?oki=>0_l0
0006ooooo`?o0000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`15
ooooo`?o00001?l002l00ol0003oGRUfoehYMP0>oehYMP03o`000?mY?8Oo000001[oT5Z=00?o0000
oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Kol:2SP03o`000?oHUX_of9J;00[of9J;0_l00002
omV=O003o`000?oISGcofHel00CofHel00?o0000oo6SJooaXf/01?oaXf/00ol0003oki=>onnCCP03
onnCCP04o`000?ooooooooooooooo`?o0000;_ooool00ol0003oooooooooo`0Cooooo`008_ooool0
0ol0003oooooooooo`15ooooo`;o00001Ol002l00ol0003oGRUfoehYMP0<oehYMP;o00000_mY?8L0
0ol0003oT5Z=oi1JS@0Hoi1JS@03o`000?n[KhkoZfn>01_oZfn>00?o0000ol:2S_o2PXh06_o2PXh0
0ol0003of9J;omRFR`0=omRFR`?o00001_oISG`00ol0003olJ=[oo6SJ`05oo6SJ`03o`000?o_Tdko
ki=>00;oki=>1?l0000aooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
04Cooooo0ol00004o`00;`;o00003OmN:GH00ol0003oJCb7ofTlQ`02ofTlQ`03o`000?n@FXgoT5Z=
01SoT5Z=00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Jol:2SP03o`000?oHUX_of9J;
00oof9J;0ol00004omV=O003o`000?oaXf_olJ=[00KolJ=[00Co0000onnCC_o_Tdkoki=>0_l0000c
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04Cooooo0_l00004o`00
;`03o`000?l405Oo000000_oGRUf0_l00005ofTlQ`03o`000?n@FXgoT5Z=01SoT5Z=00?o0000oj]_
S_n[Khh03?n[KhhDo`0001So`X:>00?o0000omRFRooHUX/03ooHUX/00ol0003of9J;omRFR`02o`00
00;ofHel00?o0000oo6SJooaXf/01ooaXf/01?l0003oki=>onnCC_o_Tdh2o`0003;ooooo00?o0000
ooooooooool04oooool0027ooooo0ol00015ooooo`03o`000?l002oo000_00;o000_00Co0000o`@0
Eol405Oo00002_mN:GH00ol0003oJCb7ofTlQ`05ofTlQ`03o`000?n@FXgoT5Z=01KoT5Z=4Ol0000?
ojehV@03o`000?o2RYWo`XZI00;o`XZI1ol0000Aol:2SP03o`000?oHUX_of9J;00oof9J;00?o0000
omRFRooHUX/00_oHUX/3o`0000[olJ=[00?o0000onnCC_o_Tdh00_l0000cooooo`03o`000?oooooo
oooo01;ooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000o`00;ol002l00ol002l01?l0
003o101Go`@0Eol00008oehYMP;o00002?mY?8L00ol0003oT5Z=oi1JS@0Coi1JS@?o00000_nEIYP0
0ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI00Wo`XZI1ol0000:ol:2SP03o`000?oHUX_o
f9J;00oof9J;00?o0000omRFRooHUX/01?oHUX/2o`0000[olJ=[00?o0000onnCC_l000000_l0000b
ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000o`00
;ol002l00_l002l01Ol0003o101Go`@0Eol405Oo000000KoGRUf0_l0000;ofTlQ`03o`000?n@FXgo
T5Z=00ooT5Z=0ol00005oiEVV003o`000?n]N9Wo[GRI01_o[GRI00?o0000ol::VOo2RYT04?o2RYT7
o`0000?o`X:>00?o0000omRFRooHUX/03ooHUX/00ol0003of9J;omRFR`04omRFR`03o`000?oa[H7o
000000[olJ=[0_l000000ooGQP3o0000ooooo`0aooooo`03o`000?oooooooooo01;ooooo000Qoooo
o`03o`000?oooooooooo04Cooooo00Go0000o`00;ol002oo000_o`000003o`@0E`03o`000?mN:GKo
GRUf00CoGRUf00?o0000ofTlQomY?8L02omY?8L00ol0003oT5Z=oi1JS@0<oi1JS@?o00002?nEIYP0
0ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01Oo`XZI1Ol0000@omRFR`03o`000?oHUX_o
f9J;00Cof9J;00Co0000oo6]POoa[H7o00002_oaXf/3o`0003;ooooo00?o0000ooooooooool04_oo
ool0027ooooo00?o0000ooooooooool0@oooool01Ol0003o000_o`00;ol002oo000000Co101G00?o
0000oehYM_mN:GH00_mN:GH2o`0000koJCb700?o0000oi1JSOn@FXd02?n@FXd4o`0000_oUFJH00?o
0000ojehVOn]N9T06on]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISo000000;o00003OoH
UX/00ol0003of9J;omRFR`04omRFR`05o`000?oa[H7olJf1oo6]POl000002_oaXf/00ol0003oehH0
o`00000aooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04?ooooo00Go
0000o`00;ol002oo000_o`000004o`@0E`05o`000?mN:GKoGRUfoehYM_l000004?mY?8L00ol0003o
T5Z=oi1JS@05oi1JS@?o00003onEIYP00ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01[o
`XZI00?o0000omNMV?oGWIP00_oGWIP2o`0000_of9J;00?o0000omRFRooHUX/01?oHUX/00ol0003o
lJf1oo6]P@02oo6]P@03o`000?oaXf_olJ=[00OolJ=[00?o0000omN60?l00000<Oooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`13ooooo`04o`000?l002oo000_o`0000Go
101G00Co0000oehYM_l0003o00004OmY?8L00ol0003oT5Z=oi1JS@02oi1JS@?o00004_nEIYP00ol0
003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01[o`XZI00?o0000omNMV?oGWIP01?oGWIP2o`00
00Wof9J;00?o0000omRFRooHUX/01?oHUX/00ol0003olJf1oo6]P@03oo6]P@03o`000?oaXf_olJ=[
00KolJ=[1?l0000`ooooo`03o`000?oooooooooo01;ooooo000Pooooo`?o0000@oooool01?l0003o
000_o`00;ol00006o`@0E`;o00004omY?8L00ol0003oT5Z=o`000002o`0001GoUFJH00?o0000ojeh
VOn]N9T06on]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00KoeifH0ol00006omRF
R`03o`000?oHUX_of9J;00Cof9J;00?o0000oo6]POoa[H401?oa[H400ol0003olJ=[oo6SJ`05oo6S
J`;o000000?oehH0o`000?ooool0<?ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003o
ooooooooo`13ooooo`03o`000?l002oo000000Oo101G00?o0000ofTlQomY?8L04OmY?8L3o`0001Wo
UFJH00?o0000ojehVOn]N9T06_n]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00Wo
eifH0_l00005omRFR`03o`000?oHUX_of9J;00;of9J;00?o0000oo6]POoa[H401_oa[H42o`0000Go
lJ=[0_l000000ooGQP3o0000ooooo`0`ooooo`03o`000?oooooooooo017ooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`13ooooo`03o`000?l002oo000000Oo
101G00?o0000ofTlQomY?8L03omY?8L2o`000003og==U_l0003oUFJH01WoUFJH00?o0000ojehVOn]
N9T06_n]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00_oeifH0ol00002omRFR`03
o`000?oHUX_of9J;00;of9J;00?o0000oo6]POoa[H402?oa[H400ol0003olJ=[oo6SJ`02oo6SJ`05
o`000?o`ZS;o0000omN60?l00000<?ooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0@oooool2o`0000Oo101G0_l0000@ofTl
Q`05o`000?mcCIKoLdfFog==U_l000006_nEIYP00ol0003o[GRIojehV@0JojehV@03o`000?o2RYWo
`XZI01[o`XZI00?o0000omNMV?oGWIP03_oGWIP3o`0000Cof9J;00?o0000oo6]POoa[H402Ooa[H40
0ol0003olJ=[oo6SJ`02oo6SJ`;o000000?oehH0o`000?ooool0;oooool00ol0003oooooooooo`0A
ooooo`005Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0@_ooool2
o`0000Oo101G00?o0000oal6MOl000003_mY?8L2o`0000CoLdfF00?o0000oiEVV?nEIYP06?nEIYP0
0ol0003o[GRIojehV@0JojehV@03o`000?o2RYWo`XZI01Wo`XZI00?o0000omNMV?oGWIP04OoGWIP2
o`0000?of9J;00?o0000oo6]POoa[H402_oa[H401?l0003olJ=[oo6SJooaXf/2o`000003omN60?l0
003ooooo02oooooo00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo04;ooooo00?o0000o`@0Eol405L01Ol405L01?l0003o7`Ieoal6
MOl0000<ofTlQ`;o00001_mcCIH00ol0003oUFJHoiEVV00HoiEVV003o`000?n]N9Wo[GRI01[o[GRI
00?o0000ol::VOo2RYT06Oo2RYT00ol0003oeifHomNMV00AomNMV003o`000?oGWISo000000?o0000
3Ooa[H401Ol0003olJ=[oo6SJol0003ol:Xb00;o0000<?ooool00ol0003oooooooooo`0Aooooo`00
5Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0@oooool00ol0003o
101Go`@0E`05o`@0E`04o`000?lO1WGo7`Ieo`0000_oJCb700?o0000og==U_mcCIH01_mcCIH00ol0
003oUFJHoiEVV00HoiEVV003o`000?n]N9Wo[GRI00co[GRI4ol0000Gol::V@03o`000?oGWISoeifH
017oeifH00?o0000omNMV?oGWIP00_oGWIP2o`0000golJf100Oo0000oo6SJol0003ol:Xbo`000?oG
QP3o000002oooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@
4005ooooo`;o0000A?ooool00ol0003o101Go`@0E`04o`@0E`05o`000?lO1WGo7`Ieoal6MOl00000
2OmY?8L2o`0000WoLdfF00?o0000oiEVV?nEIYP05_nEIYPAo`0000ko[h6S00?o0000ol:AXoo2TJ<0
0_o2TJ<7o`00013o`XZI00?o0000omNMV?oGWIP04OoGWIP00ol0003oeifHomNMV002omNMV003o`00
0?o^]I?o000000golJf10_l00002oo2Z<P;o0000;oooool00ol0003oooooooooo`0Aooooo`005Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0@oooool00ol0003o101G
o`@0E`03o`@0E`03o`000?lO1WGo7`Ie00?o7`Ie00?o0000ofTlQomY?8L01?mY?8L2o`0000_oLdfF
00?o0000oiEVV?nEIYP04onEIYP3o`0000;oVG2S00?o0000ojn1Xon_PJ<06_n_PJ<00ol0003o`Y6S
ol:AX`09ol:AX`Oo00002Oo2RYT00ol0003oeifHomNMV00AomNMV003o`000?oGWISoeifH00;oeifH
00Co0000onjeToo^]I?o00003Ooa[H400ol0003ol:Xboo2Z<P02o`00033ooooo00?o0000oooooooo
ool04?ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo04?o
oooo00?o0000o`@0Eol405L00_l405L00ol0003o7`Ieoal6M@04oal6M@03o`000?mY?8OoJCb700?o
JCb700?o0000og==U_mcCIH03?mcCIH00ol0003oUFJHoiEVV00?oiEVV0?o00001OnIL:<00ol0003o
[h6Sojn1X`0Jojn1X`03o`000?o2TJ?o`Y6S013o`Y6S1ol00002ol::V@03o`000?oGWISoeifH017o
eifH00?o0000omNMV?oGWIP00_oGWIP01Ol0003ok[FConjeToo^]I?o000000colJf100?o0000oo2Z
<_o`ZS800_l0000`ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo04;o
oooo0_l00004o`@0E`03o`000?lO1WGo7`Ie00Co7`Ie00Co0000ofTlQomY?8OoJCb70_l0000?og==
UP03o`000?nEIYSoUFJH00coUFJH0ol00008oiU`X`03o`000?n_PJ?o[h6S01[o[h6S00?o0000ol:A
Xoo2TJ<05oo2TJ<4o`0001;oeifH00Go0000omNMV?oGWISoeifHo`000005onjeT`03o`000?oa[H7o
lJf100WolJf10_l00002oo2Z<P03o`000?oooooooooo02kooooo00?o0000ooooooooool04?ooool0
01oooooo00?o0000ooooooooool0@_ooool2o`0000?o101G00?o0000oal6MOlO1WD01OlO1WD01?l0
003oJCb7o`000?l0000Aog==UP03o`000?nEIYSoUFJH00SoUFJH1?l0000;oiU`X`03o`000?n_PJ?o
[h6S01[o[h6S00?o0000ol:AXoo2TJ<06Oo2TJ<01?l0003oeJBTo`000?l0000@omNMV005o`000?oG
WISoeifHomNMV?l000001_o^]I<00ol0003olJf1oo6]P@08oo6]P@;o00000_o`ZS82o`0002oooooo
00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0@_ooool2o`0000;o101G00?o
0000oal6MOlO1WD01_lO1WD2o`0001?oLdfF00?o0000oiEVV?nEIYP01OnEIYP3o`00013oVG2S00?o
0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6Sol:AX`0Iol:AX`04o`000?oEY:CoeJBTomFTY0?o0000
3OoGWIP01Ol0003oeifHomNMV?oGWISo000000Ook[FC00?o0000oo6]POoa[H401ooa[H42o`0000;o
l:Xb0_l0000_ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo04?ooooo
0_l00002o`@0E`03o`000?lO1WGo7`Ie00Ko7`Ie00?o0000og==U_mcCIH04_mcCIH00ol0003oUFJH
oiEVV002oiEVV0?o00004onIL:<00ol0003o[h6Sojn1X`0Iojn1X`03o`000?o2TJ?o`Y6S01Wo`Y6S
00?o0000omFTY?oEY:@01?oEY:@2o`0000_oeifH00Go0000omNMV?oGWISoeifHo`000008onjeT`;o
00001ooa[H400ol0003oo<5Mo`000002oo2Z<P03o`000?oooooooooo02gooooo00?o0000oooooooo
ool04?ooool001kooooo00?o0000ooooooooool0@oooool2o`000003o`@0Eol0003o7`Ie00So7`Ie
00?o0000og==U_mcCIH04_mcCIH00ol0003oUFJHo`000002o`0001KoVG2S00?o0000ojn1Xon_PJ<0
6On_PJ<00ol0003o`Y6Sol:AX`0Iol:AX`03o`000?oEY:CoeJBT00KoeJBT0_l00009omNMV005o`00
0?oGWISoeifHomNMV?l000002_o^]I<00ol0003olJf1oo6]P@04oo6]P@03o`000?ol`Ego000000;o
l:Xb00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`007_ooool2o`0004Cooooo
0ol00009oal6M@;o00004omcCIH3o`0001WoVG2S00?o0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6S
ol:AX`0Hol:AX`03o`000?oEY:CoeJBT00WoeJBT0ol00006omNMV005o`000?oGWISoeifHomNMV?l0
00002oo^]I<00ol0003olJf1oo6]P@02oo6]P@04o`000?ol`Egoo<5Mo`0000;ol:Xb00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o
00002OlO1WD00ol0003o=R>=o`00000Aog==UP;o000000?oNebTo`000?nIL:<06OnIL:<00ol0003o
[h6Sojn1X`0Iojn1X`03o`000?o2TJ?o`Y6S01So`Y6S00?o0000omFTY?oEY:@03?oEY:@2o`0000Co
eifH00Go0000omNMV?oGWISoeifHo`00000<onjeT`05o`000?oa[H7olJf1oo6]POl000000ool`Ed0
0ol0003ol:Xbo`00000`ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l00008oal6M@05o`000?lf8hgo=R>=ocHSSOl000003omcCIH01Ol0003oNebTog]LY?mk
G:Co000001[oVG2S00?o0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6Sol:AX`0Hol:AX`03o`000?oE
Y:CoeJBT00koeJBT0_l00002omNMV004o`000?oGWISoeifHo`0000kok[FC00Co0000oo6]POoa[H7o
00000ool`Ed00ol0003ol:Xbo`00000`ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`00
0?oooooooooo04;ooooo0ol00007oal6M@03o`000?lf8hgo=R>=00;o=R>=00?o0000og==U_mcCIH0
2omcCIH2o`0000GoNebT00?o0000oiU`XonIL:<05onIL:<00ol0003o[h6Sojn1X`0Iojn1X`03o`00
0?o2TJ?o`Y6S01So`Y6S00?o0000omFTY?oEY:@04?oEY:@3o`0000;oeifH00?o0000onjeToo^]I<0
3Oo^]I<00ol0003olJf1o`000004ooc1G@;o0000<?ooool00ol0003oooooooooo`0?ooooo`007Ooo
ool00ol0003oooooooooo`13ooooo`?o00001olO1WD00ol0003o=R>=ocHSS@02ocHSS@03o`000?mc
CIKoLdfF00WoLdfF0_l00007og]LY003o`000?nIL:?oVG2S01OoVG2S00?o0000ojn1Xon_PJ<06On_
PJ<00ol0003o`Y6Sol:AX`0Hol:AX`03o`000?oEY:CoeJBT01;oeJBT1?l0000@onjeT`;o00001?ol
`Ed00ol0003ol:Xbo`00000_ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo04?ooooo0ol00006oal6M@03o`000?lf8hgo=R>=00?o=R>=00?o0000og==U_mcCIH01omcCIH2
o`0000WoNebT00?o0000oiU`XonIL:<06?nIL:<00ol0003o[h6Sojn1X`0Hojn1X`03o`000?o2TJ?o
`Y6S01So`Y6S00?o0000omFTY?oEY:@04ooEY:@01?l0003oeJBTo`000?l0000@onjeT`03o`000?ol
`Egoo<5M00;oo<5M00?o0000oo2Z<_l00000;oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`13ooooo`?o00001OlO1WD00ol0003o=R>=ocHSS@04ocHSS@03o`000?mcCIKo
LdfF00KoLdfF00?o0000og]LY?mkG:@02OmkG:@00ol0003oVG2SoiU`X`0HoiU`X`03o`000?n_PJ?o
[h6S01So[h6S00?o0000ol:AXoo2TJ<06?o2TJ<00ol0003oeJBTomFTY00ComFTY005o`000?oEY:Co
0000onZkXol000003oo^]I<00ol0003oo<5Mooc1G@03ooc1G@;o0000;oooool00ol0003ooooooooo
o`0?ooooo`007Oooool2o`0004Cooooo0ol00004oal6M@03o`000?lf8hgo=R>=00Go=R>=00?o0000
og==U_mcCIH01?mcCIH2o`0000coNebT00?o0000oiU`XonIL:<06?nIL:<00ol0003o[h6Sojn1X`0;
ojn1Xa7o00005oo2TJ<00ol0003oeJBTomFTY00ComFTY003o`000?oEY:Co000000;oj[^S00?o0000
onjeToo^]I<03?o^]I<2o`0000Coo<5M0_l0000`ooooo`03o`000?oooooooooo00kooooo000Moooo
o`03o`000?oooooooooo04?ooooo0ol00003oal6M@03o`000?lf8hgo=R>=00Ko=R>=00?o0000og==
U_mcCIH00_mcCIH2o`0000ooNebT00?o0000oiU`XonIL:<05OnIL:<@o`0000go/8V]00Co0000ol6H
[Oo1V:go`IR]1ol0000?ol:AX`03o`000?oEY:CoeJBT01CoeJBT0_l00004onZkX`03o`000?o^]I?o
k[FC00_ok[FC0_l00004ooc1G@;o0000<?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0
003oooooooooo`13ooooo`?o00000olO1WD00ol0003o=R>=ocHSS@07ocHSS@04o`000?mcCIKoLdfF
o`00017oNebT00?o0000oiU`XonIL:<04OnIL:<4o`0000;oW7^^00?o0000ok29[On`RJd06?n`RJd0
0ol0003o`IR]ol6H[@08ol6H[@Ko00002Oo2TJ<00ol0003oeJBTomFTY00DomFTY0;o00001OoZ^j<2
o`0000[ok[FC00Co0000ooo@P?ood83o00001?ol`Ed00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo04Cooooo00?o0000o`00<?l000000_lO1WD0
0ol0003o=R>=ocHSS@08ocHSS@?o00004_mkG:@00ol0003oVG2SoiU`X`0=oiU`X`Co00001_nLNjh0
0ol0003o/8V]ok29[@0Hok29[@03o`000?o1V:go`IR]00ko`IR]1ol00002ol:AX`03o`000?oEY:Co
eJBT01CoeJBT0_l00007onZkX`03o`000?o^]I?ok[FC00Ook[FC00Co0000ooo@P?ood83o00001?ol
`Ed00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooo
oooo04Cooooo00Go0000o`00<?l0003o7`Ieo`00000;ocHSS@03o`000?mkG:CoNebT01;oNebT00?o
0000oiU`XonIL:<02?nIL:<5o`0000[oW7^^00?o0000ok29[On`RJd06?n`RJd00ol0003o`IR]ol6H
[@0Eol6H[@Co00005OoEY:@2o`0000Soj[^S00?o0000onjeToo^]I<01_o^]I<01?l0003oom20ooo@
P?l00004ooc1G@03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool0A?ooool01?l0003o000`o`000?l0000<ocHSS@03o`000?mkG:CoNebT01;oNebT
00?o0000oiU`XonIL:<01?nIL:<4o`0000ooW7^^00?o0000ok29[On`RJd06?n`RJd00ol0003o`IR]
ol6H[@0Gol6H[@03o`000?oCZZoo000000;o00004_oEY:@2o`0000Woj[^S00?o0000onjeToo^]I<0
1Oo^]I<01Ol0003oom20ooo@P?ood83o000000?oo<5M00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`14ooooo`03o`000?l0033o000000co=R>=
0_l0000Eog]LY003o`000?nIL:?o000000?o00004onLNjh00ol0003o/8V]ok29[@0Hok29[@03o`00
0?o1V:go`IR]01Oo`IR]00?o0000om>Z[ooCZZl00_oCZZl3o`0000goeJBT0ol0000;onZkX`03o`00
0?o^]I?ok[FC00Cok[FC00Go0000ooo@P?ood83oom20o`000003ooc1G@03o`000?oooooooooo02ko
oooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0A?ooool00ol0003o000`
o`00000;ocHSS@04o`000?m9?J7oBCfQo`0001?oNebT0ol0000Goiak[P03o`000?n`RJgo/8V]01So
/8V]00?o0000ol6H[Oo1V:d05oo1V:d00ol0003odjZ_om>Z[`05om>Z[`?o00001ooEY:@3o`0000;o
eJBT00?o0000onZkXooZ^j<02_oZ^j<2o`0000Cok[FC00?o0000ooo@P?ood8000_ood8001?l0003o
o<5Mooc1GOl0000aooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000AOooool00ol0003o
000`o`00000:ocHSS@05o`000?m9?J7oBCfQodTmXOl000004_mkG:@00ol0003oPV^`o`00000Hoiak
[P03o`000?n`RJgo/8V]01So/8V]00?o0000ol6H[Oo1V:d05_o1V:d00ol0003odjZ_om>Z[`09om>Z
[`;o00000_oEY:@3o`0000GoeJBT0_l0000=onZkX`05o`000?o^]I?ok[FConjeTol000001?ood800
1?l0003oo<5Mooc1GOl0000aooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooo
oooo04Gooooo00Co0000o`00<?l006;o00002?lf8hd00ol0003oBCfQodTmX@02odTmX@03o`000?mk
G:CoNebT00koNebT0_l00002oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o0000ok29[On`RJd05on`
RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00[odjZ_1?l00007omFTY003o`000?oZ
^j?o000000goj[^S00?o0000onjeTol000001_ood8000ol0003oo<5Mo`00000aooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo04Gooooo00Co0000o`00<?l006;o00002?lf
8hd00ol0003oBCfQodTmX@03odTmX@03o`000?mkG:CoNebT00_oNebT0_l00005oh9[/003o`000?nL
NjkoW7^^01KoW7^^00?o0000ok29[On`RJd05_n`RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oC
ZZoodjZ_00KodjZ_1?l00004om>Z[`?o00001?oEY:@01?l0003oj[^SonZkXol0000=onZkX`;o0000
1_ood8000ol0003oo<5Mo`00000aooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oo
oooooooo04Gooooo0_l000000ol006;o0000ocHSS@06ocHSS@03o`000?m9?J7oBCfQ00CoBCfQ00?o
0000og]LY?mkG:@02_mkG:@00ol0003oPV^`oh9[/005oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o
0000ok29[On`RJd05_n`RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00?odjZ_0ol0
000;om>Z[`Co00001?oZ^j<00ol0003oj[^SonZkX`0;onZkX`03o`000?ood83oom2000Coom2000?o
0000ooc1GOl00000<Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`15
ooooo`;o000000?o001Ro`000?lf8hd01Olf8hd00ol0003oBCfQodTmX@05odTmX@03o`000?mkG:Co
NebT00SoNebT0_l00008oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o0000ok29[On`RJd05_n`RJd0
0ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00?o00004OoCZZl2o`0000?oj[^S00?o0000
onZkXooZ^j<02ooZ^j<00ol0003oom20ooo@P005ooo@P0;o0000<Oooool00ol0003oooooooooo`0=
ooooo`006oooool00ol0003oooooooooo`15ooooo`;o00000_l006800ol0003o=R>=ocHSS@02ocHS
S@03o`000?m9?J7oBCfQ00KoBCfQ00?o0000og]LY?mkG:@01_mkG:@2o`0000[oPV^`00?o0000oiak
[_nLNjh05_nLNjh00ol0003o/8V]ok29[@0Fok29[@03o`000?o1V:go`IR]01Ko`IR]1?l0000Dom>Z
[`03o`000?oU`;7o000000?oj[^S00?o0000onZkXooZ^j<02OoZ^j<00ol0003ooMVKo`000006ooo@
P0;o0000<Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`15ooooo`;o
00000_l006800ol0003o=R>=ocHSS@02ocHSS@03o`000?m9?J7oBCfQ00OoBCfQ00?o0000og]LY?mk
G:@01?mkG:@00ol0003oPV^`oh9[/00;oh9[/003o`000?nLNjkoW7^^01GoW7^^00?o0000ok29[On`
RJd05_n`RJd00ol0003o`IR]ol6H[@0Col6H[@Co00005_oCZZl01Ol0003oiL2aonG0/OoU`;7o0000
00?oj[^S00?o0000onZkXooZ^j<02?oZ^j<00ol0003ooMVKo`000007ooo@P003o`000?oooooooooo
02oooooo00?o0000ooooooooool03Oooool001_ooooo0_l00016ooooo`;o00000_l006801Ol0003o
=R>=ocHSSOlf8hgo000000[oBCfQ00?o0000og]LY?mkG:@00_mkG:@2o`0000koPV^`00?o0000oiak
[_nLNjh05OnLNjh00ol0003o/8V]ok29[@0Fok29[@03o`000?o1V:go`IR]013o`IR]0ol00003ol6H
[@03o`000?oCZZoodjZ_01CodjZ_00?o0000onG0/OoU`;400_oU`;401Ol0003oj[^SonZkXooZ^j?o
000000Woj[^S00?o0000oogIVol000001oood8000ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo04Kooooo0_l00002o`00HP04o`000?lf8hgo=R>=
o`0000_oBCfQ00?o0000og]LY?mkG:@00_l0000@oh9[/003o`000?nLNjkoW7^^01GoW7^^00?o0000
ok29[On`RJd02_n`RJd@o`0000co`IR]0ol00006ol6H[@03o`000?oCZZoodjZ_01CodjZ_00?o0000
onG0/OoU`;400ooU`;401Ol0003oj[^SonZkXooZ^j?o000000Ooj[^S00Go0000oogIVoomfI_ooMVK
o`000006ooo@P003o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00004oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`16ooooo`03o`00<?l0003o001R00;o001R0_l0000=odTmX@;o00004_n2Jk000ol0003o
W7^^oiak[P0Coiak[Poo00003?n`T[L01?l0003o`9nhol2O^?o0WkP6o`0000?o`IR]0ol00009ol6H
[@03o`000?oCZZoodjZ_01?odjZ_00?o0000onG0/OoU`;401OoU`;401Ol0003oj[^SonZkXooZ^j?o
000000Koj[^S00Go0000oogIVoomfI_ooMVKo`000005ooo@P003o`000?oooooooooo037ooooo00?o
0000ooooooooool03?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0A_ooool00ol0033o0000o`00HP02o`00HP03o`000?m9
?J7oBCfQ00coBCfQ00?o0000oh9[/?n2Jk004_n2Jk000ol0003oW7^^oiak[P0>oiak[PCo00000_nO
Q[T00ol0003o/9:gok2B]`0Fok2B]`03o`000?o0WkSo`9nh00Ko`9nh1ol00008ol6H[@03o`000?oC
ZZoodjZ_01CodjZ_00?o0000onG0/OoU`;401_oU`;42o`000003onZkXol0003oj[^S00Coj[^S00?o
0000oogIVoomfI/00oomfI/00ol0003oom20ooo@P002ooo@P003o`000?oooooooooo037ooooo00?o
0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Kooooo00?o0000o`00H_l006800_l006800ol0003oBCfQodTmX@0<
odTmX@03o`000?n2Jk3oPV^`01;oPV^`00?o0000oiak[_nLNjh02onLNjh3o`0000KoWhJi00?o0000
ok2B]on`T[L05_n`T[L00ol0003o`9nhol2O^003ol2O^0?o00001oo0WkP6o`0000;o`IR]00?o0000
om>Z[ooCZZl05?oCZZl00ol0003oiL2aonG0/@08onG0/@03o`000?oZ^j?o000000Coj[^S00?o0000
oogIVoomfI/00oomfI/00ol0003oom20ooo@P002ooo@P003o`000?oooooooooo037ooooo00?o0000
ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo04Kooooo00?o0000o`00H_l006800_l006800ol0003oBCfQodTmX@0;odTm
X@03o`000?mJEK;o000001?oPV^`00?o0000oiak[_nLNjh01onLNjh4o`0000WoWhJi00?o0000ok2B
]on`T[L05_n`T[L00ol0003o`9nhol2O^003o`00013o`9nh1?l0000Dom>Z[`03o`000?oU`;7oiL2a
00[oiL2a00?o0000onZkXol000000ooZ^j<00ol0003ooMVKoogIV`03oogIV`03o`000?ood83oom20
00;oom2000?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003o
ooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`16oooo
o`03o`000?l006;o001R00;o001R00?o002<o`000?m9?J402_m9?J401?l0003oFUFboeYE/_l0000C
oh9[/003o`000?nLNjkoW7^^00?oW7^^1?l0000>oin6^@03o`000?n`T[Oo/9:g01Go/9:g0ol0000E
ol2O^003o`000?o?/;[o000000;o00004OoCZZl00ol0003oiL2aonG0/@0;onG0/@05o`000?oZ^j?o
0000onZkXol000001oomfI/00ol0003oom20ooo@P002o`0003?ooooo00?o0000ooooooooool03?oo
ool000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Oooooo00?o0000o`00H_l006800_l006800ol008co0000odTmX@09odTmX@03o`000?mJEK;o
FUFb00;oFUFb00?o0000oh9[/?n2Jk004On2Jk000ol0003oW7^^o`000002o`0001;oWhJi00?o0000
ok2B]on`T[L04On`T[L5o`0001Oo`9nh00?o0000oln`^_o?/;X00_o?/;X3o`0000kodjZ_00?o0000
onG0/OoU`;403?oU`;401?l0003oj[^So`000?l00007oogIV`04o`000?ood83oom20o`0003Gooooo
00?o0000ooooooooool02oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool2o`0004Sooooo00Oo0000o`00H_l006;o001Ro`000?l008co000000WoBCfQ00?o0000oeYE
/_mJEK800omJEK800ol0003oPV^`oh9[/00@oh9[/0?o00005OnOQ[T00ol0003o/9:gok2B]`0>ok2B
]`?o00001?n`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[ock2j00Kock2j0ol0000:om>Z
[`03o`000?oU`;7oiL2a00koiL2a0ol00008oogIV`03o`000?ood83o000003Gooooo00?o0000oooo
ooooool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo
04Oooooo00Go0000o`00H_l006;o001Ro`000002o`00S003o`000?m9?J7oBCfQ00GoBCfQ00?o0000
oeYE/_mJEK801?mJEK800ol0003oPV^`oh9[/00>oh9[/0;o000000?oRGZlo`000?nOQ[T05OnOQ[T0
0ol0003o/9:gok2B]`0;ok2B]`?o00001on`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[o
ck2j00Wock2j0ol00007om>Z[`03o`000?oU`;7oiL2a00ooiL2a0_l00008oogIV`03o`000?ood83o
000003Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0B?ooool01?l0
003o001Ro`00H_l00002o`00S003o`000?m9?J7oBCfQ00CoBCfQ00?o0000oeYE/_mJEK801_mJEK80
0ol0003oPV^`oh9[/00<oh9[/003o`000?n9N[coRGZl00;oRGZl00?o0000oin6^OnOQ[T04onOQ[T0
0ol0003o/9:gok2B]`08ok2B]`?o00002On`T[L00ol0003o`9nhol2O^00Eol2O^003o`000?o?/;[o
ck2j00cock2j0ol00004om>Z[`03o`000?oU`;7oiL2a00ooiL2a00?o0000oogIVol000001oomfI/3
o`0003Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0B?ooool01?l0
003o001Ro`00H_l00002o`00S003o`000?m9?J7oBCfQ00CoBCfQ00?o0000oeYE/_mJEK801_mJEK80
0ol0003oPV^`oh9[/00:oh9[/0;o00001On9N[`00ol0003oWhJioin6^@0Doin6^@03o`000?n`T[Oo
/9:g00?o/9:g1?l0000<ok2B]`03o`000?o0WkSo`9nh01Co`9nh00?o0000oln`^_o?/;X04?o?/;X4
o`00017oiL2a00Go0000ooKN/_l0003ooMVKo`000007oogIV`;o0000=Oooool00ol0003ooooooooo
o`0;ooooo`006Oooool00ol0003oooooooooo`18ooooo`04o`000?l006;o001Ro`0000?o002<00?o
0000odTmXOm9?J400_m9?J400ol0003oFUFboeYE/P08oeYE/P03o`000?n2Jk3oPV^`00OoPV^`0_l0
0007ohUj_003o`000?nOQ[WoWhJi01CoWhJi00?o0000ok2B]on`T[L00ol0000@ok2B]`03o`000?o0
WkSo`9nh01Co`9nh00?o0000oln`^_o?/;X04oo?/;X2o`00013oiL2a00?o0000ooKN/_l000000_om
fI/00ol0003ooMVKoogIV`04oogIV`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02ooo
ool001Sooooo00?o0000ooooooooool0B_ooool00ol0003o001Ro`000003o`00S005o`000?m9?J7o
BCfQodTmXOl000002omJEK800ol0003oPV^`oh9[/005oh9[/0;o00002_n9N[`00ol0003oWhJioin6
^@0Coin6^@?o00004on`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[ock2j01?ock2j00?o
0000omk4__l000003_oU`;401Ol0003om]jbooKN/_ofg[;o000000;ooMVK00?o0000oogIVoomfI/0
0_omfI/2o`0003Kooooo00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool0B_oo
ool00ol0003o001Ro`000003o`00S004o`000?m9?J7oBCfQo`0000goFUFb00?o0000oh9[/?n2Jk00
0_n2Jk02o`0000coRGZl00?o0000oin6^OnOQ[T04?nOQ[T4o`0001Go/9:g00?o0000ol2O^?o0WkP0
4oo0WkP00ol0003ock2joln`^P0Coln`^P05o`000?oNa;kog/Bnomk4__l000003OoU`;401Ol0003o
m]jbooKN/_ofg[;o000000;ooMVK00?o0000oogIVoomfI/00_omfI/2o`0003Oooooo00?o0000oooo
ooooool02_ooool001Sooooo00?o0000ooooooooool0B_ooool2o`0000Go002<0_l0000>oeYE/P05
o`000?n2Jk3oPV^`oh9[/?l000003_n9N[`00ol0003oWhJioin6^@0<oin6^@Co00000onOQ[T00ol0
003o/9:gok2B]`0Cok2B]`03o`000?o0WkSo`9nh01?o`9nh00?o0000oln`^_o?/;X04oo?/;X00ol0
003og/Bnomk4_P02omk4_P03o`000?oU`;7oiL2a00[oiL2a00?o0000ooKN/_ofg[800_ofg[801?l0
003ooMVKoogIVol00003oogIV`;o0000=oooool00ol0003oooooooooo`0:ooooo`006?ooool2o`00
04_ooooo0_l00005o`00S003o`000?mJEK;oFUFb00goFUFb00Co0000oh9[/?l0003o00004?n9N[`0
0ol0003oWhJioin6^@08oin6^@?o00001onOQ[T00ol0003o/9:gok2B]`0Cok2B]`03o`000?o0WkSo
`9nh01?o`9nh00?o0000oln`^_o?/;X04_o?/;X00ol0003og/Bnomk4_P04omk4_P03o`000?oU`;7o
iL2a00SoiL2a00?o0000ooKN/_ofg[800oofg[801_l0003ooMVKoogIVoomfI_o0000oogIV`?o0000
=oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`1;ooooo`03o`000?l0
08co002<00?o002<00?o0000oeYE/_mJEK803_mJEK800ol0003oRGZlohUj_00@ohUj_003o`000?nO
Q[WoWhJi00GoWhJi0ol0000;oin6^@03o`000?n`T[Oo/9:g01;o/9:g00?o0000ol2O^?o0WkP04_o0
WkP00ol0003ock2joln`^P0Coln`^P03o`000?oNa;kog/Bn00Gog/Bn0_l00008onG0/@03o`000?of
g[;om]jb00Com]jb00Co0000oogIVoomfI_ooMVK1?l0000gooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04_ooooo00?o0000o`00S?l008`00ol008`00ol=;Jgo0000oeYE
/P0>oeYE/P03o`000?n9N[coRGZl017oRGZl00Co0000oin6^OnOQ[WoWhJi0ol0000>oin6^@03o`00
0?n`T[Oo/9:g00So/9:g3_l0000Aol2O^003o`000?o?/;[ock2j01;ock2j00?o0000omk4__oNa;h0
2?oNa;h00ol0003oiL2aonG0/@04onG0/@03o`000?ofg[;om]jb00Gom]jb00?o0000oogIVoomfI/0
0_omfI/2o`0003Sooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0C?oo
ool00ol0003o002<o`00S003o`00S0;o00003_mJEK800ol0003oJF_1o`00000BohUj_0Co00003onO
Q[T=o`0000[o/9_200Co0000okjW`onnYl?o_ZO31ol0000:ol2O^003o`000?o?/;[ock2j01;ock2j
00?o0000omk4__oNa;h02OoNa;h00ol0003oiL2aonG0/@03onG0/@03o`000?ofg[;om]jb00Kom]jb
00?o0000oogIVoomfI/00ol0000hooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oo
oooooooo04gooooo00Go0000o`00S?l008co002<o`000002o`d][@03o`000?mJEK;oFUFb00[oFUFb
00Co0000ofU[`OmYJl7o00003on9N[`4o`0000koWhJi1?l00002oj:Aa003o`000?n`Vl;o/9_201;o
/9_200?o0000okjW`onnYl<02?nnYl<7o`0000;o`9nh00?o0000oln`^_o?/;X04_o?/;X00ol0003o
g/Bnomk4_P0;omk4_P05o`000?oU`;7oiL2aonG0/Ol000002Oofg[801_l0003ooMVKoogIVol0003o
fmaYo`0003Sooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0COooool0
1Ol0003o002<o`00S?l008co000000;o3Bf]00?o0000oeYE/_mJEK802OmJEK800ol0003oJF_1ofU[
`@02ofU[`@03o`000?n9N[coRGZl00WoRGZl0ol00004ohUj_003o`000?nOQ[WoWhJi00OoWhJi1?l0
0006oj:Aa003o`000?n`Vl;o/9_201;o/9_200?o0000okjW`onnYl<03onnYl<4o`0001?ock2j00?o
0000omk4__oNa;h03?oNa;h01?l0003oiL2aonG0/Ol0000:ooKN/P04o`000?omfI_o0000om_LJ@;o
0000>?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1=ooooo`05o`00
0?l008co002<o`00S?l000000ol=;Jd00ol0003oFUFboeYE/P07oeYE/P03o`000?mYJl7oJF_100?o
JF_100?o0000ohUj_?n9N[`01_n9N[`3o`0000OoRGZl00?o0000oin6^OnOQ[T01?nOQ[T3o`0000[o
XY7400?o0000ok2K`_n`Vl804_n`Vl800ol0003o_ZO3okjW``0AokjW``03o`000?o;]LGo000000;o
00003oo?/;X00ol0003og/Bnomk4_P0>omk4_P03o`000?oU`;7o000000[om]jb0_l000001OoKg6Wo
0000o`000?oooooo000003Oooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000oooooooo
ool0C_ooool01?l0003o002<o`00S?l00004o`d][@03o`000?mJEK;oFUFb00GoFUFb00?o0000ofU[
`OmYJl401OmYJl401?l0003oRGZlohUj_?n9N[`4o`0000[oRGZl00?o0000oin6^OnOQ[T01?l0000>
oj:Aa003o`000?n`Vl;o/9_2017o/9_200?o0000okjW`onnYl<04OnnYl<00ol0003obkG5ol^ea@02
ol^ea@;o00003Oo?/;X00ol0003og/Bnomk4_P0?omk4_P03o`000?ofg[;om]jb00[om]jb00?o0000
om_LJOl000000oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Goooo
o`03o`000?oooooooooo04kooooo00Co0000o`00S?l008co00001?l=;Jd00ol0003oFUFboeYE/P05
oeYE/P03o`000?mYJl7oJF_100GoJF_11?l0000>ohUj_0?o00004_nRTL@00ol0003o/9_2ok2K`P0A
ok2K`P03o`000?nnYl?o_ZO3013o_ZO300?o0000ol^eaOo;]LD01Oo;]LD3o`0000Wock2j00?o0000
omk4__oNa;h04?oNa;h00ol0003om]jbooKN/P0:ooKN/P03o`000?oKg6Wo000000?ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`005oooool2o`0004oooooo00Co0000o`00
S?l008co00001Ol=;Jd00ol0003oFUFboeYE/P03oeYE/P03o`000?mYJl7oJF_100CoJF_11?l0000>
ohUj_0;o000000?oShS8o`000?nRTL@04_nRTL@00ol0003o/9_2ok2K`P0Aok2K`P03o`000?nnYl?o
_ZO3013o_ZO300?o0000ol^eaOo;]LD02?o;]LD2o`0000Oock2j00?o0000omk4__oNa;h03ooNa;h0
0ol0003ok=o4o`00000:ooKN/P;o000000?ofmaYo`000?ooool00oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo053ooooo00?o0000o`00
S?l000001Ol=;Jd00ol0003oFUFboeYE/P02oeYE/P03o`000?mYJl7oJF_100;oJF_10ol00004ofU[
`@03o`000?n9N[coRGZl00[oRGZl00?o0000ohn8b?n?R<P00_n?R<P00ol0003oXY74oj:Aa00@oj:A
a003o`000?n`Vl;o/9_2017o/9_200?o0000okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0:ol^e
a@;o00001?o?/;X00ol0003og/Bnomk4_P0?omk4_P04o`000?o/glCok=o4o`0000[om]jb0_l00000
0ooKg6Wo0000ooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool0
01Kooooo00?o0000ooooooooool0D?ooool2o`0000Oo3Bf]00Go0000oeYE/_mJEK;o0000ofU[`@04
o`0000OoJF_100?o0000ohUj_?n9N[`02?n9N[`2o`0000GoShS800?o0000oj:Aa?nRTL@04?nRTL@0
0ol0003o/9_2ok2K`P0@ok2K`P03o`000?nnYl?o_ZO3013o_ZO300?o0000ol^eaOo;]LD03Oo;]LD3
o`000003oln`^_l0003og/Bn013og/Bn00Go0000oncOa?o/glCok=o4o`000008ooKN/P;o000000?o
fmaYo`000?ooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo000F
ooooo`03o`000?oooooooooo053ooooo0_l00007o`d][@03o`000?mJEK;o000000;o00003?mYJl40
0ol0003oRGZlohUj_005ohUj_0;o00002?n?R<P00ol0003oXY74oj:Aa00@oj:Aa003o`000?n`Vl;o
/9_200oo/9_200?o0000okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0@ol^ea@;o00004?oNa;h0
0ol0003ok=o4oncOa002oncOa003o`000?ofg[;om]jb00Gom]jb00Go0000on[cW?l0003ofmaYo`00
0008ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0DOooool00ol0003o3Bf]o`d][@04o`d][@?o00003omYJl400ol0003oRGZlohUj_003
ohUj_0;o00002_n?R<P00ol0003oXY74oj:Aa00@oj:Aa003o`000?n`Vl;o/9_200oo/9_200?o0000
okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0@ol^ea@03o`000?oGal_o000000kog/Bn00?o0000
oncOa?o/gl@01?o/gl@00ol0003om]jbooKN/P04ooKN/P05o`000?oZlico0000om_LJOl000002Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooo
oooo057ooooo00Co0000o`d][Ol=;Jgo3Bf]0ol00002o`d][@03o`000?mYJl7oJF_100koJF_100Go
0000ohUj_?n9N[coRGZlo`00000=ohn8b003o`000?nRTLCoXY7400ooXY7400?o0000ok2K`_n`Vl80
3on`Vl800ol0003o_ZO3okjW``0?okjW``03o`000?o;]LGobkG5013obkG500Co0000omO7booGal_o
elO;0_l0000;omk4_P03o`000?o/glCok=o400Gok=o400?o0000ooKN/_ofg[800oofg[800ol0003o
j_>Lon[cW002o`0000[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00
5_ooool00ol0003oooooooooo`1Aooooo`Co00001Ol=;Jd00olbDlGo0000ofU[`@0>ofU[`@04o`00
0?n9N[co0000o`0000koShS800?o0000oj:Aa?nRTL@03onRTL@00ol0003o/9_2ok2K`P0?ok2K`P03
o`000?nnYl?o_ZO300oo_ZO300?o0000ol^eaOo;]LD04?o;]LD00ol0003oelO;omO7b`03omO7b`03
o`000?oNa;kog/Bn00Sog/Bn00?o0000oncOa?o/gl@01_o/gl@00ol0003om]jbooKN/P02ooKN/P03
o`000?oZlicoj_>L00;o00002oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo04oooooo0ol000000ooooooo0000o`d][@06o`d][@03o`00
0?lbDlGo000000ooJF_100?o0000ohn8b?n?R<P03on?R<P00ol0003oXY74oj:Aa00>oj:Aa003o`00
0?n`Vl;o/9_200oo/9_200?o0000okjW`onnYl<03onnYl<00ol0003obkG5ol^ea@0?ol^ea@03o`00
0?oGal_oelO;00GoelO;0_l00007omk4_P03o`000?o/glCok=o400Ook=o400Go0000ooKN/_ofg[;o
m]jbo`000003on[cW0;o00003?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00So
oooo000Eooooo`?o0000C?ooool3o`0000Cooooo00?o001fo`000?l=;Jd01?l=;Jd01Ol0003o<U?5
oc9CaOlbDlGo000000goJF_10_l0000Aohn8b003o`000?nRTLCoXY7400koXY7400?o0000ok2K`_n`
Vl803on`Vl800ol0003o_ZO3okjW``0>okjW``03o`000?o;]LGobkG500oobkG500?o0000omO7booG
al/02?oGal/00ol0003og/Bnomk4_P03omk4_P03o`000?o/glCok=o400Wok=o400?o0000ooKN/_l0
00001?oZli`00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000Sooooo00?o0000o`d][Ol=;Jd0
0ol=;Jd01Ol0003o<U?5oc9CaOlbDlGo000000coJF_100Co0000ogIoc_mfOlko00004On?R<P00ol0
003oXY74oj:Aa00>oj:Aa003o`000?n`Vl;o/9_200ko/9_200?o0000okjW`onnYl<03_nnYl<00ol0
003obkG5ol^ea@0?ol^ea@03o`000?oGal_oelO;00WoelO;0_l00003omk4_P03o`000?o/glCok=o4
00Wok=o400?o0000ooKN/_l000000ooZli`2o`0000oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002oooool00ol007Ko
0000o`d][@03o`d][@03o`000?lbDlGo<U?500;o<U?500?o0000ofU[`OmYJl402?mYJl400ol0003o
MWo>ogIocP02ogIocP03o`000?n?R<SoShS800koShS800?o0000oj:Aa?nRTL@03_nRTL@00ol0003o
/9_2ok2K`P06ok2K`Pgo00003?nnYl<00ol0003obkG5ol^ea@0>ol^ea@03o`000?oGal_oelO;00co
elO;00?o0000omk4__l000003Oo/gl@00ol0003oj_>Lon[cW002on[cW0;o00003oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo
0ol0000@ooooo`03o`00M_l0003o3Bf]00;o3Bf]00?o0000oc9CaOlbDlD00olbDlD00ol0003oJF_1
ofU[`@06ofU[`@03o`000?mfOlkoMWo>00CoMWo>00?o0000ohn8b?n?R<P03_n?R<P00ol0003oXY74
oj:Aa00;oj:Aa0_o00002?n`Y/h00ol0003o^Zo>okZ_cP02okZ_cPSo00000onnYl<00ol0003obkG5
ol^ea@0?ol^ea@03o`000?oGal_oelO;00goelO;00?o0000oncOa?o/gl@03?o/gl@00ol0003oj_>L
on[cW002on[cW003o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`07ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00004oooool00ol007Ko0000o`d]
[@02o`d][@03o`000?lbDlGo<U?500Co<U?500?o0000ofU[`OmYJl401?mYJl400ol0003oMWo>ogIo
cP05ogIocP03o`000?n?R<SoShS800koShS800?o0000oj:Aa?nRTL@02?nRTL@3o`0000;oXik@00?o
0000ok2Vc_n`Y/h03_n`Y/h00ol0003o^Zo>okZ_cP0:okZ_cPGo00003oo;]LD00ol0003oelO;omO7
b`0>omO7b`03o`000?o/glCok=o400_ok=o40_l00004on[cW003o`000?oooooooooo013ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0m
ooooo`?o00005_ooool00ol0003o001fo`000002o`d][@03o`000?lbDlGo<U?500Co<U?500?o0000
ofU[`OmYJl400omYJl400ol0003oMWo>ogIocP07ogIocP03o`000?n?R<SoShS800koShS800?o0000
oj:Aa?nRTL@00onRTL@4o`0000GoXik@00?o0000ok2Vc_n`Y/h03_n`Y/h00ol0003o^Zo>okZ_cP0=
okZ_cP03o`000?o4^m7o000000;o00003?o;]LD00ol0003oelO;omO7b`0=omO7b`03o`000?oPg]?o
000000_ok=o400?o0000onWj`Ol000000ooZli`00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0>Oooool4o`00
01[ooooo00Co001fo`000?l=;Jgo00002?lbDlD01Ol0003oJF_1ofU[`OmYJl7o000000_oMWo>00?o
0000ohn8b?n?R<P03On?R<P00ol0003oXY74oj:Aa003o`0000[oXik@00?o0000ok2Vc_n`Y/h03On`
Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`000?o4^m7oa;_A00?oa;_A0ol00008ol^ea@03o`000?oG
al_oelO;00goelO;00Co0000on3NdooPg]?o00002_o/gl@00ol0003ojO[1o`000003on[cW003o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`005?oo
ool00ol0003oooooooooo`0fooooo`?o00007_ooool01?l0003o001fo`000?l00009oc9Ca@03o`00
0?mYJl7o000000goMWo>00?o0000ohn8b?n?R<P03?n?R<P3o`0000goXik@00?o0000ok2Vc_n`Y/h0
3On`Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`000?o4^m7oa;_A00Koa;_A0ol00004ol^ea@03o`00
0?oGal_oelO;00goelO;00?o0000on3NdooPg]<00_oPg]<00ol0003ok=o4oncOa006oncOa004o`00
0?oYn/7ojO[1o`0000?oj_>L00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo000Dooooo`?o0000<oooool3o`0002;ooooo0_l007H00ol0003o<U?5
oc9Ca@08oc9Ca@03o`000?mfOlkoMWo>00goMWo>00?o0000ohn8b?n?R<P02?n?R<P3o`000003oiFH
e?l0003oXik@00goXik@00?o0000ok2Vc_n`Y/h03On`Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`00
0?o4^m7oa;_A00Woa;_A0ol000000oo;]LGo0000omO7b`0=omO7b`03o`000?oPg]?oh=kC00?oh=kC
00?o0000oncOa?o/gl@01Oo/gl@01Ol0003ojO[1onWj`OoYn/7o000000;oj_>L00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`00
0?oooooooooo033ooooo0ol0000Uooooo`03o`000?l007Ko000000[o<U?500?oDGCGo`000?mfOlh0
3OmfOlh00ol0003oShS8ohn8b006ohn8b0;o00001OnEV=@00ol0003oXik@oj>Nd00;oj>Nd003o`00
0?n`Y/ko/:K>00go/:K>00?o0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0=olBkd@;o0000
3OoGal/00ol0003oh=kCon3Nd`05on3Nd`03o`000?o/glCok=o400?ok=o400?o0000onWj`OoYn/40
0_oYn/400ol0003oj_>Lo`00000Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02cooooo1?l0
000Yooooo`03o`000?l007Ko000000Wo<U?500?o0000oe5deol000003_mfOlh00ol0003oShS8ohn8
b003ohn8b0;o00001onEV=@00ol0003oXik@oj>Nd00<oj>Nd003o`000?n`Y/ko/:K>00co/:K>00?o
0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0=olBkd@03o`000?o=bMOo000000_oelO;00?o
0000on3NdooPg]<01_oPg]<00ol0003ok=o4oncOa002oncOa003o`000?oYn/7ojO[100?ojO[100?o
0000on[cW?l000006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool3o`0002gooooo00Co0000
o`00M_l0003o00002?lbDlD01?l0003oDGCGoe5deol0000>ogIocP03o`000?n?R<So000000;o0000
2_nEV=@00ol0003oXik@oj>Nd00;oj>Nd003o`000?n`Y/ko/:K>00_o/:K>00?o0000okZ_c_nj[lh0
2onj[lh00ol0003oa;_AolBkd@0=olBkd@05o`000?o=bMOocLWGolg9eol000002_oGal/00ol0003o
h=kCon3Nd`07on3Nd`04o`000?o/glCok=o4o`0000KojO[10_l0000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Wooooo`?o0000<Oooool2o`000003o`0W/Ol0003o<U?500Go<U?500?o0000oe5deomA
M=L00_mAM=L00ol0003oMWo>ogIocP0<ogIocP03o`000?nEV=CoUISD00coUISD00?o0000oj>Nd?nS
W]002_nSW]000ol0003o/:K>ok2VcP0;ok2VcP03o`000?nj[lko^Zo>00_o^Zo>00?o0000olBkdOo4
^m403?o4^m400ol0003ocLWGolg9e`03olg9e`;o00001ooGal/00ol0003oh=kCon3Nd`08on3Nd`03
o`000?o/glCo000000KojO[100?o0000on[cW?l000007_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9?ooool3o`0003Gooooo00Co001fo`000?l09k7o00001OlbDlD00ol0003oDGCGoe5de`03oe5de`03
o`000?mfOlkoMWo>00_oMWo>00?o0000oiFHe?nEV=@03?nEV=@00ol0003oXik@oj>Nd00;oj>Nd003
o`000?n`Y/ko/:K>00[o/:K>00?o0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0;olBkd@03
o`000?o=bMOocLWG00KocLWG00?o0000omO7booGal/00ooGal/00ol0003oh=kCon3Nd`0:on3Nd`03
o`000?oYn/7ojO[100GojO[10_l0000Oooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`Co0000
>?ooool2o`0000;o02Na00?o0000oc9CaOlbDlD00_lbDlD00ol0003oDGCGoe5de`04oe5de`03o`00
0?mfOlkoMWo>00WoMWo>00?o0000oh>Cf_l000003_nEV=@00ol0003oXik@oj>Nd00:oj>Nd003o`00
0?n`Y/ko/:K>00[o/:K>00?o0000okZ_c_nj[lh02_nj[lh00ol0003oa;_AolBkd@0;olBkd@03o`00
0?o=bMOocLWG00SocLWG00Go0000omO7booGal_oelO;o`00000;on3Nd`03o`000?oOmmWo000000Oo
jO[100?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool3o`0003gooooo
00Co001fo`000?l09k7o00001?lbDlD00ol0003oDGCGoe5de`05oe5de`03o`000?mfOlkoMWo>00Oo
MWo>00Go0000oh>Cf_n3Tm[oPi?Jo`00000=oiFHe003o`000?nSW]3oXik@00[oXik@00?o0000ok2V
c_n`Y/h02_n`Y/h00ol0003o^Zo>okZ_cP0:okZ_cP03o`000?o4^m7oa;_A00[oa;_A00?o0000olg9
eoo=bML02_o=bML00ol0003oelO;o`00000;on3Nd`04o`000?oOmmWogoOIo`0000OojO[100?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool3o`00043ooooo0_l00002o`0W
/@05o`000?lbDlGo<U?5oc9CaOl000002?mAM=L00ol0003oMWo>ogIocP05ogIocP03o`000?n3Tm[o
Pi?J00?oPi?J00?o0000oiFHe?nEV=@02onEV=@00ol0003oXik@oj>Nd009oj>Nd003o`000?n`Y/ko
/:K>00[o/:K>00?o0000okZ_c_nj[lh02Onj[lh00ol0003oa;_AolBkd@0:olBkd@03o`000?o=bMOo
cLWG00cocLWG00?o0000on3NdooPg]<02OoPg]<01Ol0003ogoOIomogfOoOmmWo000000KojO[100?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo000:
ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000A?ooool01ol007Ko0000o`0W/Ol0
9k7o0000oc9CaOl000002_mAM=L00ol0003oMWo>ogIocP03ogIocP03o`000?n3Tm[oPi?J00GoPi?J
00?o0000oiFHe?nEV=@02_nEV=@00ol0003oXik@oj>Nd00:oj>Nd003o`000?n`Y/ko/:K>00Wo/:K>
00?o0000okZ_c_nj[lh02Onj[lh00ol0003oa;_AolBkd@0:olBkd@03o`000?o=bMOocLWG00[ocLWG
00?o0000om;Kgol000002_oPg]<00ol0003ogoOIomogf@02omogf@03o`000?oYn/7ojO[100?ojO[1
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo
000Booooo`03o`000?oooooooooo01Cooooo1?l00018ooooo`04o`000?l09k7o02Nao`0W/@;o0000
2omAM=L01Ol0003oMWo>ogIoc_mfOlko000000WoPi?J00?o0000oiFHe?nEV=@02_nEV=@00ol0003o
Xik@oj>Nd007oj>Nd1Go00001Onj[lh00ol0003oa;_AolBkd@09olBkd@03o`000?o=bMOocLWG00[o
cLWG00Go0000om;KgooBfmood]_Oo`000008on3Nd`03o`000?oOmmWogoOI00?ogoOI00?o0000onWj
`OoYn/400_oYn/400ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`0004cooooo00?o0000o`0W/Ol0
9k400_l09k42o`0000_oDGCG00?o0000ogIoc_l000002on3TmX00ol0003oUISDoiFHe00:oiFHe003
o`000?nSW]3oXik@00?oXik@0ol00002ojB/g@03o`000?n]/M_o[K7K00Wo[K7K00?o0000okBhg?nd
^=`01?nd^=`7o`0000Woa;_A00?o0000olg9eoo=bML02_o=bML00ol0003od]_Oom;Kg`02om;Kg`03
o`000?oPg]?oh=kC00Goh=kC00?o0000omogfOoOmmT00ooOmmT00ol0003ojO[1onWj`@02onWj`@03
o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00
4_ooool00ol0003oooooooooo`0>ooooo`?o0000D?ooool01?l0003o02Nao`0W/Ol09k42oa=Qf003
o`000?mAM=OoDGCG00WoDGCG0_l0000<oh>CfP03o`000?nEV=CoUISD00WoUISD00?o0000oj>Nd?nS
W]000ol00006ojB/g@03o`000?n]/M_o[K7K00So[K7K00?o0000okBhg?nd^=`02?nd^=`00ol0003o
^l7Nok_1gP03o`0000Goa;_A00?o0000olg9eoo=bML02_o=bML00ol0003od]_Oom;Kg`04om;Kg`03
o`000?oPg]?oh=kC00?oh=kC00?o0000omogfOoOmmT01?oOmmT01Ol0003ojO[1onWj`OoYn/7o0000
02_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003o
ooooooooo`0;ooooo`?o0000E?ooool01?l0003o02Nao`0W/Ol09k42oa=Qf003o`000?mAM=OoDGCG
00SoDGCG0_m[Sn<00ol0003oPi?Joh>CfP0:oh>CfP03o`000?nEV=CoUISD00SoUISD0ol00009ojB/
g@03o`000?n]/M_o[K7K00So[K7K00?o0000okBhg?nd^=`01ond^=`00ol0003o^l7Nok_1gP04ok_1
gP?o000000?oa;_Ao`000?o=bML02_o=bML2o`0000Ood]_O00?o0000on3NdooPg]<00_oPg]<00ol0
003ogoOIomogf@05omogf@03o`000?oYn/7ojO[100;o0000;?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Oooooo1?l0001Hooooo`04
o`000?l09k7o02Nao`0000;o4f7H0_l00008oe5de`03o`000?m[Sn?oJhoS00;o00002on3TmX00ol0
003oUISDoiFHe005oiFHe0;o000000?oVZWPo`000?nT[=d02OnT[=d00ol0003o[K7Kojfaf`07ojfa
f`03o`000?nd^=co];SL00So];SL00?o0000ok_1g_nk`Mh01onk`Mh00ol0003ocLWGolg9e`09olg9
e`03o`000?oBfmood]_O00Sod]_O00Co0000on3NdooPg]?o00002?oOmmT01?l0003ojO[1o`000?l0
000^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000
ooooooooool01?ooool3o`0005gooooo00Co0000o`0W/Ol09k7o00000olCHMP00ol0003oDGCGoe5d
e`04oe5de`03o`000?m[Sn?oJhoS00?oJhoS00?o0000oh>Cf_n3TmX02On3TmX00ol0003oUISDoiFH
e002oiFHe0;o00001?nJZN000ol0003oY:cMojB/g@08ojB/g@03o`000?n]/M_o[K7K00Ko[K7K00?o
0000okBhg?nd^=`01ond^=`00ol0003o^l7Nok_1gP07ok_1gP04o`000?nob^?o_l[So`0000SocLWG
00?o0000om;KgooBfml02OoBfml00ol0003oh=kCo`000009omogf@?o0000<?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooooooo00;ooooo0ol0
001Qooooo`03o`000?l09k7o000000Co4f7H00?o0000oe5deomAM=L00omAM=L00ol0003oJhoSof^?
h`04of^?h`03o`000?n3Tm[oPi?J00WoPi?J00Co0000oiFHe?l0003o00001onJZN000ol0003oY:cM
ojB/g@07ojB/g@03o`000?n]/M_o[K7K00Ko[K7K00?o0000okBhg?nd^=`01ond^=`00ol0003o^l7N
ok_1gP06ok_1gP03o`000?nob^?o_l[S00;o_l[S0_l00005olg9e`03o`000?oBfmood]_O00_od]_O
00?o0000omogfOoOmmT02?oOmmT2o`00037ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0006Gooooo00?o0000o`0W/Ol000001?lC
HMP2o`0000?oDGCG00?o0000of^?hom[Sn<01Om[Sn<2o`0000[oPi?J0_l00009oiZYh003o`000?nT
[=goY:cM00OoY:cM00?o0000ojfafon]/M/01On]/M/00ol0003o];SLokBhg006okBhg003o`000?nk
`Mko^l7N00Ko^l7N00?o0000oko:honob^<01Onob^<01Ol0003ocLWGolg9eoo=bMOo000000_od]_O
0_l000000oo@kNSo0000omogf@07omogf@03o`000?njo<go000003?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0006Wooooo0_l00006oa=Qf004o`000?mA
M=OoDGCGo`0000WoJhoS00?o0000oh>Cf_n3TmX01_n3TmX01?l0003oSjOUohnWiOl00008oiZYh003
o`000?nT[=goY:cM00OoY:cM00?o0000ojfafon]/M/01On]/M/00ol0003o];SLokBhg005okBhg003
o`000?nk`Mko^l7N00Ko^l7N00?o0000oko:honob^<01onob^<00ol0003ocLWGo`00000;om;Kg`05
o`000?o@kNSod>gXom3]j?l000001ooOmmT01?l0003o^_c=o`000?l0000dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool001?ooooo00?o0000ooooooooool0Ioooool00ol0
9k7o0000oa=Qf005oa=Qf003oe5deol0003oJhoS00[oJhoS0_l00005oh>CfP03o`000?n?YnGoSjOU
00;oSjOU0_l00007oiZYh003o`000?nT[=goY:cM00KoY:cM00?o0000ojfafon]/M/01On]/M/00ol0
003o];SLokBhg005okBhg003o`000?nk`Mko^l7N00Go^l7N00?o0000oko:honob^<02Onob^<00ol0
003od]_Oom;Kg`08om;Kg`;o00001?o@kNP00ol0003ogoOIomogf@03omogf@;o000000?o^_c=o`00
0?l00000=_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo000Dooooo`;o
0000J?ooool00ol0003o4f7Hoa=Qf005oa=Qf0;o00003?m[Sn<01Ol0003oPi?Joh>Cf_n3Tm[o0000
00OoSjOU00?o0000oiZYh?nJZN001OnJZN000ol0003oY:cMojB/g@06ojB/g@03o`000?n]/M_o[K7K
00Co[K7K00?o0000okBhg?nd^=`01?nd^=`00ol0003o^l7Nok_1gP05ok_1gP03o`000?nob^?o_l[S
00Wo_l[S00?o`MGYo`000?oBfml01ooBfml2o`0000Kod>gX00?o0000omogfOoOmmT00_oOmmT00ol0
003o^_c=ok[lc@02o`0003Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04oooo
o`005_ooool00ol0003oooooo`00001Vooooo`;o00001OlCHMP01?l0003oBXc[o`000?l0000;of^?
h`;oPi?J00?o0000ohnWiOn?YnD01on?YnD2o`0000KoVZWP00?o0000ojB/gOnT[=d01OnT[=d00ol0
003o[K7Kojfaf`03ojfaf`03o`000?nd^=co];SL00Go];SL00?o0000ok_1g_nk`Mh01?nk`Mh00ol0
003o_l[Soko:h`07oko:h`03o`000?o1eNWo`MGY00;o`MGY00?o0000om;KgooBfml00ooBfml2o`00
00Sod>gX00?o0000omogfOoOmmT00_l00002ok[lc@;o0000>Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Cooooo000Gooooo`;o0000J?ooool00ol0003o4f7Hoa=Qf003oa=Qf003
o`000?m:S>_oBXc[00;o00002_m[Sn<2o`0000_oSjOU00?o0000oiZYh?nJZN000onJZN000ol0003o
Y:cMojB/g@05ojB/g@03o`000?n]/M_o[K7K00?o[K7K00?o0000okBhg?nd^=`01?nd^=`00ol0003o
^l7Nok_1gP04ok_1gP03o`000?nob^?o_l[S00Ko_l[S0_l00006ol7Ej@05o`000?oBfmood]_Oom;K
gol000002_o@kNP00ol0003ogoOIo`000004ok[lc@03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`006?ooool2o`0006Sooooo0_l00003oa=Qf003
o`000?m:S>_oBXc[00;oBXc[0ol00007of^?h`04o`000?n2Ynco0000o`0000[oSjOU00?o0000oiZY
h?nJZN000onJZN000ol0003oY:cMojB/g@04ojB/g@[o00000ond^=`00ol0003o^l7Nok_1gP03ok_1
gP03o`000?nob^?o_l[S00Go_l[S0_l00008ol7Ej@04o`000?oBfmoo0000o`0000_od>gX0_l00004
ok[lc@03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`006_ooool00ol0003oooooooooo`1Vooooo`03o`10]_l0003o000000;o4f7H00?o0000odZ<
jom:S>/01?m:S>/2o`0000GoJhoS00Co0000oh:Wk?n2YncoPZO/0ol00008ohnWi@;o00001?nJZN00
0ol0003oY:cMojB/g@03o`000003oj>mk?l0003oY[o[00?oY[o[00Co0000ojW2k?nY`^coZL;/1_l0
0002ok_1gP03o`000?nob^?o_l[S00Go_l[S00?o0000ol7EjOo1eNT02Oo1eNT00ol0003od>gXom3]
j00;om3]j003o`000?njo<go^_c=00;o^_c=00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0I?ooool0
1Ol0003o042fo`000?lCHMSo000000SoBXc[0_l00002of^?h`03o`000?n2YncoPZO/00GoPZO/0_l0
0008ohnWi@03o`000?nJZN3oVZWP00Co00001OnS_N`01Ol0003oY[o[ojJojonV_n_o000000GoZL;/
00Co0000ojc5kOn/aNgo[<G]0_l00006oko:h`;o00002_o1eNT00ol0003o_mo`o`000009om3]j0?o
000000?o__W]o`000?njo<d00_njo<d00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00oooool001gooooo0_l0001Wooooo`04o`10]_l0003o4f7Ho`0000Wo
BXc[00?o0000of^?hol000002On2Yn`2o`0000OoSjOU0_l00004oinlk@03o`000?nS_NcoXkg/00;o
Xkg/00Go0000ojJojonV_n_oY[o[o`000004ojW2k005o`000?n/aNgo[<G]ojc5kOl000000_n]bNh0
1?l0003o_l[Soko:honob^<2o`0000Oo`MGY0ol00004okoOl003o`000?o@kNSod>gX00God>gX0_l0
0003okkik@04o`000?njo<go0000o`0004?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`03ooooo`007_ooool00ol0003oooooooooo`1Vooooo`03o`000?l0@;Ko000000_oBXc[0ol0
0009oh:Wk0?o00001?n?YnD01?l0003oV[c_o`000?l00003oinlk@05o`000?nS_NcoXkg/oj>mk?l0
00000onV_n/01Ol0003oZL;/ojW2k?nY`^co000000;o[<G]0_l00004ojg9kP03o`000?nob^?o0000
00Oo`MGY0_l00007okoOl003o`000?o@kNSod>gX00?od>gX0_l00004okkik@03o`000?njo<go0000
04Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`007oooool2o`0006Oo
oooo00Co0000o`10]_l0003o00002Om:S>/00ol0003oLjWcog>Yl`03o`0000WoPZO/0_l000000on?
YnGo0000oiZlk`03oiZlk`;o00000_nO_>d01Ol0003oXkg/oj>mk?nS_Nco000000;oY[o[00Co0000
ojW2k?nY`^co00000_n/aNd00ol0003o[LW^ojg9kP04ojg9kP;o00001Oo1eNT3o`0000Wo_mo`00?o
0000om3]j?o@kNP00ol00005okkik@?o0000B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo000Qooooo`03o`000?oooooooooo06Gooooo00?o0000o`10]_l0@;H00ol00007
odZ<j`03o`000?mcZO?oLjWc00;oLjWc0ol00008oh:Wk0?o00001OnJ_>l2o`000007oinlkOl0003o
0000oj>mk?l0003oY[o[o`000002ojW2k004o`000?n/aNgo0000o`0000Co[LW^0ol00002ojg=l@03
o`000?o1eNWo000000;o00003?nogo03o`0000Oo__W]0_l0001;ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool002;ooooo0ol0001Vooooo`04o`000?l0@;Ko0000oan6jP?o
00001?m:S>/00ol0003oLjWcog>Yl`05og>Yl`?o00001On2Yn`00ol0003oU[gboiJmlP04o`0000?o
V[c_0_l000000onO_>go0000oj>mk002o`0000;oZL;/0_l00003ojg9kP?o00000on]cO44o`0000oo
_mo`00?o0000okkikOnnnNd01_nnnNd00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0IOooool00ol0003o042f
o`000003oan6jP;o00000_m:S>/00ol0003oLjWcog>Yl`08og>Yl`?o000000?oPZO/o`000?nF_O80
1_nF_O84o`000003oiZlkol0003o000000?o000000CoZL;/o`000?l0003o[LW^2Ol00003oj_@l`03
o`000?nogo3o_mo`00Go_mo`1Ol00003okGWm`03o`000?nnnNgo__W]00Go__W]00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o0000
Ioooool2o`0000Co7hKZ0_l000000om:S>_o0000og>Yl`0;og>Yl`_o00000_nF_O8=o`0000WoZm3c
00?o0000okoOl?nogo001Ol00007okGWm`03o`000?nnnNgo__W]00;o__W]0ol0001Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0I_oo
ool00ol0003o7hKZoan6jP04oan6jPGo00002OmcZO<00ol0003oTkkeoi>nm@07oi>nmA_o00002one
ioL00ol0003o__W]okkik@04o`0005Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`00:?ooool00ol0003oooooo`00001Vooooo`?o00001OlOQ^X00ol0003oI:kiofB^n@07
o`0000?oLjWc00Co0000oi>nmOnC__GoTkke2ol000000on@bO_o0000oiS@n`07o`0000SoYm;f00?o
0000okGWmoneioL02_neioL4o`000003oho_h_l0003o000005Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001V
ooooo`03o`000?oooooo07gF00Co00000_lOQ^X00ol0003oI:kiofB^n@06ofB^n@Oo00000on@`OL4
o`000004oho5nOl0003o0000oi39n`;o00000_nHd?/4o`0000;oXm;h1Ol00002ojOBmP03o`000?ne
ioOo]NOg00?o]NOg1Ol00002okGWm`;o00000_n?kn82o`0005[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool00_ooool2o`1meP;o000000?o7hKZo`000?mT[_T02_mT[_T0
0ol0003oT<7goi31m`03o`0000CoSlGi00Co0000oi39non@bO_oT<Wk0_l00003oiS@n`03o`000?nM
d_[oWM;j00;o00001OnSd_P8o`0000CoXnWk0_l00004oho_hP03o`000?oooooooooo05_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000
ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool01?ooool00ol0003o07gFo`1meP0<
o`000003ofB^nOl0003o000000GoSlGi0_l00003oi39n`04o`000?nCc?_oTlcko`0000?oV=3k00Co
0000oigBn_nMd_[oWM;j0_l000000onSd_So0000o`00000;oj?Yn`04o`000?n?kn;oSnoRoho_hP?o
0000G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`06ooooo`;o0000
0_l0OMH2o`0000[oF;Ck0ol000000on?aOWo0000oi39n`03oi39n`05o`000?nCc?_oTlckoi?<nol0
00001?nHd?/00ol0003oWM;joigBnP09o`0000GoXnWk1_l0001Rooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool03?ooool2o`00063ooooo
00?o0000ooooooooool02Oooool00ol0003o07gFo`1meP02o`0000_oF;Ck1?l00002oi39n`05o`00
0?nCc?_oTlckoi?<nol000000_nHd?/5o`0000WoRN;k2?l0001Vooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03Oooool2o`0005oooooo
00?o0000ooooooooool03?ooool01?l0003o07gFo`000?l00002oeRdn`Go00001_mD_?X9o`0000Go
KmKj0_l00007ohWRn`Go0000J_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007o
oooo000Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0@ooooo`?o00002_mD_?X00ol0003oG<Sioec8n@04oec8n@03o`000?m_e_[oKmKj00OoKmKj
00Co0000ohWRnon9h__oRN;k1Ol0001^ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00Oooool001kooooo00?oEEEEofIVI_l000004_ooool2o`000003ooooool0003ooooo05Sooooo
00?o0000ooooooooool05Oooool5o`0000;oE;cj00?o0000oec8nOmLb?T01_mLb?T00ol0003oKmKj
ofoFnP03ofoFnPSo0000L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo
000eooooo`;o0000FOooool00ol0003oooooooooo`0Jooooo`;o000000?oG<Sio`000?l000003Ol0
001jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003Kooooo0_l0001H
ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01
ooooo`00>?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000iooooo`04o`000?oooooooooo
o`0005?ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`09ooooo`7o00000Oooool1
ooooo`00>_ooool3o`0005?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00??ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool003gooooo0_l0001Aooooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool003oooooo00?o
0000ooooool00000C_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo0010ooooo`;o0000C_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo0011ooooo`;o0000COooool00ol0003oooooooooo`2^oooo
o`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool004Cooooo
0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0016ooooo`;o0000B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`00<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000Aoooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`04ogMgMolb<S;oooooo`0004Kooooo00?o0000ooooooooool0/_ooool01Ol0003o
oooooooooooooooo0000007ooooo000Zooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00ol00013ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooo
oooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2cooooo`04o`000?oooooo
ooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo007o0000000booooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`08ooooo`;o0000@?ooool00ol0003oooooooooo`2eooooo`7o00000Oooool1o`000000<_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0003kooooo
00?o0000ooooooooool0]_ooool2o`000000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000:ooooo`;o0000?Oooool00ol0003oooooooooo`2eooooo`?o0000001Cooooo`05o`000?oo
ooooooooooooool00000>?ooool00ol0003oooooooooo`2`ooooo`Go00000oooool005Cooooo00Co
0000oooooooooooo0000>?ooool00ol0003oooooooooo`2/ooooo`Co00002?ooool005Gooooo0ol0
000hooooo`03o`000?oooooooooo0:Sooooo1?l0000<ooooo`00Eoooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0:Cooooo1Ol0000@ooooo`00F?ooool2o`0003Gooooo00?o0000oooo
ooooool0X?ooool4o`0001Gooooo001Jooooo`03o`000?oooooo000003;ooooo00?o0000oooooooo
ool0W?ooool4o`0001Wooooo001Kooooo`;o0000<_ooool00ol0003oooooooooo`2Gooooo`Go0000
7Oooool005gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co00008_oo
ool005kooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`2>ooooo`Go00009_oo
ool005oooooo0ol0000]ooooo`03o`000?oooooooooo08[ooooo1?l0000[ooooo`00HOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000_ooooo`00Doooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00[ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo1Ol0000coooo
o`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`1mooooo`Co0000>?ooool005?ooooo00Go410@oooooooooooooooooa0@400=oooo
o`;o0000:?ooool00ol0003oooooooooo`1iooooo`Co0000??ooool005?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool5o`00
043ooooo001Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000S
ooooo`03o`000?oooooooooo073ooooo1?l00015ooooo`00Doooool01Ol@413ooooooooooooooooo
410@017ooooo0ol0000Sooooo`03o`000?oooooooooo06_ooooo1Ol00019ooooo`00Doooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo1?l0001>
ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l000000ooooooo0000ooooo`0N
ooooo`03o`000?oooooooooo06?ooooo1?l0001Booooo`00K_ooool2o`0001oooooo00?o0000oooo
ooooool0G_ooool5o`0005Kooooo001_ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0F_ooool4o`0005_ooooo001`ooooo`;o00007Oooool00ol0003oooooooooo`1Fooooo`Co0000
Goooool007;ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`1Aooooo`Go0000Hooo
ool007?ooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0001Xooooo`00MOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001/ooooo`00M_ooool2o`000003
ooooool0003ooooo01Cooooo00?o0000ooooooooool0A?ooool5o`00073ooooo001hooooo`;o0000
5Oooool00ol0003oooooooooo`10ooooo`Co0000MOooool007Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0kooooo`Go0000NOooool007[ooooo0_l000000ooooooo0000ooooo`0@
ooooo`03o`000?oooooooooo03Oooooo1?l0001nooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool2o`00017ooooo00?o
0000ooooooooool0<oooool4o`0008;ooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool2o`0000oooooo00?o0000ooooooooool0;ooo
ool5o`0008Kooooo001Sooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:oooool4o`0008_ooooo001S
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`?o00002ooo
ool00ol0003oooooooooo`0Wooooo`Co0000Soooool006?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02;ooooo1Ol0002Cooooo`00Hoooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01ko
oooo1?l0002Hooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03Oooool3o`0000Oooooo00?o0000ooooooooool06Oooool5o`0009cooooo001Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000XOooool008Oooooo0_l00005ooooo`03o`000?oooooooooo017ooooo
1?l0002Uooooo`00ROooool2o`0000?ooooo00?o0000ooooooooool03?ooool5o`000:Wooooo002:
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:kooooo002;ooooo`;o000000?ooooo
o`000?ooool01Oooool4o`000;;ooooo002=ooooo`;o000000?oooooo`000?l000000ol0002foooo
o`00S_ooool2o`000;_ooooo003oooooodcooooo003oooooodcooooo0024ooooo`Co000000?o410@
ooooooooool0`?ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000oooooooo
ool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_oo
ool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Co
oooo00?oEEEEofIVI_l00000a?ooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48803 .51066 m .48098 .55168 L .54163 .55469 L p .718 .606 .731 r
F P
0 g
s
.54163 .55469 m .53926 .51326 L .48803 .51066 L p .718 .606 .731 r
F P
0 g
s
.54359 .59595 m .54163 .55469 L .48098 .55168 L p .72 .583 .701 r
F P
0 g
s
.53926 .51326 m .54163 .55469 L .60094 .54566 L p .672 .571 .733 r
F P
0 g
s
.54163 .55469 m .54359 .59595 L .61054 .58601 L p .668 .542 .703 r
F P
0 g
s
.61054 .58601 m .60094 .54566 L .54163 .55469 L p .668 .542 .703 r
F P
0 g
s
.48098 .55168 m .47517 .59264 L .54359 .59595 L p .72 .583 .701 r
F P
0 g
s
.54512 .63636 m .54359 .59595 L .47517 .59264 L p .72 .559 .67 r
F P
0 g
s
.54359 .59595 m .54512 .63636 L .61806 .62579 L p .662 .513 .672 r
F P
0 g
s
.61806 .62579 m .61054 .58601 L .54359 .59595 L p .662 .513 .672 r
F P
0 g
s
.44029 .49784 m .42433 .53684 L .48098 .55168 L p .761 .648 .736 r
F P
0 g
s
.48098 .55168 m .48803 .51066 L .44029 .49784 L p .761 .648 .736 r
F P
0 g
s
.47517 .59264 m .48098 .55168 L .42433 .53684 L p .769 .629 .706 r
F P
0 g
s
.49623 .47042 m .48803 .51066 L .53926 .51326 L p .714 .63 .762 r
F P
0 g
s
.53926 .51326 m .53649 .47251 L .49623 .47042 L p .714 .63 .762 r
F P
0 g
s
.53649 .47251 m .53926 .51326 L .58931 .50545 L p .675 .6 .764 r
F P
0 g
s
.60094 .54566 m .58931 .50545 L .53926 .51326 L p .672 .571 .733 r
F P
0 g
s
.42433 .53684 m .41113 .57628 L .47517 .59264 L p .769 .629 .706 r
F P
0 g
s
.47063 .63284 m .47517 .59264 L .41113 .57628 L p .775 .609 .674 r
F P
0 g
s
.47517 .59264 m .47063 .63284 L .54512 .63636 L p .72 .559 .67 r
F P
0 g
s
.54622 .67537 m .54512 .63636 L .47063 .63284 L p .719 .534 .638 r
F P
0 g
s
.54512 .63636 m .54622 .67537 L .62347 .66445 L p .656 .483 .639 r
F P
0 g
s
.62347 .66445 m .61806 .62579 L .54512 .63636 L p .656 .483 .639 r
F P
0 g
s
.45883 .46013 m .44029 .49784 L .48803 .51066 L p .75 .666 .768 r
F P
0 g
s
.48803 .51066 m .49623 .47042 L .45883 .46013 L p .75 .666 .768 r
F P
0 g
s
.58931 .50545 m .60094 .54566 L .65358 .52521 L p .621 .54 .742 r
F P
0 g
s
.60094 .54566 m .61054 .58601 L .67019 .56344 L p .608 .505 .71 r
F P
0 g
s
.67019 .56344 m .65358 .52521 L .60094 .54566 L p .608 .505 .71 r
F P
0 g
s
.41113 .57628 m .40078 .61545 L .47063 .63284 L p .775 .609 .674 r
F P
0 g
s
.46736 .67174 m .47063 .63284 L .40078 .61545 L p .78 .588 .64 r
F P
0 g
s
.47063 .63284 m .46736 .67174 L .54622 .67537 L p .719 .534 .638 r
F P
0 g
s
.61054 .58601 m .61806 .62579 L .68322 .60177 L p .595 .468 .678 r
F P
0 g
s
.68322 .60177 m .67019 .56344 L .61054 .58601 L p .595 .468 .678 r
F P
0 g
s
.58931 .50545 m .57578 .46624 L .53649 .47251 L p .675 .6 .764 r
F P
0 g
s
.57578 .46624 m .58931 .50545 L .63355 .48781 L p .633 .576 .773 r
F P
0 g
s
.65358 .52521 m .63355 .48781 L .58931 .50545 L p .621 .54 .742 r
F P
0 g
s
.50547 .43198 m .49623 .47042 L .53649 .47251 L p .708 .655 .795 r
F P
0 g
s
.53649 .47251 m .53336 .43346 L .50547 .43198 L p .708 .655 .795 r
F P
0 g
s
.53336 .43346 m .53649 .47251 L .57578 .46624 L p .678 .632 .797 r
F P
0 g
s
.47965 .42471 m .45883 .46013 L .49623 .47042 L p .736 .684 .8 r
F P
0 g
s
.49623 .47042 m .50547 .43198 L .47965 .42471 L p .736 .684 .8 r
F P
0 g
s
.54689 .71255 m .54622 .67537 L .46736 .67174 L p .717 .507 .604 r
F P
0 g
s
.54622 .67537 m .54689 .71255 L .62674 .70153 L p .647 .451 .603 r
F P
0 g
s
.62674 .70153 m .62347 .66445 L .54622 .67537 L p .647 .451 .603 r
F P
0 g
s
.61806 .62579 m .62347 .66445 L .69262 .6396 L p .58 .43 .642 r
F P
0 g
s
.69262 .6396 m .68322 .60177 L .61806 .62579 L p .58 .43 .642 r
F P
0 g
s
.4006 .47577 m .37693 .51121 L .42433 .53684 L p .802 .698 .749 r
F P
0 g
s
.42433 .53684 m .44029 .49784 L .4006 .47577 L p .802 .698 .749 r
F P
0 g
s
.41113 .57628 m .42433 .53684 L .37693 .51121 L p .818 .685 .717 r
F P
0 g
s
.42796 .44249 m .4006 .47577 L .44029 .49784 L p .784 .709 .781 r
F P
0 g
s
.44029 .49784 m .45883 .46013 L .42796 .44249 L p .784 .709 .781 r
F P
0 g
s
.57578 .46624 m .56056 .42902 L .53336 .43346 L p .678 .632 .797 r
F P
0 g
s
.56056 .42902 m .57578 .46624 L .61034 .45211 L p .644 .615 .805 r
F P
0 g
s
.63355 .48781 m .61034 .45211 L .57578 .46624 L p .633 .576 .773 r
F P
0 g
s
.40078 .61545 m .39333 .65375 L .46736 .67174 L p .78 .588 .64 r
F P
0 g
s
.46538 .70888 m .46736 .67174 L .39333 .65375 L p .783 .564 .603 r
F P
0 g
s
.46736 .67174 m .46538 .70888 L .54689 .71255 L p .717 .507 .604 r
F P
0 g
s
.37693 .51121 m .35726 .54794 L .41113 .57628 L p .818 .685 .717 r
F P
0 g
s
.40078 .61545 m .41113 .57628 L .35726 .54794 L p .831 .67 .683 r
F P
0 g
s
.45851 .41231 m .42796 .44249 L .45883 .46013 L p .761 .718 .812 r
F P
0 g
s
.45883 .46013 m .47965 .42471 L .45851 .41231 L p .761 .718 .812 r
F P
0 g
s
.35726 .54794 m .34179 .58524 L .40078 .61545 L p .831 .67 .683 r
F P
0 g
s
.39333 .65375 m .40078 .61545 L .34179 .58524 L p .843 .652 .645 r
F P
0 g
s
.62347 .66445 m .62674 .70153 L .69831 .67642 L p .563 .389 .603 r
F P
0 g
s
.69831 .67642 m .69262 .6396 L .62347 .66445 L p .563 .389 .603 r
F P
0 g
s
.51558 .39647 m .50547 .43198 L .53336 .43346 L p .699 .683 .831 r
F P
0 g
s
.53336 .43346 m .52995 .39725 L .51558 .39647 L p .699 .683 .831 r
F P
0 g
s
.52995 .39725 m .53336 .43346 L .56056 .42902 L p .678 .667 .832 r
F P
0 g
s
.61034 .45211 m .63355 .48781 L .6676 .46174 L p .584 .558 .791 r
F P
0 g
s
.63355 .48781 m .65358 .52521 L .69446 .49484 L p .56 .513 .759 r
F P
0 g
s
.69446 .49484 m .6676 .46174 L .63355 .48781 L p .56 .513 .759 r
F P
0 g
s
.65358 .52521 m .67019 .56344 L .71683 .52979 L p .536 .467 .726 r
F P
0 g
s
.71683 .52979 m .69446 .49484 L .65358 .52521 L p .536 .467 .726 r
F P
0 g
s
.50233 .39266 m .47965 .42471 L .50547 .43198 L p .717 .702 .835 r
F P
0 g
s
.50547 .43198 m .51558 .39647 L .50233 .39266 L p .717 .702 .835 r
F P
0 g
s
.54711 .74746 m .54689 .71255 L .46538 .70888 L p .713 .475 .564 r
F P
0 g
s
.54689 .71255 m .54711 .74746 L .62784 .73657 L p .637 .414 .563 r
F P
0 g
s
.62784 .73657 m .62674 .70153 L .54689 .71255 L p .637 .414 .563 r
F P
0 g
s
.56056 .42902 m .54393 .39492 L .52995 .39725 L p .678 .667 .832 r
F P
0 g
s
.54393 .39492 m .56056 .42902 L .58434 .41906 L p .656 .656 .839 r
F P
0 g
s
.61034 .45211 m .58434 .41906 L .56056 .42902 L p .644 .615 .805 r
F P
0 g
s
.58434 .41906 m .61034 .45211 L .63666 .43133 L p .608 .604 .821 r
F P
0 g
s
.6676 .46174 m .63666 .43133 L .61034 .45211 L p .584 .558 .791 r
F P
0 g
s
.67019 .56344 m .68322 .60177 L .73447 .56583 L p .509 .419 .689 r
F P
0 g
s
.73447 .56583 m .71683 .52979 L .67019 .56344 L p .509 .419 .689 r
F P
0 g
s
.39333 .65375 m .38882 .69072 L .46538 .70888 L p .783 .564 .603 r
F P
0 g
s
.46472 .74384 m .46538 .70888 L .38882 .69072 L p .784 .535 .56 r
F P
0 g
s
.46538 .70888 m .46472 .74384 L .54711 .74746 L p .713 .475 .564 r
F P
0 g
s
.49158 .3862 m .45851 .41231 L .47965 .42471 L p .732 .725 .844 r
F P
0 g
s
.47965 .42471 m .50233 .39266 L .49158 .3862 L p .732 .725 .844 r
F P
0 g
s
.34179 .58524 m .33062 .62247 L .39333 .65375 L p .843 .652 .645 r
F P
0 g
s
.38882 .69072 m .39333 .65375 L .33062 .62247 L p .852 .63 .601 r
F P
0 g
s
.40688 .41906 m .37311 .44627 L .4006 .47577 L p .813 .76 .803 r
F P
0 g
s
.4006 .47577 m .42796 .44249 L .40688 .41906 L p .813 .76 .803 r
F P
0 g
s
.37693 .51121 m .4006 .47577 L .37311 .44627 L p .842 .76 .772 r
F P
0 g
s
.58434 .41906 m .55609 .38971 L .54393 .39492 L p .656 .656 .839 r
F P
0 g
s
.55609 .38971 m .58434 .41906 L .60224 .4045 L p .633 .651 .85 r
F P
0 g
s
.63666 .43133 m .60224 .4045 L .58434 .41906 L p .608 .604 .821 r
F P
0 g
s
.44431 .39596 m .40688 .41906 L .42796 .44249 L p .781 .757 .832 r
F P
0 g
s
.42796 .44249 m .45851 .41231 L .44431 .39596 L p .781 .757 .832 r
F P
0 g
s
.68322 .60177 m .69262 .6396 L .74722 .60234 L p .48 .367 .647 r
F P
0 g
s
.74722 .60234 m .73447 .56583 L .68322 .60177 L p .48 .367 .647 r
F P
0 g
s
.37311 .44627 m .34369 .47674 L .37693 .51121 L p .842 .76 .772 r
F P
0 g
s
.35726 .54794 m .37693 .51121 L .34369 .47674 L p .868 .756 .737 r
F P
0 g
s
.62674 .70153 m .62784 .73657 L .70022 .71176 L p .543 .341 .556 r
F P
0 g
s
.70022 .71176 m .69831 .67642 L .62674 .70153 L p .543 .341 .556 r
F P
0 g
s
.48449 .37774 m .44431 .39596 L .45851 .41231 L p .743 .75 .858 r
F P
0 g
s
.45851 .41231 m .49158 .3862 L .48449 .37774 L p .743 .75 .858 r
F P
0 g
s
.52995 .39725 m .52632 .36507 L .51558 .39647 L closepath p .683 .713 .871 r
F P
0 g
s
.54393 .39492 m .52632 .36507 L .52995 .39725 L closepath p .675 .707 .872 r
F P
0 g
s
.51558 .39647 m .52632 .36507 L .50233 .39266 L closepath p .69 .721 .873 r
F P
0 g
s
.54687 .77963 m .54711 .74746 L .46472 .74384 L p .706 .437 .515 r
F P
0 g
s
.54711 .74746 m .54687 .77963 L .62666 .7691 L p .623 .369 .513 r
F P
0 g
s
.62666 .7691 m .62784 .73657 L .54711 .74746 L p .623 .369 .513 r
F P
0 g
s
.34369 .47674 m .3191 .50966 L .35726 .54794 L p .868 .756 .737 r
F P
0 g
s
.34179 .58524 m .35726 .54794 L .3191 .50966 L p .891 .748 .697 r
F P
0 g
s
.55609 .38971 m .52632 .36507 L .54393 .39492 L closepath p .666 .704 .875 r
F P
0 g
s
.60224 .4045 m .63666 .43133 L .6518 .40578 L p .569 .6 .844 r
F P
0 g
s
.63666 .43133 m .6676 .46174 L .68761 .42945 L p .528 .546 .818 r
F P
0 g
s
.68761 .42945 m .6518 .40578 L .63666 .43133 L p .528 .546 .818 r
F P
0 g
s
.50233 .39266 m .52632 .36507 L .49158 .3862 L closepath p .695 .729 .877 r
F P
0 g
s
.38882 .69072 m .38731 .7259 L .46472 .74384 L p .784 .535 .56 r
F P
0 g
s
.46543 .77612 m .46472 .74384 L .38731 .7259 L p .782 .499 .508 r
F P
0 g
s
.46472 .74384 m .46543 .77612 L .54687 .77963 L p .706 .437 .515 r
F P
0 g
s
.6676 .46174 m .69446 .49484 L .71894 .45699 L p .483 .489 .787 r
F P
0 g
s
.71894 .45699 m .68761 .42945 L .6676 .46174 L p .483 .489 .787 r
F P
0 g
s
.69262 .6396 m .69831 .67642 L .75497 .63874 L p .446 .307 .599 r
F P
0 g
s
.75497 .63874 m .74722 .60234 L .69262 .6396 L p .446 .307 .599 r
F P
0 g
s
.33062 .62247 m .32385 .6591 L .38882 .69072 L p .852 .63 .601 r
F P
0 g
s
.38731 .7259 m .38882 .69072 L .32385 .6591 L p .859 .603 .55 r
F P
0 g
s
.56513 .38215 m .52632 .36507 L .55609 .38971 L closepath p .658 .702 .879 r
F P
0 g
s
.60224 .4045 m .56513 .38215 L .55609 .38971 L p .633 .651 .85 r
F P
0 g
s
.56513 .38215 m .60224 .4045 L .61228 .38674 L p .61 .652 .867 r
F P
0 g
s
.6518 .40578 m .61228 .38674 L .60224 .4045 L p .569 .6 .844 r
F P
0 g
s
.49158 .3862 m .52632 .36507 L .48449 .37774 L closepath p .698 .738 .882 r
F P
0 g
s
.69446 .49484 m .71683 .52979 L .74519 .48764 L p .435 .426 .75 r
F P
0 g
s
.74519 .48764 m .71894 .45699 L .69446 .49484 L p .435 .426 .75 r
F P
0 g
s
.3191 .50966 m .29967 .54429 L .34179 .58524 L p .891 .748 .697 r
F P
0 g
s
.33062 .62247 m .34179 .58524 L .29967 .54429 L p .912 .735 .65 r
F P
0 g
s
.62784 .73657 m .62666 .7691 L .69818 .74511 L p .517 .283 .499 r
F P
0 g
s
.69818 .74511 m .70022 .71176 L .62784 .73657 L p .517 .283 .499 r
F P
0 g
s
.57006 .373 m .52632 .36507 L .56513 .38215 L closepath p .651 .704 .886 r
F P
0 g
s
.61228 .38674 m .57006 .373 L .56513 .38215 L p .61 .652 .867 r
F P
0 g
s
.48186 .36815 m .43873 .37726 L .44431 .39596 L p .747 .776 .877 r
F P
0 g
s
.44431 .39596 m .48449 .37774 L .48186 .36815 L p .747 .776 .877 r
F P
0 g
s
.40688 .41906 m .44431 .39596 L .43873 .37726 L p .792 .801 .859 r
F P
0 g
s
.43873 .37726 m .39816 .39205 L .40688 .41906 L p .792 .801 .859 r
F P
0 g
s
.37311 .44627 m .40688 .41906 L .39816 .39205 L p .835 .821 .836 r
F P
0 g
s
.48449 .37774 m .52632 .36507 L .48186 .36815 L closepath p .698 .747 .889 r
F P
0 g
s
.71683 .52979 m .73447 .56583 L .766 .52065 L p .381 .356 .705 r
F P
0 g
s
.766 .52065 m .74519 .48764 L .71683 .52979 L p .381 .356 .705 r
F P
0 g
s
.39816 .39205 m .36123 .41199 L .37311 .44627 L p .835 .821 .836 r
F P
0 g
s
.34369 .47674 m .37311 .44627 L .36123 .41199 L p .875 .837 .805 r
F P
0 g
s
.69831 .67642 m .70022 .71176 L .75756 .67451 L p .404 .237 .538 r
F P
0 g
s
.75756 .67451 m .75497 .63874 L .69831 .67642 L p .404 .237 .538 r
F P
0 g
s
.57028 .36323 m .52632 .36507 L .57006 .373 L closepath p .645 .708 .893 r
F P
0 g
s
.57006 .373 m .61228 .38674 L .61315 .36759 L p .589 .661 .888 r
F P
0 g
s
.61315 .36759 m .57028 .36323 L .57006 .373 L p .589 .661 .888 r
F P
0 g
s
.54615 .80845 m .54687 .77963 L .46543 .77612 L p .694 .387 .453 r
F P
0 g
s
.54687 .77963 m .54615 .80845 L .6231 .79849 L p .602 .312 .448 r
F P
0 g
s
.6231 .79849 m .62666 .7691 L .54687 .77963 L p .602 .312 .448 r
F P
0 g
s
.61228 .38674 m .6518 .40578 L .65368 .37798 L p .528 .607 .876 r
F P
0 g
s
.65368 .37798 m .61315 .36759 L .61228 .38674 L p .528 .607 .876 r
F P
0 g
s
.29967 .54429 m .28559 .57995 L .33062 .62247 L p .912 .735 .65 r
F P
0 g
s
.32385 .6591 m .33062 .62247 L .28559 .57995 L p .929 .716 .592 r
F P
0 g
s
.55677 .34605 m .52632 .36507 L .5657 .3539 L closepath p .642 .724 .908 r
F P
0 g
s
.54442 .34057 m .52632 .36507 L .55677 .34605 L closepath p .645 .733 .913 r
F P
0 g
s
.53003 .3381 m .52632 .36507 L .54442 .34057 L closepath p .651 .743 .917 r
F P
0 g
s
.49088 .34975 m .52632 .36507 L .50166 .34298 L closepath p .68 .759 .911 r
F P
0 g
s
.48405 .35847 m .52632 .36507 L .49088 .34975 L closepath p .689 .758 .904 r
F P
0 g
s
.48186 .36815 m .52632 .36507 L .48405 .35847 L closepath p .695 .753 .897 r
F P
0 g
s
.5657 .3539 m .52632 .36507 L .57028 .36323 L closepath p .642 .715 .901 r
F P
0 g
s
.51522 .33894 m .52632 .36507 L .53003 .3381 L closepath p .66 .751 .918 r
F P
0 g
s
.50166 .34298 m .52632 .36507 L .51522 .33894 L closepath p .67 .757 .915 r
F P
0 g
s
.32385 .6591 m .32158 .69464 L .38731 .7259 L p .859 .603 .55 r
F P
0 g
s
.38893 .75877 m .38731 .7259 L .32158 .69464 L p .862 .565 .484 r
F P
0 g
s
.38731 .7259 m .38893 .75877 L .46543 .77612 L p .782 .499 .508 r
F P
0 g
s
.43873 .37726 m .48186 .36815 L .48405 .35847 L p .741 .8 .899 r
F P
0 g
s
.46758 .80514 m .46543 .77612 L .38893 .75877 L p .776 .451 .439 r
F P
0 g
s
.46543 .77612 m .46758 .80514 L .54615 .80845 L p .694 .387 .453 r
F P
0 g
s
.6518 .40578 m .68761 .42945 L .69074 .39402 L p .458 .544 .856 r
F P
0 g
s
.69074 .39402 m .65368 .37798 L .6518 .40578 L p .458 .544 .856 r
F P
0 g
s
.36123 .41199 m .3288 .43642 L .34369 .47674 L p .875 .837 .805 r
F P
0 g
s
.3191 .50966 m .34369 .47674 L .3288 .43642 L p .913 .848 .766 r
F P
0 g
s
.73447 .56583 m .74722 .60234 L .78111 .55535 L p .319 .274 .65 r
F P
0 g
s
.78111 .55535 m .766 .52065 L .73447 .56583 L p .319 .274 .65 r
F P
0 g
s
.57028 .36323 m .61315 .36759 L .60449 .34912 L p .573 .678 .911 r
F P
0 g
s
.60449 .34912 m .5657 .3539 L .57028 .36323 L p .573 .678 .911 r
F P
0 g
s
.48405 .35847 m .44262 .35818 L .43873 .37726 L p .741 .8 .899 r
F P
0 g
s
.39816 .39205 m .43873 .37726 L .44262 .35818 L p .789 .845 .894 r
F P
0 g
s
.62666 .7691 m .6231 .79849 L .69198 .77583 L p .48 .207 .422 r
F P
0 g
s
.69198 .77583 m .69818 .74511 L .62666 .7691 L p .48 .207 .422 r
F P
0 g
s
.44262 .35818 m .48405 .35847 L .49088 .34975 L p .724 .817 .922 r
F P
0 g
s
.68761 .42945 m .71894 .45699 L .72341 .41517 L p .377 .467 .826 r
F P
0 g
s
.72341 .41517 m .69074 .39402 L .68761 .42945 L p .377 .467 .826 r
F P
0 g
s
.3288 .43642 m .30152 .46462 L .3191 .50966 L p .913 .848 .766 r
F P
0 g
s
.29967 .54429 m .3191 .50966 L .30152 .46462 L p .948 .852 .713 r
F P
0 g
s
.5657 .3539 m .60449 .34912 L .587 .33342 L p .565 .703 .934 r
F P
0 g
s
.587 .33342 m .55677 .34605 L .5657 .3539 L p .565 .703 .934 r
F P
0 g
s
.44262 .35818 m .40327 .36422 L .39816 .39205 L p .789 .845 .894 r
F P
0 g
s
.36123 .41199 m .39816 .39205 L .40327 .36422 L p .836 .888 .878 r
F P
0 g
s
.61315 .36759 m .65368 .37798 L .6415 .35091 L p .487 .626 .913 r
F P
0 g
s
.6415 .35091 m .60449 .34912 L .61315 .36759 L p .487 .626 .913 r
F P
0 g
s
.28559 .57995 m .27703 .61607 L .32385 .6591 L p .929 .716 .592 r
F P
0 g
s
.32158 .69464 m .32385 .6591 L .27703 .61607 L p .943 .686 .519 r
F P
0 g
s
.70022 .71176 m .69818 .74511 L .75478 .7091 L p .352 .15 .46 r
F P
0 g
s
.75478 .7091 m .75756 .67451 L .70022 .71176 L p .352 .15 .46 r
F P
0 g
s
.45583 .34083 m .49088 .34975 L .50166 .34298 L p .696 .824 .944 r
F P
0 g
s
.49088 .34975 m .45583 .34083 L .44262 .35818 L p .724 .817 .922 r
F P
0 g
s
.74722 .60234 m .75497 .63874 L .79031 .59113 L p .244 .176 .578 r
F P
0 g
s
.79031 .59113 m .78111 .55535 L .74722 .60234 L p .244 .176 .578 r
F P
0 g
s
.55677 .34605 m .587 .33342 L .5625 .3224 L p .569 .734 .953 r
F P
0 g
s
.5625 .3224 m .54442 .34057 L .55677 .34605 L p .569 .734 .953 r
F P
0 g
s
.32158 .69464 m .32401 .72856 L .38893 .75877 L p .862 .565 .484 r
F P
0 g
s
.39384 .78874 m .38893 .75877 L .32401 .72856 L p .858 .512 .395 r
F P
0 g
s
.38893 .75877 m .39384 .78874 L .46758 .80514 L p .776 .451 .439 r
F P
0 g
s
.71894 .45699 m .74519 .48764 L .75099 .44078 L p .279 .374 .781 r
F P
0 g
s
.75099 .44078 m .72341 .41517 L .71894 .45699 L p .279 .374 .781 r
F P
0 g
s
.54491 .83314 m .54615 .80845 L .46758 .80514 L p .672 .318 .365 r
F P
0 g
s
.54615 .80845 m .54491 .83314 L .617 .82397 L p .569 .232 .358 r
F P
0 g
s
.617 .82397 m .6231 .79849 L .54615 .80845 L p .569 .232 .358 r
F P
0 g
s
.40327 .36422 m .44262 .35818 L .45583 .34083 L p .761 .881 .932 r
F P
0 g
s
.4771 .32725 m .50166 .34298 L .51522 .33894 L p .658 .817 .96 r
F P
0 g
s
.50166 .34298 m .4771 .32725 L .45583 .34083 L p .696 .824 .944 r
F P
0 g
s
.54442 .34057 m .5625 .3224 L .53375 .31741 L p .587 .767 .965 r
F P
0 g
s
.53375 .31741 m .53003 .3381 L .54442 .34057 L p .587 .767 .965 r
F P
0 g
s
.40327 .36422 m .36712 .37637 L .36123 .41199 L p .836 .888 .878 r
F P
0 g
s
.3288 .43642 m .36123 .41199 L .36712 .37637 L p .882 .927 .847 r
F P
0 g
s
.47127 .83009 m .46758 .80514 L .39384 .78874 L p .758 .382 .341 r
F P
0 g
s
.46758 .80514 m .47127 .83009 L .54491 .83314 L p .672 .318 .365 r
F P
0 g
s
.30152 .46462 m .27985 .49589 L .29967 .54429 L p .948 .852 .713 r
F P
0 g
s
.28559 .57995 m .29967 .54429 L .27985 .49589 L p .978 .845 .643 r
F P
0 g
s
.50411 .3191 m .51522 .33894 L .53003 .3381 L p .619 .797 .967 r
F P
0 g
s
.51522 .33894 m .50411 .3191 L .4771 .32725 L p .658 .817 .96 r
F P
0 g
s
.65368 .37798 m .69074 .39402 L .67565 .35922 L p .374 .553 .902 r
F P
0 g
s
.67565 .35922 m .6415 .35091 L .65368 .37798 L p .374 .553 .902 r
F P
0 g
s
.53003 .3381 m .53375 .31741 L .50411 .3191 L p .619 .797 .967 r
F P
0 g
s
.60449 .34912 m .6415 .35091 L .61609 .32771 L p .453 .661 .951 r
F P
0 g
s
.61609 .32771 m .587 .33342 L .60449 .34912 L p .453 .661 .951 r
F P
0 g
s
.27703 .61607 m .27417 .65209 L .32158 .69464 L p .943 .686 .519 r
F P
0 g
s
.32401 .72856 m .32158 .69464 L .27417 .65209 L p .947 .639 .42 r
F P
0 g
s
.6231 .79849 m .617 .82397 L .68138 .80313 L p .425 .102 .312 r
F P
0 g
s
.68138 .80313 m .69198 .77583 L .6231 .79849 L p .425 .102 .312 r
F P
0 g
s
.74519 .48764 m .766 .52065 L .77298 .47017 L p .159 .255 .715 r
F P
0 g
s
.77298 .47017 m .75099 .44078 L .74519 .48764 L p .159 .255 .715 r
F P
0 g
s
.69818 .74511 m .69198 .77583 L .74635 .74186 L p .279 .034 .352 r
F P
0 g
s
.74635 .74186 m .75478 .7091 L .69818 .74511 L p .279 .034 .352 r
F P
0 g
s
.75497 .63874 m .75756 .67451 L .79339 .62742 L p .15 .054 .481 r
F P
0 g
s
.79339 .62742 m .79031 .59113 L .75497 .63874 L p .15 .054 .481 r
F P
0 g
s
.42224 .33869 m .45583 .34083 L .4771 .32725 L p .702 .896 .967 r
F P
0 g
s
.45583 .34083 m .42224 .33869 L .40327 .36422 L p .761 .881 .932 r
F P
0 g
s
.36712 .37637 m .40327 .36422 L .42224 .33869 L p .793 .944 .923 r
F P
0 g
s
.36712 .37637 m .33512 .39421 L .3288 .43642 L p .882 .927 .847 r
F P
0 g
s
.30152 .46462 m .3288 .43642 L .33512 .39421 L p .922 .955 .792 r
F P
0 g
s
.27985 .49589 m .26408 .52953 L .28559 .57995 L p .978 .845 .643 r
F P
0 g
s
.27703 .61607 m .28559 .57995 L .26408 .52953 L p .997 .822 .545 r
F P
0 g
s
.69074 .39402 m .72341 .41517 L .706 .37378 L p .221 .446 .866 r
F P
0 g
s
.706 .37378 m .67565 .35922 L .69074 .39402 L p .221 .446 .866 r
F P
0 g
s
.587 .33342 m .61609 .32771 L .57999 .31131 L p .439 .71 .98 r
F P
0 g
s
.57999 .31131 m .5625 .3224 L .587 .33342 L p .439 .71 .98 r
F P
0 g
s
.32401 .72856 m .33138 .76021 L .39384 .78874 L p .858 .512 .395 r
F P
0 g
s
.40225 .81499 m .39384 .78874 L .33138 .76021 L p .838 .429 .267 r
F P
0 g
s
.39384 .78874 m .40225 .81499 L .47127 .83009 L p .758 .382 .341 r
F P
0 g
s
.766 .52065 m .78111 .55535 L .78901 .50266 L p .01 .104 .616 r
F P
0 g
s
.78901 .50266 m .77298 .47017 L .766 .52065 L p .01 .104 .616 r
F P
0 g
s
.4534 .31854 m .4771 .32725 L .50411 .3191 L p .615 .878 .99 r
F P
0 g
s
.4771 .32725 m .4534 .31854 L .42224 .33869 L p .702 .896 .967 r
F P
0 g
s
.54312 .85272 m .54491 .83314 L .47127 .83009 L p .629 .211 .232 r
F P
0 g
s
.54491 .83314 m .54312 .85272 L .60822 .84455 L p .512 .112 .219 r
F P
0 g
s
.60822 .84455 m .617 .82397 L .54491 .83314 L p .512 .112 .219 r
F P
0 g
s
.6415 .35091 m .67565 .35922 L .64312 .32918 L p .279 .578 .941 r
F P
0 g
s
.64312 .32918 m .61609 .32771 L .6415 .35091 L p .279 .578 .941 r
F P
0 g
s
.47658 .85 m .47127 .83009 L .40225 .81499 L p .717 .271 .191 r
F P
0 g
s
.47127 .83009 m .47658 .85 L .54312 .85272 L p .629 .211 .232 r
F P
0 g
s
.27417 .65209 m .27724 .68744 L .32401 .72856 L p .947 .639 .42 r
F P
0 g
s
.33138 .76021 m .32401 .72856 L .27724 .68744 L p .932 .562 .28 r
F P
0 g
s
.5625 .3224 m .57999 .31131 L .53735 .30386 L p .461 .77 .997 r
F P
0 g
s
.53735 .30386 m .53375 .31741 L .5625 .3224 L p .461 .77 .997 r
F P
0 g
s
.75756 .67451 m .75478 .7091 L .79009 .66361 L p .028 0 .347 r
F P
0 g
s
.79009 .66361 m .79339 .62742 L .75756 .67451 L p .028 0 .347 r
F P
0 g
s
.33512 .39421 m .30802 .41718 L .30152 .46462 L p .922 .955 .792 r
F P
0 g
s
.27985 .49589 m .30152 .46462 L .30802 .41718 L p .944 .961 .696 r
F P
0 g
s
.49335 .30639 m .50411 .3191 L .53375 .31741 L p .525 .831 1 r
F P
0 g
s
.50411 .3191 m .49335 .30639 L .4534 .31854 L p .615 .878 .99 r
F P
0 g
s
.42224 .33869 m .39113 .34342 L .36712 .37637 L p .793 .944 .923 r
F P
0 g
s
.33512 .39421 m .36712 .37637 L .39113 .34342 L p .806 .993 .873 r
F P
0 g
s
.53375 .31741 m .53735 .30386 L .49335 .30639 L p .525 .831 1 r
F P
0 g
s
.72341 .41517 m .75099 .44078 L .73179 .3941 L p .014 .288 .785 r
F P
0 g
s
.73179 .3941 m .706 .37378 L .72341 .41517 L p .014 .288 .785 r
F P
0 g
s
.26408 .52953 m .25446 .56493 L .27703 .61607 L p .997 .822 .545 r
F P
0 g
s
.27417 .65209 m .27703 .61607 L .25446 .56493 L p .995 .769 .408 r
F P
0 g
s
.69198 .77583 m .68138 .80313 L .73197 .77197 L p .173 0 .192 r
F P
0 g
s
.73197 .77197 m .74635 .74186 L .69198 .77583 L p .173 0 .192 r
F P
0 g
s
.617 .82397 m .60822 .84455 L .66617 .82603 L p .334 0 .143 r
F P
0 g
s
.66617 .82603 m .68138 .80313 L .617 .82397 L p .334 0 .143 r
F P
0 g
s
.39113 .34342 m .42224 .33869 L .4534 .31854 L p .675 .955 .95 r
F P
0 g
s
.78111 .55535 m .79031 .59113 L .7988 .53764 L p 0 0 .47 r
F P
0 g
s
.7988 .53764 m .78901 .50266 L .78111 .55535 L p 0 0 .47 r
F P
0 g
s
.61609 .32771 m .64312 .32918 L .59633 .30779 L p .202 .618 .949 r
F P
0 g
s
.59633 .30779 m .57999 .31131 L .61609 .32771 L p .202 .618 .949 r
F P
0 g
s
.33138 .76021 m .34398 .78879 L .40225 .81499 L p .838 .429 .267 r
F P
0 g
s
.41433 .83657 m .40225 .81499 L .34398 .78879 L p .778 .291 .067 r
F P
0 g
s
.40225 .81499 m .41433 .83657 L .47658 .85 L p .717 .271 .191 r
F P
0 g
s
.30802 .41718 m .28635 .44465 L .27985 .49589 L p .944 .961 .696 r
F P
0 g
s
.26408 .52953 m .27985 .49589 L .28635 .44465 L p .927 .921 .541 r
F P
0 g
s
.67565 .35922 m .706 .37378 L .66731 .33779 L p .009 .417 .858 r
F P
0 g
s
.66731 .33779 m .64312 .32918 L .67565 .35922 L p .009 .417 .858 r
F P
0 g
s
.75478 .7091 m .74635 .74186 L .78008 .69903 L p 0 0 .155 r
F P
0 g
s
.78008 .69903 m .79009 .66361 L .75478 .7091 L p 0 0 .155 r
F P
0 g
s
.27724 .68744 m .28656 .72145 L .33138 .76021 L p .932 .562 .28 r
F P
0 g
s
.34398 .78879 m .33138 .76021 L .28656 .72145 L p .873 .432 .074 r
F P
0 g
s
.75099 .44078 m .77298 .47017 L .75247 .41963 L p 0 .065 .629 r
F P
0 g
s
.75247 .41963 m .73179 .3941 L .75099 .44078 L p 0 .065 .629 r
F P
0 g
s
.39113 .34342 m .36338 .35487 L .33512 .39421 L p .806 .993 .873 r
F P
0 g
s
.30802 .41718 m .33512 .39421 L .36338 .35487 L p .765 .984 .739 r
F P
0 g
s
.25446 .56493 m .25123 .60149 L .27417 .65209 L p .995 .769 .408 r
F P
0 g
s
.27724 .68744 m .27417 .65209 L .25123 .60149 L p .949 .667 .215 r
F P
0 g
s
.43131 .31724 m .4534 .31854 L .49335 .30639 L p .486 .889 .941 r
F P
0 g
s
.4534 .31854 m .43131 .31724 L .39113 .34342 L p .675 .955 .95 r
F P
0 g
s
.54076 .86608 m .54312 .85272 L .47658 .85 L p .534 .032 .009 r
F P
0 g
s
.54312 .85272 m .54076 .86608 L .59668 .85913 L p .398 0 0 r
F P
0 g
s
.59668 .85913 m .60822 .84455 L .54312 .85272 L p .398 0 0 r
F P
0 g
s
.79031 .59113 m .79339 .62742 L .80208 .57446 L p 0 0 .263 r
F P
0 g
s
.80208 .57446 m .7988 .53764 L .79031 .59113 L p 0 0 .263 r
F P
0 g
s
.48356 .86377 m .47658 .85 L .41433 .83657 L p .615 .081 0 r
F P
0 g
s
.47658 .85 m .48356 .86377 L .54076 .86608 L p .534 .032 .009 r
F P
0 g
s
.68138 .80313 m .66617 .82603 L .7114 .79843 L p .01 0 0 r
F P
0 g
s
.7114 .79843 m .73197 .77197 L .68138 .80313 L p .01 0 0 r
F P
0 g
s
.57999 .31131 m .59633 .30779 L .54073 .29805 L p .199 .682 .929 r
F P
0 g
s
.54073 .29805 m .53735 .30386 L .57999 .31131 L p .199 .682 .929 r
F P
0 g
s
.36338 .35487 m .39113 .34342 L .43131 .31724 L p .559 .932 .814 r
F P
0 g
s
.48328 .30136 m .49335 .30639 L .53735 .30386 L p .301 .779 .922 r
F P
0 g
s
.49335 .30639 m .48328 .30136 L .43131 .31724 L p .486 .889 .941 r
F P
0 g
s
.60822 .84455 m .59668 .85913 L .64624 .84341 L p .17 0 0 r
F P
0 g
s
.64624 .84341 m .66617 .82603 L .60822 .84455 L p .17 0 0 r
F P
0 g
s
.28635 .44465 m .27052 .47596 L .26408 .52953 L p .927 .921 .541 r
F P
0 g
s
.25446 .56493 m .26408 .52953 L .27052 .47596 L p .84 .805 .315 r
F P
0 g
s
.53735 .30386 m .54073 .29805 L .48328 .30136 L p .301 .779 .922 r
F P
0 g
s
.706 .37378 m .73179 .3941 L .688 .35329 L p 0 .147 .637 r
F P
0 g
s
.688 .35329 m .66731 .33779 L .706 .37378 L p 0 .147 .637 r
F P
0 g
s
.77298 .47017 m .78901 .50266 L .76761 .44973 L p 0 0 .382 r
F P
0 g
s
.76761 .44973 m .75247 .41963 L .77298 .47017 L p 0 0 .382 r
F P
0 g
s
.74635 .74186 m .73197 .77197 L .76305 .73281 L p 0 0 0 r
F P
0 g
s
.76305 .73281 m .78008 .69903 L .74635 .74186 L p 0 0 0 r
F P
0 g
s
.25123 .60149 m .25469 .63858 L .27724 .68744 L p .949 .667 .215 r
F P
0 g
s
.28656 .72145 m .27724 .68744 L .25469 .63858 L p .826 .493 0 r
F P
0 g
s
.36338 .35487 m .33972 .37269 L .30802 .41718 L p .765 .984 .739 r
F P
0 g
s
.28635 .44465 m .30802 .41718 L .33972 .37269 L p .626 .857 .487 r
F P
0 g
s
.64312 .32918 m .66731 .33779 L .61103 .31203 L p 0 .382 .745 r
F P
0 g
s
.61103 .31203 m .59633 .30779 L .64312 .32918 L p 0 .382 .745 r
F P
0 g
s
.34398 .78879 m .36203 .81331 L .41433 .83657 L p .778 .291 .067 r
F P
0 g
s
.43018 .85235 m .41433 .83657 L .36203 .81331 L p .621 .054 0 r
F P
0 g
s
.41433 .83657 m .43018 .85235 L .48356 .86377 L p .615 .081 0 r
F P
0 g
s
.28656 .72145 m .30242 .75329 L .34398 .78879 L p .873 .432 .074 r
F P
0 g
s
.36203 .81331 m .34398 .78879 L .30242 .75329 L p .722 .216 0 r
F P
0 g
s
.79339 .62742 m .79009 .66361 L .79856 .61251 L p 0 0 0 r
F P
0 g
s
.79856 .61251 m .80208 .57446 L .79339 .62742 L p 0 0 0 r
F P
0 g
s
.43131 .31724 m .41148 .32342 L .36338 .35487 L p .559 .932 .814 r
F P
0 g
s
.41148 .32342 m .43131 .31724 L .48328 .30136 L p 0 0 0 r
F P
0 g
s
.27052 .47596 m .26083 .51048 L .25446 .56493 L p .84 .805 .315 r
F P
0 g
s
.25123 .60149 m .25446 .56493 L .26083 .51048 L p 0 0 0 r
F P
0 g
s
.66617 .82603 m .64624 .84341 L .6846 .8201 L p 0 0 0 r
F P
0 g
s
.6846 .8201 m .7114 .79843 L .66617 .82603 L p 0 0 0 r
F P
0 g
s
.33972 .37269 m .36338 .35487 L .41148 .32342 L p 0 0 0 r
F P
0 g
s
.53785 .87206 m .54076 .86608 L .48356 .86377 L p .313 0 0 r
F P
0 g
s
.54076 .86608 m .53785 .87206 L .58242 .86654 L p .16 0 0 r
F P
0 g
s
.58242 .86654 m .59668 .85913 L .54076 .86608 L p .16 0 0 r
F P
0 g
s
.78901 .50266 m .7988 .53764 L .77689 .48377 L p .793 .471 0 r
F P
0 g
s
.77689 .48377 m .76761 .44973 L .78901 .50266 L p .793 .471 0 r
F P
0 g
s
.4922 .87022 m .48356 .86377 L .43018 .85235 L p .366 0 0 r
F P
0 g
s
.48356 .86377 m .4922 .87022 L .53785 .87206 L p .313 0 0 r
F P
0 g
s
.59633 .30779 m .61103 .31203 L .54377 .30025 L p .208 0 0 r
F P
0 g
s
.54377 .30025 m .54073 .29805 L .59633 .30779 L p .208 0 0 r
F P
0 g
s
.25469 .63858 m .26515 .6755 L .28656 .72145 L p .826 .493 0 r
F P
0 g
s
.30242 .75329 m .28656 .72145 L .26515 .6755 L p 0 0 .338 r
F P
0 g
s
.73179 .3941 m .75247 .41963 L .70467 .37523 L p .675 .167 0 r
F P
0 g
s
.70467 .37523 m .688 .35329 L .73179 .3941 L p .675 .167 0 r
F P
0 g
s
.73197 .77197 m .7114 .79843 L .73881 .76391 L p 0 0 0 r
F P
0 g
s
.73881 .76391 m .76305 .73281 L .73197 .77197 L p 0 0 0 r
F P
0 g
s
.33972 .37269 m .32071 .39636 L .28635 .44465 L p .626 .857 .487 r
F P
0 g
s
.27052 .47596 m .28635 .44465 L .32071 .39636 L p 0 0 0 r
F P
0 g
s
.59668 .85913 m .58242 .86654 L .62171 .8541 L p 0 0 0 r
F P
0 g
s
.62171 .8541 m .64624 .84341 L .59668 .85913 L p 0 0 0 r
F P
0 g
s
.47421 .30426 m .48328 .30136 L .54073 .29805 L p .076 0 0 r
F P
0 g
s
.48328 .30136 m .47421 .30426 L .41148 .32342 L p 0 0 0 r
F P
0 g
s
.79009 .66361 m .78008 .69903 L .78791 .65102 L p .798 .785 .284 r
F P
0 g
s
.78791 .65102 m .79856 .61251 L .79009 .66361 L p .798 .785 .284 r
F P
0 g
s
.54073 .29805 m .54377 .30025 L .47421 .30426 L p .076 0 0 r
F P
0 g
s
.30242 .75329 m .32507 .78194 L .36203 .81331 L p .722 .216 0 r
F P
0 g
s
.36203 .81331 m .38561 .83266 L .43018 .85235 L p .621 .054 0 r
F P
0 g
s
.38561 .83266 m .36203 .81331 L .32507 .78194 L p 0 .088 .561 r
F P
0 g
s
.66731 .33779 m .688 .35329 L .62365 .32393 L p .547 0 0 r
F P
0 g
s
.62365 .32393 m .61103 .31203 L .66731 .33779 L p .547 0 0 r
F P
0 g
s
.26083 .51048 m .25758 .54757 L .25123 .60149 L p 0 0 0 r
F P
0 g
s
.25469 .63858 m .25123 .60149 L .25758 .54757 L p 0 0 .239 r
F P
0 g
s
.44974 .86117 m .43018 .85235 L .38561 .83266 L p .294 0 0 r
F P
0 g
s
.43018 .85235 m .44974 .86117 L .4922 .87022 L p .366 0 0 r
F P
0 g
s
.7988 .53764 m .80208 .57446 L .78001 .5211 L p .937 .662 .192 r
F P
0 g
s
.78001 .5211 m .77689 .48377 L .7988 .53764 L p .937 .662 .192 r
F P
0 g
s
.41148 .32342 m .39448 .33692 L .33972 .37269 L p 0 0 0 r
F P
0 g
s
.32071 .39636 m .33972 .37269 L .39448 .33692 L p 0 0 0 r
F P
0 g
s
.39448 .33692 m .41148 .32342 L .47421 .30426 L p .125 0 0 r
F P
0 g
s
.26515 .6755 m .28292 .71136 L .30242 .75329 L p 0 0 .338 r
F P
0 g
s
.32507 .78194 m .30242 .75329 L .28292 .71136 L p 0 .036 .601 r
F P
0 g
s
.64624 .84341 m .62171 .8541 L .6518 .83576 L p .465 .878 .743 r
F P
0 g
s
.6518 .83576 m .6846 .8201 L .64624 .84341 L p .465 .878 .743 r
F P
0 g
s
.32071 .39636 m .30675 .42529 L .27052 .47596 L p 0 0 0 r
F P
0 g
s
.26083 .51048 m .27052 .47596 L .30675 .42529 L p 0 0 .126 r
F P
0 g
s
.75247 .41963 m .76761 .44973 L .71692 .40306 L p .858 .408 .031 r
F P
0 g
s
.71692 .40306 m .70467 .37523 L .75247 .41963 L p .858 .408 .031 r
F P
0 g
s
.78008 .69903 m .76305 .73281 L .76985 .68909 L p .897 .919 .526 r
F P
0 g
s
.76985 .68909 m .78791 .65102 L .78008 .69903 L p .897 .919 .526 r
F P
0 g
s
.7114 .79843 m .6846 .8201 L .70741 .79112 L p .694 .957 .702 r
F P
0 g
s
.70741 .79112 m .73881 .76391 L .7114 .79843 L p .694 .957 .702 r
F P
0 g
s
.53441 .86959 m .53785 .87206 L .4922 .87022 L p .086 .64 .809 r
F P
0 g
s
.53785 .87206 m .53441 .86959 L .56563 .86572 L p .212 .736 .825 r
F P
0 g
s
.56563 .86572 m .58242 .86654 L .53785 .87206 L p .212 .736 .825 r
F P
0 g
s
.25758 .54757 m .26107 .58656 L .25469 .63858 L p 0 0 .239 r
F P
0 g
s
.26515 .6755 m .25469 .63858 L .26107 .58656 L p 0 0 .462 r
F P
0 g
s
.61103 .31203 m .62365 .32393 L .54639 .31047 L p .522 0 0 r
F P
0 g
s
.54639 .31047 m .54377 .30025 L .61103 .31203 L p .522 0 0 r
F P
0 g
s
.50239 .8683 m .4922 .87022 L .44974 .86117 L p .054 .593 .851 r
F P
0 g
s
.4922 .87022 m .50239 .8683 L .53441 .86959 L p .086 .64 .809 r
F P
0 g
s
.32507 .78194 m .3545 .80623 L .38561 .83266 L p 0 .088 .561 r
F P
0 g
s
.38561 .83266 m .41456 .84563 L .44974 .86117 L p .294 0 0 r
F P
0 g
s
.41456 .84563 m .38561 .83266 L .3545 .80623 L p 0 .386 .825 r
F P
0 g
s
.58242 .86654 m .56563 .86572 L .59299 .85702 L p .406 .857 .884 r
F P
0 g
s
.59299 .85702 m .62171 .8541 L .58242 .86654 L p .406 .857 .884 r
F P
0 g
s
.688 .35329 m .70467 .37523 L .63386 .34317 L p .745 .237 .006 r
F P
0 g
s
.63386 .34317 m .62365 .32393 L .688 .35329 L p .745 .237 .006 r
F P
0 g
s
.46641 .31505 m .47421 .30426 L .54377 .30025 L p .383 0 0 r
F P
0 g
s
.47421 .30426 m .46641 .31505 L .39448 .33692 L p .125 0 0 r
F P
0 g
s
.80208 .57446 m .79856 .61251 L .77666 .56105 L p .993 .775 .403 r
F P
0 g
s
.77666 .56105 m .78001 .5211 L .80208 .57446 L p .993 .775 .403 r
F P
0 g
s
.54377 .30025 m .54639 .31047 L .46641 .31505 L p .383 0 0 r
F P
0 g
s
.47272 .86196 m .44974 .86117 L .41456 .84563 L p .114 .585 .915 r
F P
0 g
s
.44974 .86117 m .47272 .86196 L .50239 .8683 L p .054 .593 .851 r
F P
0 g
s
.30675 .42529 m .29819 .45886 L .26083 .51048 L p 0 0 .126 r
F P
0 g
s
.25758 .54757 m .26083 .51048 L .29819 .45886 L p .009 0 .338 r
F P
0 g
s
.28292 .71136 m .30816 .74508 L .32507 .78194 L p 0 .036 .601 r
F P
0 g
s
.3545 .80623 m .32507 .78194 L .30816 .74508 L p 0 .28 .783 r
F P
0 g
s
.76305 .73281 m .73881 .76391 L .74427 .72559 L p .921 .974 .699 r
F P
0 g
s
.74427 .72559 m .76985 .68909 L .76305 .73281 L p .921 .974 .699 r
F P
0 g
s
.39448 .33692 m .38077 .35737 L .32071 .39636 L p 0 0 0 r
F P
0 g
s
.30675 .42529 m .32071 .39636 L .38077 .35737 L p .159 0 .16 r
F P
0 g
s
.76761 .44973 m .77689 .48377 L .72445 .43617 L p .929 .552 .262 r
F P
0 g
s
.72445 .43617 m .71692 .40306 L .76761 .44973 L p .929 .552 .262 r
F P
0 g
s
.6846 .8201 m .6518 .83576 L .66928 .81314 L p .749 .993 .871 r
F P
0 g
s
.66928 .81314 m .70741 .79112 L .6846 .8201 L p .749 .993 .871 r
F P
0 g
s
.26107 .58656 m .2716 .62669 L .26515 .6755 L p 0 0 .462 r
F P
0 g
s
.28292 .71136 m .26515 .6755 L .2716 .62669 L p 0 .1 .623 r
F P
0 g
s
.38077 .35737 m .39448 .33692 L .46641 .31505 L p .332 0 .085 r
F P
0 g
s
.62171 .8541 m .59299 .85702 L .61367 .84428 L p .605 .943 .937 r
F P
0 g
s
.61367 .84428 m .6518 .83576 L .62171 .8541 L p .605 .943 .937 r
F P
0 g
s
.79856 .61251 m .78791 .65102 L .76657 .6028 L p .998 .835 .553 r
F P
0 g
s
.76657 .6028 m .77666 .56105 L .79856 .61251 L p .998 .835 .553 r
F P
0 g
s
.3545 .80623 m .39038 .82491 L .41456 .84563 L p 0 .386 .825 r
F P
0 g
s
.44836 .85112 m .41456 .84563 L .39038 .82491 L p .23 .589 .947 r
F P
0 g
s
.41456 .84563 m .44836 .85112 L .47272 .86196 L p .114 .585 .915 r
F P
0 g
s
.62365 .32393 m .63386 .34317 L .54851 .32844 L p .664 .196 .131 r
F P
0 g
s
.54851 .32844 m .54639 .31047 L .62365 .32393 L p .664 .196 .131 r
F P
0 g
s
.70467 .37523 m .71692 .40306 L .64138 .36927 L p .82 .397 .239 r
F P
0 g
s
.64138 .36927 m .63386 .34317 L .70467 .37523 L p .82 .397 .239 r
F P
0 g
s
.29819 .45886 m .29531 .49641 L .25758 .54757 L p .009 0 .338 r
F P
0 g
s
.26107 .58656 m .25758 .54757 L .29531 .49641 L p .144 .054 .486 r
F P
0 g
s
.73881 .76391 m .70741 .79112 L .71136 .75918 L p .899 .976 .81 r
F P
0 g
s
.71136 .75918 m .74427 .72559 L .73881 .76391 L p .899 .976 .81 r
F P
0 g
s
.53052 .8579 m .53441 .86959 L .50239 .8683 L p .427 .8 .993 r
F P
0 g
s
.53441 .86959 m .53052 .8579 L .54672 .85587 L p .488 .844 .994 r
F P
0 g
s
.54672 .85587 m .56563 .86572 L .53441 .86959 L p .488 .844 .994 r
F P
0 g
s
.30816 .74508 m .34075 .7754 L .3545 .80623 L p 0 .28 .783 r
F P
0 g
s
.39038 .82491 m .3545 .80623 L .34075 .7754 L p .18 .461 .885 r
F P
0 g
s
.51389 .85722 m .50239 .8683 L .47272 .86196 L p .4 .76 .994 r
F P
0 g
s
.50239 .8683 m .51389 .85722 L .53052 .8579 L p .427 .8 .993 r
F P
0 g
s
.2716 .62669 m .28943 .667 L .28292 .71136 L p 0 .1 .623 r
F P
0 g
s
.30816 .74508 m .28292 .71136 L .28943 .667 L p .136 .265 .733 r
F P
0 g
s
.77689 .48377 m .78001 .5211 L .72698 .47391 L p .946 .636 .418 r
F P
0 g
s
.72698 .47391 m .72445 .43617 L .77689 .48377 L p .946 .636 .418 r
F P
0 g
s
.38077 .35737 m .37067 .38425 L .30675 .42529 L p .159 0 .16 r
F P
0 g
s
.29819 .45886 m .30675 .42529 L .37067 .38425 L p .284 .03 .341 r
F P
0 g
s
.56563 .86572 m .54672 .85587 L .56082 .85134 L p .568 .879 .993 r
F P
0 g
s
.56082 .85134 m .59299 .85702 L .56563 .86572 L p .568 .879 .993 r
F P
0 g
s
.4601 .33345 m .46641 .31505 L .54639 .31047 L p .534 .095 .152 r
F P
0 g
s
.46641 .31505 m .4601 .33345 L .38077 .35737 L p .332 0 .085 r
F P
0 g
s
.6518 .83576 m .61367 .84428 L .62536 .8287 L p .739 .954 .945 r
F P
0 g
s
.62536 .8287 m .66928 .81314 L .6518 .83576 L p .739 .954 .945 r
F P
0 g
s
.54639 .31047 m .54851 .32844 L .4601 .33345 L p .534 .095 .152 r
F P
0 g
s
.49853 .85391 m .47272 .86196 L .44836 .85112 L p .407 .726 .99 r
F P
0 g
s
.47272 .86196 m .49853 .85391 L .51389 .85722 L p .4 .76 .994 r
F P
0 g
s
.78791 .65102 m .76985 .68909 L .74952 .64536 L p .977 .862 .659 r
F P
0 g
s
.74952 .64536 m .76657 .6028 L .78791 .65102 L p .977 .862 .659 r
F P
0 g
s
.37067 .38425 m .38077 .35737 L .4601 .33345 L p .442 .099 .286 r
F P
0 g
s
.59299 .85702 m .56082 .85134 L .57132 .84475 L p .645 .895 .984 r
F P
0 g
s
.57132 .84475 m .61367 .84428 L .59299 .85702 L p .645 .895 .984 r
F P
0 g
s
.70741 .79112 m .66928 .81314 L .67173 .78842 L p .853 .95 .878 r
F P
0 g
s
.67173 .78842 m .71136 .75918 L .70741 .79112 L p .853 .95 .878 r
F P
0 g
s
.29531 .49641 m .2984 .53725 L .26107 .58656 L p .144 .054 .486 r
F P
0 g
s
.2716 .62669 m .26107 .58656 L .2984 .53725 L p .245 .187 .591 r
F P
0 g
s
.28943 .667 m .31463 .70631 L .30816 .74508 L p .136 .265 .733 r
F P
0 g
s
.34075 .7754 m .30816 .74508 L .31463 .70631 L p .263 .396 .809 r
F P
0 g
s
.34075 .7754 m .38015 .80094 L .39038 .82491 L p .18 .461 .885 r
F P
0 g
s
.4319 .83679 m .39038 .82491 L .38015 .80094 L p .352 .59 .934 r
F P
0 g
s
.39038 .82491 m .4319 .83679 L .44836 .85112 L p .23 .589 .947 r
F P
0 g
s
.48605 .84828 m .44836 .85112 L .4319 .83679 L p .439 .7 .976 r
F P
0 g
s
.44836 .85112 m .48605 .84828 L .49853 .85391 L p .407 .726 .99 r
F P
0 g
s
.78001 .5211 m .77666 .56105 L .72426 .51557 L p .941 .688 .526 r
F P
0 g
s
.72426 .51557 m .72698 .47391 L .78001 .5211 L p .941 .688 .526 r
F P
0 g
s
.71692 .40306 m .72445 .43617 L .64601 .40165 L p .844 .492 .386 r
F P
0 g
s
.64601 .40165 m .64138 .36927 L .71692 .40306 L p .844 .492 .386 r
F P
0 g
s
.76985 .68909 m .74427 .72559 L .72549 .68747 L p .943 .872 .738 r
F P
0 g
s
.72549 .68747 m .74952 .64536 L .76985 .68909 L p .943 .872 .738 r
F P
0 g
s
.63386 .34317 m .64138 .36927 L .55008 .35371 L p .721 .332 .313 r
F P
0 g
s
.55008 .35371 m .54851 .32844 L .63386 .34317 L p .721 .332 .313 r
F P
0 g
s
.37067 .38425 m .36445 .41696 L .29819 .45886 L p .284 .03 .341 r
F P
0 g
s
.29531 .49641 m .29819 .45886 L .36445 .41696 L p .365 .159 .461 r
F P
0 g
s
.61367 .84428 m .57132 .84475 L .57707 .83677 L p .702 .887 .966 r
F P
0 g
s
.57707 .83677 m .62536 .8287 L .61367 .84428 L p .702 .887 .966 r
F P
0 g
s
.52632 .83667 m .53052 .8579 L .51389 .85722 L closepath p .588 .797 .979 r
F P
0 g
s
.52632 .83667 m .54672 .85587 L .53052 .8579 L closepath p .603 .807 .978 r
F P
0 g
s
.66928 .81314 m .62536 .8287 L .62652 .81185 L p .796 .909 .918 r
F P
0 g
s
.62652 .81185 m .67173 .78842 L .66928 .81314 L p .796 .909 .918 r
F P
0 g
s
.52632 .83667 m .51389 .85722 L .49853 .85391 L closepath p .578 .784 .977 r
F P
0 g
s
.2984 .53725 m .30771 .58054 L .2716 .62669 L p .245 .187 .591 r
F P
0 g
s
.28943 .667 m .2716 .62669 L .30771 .58054 L p .323 .293 .67 r
F P
0 g
s
.45544 .359 m .4601 .33345 L .54851 .32844 L p .604 .24 .325 r
F P
0 g
s
.4601 .33345 m .45544 .359 L .37067 .38425 L p .442 .099 .286 r
F P
0 g
s
.31463 .70631 m .34694 .74321 L .34075 .7754 L p .263 .396 .809 r
F P
0 g
s
.38015 .80094 m .34075 .7754 L .34694 .74321 L p .366 .502 .863 r
F P
0 g
s
.52632 .83667 m .56082 .85134 L .54672 .85587 L closepath p .621 .814 .975 r
F P
0 g
s
.38015 .80094 m .42532 .82036 L .4319 .83679 L p .352 .59 .934 r
F P
0 g
s
.4778 .8409 m .4319 .83679 L .42532 .82036 L p .483 .682 .954 r
F P
0 g
s
.4319 .83679 m .4778 .8409 L .48605 .84828 L p .439 .7 .976 r
F P
0 g
s
.52632 .83667 m .49853 .85391 L .48605 .84828 L closepath p .574 .771 .972 r
F P
0 g
s
.54851 .32844 m .55008 .35371 L .45544 .359 L p .604 .24 .325 r
F P
0 g
s
.36445 .41696 m .37067 .38425 L .45544 .359 L p .505 .218 .413 r
F P
0 g
s
.74427 .72559 m .71136 .75918 L .69478 .72766 L p .902 .871 .798 r
F P
0 g
s
.69478 .72766 m .72549 .68747 L .74427 .72559 L p .902 .871 .798 r
F P
0 g
s
.52632 .83667 m .57132 .84475 L .56082 .85134 L closepath p .639 .817 .968 r
F P
0 g
s
.77666 .56105 m .76657 .6028 L .71608 .56028 L p .926 .721 .607 r
F P
0 g
s
.71608 .56028 m .72426 .51557 L .77666 .56105 L p .926 .721 .607 r
F P
0 g
s
.52632 .83667 m .48605 .84828 L .4778 .8409 L closepath p .577 .759 .965 r
F P
0 g
s
.36445 .41696 m .36236 .45486 L .29531 .49641 L p .365 .159 .461 r
F P
0 g
s
.2984 .53725 m .29531 .49641 L .36236 .45486 L p .422 .254 .547 r
F P
0 g
s
.72445 .43617 m .72698 .47391 L .64757 .43968 L p .85 .552 .485 r
F P
0 g
s
.64757 .43968 m .64601 .40165 L .72445 .43617 L p .85 .552 .485 r
F P
0 g
s
.62536 .8287 m .57707 .83677 L .57737 .82823 L p .733 .861 .941 r
F P
0 g
s
.57737 .82823 m .62652 .81185 L .62536 .8287 L p .733 .861 .941 r
F P
0 g
s
.34694 .74321 m .38568 .77614 L .38015 .80094 L p .366 .502 .863 r
F P
0 g
s
.42532 .82036 m .38015 .80094 L .38568 .77614 L p .452 .592 .901 r
F P
0 g
s
.52632 .83667 m .57707 .83677 L .57132 .84475 L closepath p .654 .814 .96 r
F P
0 g
s
.30771 .58054 m .32342 .62523 L .28943 .667 L p .323 .293 .67 r
F P
0 g
s
.31463 .70631 m .28943 .667 L .32342 .62523 L p .386 .382 .732 r
F P
0 g
s
.71136 .75918 m .67173 .78842 L .6581 .76424 L p .856 .863 .845 r
F P
0 g
s
.6581 .76424 m .69478 .72766 L .71136 .75918 L p .856 .863 .845 r
F P
0 g
s
.42532 .82036 m .4747 .83253 L .4778 .8409 L p .483 .682 .954 r
F P
0 g
s
.52632 .83667 m .4778 .8409 L .4747 .83253 L closepath p .585 .75 .956 r
F P
0 g
s
.64138 .36927 m .64601 .40165 L .55104 .38574 L p .745 .417 .428 r
F P
0 g
s
.55104 .38574 m .55008 .35371 L .64138 .36927 L p .745 .417 .428 r
F P
0 g
s
.38568 .77614 m .42965 .80355 L .42532 .82036 L p .452 .592 .901 r
F P
0 g
s
.4747 .83253 m .42532 .82036 L .42965 .80355 L p .528 .671 .928 r
F P
0 g
s
.52632 .83667 m .57737 .82823 L .57707 .83677 L closepath p .665 .807 .951 r
F P
0 g
s
.76657 .6028 m .74952 .64536 L .70229 .60695 L p .906 .744 .67 r
F P
0 g
s
.70229 .60695 m .71608 .56028 L .76657 .6028 L p .906 .744 .67 r
F P
0 g
s
.32342 .62523 m .34551 .67001 L .31463 .70631 L p .386 .382 .732 r
F P
0 g
s
.34694 .74321 m .31463 .70631 L .34551 .67001 L p .44 .459 .783 r
F P
0 g
s
.67173 .78842 m .62652 .81185 L .61666 .79554 L p .804 .848 .884 r
F P
0 g
s
.61666 .79554 m .6581 .76424 L .67173 .78842 L p .804 .848 .884 r
F P
0 g
s
.45258 .39116 m .45544 .359 L .55008 .35371 L p .64 .332 .434 r
F P
0 g
s
.45544 .359 m .45258 .39116 L .36445 .41696 L p .505 .218 .413 r
F P
0 g
s
.42965 .80355 m .4772 .82406 L .4747 .83253 L p .528 .671 .928 r
F P
0 g
s
.52632 .83667 m .4747 .83253 L .4772 .82406 L closepath p .596 .743 .946 r
F P
0 g
s
.36236 .45486 m .36445 .41696 L .45258 .39116 L p .544 .302 .499 r
F P
0 g
s
.52632 .83667 m .56173 .81317 L .5721 .82006 L closepath p .672 .785 .934 r
F P
0 g
s
.52632 .83667 m .54738 .80836 L .56173 .81317 L closepath p .669 .773 .928 r
F P
0 g
s
.52632 .83667 m .53064 .8062 L .54738 .80836 L closepath p .661 .761 .924 r
F P
0 g
s
.52632 .83667 m .5134 .80693 L .53064 .8062 L closepath p .651 .752 .923 r
F P
0 g
s
.52632 .83667 m .49763 .81048 L .5134 .80693 L closepath p .638 .745 .926 r
F P
0 g
s
.52632 .83667 m .48511 .81642 L .49763 .81048 L closepath p .624 .741 .93 r
F P
0 g
s
.52632 .83667 m .4772 .82406 L .48511 .81642 L closepath p .61 .74 .938 r
F P
0 g
s
.52632 .83667 m .5721 .82006 L .57737 .82823 L closepath p .671 .797 .942 r
F P
0 g
s
.36236 .45486 m .36461 .49722 L .2984 .53725 L p .422 .254 .547 r
F P
0 g
s
.30771 .58054 m .2984 .53725 L .36461 .49722 L p .464 .33 .613 r
F P
0 g
s
.62652 .81185 m .57737 .82823 L .5721 .82006 L p .743 .827 .916 r
F P
0 g
s
.5721 .82006 m .61666 .79554 L .62652 .81185 L p .743 .827 .916 r
F P
0 g
s
.55008 .35371 m .55104 .38574 L .45258 .39116 L p .64 .332 .434 r
F P
0 g
s
.72698 .47391 m .72426 .51557 L .6459 .4826 L p .846 .595 .558 r
F P
0 g
s
.6459 .4826 m .64757 .43968 L .72698 .47391 L p .846 .595 .558 r
F P
0 g
s
.34551 .67001 m .37365 .71329 L .34694 .74321 L p .44 .459 .783 r
F P
0 g
s
.38568 .77614 m .34694 .74321 L .37365 .71329 L p .487 .531 .828 r
F P
0 g
s
.74952 .64536 m .72549 .68747 L .68294 .65419 L p .883 .761 .723 r
F P
0 g
s
.68294 .65419 m .70229 .60695 L .74952 .64536 L p .883 .761 .723 r
F P
0 g
s
.4448 .78821 m .48511 .81642 L .4772 .82406 L p .571 .668 .905 r
F P
0 g
s
.4772 .82406 m .42965 .80355 L .4448 .78821 L p .571 .668 .905 r
F P
0 g
s
.37365 .71329 m .40714 .7533 L .38568 .77614 L p .487 .531 .828 r
F P
0 g
s
.42965 .80355 m .38568 .77614 L .40714 .7533 L p .53 .6 .868 r
F P
0 g
s
.40714 .7533 m .4448 .78821 L .42965 .80355 L p .53 .6 .868 r
F P
0 g
s
.61666 .79554 m .5721 .82006 L .56173 .81317 L p .738 .79 .894 r
F P
0 g
s
.64601 .40165 m .64757 .43968 L .55137 .42389 L p .756 .475 .507 r
F P
0 g
s
.55137 .42389 m .55104 .38574 L .64601 .40165 L p .756 .475 .507 r
F P
0 g
s
.36461 .49722 m .37136 .54315 L .30771 .58054 L p .464 .33 .613 r
F P
0 g
s
.32342 .62523 m .30771 .58054 L .37136 .54315 L p .498 .394 .668 r
F P
0 g
s
.72549 .68747 m .69478 .72766 L .65835 .70032 L p .856 .774 .77 r
F P
0 g
s
.65835 .70032 m .68294 .65419 L .72549 .68747 L p .856 .774 .77 r
F P
0 g
s
.46933 .77618 m .49763 .81048 L .48511 .81642 L p .61 .674 .886 r
F P
0 g
s
.48511 .81642 m .4448 .78821 L .46933 .77618 L p .61 .674 .886 r
F P
0 g
s
.56173 .81317 m .59654 .78165 L .61666 .79554 L p .738 .79 .894 r
F P
0 g
s
.59654 .78165 m .56173 .81317 L .54738 .80836 L p .723 .757 .879 r
F P
0 g
s
.6581 .76424 m .61666 .79554 L .59654 .78165 L p .787 .789 .854 r
F P
0 g
s
.45258 .39116 m .45161 .42926 L .36236 .45486 L p .544 .302 .499 r
F P
0 g
s
.36461 .49722 m .36236 .45486 L .45161 .42926 L p .571 .366 .565 r
F P
0 g
s
.72426 .51557 m .71608 .56028 L .64086 .52951 L p .839 .628 .616 r
F P
0 g
s
.64086 .52951 m .6459 .4826 L .72426 .51557 L p .839 .628 .616 r
F P
0 g
s
.69478 .72766 m .6581 .76424 L .6292 .74345 L p .825 .783 .813 r
F P
0 g
s
.6292 .74345 m .65835 .70032 L .69478 .72766 L p .825 .783 .813 r
F P
0 g
s
.45161 .42926 m .45258 .39116 L .55104 .38574 L p .66 .397 .511 r
F P
0 g
s
.50059 .76894 m .5134 .80693 L .49763 .81048 L p .644 .685 .874 r
F P
0 g
s
.49763 .81048 m .46933 .77618 L .50059 .76894 L p .644 .685 .874 r
F P
0 g
s
.59654 .78165 m .6292 .74345 L .6581 .76424 L p .787 .789 .854 r
F P
0 g
s
.54738 .80836 m .56823 .77187 L .59654 .78165 L p .723 .757 .879 r
F P
0 g
s
.56823 .77187 m .54738 .80836 L .53064 .8062 L p .702 .728 .87 r
F P
0 g
s
.37136 .54315 m .38273 .59152 L .32342 .62523 L p .498 .394 .668 r
F P
0 g
s
.34551 .67001 m .32342 .62523 L .38273 .59152 L p .526 .452 .715 r
F P
0 g
s
.55104 .38574 m .55137 .42389 L .45161 .42926 L p .66 .397 .511 r
F P
0 g
s
.53493 .76744 m .53064 .8062 L .5134 .80693 L p .675 .704 .869 r
F P
0 g
s
.5134 .80693 m .50059 .76894 L .53493 .76744 L p .675 .704 .869 r
F P
0 g
s
.53064 .8062 m .53493 .76744 L .56823 .77187 L p .702 .728 .87 r
F P
0 g
s
.44269 .73521 m .46933 .77618 L .4448 .78821 L p .592 .614 .843 r
F P
0 g
s
.4448 .78821 m .40714 .7533 L .44269 .73521 L p .592 .614 .843 r
F P
0 g
s
.64757 .43968 m .6459 .4826 L .55102 .4674 L p .76 .519 .568 r
F P
0 g
s
.55102 .4674 m .55137 .42389 L .64757 .43968 L p .76 .519 .568 r
F P
0 g
s
.38273 .59152 m .39865 .64086 L .34551 .67001 L p .526 .452 .715 r
F P
0 g
s
.37365 .71329 m .34551 .67001 L .39865 .64086 L p .55 .506 .759 r
F P
0 g
s
.71608 .56028 m .70229 .60695 L .6324 .57924 L p .83 .654 .665 r
F P
0 g
s
.6324 .57924 m .64086 .52951 L .71608 .56028 L p .83 .654 .665 r
F P
0 g
s
.41883 .68943 m .44269 .73521 L .40714 .7533 L p .572 .559 .801 r
F P
0 g
s
.40714 .7533 m .37365 .71329 L .41883 .68943 L p .572 .559 .801 r
F P
0 g
s
.6292 .74345 m .59654 .78165 L .56823 .77187 L p .759 .738 .834 r
F P
0 g
s
.39865 .64086 m .41883 .68943 L .37365 .71329 L p .55 .506 .759 r
F P
0 g
s
.45161 .42926 m .45265 .47258 L .36461 .49722 L p .571 .366 .565 r
F P
0 g
s
.37136 .54315 m .36461 .49722 L .45265 .47258 L p .591 .419 .617 r
F P
0 g
s
.48848 .72427 m .50059 .76894 L .46933 .77618 L p .642 .635 .827 r
F P
0 g
s
.46933 .77618 m .44269 .73521 L .48848 .72427 L p .642 .635 .827 r
F P
0 g
s
.45265 .47258 m .45161 .42926 L .55137 .42389 L p .673 .447 .569 r
F P
0 g
s
.70229 .60695 m .68294 .65419 L .62056 .63028 L p .817 .677 .709 r
F P
0 g
s
.62056 .63028 m .6324 .57924 L .70229 .60695 L p .817 .677 .709 r
F P
0 g
s
.65835 .70032 m .6292 .74345 L .58791 .7287 L p .784 .719 .791 r
F P
0 g
s
.56823 .77187 m .58791 .7287 L .6292 .74345 L p .759 .738 .834 r
F P
0 g
s
.58791 .7287 m .56823 .77187 L .53493 .76744 L p .725 .696 .823 r
F P
0 g
s
.55137 .42389 m .55102 .4674 L .45265 .47258 L p .673 .447 .569 r
F P
0 g
s
.53899 .72199 m .53493 .76744 L .50059 .76894 L p .686 .662 .821 r
F P
0 g
s
.50059 .76894 m .48848 .72427 L .53899 .72199 L p .686 .662 .821 r
F P
0 g
s
.68294 .65419 m .65835 .70032 L .60558 .6808 L p .802 .699 .75 r
F P
0 g
s
.60558 .6808 m .62056 .63028 L .68294 .65419 L p .802 .699 .75 r
F P
0 g
s
.58791 .7287 m .60558 .6808 L .65835 .70032 L p .784 .719 .791 r
F P
0 g
s
.53493 .76744 m .53899 .72199 L .58791 .7287 L p .725 .696 .823 r
F P
0 g
s
.45265 .47258 m .45576 .52017 L .37136 .54315 L p .591 .419 .617 r
F P
0 g
s
.38273 .59152 m .37136 .54315 L .45576 .52017 L p .606 .464 .663 r
F P
0 g
s
.6459 .4826 m .64086 .52951 L .54997 .51535 L p .76 .554 .617 r
F P
0 g
s
.54997 .51535 m .55102 .4674 L .6459 .4826 L p .76 .554 .617 r
F P
0 g
s
.47758 .67491 m .48848 .72427 L .44269 .73521 L p .637 .589 .784 r
F P
0 g
s
.44269 .73521 m .41883 .68943 L .47758 .67491 L p .637 .589 .784 r
F P
0 g
s
.45576 .52017 m .461 .57084 L .38273 .59152 L p .606 .464 .663 r
F P
0 g
s
.39865 .64086 m .38273 .59152 L .461 .57084 L p .618 .506 .704 r
F P
0 g
s
.45576 .52017 m .45265 .47258 L .55102 .4674 L p .682 .488 .618 r
F P
0 g
s
.60558 .6808 m .58791 .7287 L .53899 .72199 L p .739 .667 .78 r
F P
0 g
s
.46833 .62305 m .47758 .67491 L .41883 .68943 L p .628 .547 .744 r
F P
0 g
s
.41883 .68943 m .39865 .64086 L .46833 .62305 L p .628 .547 .744 r
F P
0 g
s
.461 .57084 m .46833 .62305 L .39865 .64086 L p .618 .506 .704 r
F P
0 g
s
.64086 .52951 m .6324 .57924 L .54821 .56651 L p .759 .584 .661 r
F P
0 g
s
.54821 .56651 m .54997 .51535 L .64086 .52951 L p .759 .584 .661 r
F P
0 g
s
.55102 .4674 m .54997 .51535 L .45576 .52017 L p .682 .488 .618 r
F P
0 g
s
.54264 .67188 m .53899 .72199 L .48848 .72427 L p .691 .625 .778 r
F P
0 g
s
.48848 .72427 m .47758 .67491 L .54264 .67188 L p .691 .625 .778 r
F P
0 g
s
.53899 .72199 m .54264 .67188 L .60558 .6808 L p .739 .667 .78 r
F P
0 g
s
.62056 .63028 m .60558 .6808 L .54264 .67188 L p .748 .64 .74 r
F P
0 g
s
.6324 .57924 m .62056 .63028 L .54575 .61933 L p .755 .612 .701 r
F P
0 g
s
.54575 .61933 m .54821 .56651 L .6324 .57924 L p .755 .612 .701 r
F P
0 g
s
.461 .57084 m .45576 .52017 L .54997 .51535 L p .687 .524 .66 r
F P
0 g
s
.54264 .67188 m .54575 .61933 L .62056 .63028 L p .748 .64 .74 r
F P
0 g
s
.54575 .61933 m .54264 .67188 L .47758 .67491 L p .692 .591 .738 r
F P
0 g
s
.47758 .67491 m .46833 .62305 L .54575 .61933 L p .692 .591 .738 r
F P
0 g
s
.54997 .51535 m .54821 .56651 L .461 .57084 L p .687 .524 .66 r
F P
0 g
s
.46833 .62305 m .461 .57084 L .54821 .56651 L p .691 .558 .699 r
F P
0 g
s
.54821 .56651 m .54575 .61933 L .46833 .62305 L p .691 .558 .699 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo3_l0000Z
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool002?ooooo00?o0000oooo
ooooool01?ooool2o`0001;ooooo00?o0000ooooooooool0IOooool@o`0000GoHP0000Co0000ohD0
0?n5003oQ@001Ol0000Uooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool0
02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
067ooooo2?l0000Aof800003o`000?n5003oQ@0000GoQ@001_l0000Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0:_ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05gooooo1?l000000olO003o0000of80000?of8000Wo
00002_n50006o`0001[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`00
8Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool4o`0000?o7`0000?o0000of800?mR00000_mR000=o`0000KoR1PV00?o0000ojTb8OnY<R40
1Ol0000:ohD000Co00005oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0EOooool4o`0000?o7`002?l0
000CohPH9P03o`000?nY<R7oZC8Q00GoZC8Q1Ol00008ohD000?o00005Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0DOooool3o`0000Co7`000ol00002oe@05@03o`000?n862KoR1PV01KoR1PV00?o0000
ojTb8OnY<R402_nY<R45o`0000CoQ@0000?o0000oh`00?l000000_l0000Booooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1=ooooo`?o00001?lO0003o`0000CoE00E00?o0000ohPH9_n862H06?n862H00ol0
003oZC8QojTb8@0>ojTb8@Ko00000on<0002o`00013ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Wooooo`00:Oooool2o`0001[ooooo00?o0000ooooooooool0BOooool3o`0000Co
7`000ol00007oe@05@03o`000?n862KoR1PV01SoR1PV00?o0000ojTb8OnY<R404onY<R43o`0000?o
S0000_l0000?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`;o00001?lO0003o`0000[oE00E
00?o0000ohPH9_n862H04On862H;o`0001?oZC8Q00Co0000okhl0Ol0003o00000on<0002o`0000go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04Cooooo0_l00002oal000?o00003?mD01D00ol0003oR1PV
ohPH9P04ohPH9Pko00001onJ?E<01?l0003o^5A@okQDD?nhE505o`0000ooZC8Q00?o0000okhl0Onn
?0400ol00002oh`000?o00002_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Go
oooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool6o`0000goE00E
2Ol0000EoiXmD`03o`000?nhE53o^5A@00Ko^5A@1_l0000:ojTb8@03o`000?nn?07o_S`100;o_S`1
0_l00003oh`000;o00002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo
000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool5o`0000goE00E0ol0
0002og4IB@03o`000?nJ?E?oVSeC01WoVSeC00?o0000okQDD?nhE5003?nhE505o`0000GoZC8Q00?o
0000okhl0Onn?0401?nn?042o`0000?oS0000_l00006ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0l
ooooo`Go00002_mD01D4o`0000GoLAU900?o0000oiXmDonJ?E<06OnJ?E<00ol0003o^5A@okQDD00A
okQDD0Go000000?oZC8Qo`000?nn?0401_nn?042o`0000?oS00000?o0000ooooooooool00oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0
003oooooooooo`0iooooo`Ko00001omD01D4o`0000WoLAU900?o0000oiXmDonJ?E<06OnJ?E<00ol0
003o^5A@okQDD00FokQDD0Co00001onn?042o`0000;oS00000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0=_ooool7o`0000GoE00E0ol0000=og4IB@03o`000?nJ?E?oVSeC01Wo
VSeC00?o0000okQDD?nhE5006?nhE5001?l0003odFDmo`000?l00007okhl0@Co00000oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0=?ooool7o`0000;oE00E1?l0000?og4IB@03o`000?nJ?E?oVSeC01[o
VSeC00?o0000okQDD?nhE5006?nhE5001?l0003odFDmom5U?OoAICd3o`0000Oo_S`10_l00002oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08Oooool002Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0aooooo`_o00004oma6DT00ol0003oVSeCoiXmD`0CoiXmD`_o
00006?nhE5000ol0003odFDmom5U?@03om5U?@;o00001onn?043o`0003cooooo00?o0000oooooooo
ool08Oooool002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0_ooooo`Wo0000
5_ma6DT00ol0003oVSeCoiXmD`04oiXmD`oo00001onSE6l01?l0003o_VY]okiZKOnnJVd6o`0001;o
^5A@00?o0000om5U?OoAICd01OoAICd2o`0000Go_S`100?o0000oj`Z0?l00000?Oooool00ol0003o
ooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo
1ol000000olX02So0000og4IB@0Dog4IB@Wo00005_nSE6l00ol0003o_VY]okiZK@07okiZK@Ko0000
3?nhE5000ol0003odFDmom5U?@07om5U?@;o00001?nn?043o`0003cooooo00?o0000ooooooooool0
8?ooool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Zooooo`So000000?o
:00Xo`000?ma6DT04_ma6DT3o`0000;oPCMY00?o0000oj=DKonSE6l06_nSE6l00ol0003o_VY]okiZ
K@0=okiZK@Go00001onhE5000ol0003odFDmom5U?@09om5U?@;o00000onn?0400ol0003o[2X0o`00
000looooo`03o`000?oooooooooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0X
ooooo`Oo00000olX02P00ol0003oLAU9og4IB@0>og4IB@?o00001On1=fT00ol0003oXeA_oj=DK`0J
oj=DK`03o`000?nnJVgo_VY]01;o_VY]1_l00002okQDD003o`000?oAICgodFDm00[odFDm1Ol00000
0on/:P3o0000ooooo`0kooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09_ooool7o`0000Co:00X00?o0000og4IBOma6DT02_ma6DT4o`00
00SoPCMY00?o0000oj=DKonSE6l06_nSE6l00ol0003o_VY]okiZK@0HokiZK@Co00003_oAICd3o`00
0003oj`Z0?l0003ooooo03[ooooo00?o0000ooooooooool07_ooool002Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Tooooo`Ko00001OlX02P00ol0003oLAU9og4IB@08og4IB@?o
00003?n1=fT00ol0003oXeA_oj=DK`0Koj=DK`03o`000?nnJVgo_VY]01Wo_VY]00?o0000omQmH_l0
00000_l0000;om5U?@06o`000?oAICgo0000o`000?n/:P3o0000>oooool00ol0003oooooooooo`0M
ooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02?ooooo1Ol00006obP0
:003o`000?ma6DWoLAU900CoLAU91?l0000?oh4gJ@03o`000?nSE6ooXeA_01_oXeA_00?o0000okiZ
KOnnJVd06OnnJVd00ol0003of7eRomQmHP02omQmHP;o00002OoAICd01?l0003odFDmom5U?OoAICd3
o`0003[ooooo00?o0000ooooooooool07Oooool002Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Qooooo`Co00002?lX02P01?l0003oLAU9og4IBOma6DT3o`0001;oPCMY00?o0000
oj=DKonSE6l07?nSE6l00ol0003o_VY]okiZK@0IokiZK@03o`000?oHOF;of7eR00Cof7eR0_l00007
om5U?@06o`000?oAICgodFDmom5U?Ol0003offP70_l0000jooooo`03o`000?oooooooooo01cooooo
000Vooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07oooool4o`0000So:00X00?o
0000og4IBOl000000_l0000Eoh4gJ@03o`000?nSE6ooXeA_01coXeA_00?o0000okiZKOnnJVd06Onn
JVd00ol0003of7eRomQmHP06omQmHP?o00001?oAICd00ol0003odFDmom5U?@02om5U?@04o`000?oK
J0Oo0000o`0003[ooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_ooooo`03o`000?oo
oooooooo01gooooo0ol00009obP0:0?o00006?n1=fT00ol0003oXeA_oj=DK`0Doj=DK`co00006?nn
JVd00ol0003of7eRomQmHP09omQmHP;o00000ooAICd01Ol0003odFDmom5U?OoAICgo000000;offP7
0_l0000iooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool07?ooool2o`0000So:00X0_l000000om81eOo0000oh4gJ@0Hoh4gJ@03o`000?nS
E6ooXeA_00GoXeA_3ol00008ojQUPP04o`000?o1NH7o`GV1ol5iP@Ko00004onnJVd00ol0003of7eR
omQmHP0:omQmHPCo00001?oAICd00ol0003offP7om]X1`02o`0003Wooooo00?o0000ooooooooool0
6_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Jooooo`03
o`000?lX02So:00X00Oo:00X00Go0000odP7Eom81eOoB0MGo`00000Goh4gJ@[o00005onXIH800ol0
003o`GV1ol5iP@07ol5iP@Ko00003OnnJVd00ol0003of7eRomQmHP0=omQmHP;o00000ooAICd01?l0
003offP7om]X1ooKJ0L2o`0003Sooooo00?o0000ooooooooool06_ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06?ooool00ol0003o:00XobP0:006obP0:0;o00000om81eL0
0ol0003oPCMYoh4gJ@0Coh4gJ@?o00000_n;CGl00ol0003oZ6F2ojQUPP0LojQUPP03o`000?o1NH7o
`GV100go`GV11Ol00008okiZK@03o`000?oHOF;of7eR00gof7eR00Co0000omQmH_l0003o00000_oA
ICd01?l0003offP7om]X1ooKJ0L2o`0003Sooooo00?o0000ooooooooool06Oooool000?ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool05oooool00ol0003o:00XobP0:004obP0:0;o0000
1Om81eL00ol0003oPCMYoh4gJ@0?oh4gJ@Co00001On;CGl00ol0003oZ6F2ojQUPP0LojQUPP03o`00
0?o1NH7o`GV101;o`GV11_l00002okiZK@03o`000?oHOF;of7eR00gof7eR00Co0000omQmH_oHOF;o
f7eR0ol00004om]X1`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool000_ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Eooooo`03o`000?lX02So:00X00Co:00X00?o0000odP7Eom8
1eL01Om81eL00ol0003oPCMYoh4gJ@0<oh4gJ@?o00002On;CGl00ol0003oZ6F2ojQUPP0LojQUPP03
o`000?o1NH7o`GV101So`GV11?l0000>omQmHP03o`000?oHOF;of7eR00Cof7eR00?o0000om]X1ooK
J0L00_oKJ0L00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Cooooo`;o00001?lX02P2o`0000SoB0MG00?o0000oh4g
JOn1=fT02?n1=fT4o`0000coRdeo00?o0000ojQUP_nXIH807?nXIH800ol0003o`GV1ol5iP@0Jol5i
P@04o`000?oISGco0000o`0000cof7eR00?o0000omQmH_oHOF801?oHOF82o`0000CoffP700?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Gooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o0000ooooooooool04Oooool2
o`0000?o:00X0_l0000:odP7E`03o`000?n1=fWoPCMY00GoPCMY0ol0000@oh]=O`03o`000?nXIH;o
Z6F201coZ6F200?o0000ol5iPOo1NH406_o1NH401?l0003ofHelomV=O?oISG`3o`0000Wof7eR00?o
0000omQmH_oHOF801?oHOF800ol0003okHe3o`000004om]X1`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool05oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0@ooooo`05o`000?lX
02So:00XobP0:?l000002om81eL00ol0003oPCMYoh4gJ@02oh4gJ@Co00004on;CGl00ol0003oZ6F2
ojQUPP0LojQUPP03o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oISG`01?oISG`2o`0000Oof7eR
00?o0000omQmH_oHOF801?oHOF801?l0003okHe3onf=@ol00004om]X1`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo0_l000000olX02So
0000o`00000<odP7E`03o`000?n1=fWo000000;o00005_n;CGl00ol0003oZ6F2ojQUPP0MojQUPP03
o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oISG`01_oISG`2o`0000Gof7eR00?o0000omQmH_oH
OF801OoHOF801?l0003okHe3onf=@ol00004om]X1`03o`000?oooooooooo03?ooooo0ol0000Goooo
o`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00gooooo1?l0000=odP7E`?o
00006On;CGl00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oI
SG`02?oISG`3o`0000;of7eR00?o0000omQmH_oHOF801OoHOF801Ol0003okHe3onf=@oo]SD?o0000
00CoffP700?o0000ooooooooool0;oooool3o`0000;ooooo00?o0000ooooooooool05Oooool002Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`?o00003_m81eL00ol0003o
GBQfo`00000Joh]=O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH406_o1NH400ol0003o
fHelomV=O00;omV=O0?o00001ooHOF800ol0003okHe3onf=@`02onf=@`03o`000?oKJ0OoffP700;o
ffP700?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0:ooooo`;o00003Om81eL2o`0000;oGBQf
00?o0000oh]=Oon;CGl06?n;CGl00ol0003oZ6F2ojQUPP0EojQUPPco00006_o1NH400ol0003ofHel
omV=O00<omV=O0;o00001_oHOF800ol0003okHe3onf=@`03onf=@`05o`000?oKJ0OoffP7om]X1ol0
0000:_ooool3o`0000Sooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`08ooooo`?o00002om81eL2o`0000CoGBQf00?o0000oh]=Oon;CGl0
6?n;CGl00ol0003oZ6F2ojQUPP05ojQUPQ3o00002?n/LY401?l0003o`XBAol:4TOo2Q946o`0001Co
`GV100?o0000omV=O?oISG`03?oISG`01?l0003ofHelo`000?l00004omQmHP03o`000?o]SD?okHe3
00CokHe300Go0000om]X1ooKJ0OoffP7o`00000Vooooo`?o00002oooool00ol0003oooooooooo`0E
ooooo`009?ooool2o`0003oooooo00?o0000ooooooooool01_ooool4o`0000[oB0MG00?o0000oedX
M_mM:7H01?mM:7H00ol0003oRdeooh]=O`0Foh]=O`[o00006?n/LY400ol0003o`XBAol:4T@07ol:4
T@Ko00003_o1NH400ol0003ofHelomV=O00<omV=O004o`000?oISGcofHelomV=O0?o00000_oHOF80
0ol0003okHe3onf=@`04onf=@`04o`000?oKJ0OoffP7o`0002?ooooo0ol0000?ooooo`03o`000?oo
oooooooo01Cooooo000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01Oooool3
o`0000WoB0MG0_l00007oedXMP03o`000?n;CGooRdeo01?oRdeo0ol00002oi9MT003o`000?n/LY7o
[7:A01go[7:A00?o0000ol:4TOo2Q9403Oo2Q946o`0000So`GV100?o0000omV=O?oISG`03?oISG`0
0ol0003ofHelomV=O004omV=O0?o00001oo]SD<01?l0003offP7om]X1ol0000Oooooo`?o00004_oo
ool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00?ooooo1?l00007odP7E`;o00002OmM:7H00ol0003oRdeooh]=O`0@oh]=O`?o00001OnBGI00
0ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o`XBA01?o`XBA1_l00002ol5iP@03o`000?oISGco
fHel00cofHel00?o0000omV=O?oISG`01_oISG`2o`0000OokHe300?o0000om]X1ol000007?ooool3
o`0001Gooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@_ooool01?l0
003oooooooooooooool3o`000003o`008?l0003oB0MG00GoB0MG00?o0000oedXM_mM:7H02OmM:7H0
0ol0003oRdeooh]=O`0<oh]=O`Co00002?nBGI000ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o
`XBA01Wo`XBA1?l0000=omV=O003o`000?oISGcofHel00KofHel00?o0000oo:RJol000001oo]SD<2
o`0001Wooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooool000000_l000000ol0023o0000odP7E`04odP7E`;o00003?mM:7H00ol0
003oRdeooh]=O`09oh]=O`?o00003?nBGI000ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o`XBA
01_o`XBA00Co0000omRHS_l0003o00003?oISG`00ol0003ofHelomV=O005omV=O004o`000?obXV_o
lZ9[o`0000OokHe30_l0000Eooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool0
0ol0003oooooooooo`14ooooo`Co000000?o000Po`000?m81eL00om81eL00ol0003oGBQfoedXMP0<
oedXMP03o`000?n;CGooRdeo00GoRdeo1?l0000?oi9MT003o`000?n/LY7o[7:A01go[7:A00?o0000
ol:4TOo2Q9406oo2Q9401?l0003of9R>omRHS_oHV8h3o`0000WofHel00?o0000omV=O?oISG`01OoI
SG`01Ol0003olZ9[oo:RJoobXV_o000000OokHe300?o0000ooooooooool04?ooool3o`0001kooooo
00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0A?ooool3o`0000;o000P00?o
0000odP7Eom81eL00_l0000?oedXMP03o`000?n;CGooRdeo00;oRdeo0ol0000Coi9MT003o`000?n/
LY7o[7:A01go[7:A00?o0000ol:4TOo2Q9406oo2Q9400ol0003of9R>omRHSP04omRHSP;o00001ooI
SG`00ol0003ofHelomV=O005omV=O003o`000?obXV_olZ9[00;olZ9[00?o0000onf=@oo]SD<01Oo]
SD<00ol0003oooooooooo`0<ooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2
o`0004Gooooo0_l00003o`0080?o00004OmM:7H00ol0003oRdeoo`000002o`0001OoTUf@00?o0000
ojabTOn/LY407?n/LY400ol0003o`XBAol:4T@0Kol:4T@03o`000?oHV8kof9R>00Kof9R>0_l00005
omV=O003o`000?oISGcofHel00GofHel00?o0000oo:RJoobXV/00oobXV/00ol0003okHe3onf=@`04
onf=@`03o`000?oooooooooo00Wooooo0ol0000Uooooo`03o`000?oooooooooo01?ooooo000Soooo
o`03o`000?oooooooooo04?ooooo0_l00003o`0080;o00004_mM:7H3o`0001[oTUf@00?o0000ojab
TOn/LY407?n/LY400ol0003o`XBAol:4T@0Kol:4T@03o`000?oHV8kof9R>00Sof9R>0ol00002omV=
O003o`000?oISGcofHel00GofHel00?o0000oo:RJoobXV/01?obXV/00ol0003okHe3onf=@`03onf=
@`;o00001oooool3o`0002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooooooo
ool0A?ooool2o`0000?o000P00?o0000oedXM_mM:7H04?mM:7H00ol0003oK46<o`00000Koi9MT003
o`000?n/LY7o[7:A01co[7:A00?o0000ol:4TOo2Q9406oo2Q9400ol0003of9R>omRHSP0;omRHSP?o
00002?oISG`00ol0003olZ9[oo:RJ`04oo:RJ`03o`000?o]SD?okHe300?okHe300?o0000oooooooo
ool00_ooool3o`0002_ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0
@oooool2o`0000Co000P00?o0000oedXM_mM:7H03_mM:7H2o`0000;oK46<00?o0000oi9MT?nBGI00
6OnBGI000ol0003o[7:AojabT@0LojabT@03o`000?o2Q97o`XBA01[o`XBA00?o0000omRHS_oHV8h0
3_oHV8h2o`0000OofHel00?o0000oo:RJoobXV/01OobXV/00ol0003okHe3onf=@`02onf=@`03o`00
0?oooooo000000;o0000;_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooooooo
o`13ooooo`03o`000?l0023o000P00;o000P0_l0000>oedXMP;o00001?m/@H`00ol0003oTUf@oi9M
T00Ioi9MT003o`000?n/LY7o[7:A01co[7:A00?o0000ol:4TOo2Q9406_o2Q9400ol0003of9R>omRH
SP0>omRHSP04o`000?oHV8ko0000o`0000GofHel00?o0000oo:RJoobXV/01_obXV/01?l0003okHe3
onf=@oo]SD<2o`00037ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0
@_ooool2o`0000?o000P00?o0000o`80E_l000003OmM:7H00ol0003oK46<ofa1S004ofa1S003o`00
0?nBGI3oTUf@01WoTUf@00?o0000ojabTOn/LY403On/LY4Do`0001So`XBA00?o0000omRHS_oHV8h0
3_oHV8h01?l0003of9R>omRHS_oHV8h3o`0000;ofHel00?o0000oo:RJoobXV/01oobXV/01Ol0003o
kHe3onf=@oo]SD?o0000037ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooooooo
ool0@_ooool00ol0003o000Po`008002o`008003o`000?l205Ko000000_oGBQf0_l00007ofa1S003
o`000?nBGI3oTUf@01OoTUf@4_l0000?ojilWP03o`000?o2SIgo`XfM00;o`XfM1ol0000Aol:4T@03
o`000?oHV8kof9R>00kof9R>00?o0000omRHS_oHV8h01?oHV8h3o`0000[olZ9[00?o0000onf=@oo]
SD<00_l0000`ooooo`03o`000?oooooooooo01?ooooo000Qooooo`?o0000@_ooool00ol0003o000P
o`008002o`008004o`000?l205Ko0P1Fo`0000WoGBQf0_l00009ofa1S003o`000?nBGI3oTUf@01Co
TUf@0ol00002oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2SId02Oo2SId7o`0000[o
`XBA00?o0000omRHS_oHV8h03_oHV8h00ol0003of9R>omRHSP06omRHSP;o00002_obXV/01?l0003o
kHe3o`000?l0000aooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04;o
oooo00Go0000o`008?l0023o000Po`000003o`80EP03o`000?mM:7KoGBQf00KoGBQf00?o0000ofa1
S?m/@H`02Om/@H`00ol0003oTUf@oi9MT00@oi9MT0Co00001OnGJid00ol0003o[WbNojilWP0Lojil
WP03o`000?o2SIgo`XfM013o`XfM1ol00003ol:4T@03o`000?oHV8kof9R>00kof9R>00?o0000omRH
S_oHV8h01_oHV8h00ol0003ol;26o`00000:oo:RJ`;o000000?obgP0o`000?ooool0;oooool00ol0
003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`12ooooo`05o`000?l0023o000Po`00
8?l000000ol205H00ol0003oGBQfoedXMP04oedXMP;o00003?m/@H`00ol0003oTUf@oi9MT00=oi9M
T0?o00002OnGJid00ol0003o[WbNojilWP0LojilWP03o`000?o2SIgo`XfM01Oo`XfM1Ol0000?omRH
SP03o`000?oHV8kof9R>00Kof9R>00Co0000oo2`Q_o`/8Ko00002_obXV/3o`00033ooooo00?o0000
ooooooooool04_ooool0027ooooo00?o0000ooooooooool0@Oooool01Ol0003o000Po`008?l0023o
000000Co0P1F00?o0000oedXM_mM:7H00omM:7H00ol0003oK46<ofa1S00<ofa1S003o`000?nBGI3o
TUf@00WoTUf@1?l0000<oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2SId06_o2SId0
1?l0003oeZ2Mo`000?l0000=omRHSP03o`000?oHV8kof9R>00Kof9R>00Go0000oo2`Q_o`/8Kol;26
o`00000:oo:RJ`;o0000<?ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`11ooooo`04o`000?l0023o000Po`0000Go0P1F00Co0000oedXM_mM:7KoGBQf0_l0000?ofa1S003
o`000?nBGI3oTUf@00KoTUf@0ol0000@oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2
SId06_o2SId01?l0003oeZ2MomJPWOoFX9d3o`0000[of9R>00?o0000omRHS_oHV8h01_oHV8h00ol0
003ol;26oo2`QP02oo2`QP03o`000?obXV_olZ9[00OolZ9[00?o0000ol]h0?l00000;oooool00ol0
003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?l0023o000000Ko
0P1F00Co0000oedXM_l0003o00004Om/@H`00ol0003oTUf@oi9MT002oi9MT0Co00004onGJid00ol0
003o[WbNojilWP0LojilWP03o`000?o2SIgo`XfM01[o`XfM00?o0000omJPWOoFX9d01?oFX9d2o`00
00Sof9R>00?o0000omRHS_oHV8h01_oHV8h00ol0003ol;26oo2`QP03oo2`QP03o`000?obXV_olZ9[
00KolZ9[0ol0000_ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo043o
oooo00Co0000o`008?l0023o00001_l205H2o`0001?oK46<00?o0000oi9MT?l000000_l0000GoiM[
W@03o`000?n^O9ko[WbN01_o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2MomJPW@06omJP
W@;o00001_oHV8h00ol0003of9R>omRHSP06omRHSP03o`000?o`/8Kol;2600Col;2600?o0000oo:R
JoobXV/01OobXV/2o`000003ol]h0?l0003ooooo02gooooo00?o0000ooooooooool04_ooool0023o
oooo0ol00011ooooo`03o`000?l0023o000000Oo0P1F00?o0000ofa1S?m/@H`04Om/@H`3o`0001_o
Uf^M00?o0000ojilW_n^O9h06_n^O9h00ol0003o`XfMol:=W@0Kol:=W@03o`000?oFX9goeZ2M00So
eZ2M0ol00003omRHSP03o`000?oHV8kof9R>00Gof9R>00?o0000oo2`Q_o`/8H01_o`/8H2o`0000Go
lZ9[0_l000000oo;N03o0000ooooo`0^ooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`00
0?oooooooooo047ooooo0_l00008o`80EP03o`000?m/@HcoK46<00ooK46<0_l000000omfE9co0000
oiM[W@0KoiM[W@03o`000?n^O9ko[WbN01[o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2M
omJPW@0;omJPW@;o00000_oHV8h00ol0003of9R>omRHSP04omRHSP03o`000?o`/8Kol;2600Sol;26
00?o0000oo:RJoobXV/00_obXV/01?l0003okjTao`000?l0000_ooooo`03o`000?oooooooooo017o
oooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`11ooooo`;o
00001ol205H2o`00013oK46<00Go0000ogIDW?mfE9coMUBLo`00000LoiM[W@03o`000?n^O9ko[WbN
01[o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2MomJPW@0=omJPW@?o00001_oHV8h00ol0
003ol;26oo2`QP09oo2`QP03o`000?obXV_olZ9[00;olZ9[0_l000000oo;N03o0000ooooo`0]oooo
o`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`10ooooo`;o00001ol205H00ol0003o90elo`00000>ofa1S0;o00001?mfE9`00ol0
003oUf^MoiM[W@0JoiM[W@03o`000?n^O9ko[WbN01[o[WbN00?o0000ol:=WOo2SId06_o2SId00ol0
003oeZ2MomJPW@0@omJPW@;o00001OoHV8h00ol0003ol;26oo2`QP0:oo2`QP06o`000?obXV_olZ9[
oo:RJol0003okjTa0_l0000^ooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`10ooooo`03o`000?l205Ko0P1F00Go0P1F00Co
0000ob@=O?lT3Gco00003?m/@H`2o`0000OoMUBL00?o0000oiM[WOnGJid06OnGJid00ol0003o[WbN
ojilWP0JojilWP03o`000?o2SIgo`XfM01[o`XfM00?o0000omJPWOoFX9d04?oFX9d00ol0003oeZ2M
o`000002o`0000;of9R>00?o0000oo2`Q_o`/8H02oo`/8H01Ol0003olZ9[oo:RJol0003okjTa00;o
0000;_ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0@?ooool00ol0003o0P1Fo`80EP05o`80EP04o`000?lT3Gco90elo`00
00_oK46<00?o0000ogIDW?mfE9`01omfE9`00ol0003oUf^MoiM[W@0IoiM[W@03o`000?n^O9ko[WbN
01[o[WbN00?o0000ol:=WOo2SId06_o2SId00ol0003oeZ2MomJPW@0@omJPW@03o`000?oFX9goeZ2M
00;oeZ2M0ol0000>oo2`QP03o`000?obXV_o000000;okjTa0_l0000]ooooo`03o`000?oooooooooo
017ooooo000Eooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`11oooo
o`03o`000?l205Ko0P1F00Co0P1F00Go0000ob@=O?lT3Gco90elo`000009ofa1S0;o00002_mfE9`0
0ol0003oUf^MoiM[W@0IoiM[W@03o`000?n^O9ko[WbN00co[WbN4ol0000Hol:=W@03o`000?oFX9go
eZ2M013oeZ2M00?o0000omJPWOoFX9d01?oFX9d2o`0000kol;260_l00002onnY<@;o0000;Oooool0
0ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00012
ooooo`03o`000?l205Ko0P1F00?o0P1F00?o0000ob@=O?lT3G`00olT3G`00ol0003oK46<ofa1S004
ofa1S0;o00003?mfE9`00ol0003oUf^MoiM[W@0GoiM[WA7o00003_n_QZP00ol0003o`YFYol:EZ@02
ol:EZ@Oo00004Oo2SId00ol0003oeZ2MomJPW@0@omJPW@03o`000?oFX9goeZ2M00CoeZ2M00?o0000
onfhVol000003_o`/8H00ol0003okjTaonnY<@02o`0002gooooo00?o0000ooooooooool04Oooool0
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo047ooooo00?o0000
o`80E_l205H00_l205H00ol0003o90elob@=O004ob@=O003o`000?m/@HcoK46<00?oK46<00?o0000
ogIDW?mfE9`03?mfE9`00ol0003oUf^MoiM[W@0CoiM[W@Co00000_nKMZT00ol0003o[hJXojn6Z00J
ojn6Z003o`000?o2UJWo`YFY00Wo`YFY1ol0000:ol:=W@03o`000?oFX9goeZ2M013oeZ2M00?o0000
omJPWOoFX9d01?oFX9d01?l0003okKRKonfhVol0000=oo2`QP04o`000?o_ZC7okjTaonnY<@;o0000
;Oooool00ol0003oooooooooo`0@ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0@?ooool2o`0000Co0P1F00?o0000ob@=O?lT3G`01?lT3G`01?l0003oK46<
ofa1S?m/@H`2o`0000ooMUBL00?o0000oiM[WOnGJid03onGJid4o`0000KoVgJY00?o0000ojn6Z?n_
QZP06_n_QZP00ol0003o`YFYol:EZ@0@ol:EZ@Oo00000oo2SId00ol0003oeZ2MomJPW@0@omJPW@03
o`000?oFX9goeZ2M00?oeZ2M00?o0000onfhVoo]^9/00_o]^9/00ol0003ol;26oo2`QP0:oo2`QP;o
00000_o_ZC42o`0002gooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
@?ooool2o`0000?o0P1F00?o0000ob@=O?lT3G`01OlT3G`01?l0003oK46<o`000?l0000AogIDW003
o`000?nGJigoUf^M00_oUf^M1?l0000:oi]fZ@03o`000?n_QZSo[hJX01[o[hJX00?o0000ol:EZOo2
UJT05oo2UJT5o`00017oeZ2M00?o0000omJPWOoFX9d00ooFX9d00ol0003okKRKonfhV`03onfhV`03
o`000?o`/8Kol;2600Wol;260_l00003onnY<@03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool04?ooool001oooooo00?o0000ooooooooool0@?ooool01Ol0003o0P1Fo`80E_l205Ko000000So
90el0_l0000DogIDW003o`000?nGJigoUf^M00OoUf^M0ol0000>oi]fZ@03o`000?n_QZSo[hJX01[o
[hJX00?o0000ol:EZOo2UJT06_o2UJT01?l0003oe:NZo`000?l0000?omJPW@03o`000?oFX9goeZ2M
00?oeZ2M00?o0000onfhVoo]^9/01?o]^9/00ol0003ol;26oo2`QP08oo2`QP;o00000oo_ZC400ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo043o
oooo00Co0000o`80E_l205Ko00002OlT3G`00ol0003oMUBLogIDW00CogIDW003o`000?nGJigoUf^M
00?oUf^M1?l0000Aoi]fZ@03o`000?n_QZSo[hJX01[o[hJX00?o0000ol:EZOo2UJT06_o2UJT01?l0
003oe:NZomBWZ_oDYjX3o`0000coeZ2M00?o0000omJPWOoFX9d00ooFX9d00ol0003okKRKonfhV`05
onfhV`03o`000?o`/8Kol;2600Ool;2600?o0000ook6Iol000000_o_ZC42o`0002cooooo00?o0000
ooooooooool04?ooool001kooooo00?o0000ooooooooool0@Oooool01?l0003o0P1Fo`80E_l00009
ob@=O003o`000?mfE9coMUBL01?oMUBL00?o0000oiM[WOl000000ol0000Eoi]fZ@03o`000?n_QZSo
[hJX01[o[hJX00?o0000ol:EZOo2UJT06_o2UJT00ol0003oe:NZomBWZP04omBWZP;o00002_oFX9d0
0ol0003oeZ2MomJPW@03omJPW@03o`000?o]^9_okKRK00KokKRK0_l00007oo2`QP03o`000?onaVOo
000000?okjTa00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0
003oooooooooo`11ooooo`03o`000?l205Ko000000Wo90el0_l0000DogIDW0?o00006OnKMZT00ol0
003o[hJXojn6Z00Jojn6Z003o`000?o2UJWo`YFY01Wo`YFY00?o0000omBWZ_oDYjX01ooDYjX2o`00
00SoeZ2M00?o0000omJPWOoFX9d00_oFX9d00ol0003okKRKonfhV`09onfhV`03o`000?o`/8Kol;26
00?ol;2600Go0000ook6IoonaVOoo/IWo`000002onnY<@03o`000?oooooooooo02[ooooo00?o0000
ooooooooool04?ooool001kooooo0_l00012ooooo`;o00002OlT3G`00ol0003o?RnGo`00000BogID
W0;o000000?oOfB[o`000?nKMZT06OnKMZT00ol0003o[hJXojn6Z00Jojn6Z003o`000?o2UJWo`YFY
01Wo`YFY00?o0000omBWZ_oDYjX02OoDYjX3o`0000GoeZ2M00?o0000omJPWOoFX9d00_oFX9d00ol0
003okKRKonfhV`0:onfhV`03o`000?o`/8Kol;2600;ol;2600Go0000ook6IoonaVOoo/IWo`000002
onnY<@03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooo
ooooool0@Oooool00ol0003o90elob@=O007ob@=O005o`000?ln;iOo?RnGoch_Uol000004?mfE9`0
1Ol0003oOfB[ogmTZomoI:_o000001_oVgJY00?o0000ojn6Z?n_QZP06On_QZP00ol0003o`YFYol:E
Z@0Iol:EZ@03o`000?oDYj[oe:NZ00coe:NZ0_l00003omJPW@03o`000?oFX9goeZ2M00;oeZ2M00?o
0000onfhVoo]^9/02oo]^9/01Ol0003ol;26oo2`Q_o`/8Ko000000Coo/IW00?o0000onnY<Ol00000
;Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`11ooooo`03o`000?lT
3Gco90el00Oo90el00Go0000och_Uoln;iOo?RnGo`00000>ogIDW0;o00001OmoI:/00ol0003oVgJY
oi]fZ@0Hoi]fZ@03o`000?n_QZSo[hJX01Wo[hJX00?o0000ol:EZOo2UJT06Oo2UJT00ol0003oe:NZ
omBWZP0>omBWZP;o000000?oeZ2Mo`000?oFX9d00ooFX9d00ol0003okKRKonfhV`0<onfhV`04o`00
0?o`/8Kol;26o`0000Coo/IW00?o0000onnY<Ol00000;Oooool00ol0003oooooooooo`0?ooooo`00
7_ooool00ol0003oooooooooo`10ooooo`;o00002?lT3G`00ol0003o?RnGoch_U`02och_U`03o`00
0?mfE9coMUBL00[oMUBL0_l00007ogmTZ`03o`000?nKMZWoVgJY01SoVgJY00?o0000ojn6Z?n_QZP0
6On_QZP00ol0003o`YFYol:EZ@0Iol:EZ@03o`000?oDYj[oe:NZ013oe:NZ0ol00003omJPW@03o`00
0?o]^9_okKRK00gokKRK00?o0000oo2`Q_l000001?onaVL00ol0003okjTao`00000]ooooo`03o`00
0?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo047ooooo0_l00007ob@=O003o`000?ln
;iOo?RnG00?o?RnG00?o0000ogIDW?mfE9`02OmfE9`00ol0003oOfB[ogmTZ`07ogmTZ`03o`000?nK
MZWoVgJY01SoVgJY00?o0000ojn6Z?n_QZP06On_QZP00ol0003o`YFYol:EZ@0Hol:EZ@03o`000?oD
Yj[oe:NZ01;oe:NZ00?o0000omBWZ_l000000_l0000AonfhV`;o00001OonaVL00ol0003okjTao`00
000/ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo047ooooo0_l00006
ob@=O003o`000?ln;iOo?RnG00Co?RnG00?o0000ogIDW?mfE9`01omfE9`2o`0000[oOfB[00?o0000
oi]fZOnKMZT06?nKMZT00ol0003o[hJXojn6Z00Iojn6Z003o`000?o2UJWo`YFY01So`YFY00?o0000
omBWZ_oDYjX04ooDYjX00ol0003oe:NZomBWZP02o`00017okKRK00?o0000ook6IoonaVL00oonaVL0
0ol0003okjTao`00000/ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo
047ooooo0_l00006ob@=O003o`000?ln;iOo?RnG00Co?RnG00?o0000ogIDW?mfE9`01OmfE9`2o`00
00goOfB[00?o0000oi]fZOnKMZT05onKMZT00ol0003o[hJXojn6Z00Iojn6Z003o`000?o2UJWo`YFY
01So`YFY00?o0000omBWZ_oDYjX04ooDYjX01_l0003oe:NZomBWZ_l0003oikj[o`00013okKRK00?o
0000ook6IoonaVL01?onaVL2o`0002cooooo00?o0000ooooooooool03oooool001gooooo0_l00012
ooooo`;o00001OlT3G`00ol0003o?RnGoch_U`05och_U`03o`000?mfE9coMUBL00CoMUBL00?o0000
ogmTZomoI:/03OmoI:/00ol0003oVgJYoi]fZ@0Goi]fZ@03o`000?n_QZSo[hJX00_o[hJX4_l0000G
ol:EZ@03o`000?oDYj[oe:NZ01?oe:NZ00Co0000omBWZ_oDYj[o00000_oW_Z/00ol0003okKRKonfh
V`0=onfhV`;o00001OonaVL2o`0002gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool0@Oooool00ol0003o000mo`000003ob@=O003o`000?ln;iOo?RnG00Oo?RnG00Co0000
ogIDW?mfE9coMUBL0_l0000@ogmTZ`03o`000?nKMZWoVgJY01GoVgJY4?l0000>ok2>/P04o`000?o1
W;?o`Ibcol6L/`Oo00004?o2UJT00ol0003oe:NZomBWZP0ComBWZP03o`000?oDYj[o000000Coikj[
00?o0000onfhVoo]^9/02oo]^9/00ol0003oomF=o`000005ook6I`;o0000;Oooool00ol0003ooooo
ooooo`0>ooooo`007Oooool00ol0003oooooooooo`11ooooo`03o`000?l003go000000;o90el00?o
0000och_Uoln;iL02?ln;iL01?l0003oMUBLo`000?l0000CogmTZ`03o`000?nKMZWoVgJY013oVgJY
1?l00002oij1]003o`000?n`S[;o/8jb01Wo/8jb00?o0000ol6L/oo1W;<02?o1W;<6o`0000Wo`YFY
00?o0000omBWZ_oDYjX05?oDYjX00ol0003oe:NZo`000005onNnZ`;o00002oo]^9/01?l0003oomF=
oooESOl00005ook6I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool0@_ooool00ol0003o000mo`000002ob@=O003o`000?ln;iOo?RnG00So?RnG
0_l0000EogmTZ`03o`000?nKMZWoVgJY00coVgJY1?l00006oij1]003o`000?n`S[;o/8jb01Wo/8jb
00?o0000ol6L/oo1W;<03_o1W;<7o`0000;o`YFY00?o0000omBWZ_oDYjX05?oDYjX00ol0003oe:NZ
o`000007onNnZ`03o`000?o]^9_okKRK00SokKRK00Co0000oooESOooeHgo00001OonaVL00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo04;ooooo
00Go0000o`00?Ol0003o90elo`00000;och_U`03o`000?moI:_oOfB[01CoOfB[00?o0000oi]fZOnK
MZT02?nKMZT4o`0000[oWX6d00?o0000ok2>/_n`S[806On`S[800ol0003o`Ibcol6L/`0Eol6L/`Co
00005OoDYjX2o`0000Woikj[00?o0000onfhVoo]^9/01oo]^9/01?l0003oomF=oooESOl00005ook6
I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo00?o0000oooooooo
ool0@_ooool01?l0003o000mo`000?l0000<och_U`03o`000?moI:_oOfB[01CoOfB[00?o0000oi]f
ZOnKMZT01?nKMZT4o`0000ooWX6d00?o0000ok2>/_n`S[806?n`S[800ol0003o`Ibcol6L/`0Gol6L
/`03o`000?oA[KGo000000;o00004_oDYjX2o`0000[oikj[00?o0000onfhVoo]^9/01Oo]^9/00ol0
003oomF=oooES@02oooES@03o`000?onaVOoo/IW00;oo/IW00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?o000mo`000?ln
;iL02oln;iL00ol0003oDT^[o`00000FogmTZ`03o`000?nKMZWo000000?o00004onNPK@00ol0003o
/8jbok2>/P0Hok2>/P03o`000?o1W;?o`Ibc01Oo`Ibc00?o0000om6]]OoA[KD00_oA[KD3o`0000go
e:NZ1?l0000;onNnZ`03o`000?o]^9_okKRK00CokKRK00?o0000oooESOooeHd00_ooeHd00ol0003o
o/IWook6I`02ook6I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool0@Oooool2o`000003o`00?Ol0003o?RnG00[o?RnG00Co0000oe9;ZomBBj_o
00005OmoI:/3o`0001OoWX6d00?o0000ok2>/_n`S[806?n`S[800ol0003o`Ibcol6L/`0Fol6L/`03
o`000?oA[KGodJfe00KodJfe0ol00007omBWZP?o00000_oDYjX2o`0000coikj[0_l00004onfhV`03
o`000?ooeHgoomF=00?oomF=00Go0000ook6IoonaVOoo/IWo`00000^ooooo`03o`000?oooooooooo
00gooooo000Looooo`;o0000@_ooool01?l0003o000mo`00?Ol0000:och_U`05o`000?mBBj_oDT^[
oe9;Zol000004omoI:/2o`000003ohIc]ol0003oWX6d01OoWX6d00?o0000ok2>/_n`S[806?n`S[80
0ol0003o`Ibcol6L/`0Fol6L/`03o`000?oA[KGodJfe00WodJfe0_l00002omBWZP?o00001OoDYjX2
o`0000koikj[00Go0000onfhVoo]^9_okKRKo`000005oooES@05o`000?onaVOoo/IWook6Iol00000
;_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`12ooooo`05o`000?l0
03go000mo`00M_l000002?ln;iL00ol0003oDT^[oe9;Z`03oe9;Z`03o`000?moI:_oOfB[00ooOfB[
00Go0000ohIc]on6LkOoQW>go`00000Hoij1]003o`000?n`S[;o/8jb01Oo/8jb00?o0000ol6L/oo1
W;<05oo1W;<00ol0003odJfeom6]]@0:om6]]@Co00001ooDYjX00ol0003oikj[o`00000>onNnZ`04
o`000?o]^9_okKRKo`0000KoomF=00?o0000ook6Iol00000;oooool00ol0003oooooooooo`0=oooo
o`006oooool00ol0003oooooooooo`12ooooo`05o`000?l003go000mo`00M_l000002?ln;iL00ol0
003oDT^[oe9;Z`03oe9;Z`03o`000?moI:_oOfB[00goOfB[0_l00005ohIc]`03o`000?nNPKCoWX6d
01KoWX6d00?o0000ok2>/_n`S[805_n`S[800ol0003o`Ibcol6L/`0Gol6L/`03o`000?oA[KGodJfe
00KodJfe1?l00004om6]]@?o00001?oDYjX01?l0003oikj[onNnZol0000>onNnZ`;o00001oooeHd0
0ol0003oo/IWo`00000_ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
04;ooooo00Go0000o`00?Ol0003o001fo`000007och_U`03o`000?mBBj_oDT^[00CoDT^[00?o0000
ogmTZomoI:/02omoI:/2o`0000OoQW>g00?o0000oij1]?nNPK@05_nNPK@00ol0003o/8jbok2>/P0F
ok2>/P03o`000?o1W;?o`Ibc01Ko`Ibc00?o0000om6]]OoA[KD01?oA[KD3o`0000_odJfe1?l00004
onNnZ`03o`000?oW_Z_oikj[00coikj[00?o0000oooESOooeHd01OooeHd00ol0003oo/IWo`00000_
ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo04;ooooo00Go0000o`00
?Ol0003o001fo`000006och_U`03o`000?mBBj_oDT^[00KoDT^[00?o0000ogmTZomoI:/02?moI:/2
o`0000WoQW>g00?o0000oij1]?nNPK@05_nNPK@00ol0003o/8jbok2>/P0Fok2>/P03o`000?o1W;?o
`Ibc01Ko`Ibc00Co0000om6]]OoA[KGodJfe0ol0000Aom6]]@;o00000ooW_Z/00ol0003oikj[onNn
Z`0<onNnZ`03o`000?ooeHgoomF=00KoomF=0_l0000_ooooo`03o`000?oooooooooo00gooooo000K
ooooo`03o`000?oooooooooo04;ooooo00?o0000o`00?Ol000000_l007H00ol0003o?RnGoch_U`02
och_U`03o`000?mBBj_oDT^[00OoDT^[00?o0000ogmTZomoI:/01omoI:/00ol0003oQW>gohIc]`0:
ohIc]`03o`000?nNPKCoWX6d01GoWX6d00?o0000ok2>/_n`S[805_n`S[800ol0003o`Ibcol6L/`0F
ol6L/`Co00005?oA[KD00ol0003oh/:io`000003onNnZ`03o`000?oW_Z_oikj[00[oikj[00?o0000
oo[LZ?l000001oooeHd2o`0002oooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0@_ooool00ol0003o000mo`000002o`00MP03o`000?ln;iOo?RnG00;o?RnG00?o0000oe9;
ZomBBj/01omBBj/00ol0003oOfB[ogmTZ`05ogmTZ`;o00003On6LkL00ol0003oWX6doij1]00Eoij1
]003o`000?n`S[;o/8jb01Ko/8jb00?o0000ol6L/oo1W;<04oo1W;<4o`0001KodJfe00Go0000on;2
^OoR`[Woh/:io`000003onNnZ`03o`000?oW_Z_oikj[00Woikj[00?o0000oo[LZ?l000002?ooeHd0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo000Kooooo`;o0000@oooool00ol0
003o000mo`000002o`00MP05o`000?ln;iOo?RnGoch_Uol000002omBBj/00ol0003oOfB[ogmTZ`02
ogmTZ`;o00003on6LkL00ol0003oWX6doij1]00Foij1]003o`000?n`S[;o/8jb01Go/8jb00?o0000
ol6L/oo1W;<04?o1W;<3o`0000;o`Ibc00?o0000om6]]OoA[KD05OoA[KD00ol0003oh/:ion;2^@02
on;2^@05o`000?oW_Z_oikj[onNnZol000002_oW_Z/01?l0003on]bXoo[LZ?l00007oooES@03o`00
0?oooooooooo02kooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000ooooooooool0@ooo
ool00ol0003o000mo`000002o`00MP04o`000?ln;iOo?RnGo`0000coDT^[00Go0000ogmTZomoI:_o
OfB[o`00000BohIc]`03o`000?nNPKCoWX6d01GoWX6d00?o0000ok2>/_n`S[802On`S[8@o`0000co
`Ibc0ol00005ol6L/`03o`000?oA[KGodJfe01GodJfe00?o0000on;2^OoR`[T00ooR`[T2o`0000;o
ikj[00?o0000onNnZooW_Z/01_oW_Z/01Ol0003on]bXoo[LZ?ojg:So000000OoomF=00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Cooooo00?o000m
o`000?l007H00_l007H2o`0000goDT^[00Co0000ogmTZol0003o00004on6LkL00ol0003oWX6doij1
]00Coij1]0ko00003?naUk`01?l0003o_j>moknS_OnoXkd6o`0000?o`Ibc0ol00008ol6L/`03o`00
0?oA[KGodJfe01CodJfe00?o0000on;2^OoR`[T01_oR`[T01?l0003oikj[onNnZol00007onNnZ`03
o`000?ojg:Son]bX00;on]bX00?o0000oooESOooeHd00oooeHd2o`00033ooooo00?o0000oooooooo
ool03?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0A?ooool00ol003go0000o`00MP02o`00MP03o`000?mBBj_oDT^[00go
DT^[00?o0000ohIc]on6LkL04on6LkL00ol0003oWX6doij1]00?oij1]0Co00000_nPS;h00ol0003o
/INlok6G_00Eok6G_003o`000?noXkgo_j>m00Ko_j>m1_l00009ol6L/`03o`000?oA[KGodJfe01Co
dJfe00?o0000on;2^OoR`[T01ooR`[T00ol0003oikj[o`000006onNnZ`03o`000?ojg:Son]bX00?o
n]bX00?o0000oooESOooeHd00oooeHd00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00co
oooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`14ooooo`03o`000?l007Ko001f00;o001f00?o0000oe9;ZomBBj/03OmBBj/00ol0003oQW>g
ohIc]`0DohIc]`03o`000?nNPKCoWX6d00_oWX6d0ol00006oj2<_P03o`000?naUkco/INl01Go/INl
00?o0000oknS_OnoXkd00onoXkd3o`0000Ko_j>m1_l00002ol6L/`03o`000?oA[KGodJfe01CodJfe
00?o0000on;2^OoR`[T02OoR`[T00ol0003oikj[o`000005onNnZ`03o`000?ojg:Son]bX00Con]bX
00?o0000oooESOooeHd00_ooeHd00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo
0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`14ooooo`03o`000?l007Ko001f00;o001f00?o01VOo`000?mBBj/03?mBBj/00ol0003oHV6ko`00
000EohIc]`03o`000?nNPKCoWX6d00OoWX6d1?l00009oj2<_P03o`000?naUkco/INl01Go/INl00?o
0000oknS_OnoXkd00ol0000?oknS_@Co00005OoA[KD00ol0003oh/:ion;2^@0:on;2^@?o00001?oW
_Z/00ol0003on]bXoo[LZ004oo[LZ003o`000?ooeHgoomF=00;oomF=00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`14ooooo`03o`000?l007Ko001f00;o001f00?o
01VOo`000?mBBj/02omBBj/01?l0003oHV6kof9Q^ol0000EohIc]`03o`000?nNPKCoWX6d00?oWX6d
1?l0000>oj2<_P03o`000?naUkco/INl01Co/INl0ol0000DoknS_@03o`000?o=/[oo000000;o0000
4_oA[KD00ol0003oh/:ion;2^@0<on;2^@;o00000_oW_Z/00ol0003on]bXoo[LZ005oo[LZ004o`00
0?ooeHgoomF=oooES@;o0000<Oooool00ol0003oooooooooo`0<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool00ol0003o001f
o`00MP02o`00MP03o`000?l06Ioo000000[oDT^[00?o0000of9Q^omRHK/00_mRHK/00ol0003oQW>g
ohIc]`0CohIc]`03o`000?nNPKCo000000;o00004_nPS;h00ol0003o/INlok6G_00@ok6G_0Go0000
5_noXkd00ol0003ocK:oolfb_`02olfb_`?o00003_oA[KD00ol0003oh/:ion;2^@0>on;2^@;o0000
00?oikj[o`000?ojg:P01oojg:P00ol0003oomF=oooES@02o`0003;ooooo00?o0000ooooooooool0
2oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`0004Kooooo
00Go0000o`00M_l007Ko001fo`000002o`0IW`03o`000?mBBj_oDT^[00SoDT^[00?o0000of9Q^omR
HK/00_mRHK/00ol0003oQW>gohIc]`0BohIc]`?o00005OnPS;h00ol0003o/INlok6G_00=ok6G_0?o
00001?naUk`00ol0003o_j>moknS_@0CoknS_@03o`000?o=/[oocK:o00KocK:o0ol0000;om6]]@03
o`000?oR`[Woh/:i00ooh/:i00?o0000onNnZol000002?ojg:P01?l0003oomF=oooESOl0000coooo
o`03o`000?oooooooooo00_ooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0
003oooooooooo`15ooooo`05o`000?l007Ko001fo`00M_l000000ol06Il00ol0003oDT^[oe9;Z`06
oe9;Z`03o`000?mRHK_oHV6k00CoHV6k00?o0000ohIc]on6LkL03on6LkL2o`000003ohb1`_l0003o
X8bn01GoX8bn00?o0000ok6G_?naUk`02_naUk`3o`0000Oo/INl00?o0000oknS_OnoXkd04onoXkd0
0ol0003ocK:oolfb_`09olfb_`?o00001ooA[KD00ol0003oh/:ion;2^@0Aon;2^@03o`000?ojg:So
n]bX00Son]bX00?o0000oooESOl00000<oooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0
003oooooooooo`16ooooo`04o`000?l007Ko001fo`0000?o01VO00?o0000oe9;ZomBBj/01OmBBj/0
0ol0003oHV6kof9Q^`05of9Q^`03o`000?n6LkOoQW>g00goQW>g0_l00004ohb1`P03o`000?nPS;ko
X8bn01?oX8bn00?o0000ok6G_?naUk`01onaUk`3o`0000Wo/INl00?o0000oknS_OnoXkd05?noXkd0
0ol0003ocK:oolfb_`0<olfb_`?o00001?oA[KD00ol0003oh/:ion;2^@0Aon;2^@;o00002Oojg:P3
o`0003?ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0A_ooool01?l0
003o001fo`00M_l00003o`0IW`03o`000?mBBj_oDT^[00CoDT^[00?o0000of9Q^omRHK/01omRHK/0
0ol0003oQW>gohIc]`0:ohIc]`;o00001_n<PL800ol0003oX8bnoj2<_P0Doj2<_P03o`000?naUkco
/INl00;o/INl1?l0000<ok6G_003o`000?noXkgo_j>m01Co_j>m00?o0000olfb_oo=/[l03oo=/[l3
o`000003om6]]Ol0003oh/:i017oh/:i00Co0000oo7O_?l0003o00002Oojg:P2o`0003?ooooo00?o
0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0A_ooool01?l0003o001fo`00M_l0
0004o`0IW`03o`000?mBBj_oDT^[00;oDT^[00?o0000of9Q^omRHK/02?mRHK/00ol0003oQW>gohIc
]`08ohIc]`;o00002?n<PL800ol0003oX8bnoj2<_P0Doj2<_P03o`000?naUkco000000;o00004?na
Uk`00ol0003o_j>moknS_@0CoknS_@03o`000?o=/[oocK:o01?ocK:o0_l0000Aon;2^@06o`000?oa
gkcolMnlo`000?ojg:So00002?ojg:P2o`0003?ooooo00?o0000ooooooooool02oooool001Sooooo
00?o0000ooooooooool0Aoooool01?l0003o001fo`00M_l00004o`0IW`03o`000?mBBj_oDT^[00;o
DT^[00?o0000of9Q^omRHK/02OmRHK/00ol0003oQW>gohIc]`06ohIc]`03o`000?n<PL;oS87200Wo
S87200?o0000oj2<__nPS;h04_nPS;h3o`0001?o/INl00?o0000oknS_OnoXkd04onoXkd00ol0003o
cK:oolfb_`0Colfb_`03o`000?oKa/Go0000013oh/:i00Oo0000oo7O_?oagkcolMnlo`000?ojg:So
000000Kon]bX0_l0000dooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`000?oooooooooo
04Sooooo00?o0000o`00M_l000001Ol06Il01?l0003oDT^[oe9;Zol0000<of9Q^`03o`000?n6LkOo
QW>g00CoQW>g0_l0000<ohb1`P03o`000?nPS;koX8bn00ooX8bn0ol000000onPS;ko0000ok6G_00C
ok6G_003o`000?noXkgo_j>m01?o_j>m00?o0000olfb_oo=/[l04_o=/[l01Ol0003oflK5om_6aOoK
a/Go000000koh/:i00?o0000oo7O_?oagk`00_oagk`00ol0003on]bXo`000006oo[LZ0;o0000=Ooo
ool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`18ooooo`03o`000?l007Ko
000000Go01VO00?o0000oe9;Zol000003_mRHK/01?l0003oQW>gohIc]on6LkL2o`0000ooS87200?o
0000oj2<__nPS;h02_nPS;h4o`0000CoX8bn00?o0000ok6G_?naUk`04_naUk`00ol0003o_j>moknS
_@0BoknS_@03o`000?o=/[oocK:o01?ocK:o00?o0000om_6aOoKa/D00_oKa/D2o`0000coh/:i00?o
0000oo7O_?oagk`00_oagk`01?l0003on]bXoo[LZ?l00004oo[LZ0?o0000=Oooool00ol0003ooooo
ooooo`0:ooooo`006?ooool2o`0004Wooooo0_l00007o`0IW`03o`000?mRHK_oHV6k00goHV6k00Co
0000ohIc]ol0003o00004On<PL800ol0003oX8bnoj2<_P07oj2<_P?o00002?nPS;h00ol0003o/INl
ok6G_00Bok6G_003o`000?noXkgo_j>m01;o_j>m00?o0000olfb_oo=/[l04_o=/[l00ol0003oflK5
om_6a@05om_6a@03o`000?oR`[Woh/:i00Soh/:i00?o0000oo7O_?oagk`01?oagk`01?l0003on]bX
oo[LZ?l00003oo[LZ0?o0000=Oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003ooooo
ooooo`18ooooo`;o00001ol06Il00ol0003oHV6kof9Q^`0>of9Q^`03o`000?n<PL;oS872017oS872
00?o0000oj2<__nPS;h01?nPS;h3o`0000coX8bn00?o0000ok6G_?naUk`04OnaUk`00ol0003o_j>m
oknS_@0BoknS_@03o`000?o=/[oocK:o017ocK:o00?o0000om_6aOoKa/D01ooKa/D00ol0003oh/:i
on;2^@06on;2^@03o`000?oagkcolMnl00GolMnl00So0000oo[LZ?ojg:Son]bXo`000?ojg:So0000
onG[QP;o0000=Oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`19oooo
o`03o`000?l06Ioo01VO00Go01VO00?o8T>ko`000?mRHK/03_mRHK/00ol0003oS872ohb1`P0Bohb1
`P03o`000?nPS;koX8bn00?o00003onPS;h00ol0003o/INlok6G_007ok6G_13o00003onoXkd00ol0
003ocK:oolfb_`0Aolfb_`03o`000?oKa/GoflK500SoflK500?o0000on;2^OoR`[T01OoR`[T00ol0
003olMnloo7O_006oo7O_004o`000?ojg:Son]bXoo[LZ0;o000000?oiN^6o`000?ooool0=Oooool0
0ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1:ooooo`03o`000?l06Ioo01VO
00Go01VO00?o0000ob93^ol000003OmRHK/00ol0003oL7G8o`00000Bohb1`PCo00004?nPS;h<o`00
00[o/9o700?o0000okfZaonmZ/L00onmZ/L:o`0000Co_j>m00?o0000olfb_oo=/[l04Oo=/[l00ol0
003oflK5om_6a@0:om_6a@;o00001?oR`[T00ol0003olMnloo7O_007oo7O_006o`000?ojg:Son]bX
oo[LZ?l0003oiN^60_l0000fooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooo
oooo04[ooooo00?o0000o`0IWol06Il01?l06Il01?l0003o8T>kob93^ol0000<of9Q^`05o`000?m`
MLSoL7G8og1eb?l000003_n<PL83o`0000;oS87200?o0000oj2<__nPS;h02_nPS;h5o`0000;oXiK8
00?o0000ok2Oaon`WlL04On`WlL00ol0003o_J[7okfZa`0=okfZa`Ko00004_o=/[l00ol0003oflK5
om_6a@0<om_6a@05o`000?oR`[Woh/:ion;2^Ol000002_oagk`00ol0003on]bXoo[LZ004o`0003Ko
oooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0Boooool00ol0003o01VO
o`0IW`03o`0IW`05o`000?lR@k_o8T>kob93^ol000002_mRHK/00ol0003oL7G8og1eb002og1eb003
o`000?n<PL;oS87200WoS8720ol00005ohb1`P03o`000?nPS;koX8bn00GoX8bn1Ol00007oj>Fb003
o`000?n`WlOo/9o7017o/9o700?o0000okfZaonmZ/L04OnmZ/L00ol0003ob;S:o`000002o`0000ko
cK:o00?o0000om_6aOoKa/D03_oKa/D00ol0003oh/:io`00000;oo7O_003o`000?ojg:So000000;o
iN^600?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?l06Ioo01VO00?o01VO00?o0000ob93^olR@k/00_lR@k/00ol0003oHV6k
of9Q^`06of9Q^`03o`000?m`MLSoL7G800CoL7G800?o0000ohb1`_n<PL801On<PL83o`0000SoS872
00?o0000oj2<__nPS;h01Ol0000=oj>Fb003o`000?n`WlOo/9o7013o/9o700?o0000okfZaonmZ/L0
4?nmZ/L00ol0003ob;S:olRhbP03olRhbP?o00002oo=/[l00ol0003oflK5om_6a@0?om_6a@03o`00
0?oagkcolMnl00[olMnl00?o0000oo[LZ?l000000_oUjhH2o`0003Oooooo00?o0000ooooooooool0
2Oooool001Oooooo00?o0000ooooooooool0C?ooool00ol0003o01VOo`0IW`02o`0IW`03o`000?lR
@k_o8T>k00;o8T>k00?o0000of9Q^omRHK/01OmRHK/00ol0003oL7G8og1eb006og1eb003o`000?n<
PL;oS87200Co00002on<PL83o`0001;oXiK800?o0000ok2Oaon`WlL04?n`WlL00ol0003o_J[7okfZ
a`0@okfZa`03o`000?o8^<[ob;S:00Kob;S:0_l00008olfb_`03o`000?oKa/GoflK5013oflK500?o
0000oo7O_?oagk`02ooagk`01ol0003oiN^6onG[Q_oUjhKo0000ooooool00000=_ooool00ol0003o
ooooooooo`09ooooo`005oooool00ol0003oooooooooo`1<ooooo`03o`000?l06Ioo01VO00;o01VO
00?o0000ob93^olR@k/00olR@k/00ol0003oHV6kof9Q^`04of9Q^`03o`000?m`MLSoL7G800KoL7G8
0ol0000=ohb1`P;o000000?oTXo=o`000?nSU/P04_nSU/P00ol0003o/9o7ok2Oa`0@ok2Oa`03o`00
0?nmZ/Oo_J[7013o_J[700?o0000olRhb_o8^<X02?o8^<X3o`0000CocK:o00?o0000om_6aOoKa/D0
4?oKa/D00ol0003oi]k<o`00000<oo7O_003o`000?oUjhKoiN^600;o000000?oooooo`000?ooool0
=Oooool00ol0003oooooooooo`09ooooo`005oooool2o`0004kooooo00Go0000o`0IWol06Ioo01VO
o`000006ob93^`03o`000?mRHK_oHV6k00;oHV6k00?o0000og1eb?m`MLP01?m`MLP3o`000003og1e
b?l0003oS87200coS87200?o0000oi:?cOnBSld00_nBSld00ol0003oXiK8oj>Fb00@oj>Fb003o`00
0?n`WlOo/9o7013o/9o700?o0000okfZaonmZ/L03onmZ/L00ol0003ob;S:olRhbP0<olRhbP?o0000
00?ocK:oo`000?oKa/D04?oKa/D01?l0003oi]k<onKNc?l0000;oo7O_0;o00000_oUjhH01Ol0003o
oooooooooooooooo000003Gooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooooooo
ool0C_ooool01Ol005Ko0000o`0IWol06Ioo000000Ko8T>k00Go0000of9Q^omRHK_oHV6ko`000004
og1eb0?o00001?m`MLP00ol0003oS872ohb1`P09ohb1`P;o00001OnBSld00ol0003oXiK8oj>Fb00@
oj>Fb003o`000?n`WlOo/9o700oo/9o700?o0000okfZaonmZ/L04?nmZ/L00ol0003ob;S:olRhbP0?
olRhbP;o00004OoKa/D01Ol0003oi]k<onKNc?oVg/co000000WolMnl00?o0000on_i/_l000000_oU
jhH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Ooo
ool001Kooooo00?o0000ooooooooool0Coooool00ol0003o01VOo`000008ob93^`04o`000?mRHK_o
0000og1eb0Co00002?m`MLP00ol0003oS872ohb1`P06ohb1`P;o00002?nBSld00ol0003oXiK8oj>F
b00@oj>Fb003o`000?n`WlOo/9o700ko/9o700?o0000okfZaonmZ/L03onmZ/L00ol0003ob;S:olRh
bP0@olRhbP03o`000?oCb=3o000000ooflK500?o0000onKNc?oVg/`00_oVg/`00ol0003olMnloo7O
_006oo7O_003o`000?o[nK;o000000?oiN^600?o0000ooooooooool00oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04oooooo00?o001F
o`000?l000002OlR@k/3o`0000goL7G800?o0000ohb1`_n<PL800on<PL82o`0000_oTXo=00?o0000
oj>Fb?nSU/P03onSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo_J[700oo_J[700?o0000
olRhb_o8^<X03oo8^<X01Ol0003odlS@om?8d?oCb=3o000000goflK500?o0000onKNc?oVg/`01?oV
g/`00ol0003olMnloo7O_005oo7O_003o`000?o[nK;o000000;oiN^600?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooo
oooo053ooooo0_l00006ob93^`Co00003om`MLP00ol0003oS872ohb1`P02ohb1`P03o`000?nBSlgo
TXo=00_oTXo=00?o0000oj>Fb?nSU/P03onSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo
_J[700oo_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d003om?8d0;o00002_oKa/D0
0ol0003oi]k<onKNc005onKNc003o`000?oagkcolMnl00ColMnl00Co0000on_i/_o[nK;o00000_oU
jhH00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool001Kooooo00?o0000ooooooooool0D?ooool00ol005Ko0000ob93^`02ob93^`?o00000olR@k/2
o`0000ooL7G800Co0000ohb1`_l0003o00003onBSld00ol0003oXiK8oj>Fb00>oj>Fb003o`000?n`
WlOo/9o700ko/9o700?o0000okfZaonmZ/L03_nmZ/L00ol0003ob;S:olRhbP0?olRhbP03o`000?oC
b=3odlS@00GodlS@00?o0000om_6aOoKa/D01ooKa/D00ol0003oi]k<onKNc006onKNc003o`000?oa
gkcolMnl00;olMnl00Oo0000on_i/_o[nK;ojoVbo`000?oUjhKo000000Wooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1Aooooo`Co0000
1_lR@k/00ol0003o@fG?o`00000?og1eb003o`000?nBSlgoTXo=00ooTXo=00?o0000oj>Fb?nSU/P0
3_nSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo_J[700ko_J[700?o0000olRhb_o8^<X0
3_o8^<X00ol0003odlS@om?8d007om?8d003o`000?oKa/GoflK500GoflK500?o0000onKNc?oVg/`0
1ooVg/`00ol0003olMnloo7O_002oo7O_007o`000?o[nK;ojoVbon_i/_l0003oiN^6o`00000:oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool0Coooool3o`000003o`00E_l0003o8T>k00Ko8T>k00Go0000od=Ucom3ILoo@fG?o`00000>og1e
b003o`000?nBSlgoTXo=013oTXo=00?o0000oj>Fb?nSU/P03_nSU/P00ol0003o/9o7ok2Oa`0=ok2O
a`03o`000?nmZ/Oo_J[700go_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d009om?8
d0;o00001?oKa/D00ol0003oi]k<onKNc009onKNc004o`000?oagkcolMnlo`0000CojoVb0_l0000<
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001<oooo
o`?o00001?ooool00ol02IWo0000ob93^`05ob93^`03o`000?m3ILoo@fG?00;o@fG?00?o0000og1e
b?m`MLP02_m`MLP00ol0003oO8OCo`00000Aoi:?c@03o`000?nSU/SoXiK800koXiK800?o0000ok2O
aon`WlL01On`WlL=o`0000_o_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d00;om?8
d005o`000?oKa/GoflK5om_6aOl000002ooVg/`00ol0003olMnlo`000005on_i/P;o00003Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
04Wooooo0ol00007ooooo`03o`00E_l02IWo000000Go8T>k00?o0000od=Ucom3ILl00om3ILl00ol0
003oL7G8og1eb008og1eb005o`000?mlQm?oO8OCogb7dol000004OnBSld00ol0003oXiK8oj>Fb00;
oj>Fb0[o00002?n_ZM800ol0003o^K;BokVbdP02okVbdPOo00001?nmZ/L00ol0003ob;S:olRhbP0=
olRhbP03o`000?oCb=3odlS@00godlS@00?o0000om_6aOl000003OoVg/`00ol0003ojoVbon_i/P03
on_i/P03o`000?oUjhKo000000kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08
ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002oooool00ol0003o00VIo`000004ob93
^`03o`000?m3ILoo@fG?00?o@fG?00?o0000og1eb?m`MLP01om`MLP00ol0003oO8OCogb7d`03ogb7
d`03o`000?nBSlgoTXo=00ooTXo=00?o0000oj>Fb?nSU/P01OnSU/P5o`0000;oY:;C00?o0000ojnY
d_n_ZM803On_ZM800ol0003o^K;BokVbdP09okVbdPGo00003oo8^<X00ol0003odlS@om?8d00>om?8
d003o`000?oVg/coi]k<00coi]k<00?o0000on_i/_o[nK800oo[nK82o`0000oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`12ooooo`?o
00003oooool00ol005Ko00VIo`000004ob93^`03o`000?m3ILoo@fG?00Co@fG?00?o0000og1eb?m`
MLP01Om`MLP00ol0003oO8OCogb7d`05ogb7d`03o`000?nBSlgoTXo=00koTXo=00?o0000oj>Fb?nS
U/P01Ol00007ojBRd`03o`000?n_ZM;o[jWB00go[jWB00?o0000okVbd_ni/]803?ni/]800ol0003o
`[cEo`000002o`0000_ob;S:00?o0000om?8d?oCb=003OoCb=000ol0003ofmcHo`00000=onKNc0;o
00001Oo[nK82o`00013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`00
5Oooool00ol0003oooooooooo`0oooooo`?o00004oooool00ol0003o00VIo`000003ob93^`03o`00
0?m3ILoo@fG?00Go@fG?00?o0000og1eb?m`MLP00om`MLP00ol0003oO8OCogb7d`07ogb7d`03o`00
0?nBSlgoTXo=00goTXo=0ol0000=ojBRd`03o`000?n_ZM;o[jWB00co[jWB00?o0000okVbd_ni/]80
2oni/]800ol0003o`[cEol:le@03ol:le@?o00001oo8^<X00ol0003odlS@om?8d00=om?8d005o`00
0?oKg=SofmcHom_Lf?l000002ooVg/`00ol0003oi_W?o`000005on_i/P03o`000?oooooooooo013o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0mooooo`?o00005_ooool01_l0003o00VIo`09VOl0003o8T>ko`0000Wo@fG?00Go0000og1e
b?m`MLSoL7G8o`00000;ogb7d`03o`000?nBSlgoTXo=00[oTXo=0_l000000onGWMOo0000ojBRd`0=
ojBRd`03o`000?n_ZM;o[jWB00co[jWB00?o0000okVbd_ni/]802oni/]800ol0003o`[cEol:le@06
ol:le@;o00001Oo8^<X00ol0003odlS@om?8d00<om?8d003o`000?oKg=SofmcH00;ofmcH00?o0000
onKNc?oVg/`02?oVg/`00ol0003oi_W?o`000006on_i/P03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0ioooo
o`Co00006_ooool00ol0003o00VIo`09V@02o`0000[o@fG?00?o0000og1eb?l000003OmlQm<00ol0
003oTXo=oi:?c@07oi:?c@;o00001?nGWML00ol0003oY:;CojBRd`0;ojBRd`03o`000?n_ZM;o[jWB
00co[jWB00?o0000okVbd_ni/]802_ni/]800ol0003o`[cEol:le@09ol:le@?o000000?ob;S:o`00
0?oCb=003OoCb=000ol0003ofmcHom_Lf004om_Lf003o`000?oVg/coi]k<00Koi]k<00Co0000onKi
cooVnLoo00001Oo[nK800ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool01oooool001Cooooo00?o0000ooooooooool0=_ooool3o`0001kooooo00Go0000o`09
VOl02IWo00VIo`00000;od=Uc`;o00003_mlQm<00ol0003oTXo=oi:?c@05oi:?c@03o`000?nGWMOo
UigG00GoUigG00?o0000ojBRdonTX]<02onTX]<00ol0003o[jWBojnYdP0;ojnYdP03o`000?ni/];o
^K;B00[o^K;B00?o0000ol:leOo2_=D03?o2_=D2o`0000godlS@00?o0000om_Lf?oKg=P01OoKg=P0
0ol0003oi]k<onKNc005onKNc005o`000?oVnLooi_W?onKicol000001?o[nK800ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool001Cooooo0ol0000c
ooooo`?o00008_ooool01Ol0003o00VIo`09VOl0AlSo000000[o@fG?0_mMP=`00ol0003oO8OCogb7
d`0<ogb7d`03o`000?nBSlgoTXo=00;oTXo=0_l00008oiNMe`03o`000?nTX]?oY:;C00_oY:;C00?o
0000ojnYd_n_ZM802_n_ZM800ol0003o^K;BokVbdP0;okVbdP03o`000?o2_=Go`[cE00co`[cE00?o
0000olW9f_l000002ooCb=000ol0003ofmcHom_Lf007om_Lf003o`000?oVg/coi]k<00?oi]k<00?o
0000onKicooVnLl00_oVnLl01Ol0003ojoVbon_i/_o[nK;o000001Sooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00009Ooo
ool01_l0003o00VIo`09VOl02IWo04O8o`0000Wo@fG?00Co0000oef0g?mMP=co00003_mlQm<01?l0
003oTXo=o`000?l0000;oiNMe`03o`000?nTX]?oY:;C00[oY:;C00?o0000ojnYd_n_ZM802_n_ZM80
0ol0003o^K;BokVbdP0:okVbdP03o`000?o2_=Go`[cE00co`[cE00Co0000olW9f_o9bM[obLWJ0_l0
0008om?8d003o`000?oKg=SofmcH00SofmcH00?o0000onKNc?oVg/`00_oVg/`00ol0003oi_W?onKi
c`03onKic`04o`000?o[nK;ojoVbo`0001[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?oo
ool4o`0002Wooooo00Ko0000o`09VOl02IWo0000o`17b?l00007od=Uc`03o`000?mMP=coGH3L00;o
GH3L00?o0000ogb7domlQm<03?mlQm<00ol0003oUigGoiNMe`0;oiNMe`03o`000?nTX]?oY:;C00[o
Y:;C00?o0000ojnYd_n_ZM802_n_ZM800ol0003o^K;BokVbdP0:okVbdP03o`000?o2_=Go`[cE00_o
`[cE00?o0000olW9f_o9bMX01?o9bMX00ol0003odlS@om?8d004om?8d003o`000?oKg=SofmcH00[o
fmcH00Co0000onKNc?oVg/co00001_oVnLl00ol0003ojoVbo`00000Looooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Zooooo`?o0000;Oooool01?l0003o00VIo`09VOl00002o`17b003o`000?m3ILoo@fG?
00Co@fG?00?o0000oef0g?mMP=`00omMP=`00ol0003oO8OCogb7d`0:ogb7d`03o`000?n7VMko0000
00goUigG00?o0000ojBRdonTX]<02_nTX]<00ol0003o[jWBojnYdP09ojnYdP03o`000?ni/];o^K;B
00Wo^K;B00?o0000ol:leOo2_=D02oo2_=D00ol0003obLWJolW9fP06olW9fP;o00000ooCb=000ol0
003ofmcHom_Lf00;om_Lf003o`000?oVg/co000000Koi_W?00Co0000on_i/_l0003o00007Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09oooool3o`00037ooooo00Co0000o`09VOl02IWo00000_l0AlP0
0ol0003o@fG?od=Uc`03od=Uc`03o`000?mMP=coGH3L00CoGH3L0_l00009ogb7d`05o`000?n7VMko
QiWNohNIg_l000003OnGWML00ol0003oY:;CojBRd`09ojBRd`03o`000?n_ZM;o[jWB00Wo[jWB00?o
0000okVbd_ni/]802Oni/]800ol0003o`[cEol:le@0:ol:le@03o`000?o9bM[obLWJ00WobLWJ00?o
0000om?8d?l000003ooKg=P00ol0003oi_W?onKic`05onKic`?o00007oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09?ooool3o`0003Gooooo00?o0000o`09VOl000000ol0AlP00ol0003o@fG?od=Uc`02
od=Uc`03o`000?mMP=coGH3L00KoGH3L00?o0000ogb7domlQm<01OmlQm<00ol0003oQiWNohNIgP03
ohNIgP03o`000?nGWMOoUigG00[oUigG00?o0000ojBRdonTX]<02OnTX]<00ol0003o[jWBojnYdP09
ojnYdP03o`000?ni/];o^K;B00So^K;B00?o0000ol:leOo2_=D02_o2_=D00ol0003obLWJolW9fP0;
olW9fP03o`000?oKg=SofmcH00cofmcH00?o0000om[ch?l000001ooVnLl2o`00023ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo023ooooo1?l0000iooooo`03o`000?l02IWo000000?o04O800Go0000od=U
com3ILoo@fG?o`000009oef0g003o`000?mlQm?oO8OC00?oO8OC00?o0000ohNIg_n7VMh01On7VMh0
0ol0003oUigGoiNMe`0:oiNMe`03o`000?nTX]?oY:;C00WoY:;C00?o0000ojnYd_n_ZM800on_ZM89
o`0000Oo^K;B00?o0000ol:leOo2_=D02_o2_=D00ol0003obLWJolW9fP09olW9fP03o`000?o=fN;o
000000cofmcH0_l00002om[ch003o`000?oVnLooi_W?00Coi_W?0_l0000Rooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Mooooo`?o0000?_ooool00ol02IWo0000o`17b003o`17b003o`000?m3ILoo0000
00_oGH3L00Go0000ogb7domlQm?oO8OCo`000009ohNIgP03o`000?nGWMOoUigG00WoUigG00?o0000
ojBRdonTX]<01onTX]<8o`0000Go[;CN00Co0000ok>jg_nc^]ko/k[N1Ol00002okVbdP03o`000?o2
_=Go`[cE00Wo`[cE00?o0000olW9f_o9bMX02Oo9bMX01Ol0003ocMWRolgIh_o=fN;o000000[ofmcH
00?o0000om[ch?oJln000_oJln000ol0003oi_W?onKic`03onKic`;o00009?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool3o`00047ooooo00?o0000o`09VOl000001?l0AlP00om3ILoo0000oef0
g00;oef0g003o`000?mlQm?o000000_oQiWN00?o0000oiNMeonGWML02OnGWML01?l0003oY:;CojBR
donTX]<5o`0000;oY:oO00?o0000ojbdg_n/]=h02?n/]=h00ol0003o/k[Nok>jgP06ok>jgPCo0000
2Oo2_=D00ol0003obLWJolW9fP08olW9fP;o00001?o=fN800ol0003ofmcHom_Lf006om_Lf0;o0000
1OoJln000ol0003oi_W?onKic`02onKic`;o00009_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000AOoo
ool2o`0000Go04O80_l0000<oef0g0;o00003?n7VMh00ol0003oUigGoiNMe`08oiNMe`Co00002?nT
[ml00ol0003o[;CNojbdgP07ojbdgP03o`000?nc^]ko/k[N00Oo/k[N00?o0000okW1hOni`N400ol0
0005ol:le@03o`000?o9bM[obLWJ00SobLWJ00?o0000olgIh_o=fN801Oo=fN800ol0003ofmcHom_L
f004om_Lf003o`000?oJln3of_?P00Gof_?P00Co0000onKicooVnLooi_W?0ol0000Wooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool001;ooooo00?o0000ooooooooool05?oo
ool4o`0004Wooooo00?o0000o`17b?l0AlP00ol0AlP00ol0003o;WKRo`00000;oef0g0;oLiOV00?o
0000ohNIg_n7VMh02_n7VMh00ol0003oUigGoiNMe`05oiNMe`;o000000?oW:cRo`000?nT[ml02OnT
[ml00ol0003o[;CNojbdgP06ojbdgP03o`000?nc^]ko/k[N00Oo/k[N00?o0000okW1hOni`N401?ni
`N43o`000003ol:leOl0003obLWJ00WobLWJ00?o0000olgIh_o=fN801_o=fN800ol0003ofmcHom_L
f003om_Lf003o`000?oJln3of_?P00Gof_?P00Oo0000onKicooVnLooi_W?o`000?nam;?o000002So
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`0Aooooo`?o0000C_ooool2o`0000Co04O800Co0000obifh_l0003o00002OmMP=`00ol0003o
LiOVog>GiP02o`0000_oQiWN00?o0000oiNMeonGWML00_nGWML2o`0000CoW:cR00?o0000ojB_gonT
[ml01onT[ml00ol0003o[;CNojbdgP06ojbdgP03o`000?nc^]ko/k[N00Ko/k[N00?o0000okW1hOni
`N402?ni`N400ol0003obLWJolW9fP08olW9fP03o`000?o=fN;ocMWR00SocMWR00?o0000om_Lf?oK
g=P00_l00008om[ch006o`000?oVnLooi_W?o`000?nam;?o0000:_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0001Coooo
o`05o`000?l0AlSo04O8o`17b?l000000ol^M^800ol0003oGH3Loef0g005oef0g003o`000?mcUnKo
LiOV00?oLiOV00?o0000ohNIg_n7VMh02On7VMh01?l0003oUigGo`000?l00007oib/hP03o`000?nT
[mooY:oO00OoY:oO00?o0000ojbdg_n/]=h01On/]=h00ol0003o/k[Nok>jgP06ok>jgP03o`000?ni
`N7o^L7Q00Oo^L7Q0onlb^@00ol0003obLWJolW9fP04olW9fP;o00002oo=fN800ol0003ofmcHo`00
000:om[ch005o`000?oVnLoo0000ok7d/ol00000;?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00_ooooo0ol0001Gooooo`04o`000?l0
AlSo04O8o`0000Co;WKR0_l00005oef0g003o`000?mcUnKoLiOV00CoLiOV0_l0000:ohNIgP;o0000
2OnL[>800ol0003oY:oOojB_g`06ojB_g`03o`000?n/]=ko[;CN00Go[;CN00?o0000ok>jg_nc^]h0
1Onc^]h00ol0003o^L7QokW1h@06okW1h@03o`000?nlb^Co_<[T00?o_<[T0_l00003olW9fP03o`00
0?o=fN;ocMWR00cocMWR00?o0000om[ch?oJln002OoJln02o`0000;o/OBc00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oo
oooooooo00Oooooo1?l0001Kooooo`04o`000?l0AlSo04O8o`0000Go;WKR00?o0000oef0g?mMP=`0
0_mMP=`00ol0003oLiOVog>GiP06og>GiP;o00002?n7VMh00ol0003oTZ_Wo`000009oib/hP03o`00
0?nT[mooY:oO00GoY:oO00?o0000ojbdg_n/]=h01On/]=h00ol0003o/k[Nok>jgP04ok>jgP03o`00
0?ni`N7o^L7Q00Ko^L7Q00?o0000okc:i?nlb^@01_nlb^@00ol0003obLWJo`00000<olgIhP;o0000
00?obnS[o`000?oJln002_oJln001?l0003o/OBcok7d/ol0000_ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3o`00063ooooo
00?o0000o`17b?l000001_l^M^82o`0000;oGH3L00?o0000og>Gi_mcUnH02?mcUnH00ol0003oQiWN
ohNIgP04ohNIgP04o`000?nBZnOoTZ_Woi:[i`;o00002?nL[>800ol0003oY:oOojB_g`05ojB_g`03
o`000?n/]=ko[;CN00Co[;CN00?o0000ok>jg_nc^]h01?nc^]h00ol0003o^L7QokW1h@05okW1h@03
o`000?nlb^Co_<[T00So_<[T00?o0000olgIh_o=fN802Oo=fN82o`0000?obnS[00?o0000om[ch?oJ
ln001_oJln02o`000004okong_l0003o/OBco`00037ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000I?ooool00ol0003o
04O8o`000007obifhP03oef0g?l0003oLiOV00_oLiOV0_l00003ohNIgP03o`000?nBZnOoTZ_W00Co
TZ_W00?o0000oib/h_nL[>801OnL[>800ol0003oY:oOojB_g`05ojB_g`03o`000?n/]=ko[;CN00Co
[;CN00?o0000ok>jg_nc^]h00onc^]h00ol0003o^L7QokW1h@05okW1h@03o`000?nlb^Co_<[T00So
_<[T00?o_]?Zo`000?o=fN802?o=fN82o`0000GobnS[00?o0000om[ch?oJln001OoJln000ol0003o
_okNokongP03o`0003;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`00
4Oooool00ol0003oooooo`000002o`0006Sooooo00?o04O8o`000?l^M^801ol^M^82o`0000goLiOV
0_n7VMh00ol0003oTZ_Woi:[i`06oi:[i`;o00001_nL[>800ol0003oY:oOojB_g`04ojB_g`03o`00
0?n/]=ko[;CN00?o[;CN00?o0000ok>jg_nc^]h01?nc^]h00ol0003o^L7QokW1h@04okW1h@03o`00
0?nlb^Co_<[T00Ko_<[T00?o0000okkCj_nndnX00_nndnX00ol0003ocMWRolgIhP04olgIhP;o0000
1oo;j>/00ol0003of_?Pom[ch003om[ch0;o00000_noo]h2o`0003Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0006cooooo00?o0000obifh_l^M^801_l^
M^800ol0003oFYO_o`000002o`0000_oLiOV0_l0000:oi:[i`03o`000?nL[>;oW:cR00CoW:cR00?o
0000ojB_gonT[ml01?nT[ml00ol0003o[;CNojbdgP02ojbdgP03o`000?nc^]ko/k[N00?o/k[N00?o
0000okW1hOni`N401?ni`N400ol0003o_<[Tokc:i005okc:i0;o00001_nndnX01?l0003ocMWRolgI
h_o=fN82o`0000WobnS[00Co0000om[ch?oJln3of_?P0_l00003okongP;o0000=oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06[ooooo
0_l00007obifhP04o`000?mJUnooFYO_oeZGk`;o00002OmcUnH00ol0003oQj_]o`000002o`0000So
TZ_W00?o0000oib/h_nL[>801?nL[>801?l0003oY:oOojB_gonT[ml>o`0000Go^L7Q00?o0000okc:
i?nlb^@01?nlb^@2o`0000So_]?Z00Co0000olgIh_l0003o00002oo;j>/01?l0003of_?Pom[ch?l0
0004okongP;o0000>Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo000D
ooooo`;o0000Joooool3o`0000Go;WKR00?o0000oeZGkomJUnl00omJUnl2o`0000KoLiOV00?o0000
ohN[kOn7Znd00on7Znd2o`0000OoTZ_W0_l00004oib/hPCo00000_nS_^d00ol0003oY/3/ojK0k002
ojK0k003o`000?nY`^coZL;/00;oZL;/00?o0000oj_5kOl000000_l000000oni`N7o0000okc:i004
okc:i0;o00002onndnX00ol0003obnS[ol_Xj`0;ol_Xj`?o00001?noo]h00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000oooo
ool00000JOooool00ol0003o06;Co`000002o`0000?o;WKR00?o0000oeZGkomJUnl01?mJUnl3o`00
00?oLiOV00?o0000ohN[kOn7Znd01On7Znd3o`0000KoTZ_W00Co0000oib/h_l0003o00000onO_Nh0
1Ol0003oXkk]oj>nkOnS_^go000000?oY/3/00Go0000ojW2k?nY`^coZL;/o`000004oj_5k@?o0000
1?nlb^@00ol0003o_]?ZokkCjP08okkCjP;o000000?o^mc`o`000?o;j>/03?o;j>/00ol0003o_okN
okongP03okongP03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`04ooooo`005oooool2o`0006_ooooo00?o0000o`1Rdol0H]<00_l000000ol^M^;o0000oeZG
k`08oeZGk`04o`000?mcUnKoLiOVo`0000[oQj_]0_l00005oi:[i`;o00001OnO_Nh01?l0003oXkk]
oj>nkOl00003ojK0k004o`000?nY`^coZL;/o`0000CoZlG]00Ko0000ojc8kon/b>oo[<S_o`000?nl
b^@2o`0000Oo_]?Z0ol00004ok_Ll003o`000?o;j>_obnS[00OobnS[0ol000000onmm?7o0000okon
gP03okongP03o`000?oooooooooo03gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`04ooooo`006?ooool2o`0006_ooooo0_l00002o`1Rd`;o00002omJUnl3o`0000_oQj_]0ol00000
1?nBZnOo0000oibml?nL_O02o`0000CoWkg^00Co0000oj>nkOnS_^go00000_nV`>`01?l0003oZL;/
ojW2k?l00002oj_5k@;o00001?n/b>l2o`0000Ko_]?Z0ol00007ok_Ll003o`000?o;j>_obnS[00Co
bnS[0ol00003okgdl@04o`000?noo]ko_okNokongP;o0000@Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo06Wooooo0_l00003o`1Rd`?o
00002?mJUnl00ol0003oNjkdog^^m004o`0000[oQj_]0ol00003oibml0;o00000onO_Nh01Ol0003o
Xkk]o`000?nV`>co000000;oZL;/00Co0000oj_5kOl0003o00000on/b>l3o`0000;oZlca00?o0000
okkCj_nndnX00ol0000:ok_Ll004o`000?o;j>_obnS[ol_Xj`?o00001Onmm?400ol0003o_okNokon
gP02o`0004Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`006oooool2
o`000003ooooool0003ooooo06Sooooo00?o0000o`1Rdol0H]<00_l0H]<01?ljU_;o0000o`000?l0
0006oeZGk`03o`000?mk[_CoNjkd00?oNjkd1?l00006ohN[k@03o`000?nH__;oV;kb00Co000000Go
W;g`o`000?l0003o0000oinmkP02o`000006ojK0k?l0003oZL;/o`000?n[aNgo00000_n/b>l3o`00
00?oZlca1Ol0000=ok_Ll0Co00001onmm?401?l0003o_okNo`000?l00017ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool001gooooo0_l0001Zooooo`03o`000?l0H]?o06;C
00;o06;C00?o0000ocZFl_ljU_800ol00003oeZGk`03o`000?mk[_CoNjkd00OoNjkd1?l000000on7
Zngo0000oiRnlP06oiRnlP?o000000?oW;g`o`000?l000000ol000000onY`^co0000o`000003o`00
0003oj_<lOl0003o000000?o00000onZc_<00ol0003o^mc`ok_Ll00<ok_Ll003o`000?nmm?7o_OCa
00Oo_OCa1?l00018ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001ko
oooo00?o0000ooooooooool0JOooool2o`0000?o06;C00?o0000ocZFl_ljU_800_ljU_84o`0000go
Njkd2_l00002oiRnlPgo00002?nZc_<01?l0003o^mc`ok_Ll?nkg?07o`0000Co/n?g00?o0000okgd
lOnmm?401_nmm?43o`0004_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03oooo
o`007oooool2o`0006_ooooo0_l00002o`1Rd`03o`000?ljU_;o>YKb00Co>YKb2_l00005og^^m003
o`000?nE_oCoUKod00KoUKod6ol0000:ok?Sm`03o`000?nmm?7o_OCa00Co_OCa00Co0000okgdlOl0
003o0000C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Qooooo`03
o`000?oooooooooo06[ooooo0_l000000ol0H]?o0000ocZFlP06ocZFlP03o`000?m`/oWoL;?i00Go
L;?i3_l00002oi?2m`Co000000?oTlSjo`000?l000001_l00008ojO@m@03o`000?nchoOo/n?g00[o
/n?g00Co0000okgdlOnmm?7o_OCa1ol0001@ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool002;ooooo0ol0001/ooooo`;o00001oljU_800ol0003oL;?iog2cn@0:og2cn@03
o`000?nC`_OoTl;g00CoTl;g0ol000001?nBaOSo0000o`000?nCb?X2o`000003oi[>n_l0003oW]3i
00?o000000?oXm7go`000?l000000ol00002ojO@m@03o`000?nchoOo/n?g00[o/n?g1Ol00002oi[a
k`?o0000Doooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Tooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooool000000ol00004ocZFlP03o`000?m`/oWoL;?i00[o
L;?i00?o0000oi?2monC`_L00ol00003oi;5n004o`000?nCb?[oTlSjoi?8nP;o00000_nJc_X01?l0
003oW]3ioik@nOnNd?T2o`0000CoXm7g3Ol000000onchoOo0000o`000005oi[ak`;o0000E_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o0000J_ooool01_l0
003ooooooooooooooooo0000oafEjPCo000000?o>YKbo`000?m`/oT01Om`/oT5o`000003og2cnOl0
003o000000CoT/Gh0_l00003oi?8nP04o`000?nFc?[oU/cjo`0000;oV/kj00?o0000oik@nOnNd?T0
0_nNd?T2o`000003oj?Amol0003oYNGk00_oYNGk00?o0000oi[akonJlNl01?nJlNl2o`0005Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo00?ooooo0_l00003oafEjPOo00002?mX^Od2o`000003oi;5n?l0
003oTlSj00?oTlSj00Go0000oiK<n_nFc?[oU/cjo`000003oi[>nP04o`000?nNd?WoW]3ioik@n@Ko
00002?nUiO/2o`0000KoV_7_0_l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool002Sooooo00?o0000ooooool00000I_ooool00ol0003oooooooooo`05ooooo`03od/0
0?l0003o000000?o7IGZ0ol0000;ofRio@Co00000_nCb?X01Ol0003oU/cjoiK<n_nFc?[o000000;o
V/kj1Ol00006oi7QoPCo00000onUiO/01?l0003oV_7_oi[akonJlNl5o`0005gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Co
oooo0_l0001Vooooo`03o`000?oooooooooo00Sooooo0_l00004oafEjP?o00000_mX^Od4o`0000Ko
I/;n2Ol00004ogcHoP;o00002OnAhOh9o`00067ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool02_ooool6o`000003oafEj_l0003o000000WoI/;n00?o0000ofg<o_m]c?h0
1?m]c?h00ol0003oO=SnogcHoP06ogcHoP;o00000_nAhOh9o`0006Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000ooooooooool02Ooo
ool2o`0006?ooooo00?o0000ooooooooool03Oooool2o`0000Go3IOI1Ol00002ofK2oP03o`000?m]
c?koKLcn00KoKLcn00?o0000ogcHo_mlf?h00_mlf?h<o`0006_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
0000063ooooo00?o0000ooooooooool04_ooool4o`0000?o3IOI0_l000000om]c?ko0000o`00000B
o`00077ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`008?ooool00ol0
003oooooooooo`0<ooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`?o00001OlFXll;o`00
07Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003o
ooooooooo`0=ooooo`;o0000Goooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o000000?oooooo`000?ooool0F?oo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Ooo
ool003Gooooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000hooooo`05o`000?oooooooooooooo
ool00000Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool003Wooooo00Co0000oooooooooooo0000Doooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000jooooo`?o0000Doooool00ol0003o
ooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000looooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o0000
0Oooool1ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00001>ooooo`03o`000?oooooo
oooo0:cooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0043ooooo0_l0001>oooo
o`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool0047o
oooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003ooooool0003ooooo04Oooooo00?o
0000ooooooooool0[oooool00ol0003oooooooooo`04ooooo`7o00000Oooool004Kooooo0_l00018
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo000boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l0
0017ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool00_ooool1o`00007ooooo000b
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000
A_ooool00ol0003oooooooooo`2booooo`05o`000?ooooooooooooooool000000Oooool002[ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03o`0004?o
oooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00Ol0000003;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`03o`000?oo
oooooooo0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`0:ooooo`;o0000?_ooool00ol0003oooooooooo`2fooooo`;o0000000b
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l0000mooooo`03o`000?oo
oooooooo0;Gooooo0ol0000005?ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oo
oooooooo0;3ooooo1Ol00003ooooo`00E?ooool01?l0003oooooooooool0000hooooo`03o`000?oo
oooooooo0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o0000ooooooooool0Z?ooool4
o`0000cooooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y?ooool5o`00
013ooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Pooooo`Co00005Oooool005[ooooo
00?o0000ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co00006Oooool005_ooooo0_l0
000booooo`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool01?l0003oooooooooool0000]
ooooo`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3o`0002gooooo00?o0000oooo
ooooool0R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0002_o
oooo00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo07gooooo1?l0000hooooo`00
Doooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Xooooo`03o`000?oooooooooo07Wo
oooo1?l0000looooo`00Doooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0L?ooool4o`00
04Gooooo001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3o`0002?ooooo00?o0000oooo
ooooool0Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`00
02?ooooo00?o0000ooooooooool0Ioooool4o`0004kooooo001Cooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05?ooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool0Hoooool4o`00
05;ooooo001^ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Go0000E_ooool006oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co0000Foooool0073ooooo0_l0
000Mooooo`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_ooool00ol0003oooooo`00000J
ooooo`03o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2o`0001[ooooo00?o0000oooo
ooooool0COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0BOooool4o`0006cooooo001fooooo`;o000000?oooooo`000?ooool05?ooool00ol0003ooooo
ooooo`14ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`000?oooooooooo043ooooo1?l0
001eooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo1Ol0001i
ooooo`00N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0=oooool4o`00
07kooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@03ooooo`;o00004Oooool00ol0003oooooooooo`0cooooo`Co0000P_ooool0
06?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_ooool006?ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oooooooooo02Oooooo1?l0002?
ooooo`00Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool5o`0009?ooooo001S
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool07_ooool4o`0009Sooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o00001oooool00ol0003ooooo
ooooo`0Iooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Qooooo`00Qooo
ool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo0029ooooo`;o00000oooool0
0ol0003oooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000ooooooooooooooooo`00000:
ooooo`Co0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05ooooo`Co0000/_ooool008go
oooo0_l000000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o0000^oooool00?ooooooC?oo
ool00?ooooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30ooooo`00Q_ooool00ol0003o
ooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003ooooooooo
o`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32oooo
o`00Q_ooool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGoIVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48157 .55209 m .47499 .59268 L .54365 .596 L p .719 .599 .722 r
F P
0 g
s
.54365 .596 m .54143 .55506 L .48157 .55209 L p .719 .599 .722 r
F P
0 g
s
.54546 .63733 m .54365 .596 L .47499 .59268 L p .72 .574 .689 r
F P
0 g
s
.54143 .55506 m .54365 .596 L .61084 .58602 L p .671 .562 .724 r
F P
0 g
s
.54365 .596 m .54546 .63733 L .61973 .62657 L p .666 .531 .691 r
F P
0 g
s
.61973 .62657 m .61084 .58602 L .54365 .596 L p .666 .531 .691 r
F P
0 g
s
.48917 .51282 m .48157 .55209 L .54143 .55506 L p .716 .623 .752 r
F P
0 g
s
.54143 .55506 m .53887 .51534 L .48917 .51282 L p .716 .623 .752 r
F P
0 g
s
.53887 .51534 m .54143 .55506 L .59996 .54615 L p .674 .591 .754 r
F P
0 g
s
.61084 .58602 m .59996 .54615 L .54143 .55506 L p .671 .562 .724 r
F P
0 g
s
.47499 .59268 m .46961 .63375 L .54546 .63733 L p .72 .574 .689 r
F P
0 g
s
.5468 .67806 m .54546 .63733 L .46961 .63375 L p .72 .546 .654 r
F P
0 g
s
.54546 .63733 m .5468 .67806 L .62632 .66684 L p .659 .498 .655 r
F P
0 g
s
.62632 .66684 m .61973 .62657 L .54546 .63733 L p .659 .498 .655 r
F P
0 g
s
.42567 .53745 m .41072 .57626 L .47499 .59268 L p .764 .642 .727 r
F P
0 g
s
.47499 .59268 m .48157 .55209 L .42567 .53745 L p .764 .642 .727 r
F P
0 g
s
.46961 .63375 m .47499 .59268 L .41072 .57626 L p .771 .622 .694 r
F P
0 g
s
.44288 .5004 m .42567 .53745 L .48157 .55209 L p .754 .66 .758 r
F P
0 g
s
.48157 .55209 m .48917 .51282 L .44288 .5004 L p .754 .66 .758 r
F P
0 g
s
.41072 .57626 m .39848 .61604 L .46961 .63375 L p .771 .622 .694 r
F P
0 g
s
.46564 .67432 m .46961 .63375 L .39848 .61604 L p .778 .598 .657 r
F P
0 g
s
.46961 .63375 m .46564 .67432 L .5468 .67806 L p .72 .546 .654 r
F P
0 g
s
.49759 .47553 m .48917 .51282 L .53887 .51534 L p .711 .646 .782 r
F P
0 g
s
.53887 .51534 m .53603 .47752 L .49759 .47553 L p .711 .646 .782 r
F P
0 g
s
.53603 .47752 m .53887 .51534 L .58742 .50778 L p .677 .62 .784 r
F P
0 g
s
.59996 .54615 m .58742 .50778 L .53887 .51534 L p .674 .591 .754 r
F P
0 g
s
.59996 .54615 m .61084 .58602 L .67071 .56337 L p .617 .529 .732 r
F P
0 g
s
.61084 .58602 m .61973 .62657 L .68613 .60212 L p .604 .491 .698 r
F P
0 g
s
.68613 .60212 m .67071 .56337 L .61084 .58602 L p .604 .491 .698 r
F P
0 g
s
.54761 .7171 m .5468 .67806 L .46564 .67432 L p .718 .514 .613 r
F P
0 g
s
.5468 .67806 m .54761 .7171 L .6303 .70573 L p .65 .46 .613 r
F P
0 g
s
.6303 .70573 m .62632 .66684 L .5468 .67806 L p .65 .46 .613 r
F P
0 g
s
.58742 .50778 m .59996 .54615 L .6519 .52598 L p .629 .565 .763 r
F P
0 g
s
.67071 .56337 m .6519 .52598 L .59996 .54615 L p .617 .529 .732 r
F P
0 g
s
.46191 .46573 m .44288 .5004 L .48917 .51282 L p .742 .677 .788 r
F P
0 g
s
.48917 .51282 m .49759 .47553 L .46191 .46573 L p .742 .677 .788 r
F P
0 g
s
.61973 .62657 m .62632 .66684 L .69757 .64128 L p .588 .449 .66 r
F P
0 g
s
.69757 .64128 m .68613 .60212 L .61973 .62657 L p .588 .449 .66 r
F P
0 g
s
.39848 .61604 m .38941 .65584 L .46564 .67432 L p .778 .598 .657 r
F P
0 g
s
.46323 .71332 m .46564 .67432 L .38941 .65584 L p .782 .57 .614 r
F P
0 g
s
.46564 .67432 m .46323 .71332 L .54761 .7171 L p .718 .514 .613 r
F P
0 g
s
.58742 .50778 m .57353 .47155 L .53603 .47752 L p .677 .62 .784 r
F P
0 g
s
.57353 .47155 m .58742 .50778 L .63031 .49069 L p .639 .599 .793 r
F P
0 g
s
.6519 .52598 m .63031 .49069 L .58742 .50778 L p .629 .565 .763 r
F P
0 g
s
.40443 .47904 m .37892 .51216 L .42567 .53745 L p .79 .706 .771 r
F P
0 g
s
.42567 .53745 m .44288 .5004 L .40443 .47904 L p .79 .706 .771 r
F P
0 g
s
.41072 .57626 m .42567 .53745 L .37892 .51216 L p .808 .694 .74 r
F P
0 g
s
.37892 .51216 m .35664 .54781 L .41072 .57626 L p .808 .694 .74 r
F P
0 g
s
.39848 .61604 m .41072 .57626 L .35664 .54781 L p .823 .679 .704 r
F P
0 g
s
.50668 .44073 m .49759 .47553 L .53603 .47752 L p .704 .669 .812 r
F P
0 g
s
.53603 .47752 m .53296 .44212 L .50668 .44073 L p .704 .669 .812 r
F P
0 g
s
.53296 .44212 m .53603 .47752 L .57353 .47155 L p .678 .649 .814 r
F P
0 g
s
.62632 .66684 m .6303 .70573 L .70451 .67978 L p .569 .401 .614 r
F P
0 g
s
.70451 .67978 m .69757 .64128 L .62632 .66684 L p .569 .401 .614 r
F P
0 g
s
.48237 .43392 m .46191 .46573 L .49759 .47553 L p .728 .693 .817 r
F P
0 g
s
.49759 .47553 m .50668 .44073 L .48237 .43392 L p .728 .693 .817 r
F P
0 g
s
.43249 .44896 m .40443 .47904 L .44288 .5004 L p .771 .715 .8 r
F P
0 g
s
.44288 .5004 m .46191 .46573 L .43249 .44896 L p .771 .715 .8 r
F P
0 g
s
.54785 .75331 m .54761 .7171 L .46323 .71332 L p .713 .476 .564 r
F P
0 g
s
.54761 .7171 m .54785 .75331 L .63148 .74207 L p .637 .415 .563 r
F P
0 g
s
.63148 .74207 m .6303 .70573 L .54761 .7171 L p .637 .415 .563 r
F P
0 g
s
.35664 .54781 m .33834 .58528 L .39848 .61604 L p .823 .679 .704 r
F P
0 g
s
.38941 .65584 m .39848 .61604 L .33834 .58528 L p .837 .661 .663 r
F P
0 g
s
.57353 .47155 m .55857 .43796 L .53296 .44212 L p .678 .649 .814 r
F P
0 g
s
.55857 .43796 m .57353 .47155 L .60649 .4581 L p .649 .634 .822 r
F P
0 g
s
.63031 .49069 m .60649 .4581 L .57353 .47155 L p .639 .599 .793 r
F P
0 g
s
.38941 .65584 m .38391 .69456 L .46323 .71332 L p .782 .57 .614 r
F P
0 g
s
.46252 .74957 m .46323 .71332 L .38391 .69456 L p .784 .536 .561 r
F P
0 g
s
.46323 .71332 m .46252 .74957 L .54785 .75331 L p .713 .476 .564 r
F P
0 g
s
.63031 .49069 m .6519 .52598 L .6922 .49602 L p .576 .543 .781 r
F P
0 g
s
.6519 .52598 m .67071 .56337 L .71754 .52959 L p .553 .499 .749 r
F P
0 g
s
.71754 .52959 m .6922 .49602 L .6519 .52598 L p .553 .499 .749 r
F P
0 g
s
.67071 .56337 m .68613 .60212 L .73841 .56551 L p .526 .449 .712 r
F P
0 g
s
.73841 .56551 m .71754 .52959 L .67071 .56337 L p .526 .449 .712 r
F P
0 g
s
.46248 .42231 m .43249 .44896 L .46191 .46573 L p .749 .723 .828 r
F P
0 g
s
.46191 .46573 m .48237 .43392 L .46248 .42231 L p .749 .723 .828 r
F P
0 g
s
.60649 .4581 m .63031 .49069 L .66327 .46546 L p .598 .585 .81 r
F P
0 g
s
.6922 .49602 m .66327 .46546 L .63031 .49069 L p .576 .543 .781 r
F P
0 g
s
.33834 .58528 m .32473 .62365 L .38941 .65584 L p .837 .661 .663 r
F P
0 g
s
.38391 .69456 m .38941 .65584 L .32473 .62365 L p .849 .636 .614 r
F P
0 g
s
.6303 .70573 m .63148 .74207 L .70656 .71645 L p .544 .342 .557 r
F P
0 g
s
.70656 .71645 m .70451 .67978 L .6303 .70573 L p .544 .342 .557 r
F P
0 g
s
.5163 .40888 m .50668 .44073 L .53296 .44212 L p .694 .692 .844 r
F P
0 g
s
.53296 .44212 m .52971 .4096 L .5163 .40888 L p .694 .692 .844 r
F P
0 g
s
.52971 .4096 m .53296 .44212 L .55857 .43796 L p .677 .68 .845 r
F P
0 g
s
.68613 .60212 m .69757 .64128 L .75396 .60293 L p .495 .393 .668 r
F P
0 g
s
.75396 .60293 m .73841 .56551 L .68613 .60212 L p .495 .393 .668 r
F P
0 g
s
.50393 .40534 m .48237 .43392 L .50668 .44073 L p .71 .709 .847 r
F P
0 g
s
.50668 .44073 m .5163 .40888 L .50393 .40534 L p .71 .709 .847 r
F P
0 g
s
.60649 .4581 m .58095 .42863 L .55857 .43796 L p .649 .634 .822 r
F P
0 g
s
.58095 .42863 m .60649 .4581 L .63156 .43835 L p .619 .626 .836 r
F P
0 g
s
.66327 .46546 m .63156 .43835 L .60649 .4581 L p .598 .585 .81 r
F P
0 g
s
.55857 .43796 m .54276 .40744 L .52971 .4096 L p .677 .68 .845 r
F P
0 g
s
.54276 .40744 m .55857 .43796 L .58095 .42863 L p .658 .671 .851 r
F P
0 g
s
.54749 .78554 m .54785 .75331 L .46252 .74957 L p .703 .426 .502 r
F P
0 g
s
.54785 .75331 m .54749 .78554 L .6297 .77474 L p .619 .357 .499 r
F P
0 g
s
.6297 .77474 m .63148 .74207 L .54785 .75331 L p .619 .357 .499 r
F P
0 g
s
.37785 .4505 m .34616 .47818 L .37892 .51216 L p .823 .761 .794 r
F P
0 g
s
.37892 .51216 m .40443 .47904 L .37785 .4505 L p .823 .761 .794 r
F P
0 g
s
.35664 .54781 m .37892 .51216 L .34616 .47818 L p .851 .759 .761 r
F P
0 g
s
.41245 .4267 m .37785 .4505 L .40443 .47904 L p .795 .76 .821 r
F P
0 g
s
.40443 .47904 m .43249 .44896 L .41245 .4267 L p .795 .76 .821 r
F P
0 g
s
.4939 .39935 m .46248 .42231 L .48237 .43392 L p .722 .728 .855 r
F P
0 g
s
.48237 .43392 m .50393 .40534 L .4939 .39935 L p .722 .728 .855 r
F P
0 g
s
.38391 .69456 m .38229 .73105 L .46252 .74957 L p .784 .536 .561 r
F P
0 g
s
.46359 .78195 m .46252 .74957 L .38229 .73105 L p .781 .489 .493 r
F P
0 g
s
.46252 .74957 m .46359 .78195 L .54749 .78554 L p .703 .426 .502 r
F P
0 g
s
.34616 .47818 m .31832 .50939 L .35664 .54781 L p .851 .759 .761 r
F P
0 g
s
.33834 .58528 m .35664 .54781 L .31832 .50939 L p .877 .753 .722 r
F P
0 g
s
.44915 .407 m .41245 .4267 L .43249 .44896 L p .764 .756 .845 r
F P
0 g
s
.43249 .44896 m .46248 .42231 L .44915 .407 L p .764 .756 .845 r
F P
0 g
s
.32473 .62365 m .31647 .66187 L .38391 .69456 L p .849 .636 .614 r
F P
0 g
s
.38229 .73105 m .38391 .69456 L .31647 .66187 L p .858 .603 .551 r
F P
0 g
s
.69757 .64128 m .70451 .67978 L .76341 .64079 L p .456 .325 .613 r
F P
0 g
s
.76341 .64079 m .75396 .60293 L .69757 .64128 L p .456 .325 .613 r
F P
0 g
s
.58095 .42863 m .55411 .40261 L .54276 .40744 L p .658 .671 .851 r
F P
0 g
s
.55411 .40261 m .58095 .42863 L .59778 .41499 L p .639 .667 .861 r
F P
0 g
s
.63156 .43835 m .59778 .41499 L .58095 .42863 L p .619 .626 .836 r
F P
0 g
s
.63148 .74207 m .6297 .77474 L .70347 .7501 L p .51 .267 .483 r
F P
0 g
s
.70347 .7501 m .70656 .71645 L .63148 .74207 L p .51 .267 .483 r
F P
0 g
s
.31832 .50939 m .29532 .54354 L .33834 .58528 L p .877 .753 .722 r
F P
0 g
s
.32473 .62365 m .33834 .58528 L .29532 .54354 L p .902 .741 .673 r
F P
0 g
s
.4873 .39152 m .44915 .407 L .46248 .42231 L p .73 .749 .867 r
F P
0 g
s
.46248 .42231 m .4939 .39935 L .4873 .39152 L p .73 .749 .867 r
F P
0 g
s
.63156 .43835 m .66327 .46546 L .68258 .43424 L p .552 .579 .835 r
F P
0 g
s
.66327 .46546 m .6922 .49602 L .71629 .45872 L p .513 .528 .809 r
F P
0 g
s
.71629 .45872 m .68258 .43424 L .66327 .46546 L p .513 .528 .809 r
F P
0 g
s
.52971 .4096 m .52632 .38036 L .5163 .40888 L closepath p .68 .718 .878 r
F P
0 g
s
.54276 .40744 m .52632 .38036 L .52971 .4096 L closepath p .674 .713 .878 r
F P
0 g
s
.5163 .40888 m .52632 .38036 L .50393 .40534 L closepath p .686 .724 .879 r
F P
0 g
s
.59778 .41499 m .63156 .43835 L .64591 .41409 L p .588 .625 .857 r
F P
0 g
s
.68258 .43424 m .64591 .41409 L .63156 .43835 L p .552 .579 .835 r
F P
0 g
s
.55411 .40261 m .52632 .38036 L .54276 .40744 L closepath p .667 .71 .88 r
F P
0 g
s
.6922 .49602 m .71754 .52959 L .74603 .48728 L p .468 .47 .776 r
F P
0 g
s
.74603 .48728 m .71629 .45872 L .6922 .49602 L p .468 .47 .776 r
F P
0 g
s
.50393 .40534 m .52632 .38036 L .4939 .39935 L closepath p .69 .731 .882 r
F P
0 g
s
.59778 .41499 m .56253 .3956 L .55411 .40261 L p .639 .667 .861 r
F P
0 g
s
.56253 .3956 m .59778 .41499 L .60718 .39838 L p .621 .669 .874 r
F P
0 g
s
.64591 .41409 m .60718 .39838 L .59778 .41499 L p .588 .625 .857 r
F P
0 g
s
.56253 .3956 m .52632 .38036 L .55411 .40261 L closepath p .66 .709 .884 r
F P
0 g
s
.70451 .67978 m .70656 .71645 L .7662 .67793 L p .407 .24 .54 r
F P
0 g
s
.7662 .67793 m .76341 .64079 L .70451 .67978 L p .407 .24 .54 r
F P
0 g
s
.71754 .52959 m .73841 .56551 L .77067 .51944 L p .416 .401 .734 r
F P
0 g
s
.77067 .51944 m .74603 .48728 L .71754 .52959 L p .416 .401 .734 r
F P
0 g
s
.54653 .81276 m .54749 .78554 L .46359 .78195 L p .685 .359 .417 r
F P
0 g
s
.54749 .78554 m .54653 .81276 L .62497 .80265 L p .589 .279 .411 r
F P
0 g
s
.62497 .80265 m .6297 .77474 L .54749 .78554 L p .589 .279 .411 r
F P
0 g
s
.4939 .39935 m .52632 .38036 L .4873 .39152 L closepath p .692 .738 .887 r
F P
0 g
s
.31647 .66187 m .31403 .69876 L .38229 .73105 L p .858 .603 .551 r
F P
0 g
s
.38474 .76414 m .38229 .73105 L .31403 .69876 L p .862 .554 .466 r
F P
0 g
s
.38229 .73105 m .38474 .76414 L .46359 .78195 L p .781 .489 .493 r
F P
0 g
s
.29532 .54354 m .27815 .57985 L .32473 .62365 L p .902 .741 .673 r
F P
0 g
s
.31647 .66187 m .32473 .62365 L .27815 .57985 L p .924 .721 .609 r
F P
0 g
s
.44395 .38952 m .40421 .40107 L .41245 .4267 L p .771 .791 .869 r
F P
0 g
s
.41245 .4267 m .44915 .407 L .44395 .38952 L p .771 .791 .869 r
F P
0 g
s
.37785 .4505 m .41245 .4267 L .40421 .40107 L p .81 .811 .851 r
F P
0 g
s
.48486 .38264 m .44395 .38952 L .44915 .407 L p .732 .769 .883 r
F P
0 g
s
.44915 .407 m .4873 .39152 L .48486 .38264 L p .732 .769 .883 r
F P
0 g
s
.46645 .8094 m .46359 .78195 L .38474 .76414 L p .769 .423 .399 r
F P
0 g
s
.46359 .78195 m .46645 .8094 L .54653 .81276 L p .685 .359 .417 r
F P
0 g
s
.56711 .38713 m .52632 .38036 L .56253 .3956 L closepath p .654 .71 .889 r
F P
0 g
s
.60718 .39838 m .56711 .38713 L .56253 .3956 L p .621 .669 .874 r
F P
0 g
s
.40421 .40107 m .36643 .41737 L .37785 .4505 L p .81 .811 .851 r
F P
0 g
s
.34616 .47818 m .37785 .4505 L .36643 .41737 L p .848 .828 .827 r
F P
0 g
s
.4873 .39152 m .52632 .38036 L .48486 .38264 L closepath p .692 .745 .892 r
F P
0 g
s
.73841 .56551 m .75396 .60293 L .7891 .55448 L p .351 .315 .678 r
F P
0 g
s
.7891 .55448 m .77067 .51944 L .73841 .56551 L p .351 .315 .678 r
F P
0 g
s
.36643 .41737 m .33154 .43845 L .34616 .47818 L p .848 .828 .827 r
F P
0 g
s
.31832 .50939 m .34616 .47818 L .33154 .43845 L p .887 .841 .794 r
F P
0 g
s
.56711 .38713 m .60718 .39838 L .60795 .38049 L p .605 .677 .891 r
F P
0 g
s
.60718 .39838 m .64591 .41409 L .64762 .38774 L p .556 .634 .883 r
F P
0 g
s
.64762 .38774 m .60795 .38049 L .60718 .39838 L p .556 .634 .883 r
F P
0 g
s
.56731 .37809 m .52632 .38036 L .56711 .38713 L closepath p .649 .714 .895 r
F P
0 g
s
.60795 .38049 m .56731 .37809 L .56711 .38713 L p .605 .677 .891 r
F P
0 g
s
.6297 .77474 m .62497 .80265 L .69522 .7796 L p .459 .164 .377 r
F P
0 g
s
.69522 .7796 m .70347 .7501 L .6297 .77474 L p .459 .164 .377 r
F P
0 g
s
.56303 .36947 m .52632 .38036 L .56731 .37809 L closepath p .647 .72 .901 r
F P
0 g
s
.55469 .36221 m .52632 .38036 L .56303 .36947 L closepath p .647 .727 .907 r
F P
0 g
s
.54318 .35714 m .52632 .38036 L .55469 .36221 L closepath p .649 .734 .911 r
F P
0 g
s
.52977 .35487 m .52632 .38036 L .54318 .35714 L closepath p .654 .742 .914 r
F P
0 g
s
.51598 .35564 m .52632 .38036 L .52977 .35487 L closepath p .661 .748 .914 r
F P
0 g
s
.50334 .35937 m .52632 .38036 L .51598 .35564 L closepath p .669 .753 .913 r
F P
0 g
s
.49329 .36563 m .52632 .38036 L .50334 .35937 L closepath p .677 .754 .909 r
F P
0 g
s
.48691 .37369 m .52632 .38036 L .49329 .36563 L closepath p .684 .754 .904 r
F P
0 g
s
.48486 .38264 m .52632 .38036 L .48691 .37369 L closepath p .689 .75 .898 r
F P
0 g
s
.64591 .41409 m .68258 .43424 L .68551 .40003 L p .5 .583 .87 r
F P
0 g
s
.68551 .40003 m .64762 .38774 L .64591 .41409 L p .5 .583 .87 r
F P
0 g
s
.44395 .38952 m .48486 .38264 L .48691 .37369 L p .727 .788 .901 r
F P
0 g
s
.27815 .57985 m .26769 .6173 L .31647 .66187 L p .924 .721 .609 r
F P
0 g
s
.31403 .69876 m .31647 .66187 L .26769 .6173 L p .942 .686 .521 r
F P
0 g
s
.70656 .71645 m .70347 .7501 L .76199 .71308 L p .338 .127 .438 r
F P
0 g
s
.76199 .71308 m .7662 .67793 L .70656 .71645 L p .338 .127 .438 r
F P
0 g
s
.33154 .43845 m .30066 .46417 L .31832 .50939 L p .887 .841 .794 r
F P
0 g
s
.29532 .54354 m .31832 .50939 L .30066 .46417 L p .927 .85 .747 r
F P
0 g
s
.48691 .37369 m .44765 .3717 L .44395 .38952 L p .727 .788 .901 r
F P
0 g
s
.40421 .40107 m .44395 .38952 L .44765 .3717 L p .766 .825 .899 r
F P
0 g
s
.56731 .37809 m .60795 .38049 L .59977 .36325 L p .594 .691 .91 r
F P
0 g
s
.59977 .36325 m .56303 .36947 L .56731 .37809 L p .594 .691 .91 r
F P
0 g
s
.68258 .43424 m .71629 .45872 L .72064 .41752 L p .432 .52 .848 r
F P
0 g
s
.72064 .41752 m .68551 .40003 L .68258 .43424 L p .432 .52 .848 r
F P
0 g
s
.75396 .60293 m .76341 .64079 L .80036 .59144 L p .268 .206 .6 r
F P
0 g
s
.80036 .59144 m .7891 .55448 L .75396 .60293 L p .268 .206 .6 r
F P
0 g
s
.44765 .3717 m .48691 .37369 L .49329 .36563 L p .713 .801 .919 r
F P
0 g
s
.31403 .69876 m .31771 .73309 L .38474 .76414 L p .862 .554 .466 r
F P
0 g
s
.39127 .79273 m .38474 .76414 L .31771 .73309 L p .852 .479 .343 r
F P
0 g
s
.38474 .76414 m .39127 .79273 L .46645 .8094 L p .769 .423 .399 r
F P
0 g
s
.44765 .3717 m .40916 .3747 L .40421 .40107 L p .766 .825 .899 r
F P
0 g
s
.36643 .41737 m .40421 .40107 L .40916 .3747 L p .807 .864 .89 r
F P
0 g
s
.54498 .8341 m .54653 .81276 L .46645 .8094 L p .649 .258 .291 r
F P
0 g
s
.54653 .81276 m .54498 .8341 L .61735 .8249 L p .538 .165 .28 r
F P
0 g
s
.61735 .8249 m .62497 .80265 L .54653 .81276 L p .538 .165 .28 r
F P
0 g
s
.56303 .36947 m .59977 .36325 L .58331 .34862 L p .589 .712 .928 r
F P
0 g
s
.58331 .34862 m .55469 .36221 L .56303 .36947 L p .589 .712 .928 r
F P
0 g
s
.60795 .38049 m .64762 .38774 L .63595 .3621 L p .528 .653 .915 r
F P
0 g
s
.63595 .3621 m .59977 .36325 L .60795 .38049 L p .528 .653 .915 r
F P
0 g
s
.71629 .45872 m .74603 .48728 L .75187 .44022 L p .347 .44 .814 r
F P
0 g
s
.75187 .44022 m .72064 .41752 L .71629 .45872 L p .347 .44 .814 r
F P
0 g
s
.47106 .83104 m .46645 .8094 L .39127 .79273 L p .738 .321 .258 r
F P
0 g
s
.46645 .8094 m .47106 .83104 L .54498 .8341 L p .649 .258 .291 r
F P
0 g
s
.46011 .35553 m .49329 .36563 L .50334 .35937 L p .69 .805 .936 r
F P
0 g
s
.49329 .36563 m .46011 .35553 L .44765 .3717 L p .713 .801 .919 r
F P
0 g
s
.30066 .46417 m .27498 .49417 L .29532 .54354 L p .927 .85 .747 r
F P
0 g
s
.27815 .57985 m .29532 .54354 L .27498 .49417 L p .964 .849 .679 r
F P
0 g
s
.55469 .36221 m .58331 .34862 L .56028 .33835 L p .594 .736 .943 r
F P
0 g
s
.56028 .33835 m .54318 .35714 L .55469 .36221 L p .594 .736 .943 r
F P
0 g
s
.40916 .3747 m .37223 .383 L .36643 .41737 L p .807 .864 .89 r
F P
0 g
s
.33154 .43845 m .36643 .41737 L .37223 .383 L p .851 .902 .871 r
F P
0 g
s
.40916 .3747 m .44765 .3717 L .46011 .35553 L p .743 .852 .931 r
F P
0 g
s
.48011 .34287 m .50334 .35937 L .51598 .35564 L p .662 .8 .949 r
F P
0 g
s
.50334 .35937 m .48011 .34287 L .46011 .35553 L p .69 .805 .936 r
F P
0 g
s
.26769 .6173 m .26461 .65471 L .31403 .69876 L p .942 .686 .521 r
F P
0 g
s
.31771 .73309 m .31403 .69876 L .26461 .65471 L p .945 .624 .392 r
F P
0 g
s
.64762 .38774 m .68551 .40003 L .67081 .36647 L p .443 .6 .912 r
F P
0 g
s
.67081 .36647 m .63595 .3621 L .64762 .38774 L p .443 .6 .912 r
F P
0 g
s
.54318 .35714 m .56028 .33835 L .53329 .33371 L p .609 .762 .952 r
F P
0 g
s
.53329 .33371 m .52977 .35487 L .54318 .35714 L p .609 .762 .952 r
F P
0 g
s
.62497 .80265 m .61735 .8249 L .68199 .80399 L p .375 .014 .218 r
F P
0 g
s
.68199 .80399 m .69522 .7796 L .62497 .80265 L p .375 .014 .218 r
F P
0 g
s
.76341 .64079 m .7662 .67793 L .80368 .62913 L p .156 .059 .485 r
F P
0 g
s
.80368 .62913 m .80036 .59144 L .76341 .64079 L p .156 .059 .485 r
F P
0 g
s
.50547 .33529 m .51598 .35564 L .52977 .35487 L p .633 .785 .954 r
F P
0 g
s
.51598 .35564 m .50547 .33529 L .48011 .34287 L p .662 .8 .949 r
F P
0 g
s
.70347 .7501 m .69522 .7796 L .75076 .74504 L p .237 0 .288 r
F P
0 g
s
.75076 .74504 m .76199 .71308 L .70347 .7501 L p .237 0 .288 r
F P
0 g
s
.74603 .48728 m .77067 .51944 L .77792 .46791 L p .237 .332 .759 r
F P
0 g
s
.77792 .46791 m .75187 .44022 L .74603 .48728 L p .237 .332 .759 r
F P
0 g
s
.52977 .35487 m .53329 .33371 L .50547 .33529 L p .633 .785 .954 r
F P
0 g
s
.59977 .36325 m .63595 .3621 L .61171 .34017 L p .509 .685 .946 r
F P
0 g
s
.61171 .34017 m .58331 .34862 L .59977 .36325 L p .509 .685 .946 r
F P
0 g
s
.27498 .49417 m .25572 .52783 L .27815 .57985 L p .964 .849 .679 r
F P
0 g
s
.26769 .6173 m .27815 .57985 L .25572 .52783 L p .993 .829 .576 r
F P
0 g
s
.37223 .383 m .33784 .39689 L .33154 .43845 L p .851 .902 .871 r
F P
0 g
s
.30066 .46417 m .33154 .43845 L .33784 .39689 L p .895 .938 .833 r
F P
0 g
s
.42729 .35054 m .46011 .35553 L .48011 .34287 L p .699 .863 .96 r
F P
0 g
s
.46011 .35553 m .42729 .35054 L .40916 .3747 L p .743 .852 .931 r
F P
0 g
s
.37223 .383 m .40916 .3747 L .42729 .35054 L p .774 .908 .933 r
F P
0 g
s
.31771 .73309 m .32753 .76372 L .39127 .79273 L p .852 .479 .343 r
F P
0 g
s
.40176 .81589 m .39127 .79273 L .32753 .76372 L p .808 .353 .155 r
F P
0 g
s
.39127 .79273 m .40176 .81589 L .47106 .83104 L p .738 .321 .258 r
F P
0 g
s
.68551 .40003 m .72064 .41752 L .70342 .37678 L p .327 .522 .894 r
F P
0 g
s
.70342 .37678 m .67081 .36647 L .68551 .40003 L p .327 .522 .894 r
F P
0 g
s
.77067 .51944 m .7891 .55448 L .79752 .50006 L p .088 .183 .669 r
F P
0 g
s
.79752 .50006 m .77792 .46791 L .77067 .51944 L p .088 .183 .669 r
F P
0 g
s
.58331 .34862 m .61171 .34017 L .57735 .32468 L p .506 .726 .972 r
F P
0 g
s
.57735 .32468 m .56028 .33835 L .58331 .34862 L p .506 .726 .972 r
F P
0 g
s
.54288 .84888 m .54498 .8341 L .47106 .83104 L p .572 .097 .09 r
F P
0 g
s
.54498 .8341 m .54288 .84888 L .60705 .84081 L p .441 0 .071 r
F P
0 g
s
.60705 .84081 m .61735 .8249 L .54498 .8341 L p .441 0 .071 r
F P
0 g
s
.26461 .65471 m .26927 .69078 L .31771 .73309 L p .945 .624 .392 r
F P
0 g
s
.32753 .76372 m .31771 .73309 L .26927 .69078 L p .913 .511 .196 r
F P
0 g
s
.7662 .67793 m .76199 .71308 L .79866 .66624 L p 0 0 .309 r
F P
0 g
s
.79866 .66624 m .80368 .62913 L .7662 .67793 L p 0 0 .309 r
F P
0 g
s
.47729 .8462 m .47106 .83104 L .40176 .81589 L p .657 .151 .032 r
F P
0 g
s
.47106 .83104 m .47729 .8462 L .54288 .84888 L p .572 .097 .09 r
F P
0 g
s
.45698 .33151 m .48011 .34287 L .50547 .33529 L p .639 .852 .981 r
F P
0 g
s
.48011 .34287 m .45698 .33151 L .42729 .35054 L p .699 .863 .96 r
F P
0 g
s
.63595 .3621 m .67081 .36647 L .63928 .33752 L p .389 .634 .952 r
F P
0 g
s
.63928 .33752 m .61171 .34017 L .63595 .3621 L p .389 .634 .952 r
F P
0 g
s
.33784 .39689 m .30715 .41653 L .30066 .46417 L p .895 .938 .833 r
F P
0 g
s
.27498 .49417 m .30066 .46417 L .30715 .41653 L p .933 .961 .761 r
F P
0 g
s
.25572 .52783 m .24394 .56423 L .26769 .6173 L p .993 .829 .576 r
F P
0 g
s
.26461 .65471 m .26769 .6173 L .24394 .56423 L p .995 .77 .413 r
F P
0 g
s
.69522 .7796 m .68199 .80399 L .73279 .77272 L p .081 0 .056 r
F P
0 g
s
.73279 .77272 m .75076 .74504 L .69522 .7796 L p .081 0 .056 r
F P
0 g
s
.56028 .33835 m .57735 .32468 L .53681 .31765 L p .528 .774 .988 r
F P
0 g
s
.53681 .31765 m .53329 .33371 L .56028 .33835 L p .528 .774 .988 r
F P
0 g
s
.42729 .35054 m .39554 .35124 L .37223 .383 L p .774 .908 .933 r
F P
0 g
s
.33784 .39689 m .37223 .383 L .39554 .35124 L p .8 .964 .913 r
F P
0 g
s
.72064 .41752 m .75187 .44022 L .73261 .39335 L p .161 .402 .846 r
F P
0 g
s
.73261 .39335 m .70342 .37678 L .72064 .41752 L p .161 .402 .846 r
F P
0 g
s
.61735 .8249 m .60705 .84081 L .66414 .82251 L p .23 0 0 r
F P
0 g
s
.66414 .82251 m .68199 .80399 L .61735 .8249 L p .23 0 0 r
F P
0 g
s
.49498 .32003 m .50547 .33529 L .53329 .33371 L p .576 .82 .991 r
F P
0 g
s
.50547 .33529 m .49498 .32003 L .45698 .33151 L p .639 .852 .981 r
F P
0 g
s
.53329 .33371 m .53681 .31765 L .49498 .32003 L p .576 .82 .991 r
F P
0 g
s
.7891 .55448 m .80036 .59144 L .80952 .53585 L p 0 0 .517 r
F P
0 g
s
.80952 .53585 m .79752 .50006 L .7891 .55448 L p 0 0 .517 r
F P
0 g
s
.39554 .35124 m .42729 .35054 L .45698 .33151 L p .695 .924 .968 r
F P
0 g
s
.32753 .76372 m .34326 .7896 L .40176 .81589 L p .808 .353 .155 r
F P
0 g
s
.41594 .83292 m .40176 .81589 L .34326 .7896 L p .684 .139 0 r
F P
0 g
s
.40176 .81589 m .41594 .83292 L .47729 .8462 L p .657 .151 .032 r
F P
0 g
s
.30715 .41653 m .28147 .44184 L .27498 .49417 L p .933 .961 .761 r
F P
0 g
s
.25572 .52783 m .27498 .49417 L .28147 .44184 L p .943 .948 .626 r
F P
0 g
s
.61171 .34017 m .63928 .33752 L .59401 .31694 L p .356 .685 .98 r
F P
0 g
s
.59401 .31694 m .57735 .32468 L .61171 .34017 L p .356 .685 .98 r
F P
0 g
s
.76199 .71308 m .75076 .74504 L .78531 .70142 L p 0 0 .045 r
F P
0 g
s
.78531 .70142 m .79866 .66624 L .76199 .71308 L p 0 0 .045 r
F P
0 g
s
.67081 .36647 m .70342 .37678 L .66525 .34137 L p .199 .535 .925 r
F P
0 g
s
.66525 .34137 m .63928 .33752 L .67081 .36647 L p .199 .535 .925 r
F P
0 g
s
.26927 .69078 m .28169 .72426 L .32753 .76372 L p .913 .511 .196 r
F P
0 g
s
.34326 .7896 m .32753 .76372 L .28169 .72426 L p .795 .311 0 r
F P
0 g
s
.24394 .56423 m .24046 .60221 L .26461 .65471 L p .995 .77 .413 r
F P
0 g
s
.26927 .69078 m .26461 .65471 L .24046 .60221 L p .93 .634 .163 r
F P
0 g
s
.75187 .44022 m .77792 .46791 L .75713 .41627 L p 0 .212 .737 r
F P
0 g
s
.75713 .41627 m .73261 .39335 L .75187 .44022 L p 0 .212 .737 r
F P
0 g
s
.39554 .35124 m .36574 .35818 L .33784 .39689 L p .8 .964 .913 r
F P
0 g
s
.30715 .41653 m .33784 .39689 L .36574 .35818 L p .8 .999 .842 r
F P
0 g
s
.43445 .32603 m .45698 .33151 L .49498 .32003 L p .575 .895 .986 r
F P
0 g
s
.45698 .33151 m .43445 .32603 L .39554 .35124 L p .695 .924 .968 r
F P
0 g
s
.54028 .85669 m .54288 .84888 L .47729 .8462 L p .398 0 0 r
F P
0 g
s
.54288 .84888 m .54028 .85669 L .59433 .84993 L p .247 0 0 r
F P
0 g
s
.59433 .84993 m .60705 .84081 L .54288 .84888 L p .247 0 0 r
F P
0 g
s
.80036 .59144 m .80368 .62913 L .81307 .57412 L p 0 0 .272 r
F P
0 g
s
.81307 .57412 m .80952 .53585 L .80036 .59144 L p 0 0 .272 r
F P
0 g
s
.48498 .85444 m .47729 .8462 L .41594 .83292 L p .462 0 0 r
F P
0 g
s
.47729 .8462 m .48498 .85444 L .54028 .85669 L p .398 0 0 r
F P
0 g
s
.68199 .80399 m .66414 .82251 L .70867 .79525 L p 0 0 0 r
F P
0 g
s
.70867 .79525 m .73279 .77272 L .68199 .80399 L p 0 0 0 r
F P
0 g
s
.57735 .32468 m .59401 .31694 L .54025 .30756 L p .371 .751 .989 r
F P
0 g
s
.54025 .30756 m .53681 .31765 L .57735 .32468 L p .371 .751 .989 r
F P
0 g
s
.36574 .35818 m .39554 .35124 L .43445 .32603 L p .648 .961 .922 r
F P
0 g
s
.28147 .44184 m .2621 .47244 L .25572 .52783 L p .943 .948 .626 r
F P
0 g
s
.24394 .56423 m .25572 .52783 L .2621 .47244 L p .876 .847 .387 r
F P
0 g
s
.48472 .31075 m .49498 .32003 L .53681 .31765 L p .451 .828 .99 r
F P
0 g
s
.49498 .32003 m .48472 .31075 L .43445 .32603 L p .575 .895 .986 r
F P
0 g
s
.60705 .84081 m .59433 .84993 L .6422 .83464 L p 0 0 0 r
F P
0 g
s
.6422 .83464 m .66414 .82251 L .60705 .84081 L p 0 0 0 r
F P
0 g
s
.53681 .31765 m .54025 .30756 L .48472 .31075 L p .451 .828 .99 r
F P
0 g
s
.70342 .37678 m .73261 .39335 L .68866 .35234 L p 0 .342 .805 r
F P
0 g
s
.68866 .35234 m .66525 .34137 L .70342 .37678 L p 0 .342 .805 r
F P
0 g
s
.77792 .46791 m .79752 .50006 L .77567 .44528 L p 0 0 .514 r
F P
0 g
s
.77567 .44528 m .75713 .41627 L .77792 .46791 L p 0 0 .514 r
F P
0 g
s
.75076 .74504 m .73279 .77272 L .76403 .73343 L p 0 0 0 r
F P
0 g
s
.76403 .73343 m .78531 .70142 L .75076 .74504 L p 0 0 0 r
F P
0 g
s
.24046 .60221 m .24571 .64042 L .26927 .69078 L p .93 .634 .163 r
F P
0 g
s
.28169 .72426 m .26927 .69078 L .24571 .64042 L p .74 .388 0 r
F P
0 g
s
.36574 .35818 m .33897 .37184 L .30715 .41653 L p .8 .999 .842 r
F P
0 g
s
.28147 .44184 m .30715 .41653 L .33897 .37184 L p .726 .953 .659 r
F P
0 g
s
.63928 .33752 m .66525 .34137 L .60978 .31605 L p .088 .558 .906 r
F P
0 g
s
.60978 .31605 m .59401 .31694 L .63928 .33752 L p .088 .558 .906 r
F P
0 g
s
.34326 .7896 m .36443 .80995 L .41594 .83292 L p .684 .139 0 r
F P
0 g
s
.4334 .84333 m .41594 .83292 L .36443 .80995 L p .408 0 0 r
F P
0 g
s
.41594 .83292 m .4334 .84333 L .48498 .85444 L p .462 0 0 r
F P
0 g
s
.28169 .72426 m .30152 .75398 L .34326 .7896 L p .795 .311 0 r
F P
0 g
s
.36443 .80995 m .34326 .7896 L .30152 .75398 L p .535 .01 0 r
F P
0 g
s
.80368 .62913 m .79866 .66624 L .80771 .6135 L p 0 0 0 r
F P
0 g
s
.80771 .6135 m .81307 .57412 L .80368 .62913 L p 0 0 0 r
F P
0 g
s
.41317 .32724 m .43445 .32603 L .48472 .31075 L p .406 .858 .879 r
F P
0 g
s
.43445 .32603 m .41317 .32724 L .36574 .35818 L p .648 .961 .922 r
F P
0 g
s
.2621 .47244 m .25021 .50758 L .24394 .56423 L p .876 .847 .387 r
F P
0 g
s
.24046 .60221 m .24394 .56423 L .25021 .50758 L p 0 0 0 r
F P
0 g
s
.66414 .82251 m .6422 .83464 L .67918 .81198 L p .404 .826 .652 r
F P
0 g
s
.67918 .81198 m .70867 .79525 L .66414 .82251 L p .404 .826 .652 r
F P
0 g
s
.33897 .37184 m .36574 .35818 L .41317 .32724 L p .492 .888 .73 r
F P
0 g
s
.53726 .85731 m .54028 .85669 L .48498 .85444 L p .069 0 0 r
F P
0 g
s
.54028 .85669 m .53726 .85731 L .57954 .85202 L p 0 0 0 r
F P
0 g
s
.57954 .85202 m .59433 .84993 L .54028 .85669 L p 0 0 0 r
F P
0 g
s
.79752 .50006 m .80952 .53585 L .78707 .47974 L p .73 .402 0 r
F P
0 g
s
.78707 .47974 m .77567 .44528 L .79752 .50006 L p .73 .402 0 r
F P
0 g
s
.48498 .85444 m .49395 .85555 L .53726 .85731 L p .069 0 0 r
F P
0 g
s
.49395 .85555 m .48498 .85444 L .4334 .84333 L p 0 .479 .731 r
F P
0 g
s
.59401 .31694 m .60978 .31605 L .54351 .30447 L p .069 .609 .853 r
F P
0 g
s
.54351 .30447 m .54025 .30756 L .59401 .31694 L p .069 .609 .853 r
F P
0 g
s
.24571 .64042 m .25969 .67744 L .28169 .72426 L p .74 .388 0 r
F P
0 g
s
.30152 .75398 m .28169 .72426 L .25969 .67744 L p 0 0 .507 r
F P
0 g
s
.73261 .39335 m .75713 .41627 L .70844 .37084 L p .484 0 0 r
F P
0 g
s
.70844 .37084 m .68866 .35234 L .73261 .39335 L p .484 0 0 r
F P
0 g
s
.73279 .77272 m .70867 .79525 L .7356 .76118 L p .66 .924 .629 r
F P
0 g
s
.7356 .76118 m .76403 .73343 L .73279 .77272 L p .66 .924 .629 r
F P
0 g
s
.33897 .37184 m .31641 .39247 L .28147 .44184 L p .726 .953 .659 r
F P
0 g
s
.2621 .47244 m .28147 .44184 L .31641 .39247 L p 0 0 0 r
F P
0 g
s
.59433 .84993 m .57954 .85202 L .61679 .8401 L p .313 .802 .786 r
F P
0 g
s
.61679 .8401 m .6422 .83464 L .59433 .84993 L p .313 .802 .786 r
F P
0 g
s
.47499 .3084 m .48472 .31075 L .54025 .30756 L p .183 .713 .837 r
F P
0 g
s
.48472 .31075 m .47499 .3084 L .41317 .32724 L p .406 .858 .879 r
F P
0 g
s
.79866 .66624 m .78531 .70142 L .79347 .65247 L p .851 .856 .4 r
F P
0 g
s
.79347 .65247 m .80771 .6135 L .79866 .66624 L p .851 .856 .4 r
F P
0 g
s
.54025 .30756 m .54351 .30447 L .47499 .3084 L p .183 .713 .837 r
F P
0 g
s
.30152 .75398 m .32808 .77897 L .36443 .80995 L p .535 .01 0 r
F P
0 g
s
.36443 .80995 m .39039 .82418 L .4334 .84333 L p .408 0 0 r
F P
0 g
s
.39039 .82418 m .36443 .80995 L .32808 .77897 L p 0 .306 .762 r
F P
0 g
s
.66525 .34137 m .68866 .35234 L .62406 .32285 L p .307 0 0 r
F P
0 g
s
.62406 .32285 m .60978 .31605 L .66525 .34137 L p .307 0 0 r
F P
0 g
s
.25021 .50758 m .2467 .54613 L .24046 .60221 L p 0 0 0 r
F P
0 g
s
.24571 .64042 m .24046 .60221 L .2467 .54613 L p 0 0 .294 r
F P
0 g
s
.45368 .84687 m .4334 .84333 L .39039 .82418 L p 0 .495 .843 r
F P
0 g
s
.4334 .84333 m .45368 .84687 L .49395 .85555 L p 0 .479 .731 r
F P
0 g
s
.80952 .53585 m .81307 .57412 L .79045 .51855 L p .933 .658 .183 r
F P
0 g
s
.79045 .51855 m .78707 .47974 L .80952 .53585 L p .933 .658 .183 r
F P
0 g
s
.41317 .32724 m .39394 .33591 L .33897 .37184 L p .492 .888 .73 r
F P
0 g
s
.31641 .39247 m .33897 .37184 L .39394 .33591 L p 0 0 0 r
F P
0 g
s
.39394 .33591 m .41317 .32724 L .47499 .3084 L p 0 0 0 r
F P
0 g
s
.6422 .83464 m .61679 .8401 L .64524 .82254 L p .574 .94 .889 r
F P
0 g
s
.64524 .82254 m .67918 .81198 L .6422 .83464 L p .574 .94 .889 r
F P
0 g
s
.25969 .67744 m .28191 .7119 L .30152 .75398 L p 0 0 .507 r
F P
0 g
s
.32808 .77897 m .30152 .75398 L .28191 .7119 L p 0 .212 .737 r
F P
0 g
s
.31641 .39247 m .29931 .41995 L .2621 .47244 L p 0 0 0 r
F P
0 g
s
.25021 .50758 m .2621 .47244 L .29931 .41995 L p 0 0 .05 r
F P
0 g
s
.75713 .41627 m .77567 .44528 L .72346 .39688 L p .786 .303 0 r
F P
0 g
s
.72346 .39688 m .70844 .37084 L .75713 .41627 L p .786 .303 0 r
F P
0 g
s
.70867 .79525 m .67918 .81198 L .70109 .78386 L p .744 .993 .833 r
F P
0 g
s
.70109 .78386 m .7356 .76118 L .70867 .79525 L p .744 .993 .833 r
F P
0 g
s
.78531 .70142 m .76403 .73343 L .77088 .68954 L p .918 .96 .641 r
F P
0 g
s
.77088 .68954 m .79347 .65247 L .78531 .70142 L p .918 .96 .641 r
F P
0 g
s
.53387 .85071 m .53726 .85731 L .49395 .85555 L p .287 .754 .944 r
F P
0 g
s
.53726 .85731 m .53387 .85071 L .56303 .84705 L p .381 .823 .949 r
F P
0 g
s
.56303 .84705 m .57954 .85202 L .53726 .85731 L p .381 .823 .949 r
F P
0 g
s
.60978 .31605 m .62406 .32285 L .54647 .30933 L p .329 0 0 r
F P
0 g
s
.54647 .30933 m .54351 .30447 L .60978 .31605 L p .329 0 0 r
F P
0 g
s
.50397 .84949 m .49395 .85555 L .45368 .84687 L p .256 .705 .957 r
F P
0 g
s
.49395 .85555 m .50397 .84949 L .53387 .85071 L p .287 .754 .944 r
F P
0 g
s
.2467 .54613 m .25201 .58668 L .24571 .64042 L p 0 0 .294 r
F P
0 g
s
.25969 .67744 m .24571 .64042 L .25201 .58668 L p 0 0 .542 r
F P
0 g
s
.32808 .77897 m .36044 .79852 L .39039 .82418 L p 0 .306 .762 r
F P
0 g
s
.42037 .83198 m .39039 .82418 L .36044 .79852 L p .133 .527 .917 r
F P
0 g
s
.39039 .82418 m .42037 .83198 L .45368 .84687 L p 0 .495 .843 r
F P
0 g
s
.57954 .85202 m .56303 .84705 L .58856 .83881 L p .512 .89 .966 r
F P
0 g
s
.58856 .83881 m .61679 .8401 L .57954 .85202 L p .512 .89 .966 r
F P
0 g
s
.46616 .31393 m .47499 .3084 L .54351 .30447 L p .193 0 0 r
F P
0 g
s
.47499 .3084 m .46616 .31393 L .39394 .33591 L p 0 0 0 r
F P
0 g
s
.68866 .35234 m .70844 .37084 L .63617 .33801 L p .642 .082 0 r
F P
0 g
s
.63617 .33801 m .62406 .32285 L .68866 .35234 L p .642 .082 0 r
F P
0 g
s
.81307 .57412 m .80771 .6135 L .78535 .56028 L p .997 .794 .441 r
F P
0 g
s
.78535 .56028 m .79045 .51855 L .81307 .57412 L p .997 .794 .441 r
F P
0 g
s
.54351 .30447 m .54647 .30933 L .46616 .31393 L p .193 0 0 r
F P
0 g
s
.47627 .84348 m .45368 .84687 L .42037 .83198 L p .284 .674 .972 r
F P
0 g
s
.45368 .84687 m .47627 .84348 L .50397 .84949 L p .256 .705 .957 r
F P
0 g
s
.28191 .7119 m .3115 .7426 L .32808 .77897 L p 0 .212 .737 r
F P
0 g
s
.36044 .79852 m .32808 .77897 L .3115 .7426 L p .121 .413 .86 r
F P
0 g
s
.76403 .73343 m .7356 .76118 L .74089 .72338 L p .909 .979 .782 r
F P
0 g
s
.74089 .72338 m .77088 .68954 L .76403 .73343 L p .909 .979 .782 r
F P
0 g
s
.29931 .41995 m .28878 .45374 L .25021 .50758 L p 0 0 .05 r
F P
0 g
s
.2467 .54613 m .25021 .50758 L .28878 .45374 L p .001 0 .332 r
F P
0 g
s
.39394 .33591 m .37766 .35256 L .31641 .39247 L p 0 0 0 r
F P
0 g
s
.29931 .41995 m .31641 .39247 L .37766 .35256 L p .071 0 .037 r
F P
0 g
s
.67918 .81198 m .64524 .82254 L .66169 .80092 L p .751 .973 .926 r
F P
0 g
s
.66169 .80092 m .70109 .78386 L .67918 .81198 L p .751 .973 .926 r
F P
0 g
s
.77567 .44528 m .78707 .47974 L .73272 .43003 L p .917 .52 .205 r
F P
0 g
s
.73272 .43003 m .72346 .39688 L .77567 .44528 L p .917 .52 .205 r
F P
0 g
s
.61679 .8401 m .58856 .83881 L .60781 .82677 L p .639 .927 .973 r
F P
0 g
s
.60781 .82677 m .64524 .82254 L .61679 .8401 L p .639 .927 .973 r
F P
0 g
s
.25201 .58668 m .2661 .62764 L .25969 .67744 L p 0 0 .542 r
F P
0 g
s
.28191 .7119 m .25969 .67744 L .2661 .62764 L p .079 .206 .696 r
F P
0 g
s
.37766 .35256 m .39394 .33591 L .46616 .31393 L p .217 0 0 r
F P
0 g
s
.36044 .79852 m .39754 .81217 L .42037 .83198 L p .133 .527 .917 r
F P
0 g
s
.45356 .83323 m .42037 .83198 L .39754 .81217 L p .35 .653 .968 r
F P
0 g
s
.42037 .83198 m .45356 .83323 L .47627 .84348 L p .284 .674 .972 r
F P
0 g
s
.80771 .6135 m .79347 .65247 L .77184 .60323 L p .99 .851 .606 r
F P
0 g
s
.77184 .60323 m .78535 .56028 L .80771 .6135 L p .99 .851 .606 r
F P
0 g
s
.5302 .83696 m .53387 .85071 L .50397 .84949 L p .499 .808 1 r
F P
0 g
s
.53387 .85071 m .5302 .83696 L .54517 .83506 L p .543 .839 .999 r
F P
0 g
s
.54517 .83506 m .56303 .84705 L .53387 .85071 L p .543 .839 .999 r
F P
0 g
s
.51483 .83633 m .50397 .84949 L .47627 .84348 L p .476 .776 .997 r
F P
0 g
s
.50397 .84949 m .51483 .83633 L .5302 .83696 L p .499 .808 1 r
F P
0 g
s
.62406 .32285 m .63617 .33801 L .54899 .32292 L p .591 .064 0 r
F P
0 g
s
.54899 .32292 m .54647 .30933 L .62406 .32285 L p .591 .064 0 r
F P
0 g
s
.3115 .7426 m .34729 .76861 L .36044 .79852 L p .121 .413 .86 r
F P
0 g
s
.39754 .81217 m .36044 .79852 L .34729 .76861 L p .297 .547 .919 r
F P
0 g
s
.7356 .76118 m .70109 .78386 L .70476 .7529 L p .869 .958 .861 r
F P
0 g
s
.70476 .7529 m .74089 .72338 L .7356 .76118 L p .869 .958 .861 r
F P
0 g
s
.56303 .84705 m .54517 .83506 L .55818 .83081 L p .597 .861 .993 r
F P
0 g
s
.55818 .83081 m .58856 .83881 L .56303 .84705 L p .597 .861 .993 r
F P
0 g
s
.70844 .37084 m .72346 .39688 L .6454 .3618 L p .793 .33 .139 r
F P
0 g
s
.6454 .3618 m .63617 .33801 L .70844 .37084 L p .793 .33 .139 r
F P
0 g
s
.28878 .45374 m .28566 .49279 L .2467 .54613 L p .001 0 .332 r
F P
0 g
s
.25201 .58668 m .2467 .54613 L .28566 .49279 L p .167 .086 .513 r
F P
0 g
s
.2661 .62764 m .28842 .66736 L .28191 .7119 L p .079 .206 .696 r
F P
0 g
s
.3115 .7426 m .28191 .7119 L .28842 .66736 L p .228 .359 .789 r
F P
0 g
s
.64524 .82254 m .60781 .82677 L .61865 .81207 L p .726 .921 .959 r
F P
0 g
s
.61865 .81207 m .66169 .80092 L .64524 .82254 L p .726 .921 .959 r
F P
0 g
s
.50065 .83322 m .47627 .84348 L .45356 .83323 L p .476 .746 .988 r
F P
0 g
s
.47627 .84348 m .50065 .83322 L .51483 .83633 L p .476 .776 .997 r
F P
0 g
s
.45867 .32806 m .46616 .31393 L .54647 .30933 L p .454 0 0 r
F P
0 g
s
.46616 .31393 m .45867 .32806 L .37766 .35256 L p .217 0 0 r
F P
0 g
s
.37766 .35256 m .36527 .37736 L .29931 .41995 L p .071 0 .037 r
F P
0 g
s
.28878 .45374 m .29931 .41995 L .36527 .37736 L p .253 0 .297 r
F P
0 g
s
.78707 .47974 m .79045 .51855 L .73547 .46929 L p .947 .636 .414 r
F P
0 g
s
.73547 .46929 m .73272 .43003 L .78707 .47974 L p .947 .636 .414 r
F P
0 g
s
.54647 .30933 m .54899 .32292 L .45867 .32806 L p .454 0 0 r
F P
0 g
s
.58856 .83881 m .55818 .83081 L .56787 .82464 L p .65 .87 .982 r
F P
0 g
s
.56787 .82464 m .60781 .82677 L .58856 .83881 L p .65 .87 .982 r
F P
0 g
s
.79347 .65247 m .77088 .68954 L .75049 .64563 L p .957 .87 .71 r
F P
0 g
s
.75049 .64563 m .77184 .60323 L .79347 .65247 L p .957 .87 .71 r
F P
0 g
s
.70109 .78386 m .66169 .80092 L .66388 .77733 L p .819 .924 .905 r
F P
0 g
s
.66388 .77733 m .70476 .7529 L .70109 .78386 L p .819 .924 .905 r
F P
0 g
s
.36527 .37736 m .37766 .35256 L .45867 .32806 L p .396 .018 .2 r
F P
0 g
s
.34729 .76861 m .38797 .78928 L .39754 .81217 L p .297 .547 .919 r
F P
0 g
s
.43826 .8197 m .39754 .81217 L .38797 .78928 L p .424 .638 .945 r
F P
0 g
s
.39754 .81217 m .43826 .8197 L .45356 .83323 L p .35 .653 .968 r
F P
0 g
s
.48914 .82795 m .45356 .83323 L .43826 .8197 L p .493 .722 .973 r
F P
0 g
s
.45356 .83323 m .48914 .82795 L .50065 .83322 L p .476 .746 .988 r
F P
0 g
s
.28842 .66736 m .31795 .70438 L .3115 .7426 L p .228 .359 .789 r
F P
0 g
s
.34729 .76861 m .3115 .7426 L .31795 .70438 L p .338 .472 .848 r
F P
0 g
s
.28566 .49279 m .29037 .53564 L .25201 .58668 L p .167 .086 .513 r
F P
0 g
s
.2661 .62764 m .25201 .58668 L .29037 .53564 L p .281 .237 .63 r
F P
0 g
s
.60781 .82677 m .56787 .82464 L .57315 .81717 L p .69 .862 .964 r
F P
0 g
s
.57315 .81717 m .61865 .81207 L .60781 .82677 L p .69 .862 .964 r
F P
0 g
s
.52632 .81621 m .5302 .83696 L .51483 .83633 L closepath p .602 .791 .972 r
F P
0 g
s
.52632 .81621 m .54517 .83506 L .5302 .83696 L closepath p .613 .799 .971 r
F P
0 g
s
.77088 .68954 m .74089 .72338 L .72233 .68582 L p .915 .872 .781 r
F P
0 g
s
.72233 .68582 m .75049 .64563 L .77088 .68954 L p .915 .872 .781 r
F P
0 g
s
.72346 .39688 m .73272 .43003 L .65111 .39392 L p .841 .47 .351 r
F P
0 g
s
.65111 .39392 m .6454 .3618 L .72346 .39688 L p .841 .47 .351 r
F P
0 g
s
.52632 .81621 m .51483 .83633 L .50065 .83322 L closepath p .594 .781 .97 r
F P
0 g
s
.79045 .51855 m .78535 .56028 L .73132 .51317 L p .939 .698 .547 r
F P
0 g
s
.73132 .51317 m .73547 .46929 L .79045 .51855 L p .939 .698 .547 r
F P
0 g
s
.63617 .33801 m .6454 .3618 L .55092 .34563 L p .7 .275 .235 r
F P
0 g
s
.55092 .34563 m .54899 .32292 L .63617 .33801 L p .7 .275 .235 r
F P
0 g
s
.52632 .81621 m .55818 .83081 L .54517 .83506 L closepath p .626 .804 .968 r
F P
0 g
s
.66169 .80092 m .61865 .81207 L .61966 .79618 L p .767 .884 .929 r
F P
0 g
s
.61966 .79618 m .66388 .77733 L .66169 .80092 L p .767 .884 .929 r
F P
0 g
s
.36527 .37736 m .35762 .40995 L .28878 .45374 L p .253 0 .297 r
F P
0 g
s
.28566 .49279 m .28878 .45374 L .35762 .40995 L p .362 .155 .458 r
F P
0 g
s
.52632 .81621 m .50065 .83322 L .48914 .82795 L closepath p .591 .771 .966 r
F P
0 g
s
.38797 .78928 m .4322 .80421 L .43826 .8197 L p .424 .638 .945 r
F P
0 g
s
.48153 .82104 m .43826 .8197 L .4322 .80421 L p .521 .704 .954 r
F P
0 g
s
.43826 .8197 m .48153 .82104 L .48914 .82795 L p .493 .722 .973 r
F P
0 g
s
.31795 .70438 m .3534 .73744 L .34729 .76861 L p .338 .472 .848 r
F P
0 g
s
.38797 .78928 m .34729 .76861 L .3534 .73744 L p .424 .559 .887 r
F P
0 g
s
.52632 .81621 m .56787 .82464 L .55818 .83081 L closepath p .64 .806 .963 r
F P
0 g
s
.29037 .53564 m .30285 .58048 L .2661 .62764 L p .281 .237 .63 r
F P
0 g
s
.28842 .66736 m .2661 .62764 L .30285 .58048 L p .363 .349 .709 r
F P
0 g
s
.52632 .81621 m .48914 .82795 L .48153 .82104 L closepath p .592 .762 .96 r
F P
0 g
s
.45295 .35113 m .45867 .32806 L .54899 .32292 L p .576 .178 .251 r
F P
0 g
s
.45867 .32806 m .45295 .35113 L .36527 .37736 L p .396 .018 .2 r
F P
0 g
s
.74089 .72338 m .70476 .7529 L .68865 .7224 L p .87 .865 .831 r
F P
0 g
s
.68865 .7224 m .72233 .68582 L .74089 .72338 L p .87 .865 .831 r
F P
0 g
s
.61865 .81207 m .57315 .81717 L .57341 .80919 L p .715 .843 .943 r
F P
0 g
s
.57341 .80919 m .61966 .79618 L .61865 .81207 L p .715 .843 .943 r
F P
0 g
s
.52632 .81621 m .57315 .81717 L .56787 .82464 L closepath p .651 .804 .956 r
F P
0 g
s
.54899 .32292 m .55092 .34563 L .45295 .35113 L p .576 .178 .251 r
F P
0 g
s
.3534 .73744 m .39333 .76564 L .38797 .78928 L p .424 .559 .887 r
F P
0 g
s
.4322 .80421 m .38797 .78928 L .39333 .76564 L p .493 .631 .914 r
F P
0 g
s
.35762 .40995 m .36527 .37736 L .45295 .35113 L p .49 .189 .382 r
F P
0 g
s
.4322 .80421 m .4787 .81321 L .48153 .82104 L p .521 .704 .954 r
F P
0 g
s
.52632 .81621 m .48153 .82104 L .4787 .81321 L closepath p .598 .754 .953 r
F P
0 g
s
.78535 .56028 m .77184 .60323 L .72035 .55977 L p .918 .734 .638 r
F P
0 g
s
.72035 .55977 m .73132 .51317 L .78535 .56028 L p .918 .734 .638 r
F P
0 g
s
.70476 .7529 m .66388 .77733 L .65088 .75431 L p .824 .852 .868 r
F P
0 g
s
.65088 .75431 m .68865 .7224 L .70476 .7529 L p .824 .852 .868 r
F P
0 g
s
.52632 .81621 m .57341 .80919 L .57315 .81717 L closepath p .66 .799 .949 r
F P
0 g
s
.39333 .76564 m .43631 .78837 L .4322 .80421 L p .493 .631 .914 r
F P
0 g
s
.4787 .81321 m .4322 .80421 L .43631 .78837 L p .553 .693 .932 r
F P
0 g
s
.30285 .58048 m .32252 .62542 L .28842 .66736 L p .363 .349 .709 r
F P
0 g
s
.31795 .70438 m .28842 .66736 L .32252 .62542 L p .425 .436 .768 r
F P
0 g
s
.35762 .40995 m .35534 .44938 L .28566 .49279 L p .362 .155 .458 r
F P
0 g
s
.29037 .53564 m .28566 .49279 L .35534 .44938 L p .432 .273 .564 r
F P
0 g
s
.73272 .43003 m .73547 .46929 L .65281 .43348 L p .85 .552 .483 r
F P
0 g
s
.65281 .43348 m .65111 .39392 L .73272 .43003 L p .85 .552 .483 r
F P
0 g
s
.43631 .78837 m .48103 .80529 L .4787 .81321 L p .553 .693 .932 r
F P
0 g
s
.52632 .81621 m .4787 .81321 L .48103 .80529 L closepath p .606 .749 .945 r
F P
0 g
s
.52632 .81621 m .55896 .79512 L .56852 .80155 L closepath p .666 .781 .935 r
F P
0 g
s
.52632 .81621 m .54573 .79064 L .55896 .79512 L closepath p .663 .772 .93 r
F P
0 g
s
.52632 .81621 m .5303 .78861 L .54573 .79064 L closepath p .657 .763 .928 r
F P
0 g
s
.52632 .81621 m .51441 .7893 L .5303 .78861 L closepath p .649 .755 .927 r
F P
0 g
s
.52632 .81621 m .49988 .79261 L .51441 .7893 L closepath p .639 .749 .929 r
F P
0 g
s
.52632 .81621 m .48834 .79815 L .49988 .79261 L closepath p .628 .746 .933 r
F P
0 g
s
.52632 .81621 m .48103 .80529 L .48834 .79815 L closepath p .617 .746 .938 r
F P
0 g
s
.52632 .81621 m .56852 .80155 L .57341 .80919 L closepath p .665 .791 .942 r
F P
0 g
s
.66388 .77733 m .61966 .79618 L .61041 .78084 L p .776 .836 .898 r
F P
0 g
s
.61041 .78084 m .65088 .75431 L .66388 .77733 L p .776 .836 .898 r
F P
0 g
s
.6454 .3618 m .65111 .39392 L .5521 .37726 L p .741 .397 .4 r
F P
0 g
s
.5521 .37726 m .55092 .34563 L .6454 .3618 L p .741 .397 .4 r
F P
0 g
s
.61966 .79618 m .57341 .80919 L .56852 .80155 L p .724 .816 .922 r
F P
0 g
s
.56852 .80155 m .61041 .78084 L .61966 .79618 L p .724 .816 .922 r
F P
0 g
s
.32252 .62542 m .34841 .66861 L .31795 .70438 L p .425 .436 .768 r
F P
0 g
s
.3534 .73744 m .31795 .70438 L .34841 .66861 L p .474 .509 .814 r
F P
0 g
s
.77184 .60323 m .75049 .64563 L .70307 .60706 L p .892 .756 .704 r
F P
0 g
s
.70307 .60706 m .72035 .55977 L .77184 .60323 L p .892 .756 .704 r
F P
0 g
s
.45046 .77395 m .48834 .79815 L .48103 .80529 L p .585 .689 .913 r
F P
0 g
s
.48103 .80529 m .43631 .78837 L .45046 .77395 L p .585 .689 .913 r
F P
0 g
s
.34841 .66861 m .37926 .70851 L .3534 .73744 L p .474 .509 .814 r
F P
0 g
s
.39333 .76564 m .3534 .73744 L .37926 .70851 L p .516 .573 .852 r
F P
0 g
s
.61041 .78084 m .56852 .80155 L .55896 .79512 L p .721 .787 .905 r
F P
0 g
s
.44942 .38293 m .45295 .35113 L .55092 .34563 L p .632 .31 .408 r
F P
0 g
s
.45295 .35113 m .44942 .38293 L .35762 .40995 L p .49 .189 .382 r
F P
0 g
s
.41371 .7439 m .45046 .77395 L .43631 .78837 L p .552 .632 .884 r
F P
0 g
s
.43631 .78837 m .39333 .76564 L .41371 .7439 L p .552 .632 .884 r
F P
0 g
s
.37926 .70851 m .41371 .7439 L .39333 .76564 L p .516 .573 .852 r
F P
0 g
s
.35534 .44938 m .35877 .49413 L .29037 .53564 L p .432 .273 .564 r
F P
0 g
s
.30285 .58048 m .29037 .53564 L .35877 .49413 L p .48 .361 .64 r
F P
0 g
s
.35534 .44938 m .35762 .40995 L .44942 .38293 L p .543 .3 .498 r
F P
0 g
s
.47332 .76265 m .49988 .79261 L .48834 .79815 L p .616 .692 .897 r
F P
0 g
s
.48834 .79815 m .45046 .77395 L .47332 .76265 L p .616 .692 .897 r
F P
0 g
s
.55092 .34563 m .5521 .37726 L .44942 .38293 L p .632 .31 .408 r
F P
0 g
s
.75049 .64563 m .72233 .68582 L .6804 .65304 L p .864 .77 .756 r
F P
0 g
s
.6804 .65304 m .70307 .60706 L .75049 .64563 L p .864 .77 .756 r
F P
0 g
s
.73547 .46929 m .73132 .51317 L .65025 .47895 L p .846 .604 .573 r
F P
0 g
s
.65025 .47895 m .65281 .43348 L .73547 .46929 L p .846 .604 .573 r
F P
0 g
s
.55896 .79512 m .59164 .76779 L .61041 .78084 L p .721 .787 .905 r
F P
0 g
s
.59164 .76779 m .55896 .79512 L .54573 .79064 L p .71 .76 .892 r
F P
0 g
s
.65088 .75431 m .61041 .78084 L .59164 .76779 L p .765 .788 .872 r
F P
0 g
s
.5024 .75586 m .51441 .7893 L .49988 .79261 L p .645 .701 .887 r
F P
0 g
s
.49988 .79261 m .47332 .76265 L .5024 .75586 L p .645 .701 .887 r
F P
0 g
s
.72233 .68582 m .68865 .7224 L .65347 .69598 L p .835 .779 .799 r
F P
0 g
s
.65347 .69598 m .6804 .65304 L .72233 .68582 L p .835 .779 .799 r
F P
0 g
s
.54573 .79064 m .56528 .75861 L .59164 .76779 L p .71 .76 .892 r
F P
0 g
s
.56528 .75861 m .54573 .79064 L .5303 .78861 L p .692 .736 .884 r
F P
0 g
s
.68865 .7224 m .65088 .75431 L .62349 .73454 L p .802 .785 .837 r
F P
0 g
s
.59164 .76779 m .62349 .73454 L .65088 .75431 L p .765 .788 .872 r
F P
0 g
s
.53432 .75445 m .5303 .78861 L .51441 .7893 L p .67 .716 .883 r
F P
0 g
s
.51441 .7893 m .5024 .75586 L .53432 .75445 L p .67 .716 .883 r
F P
0 g
s
.5303 .78861 m .53432 .75445 L .56528 .75861 L p .692 .736 .884 r
F P
0 g
s
.62349 .73454 m .65347 .69598 L .68865 .7224 L p .802 .785 .837 r
F P
0 g
s
.44736 .72672 m .47332 .76265 L .45046 .77395 L p .602 .641 .862 r
F P
0 g
s
.45046 .77395 m .41371 .7439 L .44736 .72672 L p .602 .641 .862 r
F P
0 g
s
.35877 .49413 m .36784 .54225 L .30285 .58048 L p .48 .361 .64 r
F P
0 g
s
.32252 .62542 m .30285 .58048 L .36784 .54225 L p .515 .43 .698 r
F P
0 g
s
.65111 .39392 m .65281 .43348 L .55246 .41695 L p .756 .474 .506 r
F P
0 g
s
.55246 .41695 m .5521 .37726 L .65111 .39392 L p .756 .474 .506 r
F P
0 g
s
.62349 .73454 m .59164 .76779 L .56528 .75861 L p .743 .746 .854 r
F P
0 g
s
.73132 .51317 m .72035 .55977 L .64349 .52829 L p .835 .641 .64 r
F P
0 g
s
.64349 .52829 m .65025 .47895 L .73132 .51317 L p .835 .641 .64 r
F P
0 g
s
.44942 .38293 m .44836 .42258 L .35534 .44938 L p .543 .3 .498 r
F P
0 g
s
.35877 .49413 m .35534 .44938 L .44836 .42258 L p .576 .379 .578 r
F P
0 g
s
.42284 .68546 m .44736 .72672 L .41371 .7439 L p .585 .592 .826 r
F P
0 g
s
.41371 .7439 m .37926 .70851 L .42284 .68546 L p .585 .592 .826 r
F P
0 g
s
.36784 .54225 m .38208 .59156 L .32252 .62542 L p .515 .43 .698 r
F P
0 g
s
.34841 .66861 m .32252 .62542 L .38208 .59156 L p .543 .489 .746 r
F P
0 g
s
.44836 .42258 m .44942 .38293 L .5521 .37726 L p .66 .396 .51 r
F P
0 g
s
.4906 .71633 m .5024 .75586 L .47332 .76265 L p .645 .657 .848 r
F P
0 g
s
.47332 .76265 m .44736 .72672 L .4906 .71633 L p .645 .657 .848 r
F P
0 g
s
.40073 .63992 m .42284 .68546 L .37926 .70851 L p .566 .542 .787 r
F P
0 g
s
.37926 .70851 m .34841 .66861 L .40073 .63992 L p .566 .542 .787 r
F P
0 g
s
.38208 .59156 m .40073 .63992 L .34841 .66861 L p .543 .489 .746 r
F P
0 g
s
.5521 .37726 m .55246 .41695 L .44836 .42258 L p .66 .396 .51 r
F P
0 g
s
.56528 .75861 m .58446 .72054 L .62349 .73454 L p .743 .746 .854 r
F P
0 g
s
.58446 .72054 m .56528 .75861 L .53432 .75445 L p .715 .71 .844 r
F P
0 g
s
.65347 .69598 m .62349 .73454 L .58446 .72054 L p .769 .729 .816 r
F P
0 g
s
.53827 .71417 m .53432 .75445 L .5024 .75586 L p .682 .68 .842 r
F P
0 g
s
.5024 .75586 m .4906 .71633 L .53827 .71417 L p .682 .68 .842 r
F P
0 g
s
.72035 .55977 m .70307 .60706 L .63288 .57923 L p .822 .669 .693 r
F P
0 g
s
.63288 .57923 m .64349 .52829 L .72035 .55977 L p .822 .669 .693 r
F P
0 g
s
.53432 .75445 m .53827 .71417 L .58446 .72054 L p .715 .71 .844 r
F P
0 g
s
.65281 .43348 m .65025 .47895 L .55192 .46316 L p .761 .528 .581 r
F P
0 g
s
.55192 .46316 m .55246 .41695 L .65281 .43348 L p .761 .528 .581 r
F P
0 g
s
.44836 .42258 m .44995 .46853 L .35877 .49413 L p .576 .379 .578 r
F P
0 g
s
.36784 .54225 m .35877 .49413 L .44995 .46853 L p .598 .44 .639 r
F P
0 g
s
.6804 .65304 m .65347 .69598 L .60261 .67714 L p .79 .712 .778 r
F P
0 g
s
.58446 .72054 m .60261 .67714 L .65347 .69598 L p .769 .729 .816 r
F P
0 g
s
.47941 .67146 m .4906 .71633 L .44736 .72672 L p .641 .616 .809 r
F P
0 g
s
.44736 .72672 m .42284 .68546 L .47941 .67146 L p .641 .616 .809 r
F P
0 g
s
.70307 .60706 m .6804 .65304 L .61901 .62951 L p .807 .692 .738 r
F P
0 g
s
.61901 .62951 m .63288 .57923 L .70307 .60706 L p .807 .692 .738 r
F P
0 g
s
.60261 .67714 m .61901 .62951 L .6804 .65304 L p .79 .712 .778 r
F P
0 g
s
.44995 .46853 m .44836 .42258 L .55246 .41695 L p .676 .457 .582 r
F P
0 g
s
.60261 .67714 m .58446 .72054 L .53827 .71417 L p .731 .684 .805 r
F P
0 g
s
.44995 .46853 m .45414 .51872 L .36784 .54225 L p .598 .44 .639 r
F P
0 g
s
.38208 .59156 m .36784 .54225 L .45414 .51872 L p .614 .49 .689 r
F P
0 g
s
.46928 .62239 m .47941 .67146 L .42284 .68546 L p .635 .576 .771 r
F P
0 g
s
.42284 .68546 m .40073 .63992 L .46928 .62239 L p .635 .576 .771 r
F P
0 g
s
.55246 .41695 m .55192 .46316 L .44995 .46853 L p .676 .457 .582 r
F P
0 g
s
.54203 .66854 m .53827 .71417 L .4906 .71633 L p .689 .646 .803 r
F P
0 g
s
.4906 .71633 m .47941 .67146 L .54203 .66854 L p .689 .646 .803 r
F P
0 g
s
.65025 .47895 m .64349 .52829 L .55052 .51378 L p .76 .569 .638 r
F P
0 g
s
.55052 .51378 m .55192 .46316 L .65025 .47895 L p .76 .569 .638 r
F P
0 g
s
.53827 .71417 m .54203 .66854 L .60261 .67714 L p .731 .684 .805 r
F P
0 g
s
.45414 .51872 m .46071 .57079 L .38208 .59156 L p .614 .49 .689 r
F P
0 g
s
.40073 .63992 m .38208 .59156 L .46071 .57079 L p .626 .535 .732 r
F P
0 g
s
.46071 .57079 m .46928 .62239 L .40073 .63992 L p .626 .535 .732 r
F P
0 g
s
.61901 .62951 m .60261 .67714 L .54203 .66854 L p .742 .658 .767 r
F P
0 g
s
.45414 .51872 m .44995 .46853 L .55192 .46316 L p .685 .505 .638 r
F P
0 g
s
.64349 .52829 m .63288 .57923 L .54831 .56644 L p .756 .602 .686 r
F P
0 g
s
.54831 .56644 m .55052 .51378 L .64349 .52829 L p .756 .602 .686 r
F P
0 g
s
.54543 .61873 m .54203 .66854 L .47941 .67146 L p .691 .614 .765 r
F P
0 g
s
.47941 .67146 m .46928 .62239 L .54543 .61873 L p .691 .614 .765 r
F P
0 g
s
.63288 .57923 m .61901 .62951 L .54543 .61873 L p .75 .631 .728 r
F P
0 g
s
.54203 .66854 m .54543 .61873 L .61901 .62951 L p .742 .658 .767 r
F P
0 g
s
.55192 .46316 m .55052 .51378 L .45414 .51872 L p .685 .505 .638 r
F P
0 g
s
.54543 .61873 m .54831 .56644 L .63288 .57923 L p .75 .631 .728 r
F P
0 g
s
.46071 .57079 m .45414 .51872 L .55052 .51378 L p .689 .545 .684 r
F P
0 g
s
.54831 .56644 m .54543 .61873 L .46928 .62239 L p .692 .58 .726 r
F P
0 g
s
.46928 .62239 m .46071 .57079 L .54831 .56644 L p .692 .58 .726 r
F P
0 g
s
.55052 .51378 m .54831 .56644 L .46071 .57079 L p .689 .545 .684 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo06oooooo3ol0000Yooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:_ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo067ooooo3Ol00005oc40017o00008_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02Wooooo000Qooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Mooooo`Co00001?la000=o`0000KoM00000Co0000oiL@0?nG403oUa00
1_l000000omD003o0000o`000005o`0001_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Yooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Wooooo2ol0
000Cog@00003o`000?nG403oUa0000OoUa001_l00002oe@000Co00005oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0E?ooool7o`0000;o=`0000?o0000og@00?md00005omd00000ol0003oUa00oiL@000<
oiL@00So00005Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Yoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D?ooool6o`0000Go=`0000?o0000og@0
0?md00004Omd000;o`00017oUa001?l0000Cooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool09oooool002Wooooo0_l0000Jooooo`03o`000?oooooooooo04cooooo1Ol00009ocL00003
o`000?md003oM00000?oM0003_l00007oi<]@004o`000?ncASco/dHlok=6?0Go00003_nG40001?l0
003oY1@0o`000?l0000Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool0
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`18ooooo`Go00002Olg0009o`00
01GoTbe000?o0000ok=6??ncAS`01_ncAS`6o`0000WoUa0000?o0000oj@D0?nT50000ol0000?oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`14ooooo`Co00002_lg0003o`0000;oI@@c00?o0000oi<]@?nC
;D006OnC;D000ol0003o/dHlok=6?00<ok=6?0Go00001OnG40001?l0003oY1@0oj@D0?nT5003o`00
00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`00:Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo043ooooo0ol0000;ocL000?o00001OmU13<00ol0003o
Tbe0oi<]@00Joi<]@003o`000?ncASco/dHl013o/dHl1Ol000000onG403o0000oj@D0003oj@D00?o
00002oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000Xooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0?_ooool3o`0000Wo=`000ol00007ofD4<`03o`00
0?nC;D3oTbe001_oTbe000?o0000ok=6??ncAS`05OncAS`4o`0000CoY1@00ol00009ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0kooooo`Co00001_lg0004o`0000[oI@@c00?o0000oi<]@?nC;D006onC
;D000ol0003o/dHlok=6?00Gok=6?004o`000?o;E2?o0000o`0000GoY1@00_l00007ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03o`000?oo
oooooooo03Wooooo1?l00004ocL000?o00003_mU13<00ol0003oTbe0oi<]@00Coi<]@0_o00006?nc
AS`00ol0003obe@Sol]D8`03o`0000CoY1@00_l00005ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0g
ooooo`Co00000_lg0003o`00013oI@@c00?o0000oi<]@?nC;D001OnC;D0?o`0000SoXDmX00?o0000
okeUI_nmIFH01Ol0000Cok=6?003o`000?o;E2?obe@S00?obe@S0_l00004oj@D00;o00000oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0=?ooool8o`00017oI@@c2_l0000Goj5?J003o`000?nmIFKo_FEV
00Go_FEV1Ol0000>ok=6?003o`000?o;E2?obe@S00Gobe@S0_l00004oj@D00;o000000?oooooo`00
0?ooool0>oooool00ol0003oooooooooo`0Qooooo`00:?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03;ooooo1_l0000AofD4<`?o00000_mm<6400ol0003oXDmXoj5?J00Loj5?J003
o`000?nmIFKo_FEV00[o_FEV1Ol0000:ok=6?003o`000?o;E2?obe@S00Kobe@S0ol00003oj@D00;o
0000??ooool00ol0003oooooooooo`0Qooooo`009oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02oooooo1Ol000000olB00Wo0000ofD4<`0=ofD4<`Co00001Omm<6400ol0003oXDmX
oj5?J00Loj5?J003o`000?nmIFKo_FEV00oo_FEV1Ol00005ok=6?003o`000?o;E2?obe@S00Wobe@S
0_l00002oj@D00;o0000??ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02gooooo1Ol000000olB00Wo0000ofD4<`0;ofD4<`?o00002Omm
<6400ol0003oXDmXoj5?J00Loj5?J003o`000?nmIFKo_FEV01Co_FEV1_l0000=ol]D8`?o000000?o
Y1@0o`000?ooool0>_ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02_ooooo1?l00003oa802@03o`000?mU13?oI@@c00KoI@@c1?l0000<
ogd`H@03o`000?nQCfSoXDmX01coXDmX00?o0000okeUI_nmIFH06OnmIFH3o`0000gobe@S1?l0000k
ooooo`03o`000?oooooooooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0Xoooo
o`Co00001?lB00T00ol0003oI@@cofD4<`04ofD4<`?o00004?mm<6400ol0003oXDmXoj5?J00Loj5?
J003o`000?nmIFKo_FEV01[o_FEV00?o0000omMhFOl000000_l0000:ol]D8`03o`000?o;E2?obe@S
00;o0000>oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Kooooo1?l00004oa802@04o`000?mU13?oI@@cofD4<`Co00004_mm<6400ol0
003oXDmXoj5?J00Moj5?J003o`000?nmIFKo_FEV01[o_FEV00?o0000omMhFOoGN5T00_oGN5T2o`00
00Sobe@S00?o0000ol]D8oo;E2<00_o;E2<00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool4o`0000Ko
4P091?l0000Fogd`H@03o`000?nQCfSoXDmX01goXDmX00?o0000okeUI_nmIFH06onmIFH00ol0003o
egQIomMhF@03omMhF@?o00001Oo;E2<00ol0003obe@Sol]D8`02ol]D8`;o0000>_ooool00ol0003o
ooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo027ooooo
1?l00005oa802@?o00006Omm<6400ol0003oXDmXoj5?J00Eoj5?J0co00006_nmIFH00ol0003oegQI
omMhF@06omMhF@;o00000oo;E2<00ol0003obe@Sol]D8`03ol]D8`;o0000>Oooool00ol0003ooooo
ooooo`0Mooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01oooooo0ol0
0006oa802@03o`000?m004co000001[oOC1Q00?o0000oj5?J?nQCfP01OnQCfP@o`0000SoZ6F200Co
0000ol5iPOo1NH7o`GV11Ol0000EokeUIP03o`000?oGN5WoegQI00SoegQI1?l00006ol]D8`;o0000
>Oooool00ol0003oooooooooo`0Looooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01gooooo0ol00005oa802@;o00000_m004`00ol0003oOC1Qogd`H@0Fogd`H@[o00006?nX
IH800ol0003o`GV1ol5iP@06ol5iP@Go00004?nmIFH00ol0003oegQIomMhF@0;omMhF@;o00001Oo;
E2<00ol0003obDd0o`00000iooooo`03o`000?oooooooooo01_ooooo000Vooooo`?o0000;oooool0
0ol0003oooooooooo`0Kooooo`;o00001_lB00T00ol0003o@01<od00C002od00C003o`000?mm<67o
OC1Q01?oOC1Q0ol00002oh]<O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH402oo1NH45
o`0000_o_FEV00?o0000omMhFOoGN5T03?oGN5T4o`0000?obe@S00?o0000olU=0?l00000>?ooool0
0ol0003oooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01Wooooo00?o0000oa802OlB00T01OlB00T00ol0003o@01<od00C002od00C003o`000?mm<67oOC1Q
017oOC1Q0ol00005oh]<O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH404?o1NH45o`00
00Oo_FEV00?o0000omMhFOoGN5T02ooGN5T01?l0003oegQIomMhFOoGN5T2o`000005ol]D8ol0003o
bDd0olU=0?l00000>?ooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000oa802OlB00T01?lB00T2o`0000Go@01<
00?o0000ogd`HOmm<6403_mm<643o`0000SoRdao00?o0000ojQUP_nXIH807OnXIH800ol0003o`GV1
ol5iP@0Eol5iP@Go00000_nmIFH00ol0003oegQIomMhF@0;omMhF@03o`000?oGN5WoegQI00?oegQI
0ol00002olU=0003o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool05_ooool00ol0003o4P09oa802@03oa802@03o`00
0?m004co@01<00Go@01<00?o0000ogd`HOmm<6402_mm<644o`0000_oRdao00?o0000ojQUP_nXIH80
7OnXIH800ol0003o`GV1ol5iP@0Jol5iP@Co00003?oGN5T00ol0003oegQIomMhF@06omMhF@04o`00
0?o9C@3obDd0o`0003Oooooo00?o0000ooooooooool06Oooool000?ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05?ooool00ol0003o4P09oa802@02oa802@;o00002?m004`00ol0003o
OC1Qogd`H@07ogd`H@?o00003on;C7l00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101co
`GV100Co0000omV=Nol0003o00002_oGN5T00ol0003oegQIomMhF@06omMhF@;o00000_o9C@000ol0
003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool04_ooool2o`0000?o4P0900?o0000od00C?m004`02?m004`00ol0003oOC1Qogd`H@04ogd`
H@?o00004_n;C7l00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101co`GV100Co0000omV=
NooISG_ofHek0ol00007omMhF@03o`000?oGN5WoegQI00KoegQI00?o0000onZ5=?l000000_o9C@00
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?lB00Wo4P0900;o00002_m004`00ol0003oOC1Qogd`
H@02ogd`H@?o00005?n;C7l00ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV101co`GV100?o
0000omV=NooISG/01?oISG/2o`0000GoegQI00?o0000omMhFOoGN5T01_oGN5T01?l0003ojXDdonZ5
=?l00002olU=0003o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool000_ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000hooooo`03o`00
0?oooooooooo00oooooo00Co0000oa802OlB00Wo00003?m004`00ol0003oOC1Qo`000002o`0001Oo
Rdao00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Lol5iP@03o`000?oISG_ofHek00Ko
fHek0_l00003omMhF@03o`000?oGN5WoegQI00OoegQI00Co0000onZ5=?oZQCCo00000_o9C@000ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool03Oooool2o`000003oa802Ol0003o@01<00_o@01<0ol0000Joh]<O`03o`000?nXIH;oZ6F2
01koZ6F200?o0000ol5iPOo1NH407?o1NH400ol0003ofHekomV=N`08omV=N`Co00002OoGN5T01Ol0
003ojXDdonZ5=?oZQCCo000000;obDd000?o0000ooooooooool0<oooool00ol0003oooooooooo`0F
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool03?ooool3o`0000co@01<00?o0000oe`WMOl000006on;C7l0
0ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV101co`GV100?o0000omV=NooISG/02ooISG/2
o`0000SoegQI00?o0000onZ5=?oZQC@00_oZQC@01?l0003obDd0olU=0?l0000cooooo`?o00005ooo
ool002Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0;ooooo`;o00003?m004`2
o`0000;oG2Me00?o0000oh]<Oon;C7l06On;C7l00ol0003oZ6F2ojQUPP0FojQUPPco00006oo1NH40
0ol0003ofHekomV=N`0;omV=N`04o`000?oISG_o0000o`0000KoegQI00?o0000onZ5=?oZQC@00ooZ
QC@01?l0003obDd0olU=0?l0000_ooooo`?o00000_ooool00ol0003oooooooooo`0Eooooo`009?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo0_l0000;od00C0;o00001?mL
9gD00ol0003oRdaooh]<O`0Ioh]<O`03o`000?nXIH;oZ6F200GoZ6F24Ol00008ojedU004o`000?o2
QiCo`XNDol:7U0Ko00005Oo1NH400ol0003ofHekomV=N`0;omV=N`04o`000?oISG_ofHekomV=N`;o
00001?oGN5T00ol0003ojXDdonZ5=004onZ5=003o`000?o9C@3o000002cooooo0ol00005ooooo`03
o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1oooool3o`0000[o@01<00?o0000oe`WMOmL9gD01?mL9gD00ol0003oRdaooh]<O`0Goh]<O`[o0000
6On]M9@00ol0003o`XNDol:7U007ol:7U0Oo00003_o1NH400ol0003ofHekomV=N`0;omV=N`03o`00
0?oISG_ofHek00?ofHek0ol00002omMhF@03o`000?oZQCCojXDd00CojXDd00?o0000olU=0?l00000
:?ooool3o`0000Sooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`06ooooo`?o00002?m004`2o`0000OoG2Me00?o0000oh]<Oon;C7l05?n;
C7l3o`0000;oTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7U00>ol:7U0Ko00002?o1
NH400ol0003ofHekomV=N`0;omV=N`03o`000?oISG_ofHek00KofHek0ol00007onZ5=003o`000?o9
C@3o000002Cooooo0ol0000;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool0
0ol0003oooooooooo`04ooooo`?o00001om004`2o`0000WoG2Me00?o0000oh]<Oon;C7l04?n;C7l4
o`0000GoTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7U00Dol:7U0Ko00000_o1NH40
0ol0003ofHekomV=N`0;omV=N`03o`000?oISG_ofHek00SofHek0_l00007onZ5=0;o00008Oooool3
o`0000oooooo00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`02ooooo`;o000000?o000<o`000?m004`01Om004`00ol0003oG2Meoe`WM@08oe`W
M@03o`000?n;C7ooRdao00goRdao1?l00009oi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7
U?o2Qi@06_o2Qi@4o`0000cofHek00?o0000omV=NooISG/02?oISG/00ol0003olZ9Yo`000007onZ5
=0;o00007Oooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0@Oooool01?l0003oooooooooooooool2o`000003o`003?l0003o@01<00?o@01<0_l0000;oe`W
M@03o`000?n;C7ooRdao00[oRdao0ol0000=oi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7
U?o2Qi@07?o2Qi@00ol0003of9ZBo`000002o`0000WofHek00?o0000omV=NooISG/02?oISG/01?l0
003olZ9Yoo:RJOl00007onZ5=0;o00006Oooool3o`0001Gooooo00?o0000ooooooooool05?ooool0
02?ooooo00?o0000ooooooooool0@_ooool01_l0003oooooo`000?l0003o000<o`0000Co@01<00?o
0000oe`WMOmL9gD02omL9gD00ol0003oRdaooh]<O`06oh]<O`Co00004?nCHI<00ol0003o[GBDojed
U00NojedU003o`000?o2QiCo`XND01co`XND00?o0000omRJT_oHVY800_oHVY82o`0000OofHek00?o
0000omV=NooISG/02?oISG/01Ol0003olZ9Yoo:RJOobXVWo000000OojXDd00?o0000ooooooooool0
5?ooool3o`0001Sooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@ooo
ool2o`0000;o000<00?o0000od00C?m004`00_l0000>oe`WM@03o`000?n;C7ooRdao00;oRdao1?l0
000Doi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7U?o2Qi@07?o2Qi@00ol0003of9ZBomRJ
TP04omRJTP;o00001_oISG/00ol0003ofHekomV=N`07omV=N`03o`000?obXVWolZ9Y00;olZ9Y00?o
0000onZ5=?oZQC@01OoZQC@00ol0003oooooooooo`0@ooooo`?o00006oooool00ol0003ooooooooo
o`0Dooooo`008oooool00ol0003oooooooooo`13ooooo`04o`000?l000co000<o`0030?o00004?mL
9gD00ol0003oRdaoo`000002o`0001SoTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7
U00Lol:7U003o`000?oHVY;of9ZB00Kof9ZB0ol00003omV=N`03o`000?oISG_ofHek00OofHek00?o
0000oo:RJOobXVT00oobXVT00ol0003ojXDdonZ5=005onZ5=003o`000?oooooooooo00cooooo0ol0
000Nooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04;ooooo0_l00002
o`0030;o00004OmL9gD3o`0001coTf6C00?o0000ojedU?n]M9@07On]M9@00ol0003o`XNDol:7U00L
ol:7U003o`000?oHVY;of9ZB00Wof9ZB0_l000000ooISG_o0000omV=N`08omV=N`03o`000?obXVWo
lZ9Y00ColZ9Y00?o0000onZ5=?oZQC@01?oZQC@00ol0003oooooooooo`09ooooo`?o00008Oooool0
0ol0003oooooooooo`0Dooooo`008oooool2o`0004;ooooo0_l00003o`003003o`000?mL9gGoG2Me
00ooG2Me00?o0000ofi5T?l000007OnCHI<00ol0003o[GBDojedU00MojedU003o`000?o2QiCo`XND
01co`XND00?o0000omRJT_oHVY802ooHVY82o`0000[ofHek00?o0000oo:RJOobXVT01?obXVT2o`00
00CojXDd0_l00007ooooo`?o00009Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003o
ooooooooo`11ooooo`03o`000?l000co000<00;o000<00?o0000oe`WMOmL9gD03OmL9gD2o`0000;o
KTF@00?o0000oi=QTonCHI<06onCHI<00ol0003o[GBDojedU00MojedU003o`000?o2QiCo`XND01co
`XND00?o0000omRJT_oHVY803?oHVY84o`0000OofHek00?o0000oo:RJOobXVT01_obXVT00ol0003o
jXDdonZ5=002onZ5=003o`000?oooooooooo00;ooooo0ol0000Xooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo047ooooo00?o0000o`003?l000`00_l000`2o`0000koG2Me
00?o0000ofi5T?m^AI000_m^AI000ol0003oTf6Coi=QT`0Koi=QT`03o`000?n]M9Co[GBD01go[GBD
00?o0000ol:7U?o2Qi@07?o2Qi@00ol0003of9ZBomRJTP0<omRJTP04o`000?oHVY;of9ZBomRJTP;o
00001OoISG/00ol0003olZ9Yoo:RJ@07oo:RJ@06o`000?oZQCCojXDdonZ5=?l0003ooooo0ol0000[
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo043ooooo0_l00003o`00
3003o`000?l005Co000000coG2Me0_l00005ofi5T003o`000?nCHI?oTf6C01_oTf6C00?o0000ojed
U?n]M9@05On]M9@<o`0001_o`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZBomRJTP03omRJ
TP;o00000ooISG/00ol0003olZ9Yoo:RJ@08oo:RJ@03o`000?oZQCCojXDd00;o0000;_ooool00ol0
003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`10ooooo`05o`000?l000co000<o`00
3?l000000_l005@00ol0003oG2Meoe`WM@09oe`WM@03o`000?m^AI3oKTF@00GoKTF@00?o0000oi=Q
TonCHI<06onCHI<00ol0003o[GBDojedU005ojedU13o00002?n_PJ<01?l0003o`Y6Sol:AXoo2TJ<6
o`0001Go`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZBomRJTP05omRJTPCo00002oobXVT0
1?l0003ojXDdonZ5=?l0000^ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooo
oooo03oooooo00?o0000o`003?l000`00_l000`01?l0003o001Do`00E?l00009oe`WM@;o00002?m^
AI000ol0003oTf6Coi=QT`0Ioi=QT`[o00006?n_PJ<00ol0003o`Y6Sol:AX`07ol:AX`Oo00003_o2
Qi@00ol0003of9ZBomRJTP0<omRJTP03o`000?oHVY;of9ZB00Sof9ZB0_l0000;oo:RJ@04o`000?oZ
QCCo0000o`0002gooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0?_oo
ool00ol0003o000<o`003002o`003005o`000?l005Co001Do`00E?l000002?mL9gD00ol0003oKTF@
ofi5T008ofi5T003o`000?nCHI?oTf6C01KoTf6C0ol00002oiU`X`03o`000?n_PJ?o[h6S01go[h6S
00?o0000ol:AXoo2TJ<03_o2TJ<6o`0000So`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZB
omRJTP08omRJTP03o`000?o`/Xco000000_olZ9Y0ol0000]ooooo`03o`000?oooooooooo01?ooooo
000Qooooo`?o0000?oooool01Ol0003o000<o`003?l000co000000?o001D00?o0000oe`WMOmL9gD0
1OmL9gD2o`0000coKTF@00?o0000oi=QTonCHI<04OnCHI<4o`0000GoVG2S00?o0000ojn1Xon_PJ<0
7On_PJ<00ol0003o`Y6Sol:AX`0Dol:AX`Ko00000_o2Qi@00ol0003of9ZBomRJTP0<omRJTP03o`00
0?oHVY;of9ZB00Sof9ZB00Co0000oo2bS?o`/Xco00002oobXVT3o`0002gooooo00?o0000oooooooo
ool04_ooool0027ooooo00?o0000ooooooooool0?_ooool01Ol0003o000<o`003?l000co000000Co
001D00?o0000oe`WMOmL9gD01?mL9gD00ol0003oKTF@ofi5T00<ofi5T003o`000?nCHI?oTf6C00go
Tf6C1?l00009oiU`X`03o`000?n_PJ?o[h6S01go[h6S00?o0000ol:AXoo2TJ<06_o2TJ<4o`0000go
f9ZB00?o0000omRJT_oHVY802?oHVY801Ol0003ol;:<oo2bS?o`/Xco000000_olZ9Y0_l0000]oooo
o`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03kooooo00Co0000o`003?l0
00co00001Ol005@00ol0003oG2Meoe`WM@02oe`WM@;o00003om^AI000ol0003oTf6Coi=QT`0:oi=Q
T`?o00003OnIL:<00ol0003o[h6Sojn1X`0Mojn1X`03o`000?o2TJ?o`Y6S01co`Y6S00Co0000omFT
Xol0003o00002ooHVY800ol0003of9ZBomRJTP08omRJTP03o`000?o`/Xcol;:<00;ol;:<00?o0000
oo:RJOobXVT02?obXVT2o`0002gooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooo
ooooool0?_ooool01?l0003o000<o`003?l00005o`00E005o`000?mL9gGoG2Meoe`WMOl000004Om^
AI000ol0003oTf6Coi=QT`06oi=QT`Co00004?nIL:<00ol0003o[h6Sojn1X`0Mojn1X`03o`000?o2
TJ?o`Y6S01co`Y6S00Co0000omFTXooEY:?oeJBS0ol00008omRJTP03o`000?oHVY;of9ZB00Sof9ZB
00?o0000oo2bS?o`/X`00oo`/X`00ol0003olZ9Yoo:RJ@07oo:RJ@?o0000;?ooool00ol0003ooooo
ooooo`0Booooo`008Oooool00ol0003oooooooooo`0mooooo`04o`000?l000co000<o`0000Ko001D
00Co0000oe`WMOl0003o00004_m^AI000ol0003oTf6Coi=QT`02oi=QT`Co00005?nIL:<00ol0003o
[h6Sojn1X`0Mojn1X`03o`000?o2TJ?o`Y6S01co`Y6S00?o0000omFTXooEY:<01?oEY:<2o`0000Ko
f9ZB00?o0000omRJT_oHVY802?oHVY800ol0003ol;:<oo2bS004oo2bS003o`000?obXVWolZ9Y00Ko
lZ9Y0ol0000/ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03gooooo
00?o0000o`003?l000001ol005@2o`0001CoKTF@00?o0000oi=QTol000000_l0000HoiU`X`03o`00
0?n_PJ?o[h6S01co[h6S00?o0000ol:AXoo2TJ<07Oo2TJ<00ol0003oeJBSomFTX`06omFTX`;o0000
1?oHVY800ol0003of9ZBomRJTP08omRJTP03o`000?o`/Xcol;:<00Gol;:<00?o0000oo:RJOobXVT0
1_obXVT3o`0002_ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0?Ooo
ool2o`0000So001D00?o0000ofi5T?m^AI004_m^AI03o`0001_oVG2S00?o0000ojn1Xon_PJ<07?n_
PJ<00ol0003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00WoeJBS0ol000000ooHVY;o0000omRJ
TP08omRJTP03o`000?o`/Xcol;:<00Ool;:<0_l00006oo:RJ@?o0000:oooool00ol0003ooooooooo
o`0Booooo`008?ooool3o`0003gooooo00?o0000o`003?l000002?l005@00ol0003oKTF@ofi5T00A
ofi5T003o`000?mjG:?o000001goVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0003o`Y6Sol:AX`0L
ol:AX`03o`000?oEY:?oeJBS00coeJBS0_l00009omRJTP03o`000?o`/Xcol;:<00Wol;:<00?o0000
oo:RJOobXVT00oobXVT3o`0002cooooo00?o0000ooooooooool04Oooool0023ooooo00?o0000oooo
ooooool0?Oooool2o`0000So001D0_l0000Aofi5T0;o00000_mjG:<00ol0003oVG2SoiU`X`0KoiU`
X`03o`000?n_PJ?o[h6S01_o[h6S00?o0000ol:AXoo2TJ<07?o2TJ<00ol0003oeJBSomFTX`0>omFT
X`;o00001ooHVY800ol0003ol;:<oo2bS00:oo2bS003o`000?obXVWolZ9Y00;olZ9Y00Co0000onjX
;_l0003o0000:oooool00ol0003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0?Oooool00ol0003o001Do`00E006o`00E003o`000?lZ5X?o
000000ooKTF@0_l00005ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<0
0ol0003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00Co0000omFTXol0003o00001OoH
VY800ol0003ol;:<oo2bS00;oo2bS006o`000?obXVWolZ9Yoo:RJOl0003okZP^0_l0000[ooooo`03
o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`0looooo`03o`000?l005Co001D00Ko001D00Co0000obXFPolZ5X?o00003_m^AI000ol0
003oNUbSogYLX`05ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0
003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00Co0000omFTXooEY:?oeJBS0ol00002
omRJTP03o`000?o`/Xcol;:<00col;:<00Co0000oo:RJOobXVWo00000_o^Z2h2o`0002[ooooo00?o
0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo03cooooo00?o0000o`00E?l005@01Ol005@01Ol0003o:QJ3obXFPolZ5X?o000000coKTF@
0_l00008ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0003o`Y6S
ol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00?o0000omFTXooEY:<01?oEY:<3o`0000ool;:<
00?o0000oo:RJOl000000_o^Z2h2o`0002[ooooo00?o0000ooooooooool04Oooool001Gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03cooooo00?o0000o`00E?l005@0
1Ol005@01Ol0003o:QJ3obXFPolZ5X?o000000[oKTF@0_l0000:ogYLX`03o`000?nIL:?oVG2S01[o
VG2S00?o0000ojn1Xon_PJ<05?n_PJ<;o`0001_o`Y6S00?o0000omFTXooEY:<03_oEY:<00ol0003o
eJBSomFTX`06omFTX`;o00003oo`/X`00ol0003olZ9Yo`000002onjX;P03o`000?oooooooooo02So
oooo00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo03gooooo00?o0000o`00E?l005@01?l005@00ol0003o:QJ3obXFP`03obXFP`03
o`000?m^AI3oKTF@00KoKTF@00?o0000ogYLXomjG:<02_mjG:<00ol0003oVG2SoiU`X`0JoiU`X`03
o`000?n_PJ?o[h6S00Go[h6S3ol00007ok2;[`04o`000?o1VZoo`IZ_ol6J[`Ko00005Oo2TJ<00ol0
003oeJBSomFTX`0>omFTX`03o`000?oEY:?oeJBS00KoeJBS00?o0000on^kXol000003oo`/X`2o`00
00;okZP^0_l0000Yooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41001Oooool2o`0003kooooo00?o0000o`00E?l005@00ol005@00ol0003o:QJ3obXFP`04obXF
P`03o`000?m^AI3oKTF@00CoKTF@0_l0000>ogYLX`03o`000?nIL:?oVG2S01OoVG2S2_l0000Fok2;
[`03o`000?o1VZoo`IZ_00Oo`IZ_1_l0000>ol:AX`03o`000?oEY:?oeJBS00ooeJBS00?o0000omFT
XooEY:<01_oEY:<01?l0003ojk^Son^kXol0000?oo2bS005o`000?o^Z2kokZP^onjX;_l00000:Ooo
ool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0??ooool2o`0000Co001D00?o0000obXFPolZ5X<01OlZ5X<00ol0003oKTF@ofi5
T003ofi5T003o`000?mjG:?oNUbS00koNUbS00?o0000oiU`XonIL:<04onIL:<4o`0000;oWGf`00?o
0000ok2;[on`Rjl06on`Rjl00ol0003o`IZ_ol6J[`0=ol6J[`Ko00002?o2TJ<00ol0003oeJBSomFT
X`0?omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[^j<00_o[^j<00ol0003ol;:<oo2b
S00<oo2bS005o`000?o^Z2kokZP^onjX;_l00000:_ooool00ol0003oooooooooo`0@ooooo`005Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0??ooool2o`0000?o001D
00?o0000obXFPolZ5X<01_lZ5X<01?l0003oKTF@ofi5T?m^AI02o`00017oNUbS00?o0000oiU`XonI
L:<03onIL:<4o`0000KoWGf`00?o0000ok2;[on`Rjl06on`Rjl00ol0003o`IZ_ol6J[`0Col6J[`Ko
00000_o2TJ<00ol0003oeJBSomFTX`0?omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[
^j<00oo[^j<00ol0003ol;:<oo2bS00;oo2bS0;o00000_o^Z2h2o`0002Wooooo00?o0000oooooooo
ool04?ooool001oooooo00?o0000ooooooooool0??ooool01Ol0003o001Do`00E?l005Co000000Wo
:QJ300Co0000ofi5T?l0003o00004omjG:<00ol0003oVG2SoiU`X`0;oiU`X`Co00002_nMOK000ol0
003o/8^_ok2;[`0Kok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_1?l0000@omFTX`03o`000?oEY:?oeJBS
00GoeJBS00?o0000on^kXoo[^j<01?o[^j<00ol0003ol;:<oo2bS00:oo2bS0;o00000oo^Z2h00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03co
oooo00Go0000o`00E?l005Co001Do`000009obXFP`;o00005OmjG:<00ol0003oVG2SoiU`X`08oiU`
X`?o00003_nMOK000ol0003o/8^_ok2;[`0Kok2;[`03o`000?o1VZoo`IZ_01_o`IZ_00?o0000om:[
/Ol000000_l0000=omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[^j<01Oo[^j<00ol0
003ol;:<oo2bS008oo2bS003o`000?oobg3o000000?okZP^00?o0000ooooooooool09oooool00ol0
003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`0looooo`04o`000?l005Co001Do`00
00[o:QJ300?o0000ogYLXomjG:<05OmjG:<00ol0003oVG2SoiU`X`03oiU`X`Co00004_nMOK000ol0
003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01_o`IZ_00?o0000om:[/OoBZk400_oBZk43o`00
00[oeJBS00?o0000omFTXooEY:<01OoEY:<00ol0003ojk^Son^kX`06on^kX`;o00002?o`/X`01?l0
003ool]`ooo;L?l00003onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
01kooooo00?o0000ooooooooool0?Oooool00ol0003o001Do`00000;obXFP`03o`000?mjG:?oNUbS
01GoNUbS00?o0000oiU`Xol000000ol0000Foiem/003o`000?n`Rjoo/8^_01[o/8^_00?o0000ol6J
[oo1VZl06_o1VZl00ol0003odZ^aom:[/@06om:[/@;o00002?oEY:<00ol0003oeJBSomFTX`04omFT
X`03o`000?o[^j?ojk^S00Wojk^S00?o0000oo2bS?o`/X`01Oo`/X`01?l0003ool]`ooo;L?l00003
onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool001kooooo00?o0000oooo
ooooool0?Oooool2o`0000_o:QJ30_l0000FogYLX`?o00006_nMOK000ol0003o/8^_ok2;[`0Jok2;
[`03o`000?o1VZoo`IZ_01[o`IZ_00?o0000om:[/OoBZk402?oBZk43o`0000GoeJBS00?o0000omFT
XooEY:<01?oEY:<00ol0003ojk^Son^kX`0:on^kX`03o`000?o`/Xcol;:<00Col;:<00Go0000ooo;
L?oobg3ool]`o`000002onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
01kooooo0_l0000nooooo`03o`000?lZ5X?o:QJ300Wo:QJ300Co0000odLlXOm7?:7o00004omjG:<2
o`000003oh=^/_l0003oWGf`01[oWGf`00?o0000ok2;[on`Rjl06_n`Rjl00ol0003o`IZ_ol6J[`0J
ol6J[`03o`000?oBZk7odZ^a00_odZ^a0ol00002omFTX`03o`000?oEY:?oeJBS00CoeJBS00?o0000
on^kXoo[^j<02oo[^j<00ol0003ol;:<oo2bS003oo2bS005o`000?oobg3ool]`ooo;L?l000000_o^
Z2h00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo03gooooo00?o0000obXFPolZ5X<02?lZ5X<01Ol0003oAcbQodLlXOm7?:7o000001;oNUbS00?o
0000oh=^/_n3K[800_n3K[800ol0003oWGf`oiem/00Hoiem/003o`000?n`Rjoo/8^_01[o/8^_00?o
0000ol6J[oo1VZl06_o1VZl00ol0003odZ^aom:[/@0>om:[/@?o00001_oEY:<00ol0003ojk^Son^k
X`0<on^kX`03o`000?o`/Xcol;:<00;ol;:<00?o0000ooo;L?oobg000_oobg000ol0003okZP^o`00
000Yooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000:
obXFP`05o`000?m7?:7oAcbQodLlXOl000004?mjG:<2o`0000GoPfjb00?o0000oiem/?nMOK006?nM
OK000ol0003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_00?o0000om:[/OoBZk404OoB
Zk43o`0000CoeJBS00?o0000on^kXoo[^j<03Oo[^j<01Ol0003ol;:<oo2bS?o`/Xco000000Cool]`
00?o0000onjX;_l00000:Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`0looooo`;o00002OlZ5X<00ol0003oAcbQodLlX@03odLlX@03o`000?mjG:?oNUbS00_oNUbS0_l0
0007oh=^/P03o`000?nMOK3oWGf`01SoWGf`00?o0000ok2;[on`Rjl06_n`Rjl00ol0003o`IZ_ol6J
[`0Iol6J[`03o`000?oBZk7odZ^a017odZ^a00?o0000om:[/OoBZk401?l0000Aon^kX`03o`000?o`
/Xco000000Gool]`00?o0000onjX;_l00000:Oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`0mooooo`03o`000?l004_o000000Oo:QJ300?o0000odLlXOm7?:401?m7?:40
0ol0003oNUbSogYLX`0:ogYLX`03o`000?n3K[;oPfjb00SoPfjb00?o0000oiem/?nMOK005onMOK00
0ol0003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_00?o0000om:[/OoBZk404OoBZk40
0ol0003odZ^aom:[/@03om:[/@;o00004Oo[^j<2o`0000Kool]`00?o0000onjX;_l00000:?ooool0
0ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?l004_o0000
00Ko:QJ300?o0000odLlXOm7?:401Om7?:400ol0003oNUbSogYLX`08ogYLX`;o00002on3K[800ol0
003oWGf`oiem/00Hoiem/003o`000?n`Rjoo/8^_01Wo/8^_00?o0000ol6J[oo1VZl06Oo1VZl00ol0
003odZ^aom:[/@0Bom:[/@03o`000?oBZk7odZ^a00;odZ^a00?o0000onC1]?l000004Oo[^j<00ol0
003ool]`ooo;L004ooo;L003o`000?o^Z2ko000002Sooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003o001;o`000006obXFP`03o`000?m7?:7oAcbQ00Go
AcbQ00?o0000ogYLXomjG:<01_mjG:<2o`0000goPfjb00?o0000oiem/?nMOK006?nMOK000ol0003o
/8^_ok2;[`0Iok2;[`03o`000?o1VZoo`IZ_01So`IZ_00?o0000om:[/OoBZk404ooBZk401Ol0003o
dZ^aom:[/OoBZk7o000000?oi<6d00?o0000on^kXoo[^j<03_o[^j<00ol0003ool]`ooo;L005ooo;
L0;o0000:?ooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0003kooooo00?o0000o`00Bol0
00001OlZ5X<00ol0003oAcbQodLlX@07odLlX@03o`000?mjG:?oNUbS00CoNUbS00?o0000oh=^/_n3
K[803_n3K[800ol0003oWGf`oiem/00Goiem/003o`000?n`Rjoo/8^_00_o/8^_4_l0000Gol6J[`03
o`000?oBZk7odZ^a01?odZ^a00Go0000om:[/OoBZk7odZ^ao`000004onC1]003o`000?o[^j?ojk^S
00gojk^S0_l00006ooo;L0;o0000:Oooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`0mooooo`03o`000?l004_o000000Co:QJ300?o0000odLlXOm7?:402?m7?:400ol0003o
NUbSogYLX`02ogYLX`;o00004On3K[800ol0003oWGf`oiem/00Eoiem/13o00003_naU;T01?l0003o
_j6joknQ^_noXKX7o`00013o`IZ_00?o0000om:[/OoBZk404ooBZk401Ol0003odZ^aom:[/OoBZk7o
000000Goi<6d00?o0000on^kXoo[^j<02oo[^j<00ol0003ooMVKo`000006ooo;L0;o0000:Oooool0
0ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?l004_o0000
00?o:QJ300?o0000odLlXOm7?:402Om7?:400ol0003oNUbSogYLX`02o`0001?oPfjb00?o0000oiem
/?nMOK004OnMOK04o`0000;oX8Rk00?o0000ok6D^OnaU;T06OnaU;T00ol0003o_j6joknQ^P08oknQ
^PKo00002_o1VZl00ol0003odZ^aom:[/@0Com:[/@04o`000?oBZk7odZ^ao`0000Ooi<6d00?o0000
on^kXoo[^j<02_o[^j<01?l0003ooMVKoogIVol00006ooo;L003o`000?oooooooooo02Oooooo00?o
0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0?_ooool00ol0003o001;o`000003
obXFP`03o`000?m7?:7oAcbQ00[oAcbQ0_l0000Foh=^/P03o`000?nMOK3oWGf`00coWGf`1?l00006
oj28^`03o`000?naU;Wo/IBi01Wo/IBi00?o0000oknQ^_noXKX03_noXKX7o`0000;o`IZ_00?o0000
om:[/OoBZk405?oBZk401?l0003odZ^aom:[/Ol00008onC1]003o`000?o[^j?ojk^S00Wojk^S00Co
0000oogIVoomfI_o00001_oobg000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o0000obXFPol0000=odLlX@03
o`000?n3K[;oPfjb01GoPfjb00?o0000oiem/?nMOK002?nMOK04o`0000[oX8Rk00?o0000ok6D^Ona
U;T06OnaU;T00ol0003o_j6joknQ^P0EoknQ^PCo00005OoBZk400ol0003odZ^ao`00000:onC1]0;o
00002?o[^j<01Ol0003ooMVKoogIVoomfI_o000000Kool]`00?o0000ooooooooool09oooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0nooooo`03o`000?l004_o001;00;o
00003_m7?:400ol0003oPfjboh=^/P0Eoh=^/P03o`000?nMOK3oWGf`00CoWGf`1?l0000?oj28^`03
o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_noXKX05onoXKX00ol0003oc[6lo`000002o`0001;o
dZ^a00?o0000om:[/Ol000003?oT`K@00ol0003ojk^Son^kX`05on^kX`03o`000?omfI_ooMVK00;o
oMVK00?o0000ooo;L?oobg000ooobg000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00002o`00B`03o`000?m7?:7oAcbQ00coAcbQ
00?o0000oeaI]Ol000005on3K[800ol0003oWGf`o`000003o`0001?oX8Rk00?o0000ok6D^OnaU;T0
6?naU;T00ol0003o_j6joknQ^P0GoknQ^P03o`000?o>/Kcoc[6l00;oc[6l0ol0000=om:[/@?o0000
00?odZ^ao`000?oT`K@03?oT`K@00ol0003ojk^Son^kX`04on^kX`03o`000?omfI_ooMVK00;ooMVK
00?o0000ooo;L?oobg000_oobg000ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03gooooo00Go0000o`00Bol004_o001;o`00000=odLlX@04o`00
0?mLFKGoG5Veo`0001KoPfjb0ol0000Goj28^`03o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_no
XKX05_noXKX00ol0003oc[6lolja_006olja_0?o00001ooBZk43o`0000;odZ^a0_l0000?onC1]003
o`000?o[^j?ojk^S00;ojk^S00?o0000oogIVoomfI/01?omfI/01Ol0003ool]`ooo;L?oobg3o0000
02_ooooo00?o0000ooooooooool03Oooool001cooooo0_l0000nooooo`05o`000?l004_o001;o`00
Bol000003?m7?:400ol0003oG5VeoeaI]@02oeaI]@03o`000?n3K[;oPfjb017oPfjb0_l000000on;
OKko0000oj28^`0Goj28^`03o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_noXKX05_noXKX00ol0
003oc[6lolja_009olja_0;o00000_oBZk43o`0000KodZ^a00?o0000onC1]?oT`K@03_oT`K@01Ol0
003ojk^Son^kXoo[^j?o000000KooMVK00Go0000ooo;L?oobg3ool]`o`00000[ooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o001;o`00
R_l0000:odLlX@03o`000?mLFKGoG5Ve00?oG5Ve00?o0000oh=^/_n3K[804?n3K[800ol0003oRgfn
oh]m_P02oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000ok6D^OnaU;T05onaU;T00ol0003o_j6j
oknQ^P0GoknQ^P03o`000?o>/Kcoc[6l00[oc[6l1?l00007om:[/@03o`000?oT`KCo0000013oi<6d
00Co0000on^kXoo[^j?o00001oomfI/01?l0003ool]`ooo;L?l0000[ooooo`03o`000?oooooooooo
00gooooo000Kooooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o001;o`00R_l0000:
odLlX@03o`000?mLFKGoG5Ve00?oG5Ve00?o0000oh=^/_n3K[803_n3K[82o`0000GoRgfn00?o0000
oj28^onPR;/05_nPR;/00ol0003o/IBiok6D^@0Fok6D^@03o`000?noXK[o_j6j01Oo_j6j00?o0000
olja_?o>/K`01_o>/K`4o`0000Coc[6l0ol00004om:[/@04o`000?oT`KCoi<6do`00013oi<6d0_l0
0008oogIV`04o`000?oobg3ool]`o`0002_ooooo00?o0000ooooooooool03Oooool001_ooooo00?o
0000ooooooooool0?_ooool01_l0003o001;o`00Bol0003o002:o`0000WoAcbQ00?o0000oeaI]OmL
FKD01OmLFKD00ol0003oPfjboh=^/P0;oh=^/P;o00001on;OKh00ol0003oX8Rkoj28^`0Foj28^`03
o`000?naU;Wo/IBi01Ko/IBi00?o0000oknQ^_noXKX05_noXKX00ol0003oc[6lolja_004olja_0?o
00002oo>/K`3o`000003om:[/Ol0003oi<6d00;oi<6d00?o0000onC1]?oT`K@03_oT`K@00ol0003o
oMVKoogIV`06oogIV`04o`000?oobg3ool]`o`0002_ooooo00?o0000ooooooooool03Oooool001_o
oooo00?o0000ooooooooool0?_ooool01?l0003o001;o`00Bol00002o`00RP03o`000?m7?:7oAcbQ
00GoAcbQ00?o0000oeaI]OmLFKD01_mLFKD00ol0003oPfjboh=^/P09oh=^/P;o00002_n;OKh00ol0
003oX8Rkoj28^`0Eoj28^`03o`000?naU;Wo/IBi01Ko/IBi00?o0000oknQ^_noXKX05_noXKX01?l0
003oc[6lolja_?o>/K`3o`00017oc[6l0_l00003onC1]003o`000?oT`KCoi<6d00koi<6d00?o0000
oogIVoomfI/01oomfI/2o`0002cooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0?_ooool01?l0003o001;o`00Bol00002o`00RP03o`000?m7?:7oAcbQ00CoAcbQ00?o0000
oeaI]OmLFKD02?mLFKD00ol0003oPfjboh=^/P07oh=^/P03o`000?n;OKkoRgfn00[oRgfn00?o0000
oj28^onPR;/05OnPR;/00ol0003o/IBiok6D^@0Fok6D^@03o`000?noXK[o_j6j01Ko_j6j1?l0000D
olja_003o`000?oMaL7o000000?oi<6d00?o0000onC1]?oT`K@03?oT`K@00ol0003om=jeo`000008
oogIV`;o0000;?ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0noooo
o`04o`000?l004_o001;o`0000;o002:00?o0000odLlXOm7?:400om7?:400ol0003oG5VeoeaI]@09
oeaI]@03o`000?n3K[;oPfjb00GoPfjb0_l0000=oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000
ok6D^OnaU;T05_naU;T00ol0003o_j6joknQ^P0CoknQ^PCo00005_o>/K`01Ol0003ogLG1omg5`OoM
aL7o000000?oi<6d00?o0000onC1]?oT`K@02ooT`K@00ol0003om=jeo`000009oogIV`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool03Oooool001_ooooo0_l00010ooooo`03o`000?l004_o
000000?o002:00?o0000odLlXOm7?:400_m7?:400ol0003oG5VeoeaI]@0:oeaI]@03o`000?n3K[;o
Pfjb00;oPfjb0_l0000@oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000ok6D^OnaU;T05OnaU;T0
0ol0003o_j6joknQ^P0@oknQ^P?o00000_noXKX00ol0003oc[6lolja_00Eolja_003o`000?oMaL7o
gLG100;ogLG100Go0000onC1]?oT`KCoi<6do`00000;onC1]004o`000?odg[Gom=jeo`0000WooMVK
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003ooooooooo
o`10ooooo`03o`000?l004_o000000?o002:00Go0000odLlXOm7?:7oAcbQo`00000=oeaI]@05o`00
0?n3K[;oPfjboh=^/_l000004_n;OKh00ol0003oX8Rkoj28^`0Eoj28^`03o`000?naU;Wo/IBi00Wo
/IBi4Ol0000;oknQ^P?o00001OnoXKX00ol0003oc[6lolja_00Dolja_003o`000?oMaL7ogLG100Co
gLG10_l00002onC1]003o`000?oT`KCoi<6d00Soi<6d00Go0000ooCN]Oodg[Gom=jeo`000007oogI
V`;o0000;Oooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo043ooooo00?o0000
o`00Bol000000ol008X01?l0003oAcbQodLlXOl0000>oeaI]@04o`000?n3K[;o0000o`0001CoRgfn
00?o0000oj28^onPR;/04_nPR;/>o`0000co/9g300?o0000okfXa?nmZ<@00_nmZ<@;o`0000So_j6j
00?o0000olja_?o>/K`05?o>/K`00ol0003ogLG1omg5`@06omg5`@04o`000?oT`KCoi<6do`0000So
i<6d00?o0000ooCN]Oodg[D00_odg[D00ol0003ooMVKoogIV`05oogIV`;o0000;Oooool00ol0003o
ooooooooo`0<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`10ooooo`03o`000?l004_o000000Co002:0_l0000@oeaI]@03
o`000?n;OKkoRgfn01CoRgfn00?o0000oj28^onPR;/03onPR;/3o`0000;oXY?500?o0000ok2M`on`
WL<05On`WL<00ol0003o_JS4okfXa006okfXa0_o00000onoXKX00ol0003oc[6lolja_00Dolja_003
o`000?oMaL7ogLG100SogLG100?o0000onC1]?l000001ooT`K@00ol0003om=jeooCN]@04ooCN]@03
o`000?omfI_ooMVK00CooMVK00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`00
0oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@?ooool00ol0003o001;o`000004o`00RP03o`000?mLFKGoG5Ve00ooG5Ve00?o0000oh]m__n;OKh0
5?n;OKh00ol0003oX8Rkoj28^`0;oj28^`Co00001OnRTlD00ol0003o/9g3ok2M``0Eok2M``03o`00
0?nmZ<Co_JS400?o_JS40ol0000;okfXa0Go00005Oo>/K`00ol0003ogLG1omg5`@09omg5`@03o`00
0?oT`KCo000000Koi<6d00?o0000ooCN]Oodg[D01?odg[D00ol0003ooMVKoogIV`03oogIV`;o0000
;_ooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0@?ooool2o`0000Go002:00?o0000oeaI]OmLFKD03_mL
FKD00ol0003oK6o4o`00000Foh]m_P03o`000?nPR;_oX8Rk00OoX8Rk0ol0000:oj:Ca@03o`000?n`
WL?o/9g301Co/9g300?o0000okfXa?nmZ<@00ol0000AokfXa003o`000?o:]/Oo000000;o00004Oo>
/K`00ol0003ogLG1omg5`@0;omg5`@?o00001?oT`K@00ol0003om=jeooCN]@05ooCN]@03o`000?om
fI_ooMVK00?ooMVK0_l0000^ooooo`03o`000?oooooooooo00cooooo0003ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo047ooooo00?o
0000o`00R_l008X00ol008X00olD=;;o0000oeaI]@0=oeaI]@04o`000?m/KlCoK6o4o`0001KoRgfn
00?o0000oj28^onPR;/00onPR;/4o`0000goXY?500?o0000ok2M`on`WL<05?n`WL<3o`0001?o_JS4
00?o0000olZfaoo:]/L00oo:]/L2o`0000ooc[6l00?o0000omg5`OoMaL403OoMaL42o`0000?oi<6d
00?o0000ooCN]Oodg[D01_odg[D01ol0003ooMVKoogIVoomfI_o0000omWKI_l00000;_ooool00ol0
003oooooooooo`0<ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@_ooool00ol0003o002:o`00RP03o`00RP03oa@d/_l0003oG5Ve00co
G5Ve00?o0000ofa_a?m/Kl@00_m/Kl@00ol0003oRgfnoh]m_P0Coh]m_P03o`000?nPR;_oX8Rk00?o
00004OnRTlD00ol0003o/9g3ok2M``0@ok2M``Go00005OnmZ<@00ol0003ob[K7olZfa`05olZfa`;o
00003Oo>/K`00ol0003ogLG1omg5`@0>omg5`@;o000000?oi<6do`000?odg[D02?odg[D01ol0003o
oMVKoogIVoomfI_o0000omWKI_l00000;oooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooo
oonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`;o0000@oooool00ol0003o002:o`00RP03
o`00RP03o`000?lD=;;o000000_oG5Ve00?o0000ofa_a?m/Kl@01?m/Kl@00ol0003oRgfnoh]m_P0B
oh]m_P?o00005?nRTlD00ol0003o/9g3ok2M``0=ok2M``?o00001?n`WL<00ol0003o_JS4okfXa00C
okfXa003o`000?o:]/Oob[K700Oob[K70ol00009olja_003o`000?oMaL7ogLG1013ogLG100?o0000
onC1]?l000002_odg[D01Ol0003ooMVKo`000?oIffKo0000033ooooo00?o0000ooooooooool02ooo
ool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo04;ooooo00?o
0000o`00R_l008X00_l008X01Ol0003o53Bboa@d/_lD=;;o000000WoG5Ve00?o0000ofa_a?m/Kl@0
1Om/Kl@00ol0003oRgfnoh]m_P0@oh]m_P;o000000?oT8[9o`000?nRTlD05?nRTlD00ol0003o/9g3
ok2M``0:ok2M``?o00001on`WL<00ol0003o_JS4okfXa00BokfXa003o`000?o:]/Oob[K700_ob[K7
0_l00007olja_003o`000?oMaL7ogLG1017ogLG100?o0000ooCN]Oodg[D02Oodg[D01Ol0003ooMVK
o`000?oIffKo0000033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
@oooool01Ol0003o002:o`00R_l008[o000000?o53Bb00?o0000oeaI]OmLFKD01_mLFKD00ol0003o
K6o4ofa_a007ofa_a003o`000?n;OKkoRgfn00goRgfn0_l00004oi2:b@03o`000?nRTlGoXY?501?o
XY?500?o0000ok2M`on`WL<01_n`WL<3o`0000Wo/9g300?o0000okfXa?nmZ<@04onmZ<@00ol0003o
b[K7olZfa`0=olZfa`;o00001?o>/K`00ol0003ogLG1omg5`@0Bomg5`@;o00002_odg[D01Ol0003o
oMVKo`000?oIffKo0000033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0@oooool01Ol0003o002:o`00R_l008[o000000Co53Bb00?o0000oeaI]OmLFKD01OmLFKD00ol0
003oK6o4ofa_a007ofa_a003o`000?n;OKkoRgfn00_oRgfn0_l00006oi2:b@03o`000?nRTlGoXY?5
01?oXY?500?o0000ok2M`on`WL<00_n`WL<4o`0000co/9g300?o0000okfXa?nmZ<@04onmZ<@00ol0
003ob[K7olZfa`0?olZfa`?o000000?oc[6lo`000?oMaL404_oMaL401?l0003oj]o7o`000?l0000:
ooCN]@04o`000?oIffKofM]Vo`00033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000
ooooooooool0@oooool01Ol0003o002:o`00R_l008[o000000Co53Bb00?o0000oeaI]OmLFKD01?mL
FKD00ol0003oK6o4ofa_a009ofa_a003o`000?n;OKkoRgfn00SoRgfn0_l00009oi2:b@03o`000?nR
TlGoXY?501;oXY?500?o0000ok2M`ol000000_l0000@ok2M``03o`000?nmZ<Co_JS401;o_JS400?o
0000olZfaoo:]/L04oo:]/L2o`0001;ogLG100Ko0000on[OaooZglOo0000ooCN]Ol00009ooCN]@04
o`000?oIffKofM]Vo`00033ooooo00?o0000ooooooooool02oooool001Sooooo00?o0000oooooooo
ool0AOooool01?l0003o002:o`00R_l00005oa@d/P03o`000?mLFKGoG5Ve00;oG5Ve00?o0000ofa_
a?m/Kl@02_m/Kl@00ol0003oRgfnoh]m_P07oh]m_P03o`000?n@R/WoT8[900WoT8[900?o0000oj:C
aOnRTlD04OnRTlD3o`0001?o/9g300?o0000okfXa?nmZ<@04_nmZ<@00ol0003ob[K7olZfa`0ColZf
a`03o`000?oEalco0000017ogLG100Oo0000on[OaooZglOoj]o7o`000?odg[Go000000Oom=je0_l0
0002omWKIP03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool001Sooooo00?o0000
ooooooooool0AOooool01?l0003o002:o`00R_l00006oa@d/P04o`000?mLFKGoG5Veo`0000koK6o4
00?o0000oh]m__n;OKh01?n;OKh2o`0000coT8[900?o0000oj:CaOnRTlD03_nRTlD3o`000003oj:C
aOl0003o/9g301?o/9g300?o0000okfXa?nmZ<@04_nmZ<@00ol0003ob[K7olZfa`0BolZfa`05o`00
0?oEalcoeLO<omG7c?l000003ooMaL400ol0003oj]o7on[Oa`02on[Oa`03o`000?odg[Go000000Oo
m=je0_l000000ooIffKo0000ooooo`0aooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`00
0?oooooooooo04Gooooo00Co0000o`00R_l008[o00001_lD=;800ol0003oG5Veo`00000@ofa_a004
o`000?n;OKkoRgfnoh]m_P;o00003on@R/T00ol0003oXY?5oj:Ca@09oj:Ca@Co00001OnRTlD00ol0
003o/9g3ok2M``0Aok2M``03o`000?nmZ<Co_JS4017o_JS400?o0000olZfaoo:]/L04_o:]/L00ol0
003oeLO<omG7c003omG7c0;o00003?oMaL400ol0003oj]o7on[Oa`03on[Oa`04o`000?odg[Gom=je
o`0000Gom=je00Go0000on_eY?l0003ofM]Vo`00000booooo`03o`000?oooooooooo00[ooooo000H
ooooo`;o0000Aoooool2o`0000So53Bb00?o0000ofa_a?m/Kl@03om/Kl@01?l0003oRgfno`000?l0
000Aoi2:b@03o`000?nRTlGoXY?500KoXY?50ol00009oj:Ca@03o`000?n`WL?o/9g3017o/9g300?o
0000okfXa?nmZ<@04OnmZ<@00ol0003ob[K7olZfa`0BolZfa`03o`000?oEalcoeLO<00GoeLO<00?o
0000omg5`OoMaL402?oMaL400ol0003oj]o7on[Oa`05on[Oa`04o`000?odg[Gom=jeo`0000?om=je
00?o0000on_eY?l000000_oIffH00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04Kooooo0_l00008oa@d/P03o`000?m/KlCoK6o4013oK6o400?o
0000oi2:bOn@R/T04_n@R/T00ol0003oXY?5oj:Ca@02oj:Ca@?o00002_nRTlDLo`0000ko_JS400?o
0000olZfaoo:]/L04Oo:]/L00ol0003oeLO<omG7c007omG7c003o`000?oMaL7ogLG100OogLG100?o
0000on[OaooZglL01OoZglL01Ol0003om=jeooCN]Oodg[Go000000;om=je00?o0000on_eY?l00000
0_oIffH00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`000?oo
oooooooo04Kooooo0_l00008oa@d/P;o00004Om/Kl@00ol0003oT8[9oi2:b@0Boi2:b@03o`000?nR
TlGo000000;o00002_nRTlD3o`0000;oY9g?00?o0000ok2UcOn`YLd04On`YLd00ol0003o^jo>ok^_
cP03ok^_cPWo00001?nmZ<@00ol0003ob[K7olZfa`0BolZfa`03o`000?oEalcoeLO<00SoeLO<00?o
0000omg5`OoMaL401OoMaL400ol0003oj]o7on[Oa`07on[Oa`04o`000?odg[Gom=jeooCN]@;o0000
0_o[mJ@00ol0003ofM]Vo`00000cooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oo
oooooooo04Sooooo00?o0000oa@d/_lD=;801_lD=;800ol0003o>U_9o`00000?ofa_a003o`000?mi
P]3o0000017oT8[91?l00009oj:Ca@Co00001OnTWLl00ol0003o/:G=ok2Uc@0Aok2Uc@03o`000?nk
[lko^jo>00co^jo>1Ol0000ColZfa`03o`000?oEalcoeLO<00[oeLO<0_l00004omg5`@03o`000?oZ
glOoj]o700Soj]o700Co0000ooCN]Oodg[Gom=je0_l00002on_eY003o`000?oIffKo000003?ooooo
00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0B?ooool00ol0003o53Bboa@d
/P05oa@d/P05o`000?ljFlWo>U_9ocYKbOl000003Om/Kl@01Ol0003oNH;@ogV2d?miP]3o000000go
T8[90ol00003oi2:b@03o`000?nRTlGoXY?500?oXY?51?l0000:ojBMc`03o`000?n`YLgo/:G=013o
/:G=00?o0000ok^_c_nk[lh04?nk[lh00ol0003oa;[@o`000002o`0000kob[K700?o0000omG7c?oE
al`03OoEal`01Ol0003ogLG1omg5`OoMaL7o000000_oj]o700?o0000ooCN]Oodg[D00_l00002on_e
Y003o`000?oIffKo000003?ooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000oooooooo
ool0BOooool00ol0003o53Bboa@d/P04oa@d/P03o`000?ljFlWo>U_900;o>U_900?o0000ofa_a?m/
Kl@02Om/Kl@00ol0003oNH;@ogV2d003ogV2d003o`000?n@R/WoT8[900OoT8[90ol00006oi2:b@03
o`000?nRTlGoXY?500?o00003_nTWLl00ol0003o/:G=ok2Uc@0@ok2Uc@03o`000?nk[lko^jo>00oo
^jo>00?o0000olBjd?o4^]000oo4^]03o`0000_ob[K700?o0000omG7c?oEal`03_oEal`00ol0003o
gLG1o`00000<on[Oa`03o`000?odg[Go000000;ojoFT00Co0000on_eY?l0003o0000=Oooool00ol0
003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`19ooooo`03o`00POl0003o53Bb00Co
53Bb00?o0000ocYKbOljFlT00oljFlT00ol0003oK6o4ofa_a007ofa_a003o`000?miP]3oNH;@00Go
NH;@00?o0000oi2:bOn@R/T00on@R/T3o`0000WoT8[90ol0000AojBMc`03o`000?n`YLgo/:G=013o
/:G=00?o0000ok^_c_nk[lh03onk[lh00ol0003oa;[@olBjd006olBjd0;o00002?o:]/L00ol0003o
eLO<omG7c00@omG7c003o`000?oZglOoj]o700_oj]o700?o0000ooCN]Ol000000oo[mJ@3o`0003Go
oooo00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0B_ooool00ol0003o53Bb
oa@d/P03oa@d/P03o`000?ljFlWo>U_900?o>U_900?o0000ofa_a?m/Kl@01_m/Kl@00ol0003oNH;@
ogV2d007ogV2d0Go00002_n@R/T2o`000003oiFGdol0003oY9g?01;oY9g?00?o0000ok2UcOn`YLd0
3on`YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@00Woa;[@0ol00005olZfa`03o`00
0?oEalcoeLO<013oeLO<00?o0000on[OaooZglL03?oZglL00ol0003ojoFTon_eY003on_eY0;o0000
=Oooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1:ooooo`;o00001?lD
=;800ol0003o>U_9ocYKb@04ocYKb@03o`000?m/KlCoK6o400GoK6o400?o0000ogV2d?miP]001Omi
P]03o`0000coT8[90_l00004oiFGd`03o`000?nTWLooY9g?013oY9g?00?o0000ok2UcOn`YLd03on`
YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@00coa;[@0ol000000oo:]/Oo0000omG7
c00AomG7c003o`000?oNgMCo000000goj]o700?o0000on_eY?o[mJ@00_o[mJ@2o`0003Kooooo00?o
0000ooooooooool02Oooool001Oooooo0_l0001<ooooo`03o`00POl0003o53Bb00;o53Bb00?o0000
ocYKbOljFlT01OljFlT00ol0003oK6o4ofa_a003ofa_a003o`000?miP]3oNH;@00?oNH;@0ol00003
ogV2d003o`000?n@R/WoT8[900OoT8[90_l00007oiFGd`03o`000?nTWLooY9g?00ooY9g?00?o0000
ok2UcOn`YLd03_n`YLd00ol0003o^jo>ok^_cP0?ok^_cP03o`000?o4^]3oa;[@00ooa;[@0_l0000A
omG7c004o`000?oNgMCog]gDo`0000coj]o70_l00004on_eY0?o0000=Oooool00ol0003ooooooooo
o`09ooooo`005_ooool00ol0003oooooooooo`1<ooooo`;o00000olD=;800ol0003o>U_9ocYKb@06
ocYKb@05o`000?m/KlCoK6o4ofa_a?l000000omiP]03o`0000OoNH;@00?o0000oi2:bOn@R/T01On@
R/T00ol0003oUIOCoiFGd`07oiFGd`03o`000?nTWLooY9g?00ooY9g?00?o0000ok2UcOn`YLd03_n`
YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@013oa;[@00?o0000olg8e_l000003ooE
al`00ol0003og]gDomkMe002omkMe003o`000?oZglOoj]o700Soj]o700?o0000onSjb?l000001?o[
mJ@2o`000003ooooool0003ooooo03?ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0COooool01?l0087o0000oa@d/_l0000:ocYKb@03o`000?m/KlCo000000Co00002omi
P]000ol0003oT8[9oi2:b@02oi2:b@;o00002onEUm<00ol0003oY9g?ojBMc`0?ojBMc`03o`000?n`
YLgo/:G=00go/:G=00?o0000ok^_c_nk[lh03_nk[lh00ol0003oa;[@olBjd00?olBjd005o`000?o=
b=KocLSFolg8e_l000003OoEal`00ol0003og]gDomkMe003omkMe003o`000?oZglOoj]o700Ooj]o7
00?o0000onSjb?l000001Oo[mJ@01Ol0003ooooooooooooooooo000003?ooooo00?o0000oooooooo
ool02Oooool001Kooooo00?o0000ooooooooool0COooool2o`000003oa@d/_l0003o>U_900Wo>U_9
0ol0000@ogV2d004o`000?n@R/Wo0000o`0000goUIOC00?o0000ojBMconTWLl03onTWLl00ol0003o
/:G=ok2Uc@0=ok2Uc@03o`000?nk[lko^jo>00go^jo>00?o0000olBjd?o4^]003oo4^]000ol0003o
cLSFolg8eP03olg8eP;o00002_oEal`00ol0003og]gDomkMe005omkMe003o`000?oZglOoj]o700Go
j]o700Co0000onSjb?oXn/So00001Oo[mJ@00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0COooool01?l0003o
0021o`000?l00007ocYKb@?o000000Co>U_9oeIhfOmFN=Wo00004?miP]000ol0003oUIOCoiFGd`0>
oiFGd`03o`000?nTWLooY9g?00koY9g?00?o0000ok2UcOn`YLd03On`YLd00ol0003o^jo>ok^_cP0=
ok^_cP03o`000?o4^]3oa;[@00koa;[@00?o0000olg8e_o=b=H01_o=b=H00ol0003oeLO<omG7c006
omG7c003o`000?oNgMCog]gD00Kog]gD00?o0000on[OaooZglL01?oZglL01Ol0003oj?[8onSjb?oX
n/So000000CojoFT00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo000Fooooo`03o`000?oooooooooo04kooooo00?o0000o`00POl000001?ljFlT3
o`0000Co>U_900Co0000oeIhfOmFN=Wo00003omiP]000on4T][o0000oiFGd`0?oiFGd`03o`000?nT
WLooY9g?00koY9g?00?o0000ok2UcOn`YLd03?n`YLd00ol0003o^jo>ok^_cP0<ok^_cP03o`000?o4
^]3oa;[@00koa;[@00?o0000olg8e_o=b=H02?o=b=H2o`0000GoeLO<00?o0000omkMe?oNgM@02?oN
gM@00ol0003oj]o7on[Oa`03on[Oa`05o`000?oXn/Soj?[8onSjb?l000000oo[mJ@00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool001Kooooo00?o
0000ooooooooool0C_ooool00ol0003o0021o`0f_004o`0000Oo>U_900Go0000oeIhfOmFN=WoEWSI
o`00000=ogV2d004o`000?n4T][oQ9;Jo`0000ooUIOC00?o0000ojBMconTWLl03?nTWLlFo`0000[o
^jo>00?o0000olBjd?o4^]003Oo4^]000ol0003ocLSFolg8eP0;olg8eP05o`000?oEalcoeLO<omG7
c?l000002ooNgM@00ol0003oj]o7on[Oa`02on[Oa`03o`000?oXn/Soj?[800;oj?[800Go0000on_e
Y?o[mJCojoFTo`000008ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
01Gooooo00?o0000ooooooooool0Coooool3o`000003o`0f_?l0003o>U_900Oo>U_900?o0000oeIh
fOmFN=T00omFN=T00ol0003oNH;@ogV2d009ogV2d003o`000?n4T][oQ9;J00;oQ9;J00?o0000oiFG
donEUm<03OnEUm<00ol0003oY9g?ojBMc`08ojBMc`?o00000_nUZ=T00ol0003o[ZkGojj^e`0<ojj^
e`03o`000?ng]MSo]kGH00;o]kGH1ol00003ok^_cP03o`000?o4^]3oa;[@00goa;[@00?o0000olg8
e_o=b=H03?o=b=H00ol0003oeLO<o`00000=omkMe004o`000?oZglOoj]o7o`0000Goj?[800Co0000
on_eY?o[mJCo00002_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`?o0000C?ooool3o`000006ooooool0003o0021o`000?l0=[co00001oljFlT00ol0003oEWSI
oeIhf@04oeIhf@03o`000?miP]3oNH;@00OoNH;@00?o0000ohBBf_n4T]X01?n4T]X00ol0003oUIOC
oiFGd`0<oiFGd`03o`000?nTWLooY9g?00CoY9g?1?l00005ojFXf@03o`000?n^[]Oo[ZkG00co[ZkG
00?o0000okNef?ng]MP02Ong]MP5o`0000goa;[@00?o0000olg8e_o=b=H03_o=b=H00ol0003og]gD
omkMe00<omkMe003o`000?oZglOo000000Koj?[800?o0000on_eY?l000003?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Wooooo0ol0
0005ooooo`05o`000?l0087o0000o`0f_?l000001_ljFlT00ol0003oEWSIoeIhf@05oeIhf@03o`00
0?miP]3oNH;@00GoNH;@00?o0000ohBBf_n4T]X01_n4T]X00ol0003oUIOCoiFGd`0<oiFGd`03o`00
0?nTWLooY9g?00?o00002_nUZ=T00ol0003o[ZkGojj^e`0;ojj^e`03o`000?ng]MSo]kGH00_o]kGH
00?o0000okjnf_nn_]X00ol00009olBjd003o`000?o=b=KocLSF00gocLSF00?o0000om;Jg_l00000
3ooNgM@00ol0003oj?[8onSjb004onSjb003o`000?o[mJCo000000kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002?oo
ool00ol0003o0021o`000002o`0f_003o`000?ljFlWo>U_900?o>U_900?o0000oeIhfOmFN=T01_mF
N=T00ol0003oNH;@ogV2d003ogV2d003o`000?n4T][oQ9;J00SoQ9;J00?o0000oiFGdonEUm<02onE
Um<3o`0000goYJSI00?o0000ojj^eon^[]L02_n^[]L00ol0003o]kGHokNef00;okNef003o`000?nn
_][o_[kJ00Co_[kJ0ol00005olBjd003o`000?o=b=KocLSF00gocLSF00Go0000om;Jg_oBf]kod][N
o`00000<omkMe003o`000?oNmMco000000Koj?[800?o0000on_eY?l000003_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo0ol0
000=ooooo`03o`000?l0087o000000;o03Jl00?o0000ocYKbOljFlT00_ljFlT00ol0003oEWSIoeIh
f@07oeIhf@05o`000?miP]3oNH;@ogV2d?l000003?n4T]X00ol0003oUIOCoiFGd`08oiFGd`;o0000
00?oVZCLo`000?nUZ=T03OnUZ=T00ol0003o[ZkGojj^e`0:ojj^e`03o`000?ng]MSo]kGH00_o]kGH
00?o0000okjnf_nn_]X01onn_]X3o`000003olBjd?l0003ocLSF00kocLSF00?o0000om;Jg_oBf]h0
0_oBf]h00ol0003og]gDomkMe009omkMe004o`000?oNmMcog_GLo`0000Koj?[80_l0000@ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool01oooool001Gooooo00?o0000ooooooooool0
?oooool3o`00017ooooo00?o0000o`00POl000000_l0=[`01Ol0003o>U_9ocYKbOljFlWo000000[o
EWSI00?o0000ogV2d?l000003_n4T]X00ol0003oUIOCoiFGd`05oiFGd`;o00001?nJY=`00ol0003o
YJSIojFXf@0;ojFXf@03o`000?n^[]Oo[ZkG00[o[ZkG00?o0000okNef?ng]MP02_ng]MP00ol0003o
_[kJokjnfP0;okjnfP03o`000?o=b=KocLSF00gocLSF00?o0000om;Jg_oBf]h01?oBf]h00ol0003o
g]gDomkMe007omkMe005o`000?oNmMcog_GLomkeg?l000001_oXn/P00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool0?Oooool3o`0001Gooooo0_l00003o`0f_003o`000?ljFlWo000000coEWSI0_l0000?ohBBfP03
o`000?nEUm?oUIOC00;oUIOC0_l00007oiZTg003o`000?nUZ=WoYJSI00_oYJSI00?o0000ojj^eon^
[]L02On^[]L00ol0003o]kGHokNef00:okNef003o`000?nn_][o_[kJ00_o_[kJ00?o0000ol?9gol0
00002oo=b=H2o`0000Ood][N00?o0000omkMe?oNgM@01OoNgM@2o`0000?og_GL00?o0000onSjb?oX
n/P01?oXn/P2o`0001?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0iooooo`Co00006Oooool00ol0087o0000o`0f_002o`0f_0;o0000
3?mFN=T2ofb?h`03o`000?n4T][oQ9;J00goQ9;J00Co0000oiFGdol0003o00002_nJY=`00ol0003o
YJSIojFXf@0:ojFXf@03o`000?n^[]Oo[ZkG00Wo[ZkG00?o0000okNef?ng]MP02Ong]MP00ol0003o
_[kJokjnfP0;okjnfP04o`000?o3bMoo`lWOol?9g`;o00002?o=b=H00ol0003od][Nom;JgP08om;J
gP03o`000?oNgMCog]gD00?og]gD00?o0000omkeg?oNmM`00ooNmM`00ol0003oj?[8onSjb003onSj
b0;o00005Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03
o`000?oooooooooo03Kooooo0ol0000Mooooo`;o00001?l0=[`2o`0000_oEWSI00Co0000ofb?hom/
Sn?o00003on4T]X2o`0000_oVZCL00?o0000ojFXfOnUZ=T02_nUZ=T00ol0003o[ZkGojj^e`09ojj^
e`03o`000?ng]MSo]kGH00Wo]kGH00?o0000okjnf_nn_]X02_nn_]X00ol0003o`lWOol?9g`04ol?9
g`03o`000?o=b=KocLSF00CocLSF00?o0000om;Jg_oBf]h02OoBf]h00ol0003og]gDomkMe002omkM
e003o`000?oNmMcog_GL00Cog_GL00?o0000onSjb?oXn/P00_oXn/P2o`0001Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Qooooo`;o
00000ol0=[`2oaiYg003o`000?mFN=WoEWSI00OoEWSI00?o0000ofb?hom/Sn<00_m/Sn<2o`0000co
Q9;J00Co0000ohfQh_n=XN;o00002onJY=`00ol0003oYJSIojFXf@09ojFXf@03o`000?n^[]Oo[ZkG
00So[ZkG00?o0000okNef?ng]MP02Ong]MP00ol0003o_[kJokjnfP0:okjnfP03o`000?o3bMoo`lWO
00Ko`lWO0_l00003olg8eP03o`000?oBf]kod][N00_od][N00Co0000omkMe?oNgMCo00001ooNmM`0
1?l0003oj?[8onSjb?oXn/P2o`0001Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00009Oooool00ol0003o03Jlo`0f_002
o`0f_0;o7VWL00?o0000oeIhfOmFN=T01_mFN=T00ol0003oK8oSofb?h`04ofb?h`03o`000?n4T][o
Q9;J00SoQ9;J00?o0000ohfQh_n=XN800_n=XN800ol0003oVZCLoiZTg009oiZTg003o`000?nUZ=Wo
YJSI00SoYJSI00?o0000ojj^eon^[]L02?n^[]L00ol0003o]kGHokNef009okNef003o`000?nn_][o
_[kJ00Wo_[kJ00?o0000ol?9goo3bMl02Oo3bMl00ol0003ocLSFo`00000>om;JgP03o`000?oNgMCo
000000Sog_GL00?o0000onSjb?oXn/P00_l0000Jooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
02cooooo1?l0000Yooooo`05o`000?l0=[co03Jlo`0f_?l000000_lNJM`2o`0000KoEWSI00?o0000
ofb?hom/Sn<01Om/Sn<00ol0003oQ9;JohBBfP06ohBBfP03o`000?n=XN;oSJ7R00CoSJ7R00?o0000
oiZTg?nJY=`02?nJY=`00ol0003oYJSIojFXf@09ojFXf@03o`000?n^[]Oo[ZkG00;o[ZkG2Ol00007
okNef003o`000?nn_][o_[kJ00Wo_[kJ00?o0000ol?9goo3bMl02oo3bMl00ol0003od][Nom;JgP0>
om;JgP03o`000?oNmMcog_GL00Oog_GL00Co0000onSjb?l0003o00007?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:_ooool3o`0002kooooo00Go0000o`0f_?l0=[co03Jlo`000003oaiYg003o`000?mF
N=WoEWSI00?oEWSI00?o0000ofb?hom/Sn<01_m/Sn<2o`0000GoQ9;J00?o0000ohfQh_n=XN801_n=
XN800ol0003oVZCLoiZTg008oiZTg003o`000?nUZ=WoYJSI00KoYJSI1ol00005oj^ghP04o`000?na
_>;o/KcRok6lhPGo00000_ng]MP00ol0003o_[kJokjnfP08okjnfP03o`000?o3bMoo`lWO00[o`lWO
00?o0000olKFiOl000003_oBf]h00ol0003odNcWo`000008omkeg005o`000?oXn/So0000ojS/XOl0
00007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0003;ooooo00Co0000o`0f_?l0=[co
00001?lNJM`2o`0000?oEWSI00?o0000ofb?hom/Sn<02?m/Sn<01Ol0003oQ9;JohBBf_n4T][o0000
00[oSJ7R00?o0000oiZTg?nJY=`02?nJY=`00ol0003oYJSIojFXf@05o`0000;oYK?S00?o0000oj^g
h_n[]n801on[]n800ol0003o/KcRok6lhP06ok6lhP?o00002Onn_]X00ol0003o`lWOol?9g`09ol?9
g`;o00000oo6e^D00ol0003od][Nom;JgP09om;JgP;o00000_oAk>L00ol0003og_GLomkeg006omke
g0;o000000?oZ>bQo`000?ooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool3o`0003Ko
oooo00Co0000o`0f_?l0=[co00001OlNJM`00ol0003oEWSIo`00000<ofb?h`03o`000?n4T][o0000
00coSJ7R00?o0000oiZTg?nJY=`01onJY=`3o`0000SoYK?S00?o0000oj^gh_n[]n801_n[]n800ol0
003o/KcRok6lhP07ok6lhP03o`000?ne`^Co000000;o00001Onn_]X00ol0003o`lWOol?9g`09ol?9
g`03o`000?o6e^Goa]KU00?oa]KU00?o0000om;Jg_oBf]h01ooBf]h2o`0000CodNcW00?o0000omke
g?oNmM`01OoNmM`2o`000003ojS/XOl0003ooooo01oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023o
oooo1?l0000jooooo`03o`000?l0=[co000000Ko7VWL00?oEWSIo`000?m/Sn<03?m/Sn<2o`0000go
SJ7R00?o0000oiZTg?nJY=`01?nJY=`2o`0000;oWK7U00?o0000ojFchonU/n<01_nU/n<00ol0003o
ZkORoj^ghP06oj^ghP03o`000?na_>;o/KcR00Ko/KcR00?o0000okG2i?ne`^@00one`^@3o`000003
okjnf_l0003o`lWO00Wo`lWO0_l00007olKFi@03o`000?oBf]kod][N00God][N00?o0000om7/iooA
k>L01?oAk>L00ol0003og_GLomkeg004omkeg004o`000?nno]Go0000o`0002;ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo0ol0000oooooo`;o00001olNJM`2o`0000coK8oS00Co0000ogjQjOl0
003o00003?n=XN800ol0003oVZCLoiZTg002oiZTg003o`000?nM/NGoWK7U00?oWK7U00?o0000ojFc
honU/n<01OnU/n<00ol0003oZkORoj^ghP06oj^ghP03o`000?na_>;o/KcR00Go/KcR00?o0000okG2
i?ne`^@01one`^@00ol0003o`lWOol?9g`08ol?9g`03o`000?o6e^Goa]KU00Ooa]KU00?o0000om;J
g_oBf]h00ooBf]h2o`0000OodNcW00?o0000omkeg?oNmM`00_oNmM`2o`000003okkneOl0003o0000
02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01[ooooo0ol00013ooooo`03o`0f_?l0003o7VWL00Go
7VWL00Co0000odb<jol0003o00002_m/Sn<01?l0003oOZ7YogjQjOmnXNT2o`0000_oSJ7R00Co0000
oiZTg?l0003o00001onM/ND00ol0003oYK?SojFch`05ojFch`03o`000?n[]n;oZkOR00CoZkOR00?o
0000ok6lh_na_>801_na_>800ol0003o]L;TokG2i006okG2i0?o^<WW00?o0000ol?9goo3bMl01Oo3
bMl00ol0003oa]KUolKFi@09olKFi@03o`000?oBf]kod][N00;o00002?oAk>L00ol0003og_GLomke
g002omkeg003o`000?nno]Go__kE00;o00009_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000Aoooool0
0ol0003o7VWLoaiYg005oaiYg003o`000?m<S>_oC8c[00;o00002?m/Sn<00ol0003oOZ7YogjQj@03
ogjQj@;o00002_n=XN82o`0000WoWK7U00?o0000ojFchonU/n<01?nU/n<00ol0003oZkORoj^ghP04
oj^ghP03o`000?na_>;o/KcR00Go/KcR00?o0000okG2i?ne`^@01One`^@00ol0003o^<WWokS9i`03
okS9i`;o00000oo3bMl2o`0000coa]KU00?o0000om;Jg_l000002_oAk>L01Ol0003og_GLomkeg?oN
mMco000000;o__kE0_l0000Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool001;ooooo00?o0000ooooooooool05?ooool4o`0004_ooooo0_l00005oaiYg003o`000?m<S>_o
C8c[00;oC8c[0ol00004ofb?h`03o`000?mnXNWoOZ7Y00KoOZ7Y0_l00007ohfQhP03o`000?nE/>Wo
UK3Y00;o00002?nM/ND00ol0003oYK?SojFch`04ojFch`03o`000?n[]n;oZkOR00?oZkOR00?o0000
ok6lh_na_>801Ona_>800ol0003o]L;TokG2i004okG2i003o`000?nhbNOo^<WW00Ko^<WW00?o0000
ol?9gol000003oo6e^D00ol0003odNcWom7/i`09om7/i`04o`000?oNmMco0000o`0000;o__kE0_l0
000Yooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000
ooooooooool04Oooool3o`00057ooooo0_l00004oaiYg003o`000?m<S>_oC8c[00CoC8c[0_l00002
ofb?h`03o`000?mnXNWoOZ7Y00SoOZ7Y0_l00004ohfQhP03o`000?nE/>WoUK3Y00?oUK3Y00?o0000
oifaiOnM/ND01_nM/ND00ol0003oYK?SojFch`03ojFch`03o`000?n[]n;oZkOR00?oZkOR00?o0000
ok6lh_na_>801?na_>800ol0003o]L;TokG2i003okG2i0;o00002_nhbNL00ol0003oa]KUolKFi@0:
olKFi@?o000000?oa>;]o`000?oAk>L02_oAk>L2o`0000Co__kE00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo
00kooooo0ol0001Eooooo`03o`1>`ol0003o7VWL00;o7VWL00?o0000odb<jom<S>/01_m<S>/00ol0
003oK8oSo`00000<ogjQj@;o000000?oSJ7Ro`000?nE/>T01_nE/>T2o`0000OoWK7U00?o0000ojFc
honU/n<00_nU/n<00ol0003oZkORoj^ghP03oj^ghP03o`000?na_>;o/KcR00?o/KcR00?o0000okG2
i?ne`^@00one`^@00ol0003o^<WWokS9i`08okS9i`03o`000?nid>co000000Woa]KU0ol00004olCR
k@03o`000?oAk>OodNcW00WodNcW00?o0000okkneOnno]D00_nno]D00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooooooo
ool02oooool3o`0005Wooooo00Go04k3o`000?l0003o7VWLo`00000:odb<j`;o00003OmnXNT2o`00
00WoUK3Y0_l00006oifai@03o`000?nU/n?oYK?S00_o00000_na_>800ol0003o]L;TokG2i002okG2
i003o`000?nhbNOo^<WW00Ko^<WW0_l00004okW@k003o`000?o6e^Goa]KU00?oa]KU0ol00007olCR
k@03o`000?oAk>OodNcW00GodNcW0ol000000oo0nNgo0000okkne@02okkne@03o`000?oooooooooo
02gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`Co0000GOooool01Ol0003o04k3o`000?lNJMco000000WoC8c[00?o0000ofbS
lOl000000_l0000:ogjQj@03o`000?n=/Nko000000;o00002?nE/>T00ol0003oWK7Uoifai@03oifa
i@?o00000_nS_nd00ol0003oY/7]ojK1k@02ojK1k@04o`000?nX`ngoZ<?]ojS3k@Co00000_ne`^@0
0ol0003o^<WWokS9i`04okS9i`?o00001onid>`00ol0003oa]KUo`000002o`0000Woa>;]00?o0000
om7/iooAk>L00ooAk>L3o`0000?o`?W]00Go0000okkneOnno]Go__kEo`00000aooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3
o`0006;ooooo00Co0000o`1>`ol0C/?o00002_m<S>/01?l0003oK:?aofbSlOm/Xo43o`0000KoOZ7Y
00?o0000ohfak_n=/Nh00on=/Nh3o`0000KoUK3Y0_l000000onM/NGo0000o`000002oj2nkP05o`00
0?nS_ngoXko]oj>okOl000000onV`Nd00ol0003oZ<?]ojS3k@02ojS3k@03o`000?nYaNkoZLG^00;o
00001OnhbNL2o`0000_o^M3/00?o0000olCRkOo4h^d02_o4h^d01?l0003odNcWom7/iooAk>L2o`00
00Go`?W]00?o0000okkneOnno]D00_l0000cooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01Oooool0017ooooo00?o0000ooooooooool00_ooool3o`0006Kooooo00?o0000o`1>`ol0
C/<00ol00007odb<j`03o`000?m/Xo7oK:?a00CoK:?a0_l00004ogjQj@03o`000?n=/NkoSK7^00Ko
SK7^0ol00005oiF`j@;o00001?nP_^h01?l0003oXko]oj>okOl00003ojK1k@05o`000?nX`ngoZ<?]
ojS3kOl000000_nYaNh01_l0003oZ/O_oj[7konZanoo0000okS9i`;o00002Onid>`3o`000003okOG
lOl0003oa>;]00_oa>;]1?l00006ol3ik@04o`000?nno]Go0000o`0003Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0006[ooooo
00Go0000o`1>`ol0C/?o04k3ob:6jP03o`0000GoC8c[00?o0000ofbSlOm/Xo401Om/Xo42o`0000;o
OZ7Y00?o0000ohfak_n=/Nh02On=/Nh3o`000004oiF`jOl0003oWKk`oifnl0;o00000onP_^h01?l0
003oXko]oj>okOl00002ojK1k@05o`000?nX`ngoZ<?]o`000?nYaNh00_l00004oj[7k`;o00002?ni
d>`3o`0000Co]mOa00?o0000olCRkOo4h^d02_o4h^d00ol0003o`?W]ol3ik@06ol3ik@Co0000=ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo000Aooooo`;o0000K_ooool0
1Ol0003o04k3o`1>`ol0C/?o000000;o8XKZ0ol00002odb<j`03o`000?m/Xo7oK:?a00SoK:?a1?l0
000<ohfakP?o00000onM__02o`0000;oX;k^00Go0000oj>okOl0003oY/7]o`000002ojS3k@03o`00
0?nYaNko000000?oZ/O_0ol000000onZb_7o0000okW@k004okW@k0?o00001ongeo400ol0003oa>;]
olCRk@03olCRk@Go00000_nijoD00ol0003o`?W]ol3ik@05ol3ik@?o0000>_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06cooooo00Go
0000o`1>`ol0C/?o04k3o`000004ob:6jP?o00002_m/Xo401?l0003oQKCdohFdm?n5]?@5o`0000Oo
SK7^00?o0000oi^olOnK_o400ol00002oifnl0;o000000GoX;k^o`000?l0003oY/7]o`000002ojS3
k@;o000000CoZ/O_o`000?l0003o00001OnZb_400ol0003o^M3/o`000002o`0000[o]mOa00?o0000
olCRkOl000000ol00006okW[m@03o`000?o0nNgo`?W]00Go`?W]0ol0000looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01?ooool001Cooooo0_l0001]ooooo`;o00000_l0C/<00ol0
003o8XKZob:6jP04ob:6jP?o00002?m/Xo400ol0003oQKCdohFdm005ohFdm0Go000000?oSK7^o`00
0?nK_o401OnK_o49o`000003ojS3kOl0003o000000;o00001OnZb_45o`0000go]mOa0_l00009okW[
m@03o`000?o0nNgo`?W]00Co`?W]0ol0000oooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01?ooool001Kooooo00?o0000ooooool00000K?ooool2o`000003o`1>`ol0003o8XKZ00Go
8XKZ00?o0000oeVWmol000000ol00004ofbSl@03o`000?n5]?CoQKCd00[oQKCd2_l00002oi^ol@oo
00001?nXc?801?l0003o]mOaokOGlOngeo47o`0000?o/=cf00?o0000okW[mOnijoD01onijoD00ol0
003o`?W]ol3ik@02ol3ik@Co0000@Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Cooooo000Gooooo`;o0000K_ooool3o`0000Ko8XKZ00?o0000oeVWmomIYoL00_mIYoL5o`0000go
QKCd00?o0000oiW1lonI`O<01OnI`O<Jo`0000Wo/=cf00?o0000okW[mOnijoD02?nijoD00ol0003o
`?W]o`000005o`0004?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
6?ooool2o`0006oooooo0_l00006ob:6jP03o`000?mIYoOoFJOg00GoFJOg3_l000000on5]?Co0000
o`000005o`000003oiO3mOl0003o000000?o000000?oV<Oho`000?l000002Ol00003ojK=m003o`00
0?n`g?Ko/=cf00[o/=cf00?o0000okW[mOnijoD02?nijoD3o`0000;oT_3S0_l00016ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool001[ooooo00?o0000ooooooooool0K_oo
ool3o`0000Co8XKZ00?o0000oeVWmomIYoL01omIYoL00ol0003oO[Siogjhn@0:ogjhn@03o`000?nG
`oGoUl?e00Co00000_nGaOL2o`000005oiS7n?l0003o0000oic<n?l000000_nPcOL2o`0000CoXlkf
2Ol00006ok3LmP03o`000?nijoGo^N_e00;o^N_e1ol00003oi;`h`?o0000B?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0KOoo
ool01?l0O]Oo0000o`000?l00002ob:6jP03o`000?mIYoOoFJOg00OoFJOg00?o0000ogjhnOmn^?T0
2_mn^?T2o`0000CoUlGg0_l00002oiS7n003o`000?nJb_So000000;oW<ch00Co0000oj3=monPcOOo
X<gg0ol000000onSc_Ko0000ojKNn`07ojKNn`Co000000?o/=cfo`000?l000001?l00003oj?]n@;o
00001?nBl><2o`0004_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00
7Oooool2o`00077ooooo00Go07kGo`000?l0003o8XKZo`000009oeVWm`04o`000?mn^?WoO[Siogjh
n@Go00001Omi__`2o`000003oiO5mol0003oV<Oh00?oV<Oh00Co0000oi[:n?nJb_So00000_nLc?P0
0ol0003oX<ggoj3=m`02oj3=m`Co00002_nVg_/00ol0003oXngioj?]n@06oj?]n@;o00001?nBl><2
o`0004gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007_ooool00ol0
003oooooooooo`1`ooooo`;o000000?o07kGo`000?l000003?l0000<ogVno0?o00000_nHaoP01Ol0
003oV/[hoi[:n?nJb_So000000?oW<ch00Co0000oj3=mol0003o00001?nHg?h3o`0000GoY]kk0_l0
0008oj?]n@03o`000?nBl>?oT_3S00?oT_3S0_l0001?ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00oooool001oooooo0_l0001`ooooo`03o`000?oooooooooo00;o000000?o07kG
o`000?l000002?m8[?P3o`0000KoNKkl0ol00004ogW6o`go00002?nHg?h2o`0000;oY]kk00?o0000
oj?]nOnSkOT01_nSkOT2o`000003oi;`hol0003o000000?o0000D_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool00oooool2o`000003o`1neol0003o000000SoB:ch0_l000001?mi__co0000o`000?l00008
ogW6o`03o`000?moc_ooOlko00;oOlko00?o0000oh_Foon;e_l01?n;e_l2o`0000OoV=cn4Ol0001F
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001/oooo
o`03o`000?oooooooooo00Gooooo1_l00004odR/n004o`000?m8[?SoB:cho`0000[oNLKo00?o0000
ogo>oomoc_l00omoc_l00ol0003oRmKooh_Fo`06oh_Fo`03o`000?nHg?koV=cn00Co00001on3hoL6
o`0005_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`009?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo00?o07Zko`000?l000001?l00006od6d
m0Go00000_mia_l00ol0003oOlkoogo>o`05ogo>o`03o`000?n;e_ooRmKo00CoRmKo1Ol00007oh?S
m`Ko0000Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o
0000J_ooool00ol0003oooooooooo`0<ooooo`03o`000?l0N[_o000000Co00001om1]?@7o`0000?o
Olko00?o0000oh_Fool000001?l00005of7BlP?o000000?oPn?go`000?l000000ol0001Sooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0@ooooo`;o000000?o07Zko`000?l000000_l00002od6dm003o`00
0?m9`O7oBL7a00GoBL7a1Ol0000:of7BlPGo0000J?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo000Xooooo`03o`000?oooooo000006Kooooo00?o0000ooooooooool05?oo
ool5o`0000GoBL7a0_l00004odW1l@03o`000?mQd_;oHM;b00;oHM;b1ol0001^ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04
ooooo`;o0000I_ooool00ol0003oooooooooo`0Nooooo`;o4@002Ol0001fooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?o
oooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0023ooooo00?o
0000ooooooooool03?ooool2o`00063ooooo00?o0000ooooooooool0X_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo00gooooo0_l0001O
ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01
ooooo`008?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Nooooo`03
oeEEEOmVIVKo000001;ooooo0_l000000ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
000fooooo`;o0000F?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003Sooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00>Oooool0
1?l0003oooooooooool0001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool02Ooo
ool1o`00007ooooo0Oooool003[ooooo0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000
ooooooooool02?ooool1o`00007ooooo0Oooool003cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o
0000DOooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo000oooooo`03o`000?oooooo000004kooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool1ooooo`00@?ooool2o`0004kooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o0000
ooooooooool0[_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00
007ooooo0014ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`00A_ooool2o`0004Sooooo00?o0000ooooooooool0
/?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`0004Oooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool00016ooooo`03o`000?oooooooooo
0;;ooooo00Go0000ooooooooooooooooo`000001ooooo`00:_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o0000@oooool00ol0003oooooooooo`2c
ooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0/ooo
ool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0]?ooool00ol0003oooooooooo`01o`000000<_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool02?ooool2o`00043ooooo00?o0000ooooooooool0]Oooool1o`00007o
oooo0Ol0000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[o
oooo0_l0000nooooo`03o`000?oooooooooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00002_ooool2o`0003gooooo00?o0000ooooooooool0]Oooool3o`000000
Doooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool0/?ooool5o`0000?o
oooo001Dooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0[?ooool4o`0000So
oooo001Eooooo`?o0000>?ooool00ol0003oooooooooo`2Xooooo`Co00003?ooool005Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0000e
ooooo`03o`000?oooooooooo0:3ooooo1?l0000Eooooo`00F_ooool00ol0003oooooo`00000boooo
o`03o`000?oooooooooo09cooooo1?l0000Iooooo`00Foooool2o`0003;ooooo00?o0000oooooooo
ool0Uoooool5o`0001gooooo001Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Toooool4o`0002;ooooo001Nooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0
S_ooool5o`0002Kooooo001Oooooo`?o0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000:ooo
ool0067ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000;oooool0
05?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o0000:oooool00ol0003oooooooooo`21
ooooo`Go0000<oooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
000002Sooooo00?o0000ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?oooooooooo
ooooool@41003Oooool2o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo001Coooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo07Cooooo1Ol00010ooooo`00Doooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000
oooooooooooo00008oooool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go410@
oooooooooooooooooa0@400Aooooo`?o00008oooool00ol0003oooooooooo`1[ooooo`Go0000BOoo
ool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00008oooool00ol0003ooooooooo
o`1Wooooo`Co0000C_ooool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?o
ooooo`000?ooool07_ooool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0000O
ooooo`03o`000?oooooooooo05kooooo1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05[ooooo1?l0001Kooooo`00L?ooool2o`0001gooooo00?o0000oooooooo
ool0E_ooool4o`0005oooooo001booooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0
DOooool5o`0006?ooooo001cooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000J?oo
ool007Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000K?ooool0
07Kooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`oooo
o`00N?ooool2o`0001Gooooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0>oooool5o`0007Wooooo001jooooo`;o000000?o
ooooo`000?ooool04?ooool00ol0003oooooooooo`0gooooo`Co0000O_ooool006?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo
0_l0000Aooooo`03o`000?oooooooooo03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03o`00
0?oooooooooo02oooooo1Ol00026ooooo`00Hoooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo
1?l0002;ooooo`00Hoooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1_ooool3o`0000_ooooo00?o0000ooooooooool09oooool4o`0008oooooo001Sooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Rooooo`Go0000Toooool006?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`0Nooooo`Co0000V?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00gooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1Ol0002Loooo
o`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0003o
ooooooooo`0Aooooo`Co0000YOooool008Wooooo0_l00003ooooo`03o`000?oooooooooo00cooooo
1Ol0002Yooooo`00R_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002^ooooo`00Rooo
ool2o`000003ooooool0003ooooo00Gooooo1?l0002booooo`00SOooool2o`000003ooooool0003o
000000?o0000]_ooool008kooooo0_l0002kooooo`00oooooom<ooooo`00oooooom<ooooo`00Q?oo
ool4o`000003oa0@4?oooooooooo0<3ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026oooo
o`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`00
0?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooo
oooo0<;ooooo0024ooooo`03oeEEEOmVIVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48205 .55242 m .47484 .5927 L .5437 .59604 L p .717 .612 .738 r
F P
0 g
s
.5437 .59604 m .54127 .55536 L .48205 .55242 L p .717 .612 .738 r
F P
0 g
s
.54574 .6381 m .5437 .59604 L .47484 .5927 L p .72 .585 .704 r
F P
0 g
s
.54127 .55536 m .5437 .59604 L .61109 .58603 L p .673 .578 .74 r
F P
0 g
s
.5437 .59604 m .54574 .6381 L .62108 .6272 L p .668 .545 .705 r
F P
0 g
s
.62108 .6272 m .61109 .58603 L .5437 .59604 L p .668 .545 .705 r
F P
0 g
s
.47484 .5927 m .4688 .63448 L .54574 .6381 L p .72 .585 .704 r
F P
0 g
s
.54727 .68022 m .54574 .6381 L .4688 .63448 L p .72 .555 .665 r
F P
0 g
s
.54574 .6381 m .54727 .68022 L .62861 .66876 L p .661 .509 .666 r
F P
0 g
s
.62861 .66876 m .62108 .6272 L .54574 .6381 L p .661 .509 .666 r
F P
0 g
s
.42676 .53794 m .41038 .57624 L .47484 .5927 L p .759 .652 .744 r
F P
0 g
s
.47484 .5927 m .48205 .55242 L .42676 .53794 L p .759 .652 .744 r
F P
0 g
s
.4688 .63448 m .47484 .5927 L .41038 .57624 L p .768 .631 .709 r
F P
0 g
s
.41038 .57624 m .39662 .61652 L .4688 .63448 L p .768 .631 .709 r
F P
0 g
s
.46425 .67641 m .4688 .63448 L .39662 .61652 L p .776 .606 .669 r
F P
0 g
s
.4688 .63448 m .46425 .67641 L .54727 .68022 L p .72 .555 .665 r
F P
0 g
s
.4901 .51458 m .48205 .55242 L .54127 .55536 L p .713 .636 .77 r
F P
0 g
s
.54127 .55536 m .53856 .51704 L .4901 .51458 L p .713 .636 .77 r
F P
0 g
s
.53856 .51704 m .54127 .55536 L .59917 .54655 L p .676 .608 .772 r
F P
0 g
s
.61109 .58603 m .59917 .54655 L .54127 .55536 L p .673 .578 .74 r
F P
0 g
s
.5482 .72076 m .54727 .68022 L .46425 .67641 L p .718 .52 .62 r
F P
0 g
s
.54727 .68022 m .5482 .72076 L .63316 .7091 L p .652 .467 .621 r
F P
0 g
s
.63316 .7091 m .62861 .66876 L .54727 .68022 L p .652 .467 .621 r
F P
0 g
s
.44499 .50248 m .42676 .53794 L .48205 .55242 L p .747 .671 .776 r
F P
0 g
s
.48205 .55242 m .4901 .51458 L .44499 .50248 L p .747 .671 .776 r
F P
0 g
s
.59917 .54655 m .61109 .58603 L .67113 .56331 L p .623 .548 .749 r
F P
0 g
s
.61109 .58603 m .62108 .6272 L .68847 .60239 L p .61 .508 .713 r
F P
0 g
s
.68847 .60239 m .67113 .56331 L .61109 .58603 L p .61 .508 .713 r
F P
0 g
s
.39662 .61652 m .38625 .65752 L .46425 .67641 L p .776 .606 .669 r
F P
0 g
s
.4615 .71688 m .46425 .67641 L .38625 .65752 L p .781 .575 .621 r
F P
0 g
s
.46425 .67641 m .4615 .71688 L .5482 .72076 L p .718 .52 .62 r
F P
0 g
s
.62108 .6272 m .62861 .66876 L .70156 .64264 L p .593 .463 .672 r
F P
0 g
s
.70156 .64264 m .68847 .60239 L .62108 .6272 L p .593 .463 .672 r
F P
0 g
s
.59917 .54655 m .58589 .50967 L .53856 .51704 L p .676 .608 .772 r
F P
0 g
s
.58589 .50967 m .59917 .54655 L .65054 .5266 L p .635 .585 .781 r
F P
0 g
s
.67113 .56331 m .65054 .5266 L .59917 .54655 L p .623 .548 .749 r
F P
0 g
s
.49871 .47969 m .4901 .51458 L .53856 .51704 L p .707 .659 .8 r
F P
0 g
s
.53856 .51704 m .53565 .48161 L .49871 .47969 L p .707 .659 .8 r
F P
0 g
s
.53565 .48161 m .53856 .51704 L .58589 .50967 L p .677 .637 .802 r
F P
0 g
s
.46442 .4703 m .44499 .50248 L .4901 .51458 L p .734 .687 .805 r
F P
0 g
s
.4901 .51458 m .49871 .47969 L .46442 .4703 L p .734 .687 .805 r
F P
0 g
s
.62861 .66876 m .63316 .7091 L .7095 .68249 L p .573 .409 .622 r
F P
0 g
s
.7095 .68249 m .70156 .64264 L .62861 .66876 L p .573 .409 .622 r
F P
0 g
s
.38053 .51294 m .35614 .54771 L .41038 .57624 L p .799 .701 .757 r
F P
0 g
s
.41038 .57624 m .42676 .53794 L .38053 .51294 L p .799 .701 .757 r
F P
0 g
s
.39662 .61652 m .41038 .57624 L .35614 .54771 L p .817 .686 .72 r
F P
0 g
s
.54845 .75801 m .5482 .72076 L .4615 .71688 L p .713 .476 .565 r
F P
0 g
s
.5482 .72076 m .54845 .75801 L .6344 .7465 L p .638 .415 .564 r
F P
0 g
s
.6344 .7465 m .63316 .7091 L .5482 .72076 L p .638 .415 .564 r
F P
0 g
s
.40754 .48169 m .38053 .51294 L .42676 .53794 L p .779 .712 .789 r
F P
0 g
s
.42676 .53794 m .44499 .50248 L .40754 .48169 L p .779 .712 .789 r
F P
0 g
s
.58589 .50967 m .5717 .47588 L .53565 .48161 L p .677 .637 .802 r
F P
0 g
s
.5717 .47588 m .58589 .50967 L .62767 .49304 L p .645 .62 .81 r
F P
0 g
s
.65054 .5266 m .62767 .49304 L .58589 .50967 L p .635 .585 .781 r
F P
0 g
s
.35614 .54771 m .33555 .58531 L .39662 .61652 L p .817 .686 .72 r
F P
0 g
s
.38625 .65752 m .39662 .61652 L .33555 .58531 L p .833 .667 .677 r
F P
0 g
s
.38625 .65752 m .37996 .69766 L .4615 .71688 L p .781 .575 .621 r
F P
0 g
s
.46076 .75418 m .4615 .71688 L .37996 .69766 L p .784 .536 .562 r
F P
0 g
s
.4615 .71688 m .46076 .75418 L .54845 .75801 L p .713 .476 .565 r
F P
0 g
s
.43618 .45423 m .40754 .48169 L .44499 .50248 L p .758 .72 .817 r
F P
0 g
s
.44499 .50248 m .46442 .4703 L .43618 .45423 L p .758 .72 .817 r
F P
0 g
s
.50767 .44789 m .49871 .47969 L .53565 .48161 L p .7 .681 .829 r
F P
0 g
s
.53565 .48161 m .53262 .44921 L .50767 .44789 L p .7 .681 .829 r
F P
0 g
s
.53262 .44921 m .53565 .48161 L .5717 .47588 L p .677 .665 .83 r
F P
0 g
s
.33555 .58531 m .31999 .62461 L .38625 .65752 L p .833 .667 .677 r
F P
0 g
s
.37996 .69766 m .38625 .65752 L .31999 .62461 L p .847 .64 .623 r
F P
0 g
s
.48459 .44145 m .46442 .4703 L .49871 .47969 L p .719 .702 .833 r
F P
0 g
s
.49871 .47969 m .50767 .44789 L .48459 .44145 L p .719 .702 .833 r
F P
0 g
s
.65054 .5266 m .67113 .56331 L .71811 .52943 L p .565 .523 .767 r
F P
0 g
s
.67113 .56331 m .68847 .60239 L .74159 .56525 L p .538 .472 .729 r
F P
0 g
s
.74159 .56525 m .71811 .52943 L .67113 .56331 L p .538 .472 .729 r
F P
0 g
s
.63316 .7091 m .6344 .7465 L .71166 .72023 L p .545 .343 .558 r
F P
0 g
s
.71166 .72023 m .7095 .68249 L .63316 .7091 L p .545 .343 .558 r
F P
0 g
s
.62767 .49304 m .65054 .5266 L .69037 .49698 L p .589 .569 .799 r
F P
0 g
s
.71811 .52943 m .69037 .49698 L .65054 .5266 L p .565 .523 .767 r
F P
0 g
s
.5717 .47588 m .55694 .44527 L .53262 .44921 L p .677 .665 .83 r
F P
0 g
s
.55694 .44527 m .5717 .47588 L .60336 .46299 L p .653 .653 .837 r
F P
0 g
s
.62767 .49304 m .60336 .46299 L .5717 .47588 L p .645 .62 .81 r
F P
0 g
s
.68847 .60239 m .70156 .64264 L .75939 .6034 L p .505 .411 .683 r
F P
0 g
s
.75939 .6034 m .74159 .56525 L .68847 .60239 L p .505 .411 .683 r
F P
0 g
s
.60336 .46299 m .62767 .49304 L .65974 .46848 L p .61 .61 .826 r
F P
0 g
s
.69037 .49698 m .65974 .46848 L .62767 .49304 L p .589 .569 .799 r
F P
0 g
s
.54799 .7903 m .54845 .75801 L .46076 .75418 L p .701 .418 .491 r
F P
0 g
s
.54845 .75801 m .54799 .7903 L .63215 .77928 L p .615 .347 .488 r
F P
0 g
s
.63215 .77928 m .6344 .7465 L .54845 .75801 L p .615 .347 .488 r
F P
0 g
s
.46572 .43047 m .43618 .45423 L .46442 .4703 L p .736 .727 .843 r
F P
0 g
s
.46442 .4703 m .48459 .44145 L .46572 .43047 L p .736 .727 .843 r
F P
0 g
s
.37996 .69766 m .37825 .7352 L .46076 .75418 L p .784 .536 .562 r
F P
0 g
s
.46211 .78663 m .46076 .75418 L .37825 .7352 L p .78 .481 .482 r
F P
0 g
s
.46076 .75418 m .46211 .78663 L .54799 .7903 L p .701 .418 .491 r
F P
0 g
s
.31999 .62461 m .31052 .66411 L .37996 .69766 L p .847 .64 .623 r
F P
0 g
s
.37825 .7352 m .37996 .69766 L .31052 .66411 L p .858 .603 .552 r
F P
0 g
s
.3817 .45394 m .34817 .47935 L .38053 .51294 L p .807 .761 .811 r
F P
0 g
s
.38053 .51294 m .40754 .48169 L .3817 .45394 L p .807 .761 .811 r
F P
0 g
s
.35614 .54771 m .38053 .51294 L .34817 .47935 L p .836 .761 .779 r
F P
0 g
s
.70156 .64264 m .7095 .68249 L .77022 .64245 L p .464 .338 .623 r
F P
0 g
s
.77022 .64245 m .75939 .6034 L .70156 .64264 L p .464 .338 .623 r
F P
0 g
s
.51688 .41902 m .50767 .44789 L .53262 .44921 L p .69 .702 .856 r
F P
0 g
s
.53262 .44921 m .52951 .4197 L .51688 .41902 L p .69 .702 .856 r
F P
0 g
s
.52951 .4197 m .53262 .44921 L .55694 .44527 L p .676 .691 .857 r
F P
0 g
s
.60336 .46299 m .57819 .43644 L .55694 .44527 L p .653 .653 .837 r
F P
0 g
s
.57819 .43644 m .60336 .46299 L .62739 .44407 L p .629 .647 .849 r
F P
0 g
s
.65974 .46848 m .62739 .44407 L .60336 .46299 L p .61 .61 .826 r
F P
0 g
s
.50524 .41571 m .48459 .44145 L .50767 .44789 L p .702 .715 .859 r
F P
0 g
s
.50767 .44789 m .51688 .41902 L .50524 .41571 L p .702 .715 .859 r
F P
0 g
s
.34817 .47935 m .31769 .50917 L .35614 .54771 L p .836 .761 .779 r
F P
0 g
s
.33555 .58531 m .35614 .54771 L .31769 .50917 L p .865 .756 .74 r
F P
0 g
s
.41698 .43292 m .3817 .45394 L .40754 .48169 L p .777 .759 .836 r
F P
0 g
s
.40754 .48169 m .43618 .45423 L .41698 .43292 L p .777 .759 .836 r
F P
0 g
s
.55694 .44527 m .5418 .41768 L .52951 .4197 L p .676 .691 .857 r
F P
0 g
s
.5418 .41768 m .55694 .44527 L .57819 .43644 L p .661 .685 .862 r
F P
0 g
s
.6344 .7465 m .63215 .77928 L .70774 .75413 L p .504 .255 .47 r
F P
0 g
s
.70774 .75413 m .71166 .72023 L .6344 .7465 L p .504 .255 .47 r
F P
0 g
s
.4958 .41011 m .46572 .43047 L .48459 .44145 L p .712 .73 .865 r
F P
0 g
s
.48459 .44145 m .50524 .41571 L .4958 .41011 L p .712 .73 .865 r
F P
0 g
s
.31769 .50917 m .29181 .54294 L .33555 .58531 L p .865 .756 .74 r
F P
0 g
s
.31999 .62461 m .33555 .58531 L .29181 .54294 L p .894 .745 .69 r
F P
0 g
s
.4531 .41601 m .41698 .43292 L .43618 .45423 L p .747 .754 .858 r
F P
0 g
s
.43618 .45423 m .46572 .43047 L .4531 .41601 L p .747 .754 .858 r
F P
0 g
s
.57819 .43644 m .55248 .41315 L .5418 .41768 L p .661 .685 .862 r
F P
0 g
s
.55248 .41315 m .57819 .43644 L .59414 .42356 L p .646 .682 .87 r
F P
0 g
s
.62739 .44407 m .59414 .42356 L .57819 .43644 L p .629 .647 .849 r
F P
0 g
s
.7095 .68249 m .71166 .72023 L .77317 .68068 L p .409 .242 .541 r
F P
0 g
s
.77317 .68068 m .77022 .64245 L .7095 .68249 L p .409 .242 .541 r
F P
0 g
s
.62739 .44407 m .65974 .46848 L .67849 .43813 L p .572 .607 .849 r
F P
0 g
s
.65974 .46848 m .69037 .49698 L .71415 .46012 L p .536 .559 .826 r
F P
0 g
s
.71415 .46012 m .67849 .43813 L .65974 .46848 L p .536 .559 .826 r
F P
0 g
s
.69037 .49698 m .71811 .52943 L .7467 .48698 L p .493 .502 .795 r
F P
0 g
s
.7467 .48698 m .71415 .46012 L .69037 .49698 L p .493 .502 .795 r
F P
0 g
s
.54684 .81624 m .54799 .7903 L .46211 .78663 L p .677 .333 .385 r
F P
0 g
s
.54799 .7903 m .54684 .81624 L .62647 .806 L p .577 .25 .378 r
F P
0 g
s
.62647 .806 m .63215 .77928 L .54799 .7903 L p .577 .25 .378 r
F P
0 g
s
.48959 .40277 m .4531 .41601 L .46572 .43047 L p .717 .747 .875 r
F P
0 g
s
.46572 .43047 m .4958 .41011 L .48959 .40277 L p .717 .747 .875 r
F P
0 g
s
.31052 .66411 m .30795 .70208 L .37825 .7352 L p .858 .603 .552 r
F P
0 g
s
.38136 .76846 m .37825 .7352 L .30795 .70208 L p .861 .545 .451 r
F P
0 g
s
.37825 .7352 m .38136 .76846 L .46211 .78663 L p .78 .481 .482 r
F P
0 g
s
.59414 .42356 m .62739 .44407 L .64112 .42086 L p .604 .648 .867 r
F P
0 g
s
.67849 .43813 m .64112 .42086 L .62739 .44407 L p .572 .607 .849 r
F P
0 g
s
.29181 .54294 m .27215 .57978 L .31999 .62461 L p .894 .745 .69 r
F P
0 g
s
.31052 .66411 m .31999 .62461 L .27215 .57978 L p .92 .724 .621 r
F P
0 g
s
.71811 .52943 m .74159 .56525 L .77443 .51846 L p .44 .433 .754 r
F P
0 g
s
.77443 .51846 m .7467 .48698 L .71811 .52943 L p .44 .433 .754 r
F P
0 g
s
.52951 .4197 m .52632 .39284 L .51688 .41902 L closepath p .677 .722 .883 r
F P
0 g
s
.5418 .41768 m .52632 .39284 L .52951 .4197 L closepath p .672 .718 .884 r
F P
0 g
s
.51688 .41902 m .52632 .39284 L .50524 .41571 L closepath p .682 .727 .884 r
F P
0 g
s
.46554 .81283 m .46211 .78663 L .38136 .76846 L p .763 .397 .363 r
F P
0 g
s
.46211 .78663 m .46554 .81283 L .54684 .81624 L p .677 .333 .385 r
F P
0 g
s
.55248 .41315 m .52632 .39284 L .5418 .41768 L closepath p .667 .716 .885 r
F P
0 g
s
.50524 .41571 m .52632 .39284 L .4958 .41011 L closepath p .685 .732 .887 r
F P
0 g
s
.59414 .42356 m .56041 .4066 L .55248 .41315 L p .646 .682 .87 r
F P
0 g
s
.56041 .4066 m .59414 .42356 L .60302 .40788 L p .632 .684 .881 r
F P
0 g
s
.64112 .42086 m .60302 .40788 L .59414 .42356 L p .604 .648 .867 r
F P
0 g
s
.56041 .4066 m .52632 .39284 L .55248 .41315 L closepath p .662 .716 .888 r
F P
0 g
s
.74159 .56525 m .75939 .6034 L .79556 .55378 L p .374 .344 .697 r
F P
0 g
s
.79556 .55378 m .77443 .51846 L .74159 .56525 L p .374 .344 .697 r
F P
0 g
s
.4482 .39952 m .40914 .40841 L .41698 .43292 L p .752 .782 .878 r
F P
0 g
s
.41698 .43292 m .4531 .41601 L .4482 .39952 L p .752 .782 .878 r
F P
0 g
s
.3817 .45394 m .41698 .43292 L .40914 .40841 L p .787 .801 .863 r
F P
0 g
s
.40914 .40841 m .37065 .42175 L .3817 .45394 L p .787 .801 .863 r
F P
0 g
s
.34817 .47935 m .3817 .45394 L .37065 .42175 L p .825 .819 .843 r
F P
0 g
s
.4958 .41011 m .52632 .39284 L .48959 .40277 L closepath p .686 .738 .89 r
F P
0 g
s
.63215 .77928 m .62647 .806 L .69784 .78265 L p .439 .127 .338 r
F P
0 g
s
.69784 .78265 m .70774 .75413 L .63215 .77928 L p .439 .127 .338 r
F P
0 g
s
.48731 .39448 m .4482 .39952 L .4531 .41601 L p .718 .763 .888 r
F P
0 g
s
.4531 .41601 m .48959 .40277 L .48731 .39448 L p .718 .763 .888 r
F P
0 g
s
.56471 .39867 m .52632 .39284 L .56041 .4066 L closepath p .657 .717 .892 r
F P
0 g
s
.60302 .40788 m .56471 .39867 L .56041 .4066 L p .632 .684 .881 r
F P
0 g
s
.37065 .42175 m .33376 .4401 L .34817 .47935 L p .825 .819 .843 r
F P
0 g
s
.31769 .50917 m .34817 .47935 L .33376 .4401 L p .866 .835 .813 r
F P
0 g
s
.27215 .57978 m .26015 .6183 L .31052 .66411 L p .92 .724 .621 r
F P
0 g
s
.30795 .70208 m .31052 .66411 L .26015 .6183 L p .941 .685 .522 r
F P
0 g
s
.71166 .72023 m .70774 .75413 L .76782 .71629 L p .328 .108 .421 r
F P
0 g
s
.76782 .71629 m .77317 .68068 L .71166 .72023 L p .328 .108 .421 r
F P
0 g
s
.48959 .40277 m .52632 .39284 L .48731 .39448 L closepath p .686 .743 .894 r
F P
0 g
s
.56471 .39867 m .60302 .40788 L .60371 .391 L p .62 .691 .895 r
F P
0 g
s
.60302 .40788 m .64112 .42086 L .64269 .39567 L p .581 .657 .889 r
F P
0 g
s
.64269 .39567 m .60371 .391 L .60302 .40788 L p .581 .657 .889 r
F P
0 g
s
.33376 .4401 m .29996 .4638 L .31769 .50917 L p .866 .835 .813 r
F P
0 g
s
.29181 .54294 m .31769 .50917 L .29996 .4638 L p .909 .847 .77 r
F P
0 g
s
.56488 .39022 m .52632 .39284 L .56471 .39867 L closepath p .654 .719 .897 r
F P
0 g
s
.60371 .391 m .56488 .39022 L .56471 .39867 L p .62 .691 .895 r
F P
0 g
s
.64112 .42086 m .67849 .43813 L .68126 .40491 L p .533 .614 .879 r
F P
0 g
s
.68126 .40491 m .64269 .39567 L .64112 .42086 L p .533 .614 .879 r
F P
0 g
s
.75939 .6034 m .77022 .64245 L .80848 .59168 L p .285 .227 .615 r
F P
0 g
s
.80848 .59168 m .79556 .55378 L .75939 .6034 L p .285 .227 .615 r
F P
0 g
s
.30795 .70208 m .31262 .73675 L .38136 .76846 L p .861 .545 .451 r
F P
0 g
s
.38919 .79595 m .38136 .76846 L .31262 .73675 L p .843 .448 .297 r
F P
0 g
s
.38136 .76846 m .38919 .79595 L .46554 .81283 L p .763 .397 .363 r
F P
0 g
s
.48731 .39448 m .52632 .39284 L .48925 .3861 L closepath p .684 .747 .899 r
F P
0 g
s
.56085 .38216 m .52632 .39284 L .56488 .39022 L closepath p .652 .724 .901 r
F P
0 g
s
.553 .37538 m .52632 .39284 L .56085 .38216 L closepath p .652 .729 .906 r
F P
0 g
s
.54217 .37065 m .52632 .39284 L .553 .37538 L closepath p .654 .735 .909 r
F P
0 g
s
.52957 .36853 m .52632 .39284 L .54217 .37065 L closepath p .658 .74 .911 r
F P
0 g
s
.51659 .36925 m .52632 .39284 L .52957 .36853 L closepath p .663 .745 .911 r
F P
0 g
s
.50472 .37273 m .52632 .39284 L .51659 .36925 L closepath p .669 .749 .91 r
F P
0 g
s
.49526 .37857 m .52632 .39284 L .50472 .37273 L closepath p .675 .75 .907 r
F P
0 g
s
.48925 .3861 m .52632 .39284 L .49526 .37857 L closepath p .68 .749 .904 r
F P
0 g
s
.4482 .39952 m .48731 .39448 L .48925 .3861 L p .713 .776 .902 r
F P
0 g
s
.67849 .43813 m .71415 .46012 L .7184 .41943 L p .473 .559 .863 r
F P
0 g
s
.7184 .41943 m .68126 .40491 L .67849 .43813 L p .473 .559 .863 r
F P
0 g
s
.54504 .83488 m .54684 .81624 L .46554 .81283 L p .623 .199 .216 r
F P
0 g
s
.54684 .81624 m .54504 .83488 L .61763 .82565 L p .505 .098 .203 r
F P
0 g
s
.61763 .82565 m .62647 .806 L .54684 .81624 L p .505 .098 .203 r
F P
0 g
s
.48925 .3861 m .45175 .38272 L .4482 .39952 L p .713 .776 .902 r
F P
0 g
s
.40914 .40841 m .4482 .39952 L .45175 .38272 L p .746 .808 .902 r
F P
0 g
s
.56488 .39022 m .60371 .391 L .59592 .37476 L p .612 .703 .909 r
F P
0 g
s
.59592 .37476 m .56085 .38216 L .56488 .39022 L p .612 .703 .909 r
F P
0 g
s
.47088 .83181 m .46554 .81283 L .38919 .79595 L p .712 .258 .173 r
F P
0 g
s
.46554 .81283 m .47088 .83181 L .54504 .83488 L p .623 .199 .216 r
F P
0 g
s
.29996 .4638 m .27105 .49278 L .29181 .54294 L p .909 .847 .77 r
F P
0 g
s
.27215 .57978 m .29181 .54294 L .27105 .49278 L p .953 .85 .703 r
F P
0 g
s
.71415 .46012 m .7467 .48698 L .75258 .43977 L p .395 .486 .834 r
F P
0 g
s
.75258 .43977 m .7184 .41943 L .71415 .46012 L p .395 .486 .834 r
F P
0 g
s
.45175 .38272 m .48925 .3861 L .49526 .37857 L p .702 .786 .916 r
F P
0 g
s
.45175 .38272 m .41395 .38322 L .40914 .40841 L p .746 .808 .902 r
F P
0 g
s
.37065 .42175 m .40914 .40841 L .41395 .38322 L p .783 .842 .897 r
F P
0 g
s
.60371 .391 m .64269 .39567 L .63143 .37119 L p .561 .674 .914 r
F P
0 g
s
.63143 .37119 m .59592 .37476 L .60371 .391 L p .561 .674 .914 r
F P
0 g
s
.56085 .38216 m .59592 .37476 L .5803 .36098 L p .609 .719 .923 r
F P
0 g
s
.5803 .36098 m .553 .37538 L .56085 .38216 L p .609 .719 .923 r
F P
0 g
s
.26015 .6183 m .25688 .65682 L .30795 .70208 L p .941 .685 .522 r
F P
0 g
s
.31262 .73675 m .30795 .70208 L .25688 .65682 L p .943 .611 .37 r
F P
0 g
s
.77022 .64245 m .77317 .68068 L .812 .63051 L p .16 .063 .487 r
F P
0 g
s
.812 .63051 m .80848 .59168 L .77022 .64245 L p .16 .063 .487 r
F P
0 g
s
.46359 .36748 m .49526 .37857 L .50472 .37273 L p .685 .789 .929 r
F P
0 g
s
.49526 .37857 m .46359 .36748 L .45175 .38272 L p .702 .786 .916 r
F P
0 g
s
.62647 .806 m .61763 .82565 L .68248 .80469 L p .323 0 .123 r
F P
0 g
s
.68248 .80469 m .69784 .78265 L .62647 .806 L p .323 0 .123 r
F P
0 g
s
.70774 .75413 m .69784 .78265 L .75432 .74762 L p .2 0 .23 r
F P
0 g
s
.75432 .74762 m .76782 .71629 L .70774 .75413 L p .2 0 .23 r
F P
0 g
s
.41395 .38322 m .37637 .38838 L .37065 .42175 L p .783 .842 .897 r
F P
0 g
s
.33376 .4401 m .37065 .42175 L .37637 .38838 L p .825 .88 .884 r
F P
0 g
s
.553 .37538 m .5803 .36098 L .55848 .35132 L p .614 .737 .934 r
F P
0 g
s
.55848 .35132 m .54217 .37065 L .553 .37538 L p .614 .737 .934 r
F P
0 g
s
.7467 .48698 m .77443 .51846 L .78191 .46608 L p .29 .384 .786 r
F P
0 g
s
.78191 .46608 m .75258 .43977 L .7467 .48698 L p .29 .384 .786 r
F P
0 g
s
.41395 .38322 m .45175 .38272 L .46359 .36748 L p .727 .827 .927 r
F P
0 g
s
.64269 .39567 m .68126 .40491 L .66689 .37234 L p .494 .634 .915 r
F P
0 g
s
.66689 .37234 m .63143 .37119 L .64269 .39567 L p .494 .634 .915 r
F P
0 g
s
.48255 .35557 m .50472 .37273 L .51659 .36925 L p .665 .784 .938 r
F P
0 g
s
.50472 .37273 m .48255 .35557 L .46359 .36748 L p .685 .789 .929 r
F P
0 g
s
.54217 .37065 m .55848 .35132 L .53292 .34696 L p .626 .757 .941 r
F P
0 g
s
.53292 .34696 m .52957 .36853 L .54217 .37065 L p .626 .757 .941 r
F P
0 g
s
.27105 .49278 m .24896 .52645 L .27215 .57978 L p .953 .85 .703 r
F P
0 g
s
.26015 .6183 m .27215 .57978 L .24896 .52645 L p .989 .834 .597 r
F P
0 g
s
.50658 .34844 m .51659 .36925 L .52957 .36853 L p .643 .773 .942 r
F P
0 g
s
.51659 .36925 m .50658 .34844 L .48255 .35557 L p .665 .784 .938 r
F P
0 g
s
.52957 .36853 m .53292 .34696 L .50658 .34844 L p .643 .773 .942 r
F P
0 g
s
.59592 .37476 m .63143 .37119 L .60815 .35028 L p .551 .701 .939 r
F P
0 g
s
.60815 .35028 m .5803 .36098 L .59592 .37476 L p .551 .701 .939 r
F P
0 g
s
.37637 .38838 m .34004 .39906 L .33376 .4401 L p .825 .88 .884 r
F P
0 g
s
.29996 .4638 m .33376 .4401 L .34004 .39906 L p .872 .92 .857 r
F P
0 g
s
.31262 .73675 m .32441 .76655 L .38919 .79595 L p .843 .448 .297 r
F P
0 g
s
.40137 .81662 m .38919 .79595 L .32441 .76655 L p .769 .274 .044 r
F P
0 g
s
.38919 .79595 m .40137 .81662 L .47088 .83181 L p .712 .258 .173 r
F P
0 g
s
.46359 .36748 m .43139 .36017 L .41395 .38322 L p .727 .827 .927 r
F P
0 g
s
.37637 .38838 m .41395 .38322 L .43139 .36017 L p .756 .876 .934 r
F P
0 g
s
.77443 .51846 m .79556 .55378 L .8044 .49796 L p .142 .236 .702 r
F P
0 g
s
.8044 .49796 m .78191 .46608 L .77443 .51846 L p .142 .236 .702 r
F P
0 g
s
.68126 .40491 m .7184 .41943 L .70133 .37921 L p .399 .572 .907 r
F P
0 g
s
.70133 .37921 m .66689 .37234 L .68126 .40491 L p .399 .572 .907 r
F P
0 g
s
.43139 .36017 m .46359 .36748 L .48255 .35557 L p .695 .835 .95 r
F P
0 g
s
.54268 .84578 m .54504 .83488 L .47088 .83181 L p .494 0 0 r
F P
0 g
s
.54504 .83488 m .54268 .84578 L .6061 .83778 L p .352 0 0 r
F P
0 g
s
.6061 .83778 m .61763 .82565 L .54504 .83488 L p .352 0 0 r
F P
0 g
s
.77317 .68068 m .76782 .71629 L .80561 .66836 L p 0 0 .279 r
F P
0 g
s
.80561 .66836 m .812 .63051 L .77317 .68068 L p 0 0 .279 r
F P
0 g
s
.25688 .65682 m .26282 .69349 L .31262 .73675 L p .943 .611 .37 r
F P
0 g
s
.32441 .76655 m .31262 .73675 L .26282 .69349 L p .89 .463 .122 r
F P
0 g
s
.5803 .36098 m .60815 .35028 L .57521 .33551 L p .553 .734 .96 r
F P
0 g
s
.57521 .33551 m .55848 .35132 L .5803 .36098 L p .553 .734 .96 r
F P
0 g
s
.47786 .84312 m .47088 .83181 L .40137 .81662 L p .571 .014 0 r
F P
0 g
s
.47088 .83181 m .47786 .84312 L .54268 .84578 L p .494 0 0 r
F P
0 g
s
.24896 .52645 m .23543 .56366 L .26015 .6183 L p .989 .834 .597 r
F P
0 g
s
.25688 .65682 m .26015 .6183 L .23543 .56366 L p .996 .771 .418 r
F P
0 g
s
.34004 .39906 m .30646 .416 L .29996 .4638 L p .872 .92 .857 r
F P
0 g
s
.27105 .49278 m .29996 .4638 L .30646 .416 L p .918 .953 .799 r
F P
0 g
s
.63143 .37119 m .66689 .37234 L .63617 .34428 L p .463 .667 .952 r
F P
0 g
s
.63617 .34428 m .60815 .35028 L .63143 .37119 L p .463 .667 .952 r
F P
0 g
s
.69784 .78265 m .68248 .80469 L .73346 .77334 L p 0 0 0 r
F P
0 g
s
.73346 .77334 m .75432 .74762 L .69784 .78265 L p 0 0 0 r
F P
0 g
s
.45987 .34202 m .48255 .35557 L .50658 .34844 L p .652 .827 .967 r
F P
0 g
s
.48255 .35557 m .45987 .34202 L .43139 .36017 L p .695 .835 .95 r
F P
0 g
s
.7184 .41943 m .75258 .43977 L .73328 .39274 L p .257 .473 .877 r
F P
0 g
s
.73328 .39274 m .70133 .37921 L .7184 .41943 L p .257 .473 .877 r
F P
0 g
s
.61763 .82565 m .6061 .83778 L .6625 .81966 L p .109 0 0 r
F P
0 g
s
.6625 .81966 m .68248 .80469 L .61763 .82565 L p .109 0 0 r
F P
0 g
s
.43139 .36017 m .39912 .35757 L .37637 .38838 L p .756 .876 .934 r
F P
0 g
s
.34004 .39906 m .37637 .38838 L .39912 .35757 L p .785 .932 .929 r
F P
0 g
s
.55848 .35132 m .57521 .33551 L .53636 .32881 L p .573 .771 .972 r
F P
0 g
s
.53636 .32881 m .53292 .34696 L .55848 .35132 L p .573 .771 .972 r
F P
0 g
s
.79556 .55378 m .80848 .59168 L .8182 .5344 L p 0 .015 .549 r
F P
0 g
s
.8182 .5344 m .8044 .49796 L .79556 .55378 L p 0 .015 .549 r
F P
0 g
s
.4963 .33109 m .50658 .34844 L .53292 .34696 L p .608 .804 .975 r
F P
0 g
s
.50658 .34844 m .4963 .33109 L .45987 .34202 L p .652 .827 .967 r
F P
0 g
s
.53292 .34696 m .53636 .32881 L .4963 .33109 L p .608 .804 .975 r
F P
0 g
s
.39912 .35757 m .43139 .36017 L .45987 .34202 L p .699 .89 .967 r
F P
0 g
s
.30646 .416 m .27753 .43956 L .27105 .49278 L p .918 .953 .799 r
F P
0 g
s
.24896 .52645 m .27105 .49278 L .27753 .43956 L p .946 .958 .678 r
F P
0 g
s
.32441 .76655 m .34267 .79026 L .40137 .81662 L p .769 .274 .044 r
F P
0 g
s
.41724 .82997 m .40137 .81662 L .34267 .79026 L p .555 0 0 r
F P
0 g
s
.40137 .81662 m .41724 .82997 L .47786 .84312 L p .571 .014 0 r
F P
0 g
s
.76782 .71629 m .75432 .74762 L .78954 .70336 L p 0 0 0 r
F P
0 g
s
.78954 .70336 m .80561 .66836 L .76782 .71629 L p 0 0 0 r
F P
0 g
s
.23543 .56366 m .23174 .6028 L .25688 .65682 L p .996 .771 .418 r
F P
0 g
s
.26282 .69349 m .25688 .65682 L .23174 .6028 L p .913 .607 .122 r
F P
0 g
s
.26282 .69349 m .27775 .72654 L .32441 .76655 L p .89 .463 .122 r
F P
0 g
s
.34267 .79026 m .32441 .76655 L .27775 .72654 L p .702 .191 0 r
F P
0 g
s
.60815 .35028 m .63617 .34428 L .59212 .32434 L p .451 .715 .98 r
F P
0 g
s
.59212 .32434 m .57521 .33551 L .60815 .35028 L p .451 .715 .98 r
F P
0 g
s
.66689 .37234 m .70133 .37921 L .66359 .34427 L p .32 .601 .947 r
F P
0 g
s
.66359 .34427 m .63617 .34428 L .66689 .37234 L p .32 .601 .947 r
F P
0 g
s
.75258 .43977 m .78191 .46608 L .7609 .41354 L p .038 .307 .796 r
F P
0 g
s
.7609 .41354 m .73328 .39274 L .75258 .43977 L p .038 .307 .796 r
F P
0 g
s
.39912 .35757 m .36766 .36086 L .34004 .39906 L p .785 .932 .929 r
F P
0 g
s
.30646 .416 m .34004 .39906 L .36766 .36086 L p .805 .985 .89 r
F P
0 g
s
.80848 .59168 m .812 .63051 L .82197 .57385 L p 0 0 .279 r
F P
0 g
s
.82197 .57385 m .8182 .5344 L .80848 .59168 L p 0 0 .279 r
F P
0 g
s
.5399 .84909 m .54268 .84578 L .47786 .84312 L p .212 0 0 r
F P
0 g
s
.54268 .84578 m .5399 .84909 L .59244 .84248 L p .059 0 0 r
F P
0 g
s
.59244 .84248 m .6061 .83778 L .54268 .84578 L p .059 0 0 r
F P
0 g
s
.43699 .33314 m .45987 .34202 L .4963 .33109 L p .618 .874 .99 r
F P
0 g
s
.45987 .34202 m .43699 .33314 L .39912 .35757 L p .699 .89 .967 r
F P
0 g
s
.68248 .80469 m .6625 .81966 L .70646 .79267 L p 0 0 0 r
F P
0 g
s
.70646 .79267 m .73346 .77334 L .68248 .80469 L p 0 0 0 r
F P
0 g
s
.48613 .84689 m .47786 .84312 L .41724 .82997 L p .257 0 0 r
F P
0 g
s
.47786 .84312 m .48613 .84689 L .5399 .84909 L p .212 0 0 r
F P
0 g
s
.57521 .33551 m .59212 .32434 L .53986 .31526 L p .473 .772 .996 r
F P
0 g
s
.53986 .31526 m .53636 .32881 L .57521 .33551 L p .473 .772 .996 r
F P
0 g
s
.36766 .36086 m .39912 .35757 L .43699 .33314 L p .682 .946 .96 r
F P
0 g
s
.27753 .43956 m .25529 .46959 L .24896 .52645 L p .946 .958 .678 r
F P
0 g
s
.23543 .56366 m .24896 .52645 L .25529 .46959 L p .898 .874 .438 r
F P
0 g
s
.6061 .83778 m .59244 .84248 L .63893 .82754 L p 0 0 0 r
F P
0 g
s
.63893 .82754 m .6625 .81966 L .6061 .83778 L p 0 0 0 r
F P
0 g
s
.48588 .31834 m .4963 .33109 L .53636 .32881 L p .533 .83 .999 r
F P
0 g
s
.4963 .33109 m .48588 .31834 L .43699 .33314 L p .618 .874 .99 r
F P
0 g
s
.53636 .32881 m .53986 .31526 L .48588 .31834 L p .533 .83 .999 r
F P
0 g
s
.78191 .46608 m .8044 .49796 L .7822 .44167 L p 0 .029 .6 r
F P
0 g
s
.7822 .44167 m .7609 .41354 L .78191 .46608 L p 0 .029 .6 r
F P
0 g
s
.75432 .74762 m .73346 .77334 L .76481 .73392 L p .561 .82 .453 r
F P
0 g
s
.76481 .73392 m .78954 .70336 L .75432 .74762 L p .561 .82 .453 r
F P
0 g
s
.70133 .37921 m .73328 .39274 L .6892 .35158 L p .075 .46 .886 r
F P
0 g
s
.6892 .35158 m .66359 .34427 L .70133 .37921 L p .075 .46 .886 r
F P
0 g
s
.23174 .6028 m .23844 .64191 L .26282 .69349 L p .913 .607 .122 r
F P
0 g
s
.27775 .72654 m .26282 .69349 L .23844 .64191 L p .661 .299 0 r
F P
0 g
s
.36766 .36086 m .33835 .37115 L .30646 .416 L p .805 .985 .89 r
F P
0 g
s
.27753 .43956 m .30646 .416 L .33835 .37115 L p .773 .989 .758 r
F P
0 g
s
.63617 .34428 m .66359 .34427 L .60876 .31929 L p .261 .647 .965 r
F P
0 g
s
.60876 .31929 m .59212 .32434 L .63617 .34428 L p .261 .647 .965 r
F P
0 g
s
.34267 .79026 m .36637 .80722 L .41724 .82997 L p .555 0 0 r
F P
0 g
s
.41724 .82997 m .436 .83603 L .48613 .84689 L p .257 0 0 r
F P
0 g
s
.436 .83603 m .41724 .82997 L .36637 .80722 L p 0 .386 .742 r
F P
0 g
s
.27775 .72654 m .30078 .75454 L .34267 .79026 L p .702 .191 0 r
F P
0 g
s
.36637 .80722 m .34267 .79026 L .30078 .75454 L p 0 .169 .642 r
F P
0 g
s
.812 .63051 m .80561 .66836 L .81513 .6143 L p 0 0 0 r
F P
0 g
s
.81513 .6143 m .82197 .57385 L .812 .63051 L p 0 0 0 r
F P
0 g
s
.25529 .46959 m .24161 .50522 L .23543 .56366 L p .898 .874 .438 r
F P
0 g
s
.23174 .6028 m .23543 .56366 L .24161 .50522 L p 0 0 0 r
F P
0 g
s
.41454 .33034 m .43699 .33314 L .48588 .31834 L p .52 .896 .963 r
F P
0 g
s
.43699 .33314 m .41454 .33034 L .36766 .36086 L p .682 .946 .96 r
F P
0 g
s
.6625 .81966 m .63893 .82754 L .6748 .80543 L p .525 .918 .82 r
F P
0 g
s
.6748 .80543 m .70646 .79267 L .6625 .81966 L p .525 .918 .82 r
F P
0 g
s
.33835 .37115 m .36766 .36086 L .41454 .33034 L p .593 .949 .858 r
F P
0 g
s
.53678 .8454 m .5399 .84909 L .48613 .84689 L p .165 .691 .87 r
F P
0 g
s
.5399 .84909 m .53678 .8454 L .57722 .8403 L p .281 .778 .881 r
F P
0 g
s
.57722 .8403 m .59244 .84248 L .5399 .84909 L p .281 .778 .881 r
F P
0 g
s
.8044 .49796 m .8182 .5344 L .79533 .47646 L p .676 .345 0 r
F P
0 g
s
.79533 .47646 m .7822 .44167 L .8044 .49796 L p .676 .345 0 r
F P
0 g
s
.49535 .8437 m .48613 .84689 L .436 .83603 L p .133 .641 .9 r
F P
0 g
s
.48613 .84689 m .49535 .8437 L .53678 .8454 L p .165 .691 .87 r
F P
0 g
s
.59212 .32434 m .60876 .31929 L .5433 .30788 L p .265 .713 .958 r
F P
0 g
s
.5433 .30788 m .53986 .31526 L .59212 .32434 L p .265 .713 .958 r
F P
0 g
s
.23844 .64191 m .25526 .67901 L .27775 .72654 L p .661 .299 0 r
F P
0 g
s
.30078 .75454 m .27775 .72654 L .25526 .67901 L p 0 .06 .621 r
F P
0 g
s
.73328 .39274 m .7609 .41354 L .71149 .36728 L p 0 .178 .666 r
F P
0 g
s
.71149 .36728 m .6892 .35158 L .73328 .39274 L p 0 .178 .666 r
F P
0 g
s
.73346 .77334 m .70646 .79267 L .733 .75897 L p .72 .977 .757 r
F P
0 g
s
.733 .75897 m .76481 .73392 L .73346 .77334 L p .72 .977 .757 r
F P
0 g
s
.33835 .37115 m .31294 .38931 L .27753 .43956 L p .773 .989 .758 r
F P
0 g
s
.25529 .46959 m .27753 .43956 L .31294 .38931 L p .603 .83 .445 r
F P
0 g
s
.59244 .84248 m .57722 .8403 L .61281 .82881 L p .455 .878 .923 r
F P
0 g
s
.61281 .82881 m .63893 .82754 L .59244 .84248 L p .455 .878 .923 r
F P
0 g
s
.47561 .31176 m .48588 .31834 L .53986 .31526 L p .359 .803 .955 r
F P
0 g
s
.48588 .31834 m .47561 .31176 L .41454 .33034 L p .52 .896 .963 r
F P
0 g
s
.80561 .66836 m .78954 .70336 L .79798 .65364 L p .88 .899 .481 r
F P
0 g
s
.79798 .65364 m .81513 .6143 L .80561 .66836 L p .88 .899 .481 r
F P
0 g
s
.53986 .31526 m .5433 .30788 L .47561 .31176 L p .359 .803 .955 r
F P
0 g
s
.30078 .75454 m .33051 .77657 L .36637 .80722 L p 0 .169 .642 r
F P
0 g
s
.39425 .81733 m .36637 .80722 L .33051 .77657 L p .025 .454 .873 r
F P
0 g
s
.36637 .80722 m .39425 .81733 L .436 .83603 L p 0 .386 .742 r
F P
0 g
s
.66359 .34427 m .6892 .35158 L .62439 .32198 L p 0 .446 .808 r
F P
0 g
s
.62439 .32198 m .60876 .31929 L .66359 .34427 L p 0 .446 .808 r
F P
0 g
s
.45686 .83533 m .436 .83603 L .39425 .81733 L p .181 .621 .942 r
F P
0 g
s
.436 .83603 m .45686 .83533 L .49535 .8437 L p .133 .641 .9 r
F P
0 g
s
.24161 .50522 m .23787 .54496 L .23174 .6028 L p 0 0 0 r
F P
0 g
s
.23844 .64191 m .23174 .6028 L .23787 .54496 L p 0 0 .334 r
F P
0 g
s
.8182 .5344 m .82197 .57385 L .79893 .51648 L p .929 .655 .176 r
F P
0 g
s
.79893 .51648 m .79533 .47646 L .8182 .5344 L p .929 .655 .176 r
F P
0 g
s
.41454 .33034 m .3935 .33509 L .33835 .37115 L p .593 .949 .858 r
F P
0 g
s
.31294 .38931 m .33835 .37115 L .3935 .33509 L p 0 0 0 r
F P
0 g
s
.3935 .33509 m .41454 .33034 L .47561 .31176 L p .271 .773 .749 r
F P
0 g
s
.63893 .82754 m .61281 .82881 L .63995 .81189 L p .626 .942 .954 r
F P
0 g
s
.63995 .81189 m .6748 .80543 L .63893 .82754 L p .626 .942 .954 r
F P
0 g
s
.25526 .67901 m .28109 .71233 L .30078 .75454 L p 0 .06 .621 r
F P
0 g
s
.33051 .77657 m .30078 .75454 L .28109 .71233 L p .02 .331 .815 r
F P
0 g
s
.31294 .38931 m .29328 .41562 L .25529 .46959 L p .603 .83 .445 r
F P
0 g
s
.24161 .50522 m .25529 .46959 L .29328 .41562 L p 0 0 0 r
F P
0 g
s
.70646 .79267 m .6748 .80543 L .69599 .778 L p .756 .987 .899 r
F P
0 g
s
.69599 .778 m .733 .75897 L .70646 .79267 L p .756 .987 .899 r
F P
0 g
s
.7609 .41354 m .7822 .44167 L .72877 .39187 L p .709 .208 0 r
F P
0 g
s
.72877 .39187 m .71149 .36728 L .7609 .41354 L p .709 .208 0 r
F P
0 g
s
.78954 .70336 m .76481 .73392 L .77172 .6899 L p .92 .976 .712 r
F P
0 g
s
.77172 .6899 m .79798 .65364 L .78954 .70336 L p .92 .976 .712 r
F P
0 g
s
.53344 .8355 m .53678 .8454 L .49535 .8437 L p .421 .799 .992 r
F P
0 g
s
.53678 .8454 m .53344 .8355 L .56094 .83201 L p .486 .845 .993 r
F P
0 g
s
.56094 .83201 m .57722 .8403 L .53678 .8454 L p .486 .845 .993 r
F P
0 g
s
.50524 .83434 m .49535 .8437 L .45686 .83533 L p .392 .756 .993 r
F P
0 g
s
.49535 .8437 m .50524 .83434 L .53344 .8355 L p .421 .799 .992 r
F P
0 g
s
.60876 .31929 m .62439 .32198 L .54654 .30841 L p 0 .471 .698 r
F P
0 g
s
.54654 .30841 m .5433 .30788 L .60876 .31929 L p 0 .471 .698 r
F P
0 g
s
.23787 .54496 m .24465 .58678 L .23844 .64191 L p 0 0 .334 r
F P
0 g
s
.25526 .67901 m .23844 .64191 L .24465 .58678 L p 0 .061 .595 r
F P
0 g
s
.33051 .77657 m .36523 .79229 L .39425 .81733 L p .025 .454 .873 r
F P
0 g
s
.42505 .82098 m .39425 .81733 L .36523 .79229 L p .278 .612 .956 r
F P
0 g
s
.39425 .81733 m .42505 .82098 L .45686 .83533 L p .181 .621 .942 r
F P
0 g
s
.57722 .8403 m .56094 .83201 L .58499 .82417 L p .571 .882 .992 r
F P
0 g
s
.58499 .82417 m .61281 .82881 L .57722 .8403 L p .571 .882 .992 r
F P
0 g
s
.47561 .31176 m .46596 .31302 L .3935 .33509 L p .271 .773 .749 r
F P
0 g
s
.46596 .31302 m .47561 .31176 L .5433 .30788 L p 0 0 0 r
F P
0 g
s
.6892 .35158 m .71149 .36728 L .63804 .33383 L p .517 0 0 r
F P
0 g
s
.63804 .33383 m .62439 .32198 L .6892 .35158 L p .517 0 0 r
F P
0 g
s
.47912 .82861 m .45686 .83533 L .42505 .82098 L p .401 .72 .988 r
F P
0 g
s
.45686 .83533 m .47912 .82861 L .50524 .83434 L p .392 .756 .993 r
F P
0 g
s
.5433 .30788 m .54654 .30841 L .46596 .31302 L p 0 0 0 r
F P
0 g
s
.82197 .57385 m .81513 .6143 L .79241 .55966 L p .999 .807 .469 r
F P
0 g
s
.79241 .55966 m .79893 .51648 L .82197 .57385 L p .999 .807 .469 r
F P
0 g
s
.28109 .71233 m .3142 .7406 L .33051 .77657 L p .02 .331 .815 r
F P
0 g
s
.36523 .79229 m .33051 .77657 L .3142 .7406 L p .237 .501 .901 r
F P
0 g
s
.76481 .73392 m .733 .75897 L .73817 .72159 L p .89 .97 .83 r
F P
0 g
s
.73817 .72159 m .77172 .6899 L .76481 .73392 L p .89 .97 .83 r
F P
0 g
s
.6748 .80543 m .63995 .81189 L .65559 .79109 L p .74 .942 .95 r
F P
0 g
s
.65559 .79109 m .69599 .778 L .6748 .80543 L p .74 .942 .95 r
F P
0 g
s
.61281 .82881 m .58499 .82417 L .60311 .8127 L p .651 .898 .982 r
F P
0 g
s
.60311 .8127 m .63995 .81189 L .61281 .82881 L p .651 .898 .982 r
F P
0 g
s
.3935 .33509 m .37515 .34866 L .31294 .38931 L p 0 0 0 r
F P
0 g
s
.29328 .41562 m .31294 .38931 L .37515 .34866 L p 0 0 0 r
F P
0 g
s
.29328 .41562 m .28114 .44958 L .24161 .50522 L p 0 0 0 r
F P
0 g
s
.23787 .54496 m .24161 .50522 L .28114 .44958 L p 0 0 .327 r
F P
0 g
s
.7822 .44167 m .79533 .47646 L .73945 .42504 L p .904 .492 .157 r
F P
0 g
s
.73945 .42504 m .72877 .39187 L .7822 .44167 L p .904 .492 .157 r
F P
0 g
s
.37515 .34866 m .3935 .33509 L .46596 .31302 L p .096 0 0 r
F P
0 g
s
.24465 .58678 m .26164 .6284 L .25526 .67901 L p 0 .061 .595 r
F P
0 g
s
.28109 .71233 m .25526 .67901 L .26164 .6284 L p .148 .278 .742 r
F P
0 g
s
.36523 .79229 m .4033 .80191 L .42505 .82098 L p .278 .612 .956 r
F P
0 g
s
.45774 .81885 m .42505 .82098 L .4033 .80191 L p .435 .693 .974 r
F P
0 g
s
.42505 .82098 m .45774 .81885 L .47912 .82861 L p .401 .72 .988 r
F P
0 g
s
.52994 .82016 m .53344 .8355 L .50524 .83434 L p .548 .805 .993 r
F P
0 g
s
.53344 .8355 m .52994 .82016 L .54392 .81836 L p .578 .827 .992 r
F P
0 g
s
.54392 .81836 m .56094 .83201 L .53344 .8355 L p .578 .827 .992 r
F P
0 g
s
.51559 .81956 m .50524 .83434 L .47912 .82861 L p .53 .781 .99 r
F P
0 g
s
.50524 .83434 m .51559 .81956 L .52994 .82016 L p .548 .805 .993 r
F P
0 g
s
.81513 .6143 m .79798 .65364 L .77611 .60358 L p .982 .86 .642 r
F P
0 g
s
.77611 .60358 m .79241 .55966 L .81513 .6143 L p .982 .86 .642 r
F P
0 g
s
.56094 .83201 m .54392 .81836 L .55606 .81435 L p .614 .841 .986 r
F P
0 g
s
.55606 .81435 m .58499 .82417 L .56094 .83201 L p .614 .841 .986 r
F P
0 g
s
.3142 .7406 m .35257 .76314 L .36523 .79229 L p .237 .501 .901 r
F P
0 g
s
.4033 .80191 m .36523 .79229 L .35257 .76314 L p .381 .605 .937 r
F P
0 g
s
.62439 .32198 m .63804 .33383 L .54938 .31845 L p .5 0 0 r
F P
0 g
s
.54938 .31845 m .54654 .30841 L .62439 .32198 L p .5 0 0 r
F P
0 g
s
.733 .75897 m .69599 .778 L .69945 .74784 L p .84 .937 .89 r
F P
0 g
s
.69945 .74784 m .73817 .72159 L .733 .75897 L p .84 .937 .89 r
F P
0 g
s
.50235 .81662 m .47912 .82861 L .45774 .81885 L p .526 .758 .981 r
F P
0 g
s
.47912 .82861 m .50235 .81662 L .51559 .81956 L p .53 .781 .99 r
F P
0 g
s
.71149 .36728 m .72877 .39187 L .64867 .35572 L p .761 .266 .046 r
F P
0 g
s
.64867 .35572 m .63804 .33383 L .71149 .36728 L p .761 .266 .046 r
F P
0 g
s
.63995 .81189 m .60311 .8127 L .61327 .79872 L p .71 .889 .962 r
F P
0 g
s
.61327 .79872 m .65559 .79109 L .63995 .81189 L p .71 .889 .962 r
F P
0 g
s
.26164 .6284 m .28759 .66766 L .28109 .71233 L p .148 .278 .742 r
F P
0 g
s
.3142 .7406 m .28109 .71233 L .28759 .66766 L p .292 .424 .824 r
F P
0 g
s
.28114 .44958 m .27782 .48985 L .23787 .54496 L p 0 0 .327 r
F P
0 g
s
.24465 .58678 m .23787 .54496 L .27782 .48985 L p .184 .11 .533 r
F P
0 g
s
.45751 .32368 m .46596 .31302 L .54654 .30841 L p .36 0 0 r
F P
0 g
s
.46596 .31302 m .45751 .32368 L .37515 .34866 L p .096 0 0 r
F P
0 g
s
.58499 .82417 m .55606 .81435 L .56509 .80852 L p .65 .846 .975 r
F P
0 g
s
.56509 .80852 m .60311 .8127 L .58499 .82417 L p .65 .846 .975 r
F P
0 g
s
.37515 .34866 m .36089 .37176 L .29328 .41562 L p 0 0 0 r
F P
0 g
s
.28114 .44958 m .29328 .41562 L .36089 .37176 L p .226 0 .26 r
F P
0 g
s
.79533 .47646 m .79893 .51648 L .74239 .46554 L p .947 .636 .411 r
F P
0 g
s
.74239 .46554 m .73945 .42504 L .79533 .47646 L p .947 .636 .411 r
F P
0 g
s
.54654 .30841 m .54938 .31845 L .45751 .32368 L p .36 0 0 r
F P
0 g
s
.4033 .80191 m .44337 .80597 L .45774 .81885 L p .435 .693 .974 r
F P
0 g
s
.49161 .81164 m .45774 .81885 L .44337 .80597 L p .535 .737 .968 r
F P
0 g
s
.45774 .81885 m .49161 .81164 L .50235 .81662 L p .526 .758 .981 r
F P
0 g
s
.69599 .778 m .65559 .79109 L .65758 .76843 L p .789 .899 .92 r
F P
0 g
s
.65758 .76843 m .69945 .74784 L .69599 .778 L p .789 .899 .92 r
F P
0 g
s
.35257 .76314 m .39426 .7799 L .4033 .80191 L p .381 .605 .937 r
F P
0 g
s
.44337 .80597 m .4033 .80191 L .39426 .7799 L p .48 .674 .95 r
F P
0 g
s
.79798 .65364 m .77172 .6899 L .75128 .64585 L p .939 .873 .744 r
F P
0 g
s
.75128 .64585 m .77611 .60358 L .79798 .65364 L p .939 .873 .744 r
F P
0 g
s
.36089 .37176 m .37515 .34866 L .45751 .32368 L p .351 0 .12 r
F P
0 g
s
.28759 .66766 m .32063 .70281 L .3142 .7406 L p .292 .424 .824 r
F P
0 g
s
.35257 .76314 m .3142 .7406 L .32063 .70281 L p .394 .527 .872 r
F P
0 g
s
.60311 .8127 m .56509 .80852 L .57001 .80147 L p .679 .84 .961 r
F P
0 g
s
.57001 .80147 m .61327 .79872 L .60311 .8127 L p .679 .84 .961 r
F P
0 g
s
.52632 .79983 m .52994 .82016 L .51559 .81956 L closepath p .613 .786 .964 r
F P
0 g
s
.52632 .79983 m .54392 .81836 L .52994 .82016 L closepath p .621 .792 .964 r
F P
0 g
s
.52632 .79983 m .51559 .81956 L .50235 .81662 L closepath p .607 .779 .963 r
F P
0 g
s
.27782 .48985 m .28385 .53433 L .24465 .58678 L p .184 .11 .533 r
F P
0 g
s
.26164 .6284 m .24465 .58678 L .28385 .53433 L p .307 .273 .656 r
F P
0 g
s
.52632 .79983 m .55606 .81435 L .54392 .81836 L closepath p .63 .795 .962 r
F P
0 g
s
.52632 .79983 m .50235 .81662 L .49161 .81164 L closepath p .604 .771 .96 r
F P
0 g
s
.65559 .79109 m .61327 .79872 L .61416 .78363 L p .741 .861 .936 r
F P
0 g
s
.61416 .78363 m .65758 .76843 L .65559 .79109 L p .741 .861 .936 r
F P
0 g
s
.39426 .7799 m .43771 .79125 L .44337 .80597 L p .48 .674 .95 r
F P
0 g
s
.48453 .80512 m .44337 .80597 L .43771 .79125 L p .552 .722 .952 r
F P
0 g
s
.44337 .80597 m .48453 .80512 L .49161 .81164 L p .535 .737 .968 r
F P
0 g
s
.77172 .6899 m .73817 .72159 L .71977 .68448 L p .891 .868 .809 r
F P
0 g
s
.71977 .68448 m .75128 .64585 L .77172 .6899 L p .891 .868 .809 r
F P
0 g
s
.52632 .79983 m .56509 .80852 L .55606 .81435 L closepath p .64 .797 .958 r
F P
0 g
s
.32063 .70281 m .3586 .7328 L .35257 .76314 L p .394 .527 .872 r
F P
0 g
s
.39426 .7799 m .35257 .76314 L .3586 .7328 L p .469 .603 .903 r
F P
0 g
s
.72877 .39187 m .73945 .42504 L .65526 .38763 L p .837 .452 .321 r
F P
0 g
s
.65526 .38763 m .64867 .35572 L .72877 .39187 L p .837 .452 .321 r
F P
0 g
s
.63804 .33383 m .64867 .35572 L .5516 .33905 L p .676 .22 .163 r
F P
0 g
s
.5516 .33905 m .54938 .31845 L .63804 .33383 L p .676 .22 .163 r
F P
0 g
s
.52632 .79983 m .49161 .81164 L .48453 .80512 L closepath p .605 .764 .955 r
F P
0 g
s
.79893 .51648 m .79241 .55966 L .73707 .51121 L p .937 .705 .562 r
F P
0 g
s
.73707 .51121 m .74239 .46554 L .79893 .51648 L p .937 .705 .562 r
F P
0 g
s
.36089 .37176 m .35205 .40424 L .28114 .44958 L p .226 0 .26 r
F P
0 g
s
.27782 .48985 m .28114 .44958 L .35205 .40424 L p .359 .152 .456 r
F P
0 g
s
.52632 .79983 m .57001 .80147 L .56509 .80852 L closepath p .648 .795 .953 r
F P
0 g
s
.61327 .79872 m .57001 .80147 L .57023 .79394 L p .697 .826 .944 r
F P
0 g
s
.57023 .79394 m .61416 .78363 L .61327 .79872 L p .697 .826 .944 r
F P
0 g
s
.3586 .7328 m .39947 .75721 L .39426 .7799 L p .469 .603 .903 r
F P
0 g
s
.43771 .79125 m .39426 .7799 L .39947 .75721 L p .527 .663 .923 r
F P
0 g
s
.43771 .79125 m .4819 .79774 L .48453 .80512 L p .552 .722 .952 r
F P
0 g
s
.52632 .79983 m .48453 .80512 L .4819 .79774 L closepath p .609 .758 .95 r
F P
0 g
s
.73817 .72159 m .69945 .74784 L .68372 .71817 L p .843 .857 .854 r
F P
0 g
s
.68372 .71817 m .71977 .68448 L .73817 .72159 L p .843 .857 .854 r
F P
0 g
s
.28385 .53433 m .29891 .58044 L .26164 .6284 L p .307 .273 .656 r
F P
0 g
s
.28759 .66766 m .26164 .6284 L .29891 .58044 L p .391 .389 .737 r
F P
0 g
s
.45093 .34473 m .45751 .32368 L .54938 .31845 L p .547 .12 .182 r
F P
0 g
s
.45751 .32368 m .45093 .34473 L .36089 .37176 L p .351 0 .12 r
F P
0 g
s
.52632 .79983 m .57023 .79394 L .57001 .80147 L closepath p .655 .791 .947 r
F P
0 g
s
.39947 .75721 m .44164 .77622 L .43771 .79125 L p .527 .663 .923 r
F P
0 g
s
.4819 .79774 m .43771 .79125 L .44164 .77622 L p .574 .712 .936 r
F P
0 g
s
.54938 .31845 m .5516 .33905 L .45093 .34473 L p .547 .12 .182 r
F P
0 g
s
.69945 .74784 m .65758 .76843 L .64509 .74635 L p .796 .842 .886 r
F P
0 g
s
.64509 .74635 m .68372 .71817 L .69945 .74784 L p .796 .842 .886 r
F P
0 g
s
.44164 .77622 m .48409 .79027 L .4819 .79774 L p .574 .712 .936 r
F P
0 g
s
.52632 .79983 m .4819 .79774 L .48409 .79027 L closepath p .615 .754 .944 r
F P
0 g
s
.35205 .40424 m .36089 .37176 L .45093 .34473 L p .477 .164 .357 r
F P
0 g
s
.52632 .79983 m .55674 .7807 L .56566 .78675 L closepath p .659 .778 .937 r
F P
0 g
s
.52632 .79983 m .5444 .77648 L .55674 .7807 L closepath p .657 .771 .933 r
F P
0 g
s
.52632 .79983 m .53002 .77457 L .5444 .77648 L closepath p .653 .764 .931 r
F P
0 g
s
.52632 .79983 m .51523 .77522 L .53002 .77457 L closepath p .647 .758 .931 r
F P
0 g
s
.52632 .79983 m .50168 .77833 L .51523 .77522 L closepath p .639 .754 .932 r
F P
0 g
s
.52632 .79983 m .49091 .78355 L .50168 .77833 L closepath p .631 .752 .935 r
F P
0 g
s
.52632 .79983 m .48409 .79027 L .49091 .78355 L closepath p .622 .752 .939 r
F P
0 g
s
.52632 .79983 m .56566 .78675 L .57023 .79394 L closepath p .658 .785 .942 r
F P
0 g
s
.79241 .55966 m .77611 .60358 L .72382 .55936 L p .911 .742 .66 r
F P
0 g
s
.72382 .55936 m .73707 .51121 L .79241 .55966 L p .911 .742 .66 r
F P
0 g
s
.65758 .76843 m .61416 .78363 L .60541 .76907 L p .75 .825 .91 r
F P
0 g
s
.60541 .76907 m .64509 .74635 L .65758 .76843 L p .75 .825 .91 r
F P
0 g
s
.29891 .58044 m .3218 .62557 L .28759 .66766 L p .391 .389 .737 r
F P
0 g
s
.32063 .70281 m .28759 .66766 L .3218 .62557 L p .453 .477 .794 r
F P
0 g
s
.61416 .78363 m .57023 .79394 L .56566 .78675 L p .705 .806 .928 r
F P
0 g
s
.56566 .78675 m .60541 .76907 L .61416 .78363 L p .705 .806 .928 r
F P
0 g
s
.455 .76255 m .49091 .78355 L .48409 .79027 L p .598 .708 .92 r
F P
0 g
s
.48409 .79027 m .44164 .77622 L .455 .76255 L p .598 .708 .92 r
F P
0 g
s
.35205 .40424 m .34963 .44491 L .27782 .48985 L p .359 .152 .456 r
F P
0 g
s
.28385 .53433 m .27782 .48985 L .34963 .44491 L p .439 .287 .577 r
F P
0 g
s
.73945 .42504 m .74239 .46554 L .65708 .42844 L p .851 .551 .482 r
F P
0 g
s
.65708 .42844 m .65526 .38763 L .73945 .42504 L p .851 .551 .482 r
F P
0 g
s
.3218 .62557 m .35075 .66749 L .32063 .70281 L p .453 .477 .794 r
F P
0 g
s
.3586 .7328 m .32063 .70281 L .35075 .66749 L p .501 .548 .837 r
F P
0 g
s
.60541 .76907 m .56566 .78675 L .55674 .7807 L p .704 .784 .914 r
F P
0 g
s
.41898 .73637 m .455 .76255 L .44164 .77622 L p .571 .661 .898 r
F P
0 g
s
.44164 .77622 m .39947 .75721 L .41898 .73637 L p .571 .661 .898 r
F P
0 g
s
.64867 .35572 m .65526 .38763 L .55297 .37035 L p .736 .38 .377 r
F P
0 g
s
.55297 .37035 m .5516 .33905 L .64867 .35572 L p .736 .38 .377 r
F P
0 g
s
.35075 .66749 m .38376 .70467 L .3586 .7328 L p .501 .548 .837 r
F P
0 g
s
.39947 .75721 m .3586 .7328 L .38376 .70467 L p .539 .608 .871 r
F P
0 g
s
.47651 .75184 m .50168 .77833 L .49091 .78355 L p .622 .709 .908 r
F P
0 g
s
.49091 .78355 m .455 .76255 L .47651 .75184 L p .622 .709 .908 r
F P
0 g
s
.38376 .70467 m .41898 .73637 L .39947 .75721 L p .539 .608 .871 r
F P
0 g
s
.77611 .60358 m .75128 .64585 L .70371 .60714 L p .88 .763 .728 r
F P
0 g
s
.70371 .60714 m .72382 .55936 L .77611 .60358 L p .88 .763 .728 r
F P
0 g
s
.55674 .7807 m .58772 .75671 L .60541 .76907 L p .704 .784 .914 r
F P
0 g
s
.58772 .75671 m .55674 .7807 L .5444 .77648 L p .696 .763 .903 r
F P
0 g
s
.64509 .74635 m .60541 .76907 L .58772 .75671 L p .744 .787 .887 r
F P
0 g
s
.50385 .74542 m .51523 .77522 L .50168 .77833 L p .645 .716 .9 r
F P
0 g
s
.50168 .77833 m .47651 .75184 L .50385 .74542 L p .645 .716 .9 r
F P
0 g
s
.5444 .77648 m .56293 .74802 L .58772 .75671 L p .696 .763 .903 r
F P
0 g
s
.56293 .74802 m .5444 .77648 L .53002 .77457 L p .683 .744 .897 r
F P
0 g
s
.44684 .37623 m .45093 .34473 L .5516 .33905 L p .625 .291 .386 r
F P
0 g
s
.45093 .34473 m .44684 .37623 L .35205 .40424 L p .477 .164 .357 r
F P
0 g
s
.53383 .74409 m .53002 .77457 L .51523 .77522 L p .665 .728 .896 r
F P
0 g
s
.51523 .77522 m .50385 .74542 L .53383 .74409 L p .665 .728 .896 r
F P
0 g
s
.53002 .77457 m .53383 .74409 L .56293 .74802 L p .683 .744 .897 r
F P
0 g
s
.75128 .64585 m .71977 .68448 L .67835 .65211 L p .848 .775 .78 r
F P
0 g
s
.67835 .65211 m .70371 .60714 L .75128 .64585 L p .848 .775 .78 r
F P
0 g
s
.34963 .44491 m .35403 .49161 L .28385 .53433 L p .439 .287 .577 r
F P
0 g
s
.29891 .58044 m .28385 .53433 L .35403 .49161 L p .491 .383 .659 r
F P
0 g
s
.34963 .44491 m .35205 .40424 L .44684 .37623 L p .542 .299 .496 r
F P
0 g
s
.68372 .71817 m .64509 .74635 L .61891 .72741 L p .781 .786 .857 r
F P
0 g
s
.58772 .75671 m .61891 .72741 L .64509 .74635 L p .744 .787 .887 r
F P
0 g
s
.45109 .71992 m .47651 .75184 L .455 .76255 L p .611 .666 .879 r
F P
0 g
s
.455 .76255 m .41898 .73637 L .45109 .71992 L p .611 .666 .879 r
F P
0 g
s
.5516 .33905 m .55297 .37035 L .44684 .37623 L p .625 .291 .386 r
F P
0 g
s
.71977 .68448 m .68372 .71817 L .64954 .69249 L p .815 .783 .822 r
F P
0 g
s
.64954 .69249 m .67835 .65211 L .71977 .68448 L p .815 .783 .822 r
F P
0 g
s
.61891 .72741 m .64954 .69249 L .68372 .71817 L p .781 .786 .857 r
F P
0 g
s
.74239 .46554 m .73707 .51121 L .65379 .47597 L p .845 .611 .584 r
F P
0 g
s
.65379 .47597 m .65708 .42844 L .74239 .46554 L p .845 .611 .584 r
F P
0 g
s
.61891 .72741 m .58772 .75671 L .56293 .74802 L p .728 .752 .872 r
F P
0 g
s
.42605 .68228 m .45109 .71992 L .41898 .73637 L p .596 .621 .846 r
F P
0 g
s
.41898 .73637 m .38376 .70467 L .42605 .68228 L p .596 .621 .846 r
F P
0 g
s
.35403 .49161 m .36497 .54151 L .29891 .58044 L p .491 .383 .659 r
F P
0 g
s
.3218 .62557 m .29891 .58044 L .36497 .54151 L p .528 .457 .72 r
F P
0 g
s
.4923 .70999 m .50385 .74542 L .47651 .75184 L p .646 .678 .866 r
F P
0 g
s
.47651 .75184 m .45109 .71992 L .4923 .70999 L p .646 .678 .866 r
F P
0 g
s
.65526 .38763 m .65708 .42844 L .55335 .4113 L p .756 .474 .505 r
F P
0 g
s
.55335 .4113 m .55297 .37035 L .65526 .38763 L p .756 .474 .505 r
F P
0 g
s
.56293 .74802 m .5817 .71401 L .61891 .72741 L p .728 .752 .872 r
F P
0 g
s
.5817 .71401 m .56293 .74802 L .53383 .74409 L p .705 .722 .863 r
F P
0 g
s
.40242 .63916 m .42605 .68228 L .38376 .70467 L p .578 .572 .81 r
F P
0 g
s
.38376 .70467 m .35075 .66749 L .40242 .63916 L p .578 .572 .81 r
F P
0 g
s
.36497 .54151 m .38156 .59159 L .3218 .62557 L p .528 .457 .72 r
F P
0 g
s
.35075 .66749 m .3218 .62557 L .38156 .59159 L p .556 .518 .769 r
F P
0 g
s
.5377 .70792 m .53383 .74409 L .50385 .74542 L p .678 .697 .861 r
F P
0 g
s
.50385 .74542 m .4923 .70999 L .5377 .70792 L p .678 .697 .861 r
F P
0 g
s
.64954 .69249 m .61891 .72741 L .5817 .71401 L p .754 .738 .838 r
F P
0 g
s
.53383 .74409 m .5377 .70792 L .5817 .71401 L p .705 .722 .863 r
F P
0 g
s
.38156 .59159 m .40242 .63916 L .35075 .66749 L p .556 .518 .769 r
F P
0 g
s
.73707 .51121 m .72382 .55936 L .64562 .52729 L p .832 .65 .657 r
F P
0 g
s
.64562 .52729 m .65379 .47597 L .73707 .51121 L p .832 .65 .657 r
F P
0 g
s
.44684 .37623 m .44572 .41713 L .34963 .44491 L p .542 .299 .496 r
F P
0 g
s
.35403 .49161 m .34963 .44491 L .44572 .41713 L p .579 .389 .588 r
F P
0 g
s
.44572 .41713 m .44684 .37623 L .55297 .37035 L p .66 .395 .508 r
F P
0 g
s
.48088 .66868 m .4923 .70999 L .45109 .71992 L p .644 .64 .831 r
F P
0 g
s
.45109 .71992 m .42605 .68228 L .48088 .66868 L p .644 .64 .831 r
F P
0 g
s
.55297 .37035 m .55335 .4113 L .44572 .41713 L p .66 .395 .508 r
F P
0 g
s
.67835 .65211 m .64954 .69249 L .60023 .6742 L p .778 .722 .801 r
F P
0 g
s
.5817 .71401 m .60023 .6742 L .64954 .69249 L p .754 .738 .838 r
F P
0 g
s
.72382 .55936 m .70371 .60714 L .63327 .57921 L p .816 .68 .713 r
F P
0 g
s
.63327 .57921 m .64562 .52729 L .72382 .55936 L p .816 .68 .713 r
F P
0 g
s
.60023 .6742 m .5817 .71401 L .5377 .70792 L p .722 .698 .827 r
F P
0 g
s
.70371 .60714 m .67835 .65211 L .61776 .62888 L p .798 .703 .76 r
F P
0 g
s
.60023 .6742 m .61776 .62888 L .67835 .65211 L p .778 .722 .801 r
F P
0 g
s
.65708 .42844 m .65379 .47597 L .55266 .4597 L p .761 .535 .59 r
F P
0 g
s
.55266 .4597 m .55335 .4113 L .65708 .42844 L p .761 .535 .59 r
F P
0 g
s
.61776 .62888 m .63327 .57921 L .70371 .60714 L p .798 .703 .76 r
F P
0 g
s
.54153 .66585 m .5377 .70792 L .4923 .70999 L p .686 .666 .825 r
F P
0 g
s
.4923 .70999 m .48088 .66868 L .54153 .66585 L p .686 .666 .825 r
F P
0 g
s
.44572 .41713 m .44775 .46524 L .35403 .49161 L p .579 .389 .588 r
F P
0 g
s
.36497 .54151 m .35403 .49161 L .44775 .46524 L p .603 .456 .655 r
F P
0 g
s
.5377 .70792 m .54153 .66585 L .60023 .6742 L p .722 .698 .827 r
F P
0 g
s
.47006 .62186 m .48088 .66868 L .42605 .68228 L p .639 .6 .794 r
F P
0 g
s
.42605 .68228 m .40242 .63916 L .47006 .62186 L p .639 .6 .794 r
F P
0 g
s
.44775 .46524 m .44572 .41713 L .55335 .4113 L p .677 .465 .591 r
F P
0 g
s
.44775 .46524 m .45282 .51754 L .36497 .54151 L p .603 .456 .655 r
F P
0 g
s
.38156 .59159 m .36497 .54151 L .45282 .51754 L p .619 .51 .708 r
F P
0 g
s
.61776 .62888 m .60023 .6742 L .54153 .66585 L p .736 .673 .789 r
F P
0 g
s
.46047 .57074 m .47006 .62186 L .40242 .63916 L p .631 .557 .753 r
F P
0 g
s
.40242 .63916 m .38156 .59159 L .46047 .57074 L p .631 .557 .753 r
F P
0 g
s
.55335 .4113 m .55266 .4597 L .44775 .46524 L p .677 .465 .591 r
F P
0 g
s
.45282 .51754 m .46047 .57074 L .38156 .59159 L p .619 .51 .708 r
F P
0 g
s
.65379 .47597 m .64562 .52729 L .55096 .51251 L p .759 .579 .653 r
F P
0 g
s
.55096 .51251 m .55266 .4597 L .65379 .47597 L p .759 .579 .653 r
F P
0 g
s
.54517 .61824 m .54153 .66585 L .48088 .66868 L p .69 .633 .787 r
F P
0 g
s
.48088 .66868 m .47006 .62186 L .54517 .61824 L p .69 .633 .787 r
F P
0 g
s
.54153 .66585 m .54517 .61824 L .61776 .62888 L p .736 .673 .789 r
F P
0 g
s
.63327 .57921 m .61776 .62888 L .54517 .61824 L p .746 .646 .749 r
F P
0 g
s
.64562 .52729 m .63327 .57921 L .54839 .56637 L p .754 .615 .705 r
F P
0 g
s
.54839 .56637 m .55096 .51251 L .64562 .52729 L p .754 .615 .705 r
F P
0 g
s
.45282 .51754 m .44775 .46524 L .55266 .4597 L p .686 .518 .653 r
F P
0 g
s
.54517 .61824 m .54839 .56637 L .63327 .57921 L p .746 .646 .749 r
F P
0 g
s
.54839 .56637 m .54517 .61824 L .47006 .62186 L p .692 .598 .747 r
F P
0 g
s
.47006 .62186 m .46047 .57074 L .54839 .56637 L p .692 .598 .747 r
F P
0 g
s
.55266 .4597 m .55096 .51251 L .45282 .51754 L p .686 .518 .653 r
F P
0 g
s
.46047 .57074 m .45282 .51754 L .55096 .51251 L p .691 .561 .703 r
F P
0 g
s
.55096 .51251 m .54839 .56637 L .46047 .57074 L p .691 .561 .703 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
KOooool@o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0GOoo
ool?o`0000coG00000Co0000ogl00?mo003oO`001ol0000Rooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Iooooo`?o00000_lH00000ol0003oG000oe`0000Goe`00003o`000?mo003oO`0000KoO`002?l0
000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Eooooo`?o00001?lH00000ol0003oG000oe`0000A
oe`000_o00003?mo0007o`0001Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0X
ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo053ooooo1?l00006oaP0
0003o`000?mL003oG00000?oG0003ol00007oh`N;P04o`000?n]>2Wo[CPYojdh:@Go00003Omo0004
o`0001;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`00
01[ooooo00?o0000ooooooooool0C?ooool3o`0000Oo60002Ol0000Foh`N;P03o`000?n]>2Wo[CPY
00Ko[CPY1_l0000:ogl000?o00004Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
02Kooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?ooool3o`0000Oo
60000ol00002oeT07P03o`000?n<7RkoS1h^01[oS1h^00?o0000ojdh:On]>2T03?n]>2T6o`0000Go
O`0000?o0000oh@00?l000000_l0000>ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14ooooo`?o0000
1_lH0004o`0000CoF@0N00?o0000oh`N;_n<7Rh07?n<7Rh00ol0003o[CPYojdh:@0Aojdh:@Go0000
00?oO`00o`000?n400000_n40002o`0000cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Uooooo`00:Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo0ol0
0005oaP000Co00002?mI01h00ol0003oS1h^oh`N;P0Loh`N;P03o`000?n]>2Wo[CPY01Ko[CPY1?l0
0003oh@000;o00002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003o6000oaP00003
oaP000?o00003?mI01h00ol0003oS1h^oh`N;P0Doh`N;Pco00005on]>2T01?l0003o`T@;o`000?l0
0003oh@000;o00002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000X
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool2o`0000;o60001?l0000>
oeT07P03o`000?n<7RkoS1h^00GoS1h^4?l00008oim:HP04o`000?nlHF3o_65PokaQH0Go00004on]
>2T00ol0003o`T@;ol942`03o`0000;oQ0000_l00006ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03o`000?oooooooooo03Wooooo1Ol0000@
oeT07P[o00006?nOBV800ol0003o_65PokaQH006okaQH0Go00003_n]>2T00ol0003o`T@;ol942`03
ol942`;o00000_n40003o`0000?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0S
ooooo`00:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Kooooo1?l0000@oeT0
7P?o00000_mj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P00_o_65P1Ol0000:ojdh
:@03o`000?o2A0_o`T@;00Co`T@;0_l00003oh@000;o000000?oooooo`000?ooool0>_ooool00ol0
003oooooooooo`0Rooooo`00:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03?o
oooo1Ol0000>oeT07P?o00001Omj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P013o
_65P1Ol00005ojdh:@03o`000?o2A0_o`T@;00Ko`T@;0ol00002oh@000;o0000??ooool00ol0003o
ooooooooo`0Qooooo`00:?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo
1Ol0000<oeT07P?o00002?mj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P01Go_65P
1_l0000;ol942`;o000000?oQ000o`000?l00000>oooool00ol0003oooooooooo`0Qooooo`009ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo1_l0000:oeT07P?o00002omj
:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P01[o_65P0ol0000;ol942`;o000000?o
Q000o`000?l00000>_ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo1ol00007oeT07P?o00003_mj:E/00ol0003oWdYRoim:HP0M
oim:HP03o`000?nlHF3o_65P01_o_65P00Co0000omIcD_l0003o00002_o2A0/5o`0003Wooooo00?o
0000ooooooooool08?ooool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Y
ooooo`So00001OmI01h3o`00013oNRUK00?o0000oim:H_nOBV807_nOBV800ol0003o_65PokaQH00K
okaQH004o`000?oFLe;oeW=BomIcDP?o00001oo2A0/01?l0003o`T@;ol942oo2A0/2o`0003Wooooo
00?o0000ooooooooool07oooool002Oooooo0_l0000Yooooo`03o`000?oooooooooo02Oooooo2Ol0
0002oeT07P?o00004omj:E/00ol0003oWdYRoim:HP0Noim:HP03o`000?nlHF3o_65P01co_65P00?o
0000omIcD_oFLe800ooFLe82o`0000Go`T@;00?o0000ol942oo2A0/00oo2A0/00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09?ooool=o`0001KoNRUK00?o0000oim:H_nOBV805_nOBV8<o`0001_o_65P00?o0000
omIcD_oFLe801OoFLe82o`0000?o`T@;00?o0000ol942oo2A0/00oo2A0/2o`0003Sooooo00?o0000
ooooooooool07_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Roooo
o`_o00006Omj:E/00ol0003oWdYRoim:HP05oim:HQ7o00002?nXIH801?l0003o`GV1ol5iPOo1NH45
o`0001Ko_65P00?o0000omIcD_oFLe801ooFLe84o`0000Ko`T@;0_l0000hooooo`03o`000?oooooo
oooo01gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08?ooool9o`00
0003ocT0@_l0003oNRUK01OoNRUK2_l0000IojQUPP03o`000?o1NH7o`GV100Ko`GV11Ol0000AokaQ
H003o`000?oFLe;oeW=B00[oeW=B0_l00006ol942`;o0000=oooool00ol0003oooooooooo`0Moooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01gooooo2_l00002ocT0@P03
o`000?mj:E_oNRUK01?oNRUK0ol00002ohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1
NH402oo1NH46o`0000_o_65P00?o0000omIcD_oFLe802_oFLe801?l0003oeW=Bo`000?l00004ol94
2`03o`000?ne=@3o000003Oooooo00?o0000ooooooooool07?ooool002Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Kooooo`Wo00000oli04800ol0003oNRUKogXYF`0AogXYF`?o
00001On:C7h00ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV1017o`GV11Ol00007okaQH003
o`000?oFLe;oeW=B00WoeW=B00Co0000omIcD_oFLe;oeW=B0_l00003ol942`03o`000?ne=@3o0000
03Oooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_ooooo`03o`000?oooooooooo01Wo
oooo2?l00005ocT0@P03o`000?mj:E_oNRUK00goNRUK1?l00008ohY<OP03o`000?nXIH;oZ6F201ko
Z6F200?o0000ol5iPOo1NH405_o1NH45o`0000;o_65P00?o0000omIcD_oFLe802_oFLe800ol0003o
eW=BomIcDP02omIcDPCo00000_ne=@000ol0003oooooooooo`0dooooo`03o`000?oooooooooo01_o
oooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool8o`0000Ko>@12
00?o0000ogXYFomj:E/02_mj:E/3o`0000coRTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1
ol5iP@0Kol5iP@Co00002ooFLe800ol0003oeW=BomIcDP05omIcDP;o00000_ne=@000ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool05_ooool6o`0000Oo>@1200?o0000ogXYFomj:E/02?mj:E/3o`0000oo
RTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Mol5iP@03o`000?oISG_o000000;o
00002?oFLe800ol0003oeW=BomIcDP07omIcDP;o000000?o]CD0o`000?ooool0=?ooool00ol0003o
ooooooooo`0Jooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`Go
00002Oli04800ol0003oNRUKogXYF`04ogXYF`Co00004_n:C7h00ol0003oZ6F2ojQUPP0NojQUPP03
o`000?o1NH7o`GV101go`GV100?o0000omV=NooISG/00_oISG/2o`0000KoeW=B00?o0000omIcD_oF
Le801ooFLe801Ol0003oigdXo`000?ne=@3o000003Gooooo00?o0000ooooooooool06Oooool000?o
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool5o`0000[o>@1200Co0000ogXY
Fomj:E_oNRUK0ol0000FohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1NH407Oo1NH40
0ol0003ofHekomV=N`04omV=N`?o00000ooFLe800ol0003oeW=BomIcDP08omIcDP05o`000?oWOBSo
0000okDe0?l00000=Oooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo013ooooo1?l0000;ocT0@P03o`000?mj:E_o000000;o00006On:C7h00ol0003oZ6F2ojQU
PP0NojQUPP03o`000?o1NH7o`GV101go`GV100?o0000omV=NooISG/01ooISG/2o`000003omIcD_l0
003oeW=B00WoeW=B00Ko0000onMm:?oWOBSo0000okDe0?l0000dooooo`03o`000?oooooooooo01So
oooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`?o00002oli0483o`00
01coRTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Mol5iP@03o`000?oISG_ofHek
00WofHek0ol00009omIcDP07o`000?oWOBSoigdXonMm:?l0003o]CD0o`00000dooooo`03o`000?oo
oooooooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`;o0000>?ooool00ol0003oooooooooo`0=ooooo`;o00003?li04800ol0003oFbIdo`00
000MohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1NH407Oo1NH400ol0003ofHekomV=
N`0:omV=N`04o`000?oISG_o0000o`0000SoeW=B00Oo0000onMm:?oWOBSoigdXo`000?ne=@3o0000
03?ooooo00?o0000ooooooooool05oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;oooo
o`03o`000?li04;o>@1200[o>@120_l00002oe/VM003o`000?n:C7koRTan01_oRTan00?o0000ojQU
P_nXIH805_nXIH8<o`0001go`GV100?o0000omV=NooISG/02OoISG/01?l0003ofHekomV=NooISG/2
o`0000KoeW=B00?o0000onMm:?oWOBP00_oWOBP00ol0003o]CD0o`00000cooooo`03o`000?oooooo
oooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?li04;o>@1200Wo>@120_l00004
oe/VM003o`000?n:C7koRTan01_oRTan00?o0000ojQUP_nXIH801OnXIH8Ao`0000So[GNG00Co0000
ol:8Uoo2R9Oo`XRG1ol0000Fol5iP@03o`000?oISG_ofHek00WofHek00?o0000omV=NooISG/00ooI
SG/3o`0000CoeW=B00?o0000onMm:?oWOBP00_oWOBP00ol0003o]CD0o`00000aooooo`?o00005ooo
ool002Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?li04;o
>@1200So>@1200?o0000oe/VM?mK9W@01?mK9W@00ol0003oRTanohY<OP0IohY<OP[o00006On]MiL0
0ol0003o`XRGol:8U`08ol:8U`Oo00003oo1NH400ol0003ofHekomV=N`09omV=N`03o`000?oISG_o
fHek00KofHek0_l00002omIcDP03o`000?oWOBSoigdX00?oigdX0_l0000^ooooo`?o00000_ooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Oooooo00?o0000ocT0@_li04801oli0482o`0000OoFbId00?o0000ohY<O_n:C7h05_n:C7h3o`00
00;oU6>F00?o0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0?ol:8U`Ko00002Oo1NH400ol0
003ofHekomV=N`09omV=N`03o`000?oISG_ofHek00SofHek0ol00006onMm:0;o0000:_ooool3o`00
00Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`05ooooo`;o00002?li04800ol0003oFbIdoe/VM007oe/VM003o`000?n:C7koRTan01?o
RTan0ol00005oiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L05Oo2R9L7o`0000;o
`GV100?o0000omV=NooISG/02OoISG/00ol0003ofHekomV=N`0;omV=N`;o00001OoWOBP2o`0002Ko
oooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01?ooool2o`0000Ko>@120_l0000:oe/VM003o`000?n:C7koRTan00ooRTan
1?l00008oiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07?o2R9L4o`0000[ofHek
00?o0000omV=NooISG/02ooISG/00ol0003olZ9Yo`000005onMm:0;o00008_ooool3o`0000_ooooo
00?o0000ooooooooool05Oooool002Cooooo0_l0000oooooo`03o`000?oooooooooo00;ooooo0_l0
0006ocT0@P03o`000?mK9WCoFbId00[oFbId00?o0000ohY<O_n:C7h03?n:C7h3o`0000coU6>F00?o
0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0Nol:8U`04o`000?oHW9Go0000o`0000SofHek
00?o0000omV=NooISG/02ooISG/01?l0003olZ9Yoo:RJOl00005onMm:0;o00007_ooool3o`0000oo
oooo00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`03o`0000Co>@120_l0000=oe/VM003o`000?n:C7koRTan00WoRTan0ol0000?oiASUP03o`00
0?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L01?l0003of9bEomRLUOoHW9D2o`0000Ko
fHek00?o0000omV=NooISG/02ooISG/01Ol0003olZ9Yoo:RJOobXVWo000000GoigdX00?o0000oooo
ooooool06Oooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0@Oooool5o`0000;o>@120_l0000?oe/VM003o`000?n:C7koRTan00GoRTan1?l0000BoiASUP03
o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L00ol0003of9bEomRLU@03omRLU@?o
00000ooISG/00ol0003ofHekomV=N`0;omV=N`03o`000?obXVWolZ9Y00;olZ9Y00?o0000onMm:?oW
OBP00ooWOBP00ol0003oooooooooo`0Eooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`00
8oooool00ol0003oooooooooo`12ooooo`?o00000_li04800ol0003oFbIdoe/VM00?oe/VM003o`00
0?n:C7koRTan00;oRTan0ol0000FoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L0
7_o2R9L00ol0003of9bEomRLU@06omRLU@;o000000?ofHeko`000?oISG/03?oISG/00ol0003olZ9Y
oo:RJ@03oo:RJ@03o`000?oWOBSoigdX00?oigdX00?o0000ooooooooool04Oooool3o`0001Sooooo
00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@Oooool6o`0001;oFbId00?o
0000ohY<O_l000000_l0000IoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2
R9L00ol0003of9bEomRLU@08omRLU@?o00003?oISG/00ol0003olZ9Yoo:RJ@04oo:RJ@03o`000?oW
OBSoigdX00?oigdX00?o0000ooooooooool03Oooool3o`0001_ooooo00?o0000ooooooooool05?oo
ool002?ooooo00?o0000ooooooooool0@?ooool5o`0001?oFbId0ol0000LoiASUP03o`000?n]MiOo
[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L00ol0003of9bEomRLU@0:omRLU@;o00002ooISG/0
0ol0003olZ9Yoo:RJ@05oo:RJ@03o`000?oWOBSoigdX00;oigdX00?o0000ooooooooool02_ooool3
o`0001kooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@?ooool4o`00
01?oFbId00?o0000og19Tol000007OnDHiH00ol0003o[GNGojegU`0NojegU`03o`000?o2R9Oo`XRG
01ko`XRG00?o0000omRLUOoHW9D02_oHW9D01?l0003of9bEo`000?l00009omV=N`03o`000?obXVWo
lZ9Y00KolZ9Y00?o0000onMm:?oWOBP00_oWOBP00ol0003oooooooooo`06ooooo`?o00008Oooool0
0ol0003oooooooooo`0Dooooo`008oooool2o`00043ooooo1Ol0000Aoe/VM0;o00000_m`BI<00ol0
003oU6>FoiASUP0KoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07Oo2R9L00ol0
003of9bEomRLU@0;omRLU@04o`000?oHW9Gof9bEomRLU@;o00001ooISG/00ol0003olZ9Yoo:RJ@07
oo:RJ@05o`000?oWOBSoigdXonMm:?l000001Oooool3o`0002Gooooo00?o0000ooooooooool04ooo
ool002?ooooo00?o0000ooooooooool0?_ooool6o`0000ooFbId0_l00004og19T`03o`000?nDHiKo
U6>F01_oU6>F00?o0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0Mol:8U`03o`000?oHW9Go
f9bE00_of9bE00?o0000omRLUOoHW9D00ooHW9D3o`0000CofHek00?o0000oo:RJOobXVT02?obXVT0
1?l0003oigdXonMm:?l00002ooooo`?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_ooool0
0ol0003oooooooooo`0nooooo`Go000000?o001Co`000?mK9W@03OmK9W@00ol0003oL4VCog19T`04
og19T`03o`000?nDHiKoU6>F01_oU6>F00?o0000ojegUon]MiL05_n]MiL<o`0001co`XRG00?o0000
omRLUOoHW9D02ooHW9D00ol0003of9bEomRLU@06omRLU@;o00000_oISG/00ol0003olZ9Yoo:RJ@09
oo:RJ@03o`000?oWOBSoigdX00;o0000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0
003oooooooooo`0nooooo`Go000000?o001Co`000?mK9W@02omK9W@2o`0000OoL4VC00?o0000oiAS
U_nDHiH06onDHiH00ol0003o[GNGojegU`05ojegUa7o00002?n_Q:L01?l0003o`YBWol:DYoo2U:L7
o`0001Go`XRG00?o0000omRLUOoHW9D02ooHW9D00ol0003of9bEomRLU@08omRLU@?o00003?obXVT0
0ol0003oigdXo`00000/ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
03gooooo1Ol00002o`00D`03o`000?mK9WCoFbId00SoFbId0_l00009og19T`03o`000?nDHiKoU6>F
01WoU6>F2_l0000Iojn4Y`03o`000?o2U:Oo`YBW00So`YBW1_l0000?ol:8U`03o`000?oHW9Gof9bE
00_of9bE00?o0000omRLUOoHW9D02_oHW9D2o`0000colZ9Y00?o0000onMm:?l00000:oooool00ol0
003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0looooo`Go00000ol005<00ol0003o
FbIdoe/VM007oe/VM003o`000?m`BI?oL4VC00WoL4VC00?o0000oiASU_nDHiH05_nDHiH3o`0000;o
VWBW00?o0000ojn4Yon_Q:L07_n_Q:L00ol0003o`YBWol:DY`0>ol:DY`Ko00002Oo2R9L00ol0003o
f9bEomRLU@0;omRLU@03o`000?oHW9Gof9bE00[of9bE00?o0000onndSol000003?obXVT2o`0002_o
oooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0??ooool4o`0000?o001C
00?o0000oe/VM?mK9W@01_mK9W@2o`0000goL4VC00?o0000oiASU_nDHiH04OnDHiH4o`0000GoVWBW
00?o0000ojn4Yon_Q:L07_n_Q:L00ol0003o`YBWol:DY`0Dol:DY`Oo00000_o2R9L00ol0003of9bE
omRLU@0;omRLU@03o`000?oHW9Gof9bE00[of9bE00Co0000onndSoo_]8oo00003?obXVT2o`0002[o
oooo00?o0000ooooooooool04oooool0027ooooo0ol0000looooo`Go00000ol005<00ol0003oFbId
oe/VM004oe/VM0;o00003om`BI<00ol0003oU6>FoiASUP0=oiASUPCo00002OnJM:L00ol0003o[hBW
ojn4Y`0Nojn4Y`03o`000?o2U:Oo`YBW01_o`YBW1?l0000<omRLU@03o`000?oHW9Gof9bE00[of9bE
00Go0000onndSoo_]8ookkB?o`00000<oo:RJ@03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04_ooool0027ooooo00?o0000ooooooooool0??ooool4o`0000Co001C00?o0000oe/VM?mK9W@0
0omK9W@00ol0003oL4VCog19T`0?og19T`03o`000?nDHiKoU6>F00[oU6>F0ol0000=oiYdY`03o`00
0?n_Q:Oo[hBW01ko[hBW00?o0000ol:DYoo2U:L07Oo2U:L00ol0003oe:JXo`000002o`0000Wof9bE
00?o0000omRLUOoHW9D02_oHW9D00ol0003okkB?onndS`02onndS`03o`000?obXVWolZ9Y00WolZ9Y
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`0looooo`?o00001Ol005<01?l0003oFbIdoe/VM?mK9W@2o`0001;oL4VC00?o0000oiASU_nDHiH0
1_nDHiH4o`00017oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBWol:DY`0Mol:DY`03o`00
0?oDYZSoe:JX00;oe:JX0_l00007omRLU@03o`000?oHW9Gof9bE00[of9bE00?o0000onndSoo_]8l0
0oo_]8l00ol0003olZ9Yoo:RJ@08oo:RJ@;o0000:_ooool00ol0003oooooooooo`0Booooo`008Ooo
ool00ol0003oooooooooo`0kooooo`Co00001Ol005<01?l0003oFbIdo`000?l0000Dog19T`03o`00
0?nDHiKoU6>F00;oU6>F1?l0000EoiYdY`03o`000?n_Q:Oo[hBW01go[hBW00?o0000ol:DYoo2U:L0
7Oo2U:L00ol0003oe:JXomBVZ004omBVZ0;o00001OoHW9D00ol0003of9bEomRLU@0:omRLU@03o`00
0?o_]8ookkB?00CokkB?00?o0000oo:RJOobXVT01oobXVT2o`0002[ooooo00?o0000ooooooooool0
4_ooool0027ooooo00?o0000ooooooooool0>oooool3o`0000Ko001C0_l0000Fog19T`03o`000?nD
HiKo000000;o00006OnJM:L00ol0003o[hBWojn4Y`0Mojn4Y`03o`000?o2U:Oo`YBW01co`YBW00?o
0000omBVZ?oDYZP01ooDYZP3o`0000;of9bE00?o0000omRLUOoHW9D02_oHW9D00ol0003okkB?onnd
S`05onndS`03o`000?obXVWolZ9Y00KolZ9Y0ol0000Yooooo`03o`000?oooooooooo01;ooooo000Q
ooooo`03o`000?oooooooooo03_ooooo0_l00007o`00D`03o`000?m`BI?oL4VC01CoL4VC0ol0000L
oiYdY`03o`000?n_Q:Oo[hBW01go[hBW00?o0000ol:DYoo2U:L07?o2U:L00ol0003oe:JXomBVZ00:
omBVZ0?o00002ooHW9D00ol0003okkB?onndS`07onndS`;o00001_obXVT00ol0003okJL]o`00000Y
ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03[ooooo0_l00008o`00
D`03o`000?m`BI?oL4VC01?oL4VC00?o0000ogeRZ?l000007OnJM:L00ol0003o[hBWojn4Y`0Mojn4
Y`03o`000?o2U:Oo`YBW01co`YBW00?o0000omBVZ?oDYZP03?oDYZP2o`0000[of9bE00?o0000onnd
Soo_]8l02Oo_]8l00ol0003olZ9Yoo:RJ@03oo:RJ@03o`000?o]Ybgo000002Wooooo00?o0000oooo
ooooool04_ooool0023ooooo0ol0000kooooo`;o00001ol005<2o`0001?oL4VC0_l00002ogeRZ003
o`000?nJM:OoVWBW01_oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBWol:DY`0Lol:DY`03
o`000?oDYZSoe:JX00coe:JX00?o0000omBVZ?l000000_l00007omRLU@03o`000?o_]8ookkB?00[o
kkB?00?o0000oo:RJOobXVT00oobXVT3o`0002Wooooo00?o0000ooooooooool04Oooool0023ooooo
00?o0000ooooooooool0>oooool00ol0003o001Co`00D`05o`00D`03o`000?l_78So0000017oL4VC
0_l00004ogeRZ003o`000?nJM:OoVWBW01_oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBW
ol:DY`0Lol:DY`03o`000?oDYZSoe:JX00goe:JX00Co0000omBVZ?oDYZSoe:JX0_l00005omRLU@03
o`000?o_]8ookkB?00_okkB?00?o0000oo:RJOobXVT00_obXVT00ol0003okJL]o`00000Yooooo`03
o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0jooooo`03o`000?l005?o001C00Ko001C00Co0000oblLR?l_78So00003om`BI<00ol0
003oOF:XogeRZ005ogeRZ003o`000?nJM:OoVWBW01[oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0
003o`YBWol:DY`0Kol:DY`03o`000?oDYZSoe:JX00koe:JX00?o0000omBVZ?oDYZP00ooDYZP2o`00
00?of9bE00?o0000onndSoo_]8l03?o_]8l01_l0003olZ9Yoo:RJOobXVWo0000onfW;@;o0000:?oo
ool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0>_ooool00ol0003o001Co`00D`05o`00D`05o`000?l_78So;ab8oblLR?l00000
3Om`BI<2o`0000SoOF:X00?o0000oiYdYonJM:L06onJM:L00ol0003o[hBWojn4Y`0Lojn4Y`03o`00
0?o2U:Oo`YBW01_o`YBW00?o0000omBVZ?oDYZP03_oDYZP00ol0003oe:JXomBVZ005omBVZ0Co0000
3oo_]8l01?l0003olZ9Yoo:RJOl00002onfW;@03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03[o
oooo00?o0000o`00Dol005<01?l005<00ol0003o;ab8oblLR002oblLR003o`000?m`BI?oL4VC00[o
L4VC00?o0000ogeRZ?mmHZP02?mmHZP00ol0003oVWBWoiYdY`0KoiYdY`03o`000?n_Q:Oo[hBW01co
[hBW00?o0000ol:DYoo2U:L06oo2U:L00ol0003oe:JXomBVZ00>omBVZ003o`000?oDYZSoe:JX00So
e:JX0_l0000?onndS`03o`000?obXVWo000000;okJL]00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0>_ooool00ol0003o001Co`00D`03o`00D`03o`000?l_78So;ab800?o;ab800?o0000og19Tom`
BI<02?m`BI<2o`0000_oOF:X00?o0000oiYdYonJM:L06onJM:L00ol0003o[hBWojn4Y`0=ojn4YaCo
00006Oo2U:L00ol0003oe:JXomBVZ00>omBVZ003o`000?oDYZSoe:JX00Soe:JX00?o0000onVmZ?l0
00003oo_]8l2o`0000;okJL]0_l0000Wooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0kooooo`03o`000?l005?o001C00?o
001C00?o0000oblLR?l_78P00ol_78P00ol0003oL4VCog19T`07og19T`03o`000?mmHZSoOF:X00_o
OF:X00?o0000oiYdYonJM:L06OnJM:LBo`0000oo/8nc00?o0000ol6M]?o1WK@00_o1WK@7o`0001;o
`YBW00?o0000omBVZ?oDYZP03_oDYZP00ol0003oe:JXomBVZ008omBVZ004o`000?oY_JSojKfXo`00
00ookkB?00Go0000onfW;Oo]YbgokJL]o`00000Wooooo`03o`000?oooooooooo017ooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41001Oooool2o`0003cooooo00?o0000o`00Dol005<00_l005<0
0ol0003o;ab8oblLR004oblLR003o`000?m`BI?oL4VC00GoL4VC0_l0000?ogeRZ003o`000?nJM:Oo
VWBW01GoVWBW0ol00002oij2]@03o`000?n`Sk?o/8nc01co/8nc00?o0000ol6M]?o1WK@02Oo1WK@7
o`0000[o`YBW00?o0000omBVZ?oDYZP03ooDYZP00ol0003oe:JXomBVZ007omBVZ003o`000?oY_JSo
jKfX00;ojKfX00?o0000onndSoo_]8l03?o_]8l01Ol0003okJL]onfW;Oo]Ybgo000002Oooooo00?o
0000ooooooooool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo03[ooooo0_l00003o`00D`03o`000?l_78So;ab800Go;ab800?o0000og19Tom`BI<00om`
BI<2o`00017oOF:X00?o0000oiYdYonJM:L04OnJM:L4o`0000GoWX:e00?o0000ok2?/on`Sk<07?n`
Sk<00ol0003o`Ifdol6M]00@ol6M]0Oo00000oo2U:L00ol0003oe:JXomBVZ00?omBVZ003o`000?oD
YZSoe:JX00Ooe:JX00?o0000onVmZ?oY_JP00ooY_JP00ol0003okkB?onndS`0;onndS`;o00000_o]
Ybd2o`0002Oooooo00?o0000ooooooooool04?ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo03[ooooo00?o0000o`00Dol005<00_l005<00ol0003o;ab8oblL
R006oblLR005o`000?m`BI?oL4VCog19Tol000004ommHZP00ol0003oVWBWoiYdY`0>oiYdY`?o0000
2OnNP[D00ol0003o/8ncok2?/`0Lok2?/`03o`000?o1WKCo`Ifd01Oo`Ifd1Ol0000@omBVZ003o`00
0?oDYZSoe:JX00Ooe:JX00?o0000onVmZ?oY_JP01?oY_JP00ol0003okkB?onndS`0:onndS`;o0000
0oo]Ybd00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oo
oooooooo03[ooooo00Go0000o`00Dol005?o001Co`000009oblLR004o`000?m`BI?o0000o`0001Co
OF:X00?o0000oiYdYonJM:L02_nJM:L4o`0000coWX:e00?o0000ok2?/on`Sk<07?n`Sk<00ol0003o
`Ifdol6M]00Jol6M]003o`000?o@[[Ko000000;o00003OoDYZP00ol0003oe:JXomBVZ007omBVZ003
o`000?oY_JSojKfX00GojKfX00?o0000onndSoo_]8l02?o_]8l00ol0003ooliho`000003onfW;@03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
>_ooool01?l0003o001Co`00Dol0000:oblLR0;o00005_mmHZP00ol0003oVWBWoiYdY`07oiYdY`?o
00004OnNP[D00ol0003o/8ncok2?/`0Kok2?/`03o`000?o1WKCo`Ifd01[o`Ifd00?o0000om2^]_o@
[[H00_o@[[H2o`0000_oe:JX00?o0000omBVZ?oDYZP01_oDYZP00ol0003ojKfXonVmZ007onVmZ0;o
00002?o_]8l01?l0003oolihooo>N?l00002onfW;@;o00009_ooool00ol0003oooooooooo`0@oooo
o`007oooool00ol0003oooooooooo`0jooooo`03o`000?l005?o000000_o;ab800?o0000ogeRZ?mm
HZP05_mmHZP00ol0003oVWBWoiYdY`02oiYdY`Co00005?nNP[D00ol0003o/8ncok2?/`0Kok2?/`03
o`000?o1WKCo`Ifd01Wo`Ifd00?o0000om2^]_o@[[H01Oo@[[H3o`0000Soe:JX00?o0000omBVZ?oD
YZP01_oDYZP00ol0003ojKfXonVmZ009onVmZ003o`000?o_]8ookkB?00GokkB?00Co0000ooo>N?oo
cWSo00000oo]Ybd00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo000Nooooo`03
o`000?oooooooooo03_ooooo00?o0000o`00Dol000002ol_78P00ol0003oOF:XogeRZ00FogeRZ003
o`000?nJM:Oo000000;o00006?nNP[D00ol0003o/8ncok2?/`0Kok2?/`03o`000?o1WKCo`Ifd01Wo
`Ifd00?o0000om2^]_o@[[H02?o@[[H2o`0000Koe:JX00?o0000omBVZ?oDYZP01_oDYZP00ol0003o
jKfXonVmZ00:onVmZ003o`000?o_]8ookkB?00CokkB?00Go0000ooo>N?oocWSooliho`000002onfW
;@03o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool001kooooo00?o0000oooooooo
ool0>oooool2o`0000_o;ab800?o0000odi5Yol000005_mmHZP3o`0001_oWX:e00?o0000ok2?/on`
Sk<06_n`Sk<00ol0003o`Ifdol6M]00Jol6M]003o`000?o@[[Kod:jf00[od:jf0ol00003omBVZ003
o`000?oDYZSoe:JX00Goe:JX00?o0000onVmZ?oY_JP03?oY_JP00ol0003okkB?onndS`03onndS`05
o`000?oocWSoolihooo>N?l000000_o]Ybd00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
013ooooo000Nooooo`;o0000??ooool00ol0003o;ab8oblLR009oblLR004o`000?m>AJOoCTFWo`00
01CoOF:X0_l000000on7M;So0000oij2]@0Koij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000ol6M
]?o1WK@06_o1WK@00ol0003od:jfom2^]P0=om2^]P;o000000?oe:JXo`000?oDYZP01_oDYZP00ol0
003ojKfXonVmZ00=onVmZ003o`000?o_]8ookkB?00;okkB?00Go0000ooo>N?oocWSooliho`000002
onfW;@03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooo
ooooool0>oooool00ol0003o;ab8oblLR008oblLR005o`000?m>AJOoCTFWodi5Yol000004ommHZP0
0ol0003oQgBhohMd^002ohMd^003o`000?nNP[GoWX:e01WoWX:e00?o0000ok2?/on`Sk<06_n`Sk<0
0ol0003o`Ifdol6M]00Iol6M]003o`000?o@[[Kod:jf013od:jf0ol00006omBVZ003o`000?oY_JSo
jKfX00kojKfX00Go0000onndSoo_]8ookkB?o`000004ooo>N003o`000?o]Ybgo000002Oooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000[o;ab800?o0000
odi5Yom>AJL00_m>AJL00ol0003oOF:XogeRZ00>ogeRZ0;o00001On7M;P00ol0003oWX:eoij2]@0I
oij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000ol6M]?o1WK@06Oo1WK@00ol0003od:jfom2^]P0A
om2^]P04o`000?o@[[Ko0000o`0000Coe:JX00?o0000onVmZ?oY_JP03ooY_JP00ol0003okkB?o`00
0005ooo>N003o`000?o]Ybgo000002Oooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0>_ooool2o`0000Wo;ab800?o0000odi5Yom>AJL00om>AJL00ol0003oOF:XogeRZ00<
ogeRZ0;o00001on7M;P00ol0003oWX:eoij2]@0Ioij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000
ol6M]?o1WK@06Oo1WK@00ol0003od:jfom2^]P0Aom2^]P04o`000?o@[[Kod:jfom2^]PCo00004ooY
_JP2o`0000Goolih00?o0000onfW;Ol000009oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`0kooooo`03o`000?l005Go000000Oo;ab800?o0000odi5Yom>AJL01?m>AJL0
0ol0003oOF:XogeRZ00;ogeRZ003o`000?n7M;SoQgBh00SoQgBh00?o0000oij2]OnNP[D06?nNP[D0
0ol0003o/8ncok2?/`0Jok2?/`03o`000?o1WKCo`Ifd01Wo`Ifd00?o0000om2^]_o@[[H04Oo@[[H0
0ol0003od:jfom2^]P04om2^]P;o00004ooY_JP00ol0003oolihooo>N004ooo>N003o`000?o]Ybgo
000002Kooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0>oooool00ol0
003o001Eo`000006oblLR003o`000?m>AJOoCTFW00KoCTFW00?o0000ogeRZ?mmHZP02?mmHZP2o`00
00_oQgBh00?o0000oij2]OnNP[D06OnNP[D00ol0003o/8ncok2?/`0Iok2?/`03o`000?o1WKCo`Ifd
01Wo`Ifd00?o0000om2^]_o@[[H04_o@[[H00ol0003od:jfom2^]P03om2^]P03o`000?oQ`k[o0000
01;ojKfX00?o0000ooo>N?oocWP01?oocWP00ol0003okJL]o`00000Vooooo`03o`000?oooooooooo
00oooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000o`00EOl000001_l_78P00ol0003o
CTFWodi5Y`06odi5Y`03o`000?mmHZSoOF:X00KoOF:X0_l0000>ohMd^003o`000?nNP[GoWX:e01So
WX:e00?o0000ok2?/on`Sk<06On`Sk<00ol0003o`Ifdol6M]00Hol6M]003o`000?o@[[Kod:jf01?o
d:jf00?o0000om2^]_o@[[H00_o@[[H01Ol0003ohL>jon73^_oQ`k[o0000013ojKfX00?o0000oo_L
Y?l000001_oocWP2o`0002Kooooo00?o0000ooooooooool03oooool001gooooo0_l0000looooo`03
o`000?l005Go000000Go;ab800?o0000odi5Yom>AJL01om>AJL00ol0003oOF:XogeRZ005ogeRZ003
o`000?n7M;SoQgBh00koQgBh00?o0000oij2]OnNP[D06?nNP[D00ol0003o/8ncok2?/`0;ok2?/a;o
00005oo1WK@00ol0003od:jfom2^]P0Com2^]P03o`000?o@[[Kod:jf00;od:jf00?o0000on73^_oQ
`kX00_oQ`kX00ol0003ojKfXonVmZ00=onVmZ003o`000?okg:Co000000Koolih0_l0000Wooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000o`00EOl00000
1?l_78P00ol0003oCTFWodi5Y`09odi5Y`03o`000?mmHZSoOF:X00;oOF:X0_l0000AohMd^003o`00
0?nNP[GoWX:e01KoWX:e4?l0000>ok6I_`04o`000?nnYKoo_ZFookjU_`Oo00004?o1WK@00ol0003o
d:jfom2^]P0Com2^]P05o`000?o@[[Kod:jfom2^]_l000001_oQ`kX00ol0003ojKfXonVmZ00<onVm
Z003o`000?okg:Co000000Koolih0_l0000Wooooo`03o`000?oooooooooo00kooooo000Mooooo`03
o`000?oooooooooo03_ooooo00?o0000o`00EOl000000ol_78P00ol0003oCTFWodi5Y`0:odi5Y`03
o`000?mmHZSoOF:X00;o00005?n7M;P00ol0003oWX:eoij2]@0Aoij2]@Co00000_nQS/000ol0003o
/IVook6I_`0Iok6I_`03o`000?nnYKoo_ZFo00So_ZFo1_l0000:ol6M]003o`000?o@[[Kod:jf01?o
d:jf00Go0000om2^]_o@[[Kod:jfo`000007on73^P03o`000?oY_JSojKfX00[ojKfX00Go0000oo_L
Y?okg:ConmbTo`000006ooo>N003o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool0??ooool00ol0003o001Eo`000003oblLR003o`000?m>AJOoCTFW
00[oCTFW00?o0000ogeRZ?l000005_n7M;P00ol0003oWX:eoij2]@0=oij2]@Co00001_nQS/000ol0
003o/IVook6I_`0Iok6I_`03o`000?nnYKoo_ZFo00ko_ZFo1ol00002ol6M]003o`000?o@[[Kod:jf
01Cod:jf00Co0000om2^]_o@[[Ko00002OoQ`kX00ol0003ojKfXonVmZ009onVmZ005o`000?okg:Co
nmbToo_LY?l000001_oocWP00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo03cooooo00Ko0000o`00EOl005Go0000oblLR?l0000>odi5Y`03o`00
0?n7M;SoQgBh01KoQgBh00?o0000oij2]OnNP[D02?nNP[D4o`0000[oXHk000?o0000ok6I_onaVKl0
6OnaVKl00ol0003o_ZFookjU_`0EokjU_`Co00005Oo@[[H01?l0003od:jfom2^]_l0000:on73^P;o
00002OoY_JP00ol0003onmbToo_LY002oo_LY003o`000?oocWSoolih00?oolih00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0looooo`03o`00
0?l005Go001E00;o00003om>AJL00ol0003oQgBhohMd^00FohMd^003o`000?nNP[GoWX:e00CoWX:e
1?l0000?oj6>`003o`000?naVKoo/IVo01So/IVo00?o0000okjU_onnYKl05onnYKl00ol0003oc;?2
o`000002o`0001;od:jf00?o0000om2^]_l000003OoQ`kX00ol0003ojKfXonVmZ005onVmZ003o`00
0?okg:ConmbT00?onmbT00?o0000ooo>N?oocWP00ooocWP00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002o`00E@03o`000?m>
AJOoCTFW00goCTFW00?o0000ofAS_?l000005on7M;P00ol0003oWX:eoij2]@04o`0001?oXHk000?o
0000ok6I_onaVKl06?naVKl00ol0003o_ZFookjU_`0FokjU_`03o`000?o</l;oc;?200?oc;?20ol0
000=om2^]P?o000000?od:jfo`000?oQ`kX03OoQ`kX00ol0003ojKfXonVmZ004onVmZ003o`000?ok
g:ConmbT00?onmbT00?o0000ooo>N?oocWP00_oocWP00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo03_ooooo00Go0000o`00EOl005Go001Eo`00
000>odi5Y`04o`000?mTHkcoI6>lo`0001OoQgBh0ol0000Goj6>`003o`000?naVKoo/IVo01So/IVo
00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P06olbc`P?o00001oo@[[H3o`0000;od:jf
00?o0000om2^]_l000003ooQ`kX00ol0003ojKfXonVmZ003onVmZ003o`000?okg:ConmbT00ConmbT
00Go0000ooo>N?oocWSooliho`00000Yooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000
??ooool01_l0003o001Eo`00EOl005Go00nHo`0000coCTFW00?o0000ofAS_?mTHk`00_mTHk`00ol0
003oQgBhohMd^00BohMd^0;o000000?oSXC4o`000?nQS/005onQS/000ol0003o/IVook6I_`0Hok6I
_`03o`000?nnYKoo_ZFo01Ko_ZFo00?o0000olbc`_o</l802Oo</l82o`0000;od:jf0ol00006om2^
]P03o`000?oQ`k[ohL>j00oohL>j00Go0000onVmZ?oY_JSojKfXo`000007oo_LY005o`000?oocWSo
olihooo>N?l00000:Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0l
ooooo`06o`000?l005Go001Eo`00EOl03iSo00002om>AJL00ol0003oI6>lofAS_003ofAS_003o`00
0?n7M;SoQgBh017oQgBh00?o0000ohj4a?n>Q<@00_n>Q<@00ol0003oXHk0oj6>`00Eoj6>`003o`00
0?naVKoo/IVo01Oo/IVo00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P0;olbc`PCo0000
2?o@[[H2o`00017ohL>j00Co0000onVmZ?oY_JSo00001ookg:@01Ol0003oolihooo>N?oocWSo0000
02Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0??ooool01_l0003o
001Eo`00EOl005Go00nHo`0000_oCTFW00?o0000ofAS_?mTHk`01?mTHk`00ol0003oQgBhohMd^00>
ohMd^0;o00001On>Q<@00ol0003oXHk0oj6>`00Foj6>`003o`000?naVKoo/IVo01Ko/IVo00?o0000
okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P07olbc`PCo00001?o</l83o`0000Cod:jf00Co0000
on73^_oQ`k[o00004OoQ`kX00ol0003ojKfXo`000008oo_LY004o`000?oocWSooliho`0002Wooooo
00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0??ooool01?l0003o001Eo`00
EOl00002o`0?V003o`000?m>AJOoCTFW00OoCTFW00?o0000ofAS_?mTHk`01OmTHk`00ol0003oQgBh
ohMd^00<ohMd^0;o00001on>Q<@00ol0003oXHk0oj6>`00Foj6>`003o`000?naVKoo/IVo01Ko/IVo
00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P04olbc`P?o00002oo</l83o`000003om2^
]_l0003ohL>j00;ohL>j00?o0000on73^_oQ`kX03ooQ`kX00ol0003onmbToo_LY007oo_LY004o`00
0?oocWSooliho`0002Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
??ooool01?l0003o001Eo`00EOl00002o`0?V003o`000?m>AJOoCTFW00KoCTFW00?o0000ofAS_?mT
Hk`01omTHk`00ol0003oQgBhohMd^009ohMd^0;o00002_n>Q<@00ol0003oXHk0oj6>`00Eoj6>`003
o`000?naVKoo/IVo01Ko/IVo00?o0000okjU_onnYKl05OnnYKl00ol0003oc;?2olbc`P02olbc`P?o
00004Oo</l82o`0000?ohL>j00?o0000on73^_oQ`kX03ooQ`kX00ol0003onmbToo_LY008oo_LY003
o`000?oocWSo000002Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
??ooool01?l0003o001Eo`00EOl00003o`0?V003o`000?m>AJOoCTFW00CoCTFW00?o0000ofAS_?mT
Hk`02?mTHk`00ol0003oQgBhohMd^008ohMd^003o`000?n>Q<CoSXC400[oSXC400?o0000oj6>`?nQ
S/005OnQS/000ol0003o/IVook6I_`0Fok6I_`03o`000?nnYKoo_ZFo01Go_ZFo00?o0000olbc`_l0
00000_l0000Dolbc`P03o`000?oIa/Oo000000?ohL>j00?o0000on73^_oQ`kX03OoQ`kX00ol0003o
l=nno`000009oo_LY0;o0000:_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003ooooo
ooooo`0looooo`04o`000?l005Go001Eo`0000?o00nH00?o0000odi5Yom>AJL00om>AJL00ol0003o
I6>lofAS_00:ofAS_003o`000?n7M;SoQgBh00GoQgBh0_l0000>ohj4a003o`000?nQS/3oXHk001Co
XHk000?o0000ok6I_onaVKl05_naVKl00ol0003o_ZFookjU_`0CokjU_`Co00005_o</l801Ol0003o
fLK7omW6aooIa/Oo000000?ohL>j00?o0000on73^_oQ`kX02ooQ`kX01?l0003ol=nnoo3O__l00009
oo_LY0;o0000:_ooool00ol0003oooooooooo`0=ooooo`006oooool2o`0003kooooo00?o0000o`00
EOl000000ol03iP00ol0003oCTFWodi5Y`03odi5Y`03o`000?mTHkcoI6>l00[oI6>l00?o0000ohMd
^?n7M;P00on7M;P2o`00013oSXC400?o0000oj6>`?nQS/005OnQS/000ol0003o/IVook6I_`0Eok6I
_`03o`000?nnYKoo_ZFo013o_ZFo0ol000000onnYKoo0000olbc`P0Golbc`P03o`000?oIa/OofLK7
00;ofLK700Go0000on73^_oQ`k[ohL>jo`00000<on73^P05o`000?o`gkkol=nnoo3O__l000002Ook
g:@00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooo
oooo03kooooo00?o0000o`00EOl000001?l03iP01Ol0003oCTFWodi5Yom>AJOo000000koI6>l00Go
0000ohMd^?n7M;SoQgBho`00000Bohj4a003o`000?nQS/3oXHk001GoXHk000?o0000ok6I_onaVKl0
2OnaVKlAo`0000_o_ZFo0ol00004okjU_`03o`000?o</l;oc;?201Goc;?200?o0000omW6aooIa/L0
1?oIa/L2o`0000;ohL>j00?o0000on73^_oQ`kX02?oQ`kX00ol0003ol=nnoo3O_P02oo3O_P03o`00
0?okg:ConmbT00OonmbT00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`0000Co
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03kooooo00?o0000o`00EOl000001?l03iP01?l0003oCTFWodi5Yol0000?ofAS
_004o`000?n7M;So0000o`0001CoSXC400?o0000oj6>`?nQS/004_nQS/0>o`0000co/:;900?o0000
okb/bOnl[<T00_nl[<T7o`000004okjU_ol0003o0000o`0000Oo_ZFo00?o0000olbc`_o</l805?o<
/l800ol0003ofLK7omW6a`07omW6a`04o`000?oQ`k[ohL>jo`0000WohL>j00?o0000oo3O__o`gkh0
0_o`gkh00ol0003onmbToo_LY006oo_LY0;o0000:oooool00ol0003oooooooooo`0<ooooo`0000Co
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?l005Go000000Co00nH00?o0000odi5Yol000004OmTHk`00ol0003oSXC4
ohj4a00Dohj4a003o`000?nQS/3oXHk000koXHk01?l00002oj>Ib`03o`000?n`X/Wo/:;901Go/:;9
00?o0000okb/bOnl[<T01_nl[<T:o`0000?o_ZFo00?o0000olbc`_o</l805Oo</l800ol0003ofLK7
omW6a`08omW6a`03o`000?oQ`k[o000000SohL>j00?o0000oo3O__o`gkh01?o`gkh00ol0003onmbT
oo_LY005oo_LY0;o0000:oooool00ol0003oooooooooo`0<ooooo`000oooool00ol@413ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003o001Eo`00
0005o`0?V003o`000?mTHkcoI6>l013oI6>l00?o0000ohj4a?n>Q<@05On>Q<@00ol0003oXHk0oj6>
`008oj6>`0Go00001_nSVL/00ol0003o/:;9ok2Rb@0Eok2Rb@03o`000?nl[<Wo_:c900?o_:c90ol0
000:okb/b@Co00005_o</l800ol0003ofLK7omW6a`0:omW6a`03o`000?oQ`k[o000000KohL>j00?o
0000oo3O__o`gkh01Oo`gkh00ol0003onmbToo_LY005oo_LY003o`000?oooooooooo02[ooooo00?o
0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo03kooooo0_l00006o`0?V003o`000?mTHkcoI6>l00ooI6>l00?o0000
og=jbol000005_n>Q<@00ol0003oXHk0oj6>`004oj6>`0Co00003?nSVL/00ol0003o/:;9ok2Rb@0D
ok2Rb@03o`000?nl[<Wo_:c900?o00004?nl[<T00ol0003oakS=o`000002o`0001;oc;?200?o0000
omW6aooIa/L02ooIa/L3o`0000GohL>j00?o0000oo3O__o`gkh01_o`gkh00ol0003onmbToo_LY003
oo_LY0;o0000;?ooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0:oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0oooooo`03o`000?l03iSo
00nH00Co00nH00?o9DNmo`000?mTHk`03_mTHk`01Ol0003oLg[;og=jbomcN/_o000001GoSXC400?o
0000oj6>`?nQS/001?l0000@oj>Ib`03o`000?n`X/Wo/:;901Co/:;90ol0000Bokb/b@03o`000?o7
^<goakS=00?oakS=0ol0000>olbc`P03o`000?oIa/OofLK700kofLK70_l00003on73^P03o`000?o`
gkkol=nn00Ool=nn00?o0000oo_LY?okg:@00ookg:@2o`0002cooooo00?o0000ooooooooool03?oo
ool000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo043ooooo00?o0000o`0?V?l03iP01?l03iP00ol0003o9DNmo`00000=ofAS_003o`000?mcN/_o
Lg[;00;oLg[;00?o0000ohj4a?n>Q<@04on>Q<@3o`0001CoXiW;00?o0000ok2RbOn`X/T04?n`X/T5
o`0001Co_:c900?o0000olNhcOo7^<d01_o7^<d3o`0000_oc;?200?o0000omW6aooIa/L03ooIa/L2
o`0000;ohL>j00?o0000oo3O__o`gkh02?o`gkh01ol0003onmbToo_LY?okg:Co0000on7VNol00000
;Oooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003ooooo
ooooo`06ooooo`;o0000@Oooool00ol0003o00nHo`0?V004o`0?V003o`000?lUAkgo000000coI6>l
00?o0000og=jbomcN//01?mcN//00ol0003oSXC4ohj4a00@ohj4a0;o000000?oTi;?o`000?nSVL/0
5?nSVL/00ol0003o/:;9ok2Rb@0=ok2Rb@?o00001?n`X/T00ol0003o_:c9okb/b@0Bokb/b@03o`00
0?o7^<goakS=00WoakS=0_l00008olbc`P03o`000?oIa/OofLK7017ofLK700?o0000on73^_l00000
2oo`gkh01ol0003onmbToo_LY?okg:Co0000on7VNol00000;Oooool00ol0003oooooooooo`0;oooo
o`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0
003o00nHo`0?V003o`0?V005o`000?lUAkgo9DNmobE7_Ol000002_mTHk`00ol0003oLg[;og=jb`06
og=jb`03o`000?n>Q<CoSXC400koSXC400?o0000oi>BconCT/l00_nCT/l00ol0003oXiW;oj>Ib`0C
oj>Ib`03o`000?n`X/Wo/:;900Wo/:;90ol00006ok2Rb@03o`000?nl[<Wo_:c901;o_:c900?o0000
olNhcOo7^<d03?o7^<d3o`0000Coc;?200?o0000omW6aooIa/L04ooIa/L00ol0003ol=nnoo3O_P0:
oo3O_P06o`000?okg:ConmbTo`000?oQiW_o0000;_ooool00ol0003oooooooooo`0;ooooo`006Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?l03iSo00nH00;o00nH00?o0000obE7_OlUAkd00_lU
Akd00ol0003oI6>lofAS_006ofAS_003o`000?mcN/_oLg[;00SoLg[;00?o0000ohj4a?n>Q<@02on>
Q<@2o`0000GoTi;?00?o0000oj>IbonSVL/04onSVL/00ol0003o/:;9ok2Rb@06ok2Rb@?o00002On`
X/T00ol0003o_:c9okb/b@0Bokb/b@03o`000?o7^<goakS=00ooakS=0ol000000oo</l;o0000omW6
a`0DomW6a`;o00003?o`gkh01Ol0003onmbTo`000?oQiW_o000002kooooo00?o0000ooooooooool0
2oooool001Wooooo00?o0000ooooooooool0@Oooool00ol0003o00nHo`0?V002o`0?V003o`000?lU
Akgo9DNm00;o9DNm00?o0000ofAS_?mTHk`01_mTHk`00ol0003oLg[;og=jb`08og=jb`03o`000?n>
Q<CoSXC400WoSXC40_l00008oi>Bc`03o`000?nSVL_oXiW;01;oXiW;00?o0000ok2RbOn`X/T00_n`
X/T4o`0000co/:;900?o0000okb/bOnl[<T04_nl[<T00ol0003oakS=olNhc@0BolNhc@;o00005?oI
a/L01?l0003oi=k?o`000?l0000;oo3O_P05o`000?okg:Co0000on7VNol00000;_ooool00ol0003o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`11ooooo`03o`000?l03iSo00nH00;o00nH
00?o0000obE7_OlUAkd00olUAkd00ol0003oI6>lofAS_004ofAS_003o`000?mcN/_oLg[;00[oLg[;
00?o0000ohj4a?n>Q<@01_n>Q<@2o`0000[oTi;?00?o0000oj>IbonSVL/04onSVL/4o`00013o/:;9
00?o0000okb/bOnl[<T04Onl[<T00ol0003oakS=olNhc@0ColNhc@03o`000?o@b=;o000001;ofLK7
00Ko0000onCNcooTg/oo0000oo3O__l0000;oo3O_P04o`000?oQiW_ohNIko`0002kooooo00?o0000
ooooooooool02oooool001Sooooo00?o0000ooooooooool0@oooool01Ol0003o00nHo`0?V?l03iSo
000000Ko9DNm00?o0000ofAS_?mTHk`00_mTHk`00ol0003oLg[;og=jb`0<og=jb`03o`000?n>Q<Co
SXC400?oSXC40_l0000=oi>Bc`03o`000?nSVL_oXiW;013oXiW;0ol0000Cok2Rb@03o`000?nl[<Wo
_:c9017o_:c900?o0000olNhcOo7^<d04_o7^<d01Ol0003od<SBom38d_o@b=;o0000013ofLK700?o
0000onCNcooTg/l00_oTg/l00ol0003ol=nno`00000:oo3O_P04o`000?oQiW_ohNIko`0002kooooo
00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool0@oooool01Ol0003o00nHo`0?
V?l03iSo000000Ko9DNm00Go0000ofAS_?mTHkcoI6>lo`00000?og=jb`03o`000?n>Q<CoSXC400;o
SXC400?o0000oi>BconCT/l03OnCT/l00ol0003oXiW;oj>Ib`0=oj>Ib`?o00000_nSVL/00ol0003o
/:;9ok2Rb@0Aok2Rb@03o`000?nl[<Wo_:c9017o_:c900?o0000olNhcOo7^<d04Oo7^<d00ol0003o
d<SBom38dP03om38dP03o`000?oIa/OofLK700gofLK700?o0000onCNcooTg/l00_oTg/l00ol0003o
l=nno`000009oo3O_P;o000000?ohNIko`000?ooool0;oooool00ol0003oooooooooo`0:ooooo`00
6?ooool00ol0003oooooooooo`14ooooo`04o`000?l03iSo00nHo`0000Oo9DNm00?o0000ofAS_?l0
00004OmcN//01?l0003oSXC4o`000?l0000Aoi>Bc`03o`000?nSVL_oXiW;00SoXiW;1?l00005oj>I
b`03o`000?n`X/Wo/:;9017o/:;900?o0000okb/bOnl[<T04?nl[<T00ol0003oakS=olNhc@0BolNh
c@03o`000?o@b=;od<SB00Cod<SB00?o0000omW6aooIa/L02ooIa/L00ol0003oi=k?onCNc`04onCN
c`03o`000?o`gkko000000Ool=nn0_l00002on7VN`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02_ooool001Sooooo0_l00015ooooo`04o`000?l03iSo00nHo`0000So9DNm00?o0000og=j
bomcN//04OmcN//00ol0003oTi;?oi>Bc`0Aoi>Bc`03o`000?nSVL_oXiW;00GoXiW;0ol0000:oj>I
b`03o`000?n`X/Wo/:;900Oo/:;93ol0000=okb/b@03o`000?o7^<goakS=017oakS=00?o0000om38
d_o@b=801_o@b=82o`0000[ofLK700?o0000onCNcooTg/l01OoTg/l01?l0003ol=nnoo3O__l00005
oo3O_P03o`000?o[nKKo000000;ohNIk00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:
ooooo`006?ooool00ol0003oooooooooo`15ooooo`;o00002OlUAkd00ol0003oLg[;og=jb`0Aog=j
b`03o`000?nCT/ooTi;?01;oTi;?00Co0000oj>IbonSVL_oXiW;0ol0000;oj>Ib`co00002On_Z]<0
0ol0003o^;;CokRbd`03okRbd`Wo00001?nl[<T00ol0003oakS=olNhc@0@olNhc@03o`000?o@b=;o
d<SB00Wod<SB00?o0000omW6aooIa/L01_oIa/L00ol0003oi=k?onCNc`07onCNc`04o`000?o`gkko
l=nno`0000Col=nn00?o0000on_i]_l000000_oQiW/00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00[ooooo000Hooooo`03o`000?oooooooooo04Gooooo0_l00009obE7_@;o00004OmcN//0
0ol0003oP8cFo`00000Coi>Bc`Co00002OnSVL/5o`0000;oY:?D00?o0000ojnZdon_Z]<04?n_Z]<0
0ol0003o^;;CokRbd`0<okRbd`Co00004_o7^<d00ol0003od<SBom38dP0;om38dP03o`000?oIa/Oo
fLK700CofLK700?o0000onCNcooTg/l02?oTg/l01Ol0003ol=nnoo3O__o`gkko000000;ol=nn00Ko
0000on_i]_o[nKKo0000on7VNol0000aooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`00
0?oooooooooo04Kooooo0_l00009obE7_@03o`000?m:K=;o000000ooLg[;00Go0000oh2<e_n0S=Ko
P8cFo`00000?oi>Bc`Go00001onSVL/4o`0000OoY:?D00?o0000ojnZdon_Z]<04?n_Z]<00ol0003o
^;;CokRbd`0?okRbd`03o`000?o1_=Ko000000;o00003_o7^<d00ol0003od<SBom38dP0<om38dP03
o`000?oIa/OofLK700?ofLK700?o0000onCNcooTg/l02OoTg/l01_l0003ol=nnoo3O__l0003ol=nn
o`0000?ojoVf00?o0000on7VNol00000<Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0
003oooooooooo`17ooooo`03o`000?lUAkgo9DNm00Ko9DNm00Go0000odY/d_m:K=;oBVcBo`00000=
og=jb`03o`000?n0S=KoP8cF00?oP8cF00?o0000oi>BconCT/l02OnCT/l3o`0000CoTi;?00?o0000
oj>IbonSVL/01Ol0000<ojBSe003o`000?n_Z]?o[j[C00ko[j[C00?o0000okRbdonh/]<03onh/]<0
0ol0003o`KcFol6leP03ol6leP;o00002oo7^<d00ol0003od<SBom38dP0>om38dP05o`000?oIa/Oo
fLK7omW6aol000003?oTg/l01?l0003ol=nnoo3O__o`gkh2o`0000;ojoVf00?o0000on7VNol00000
<_ooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`17ooooo`03o`000?lU
Akgo9DNm00Ko9DNm00?o0000odY/d_m:K=800_m:K=800ol0003oLg[;og=jb`09og=jb`03o`000?n0
S=KoP8cF00GoP8cF00?o0000oi>BconCT/l01OnCT/l3o`0000OoTi;?0ol0000AojBSe003o`000?n_
Z]?o[j[C00ko[j[C00?o0000okRbdonh/]<03onh/]<00ol0003o`KcFol6leP05ol6leP?o00001oo7
^<d00ol0003od<SBom38dP0@om38dP03o`000?oIa/Oo000000koi=k?00?o0000oo3O__o`gkh00_l0
0002on_i]P03o`000?oQiW_o000003?ooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000
ooooooooool0B?ooool00ol0003o9DNmobE7_@05obE7_@03o`000?m:K=;oBVcB00?oBVcB00?o0000
og=jbomcN//01omcN//00ol0003oP8cFoh2<eP07oh2<eP04o`000?nCT/ooTi;?oi>Bc`?o00002?nC
T/l2o`000003oiRNf?l0003oY:?D017oY:?D00?o0000ojnZdon_Z]<03_n_Z]<00ol0003o^;;CokRb
d`0>okRbd`03o`000?o1_=Ko`KcF00Wo`KcF0_l00005olNhc@03o`000?o@b=;od<SB017od<SB00?o
0000onCNcooTg/l03OoTg/l00ol0003ol=nno`000002on_i]P04o`000?o[nKKo0000o`0003Cooooo
00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0B?ooool2o`0000Ko9DNm00?o
0000odY/d_m:K=801?m:K=800ol0003oLg[;og=jb`05og=jb`03o`000?n0S=KoP8cF00SoP8cF1?l0
0009oi>Bc`;o00001?nHW]P00ol0003oY:?DojBSe00?ojBSe003o`000?n_Z]?o[j[C00ko[j[C00?o
0000okRbdonh/]<03_nh/]<00ol0003o`KcFol6leP0;ol6leP?o000000?oakS=o`000?o@b=804Oo@
b=800ol0003oem_Jo`00000@onCNc`03o`000?o[nKKojoVf00;ojoVf0ol0000dooooo`03o`000?oo
oooooooo00Wooooo000Gooooo`03o`000?oooooooooo04Wooooo00?o00nNo`000?lUAkd01?lUAkd0
0ol0003oBVcBodY/dP05odY/dP03o`000?mcN/_oLg[;00?oLg[;00?o0000oh2<e_n0S=H01_n0S=H3
o`000003oh2<e_l0003oTi;?00SoTi;?0_l00007oiRNf003o`000?nTXmCoY:?D00ooY:?D00?o0000
ojnZdon_Z]<03On_Z]<00ol0003o^;;CokRbd`0=okRbd`03o`000?o1_=Ko`KcF00oo`KcF0_l0000A
om38dP05o`000?oGfm[oem_JomOKf_l000003OoTg/l00ol0003ohoSDo`000004on_i]P?o0000=?oo
ool00ol0003oooooooooo`09ooooo`005oooool2o`0004[ooooo00?o0000o`0?W_l000001?lUAkd0
0ol0003oBVcBodY/dP06odY/dP05o`000?mcN/_oLg[;og=jbol000001_n0S=H3o`0000GoP8cF00?o
0000oi>BconCT/l01OnCT/l00ol0003oV9kHoiRNf007oiRNf003o`000?nTXmCoY:?D00ooY:?D00?o
0000ojnZdon_Z]<03On_Z]<00ol0003o^;;CokRbd`0=okRbd`03o`000?o1_=Ko`KcF00oo`KcF00?o
0000olO9fol000003oo@b=800ol0003oem_JomOKfP02omOKfP03o`000?oTg/ooi=k?00[oi=k?00Co
0000on?he?oSn=Co00001?o[nKH2o`0003Gooooo00?o0000ooooooooool02Oooool001Kooooo00?o
0000ooooooooool0Boooool00ol03iko0000obE7_@03obE7_@03o`000?m:K=;oBVcB00OoBVcB00?o
0000og=jbol000001?n0S=H3o`0000WoP8cF00?o0000oi>BconCT/l00_nCT/l2o`0000_oV9kH00?o
0000ojBSe?nTXm@03_nTXm@00ol0003o[j[CojnZd`0=ojnZd`03o`000?nh/]?o^;;C00go^;;C00?o
0000ol6le_o1_=H03_o1_=H01Ol0003oalWKolO9foo7bM_o000000god<SB00?o0000omOKf_oGfmX0
1?oGfmX00ol0003oi=k?onCNc`08onCNc`05o`000?oSn=CohoSDon?he?l000001?o[nKH3o`0003Co
oooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0Boooool00ol0003o00nN
o`000002obE7_@03o`000?m:K=;oBVcB00WoBVcB1_l0000=oh2<eP04o`000?nCT/oo0000o`0000ko
V9kH00?o0000ojBSe?nTXm@03OnTXm@00ol0003o[j[CojnZd`0<ojnZd`03o`000?nh/]?o^;;C00go
^;;C00?o0000ol6le_o1_=H03_o1_=H00ol0003oalWKolO9f`03olO9f`;o00002_o@b=800ol0003o
em_JomOKfP05omOKfP03o`000?oTg/ooi=k?00Ooi=k?00Go0000on?he?oSn=CohoSDo`000005on_i
]P04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooo
ooooool0C?ooool01Ol0003o00nNo`000?lUAkgo000000[oBVcB1?l0000Aoh2<eP;o00003onHW]P0
0ol0003oY:?DojBSe00>ojBSe003o`000?n_Z]?o[j[C00_o[j[C00?o0000okRbdonh/]<03Onh/]<0
0ol0003o`KcFol6leP0=ol6leP03o`000?o7bM_oalWK00KoalWK00?o0000om38d_o@b=801_o@b=80
0ol0003oem_JomOKfP07omOKfP03o`000?oTg/ooi=k?00Goi=k?00?o0000on?he?oSn=@00_oSn=@0
0ol0003ojoVfon_i]P03on_i]P05o`000?ooooooooooooooool00000<_ooool00ol0003ooooooooo
o`09ooooo`005_ooool00ol0003oooooooooo`1<ooooo`03o`000?l03iko00nN00;o00001om:K=83
o`000005odY/d_l0003oI8KOofB6gol000004?n0S=H2ohVKgP03o`000?nHW]SoV9kH00goV9kH00?o
0000ojBSe?nTXm@02onTXm@Eo`0000[o^;;C00?o0000ol6le_o1_=H03Oo1_=H00ol0003oalWKolO9
f`08olO9f`;o00001Oo@b=800ol0003oem_JomOKfP09omOKfP03o`000?oTg/ooi=k?00?oi=k?00?o
0000on?he?oSn=@00ooSn=@00ol0003ojoVfon_i]P02on_i]P03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1<
ooooo`04o`000?l03iko00nNo`0?WP;o00000om:K=83o`0000CoBVcB00Go0000ofB6gomTQ]ooI8KO
o`00000>oh2<eP05o`000?n9VmkoRI_NohVKg_l000003onHW]P00ol0003oY:?DojBSe007ojBSe0?o
00000_nU[Md00ol0003o[K;Lojfbg00;ojfbg003o`000?nd^=co];SL00;o];SL1ol00003okRbd`03
o`000?o1_=Ko`KcF00co`KcF00?o0000olO9foo7bM/02oo7bM/01Ol0003od<SBom38d_o@b=;o0000
00coem_J00?o0000onCNcooTg/l00_oTg/l00ol0003ohoSDon?he004on?he005o`000?o[nKKojoVf
on_i]_l000001_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Foooo
o`03o`000?oooooooooo04gooooo00Co0000o`0?W_l03iko1EC@1?l00006odY/dP03o`000?mTQ]oo
I8KO00?oI8KO00?o0000oh2<e_n0S=H02_n0S=H00ol0003oRI_NohVKgP03ohVKgP03o`000?nHW]So
V9kH00coV9kH00?o0000ojBSe?nTXm@01?nTXm@3o`0000KoYJgM00?o0000ojfbg?n]/]`02_n]/]`0
0ol0003o];SLokBhg009okBhg0?o000000?o`KcFo`000?o1_=H03?o1_=H00ol0003oalWKolO9f`0<
olO9f`03o`000?o@b=;o000000koem_J00Co0000onCNcooTg/oo00001ooSn=@01Ol0003ojoVfon_i
]_o[nKKo000000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`005Ooo
ool00ol0003oooooooooo`1>ooooo`Co00000_l5E=000ol0003oBVcBodY/dP05odY/dP03o`000?mT
Q]ooI8KO00CoI8KO0_l00009oh2<eP03o`000?n9VmkoRI_N00GoRI_N00?o0000oiRNf?nHW]P03?nH
W]P00ol0003oY:?DojBSe003o`0000WoYJgM00?o0000ojfbg?n]/]`02_n]/]`00ol0003o];SLokBh
g00;okBhg003o`000?nj`=oo^/3O00?o00002Oo1_=H00ol0003oalWKolO9f`0>olO9f`03o`000?oG
fm[oem_J00goem_J00?o0000onCNcol000002?oSn=@01?l0003ojoVfon_i]_l00009ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001<ooooo`Co00000_l0
3ih01?l0003o1EC@o`EDd?l00006odY/dP03o`000?mTQ]ooI8KO00KoI8KO00?o0000oh2<e_n0S=H0
1On0S=H00ol0003oRI_NohVKgP07ohVKgP03o`000?nHW]SoV9kH00_oV9kH0ol0000<ojF]g@03o`00
0?n]/]co[K;L00[o[K;L00?o0000okBhg?nd^=`02_nd^=`00ol0003o^/3Ook[0g`04ok[0g`?o0000
1Oo1_=H00ol0003oalWKolO9f`0=olO9f`03o`000?o;en;o0000013oem_J00?o0000on?he?oSn=@0
1ooSn=@00ol0003ojoVfo`00000;ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000?ooooo00Go0000o`0?W_l03iko00nN
o`000002o`EDd003o`000?m:K=;oBVcB00?oBVcB00?o0000ofB6gomTQ]l01omTQ]l00ol0003oP8cF
oh2<eP03oh2<eP03o`000?n9VmkoRI_N00WoRI_N00?o0000oiRNf?nHW]P02?nHW]P2o`000003oibZ
hOl0003oYJgM00goYJgM00?o0000ojfbg?n]/]`02On]/]`00ol0003o];SLokBhg009okBhg003o`00
0?nj`=oo^/3O00So^/3O0ol000000oo1_=Ko0000olO9f`0>olO9f`05o`000?o;en;obmORol_Gh_l0
00003OoGfmX00ol0003oenoSo`000008on?he003o`000?o[nKKo000000gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co0000
1oooool01?l0003o00nNo`0?W_l00003o`EDd003o`000?m:K=;oBVcB00;oBVcB00?o0000ofB6gomT
Q]l02?mTQ]l01Ol0003oP8cFoh2<e_n0S=Ko000000goRI_N00?o0000oiRNf?nHW]P01OnHW]P2o`00
00CoW:[Q00?o0000ojF]gOnU[Md02onU[Md00ol0003o[K;Lojfbg008ojfbg003o`000?nd^=co];SL
00[o];SL00?o0000ok[0gonj`=l02onj`=l00ol0003oalWKolO9f`0<olO9f`;o00001?o;en800ol0
003oem_JomOKfP09omOKfP;o00000_oGkn<00ol0003ohoSDon?he006on?he003o`000?o[nKKo0000
00gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`12ooooo`?o00002oooool01Ol0003o00nNo`0?W_l03iko000000?o1EC@00Go0000odY/
d_m:K=;oBVcBo`00000;ofB6g`03o`000?n0S=Ko000000ooRI_N00?o0000oiRNf?nHW]P00_nHW]P2
o`0000OoW:[Q00?o0000ojF]gOnU[Md02_nU[Md00ol0003o[K;Lojfbg008ojfbg003o`000?nd^=co
];SL00Wo];SL00?o0000ok[0gonj`=l02onj`=l3okk9h`03o`000?o7bM_oalWK00WoalWK00?o0000
ol_Gh_o;en801Oo;en800ol0003oem_JomOKfP07omOKfP03o`000?oGkn?oenoS00;oenoS00?o0000
on?he?oSn=@01_oSn=@2o`0000oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07
ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00003oooool01?l0003o00nNo`0?W_l00004
o`EDd003o`000?m:K=;o000000goI8KO0_l0000@ohVKgP04o`000?nHW]So0000o`0000[oW:[Q00?o
0000ojF]gOnU[Md02_nU[Md00ol0003o[K;Lojfbg007ojfbg003o`000?nd^=co];SL00Wo];SL00?o
0000ok[0gonj`=l02Onj`=l00ol0003o_/WSokk9h`03okk9h`03o`000?o7bM_oalWK00OoalWK00?o
0000ol_Gh_o;en801oo;en800ol0003oem_JomOKfP04omOKfP;o00001OoGkn<00ol0003ohoSDon?h
e005on?he0;o00004Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo000D
ooooo`03o`000?oooooooooo03gooooo0ol0000Cooooo`03o`000?l03iko000000Go1EC@00?oBVcB
o`000?mTQ]l03?mTQ]l2ogRJi`;o00003on9Vmh2o`0000coW:[Q00?o0000ojF]gOnU[Md02OnU[Md0
0ol0003o[K;Lojfbg007ojfbg003o`000?nd^=co];SL00So];SL00?o0000ok[0gonj`=l02Onj`=l0
0ol0003o_/WSokk9h`05okk9h`;o00001Oo7bM/2o`0000[obmOR00?o0000omOKf_oGfmX00ooGfmX0
0ol0003oenoSomO_h`05omO_h`03o`000?oSn=CohoSD00CohoSD00?o0000okSj`Ol000004_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo
03Wooooo1?l0000Gooooo`03o`000?l03iko000000Go1EC@0_l0000<ofB6g`04o`000?mhV^OoN9[W
ogRJi`;o00003?n9Vmh01?l0003oTZWUoi:YiOl0000;oibZh@03o`000?nU[MgoYJgM00WoYJgM00?o
0000ojfbg?n]/]`01on]/]`00ol0003o];SLokBhg007okBhg003o`000?nj`=oo^/3O00Wo^/3O00?o
0000okk9honnbN<02?nnbN<01Ol0003oalWKolO9foo7bM_o000000gobmOR00?o0000omOKf_oGfmX0
0_l00008omO_h`03o`000?oSn=CohoSD00?ohoSD00?o0000okSj`Ol000005?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Kooooo0ol0
000Looooo`;o00001Ol5E=001?l0003o?83Vo`000?l00009ofB6g`03o`000?mhV^OoN9[W00CoN9[W
0_l00009ohVKgP03o`000?nBZNGoTZWU00;oTZWU0_l0000:oibZh@03o`000?nU[MgoYJgM00WoYJgM
00?o0000ojfbg?n]/]`00_n]/]`:o`0000Co];SL00?o0000ok[0gonj`=l02?nj`=l00ol0003o_/WS
okk9h`0:okk9h`03o`000?o7bM_o000000kobmOR00?o0000omOKf_l000002OoGkn<00ol0003ohoSD
on?he003on?he003o`000?nhn/7o000001Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Pooooo`03o`0?W_l0003o1EC@00Co1EC@00Co
0000ocb0i_llP>Ko00002?mTQ]l00ol0003oN9[WogRJi`06ogRJi`03o`000?n9VmkoRI_N00GoRI_N
00?o0000oi:YiOnBZND01OnBZND00ol0003oW:[QoibZh@08oibZh@03o`000?nU[MgoYJgM00KoYJgM
1ol00004ojZji@03o`000?n^_^Go[[kU00?o[[kU1?l0000:ok[0g`03o`000?nnbN?o_/WS00co_/WS
00?o0000ol_Gh_o;en803_o;en800ol0003oenoSomO_h`08omO_h`04o`000?oSn=CohoSDon?he0;o
000000?o^?[1o`000?ooool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oo
oooo000Dooooo`03o`000?oooooooooo033ooooo0ol0000Tooooo`03o`000?l5E=3o1EC@00?o1EC@
00Co0000ocb0i_llP>Ko?83V0_l00006ofB6g`03o`000?mhV^OoN9[W00OoN9[W0_l00004ohVKgP03
o`000?nBZNGoTZWU00OoTZWU0_l00009oibZh@03o`000?nU[MgoYJgM00Go00000_nU]nH00ol0003o
Z[[UojZji@06ojZji@03o`000?n^_^Go[[kU00Ko[[kU00?o0000ok;3iol000000_l00005ok[0g`03
o`000?nnbN?o_/WS00[o_/WS0_l000000onodnSo0000ol_GhP0<ol_GhP;o000000?obNK[o`000?oG
kn<02OoGkn<01?l0003ohoSDon?he?l00002okSj`@03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0;?ooool4o`0002Sooooo0_l00004o`EDd003o`000?llP>Ko?83V00;o
?83V0_l00004ofB6g`03o`000?mhV^OoN9[W00WoN9[W0_l000000on9Vmko0000oi:Yi@0;oi:Yi@03
o`000?nLZ^7oW:[Q00KoW:[Q0ol00008ojFgiP03o`000?nZ^^GoZ[[U00GoZ[[U00?o0000ojjniOn^
_^D01On^_^D00ol0003o//?Wok;3i`03ok;3i`?o000000?o^/3Oo`000?nnbN<02onnbN<00ol0003o
_m?XokoCj002okoCj003o`000?o;en;obmOR00SobmOR0_l00003olWVj`03o`000?oGkn?oenoS00So
enoS00?o0000on?he?l000000_nhn/400ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Zooooo`?o0000;_ooool01Ol0003o1EC@o`EDd?l5E=3o000000Ko?83V00Go0000ofB6gomT
Q]ooI8KOo`00000=ogRJi`;o00003OnBZND2o`0000CoW:[Q0_l00002oinej003o`000?nU]nKoYKOV
00KoYKOV00?o0000ojZjiOnZ^^D01OnZ^^D00ol0003o[[kUojjni@05ojjni@03o`000?nb`nOo//?W
00Ko//?W00?o0000okk9honnbN<02OnnbN<2o`0000Go_m?X00?o0000ol_Gh_o;en801_o;en82o`00
00GobNK[00?o0000omO_hooGkn<02?oGkn<2o`0000?o^?[100?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool09oooool3o`0003;ooooo0_l00002o`EDd003o`000?llP>Ko?83V00Co
?83V00?o0000ofB6gol000003_mhV^L01?l0003oQZW/o`000?l0000=oi:Yi@04o`000?nLZ^7o0000
o`0000GoWkGX00?o0000ojFgi_nU]nH01OnU]nH00ol0003oZ[[UojZji@05ojZji@03o`000?n^_^Go
[[kU00Co[[kU00?o0000ok;3ionb`nL01_nb`nL3okC8j@03o`000?nnbN?o_/WS00Go_/WS0_l00008
okoCj003o`000?o;en;obmOR00CobmOR00?o0000olWVjoo9i^/01Oo9i^/00ol0003oenoSomO_h`07
omO_h`;o00000onhn/400ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Toooo
o`?o0000=_ooool01Ol0:jCo0000o`EDd?l5E=3o000000Oo?83V0_l0000=ogRJi`04o`000?n6ZNco
QZW/ohJYk0;o00002onBZND3o`0000OoWkGX00?o0000ojFgi_nU]nH01OnU]nH00ol0003oZ[[UojZj
i@03ojZji@03o`000?n^_^Go[[kU00Co[[kU00?o0000ok;3ionb`nL01Onb`nL00ol0003o]<SYokC8
j@03okC8j@;o00001?nnbN<00ol0003o_m?XokoCj009okoCj004o`000?o;en;obmORol_GhP;o0000
2?o9i^/00ol0003oenoSomO_h`05omO_h`;o000000Go`OcVo`000?nhn/7o^?[1o`00000Oooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`Co0000>_ooool01?l0:jCo0000o`EDd?l00007ocb0iP03
o`000?mQV^oo000000;o00002_mhV^L00ol0003oQZW/ohJYk003ohJYk0?o00001onBZND01Ol0003o
VKG[oiVejonI]N_o000000OoWkGX00?o0000ojFgi_nU]nH01?nU]nH00ol0003oZ[[UojZji@03ojZj
i@03o`000?n^_^Go[[kU00Co[[kU00?o0000ok;3ionb`nL01?nb`nL00ol0003o]<SYokC8j@06okC8
j@04o`000?nnbN?o0000o`0000co_m?X00Co0000ol_Gh_l0003o00002Oo9i^/00ol0003oenoSomO_
h`04omO_h`;o00000_o1o>H01?l0003o^?[1okSj`Ol0000Qooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Mooooo`?o0000?oooool2o`000003o`EDd?l0003o?83V00Ko?83V00Co0000of6JkomQV^ooHI[_
0ol00006ogRJi`03o`000?n6ZNcoQZW/00OoQZW/0_l00004oi:Yi@03o`000?nI]N_oVKG[00?oVKG[
0_l00006oinej003o`000?nU]nKoYKOV00?oYKOV00?o0000ojZjiOnZ^^D00onZ^^D00ol0003o[[kU
ojjni@03ojjni@03o`000?nb`nOo//?W00?o//?W0_l0000:okC8j@03o`000?nodnSo_m?X00go_m?X
00?o0000olWVjoo9i^/02Oo9i^/00ol0003oenoSomO_h`02omO_h`;o00000oo1o>H01?l0003o^?[1
okSj`Ol0000Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`?o0000@oooool00ol0003o02^T
o`000007ocb0iP03o`000?mQV^ooHI[_00CoHI[_0ol00003ogRJi`03o`000?n6ZNcoQZW/00WoQZW/
0_l000000onBZNGo0000oiVej`07oiVej`;o00001OnO]NP00ol0003oYKOVojFgiP03ojFgiP03o`00
0?nZ^^GoZ[[U00;oZ[[U00?o0000ojjniOn^_^D00on^_^D00ol0003o//?Wok;3i`02ok;3i`03o`00
0?ndb>Wo]<SY00So]<SY00?o0000okC>kOl000002onodnP3o`000003okgLkol0003obNK[00[obNK[
00?o0000omO_hooGkn<00_l00004ol7liP04o`000?nhn/7o0000o`0002Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`06ooooo`002_ooool00omEEEGoIVIVo`000006ooooo`;o0000
6?ooool3o`0004Oooooo00Co0000o`0[Y?l0003o00001_llP>H00ol0003oHI[_of6Jk`06of6Jk`;o
000000?oN9[Wo`000?n6ZN`03?n6ZN`2o`0000[oVKG[00?o0000oinej?nO]NP00onO]NP00ol0003o
YKOVojFgiP0>o`0000?o//?W00?o0000okC8jOndb>T01_ndb>T2o`0000Co]<k]00?o0000okoCj?no
dnP01OnodnP3o`0000Co_Mc_00?o0000olWVjoo9i^/02Oo9i^/3o`0000Go`OcV00?o0000okSj`Ol0
0000:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Booooo`03o`00
0?oooooooooo01Cooooo1?l0001;ooooo`03o`000?l0:jCo02^T00;o00001?llP>H00ol0003oHI[_
of6Jk`09of6Jk`?o00002on6ZN`00ol0003oT[K_o`000002o`0000SoVKG[0_l00003oinej0?o0000
0_nS`Nh00ol0003oYL;^ojG2kP02ojG2kP03o`000?nW`nkoYl?^00;oYl?^00Go0000ojS5k_l0003o
//?Wo`000006okC8j@?o00001_ndc^d00ol0003o_m?XokoCj002okoCj0?o00001onmg>l00ol0003o
bNK[olWVj`07olWVj`03o`000?o9i^_o000000Ko`OcV0ol0000Yooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`00053ooooo
00Co0000o`0[Y?l0:jCo1WCO0_l00002ocb0iP03o`000?mQV^ooHI[_00WoHI[_00?o0000ogZ/lomj
[?<00ol00008ohJYk003o`000?nB]^ooT[K_00;oT[K_0ol00007oiVej`03o`000?nO]NSo000000?o
XL3_00Co0000oj?1k_nS`Nko00000onU`^h01Ol0003oYl?^ojO3k_nW`nko000000;oZ<G^0_l00005
okC8j@;o00002Ondc^d00ol0003o_m?Xo`000002o`0000Wo_Mc_00?o0000olWVjoo9i^/01Oo9i^/3
o`0000;o_O7c00?o0000ol7li_o1o>H00oo1o>H2o`0002cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000E?ooool01Ol0
003o02^To`0[Y?l0003o1WCO00;o000000?o?83Vo`000?mQV^l02OmQV^l00ol0003oNZccogZ/l`03
ogZ/l`?o00001?n6ZN`00ol0003oT[K_oi:fk`06oi:fk`?o00001OnI]N/2o`0000CoXL3_00?o0000
oj?1k_l000000onU`^h01?l0003oYl?^ojO3k_l00002ojS5kP06o`000?nXanooZ<O_ojS7kol0003o
]<SY0_l0000<okC>k@03o`000?nmg>oo_Mc_00[o_Mc_00?o0000olWVjoo9i^/00_o9i^/3o`0000Co
_O7c00?o0000ol7li_o1o>H00oo1o>H2o`0002kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0;ooooo`?o0000F?ooool01?l0003o02^T
o`0[Y?l00002o`Idg`;o00002omQV^l00ol0003oNZccogZ/l`05ogZ/l`?o000000?oQZW/o`000?nB
]^l02_nB]^l3o`000004oiVejol0003oWl3`oio0l0;o00000onQ`>l00ol0003oXl7^o`000002ojG2
kP04o`000?nW`nko0000ojS5kP;o00001?nXanl2o`0000Oo]<k]1Ol00002ok;Cl@03o`000?nmg>oo
_Mc_00[o_Mc_00?o0000olWVjol000000_l00006okgal`03o`000?o1o>Ko`OcV00?o`OcV00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Boooo
o`03o`000?oooooooooo00Oooooo1?l0001Looooo`;o000000?o02^To`000?l6M=l00_l6M=l3o`00
00SoHI[_00?o0000ogZ/lomj[?<02?mj[?<6o`0000[oT[K_0ol00003oio0l0?o000000GoXL3_o`00
0?l0003oYL;^o`000002ojO3kP;o00000onXanl3o`0000;oZ<Sa00?o0000okC>kOndc^d01?l00007
ok;Cl@03o`000?nmg>oo_Mc_00Oo_Mc_00?o0000okgLkonmg>l00_l00008okgal`03o`000?o1o>Ko
`OcV00;o`OcV0_l0000cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool0
01;ooooo00?o0000ooooooooool01?ooool3o`0006;ooooo00?o0000o`0[Y?l000001?l6M=l00om7
W?Co0000o`000002o`0000CoHI[_00?o0000ogZ/lomj[?<02Omj[?<00ol0003oSKScohfhl`02ohfh
l`Oo00000onB]^l00ol0003oWL7aoig1l@05o`000003oio0l?l0003o000000?o000000CoYl?^o`00
0?l0003oZ<O_0ol00003ojS8l@Go00002onbdo400ol0003o_Mc_okgLk`07o`0000?o]N?f00?o0000
okgalonmlO<01_nmlO<00ol0003o`OcVol7liP03o`0003Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000I_ooool3o`00
00Co1WCO00Co0000odNLm?m7W?CoAicd1?l000000omQV^oo0000ogZ/l`0:ogZ/l`03o`000?n=^??o
SKSc00SoSKSc2_l000000onM`O7o0000o`00000>o`0000?oYl[b00?o0000ok;ClOnbdo401?nbdo40
0ol0003o/]?aok;Cl@03ok;Cl@?o00002OnehoH00ol0003o_O7cokgal`06okgal`03o`000?o1o>Ko
000000?o0000=oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aoooo
o`03o`000?oooooo000000;o0000Joooool2o`0000Co1WCO00?o0000odNLm?m7W?@01?m7W?@5o`00
00SoNZcc00?o0000ohfhlon=^?<02_n=^?<00ol0003oVl;coi_2l`05oi_2la_o00001_n]eoH00ol0
003o]N?fokGSmP08okGSmP03o`000?nmlO?o_O7c00Ko_O7c0ol000000on6jm7o0000ooooo`0ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool0017ooooo0_l0001`ooooo`03
o`000?l6M=oo1WCO00;o1WCO0_l00007odNLm0;oKk7i1ol000000omj[??o0000ohfhl`06ohfhl`Go
000000?oSKSco`000?l000002_l000000onKaoKo0000o`000008o`0000?oYL_c00?o0000ojgGm_n]
eoH02_n]eoH00ol0003o]N?fokGSmP08okGSmP03o`000?nmlO?o_O7c00?o_O7c1?l00002ohK[d@;o
0000??ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`00
0?oooooooooo06kooooo0ol00003o`Idg`03o`000?m7W?CoAicd00GoAicd00?o0000ofnanOm_/OT0
1Om_/OT9o`0000OoR;cg00?o0000oi[3m?nJ`o@00ol00002oi[5m@;o000000KoVlOfo`000?l0003o
W/[fo`000?nQboH3o`0000?oXlce1_l00009ojgGmP03o`000?nehoKo]N?f00So]N?f00?o0000okga
lol000001?l000001?nPlOCo0000ohK[dOn6jm42o`0003oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`005?ooool2o`00073ooooo00Ko06:mo`000?l0003o0000o`Idgol0
0007odNLm003o`000?m_/OWoKk7i00OoKk7i00?o0000ohRlmon8_?L02on8_?L2o`0000?oV/Ge0_l0
0003oi_7mP;o00000_nNb_H01?l0003oXL_foj7;m_nQboH2o`000003oj?<mOl0003oY]Si00CoY]Si
1Ol00004ojgGmP03o`000?nehoKo]N?f00;o]N?f2?l00004oj3am0;o00000_n6jm400ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Kooooo00?o
0000ooooool00000Koooool00ol0003o06:mo`000002o`0000OoAicd00?o0000ofnanOm_/OT01om_
/OT00ol0003oR;cgohRlm`04ohRlm`Co00001?n6`_/00ol0003oV/Geo`000004oi_7mP04o`000?nL
bOKoW<Wfo`0000;oW/[f00?o0000oj7;m_nQboH01Ol0000:ojKHn@So00000onViO/00ol0003oX?7d
oj3am004oj3am0;o00000_n6jm42o`0004?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`04ooooo`005oooool2o`0007;ooooo0_l0H[d6o`0000;oAicd00?o0000ofnanOm_/OT01om_
/OT00ol0003oR;cgohRlm`03o`0000WoQ/;k1?l00002oi_7mP05o`000?nLbOKoW<Wfo`000?nNb_H0
1?l00005oigGo0?o00001_nVf?T2o`0000WoY^Gk00?o0000oj3am?nPlO@01?nPlO@01Ol0003oQ^_A
ohK[dOn6jm7o000004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
6?ooool2o`0007?ooooo00?o0000o`1R_Ol000000ol^W_4?o`0000WoQ/;k0_l00005ohO7o@Oo0000
1?nCdod00ol0003oWMOloigGo005oigGo0;o00000_nVf?T2o`0000WoY^Gk0_l00005oj3am0;o0000
00CoQ^_Ao`000?l0003o0000B?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Co
oooo000Jooooo`03o`000?oooooooooo07;ooooo00Co0000o`1R_Ol0003o00001Ol^W_42o`0000So
I[Sl0ol00005ohK2n`03o`000?n7aogoQlOm00GoQlOm00?o0000ohc>o_n<c_h00_n<c_h00ol0003o
Tm?moi?Co@04oi?Co@03o`000?nMeocoWMOl00KoWMOl1?l00008ojKUn`03o`000?nPlOCoX?7d00Co
X?7d1?l0001<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool001_ooooo
0_l000000ooooooo0000ooooo`1aooooo`03o`000?l0H[go000000;o00001?l^W_42o`0000WoI[Sl
0_l000000on6`__o0000o`000007ohO7o@03o`000?n<c_koS<kn00?oS<kn00?o0000oi?CoOnCdod0
1OnCdod00ol0003oWMOloigGo002oigGo0?o00001?nBhOd5o`0000;oY^Gk00?o0000oj3am?nPlO@0
1_l0001@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001gooooo0_l0
001booooo`05o`000?ooooooooooo`000?l0H[d00_l00004objNl@;o00002OmV^?`00ol0003oQlOm
o`000002o`0000CoQlOm00?o0000ohc>o_n<c_h01On<c_h00ol0003oTm?moi?Co@05oi?Co@04o`00
0?nMeoco0000o`0000_oT^7m2Ol0001Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool001kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`03o`1R
_Ol0003o000000Co;Yka0_l00002ofJho0?o00001omT`Oh9o`0000?oS<kn00?o0000oi?CoOnCdod0
0_nCdod6o`0000SoT^7m1?l00003ogCPk0?o0000Eoooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003oooooooooo`06ooooo`Go000000?o
;Ykao`000?l000003?mT`Oh00ol0003oJlcmof_<o@04of_<o@So00001_mlf?h3o`0000;oT^7m0ol0
0004ogCPk0?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Q
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02_ooool2o`0000Co8ZCV1_l00003
ofC1oP03o`000?m[c?goJlcm00SoJlcm00?o0000ogcHo_mlf?h02?mlf?h7o`0000;oM>3/0ol0001O
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001/oooo
o`03o`000?oooooooooo00oooooo1Ol00002ob:TiP?o00000_m[c?d5o`0000GoJlcm00?o0000ogcH
o_mlf?h01ol00004odO7h@Go0000Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo000Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05?ooool3o`0000Wo
:[3N2?l00002odO7h@Wo0000JOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;o
oooo000Uooooo`;o0000J_ooool00ol0003oooooooooo`0Oooooo`_o0000L_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Wooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo000X
ooooo`03o`000?oooooo000006Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;ooooo000Nooooo`Co000000?o410@ooooooooool01?ooool2o`00
06Kooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool001Gooooo
1_l00005ooooo`03o`000?oooooooooo00Wooooo0_l0001Sooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`008?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00cooooo0_l0001P
ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01
ooooo`008?ooool00ol0003oooooooooo`0=ooooo`;o0000Goooool00ol0003oooooooooo`2Soooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0023ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o0000
00?oooooo`000?ooool0F?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00Oooool003Gooooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000hoooo
o`05o`000?ooooooooooooooool00000Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00Oooool003Wooooo00Co0000oooooooooooo0000Doooool0
0ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000joooo
o`?o0000Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`7ooooo000looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`08ooooo`7o00000Oooool1ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0
Zoooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00
001>ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Ooo
ool0043ooooo0_l0001>ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1
o`00007ooooo0Oooool0047ooooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003oooo
ool0003ooooo04Oooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`04ooooo`7o0000
0Oooool004Kooooo0_l00018ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Co
A4A4o`000?l0003o<S8b0_l00017ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo000booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00CoMgMgoc8b<_oooooo0000A_ooool00ol0003oooooooooo`2booooo`05o`000?oooooooooooooo
ool000000Oooool002[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03o`0004?ooooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001
ooooo`00<_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Ooo
ool003;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0
0Ol0000003;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo
0_l00010ooooo`03o`000?oooooooooo0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o0000?_ooool00ol0003ooooo
ooooo`2fooooo`;o0000000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo
0_l0000mooooo`03o`000?oooooooooo0;Gooooo0ol0000005?ooooo00Go0000oooooooooooooooo
o`00000hooooo`03o`000?oooooooooo0;3ooooo1Ol00003ooooo`00E?ooool01?l0003ooooooooo
ool0000hooooo`03o`000?oooooooooo0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o
0000ooooooooool0Z?ooool4o`0000cooooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0Y?ooool5o`00013ooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Poooo
o`Co00005Oooool005[ooooo00?o0000ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co
00006Oooool005_ooooo0_l0000booooo`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool0
1?l0003oooooooooool0000]ooooo`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3
o`0002gooooo00?o0000ooooooooool0R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02_ooool2o`0002_ooooo00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo
07gooooo1?l0000hooooo`00Doooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Xoooo
o`03o`000?oooooooooo07Wooooo1?l0000looooo`00Doooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?o
oooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000
ooooooooool0L?ooool4o`0004Gooooo001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3
o`0002?ooooo00?o0000ooooooooool0Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool2o`0002?ooooo00?o0000ooooooooool0Ioooool4o`0004kooooo001Coooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0003ooooo01kooooo00?o0000
ooooooooool0Hoooool4o`0005;ooooo001^ooooo`;o00007oooool00ol0003oooooooooo`1Noooo
o`Go0000E_ooool006oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co
0000Foooool0073ooooo0_l0000Mooooo`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_oo
ool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2
o`0001[ooooo00?o0000ooooooooool0COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0BOooool4o`0006cooooo001fooooo`;o000000?oooooo`000?oo
ool05?ooool00ol0003oooooooooo`14ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`00
0?oooooooooo043ooooo1?l0001eooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo03_ooooo1Ol0001iooooo`00N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000
ooooooooool0=oooool4o`0007kooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o00004Oooool00ol0003ooooooooo
o`0cooooo`Co0000P_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_oo
ool006?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oo
oooooooo02Oooooo1?l0002?ooooo`00Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool5o`0009?ooooo001Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07_ooool4o`0009So
oooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o
00001oooool00ol0003oooooooooo`0Iooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo1?l0002Qooooo`00Qoooool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo
0029ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000
ooooooooooooooooo`00000:ooooo`Co0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05
ooooo`Co0000/_ooool008gooooo0_l000000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o
0000^oooool00?ooooooC?ooool00?ooooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30
ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00
Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool0
0ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGo
IVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47478 .59271 m .46849 .63475 L .54584 .6384 L p .719 .589 .709 r
F P
0 g
s
.54584 .6384 m .54372 .59605 L .47478 .59271 L p .719 .589 .709 r
F P
0 g
s
.54745 .68104 m .54584 .6384 L .46849 .63475 L p .72 .558 .669 r
F P
0 g
s
.54372 .59605 m .54584 .6384 L .6216 .62744 L p .669 .55 .711 r
F P
0 g
s
.54584 .6384 m .54745 .68104 L .62948 .66949 L p .662 .513 .671 r
F P
0 g
s
.62948 .66949 m .6216 .62744 L .54584 .6384 L p .662 .513 .671 r
F P
0 g
s
.48223 .55255 m .47478 .59271 L .54372 .59605 L p .716 .617 .745 r
F P
0 g
s
.54372 .59605 m .54121 .55547 L .48223 .55255 L p .716 .617 .745 r
F P
0 g
s
.54121 .55547 m .54372 .59605 L .61118 .58603 L p .673 .584 .747 r
F P
0 g
s
.6216 .62744 m .61118 .58603 L .54372 .59605 L p .669 .55 .711 r
F P
0 g
s
.41025 .57623 m .39591 .6167 L .46849 .63475 L p .767 .634 .714 r
F P
0 g
s
.46849 .63475 m .47478 .59271 L .41025 .57623 L p .767 .634 .714 r
F P
0 g
s
.46373 .6772 m .46849 .63475 L .39591 .6167 L p .775 .608 .673 r
F P
0 g
s
.46849 .63475 m .46373 .6772 L .54745 .68104 L p .72 .558 .669 r
F P
0 g
s
.42717 .53813 m .41025 .57623 L .47478 .59271 L p .757 .656 .75 r
F P
0 g
s
.47478 .59271 m .48223 .55255 L .42717 .53813 L p .757 .656 .75 r
F P
0 g
s
.54842 .72216 m .54745 .68104 L .46373 .6772 L p .718 .522 .623 r
F P
0 g
s
.54745 .68104 m .54842 .72216 L .63425 .71039 L p .652 .469 .623 r
F P
0 g
s
.63425 .71039 m .62948 .66949 L .54745 .68104 L p .652 .469 .623 r
F P
0 g
s
.49046 .51526 m .48223 .55255 L .54121 .55547 L p .712 .642 .777 r
F P
0 g
s
.54121 .55547 m .53844 .51769 L .49046 .51526 L p .712 .642 .777 r
F P
0 g
s
.53844 .51769 m .54121 .55547 L .59887 .5467 L p .676 .615 .779 r
F P
0 g
s
.61118 .58603 m .59887 .5467 L .54121 .55547 L p .673 .584 .747 r
F P
0 g
s
.44579 .50328 m .42717 .53813 L .48223 .55255 L p .745 .675 .783 r
F P
0 g
s
.48223 .55255 m .49046 .51526 L .44579 .50328 L p .745 .675 .783 r
F P
0 g
s
.39591 .6167 m .38505 .65816 L .46373 .6772 L p .775 .608 .673 r
F P
0 g
s
.46085 .71824 m .46373 .6772 L .38505 .65816 L p .781 .577 .624 r
F P
0 g
s
.46373 .6772 m .46085 .71824 L .54842 .72216 L p .718 .522 .623 r
F P
0 g
s
.59887 .5467 m .61118 .58603 L .67129 .56329 L p .626 .556 .756 r
F P
0 g
s
.61118 .58603 m .6216 .62744 L .68936 .6025 L p .612 .514 .719 r
F P
0 g
s
.68936 .6025 m .67129 .56329 L .61118 .58603 L p .612 .514 .719 r
F P
0 g
s
.6216 .62744 m .62948 .66949 L .70307 .64315 L p .595 .468 .676 r
F P
0 g
s
.70307 .64315 m .68936 .6025 L .6216 .62744 L p .595 .468 .676 r
F P
0 g
s
.59887 .5467 m .5853 .51039 L .53844 .51769 L p .676 .615 .779 r
F P
0 g
s
.5853 .51039 m .59887 .5467 L .65002 .52683 L p .637 .594 .788 r
F P
0 g
s
.67129 .56329 m .65002 .52683 L .59887 .5467 L p .626 .556 .756 r
F P
0 g
s
.49913 .4813 m .49046 .51526 L .53844 .51769 L p .705 .665 .808 r
F P
0 g
s
.53844 .51769 m .53551 .48318 L .49913 .4813 L p .705 .665 .808 r
F P
0 g
s
.53551 .48318 m .53844 .51769 L .5853 .51039 L p .677 .644 .809 r
F P
0 g
s
.62948 .66949 m .63425 .71039 L .7114 .68352 L p .574 .413 .625 r
F P
0 g
s
.7114 .68352 m .70307 .64315 L .62948 .66949 L p .574 .413 .625 r
F P
0 g
s
.54867 .7598 m .54842 .72216 L .46085 .71824 L p .713 .476 .565 r
F P
0 g
s
.54842 .72216 m .54867 .7598 L .63552 .74819 L p .638 .415 .564 r
F P
0 g
s
.63552 .74819 m .63425 .71039 L .54842 .72216 L p .638 .415 .564 r
F P
0 g
s
.46538 .47206 m .44579 .50328 L .49046 .51526 L p .731 .691 .813 r
F P
0 g
s
.49046 .51526 m .49913 .4813 L .46538 .47206 L p .731 .691 .813 r
F P
0 g
s
.38115 .51323 m .35595 .54767 L .41025 .57623 L p .795 .703 .763 r
F P
0 g
s
.41025 .57623 m .42717 .53813 L .38115 .51323 L p .795 .703 .763 r
F P
0 g
s
.39591 .6167 m .41025 .57623 L .35595 .54767 L p .814 .688 .726 r
F P
0 g
s
.35595 .54767 m .33449 .58532 L .39591 .6167 L p .814 .688 .726 r
F P
0 g
s
.38505 .65816 m .39591 .6167 L .33449 .58532 L p .831 .669 .681 r
F P
0 g
s
.38505 .65816 m .37846 .69883 L .46085 .71824 L p .781 .577 .624 r
F P
0 g
s
.46008 .75594 m .46085 .71824 L .37846 .69883 L p .783 .536 .562 r
F P
0 g
s
.46085 .71824 m .46008 .75594 L .54867 .7598 L p .713 .476 .565 r
F P
0 g
s
.40873 .48271 m .38115 .51323 L .42717 .53813 L p .775 .714 .796 r
F P
0 g
s
.42717 .53813 m .44579 .50328 L .40873 .48271 L p .775 .714 .796 r
F P
0 g
s
.5853 .51039 m .57099 .47754 L .53551 .48318 L p .677 .644 .809 r
F P
0 g
s
.57099 .47754 m .5853 .51039 L .62666 .49394 L p .647 .629 .817 r
F P
0 g
s
.65002 .52683 m .62666 .49394 L .5853 .51039 L p .637 .594 .788 r
F P
0 g
s
.33449 .58532 m .31818 .62497 L .38505 .65816 L p .831 .669 .681 r
F P
0 g
s
.37846 .69883 m .38505 .65816 L .31818 .62497 L p .846 .642 .626 r
F P
0 g
s
.63425 .71039 m .63552 .74819 L .71361 .72167 L p .545 .344 .558 r
F P
0 g
s
.71361 .72167 m .7114 .68352 L .63425 .71039 L p .545 .344 .558 r
F P
0 g
s
.43759 .45626 m .40873 .48271 L .44579 .50328 L p .753 .722 .824 r
F P
0 g
s
.44579 .50328 m .46538 .47206 L .43759 .45626 L p .753 .722 .824 r
F P
0 g
s
.50805 .45065 m .49913 .4813 L .53551 .48318 L p .697 .686 .836 r
F P
0 g
s
.53551 .48318 m .53249 .45193 L .50805 .45065 L p .697 .686 .836 r
F P
0 g
s
.53249 .45193 m .53551 .48318 L .57099 .47754 L p .677 .671 .837 r
F P
0 g
s
.65002 .52683 m .67129 .56329 L .71833 .52937 L p .57 .532 .773 r
F P
0 g
s
.67129 .56329 m .68936 .6025 L .7428 .56515 L p .542 .48 .735 r
F P
0 g
s
.7428 .56515 m .71833 .52937 L .67129 .56329 L p .542 .48 .735 r
F P
0 g
s
.48544 .44434 m .46538 .47206 L .49913 .4813 L p .715 .706 .84 r
F P
0 g
s
.49913 .4813 m .50805 .45065 L .48544 .44434 L p .715 .706 .84 r
F P
0 g
s
.62666 .49394 m .65002 .52683 L .68967 .49735 L p .594 .578 .805 r
F P
0 g
s
.71833 .52937 m .68967 .49735 L .65002 .52683 L p .57 .532 .773 r
F P
0 g
s
.68936 .6025 m .70307 .64315 L .76145 .60358 L p .509 .418 .688 r
F P
0 g
s
.76145 .60358 m .7428 .56515 L .68936 .6025 L p .509 .418 .688 r
F P
0 g
s
.54818 .79212 m .54867 .7598 L .46008 .75594 L p .701 .415 .487 r
F P
0 g
s
.54867 .7598 m .54818 .79212 L .63309 .78101 L p .614 .344 .484 r
F P
0 g
s
.63309 .78101 m .63552 .74819 L .54867 .7598 L p .614 .344 .484 r
F P
0 g
s
.57099 .47754 m .55632 .44808 L .53249 .45193 L p .677 .671 .837 r
F P
0 g
s
.55632 .44808 m .57099 .47754 L .60215 .46487 L p .655 .661 .843 r
F P
0 g
s
.62666 .49394 m .60215 .46487 L .57099 .47754 L p .647 .629 .817 r
F P
0 g
s
.60215 .46487 m .62666 .49394 L .65839 .46964 L p .615 .619 .832 r
F P
0 g
s
.68967 .49735 m .65839 .46964 L .62666 .49394 L p .594 .578 .805 r
F P
0 g
s
.37846 .69883 m .37671 .73679 L .46008 .75594 L p .783 .536 .562 r
F P
0 g
s
.46155 .78842 m .46008 .75594 L .37671 .73679 L p .779 .478 .477 r
F P
0 g
s
.46008 .75594 m .46155 .78842 L .54818 .79212 L p .701 .415 .487 r
F P
0 g
s
.46697 .43361 m .43759 .45626 L .46538 .47206 L p .73 .728 .849 r
F P
0 g
s
.46538 .47206 m .48544 .44434 L .46697 .43361 L p .73 .728 .849 r
F P
0 g
s
.31818 .62497 m .30826 .66496 L .37846 .69883 L p .846 .642 .626 r
F P
0 g
s
.37671 .73679 m .37846 .69883 L .30826 .66496 L p .858 .603 .552 r
F P
0 g
s
.70307 .64315 m .7114 .68352 L .77282 .64308 L p .467 .342 .626 r
F P
0 g
s
.77282 .64308 m .76145 .60358 L .70307 .64315 L p .467 .342 .626 r
F P
0 g
s
.38317 .45525 m .34894 .4798 L .38115 .51323 L p .8 .761 .817 r
F P
0 g
s
.38115 .51323 m .40873 .48271 L .38317 .45525 L p .8 .761 .817 r
F P
0 g
s
.35595 .54767 m .38115 .51323 L .34894 .4798 L p .831 .761 .786 r
F P
0 g
s
.34894 .4798 m .31745 .50908 L .35595 .54767 L p .831 .761 .786 r
F P
0 g
s
.33449 .58532 m .35595 .54767 L .31745 .50908 L p .861 .757 .747 r
F P
0 g
s
.60215 .46487 m .57712 .43945 L .55632 .44808 L p .655 .661 .843 r
F P
0 g
s
.57712 .43945 m .60215 .46487 L .6258 .44627 L p .633 .656 .855 r
F P
0 g
s
.65839 .46964 m .6258 .44627 L .60215 .46487 L p .615 .619 .832 r
F P
0 g
s
.5171 .42292 m .50805 .45065 L .53249 .45193 L p .688 .706 .861 r
F P
0 g
s
.53249 .45193 m .52943 .42358 L .5171 .42292 L p .688 .706 .861 r
F P
0 g
s
.52943 .42358 m .53249 .45193 L .55632 .44808 L p .675 .697 .862 r
F P
0 g
s
.63552 .74819 m .63309 .78101 L .70937 .75566 L p .502 .25 .465 r
F P
0 g
s
.70937 .75566 m .71361 .72167 L .63552 .74819 L p .502 .25 .465 r
F P
0 g
s
.41872 .43531 m .38317 .45525 L .40873 .48271 L p .77 .758 .842 r
F P
0 g
s
.40873 .48271 m .43759 .45626 L .41872 .43531 L p .77 .758 .842 r
F P
0 g
s
.50574 .4197 m .48544 .44434 L .50805 .45065 L p .699 .718 .864 r
F P
0 g
s
.50805 .45065 m .5171 .42292 L .50574 .4197 L p .699 .718 .864 r
F P
0 g
s
.55632 .44808 m .54143 .42161 L .52943 .42358 L p .675 .697 .862 r
F P
0 g
s
.54143 .42161 m .55632 .44808 L .57712 .43945 L p .662 .691 .866 r
F P
0 g
s
.31745 .50908 m .29048 .54272 L .33449 .58532 L p .861 .757 .747 r
F P
0 g
s
.31818 .62497 m .33449 .58532 L .29048 .54272 L p .891 .746 .695 r
F P
0 g
s
.49653 .41424 m .46697 .43361 L .48544 .44434 L p .707 .731 .87 r
F P
0 g
s
.48544 .44434 m .50574 .4197 L .49653 .41424 L p .707 .731 .87 r
F P
0 g
s
.45462 .41947 m .41872 .43531 L .43759 .45626 L p .74 .753 .862 r
F P
0 g
s
.43759 .45626 m .46697 .43361 L .45462 .41947 L p .74 .753 .862 r
F P
0 g
s
.7114 .68352 m .71361 .72167 L .77583 .68174 L p .409 .242 .541 r
F P
0 g
s
.77583 .68174 m .77282 .64308 L .7114 .68352 L p .409 .242 .541 r
F P
0 g
s
.57712 .43945 m .55186 .41721 L .54143 .42161 L p .662 .691 .866 r
F P
0 g
s
.55186 .41721 m .57712 .43945 L .59274 .42685 L p .648 .688 .874 r
F P
0 g
s
.6258 .44627 m .59274 .42685 L .57712 .43945 L p .633 .656 .855 r
F P
0 g
s
.54695 .81757 m .54818 .79212 L .46155 .78842 L p .674 .323 .372 r
F P
0 g
s
.54818 .79212 m .54695 .81757 L .62705 .80728 L p .572 .239 .365 r
F P
0 g
s
.62705 .80728 m .63309 .78101 L .54818 .79212 L p .572 .239 .365 r
F P
0 g
s
.65839 .46964 m .68967 .49735 L .71333 .46066 L p .545 .571 .832 r
F P
0 g
s
.68967 .49735 m .71833 .52937 L .74696 .48687 L p .502 .514 .802 r
F P
0 g
s
.74696 .48687 m .71333 .46066 L .68967 .49735 L p .502 .514 .802 r
F P
0 g
s
.6258 .44627 m .65839 .46964 L .67692 .43963 L p .58 .618 .854 r
F P
0 g
s
.71333 .46066 m .67692 .43963 L .65839 .46964 L p .545 .571 .832 r
F P
0 g
s
.30826 .66496 m .30563 .70334 L .37671 .73679 L p .858 .603 .552 r
F P
0 g
s
.38007 .77011 m .37671 .73679 L .30563 .70334 L p .861 .541 .446 r
F P
0 g
s
.37671 .73679 m .38007 .77011 L .46155 .78842 L p .779 .478 .477 r
F P
0 g
s
.29048 .54272 m .26986 .57975 L .31818 .62497 L p .891 .746 .695 r
F P
0 g
s
.30826 .66496 m .31818 .62497 L .26986 .57975 L p .919 .725 .625 r
F P
0 g
s
.71833 .52937 m .7428 .56515 L .77587 .51808 L p .449 .444 .761 r
F P
0 g
s
.77587 .51808 m .74696 .48687 L .71833 .52937 L p .449 .444 .761 r
F P
0 g
s
.4652 .81415 m .46155 .78842 L .38007 .77011 L p .76 .387 .349 r
F P
0 g
s
.46155 .78842 m .4652 .81415 L .54695 .81757 L p .674 .323 .372 r
F P
0 g
s
.59274 .42685 m .6258 .44627 L .63928 .42346 L p .61 .657 .871 r
F P
0 g
s
.67692 .43963 m .63928 .42346 L .6258 .44627 L p .58 .618 .854 r
F P
0 g
s
.49047 .4071 m .45462 .41947 L .46697 .43361 L p .712 .746 .878 r
F P
0 g
s
.46697 .43361 m .49653 .41424 L .49047 .4071 L p .712 .746 .878 r
F P
0 g
s
.52943 .42358 m .52632 .39764 L .5171 .42292 L closepath p .676 .724 .886 r
F P
0 g
s
.54143 .42161 m .52632 .39764 L .52943 .42358 L closepath p .672 .721 .886 r
F P
0 g
s
.5171 .42292 m .52632 .39764 L .50574 .4197 L closepath p .68 .728 .887 r
F P
0 g
s
.55186 .41721 m .52632 .39764 L .54143 .42161 L closepath p .667 .719 .887 r
F P
0 g
s
.59274 .42685 m .55959 .41082 L .55186 .41721 L p .648 .688 .874 r
F P
0 g
s
.55959 .41082 m .59274 .42685 L .60142 .41152 L p .636 .69 .884 r
F P
0 g
s
.63928 .42346 m .60142 .41152 L .59274 .42685 L p .61 .657 .871 r
F P
0 g
s
.50574 .4197 m .52632 .39764 L .49653 .41424 L closepath p .682 .733 .889 r
F P
0 g
s
.7428 .56515 m .76145 .60358 L .79802 .55351 L p .382 .355 .704 r
F P
0 g
s
.79802 .55351 m .77587 .51808 L .7428 .56515 L p .382 .355 .704 r
F P
0 g
s
.63309 .78101 m .62705 .80728 L .69884 .78382 L p .431 .112 .322 r
F P
0 g
s
.69884 .78382 m .70937 .75566 L .63309 .78101 L p .431 .112 .322 r
F P
0 g
s
.55959 .41082 m .52632 .39764 L .55186 .41721 L closepath p .662 .718 .89 r
F P
0 g
s
.41103 .41122 m .37227 .42342 L .38317 .45525 L p .778 .796 .868 r
F P
0 g
s
.38317 .45525 m .41872 .43531 L .41103 .41122 L p .778 .796 .868 r
F P
0 g
s
.34894 .4798 m .38317 .45525 L .37227 .42342 L p .817 .815 .848 r
F P
0 g
s
.44983 .40335 m .41103 .41122 L .41872 .43531 L p .743 .778 .881 r
F P
0 g
s
.41872 .43531 m .45462 .41947 L .44983 .40335 L p .743 .778 .881 r
F P
0 g
s
.49653 .41424 m .52632 .39764 L .49047 .4071 L closepath p .684 .738 .892 r
F P
0 g
s
.37227 .42342 m .33461 .44073 L .34894 .4798 L p .817 .815 .848 r
F P
0 g
s
.31745 .50908 m .34894 .4798 L .33461 .44073 L p .858 .832 .82 r
F P
0 g
s
.26986 .57975 m .25728 .61868 L .30826 .66496 L p .919 .725 .625 r
F P
0 g
s
.30563 .70334 m .30826 .66496 L .25728 .61868 L p .941 .685 .523 r
F P
0 g
s
.71361 .72167 m .70937 .75566 L .77004 .71752 L p .324 .101 .414 r
F P
0 g
s
.77004 .71752 m .77583 .68174 L .71361 .72167 L p .324 .101 .414 r
F P
0 g
s
.48825 .39902 m .44983 .40335 L .45462 .41947 L p .712 .76 .889 r
F P
0 g
s
.45462 .41947 m .49047 .4071 L .48825 .39902 L p .712 .76 .889 r
F P
0 g
s
.56379 .40311 m .52632 .39764 L .55959 .41082 L closepath p .658 .719 .893 r
F P
0 g
s
.60142 .41152 m .56379 .40311 L .55959 .41082 L p .636 .69 .884 r
F P
0 g
s
.49047 .4071 m .52632 .39764 L .48825 .39902 L closepath p .683 .742 .895 r
F P
0 g
s
.33461 .44073 m .29969 .46366 L .31745 .50908 L p .858 .832 .82 r
F P
0 g
s
.29048 .54272 m .31745 .50908 L .29969 .46366 L p .903 .845 .777 r
F P
0 g
s
.76145 .60358 m .77282 .64308 L .81157 .59178 L p .292 .235 .62 r
F P
0 g
s
.81157 .59178 m .79802 .55351 L .76145 .60358 L p .292 .235 .62 r
F P
0 g
s
.56379 .40311 m .60142 .41152 L .60209 .39503 L p .626 .697 .896 r
F P
0 g
s
.60142 .41152 m .63928 .42346 L .6408 .39871 L p .59 .666 .891 r
F P
0 g
s
.6408 .39871 m .60209 .39503 L .60142 .41152 L p .59 .666 .891 r
F P
0 g
s
.30563 .70334 m .31068 .73815 L .38007 .77011 L p .861 .541 .446 r
F P
0 g
s
.3884 .79718 m .38007 .77011 L .31068 .73815 L p .84 .436 .278 r
F P
0 g
s
.38007 .77011 m .3884 .79718 L .4652 .81415 L p .76 .387 .349 r
F P
0 g
s
.63928 .42346 m .67692 .43963 L .67964 .40677 L p .545 .626 .883 r
F P
0 g
s
.67964 .40677 m .6408 .39871 L .63928 .42346 L p .545 .626 .883 r
F P
0 g
s
.56395 .39488 m .52632 .39764 L .56379 .40311 L closepath p .655 .722 .897 r
F P
0 g
s
.60209 .39503 m .56395 .39488 L .56379 .40311 L p .626 .697 .896 r
F P
0 g
s
.67692 .43963 m .71333 .46066 L .71755 .42016 L p .487 .573 .867 r
F P
0 g
s
.71755 .42016 m .67964 .40677 L .67692 .43963 L p .487 .573 .867 r
F P
0 g
s
.55235 .38044 m .52632 .39764 L .56001 .38703 L closepath p .654 .73 .905 r
F P
0 g
s
.48825 .39902 m .52632 .39764 L .49014 .39087 L closepath p .682 .745 .899 r
F P
0 g
s
.56001 .38703 m .52632 .39764 L .56395 .39488 L closepath p .654 .725 .901 r
F P
0 g
s
.54179 .37584 m .52632 .39764 L .55235 .38044 L closepath p .656 .735 .908 r
F P
0 g
s
.52949 .37377 m .52632 .39764 L .54179 .37584 L closepath p .659 .74 .91 r
F P
0 g
s
.51683 .37447 m .52632 .39764 L .52949 .37377 L closepath p .664 .744 .91 r
F P
0 g
s
.50524 .37786 m .52632 .39764 L .51683 .37447 L closepath p .669 .747 .909 r
F P
0 g
s
.49601 .38354 m .52632 .39764 L .50524 .37786 L closepath p .674 .748 .907 r
F P
0 g
s
.49014 .39087 m .52632 .39764 L .49601 .38354 L closepath p .678 .748 .903 r
F P
0 g
s
.54506 .83517 m .54695 .81757 L .4652 .81415 L p .61 .172 .184 r
F P
0 g
s
.54695 .81757 m .54506 .83517 L .61774 .82594 L p .489 .069 .169 r
F P
0 g
s
.61774 .82594 m .62705 .80728 L .54695 .81757 L p .489 .069 .169 r
F P
0 g
s
.44983 .40335 m .48825 .39902 L .49014 .39087 L p .708 .771 .902 r
F P
0 g
s
.49014 .39087 m .45333 .38695 L .44983 .40335 L p .708 .771 .902 r
F P
0 g
s
.41103 .41122 m .44983 .40335 L .45333 .38695 L p .738 .8 .902 r
F P
0 g
s
.47082 .8321 m .4652 .81415 L .3884 .79718 L p .699 .231 .137 r
F P
0 g
s
.4652 .81415 m .47082 .8321 L .54506 .83517 L p .61 .172 .184 r
F P
0 g
s
.56395 .39488 m .60209 .39503 L .59445 .37917 L p .619 .707 .908 r
F P
0 g
s
.59445 .37917 m .56001 .38703 L .56395 .39488 L p .619 .707 .908 r
F P
0 g
s
.29969 .46366 m .26955 .49225 L .29048 .54272 L p .903 .845 .777 r
F P
0 g
s
.26986 .57975 m .29048 .54272 L .26955 .49225 L p .948 .85 .712 r
F P
0 g
s
.71333 .46066 m .74696 .48687 L .75285 .4396 L p .411 .501 .841 r
F P
0 g
s
.75285 .4396 m .71755 .42016 L .71333 .46066 L p .411 .501 .841 r
F P
0 g
s
.45333 .38695 m .41579 .38648 L .41103 .41122 L p .738 .8 .902 r
F P
0 g
s
.37227 .42342 m .41103 .41122 L .41579 .38648 L p .773 .834 .899 r
F P
0 g
s
.45333 .38695 m .49014 .39087 L .49601 .38354 L p .698 .779 .914 r
F P
0 g
s
.25728 .61868 m .25394 .65763 L .30563 .70334 L p .941 .685 .523 r
F P
0 g
s
.31068 .73815 m .30563 .70334 L .25394 .65763 L p .942 .606 .361 r
F P
0 g
s
.60209 .39503 m .6408 .39871 L .62971 .37468 L p .574 .682 .914 r
F P
0 g
s
.62971 .37468 m .59445 .37917 L .60209 .39503 L p .574 .682 .914 r
F P
0 g
s
.77282 .64308 m .77583 .68174 L .81518 .63104 L p .162 .064 .488 r
F P
0 g
s
.81518 .63104 m .81157 .59178 L .77282 .64308 L p .162 .064 .488 r
F P
0 g
s
.56001 .38703 m .59445 .37917 L .57915 .36572 L p .617 .721 .92 r
F P
0 g
s
.57915 .36572 m .55235 .38044 L .56001 .38703 L p .617 .721 .92 r
F P
0 g
s
.62705 .80728 m .61774 .82594 L .68267 .80496 L p .299 0 .082 r
F P
0 g
s
.68267 .80496 m .69884 .78382 L .62705 .80728 L p .299 0 .082 r
F P
0 g
s
.70937 .75566 m .69884 .78382 L .75569 .7486 L p .185 0 .207 r
F P
0 g
s
.75569 .7486 m .77004 .71752 L .70937 .75566 L p .185 0 .207 r
F P
0 g
s
.41579 .38648 m .37796 .39044 L .37227 .42342 L p .773 .834 .899 r
F P
0 g
s
.33461 .44073 m .37227 .42342 L .37796 .39044 L p .815 .872 .888 r
F P
0 g
s
.46492 .37206 m .49601 .38354 L .50524 .37786 L p .683 .782 .925 r
F P
0 g
s
.49601 .38354 m .46492 .37206 L .45333 .38695 L p .698 .779 .914 r
F P
0 g
s
.74696 .48687 m .77587 .51808 L .78344 .46538 L p .308 .401 .795 r
F P
0 g
s
.78344 .46538 m .75285 .4396 L .74696 .48687 L p .308 .401 .795 r
F P
0 g
s
.55235 .38044 m .57915 .36572 L .55779 .35629 L p .622 .738 .93 r
F P
0 g
s
.55779 .35629 m .54179 .37584 L .55235 .38044 L p .622 .738 .93 r
F P
0 g
s
.41579 .38648 m .45333 .38695 L .46492 .37206 L p .721 .817 .925 r
F P
0 g
s
.26955 .49225 m .24638 .52592 L .26986 .57975 L p .948 .85 .712 r
F P
0 g
s
.25728 .61868 m .26986 .57975 L .24638 .52592 L p .987 .835 .604 r
F P
0 g
s
.6408 .39871 m .67964 .40677 L .6654 .37459 L p .512 .645 .916 r
F P
0 g
s
.6654 .37459 m .62971 .37468 L .6408 .39871 L p .512 .645 .916 r
F P
0 g
s
.48349 .36044 m .50524 .37786 L .51683 .37447 L p .665 .778 .933 r
F P
0 g
s
.50524 .37786 m .48349 .36044 L .46492 .37206 L p .683 .782 .925 r
F P
0 g
s
.54179 .37584 m .55779 .35629 L .53278 .35203 L p .632 .754 .936 r
F P
0 g
s
.53278 .35203 m .52949 .37377 L .54179 .37584 L p .632 .754 .936 r
F P
0 g
s
.507 .35347 m .51683 .37447 L .52949 .37377 L p .647 .768 .937 r
F P
0 g
s
.51683 .37447 m .507 .35347 L .48349 .36044 L p .665 .778 .933 r
F P
0 g
s
.52949 .37377 m .53278 .35203 L .507 .35347 L p .647 .768 .937 r
F P
0 g
s
.31068 .73815 m .32322 .76763 L .3884 .79718 L p .84 .436 .278 r
F P
0 g
s
.40122 .8169 m .3884 .79718 L .32322 .76763 L p .749 .239 0 r
F P
0 g
s
.3884 .79718 m .40122 .8169 L .47082 .8321 L p .699 .231 .137 r
F P
0 g
s
.37796 .39044 m .34088 .39989 L .33461 .44073 L p .815 .872 .888 r
F P
0 g
s
.29969 .46366 m .33461 .44073 L .34088 .39989 L p .863 .912 .864 r
F P
0 g
s
.59445 .37917 m .62971 .37468 L .60679 .35415 L p .566 .706 .936 r
F P
0 g
s
.60679 .35415 m .57915 .36572 L .59445 .37917 L p .566 .706 .936 r
F P
0 g
s
.77587 .51808 m .79802 .55351 L .80703 .49715 L p .16 .254 .713 r
F P
0 g
s
.80703 .49715 m .78344 .46538 L .77587 .51808 L p .16 .254 .713 r
F P
0 g
s
.67964 .40677 m .71755 .42016 L .70053 .38014 L p .423 .589 .91 r
F P
0 g
s
.70053 .38014 m .6654 .37459 L .67964 .40677 L p .423 .589 .91 r
F P
0 g
s
.46492 .37206 m .43296 .36385 L .41579 .38648 L p .721 .817 .925 r
F P
0 g
s
.37796 .39044 m .41579 .38648 L .43296 .36385 L p .748 .864 .933 r
F P
0 g
s
.43296 .36385 m .46492 .37206 L .48349 .36044 L p .692 .823 .946 r
F P
0 g
s
.77583 .68174 m .77004 .71752 L .80826 .66917 L p 0 0 .267 r
F P
0 g
s
.80826 .66917 m .81518 .63104 L .77583 .68174 L p 0 0 .267 r
F P
0 g
s
.25394 .65763 m .26036 .69452 L .31068 .73815 L p .942 .606 .361 r
F P
0 g
s
.32322 .76763 m .31068 .73815 L .26036 .69452 L p .879 .443 .093 r
F P
0 g
s
.54261 .84459 m .54506 .83517 L .47082 .8321 L p .454 0 0 r
F P
0 g
s
.54506 .83517 m .54261 .84459 L .60574 .83663 L p .307 0 0 r
F P
0 g
s
.60574 .83663 m .61774 .82594 L .54506 .83517 L p .307 0 0 r
F P
0 g
s
.47808 .84194 m .47082 .8321 L .40122 .8169 L p .525 0 0 r
F P
0 g
s
.47082 .8321 m .47808 .84194 L .54261 .84459 L p .454 0 0 r
F P
0 g
s
.24638 .52592 m .23218 .56345 L .25728 .61868 L p .987 .835 .604 r
F P
0 g
s
.25394 .65763 m .25728 .61868 L .23218 .56345 L p .996 .771 .419 r
F P
0 g
s
.57915 .36572 m .60679 .35415 L .57439 .33965 L p .57 .736 .954 r
F P
0 g
s
.57439 .33965 m .55779 .35629 L .57915 .36572 L p .57 .736 .954 r
F P
0 g
s
.34088 .39989 m .30619 .41579 L .29969 .46366 L p .863 .912 .864 r
F P
0 g
s
.26955 .49225 m .29969 .46366 L .30619 .41579 L p .912 .949 .81 r
F P
0 g
s
.69884 .78382 m .68267 .80496 L .73372 .77357 L p 0 0 0 r
F P
0 g
s
.73372 .77357 m .75569 .7486 L .69884 .78382 L p 0 0 0 r
F P
0 g
s
.62971 .37468 m .6654 .37459 L .63498 .34686 L p .488 .678 .95 r
F P
0 g
s
.63498 .34686 m .60679 .35415 L .62971 .37468 L p .488 .678 .95 r
F P
0 g
s
.46098 .34604 m .48349 .36044 L .507 .35347 L p .656 .817 .961 r
F P
0 g
s
.48349 .36044 m .46098 .34604 L .43296 .36385 L p .692 .823 .946 r
F P
0 g
s
.61774 .82594 m .60574 .83663 L .66187 .81857 L p .053 0 0 r
F P
0 g
s
.66187 .81857 m .68267 .80496 L .61774 .82594 L p .053 0 0 r
F P
0 g
s
.71755 .42016 m .75285 .4396 L .73353 .3925 L p .289 .496 .886 r
F P
0 g
s
.73353 .3925 m .70053 .38014 L .71755 .42016 L p .289 .496 .886 r
F P
0 g
s
.43296 .36385 m .40049 .36 L .37796 .39044 L p .748 .864 .933 r
F P
0 g
s
.34088 .39989 m .37796 .39044 L .40049 .36 L p .779 .92 .932 r
F P
0 g
s
.79802 .55351 m .81157 .59178 L .82152 .53385 L p 0 .03 .56 r
F P
0 g
s
.82152 .53385 m .80703 .49715 L .79802 .55351 L p 0 .03 .56 r
F P
0 g
s
.55779 .35629 m .57439 .33965 L .5362 .33308 L p .587 .768 .965 r
F P
0 g
s
.5362 .33308 m .53278 .35203 L .55779 .35629 L p .587 .768 .965 r
F P
0 g
s
.4968 .33531 m .507 .35347 L .53278 .35203 L p .618 .797 .968 r
F P
0 g
s
.507 .35347 m .4968 .33531 L .46098 .34604 L p .656 .817 .961 r
F P
0 g
s
.53278 .35203 m .5362 .33308 L .4968 .33531 L p .618 .797 .968 r
F P
0 g
s
.40049 .36 m .43296 .36385 L .46098 .34604 L p .698 .876 .964 r
F P
0 g
s
.30619 .41579 m .27602 .43869 L .26955 .49225 L p .912 .949 .81 r
F P
0 g
s
.24638 .52592 m .26955 .49225 L .27602 .43869 L p .945 .96 .695 r
F P
0 g
s
.32322 .76763 m .34245 .79052 L .40122 .8169 L p .749 .239 0 r
F P
0 g
s
.41774 .82884 m .40122 .8169 L .34245 .79052 L p .491 0 0 r
F P
0 g
s
.40122 .8169 m .41774 .82884 L .47808 .84194 L p .525 0 0 r
F P
0 g
s
.77004 .71752 m .75569 .7486 L .79116 .7041 L p 0 0 0 r
F P
0 g
s
.79116 .7041 m .80826 .66917 L .77004 .71752 L p 0 0 0 r
F P
0 g
s
.23218 .56345 m .22841 .60302 L .25394 .65763 L p .996 .771 .419 r
F P
0 g
s
.26036 .69452 m .25394 .65763 L .22841 .60302 L p .906 .596 .106 r
F P
0 g
s
.26036 .69452 m .27624 .72741 L .32322 .76763 L p .879 .443 .093 r
F P
0 g
s
.34245 .79052 m .32322 .76763 L .27624 .72741 L p .659 .141 0 r
F P
0 g
s
.6654 .37459 m .70053 .38014 L .66295 .34538 L p .358 .621 .951 r
F P
0 g
s
.66295 .34538 m .63498 .34686 L .6654 .37459 L p .358 .621 .951 r
F P
0 g
s
.60679 .35415 m .63498 .34686 L .59141 .32717 L p .481 .723 .977 r
F P
0 g
s
.59141 .32717 m .57439 .33965 L .60679 .35415 L p .481 .723 .977 r
F P
0 g
s
.75285 .4396 m .78344 .46538 L .76234 .4125 L p .077 .337 .813 r
F P
0 g
s
.76234 .4125 m .73353 .3925 L .75285 .4396 L p .077 .337 .813 r
F P
0 g
s
.40049 .36 m .36838 .36188 L .34088 .39989 L p .779 .92 .932 r
F P
0 g
s
.30619 .41579 m .34088 .39989 L .36838 .36188 L p .803 .977 .902 r
F P
0 g
s
.81157 .59178 m .81518 .63104 L .82538 .57374 L p 0 0 .282 r
F P
0 g
s
.82538 .57374 m .82152 .53385 L .81157 .59178 L p 0 0 .282 r
F P
0 g
s
.53975 .84619 m .54261 .84459 L .47808 .84194 L p .124 0 0 r
F P
0 g
s
.54261 .84459 m .53975 .84619 L .59171 .83964 L p 0 0 0 r
F P
0 g
s
.59171 .83964 m .60574 .83663 L .54261 .84459 L p 0 0 0 r
F P
0 g
s
.43796 .33586 m .46098 .34604 L .4968 .33531 L p .629 .863 .986 r
F P
0 g
s
.46098 .34604 m .43796 .33586 L .40049 .36 L p .698 .876 .964 r
F P
0 g
s
.68267 .80496 m .66187 .81857 L .70561 .79169 L p 0 0 0 r
F P
0 g
s
.70561 .79169 m .73372 .77357 L .68267 .80496 L p 0 0 0 r
F P
0 g
s
.48657 .84401 m .47808 .84194 L .41774 .82884 L p .162 0 0 r
F P
0 g
s
.47808 .84194 m .48657 .84401 L .53975 .84619 L p .124 0 0 r
F P
0 g
s
.57439 .33965 m .59141 .32717 L .53971 .3182 L p .503 .775 .993 r
F P
0 g
s
.53971 .3182 m .5362 .33308 L .57439 .33965 L p .503 .775 .993 r
F P
0 g
s
.36838 .36188 m .40049 .36 L .43796 .33586 L p .689 .935 .966 r
F P
0 g
s
.27602 .43869 m .25268 .4685 L .24638 .52592 L p .945 .96 .695 r
F P
0 g
s
.23218 .56345 m .24638 .52592 L .25268 .4685 L p .905 .883 .456 r
F P
0 g
s
.60574 .83663 m .59171 .83964 L .63769 .82483 L p .276 .774 .743 r
F P
0 g
s
.63769 .82483 m .66187 .81857 L .60574 .83663 L p .276 .774 .743 r
F P
0 g
s
.48632 .32125 m .4968 .33531 L .5362 .33308 L p .557 .826 .996 r
F P
0 g
s
.4968 .33531 m .48632 .32125 L .43796 .33586 L p .629 .863 .986 r
F P
0 g
s
.5362 .33308 m .53971 .3182 L .48632 .32125 L p .557 .826 .996 r
F P
0 g
s
.78344 .46538 m .80703 .49715 L .7847 .44029 L p 0 .064 .628 r
F P
0 g
s
.7847 .44029 m .76234 .4125 L .78344 .46538 L p 0 .064 .628 r
F P
0 g
s
.75569 .7486 m .73372 .77357 L .76511 .73411 L p .593 .855 .507 r
F P
0 g
s
.76511 .73411 m .79116 .7041 L .75569 .7486 L p .593 .855 .507 r
F P
0 g
s
.70053 .38014 m .73353 .3925 L .6894 .35129 L p .132 .496 .906 r
F P
0 g
s
.6894 .35129 m .66295 .34538 L .70053 .38014 L p .132 .496 .906 r
F P
0 g
s
.22841 .60302 m .23566 .64248 L .26036 .69452 L p .906 .596 .106 r
F P
0 g
s
.27624 .72741 m .26036 .69452 L .23566 .64248 L p 0 0 .313 r
F P
0 g
s
.36838 .36188 m .33812 .37089 L .30619 .41579 L p .803 .977 .902 r
F P
0 g
s
.27602 .43869 m .30619 .41579 L .33812 .37089 L p .785 .996 .787 r
F P
0 g
s
.63498 .34686 m .66295 .34538 L .60837 .32053 L p .314 .67 .975 r
F P
0 g
s
.60837 .32053 m .59141 .32717 L .63498 .34686 L p .314 .67 .975 r
F P
0 g
s
.34245 .79052 m .36711 .80618 L .41774 .82884 L p .491 0 0 r
F P
0 g
s
.41774 .82884 m .437 .83325 L .48657 .84401 L p .162 0 0 r
F P
0 g
s
.437 .83325 m .41774 .82884 L .36711 .80618 L p 0 .456 .809 r
F P
0 g
s
.27624 .72741 m .3005 .75475 L .34245 .79052 L p .659 .141 0 r
F P
0 g
s
.36711 .80618 m .34245 .79052 L .3005 .75475 L p 0 .235 .702 r
F P
0 g
s
.81518 .63104 m .80826 .66917 L .81796 .61461 L p .7 .674 .129 r
F P
0 g
s
.81796 .61461 m .82538 .57374 L .81518 .63104 L p .7 .674 .129 r
F P
0 g
s
.25268 .4685 m .23832 .50432 L .23218 .56345 L p .905 .883 .456 r
F P
0 g
s
.22841 .60302 m .23218 .56345 L .23832 .50432 L p 0 0 0 r
F P
0 g
s
.41506 .33152 m .43796 .33586 L .48632 .32125 L p .551 .897 .979 r
F P
0 g
s
.43796 .33586 m .41506 .33152 L .36838 .36188 L p .689 .935 .966 r
F P
0 g
s
.66187 .81857 m .63769 .82483 L .67313 .80292 L p .56 .936 .867 r
F P
0 g
s
.67313 .80292 m .70561 .79169 L .66187 .81857 L p .56 .936 .867 r
F P
0 g
s
.33812 .37089 m .36838 .36188 L .41506 .33152 L p .619 .958 .891 r
F P
0 g
s
.5366 .84086 m .53975 .84619 L .48657 .84401 L p .248 .736 .923 r
F P
0 g
s
.53975 .84619 m .5366 .84086 L .57634 .83583 L p .35 .811 .93 r
F P
0 g
s
.57634 .83583 m .59171 .83964 L .53975 .84619 L p .35 .811 .93 r
F P
0 g
s
.80703 .49715 m .82152 .53385 L .79849 .47521 L p 0 0 .261 r
F P
0 g
s
.79849 .47521 m .7847 .44029 L .80703 .49715 L p 0 0 .261 r
F P
0 g
s
.49589 .83918 m .48657 .84401 L .437 .83325 L p .216 .685 .941 r
F P
0 g
s
.48657 .84401 m .49589 .83918 L .5366 .84086 L p .248 .736 .923 r
F P
0 g
s
.59141 .32717 m .60837 .32053 L .54322 .30918 L p .325 .737 .979 r
F P
0 g
s
.54322 .30918 m .53971 .3182 L .59141 .32717 L p .325 .737 .979 r
F P
0 g
s
.23566 .64248 m .25357 .67961 L .27624 .72741 L p 0 0 .313 r
F P
0 g
s
.3005 .75475 m .27624 .72741 L .25357 .67961 L p 0 .107 .659 r
F P
0 g
s
.73353 .3925 m .76234 .4125 L .71266 .36592 L p 0 .23 .714 r
F P
0 g
s
.71266 .36592 m .6894 .35129 L .73353 .3925 L p 0 .23 .714 r
F P
0 g
s
.73372 .77357 m .70561 .79169 L .73201 .75812 L p .734 .988 .795 r
F P
0 g
s
.73201 .75812 m .76511 .73411 L .73372 .77357 L p .734 .988 .795 r
F P
0 g
s
.33812 .37089 m .31161 .3881 L .27602 .43869 L p .785 .996 .787 r
F P
0 g
s
.25268 .4685 m .27602 .43869 L .31161 .3881 L p .63 .858 .487 r
F P
0 g
s
.59171 .83964 m .57634 .83583 L .61129 .8245 L p .497 .889 .954 r
F P
0 g
s
.61129 .8245 m .63769 .82483 L .59171 .83964 L p .497 .889 .954 r
F P
0 g
s
.47585 .31304 m .48632 .32125 L .53971 .3182 L p .411 .819 .978 r
F P
0 g
s
.48632 .32125 m .47585 .31304 L .41506 .33152 L p .551 .897 .979 r
F P
0 g
s
.80826 .66917 m .79116 .7041 L .79971 .65409 L p .889 .912 .509 r
F P
0 g
s
.79971 .65409 m .81796 .61461 L .80826 .66917 L p .889 .912 .509 r
F P
0 g
s
.53971 .3182 m .54322 .30918 L .47585 .31304 L p .411 .819 .978 r
F P
0 g
s
.3005 .75475 m .33143 .77565 L .36711 .80618 L p 0 .235 .702 r
F P
0 g
s
.39572 .81472 m .36711 .80618 L .33143 .77565 L p .096 .501 .903 r
F P
0 g
s
.36711 .80618 m .39572 .81472 L .437 .83325 L p 0 .456 .809 r
F P
0 g
s
.66295 .34538 m .6894 .35129 L .62451 .32165 L p 0 .5 .857 r
F P
0 g
s
.62451 .32165 m .60837 .32053 L .66295 .34538 L p 0 .5 .857 r
F P
0 g
s
.45807 .83093 m .437 .83325 L .39572 .81472 L p .251 .656 .964 r
F P
0 g
s
.437 .83325 m .45807 .83093 L .49589 .83918 L p .216 .685 .941 r
F P
0 g
s
.23832 .50432 m .23449 .54452 L .22841 .60302 L p 0 0 0 r
F P
0 g
s
.23566 .64248 m .22841 .60302 L .23449 .54452 L p 0 0 .348 r
F P
0 g
s
.82152 .53385 m .82538 .57374 L .80217 .51569 L p .928 .653 .173 r
F P
0 g
s
.80217 .51569 m .79849 .47521 L .82152 .53385 L p .928 .653 .173 r
F P
0 g
s
.41506 .33152 m .39333 .33477 L .33812 .37089 L p .619 .958 .891 r
F P
0 g
s
.31161 .3881 m .33812 .37089 L .39333 .33477 L p .391 .803 .597 r
F P
0 g
s
.39333 .33477 m .41506 .33152 L .47585 .31304 L p .333 .816 .813 r
F P
0 g
s
.63769 .82483 m .61129 .8245 L .63793 .80784 L p .638 .934 .968 r
F P
0 g
s
.63793 .80784 m .67313 .80292 L .63769 .82483 L p .638 .934 .968 r
F P
0 g
s
.25357 .67961 m .28077 .7125 L .3005 .75475 L p 0 .107 .659 r
F P
0 g
s
.33143 .77565 m .3005 .75475 L .28077 .7125 L p .069 .371 .838 r
F P
0 g
s
.31161 .3881 m .29097 .41396 L .25268 .4685 L p .63 .858 .487 r
F P
0 g
s
.23832 .50432 m .25268 .4685 L .29097 .41396 L p 0 0 0 r
F P
0 g
s
.70561 .79169 m .67313 .80292 L .69404 .77576 L p .755 .979 .916 r
F P
0 g
s
.69404 .77576 m .73201 .75812 L .70561 .79169 L p .755 .979 .916 r
F P
0 g
s
.76234 .4125 m .7847 .44029 L .7308 .38995 L p .676 .169 0 r
F P
0 g
s
.7308 .38995 m .71266 .36592 L .76234 .4125 L p .676 .169 0 r
F P
0 g
s
.79116 .7041 m .76511 .73411 L .77204 .69004 L p .918 .978 .734 r
F P
0 g
s
.77204 .69004 m .79971 .65409 L .79116 .7041 L p .918 .978 .734 r
F P
0 g
s
.53328 .82971 m .5366 .84086 L .49589 .83918 L p .463 .806 .999 r
F P
0 g
s
.5366 .84086 m .53328 .82971 L .56015 .82628 L p .517 .844 .998 r
F P
0 g
s
.56015 .82628 m .57634 .83583 L .5366 .84086 L p .517 .844 .998 r
F P
0 g
s
.50572 .82857 m .49589 .83918 L .45807 .83093 L p .436 .767 .997 r
F P
0 g
s
.49589 .83918 m .50572 .82857 L .53328 .82971 L p .463 .806 .999 r
F P
0 g
s
.60837 .32053 m .62451 .32165 L .54657 .30805 L p 0 .536 .773 r
F P
0 g
s
.54657 .30805 m .54322 .30918 L .60837 .32053 L p 0 .536 .773 r
F P
0 g
s
.23449 .54452 m .24184 .58682 L .23566 .64248 L p 0 0 .348 r
F P
0 g
s
.25357 .67961 m .23566 .64248 L .24184 .58682 L p 0 .085 .613 r
F P
0 g
s
.33143 .77565 m .36706 .78992 L .39572 .81472 L p .096 .501 .903 r
F P
0 g
s
.42684 .81679 m .39572 .81472 L .36706 .78992 L p .326 .638 .964 r
F P
0 g
s
.39572 .81472 m .42684 .81679 L .45807 .83093 L p .251 .656 .964 r
F P
0 g
s
.57634 .83583 m .56015 .82628 L .58364 .81859 L p .587 .874 .994 r
F P
0 g
s
.58364 .81859 m .61129 .8245 L .57634 .83583 L p .587 .874 .994 r
F P
0 g
s
.46588 .31268 m .47585 .31304 L .54322 .30918 L p .085 .644 .75 r
F P
0 g
s
.47585 .31304 m .46588 .31268 L .39333 .33477 L p .333 .816 .813 r
F P
0 g
s
.6894 .35129 m .71266 .36592 L .63876 .33224 L p .46 0 0 r
F P
0 g
s
.63876 .33224 m .62451 .32165 L .6894 .35129 L p .46 0 0 r
F P
0 g
s
.48021 .82295 m .45807 .83093 L .42684 .81679 L p .439 .733 .989 r
F P
0 g
s
.45807 .83093 m .48021 .82295 L .50572 .82857 L p .436 .767 .997 r
F P
0 g
s
.54322 .30918 m .54657 .30805 L .46588 .31268 L p .085 .644 .75 r
F P
0 g
s
.82538 .57374 m .81796 .61461 L .79511 .55943 L p 1 .811 .479 r
F P
0 g
s
.79511 .55943 m .80217 .51569 L .82538 .57374 L p 1 .811 .479 r
F P
0 g
s
.28077 .7125 m .31523 .73983 L .33143 .77565 L p .069 .371 .838 r
F P
0 g
s
.36706 .78992 m .33143 .77565 L .31523 .73983 L p .276 .53 .912 r
F P
0 g
s
.76511 .73411 m .73201 .75812 L .73712 .72091 L p .881 .965 .845 r
F P
0 g
s
.73712 .72091 m .77204 .69004 L .76511 .73411 L p .881 .965 .845 r
F P
0 g
s
.61129 .8245 m .58364 .81859 L .60132 .80735 L p .654 .885 .982 r
F P
0 g
s
.60132 .80735 m .63793 .80784 L .61129 .8245 L p .654 .885 .982 r
F P
0 g
s
.67313 .80292 m .63793 .80784 L .65326 .78735 L p .734 .928 .955 r
F P
0 g
s
.65326 .78735 m .69404 .77576 L .67313 .80292 L p .734 .928 .955 r
F P
0 g
s
.39333 .33477 m .37418 .34717 L .31161 .3881 L p .391 .803 .597 r
F P
0 g
s
.29097 .41396 m .31161 .3881 L .37418 .34717 L p 0 0 0 r
F P
0 g
s
.29097 .41396 m .27822 .44799 L .23832 .50432 L p 0 0 0 r
F P
0 g
s
.23449 .54452 m .23832 .50432 L .27822 .44799 L p 0 0 .326 r
F P
0 g
s
.7847 .44029 m .79849 .47521 L .74203 .42313 L p .899 .481 .139 r
F P
0 g
s
.74203 .42313 m .7308 .38995 L .7847 .44029 L p .899 .481 .139 r
F P
0 g
s
.37418 .34717 m .39333 .33477 L .46588 .31268 L p .044 0 0 r
F P
0 g
s
.24184 .58682 m .25993 .62869 L .25357 .67961 L p 0 .085 .613 r
F P
0 g
s
.28077 .7125 m .25357 .67961 L .25993 .62869 L p .172 .303 .757 r
F P
0 g
s
.36706 .78992 m .4055 .798 L .42684 .81679 L p .326 .638 .964 r
F P
0 g
s
.45933 .81338 m .42684 .81679 L .4055 .798 L p .464 .706 .973 r
F P
0 g
s
.42684 .81679 m .45933 .81338 L .48021 .82295 L p .439 .733 .989 r
F P
0 g
s
.52985 .81377 m .53328 .82971 L .50572 .82857 L p .564 .802 .988 r
F P
0 g
s
.53328 .82971 m .52985 .81377 L .54344 .81202 L p .589 .82 .987 r
F P
0 g
s
.54344 .81202 m .56015 .82628 L .53328 .82971 L p .589 .82 .987 r
F P
0 g
s
.51588 .81319 m .50572 .82857 L .48021 .82295 L p .549 .782 .985 r
F P
0 g
s
.50572 .82857 m .51588 .81319 L .52985 .81377 L p .564 .802 .988 r
F P
0 g
s
.56015 .82628 m .54344 .81202 L .55526 .80809 L p .62 .832 .982 r
F P
0 g
s
.55526 .80809 m .58364 .81859 L .56015 .82628 L p .62 .832 .982 r
F P
0 g
s
.81796 .61461 m .79971 .65409 L .77775 .60372 L p .979 .863 .654 r
F P
0 g
s
.77775 .60372 m .79511 .55943 L .81796 .61461 L p .979 .863 .654 r
F P
0 g
s
.31523 .73983 m .35458 .76106 L .36706 .78992 L p .276 .53 .912 r
F P
0 g
s
.4055 .798 m .36706 .78992 L .35458 .76106 L p .41 .625 .941 r
F P
0 g
s
.73201 .75812 m .69404 .77576 L .69742 .74592 L p .828 .928 .898 r
F P
0 g
s
.69742 .74592 m .73712 .72091 L .73201 .75812 L p .828 .928 .898 r
F P
0 g
s
.62451 .32165 m .63876 .33224 L .54953 .31674 L p .456 0 0 r
F P
0 g
s
.54953 .31674 m .54657 .30805 L .62451 .32165 L p .456 0 0 r
F P
0 g
s
.503 .81032 m .48021 .82295 L .45933 .81338 L p .544 .761 .977 r
F P
0 g
s
.48021 .82295 m .503 .81032 L .51588 .81319 L p .549 .782 .985 r
F P
0 g
s
.63793 .80784 m .60132 .80735 L .61122 .79364 L p .703 .876 .962 r
F P
0 g
s
.61122 .79364 m .65326 .78735 L .63793 .80784 L p .703 .876 .962 r
F P
0 g
s
.71266 .36592 m .7308 .38995 L .64992 .3534 L p .746 .239 .008 r
F P
0 g
s
.64992 .3534 m .63876 .33224 L .71266 .36592 L p .746 .239 .008 r
F P
0 g
s
.25993 .62869 m .28728 .66777 L .28077 .7125 L p .172 .303 .757 r
F P
0 g
s
.31523 .73983 m .28077 .7125 L .28728 .66777 L p .314 .447 .835 r
F P
0 g
s
.58364 .81859 m .55526 .80809 L .56404 .8024 L p .65 .836 .972 r
F P
0 g
s
.56404 .8024 m .60132 .80735 L .58364 .81859 L p .65 .836 .972 r
F P
0 g
s
.27822 .44799 m .27481 .48872 L .23449 .54452 L p 0 0 .326 r
F P
0 g
s
.24184 .58682 m .23449 .54452 L .27481 .48872 L p .19 .118 .54 r
F P
0 g
s
.45707 .32201 m .46588 .31268 L .54657 .30805 L p .317 0 0 r
F P
0 g
s
.46588 .31268 m .45707 .32201 L .37418 .34717 L p .044 0 0 r
F P
0 g
s
.54657 .30805 m .54953 .31674 L .45707 .32201 L p .317 0 0 r
F P
0 g
s
.37418 .34717 m .35921 .36962 L .29097 .41396 L p 0 0 0 r
F P
0 g
s
.27822 .44799 m .29097 .41396 L .35921 .36962 L p .215 0 .246 r
F P
0 g
s
.79849 .47521 m .80217 .51569 L .74504 .46409 L p .948 .635 .41 r
F P
0 g
s
.74504 .46409 m .74203 .42313 L .79849 .47521 L p .948 .635 .41 r
F P
0 g
s
.4055 .798 m .44531 .80075 L .45933 .81338 L p .464 .706 .973 r
F P
0 g
s
.49255 .80545 m .45933 .81338 L .44531 .80075 L p .551 .743 .966 r
F P
0 g
s
.45933 .81338 m .49255 .80545 L .503 .81032 L p .544 .761 .977 r
F P
0 g
s
.35458 .76106 m .39665 .77633 L .4055 .798 L p .41 .625 .941 r
F P
0 g
s
.44531 .80075 m .4055 .798 L .39665 .77633 L p .501 .687 .95 r
F P
0 g
s
.69404 .77576 m .65326 .78735 L .65518 .76505 L p .777 .889 .925 r
F P
0 g
s
.65518 .76505 m .69742 .74592 L .69404 .77576 L p .777 .889 .925 r
F P
0 g
s
.79971 .65409 m .77204 .69004 L .75158 .64593 L p .932 .873 .755 r
F P
0 g
s
.75158 .64593 m .77775 .60372 L .79971 .65409 L p .932 .873 .755 r
F P
0 g
s
.60132 .80735 m .56404 .8024 L .56882 .79551 L p .674 .831 .959 r
F P
0 g
s
.56882 .79551 m .61122 .79364 L .60132 .80735 L p .674 .831 .959 r
F P
0 g
s
.28728 .66777 m .32166 .70222 L .31523 .73983 L p .314 .447 .835 r
F P
0 g
s
.35458 .76106 m .31523 .73983 L .32166 .70222 L p .413 .547 .88 r
F P
0 g
s
.35921 .36962 m .37418 .34717 L .45707 .32201 L p .331 0 .087 r
F P
0 g
s
.52632 .79362 m .52985 .81377 L .51588 .81319 L closepath p .617 .784 .961 r
F P
0 g
s
.52632 .79362 m .54344 .81202 L .52985 .81377 L closepath p .624 .789 .961 r
F P
0 g
s
.52632 .79362 m .51588 .81319 L .503 .81032 L closepath p .612 .778 .96 r
F P
0 g
s
.52632 .79362 m .55526 .80809 L .54344 .81202 L closepath p .632 .792 .959 r
F P
0 g
s
.52632 .79362 m .503 .81032 L .49255 .80545 L closepath p .61 .771 .957 r
F P
0 g
s
.65326 .78735 m .61122 .79364 L .61208 .77886 L p .731 .852 .938 r
F P
0 g
s
.61208 .77886 m .65518 .76505 L .65326 .78735 L p .731 .852 .938 r
F P
0 g
s
.27481 .48872 m .28135 .53383 L .24184 .58682 L p .19 .118 .54 r
F P
0 g
s
.25993 .62869 m .24184 .58682 L .28135 .53383 L p .316 .286 .666 r
F P
0 g
s
.39665 .77633 m .43981 .78632 L .44531 .80075 L p .501 .687 .95 r
F P
0 g
s
.48567 .79908 m .44531 .80075 L .43981 .78632 L p .564 .729 .952 r
F P
0 g
s
.44531 .80075 m .48567 .79908 L .49255 .80545 L p .551 .743 .966 r
F P
0 g
s
.52632 .79362 m .56404 .8024 L .55526 .80809 L closepath p .64 .793 .956 r
F P
0 g
s
.77204 .69004 m .73712 .72091 L .7188 .68397 L p .882 .866 .819 r
F P
0 g
s
.7188 .68397 m .75158 .64593 L .77204 .69004 L p .882 .866 .819 r
F P
0 g
s
.32166 .70222 m .36058 .73103 L .35458 .76106 L p .413 .547 .88 r
F P
0 g
s
.39665 .77633 m .35458 .76106 L .36058 .73103 L p .486 .62 .908 r
F P
0 g
s
.52632 .79362 m .49255 .80545 L .48567 .79908 L closepath p .61 .765 .954 r
F P
0 g
s
.7308 .38995 m .74203 .42313 L .65686 .38522 L p .835 .445 .31 r
F P
0 g
s
.65686 .38522 m .64992 .3534 L .7308 .38995 L p .835 .445 .31 r
F P
0 g
s
.63876 .33224 m .64992 .3534 L .55186 .33654 L p .665 .198 .133 r
F P
0 g
s
.55186 .33654 m .54953 .31674 L .63876 .33224 L p .665 .198 .133 r
F P
0 g
s
.52632 .79362 m .56882 .79551 L .56404 .8024 L closepath p .647 .791 .951 r
F P
0 g
s
.80217 .51569 m .79511 .55943 L .73927 .51046 L p .936 .708 .568 r
F P
0 g
s
.73927 .51046 m .74504 .46409 L .80217 .51569 L p .936 .708 .568 r
F P
0 g
s
.61122 .79364 m .56882 .79551 L .56903 .78816 L p .69 .819 .944 r
F P
0 g
s
.56903 .78816 m .61208 .77886 L .61122 .79364 L p .69 .819 .944 r
F P
0 g
s
.35921 .36962 m .34992 .40205 L .27822 .44799 L p .215 0 .246 r
F P
0 g
s
.27481 .48872 m .27822 .44799 L .34992 .40205 L p .358 .15 .455 r
F P
0 g
s
.43981 .78632 m .48312 .79186 L .48567 .79908 L p .564 .729 .952 r
F P
0 g
s
.52632 .79362 m .48567 .79908 L .48312 .79186 L closepath p .613 .76 .949 r
F P
0 g
s
.36058 .73103 m .4018 .754 L .39665 .77633 L p .486 .62 .908 r
F P
0 g
s
.43981 .78632 m .39665 .77633 L .4018 .754 L p .54 .675 .926 r
F P
0 g
s
.73712 .72091 m .69742 .74592 L .68184 .71655 L p .832 .853 .862 r
F P
0 g
s
.68184 .71655 m .7188 .68397 L .73712 .72091 L p .832 .853 .862 r
F P
0 g
s
.28135 .53383 m .2974 .58042 L .25993 .62869 L p .316 .286 .666 r
F P
0 g
s
.28728 .66777 m .25993 .62869 L .2974 .58042 L p .401 .403 .747 r
F P
0 g
s
.52632 .79362 m .56903 .78816 L .56882 .79551 L closepath p .653 .788 .947 r
F P
0 g
s
.45015 .34228 m .45707 .32201 L .54953 .31674 L p .534 .096 .153 r
F P
0 g
s
.45707 .32201 m .45015 .34228 L .35921 .36962 L p .331 0 .087 r
F P
0 g
s
.4018 .754 m .44366 .7716 L .43981 .78632 L p .54 .675 .926 r
F P
0 g
s
.48312 .79186 m .43981 .78632 L .44366 .7716 L p .583 .719 .937 r
F P
0 g
s
.44366 .7716 m .48525 .78458 L .48312 .79186 L p .583 .719 .937 r
F P
0 g
s
.52632 .79362 m .48312 .79186 L .48525 .78458 L closepath p .618 .756 .944 r
F P
0 g
s
.54953 .31674 m .55186 .33654 L .45015 .34228 L p .534 .096 .153 r
F P
0 g
s
.52632 .79362 m .5559 .77523 L .56458 .78114 L closepath p .657 .777 .938 r
F P
0 g
s
.52632 .79362 m .5439 .77111 L .5559 .77523 L closepath p .655 .771 .934 r
F P
0 g
s
.52632 .79362 m .52992 .76926 L .5439 .77111 L closepath p .651 .765 .933 r
F P
0 g
s
.52632 .79362 m .51553 .76988 L .52992 .76926 L closepath p .646 .76 .932 r
F P
0 g
s
.52632 .79362 m .50237 .77292 L .51553 .76988 L closepath p .639 .756 .933 r
F P
0 g
s
.52632 .79362 m .49189 .77802 L .50237 .77292 L closepath p .632 .754 .936 r
F P
0 g
s
.52632 .79362 m .48525 .78458 L .49189 .77802 L closepath p .625 .754 .94 r
F P
0 g
s
.52632 .79362 m .56458 .78114 L .56903 .78816 L closepath p .656 .783 .942 r
F P
0 g
s
.69742 .74592 m .65518 .76505 L .64289 .74332 L p .784 .837 .892 r
F P
0 g
s
.64289 .74332 m .68184 .71655 L .69742 .74592 L p .784 .837 .892 r
F P
0 g
s
.61208 .77886 m .56903 .78816 L .56458 .78114 L p .697 .802 .93 r
F P
0 g
s
.65518 .76505 m .61208 .77886 L .60351 .76461 L p .74 .82 .914 r
F P
0 g
s
.60351 .76461 m .64289 .74332 L .65518 .76505 L p .74 .82 .914 r
F P
0 g
s
.34992 .40205 m .35921 .36962 L .45015 .34228 L p .472 .155 .347 r
F P
0 g
s
.56458 .78114 m .60351 .76461 L .61208 .77886 L p .697 .802 .93 r
F P
0 g
s
.79511 .55943 m .77775 .60372 L .72515 .5592 L p .908 .745 .667 r
F P
0 g
s
.72515 .5592 m .73927 .51046 L .79511 .55943 L p .908 .745 .667 r
F P
0 g
s
.2974 .58042 m .32152 .62562 L .28728 .66777 L p .401 .403 .747 r
F P
0 g
s
.32166 .70222 m .28728 .66777 L .32152 .62562 L p .463 .492 .803 r
F P
0 g
s
.45671 .75822 m .49189 .77802 L .48525 .78458 L p .604 .715 .923 r
F P
0 g
s
.48525 .78458 m .44366 .7716 L .45671 .75822 L p .604 .715 .923 r
F P
0 g
s
.60351 .76461 m .56458 .78114 L .5559 .77523 L p .697 .783 .917 r
F P
0 g
s
.42098 .73351 m .45671 .75822 L .44366 .7716 L p .579 .672 .903 r
F P
0 g
s
.44366 .7716 m .4018 .754 L .42098 .73351 L p .579 .672 .903 r
F P
0 g
s
.34992 .40205 m .34744 .44319 L .27481 .48872 L p .358 .15 .455 r
F P
0 g
s
.28135 .53383 m .27481 .48872 L .34744 .44319 L p .441 .292 .581 r
F P
0 g
s
.74203 .42313 m .74504 .46409 L .65871 .4265 L p .851 .551 .481 r
F P
0 g
s
.65871 .4265 m .65686 .38522 L .74203 .42313 L p .851 .551 .481 r
F P
0 g
s
.32152 .62562 m .35165 .66706 L .32166 .70222 L p .463 .492 .803 r
F P
0 g
s
.36058 .73103 m .32166 .70222 L .35165 .66706 L p .511 .563 .845 r
F P
0 g
s
.47772 .74775 m .50237 .77292 L .49189 .77802 L p .625 .717 .912 r
F P
0 g
s
.49189 .77802 m .45671 .75822 L .47772 .74775 L p .625 .717 .912 r
F P
0 g
s
.38548 .70321 m .42098 .73351 L .4018 .754 L p .548 .622 .878 r
F P
0 g
s
.4018 .754 m .36058 .73103 L .38548 .70321 L p .548 .622 .878 r
F P
0 g
s
.35165 .66706 m .38548 .70321 L .36058 .73103 L p .511 .563 .845 r
F P
0 g
s
.5559 .77523 m .58624 .75251 L .60351 .76461 L p .697 .783 .917 r
F P
0 g
s
.58624 .75251 m .5559 .77523 L .5439 .77111 L p .69 .764 .908 r
F P
0 g
s
.64992 .3534 m .65686 .38522 L .5533 .3677 L p .734 .374 .368 r
F P
0 g
s
.5533 .3677 m .55186 .33654 L .64992 .3534 L p .734 .374 .368 r
F P
0 g
s
.77775 .60372 m .75158 .64593 L .70395 .60718 L p .876 .765 .736 r
F P
0 g
s
.70395 .60718 m .72515 .5592 L .77775 .60372 L p .876 .765 .736 r
F P
0 g
s
.50439 .74146 m .51553 .76988 L .50237 .77292 L p .645 .723 .905 r
F P
0 g
s
.50237 .77292 m .47772 .74775 L .50439 .74146 L p .645 .723 .905 r
F P
0 g
s
.64289 .74332 m .60351 .76461 L .58624 .75251 L p .735 .786 .894 r
F P
0 g
s
.5439 .77111 m .56204 .744 L .58624 .75251 L p .69 .764 .908 r
F P
0 g
s
.56204 .744 m .5439 .77111 L .52992 .76926 L p .678 .747 .903 r
F P
0 g
s
.53365 .74016 m .52992 .76926 L .51553 .76988 L p .663 .733 .902 r
F P
0 g
s
.51553 .76988 m .50439 .74146 L .53365 .74016 L p .663 .733 .902 r
F P
0 g
s
.52992 .76926 m .53365 .74016 L .56204 .744 L p .678 .747 .903 r
F P
0 g
s
.45251 .71734 m .47772 .74775 L .45671 .75822 L p .614 .676 .886 r
F P
0 g
s
.45671 .75822 m .42098 .73351 L .45251 .71734 L p .614 .676 .886 r
F P
0 g
s
.68184 .71655 m .64289 .74332 L .61718 .7247 L p .772 .786 .865 r
F P
0 g
s
.58624 .75251 m .61718 .7247 L .64289 .74332 L p .735 .786 .894 r
F P
0 g
s
.44585 .37366 m .45015 .34228 L .55186 .33654 L p .622 .284 .377 r
F P
0 g
s
.45015 .34228 m .44585 .37366 L .34992 .40205 L p .472 .155 .347 r
F P
0 g
s
.75158 .64593 m .7188 .68397 L .67757 .65175 L p .842 .777 .789 r
F P
0 g
s
.67757 .65175 m .70395 .60718 L .75158 .64593 L p .842 .777 .789 r
F P
0 g
s
.34744 .44319 m .35221 .49064 L .28135 .53383 L p .441 .292 .581 r
F P
0 g
s
.2974 .58042 m .28135 .53383 L .35221 .49064 L p .495 .391 .665 r
F P
0 g
s
.34744 .44319 m .34992 .40205 L .44585 .37366 L p .541 .298 .496 r
F P
0 g
s
.7188 .68397 m .68184 .71655 L .64805 .69117 L p .807 .783 .831 r
F P
0 g
s
.61718 .7247 m .64805 .69117 L .68184 .71655 L p .772 .786 .865 r
F P
0 g
s
.64805 .69117 m .67757 .65175 L .7188 .68397 L p .807 .783 .831 r
F P
0 g
s
.55186 .33654 m .5533 .3677 L .44585 .37366 L p .622 .284 .377 r
F P
0 g
s
.61718 .7247 m .58624 .75251 L .56204 .744 L p .721 .754 .879 r
F P
0 g
s
.74504 .46409 m .73927 .51046 L .65515 .47483 L p .844 .613 .588 r
F P
0 g
s
.65515 .47483 m .65871 .4265 L .74504 .46409 L p .844 .613 .588 r
F P
0 g
s
.42727 .68107 m .45251 .71734 L .42098 .73351 L p .601 .632 .854 r
F P
0 g
s
.42098 .73351 m .38548 .70321 L .42727 .68107 L p .601 .632 .854 r
F P
0 g
s
.49295 .70758 m .50439 .74146 L .47772 .74775 L p .647 .687 .874 r
F P
0 g
s
.47772 .74775 m .45251 .71734 L .49295 .70758 L p .647 .687 .874 r
F P
0 g
s
.35221 .49064 m .36388 .54123 L .2974 .58042 L p .495 .391 .665 r
F P
0 g
s
.32152 .62562 m .2974 .58042 L .36388 .54123 L p .532 .466 .728 r
F P
0 g
s
.56204 .744 m .58065 .71153 L .61718 .7247 L p .721 .754 .879 r
F P
0 g
s
.58065 .71153 m .56204 .744 L .53365 .74016 L p .7 .727 .871 r
F P
0 g
s
.53749 .70555 m .53365 .74016 L .50439 .74146 L p .675 .704 .869 r
F P
0 g
s
.50439 .74146 m .49295 .70758 L .53749 .70555 L p .675 .704 .869 r
F P
0 g
s
.40306 .63887 m .42727 .68107 L .38548 .70321 L p .583 .584 .819 r
F P
0 g
s
.38548 .70321 m .35165 .66706 L .40306 .63887 L p .583 .584 .819 r
F P
0 g
s
.65686 .38522 m .65871 .4265 L .55369 .40913 L p .756 .473 .504 r
F P
0 g
s
.55369 .40913 m .5533 .3677 L .65686 .38522 L p .756 .473 .504 r
F P
0 g
s
.53365 .74016 m .53749 .70555 L .58065 .71153 L p .7 .727 .871 r
F P
0 g
s
.64805 .69117 m .61718 .7247 L .58065 .71153 L p .748 .742 .846 r
F P
0 g
s
.36388 .54123 m .38136 .5916 L .32152 .62562 L p .532 .466 .728 r
F P
0 g
s
.35165 .66706 m .32152 .62562 L .38136 .5916 L p .561 .529 .777 r
F P
0 g
s
.38136 .5916 m .40306 .63887 L .35165 .66706 L p .561 .529 .777 r
F P
0 g
s
.73927 .51046 m .72515 .5592 L .64644 .52691 L p .831 .654 .663 r
F P
0 g
s
.64644 .52691 m .65515 .47483 L .73927 .51046 L p .831 .654 .663 r
F P
0 g
s
.44585 .37366 m .4447 .41504 L .34744 .44319 L p .541 .298 .496 r
F P
0 g
s
.35221 .49064 m .34744 .44319 L .4447 .41504 L p .58 .392 .592 r
F P
0 g
s
.48144 .66763 m .49295 .70758 L .45251 .71734 L p .645 .65 .84 r
F P
0 g
s
.45251 .71734 m .42727 .68107 L .48144 .66763 L p .645 .65 .84 r
F P
0 g
s
.4447 .41504 m .44585 .37366 L .5533 .3677 L p .659 .394 .508 r
F P
0 g
s
.67757 .65175 m .64805 .69117 L .59932 .67308 L p .773 .726 .809 r
F P
0 g
s
.58065 .71153 m .59932 .67308 L .64805 .69117 L p .748 .742 .846 r
F P
0 g
s
.5533 .3677 m .55369 .40913 L .4447 .41504 L p .659 .394 .508 r
F P
0 g
s
.59932 .67308 m .58065 .71153 L .53749 .70555 L p .718 .704 .836 r
F P
0 g
s
.72515 .5592 m .70395 .60718 L .63342 .57921 L p .814 .683 .72 r
F P
0 g
s
.63342 .57921 m .64644 .52691 L .72515 .5592 L p .814 .683 .72 r
F P
0 g
s
.70395 .60718 m .67757 .65175 L .61728 .62864 L p .794 .707 .768 r
F P
0 g
s
.59932 .67308 m .61728 .62864 L .67757 .65175 L p .773 .726 .809 r
F P
0 g
s
.54135 .66483 m .53749 .70555 L .49295 .70758 L p .684 .673 .834 r
F P
0 g
s
.49295 .70758 m .48144 .66763 L .54135 .66483 L p .684 .673 .834 r
F P
0 g
s
.61728 .62864 m .63342 .57921 L .70395 .60718 L p .794 .707 .768 r
F P
0 g
s
.53749 .70555 m .54135 .66483 L .59932 .67308 L p .718 .704 .836 r
F P
0 g
s
.47035 .62166 m .48144 .66763 L .42727 .68107 L p .641 .609 .802 r
F P
0 g
s
.42727 .68107 m .40306 .63887 L .47035 .62166 L p .641 .609 .802 r
F P
0 g
s
.65871 .4265 m .65515 .47483 L .55295 .45837 L p .761 .537 .593 r
F P
0 g
s
.55295 .45837 m .55369 .40913 L .65871 .4265 L p .761 .537 .593 r
F P
0 g
s
.4447 .41504 m .44691 .46398 L .35221 .49064 L p .58 .392 .592 r
F P
0 g
s
.36388 .54123 m .35221 .49064 L .44691 .46398 L p .605 .462 .66 r
F P
0 g
s
.61728 .62864 m .59932 .67308 L .54135 .66483 L p .733 .679 .798 r
F P
0 g
s
.46037 .57072 m .47035 .62166 L .40306 .63887 L p .633 .566 .761 r
F P
0 g
s
.40306 .63887 m .38136 .5916 L .46037 .57072 L p .633 .566 .761 r
F P
0 g
s
.44691 .46398 m .4447 .41504 L .55369 .40913 L p .678 .468 .594 r
F P
0 g
s
.44691 .46398 m .45231 .51709 L .36388 .54123 L p .605 .462 .66 r
F P
0 g
s
.38136 .5916 m .36388 .54123 L .45231 .51709 L p .621 .517 .715 r
F P
0 g
s
.45231 .51709 m .46037 .57072 L .38136 .5916 L p .621 .517 .715 r
F P
0 g
s
.54507 .61806 m .54135 .66483 L .48144 .66763 L p .689 .641 .796 r
F P
0 g
s
.48144 .66763 m .47035 .62166 L .54507 .61806 L p .689 .641 .796 r
F P
0 g
s
.55369 .40913 m .55295 .45837 L .44691 .46398 L p .678 .468 .594 r
F P
0 g
s
.65515 .47483 m .64644 .52691 L .55113 .51202 L p .759 .583 .659 r
F P
0 g
s
.55113 .51202 m .55295 .45837 L .65515 .47483 L p .759 .583 .659 r
F P
0 g
s
.54135 .66483 m .54507 .61806 L .61728 .62864 L p .733 .679 .798 r
F P
0 g
s
.63342 .57921 m .61728 .62864 L .54507 .61806 L p .744 .651 .757 r
F P
0 g
s
.64644 .52691 m .63342 .57921 L .54842 .56635 L p .753 .62 .711 r
F P
0 g
s
.54842 .56635 m .55113 .51202 L .64644 .52691 L p .753 .62 .711 r
F P
0 g
s
.54507 .61806 m .54842 .56635 L .63342 .57921 L p .744 .651 .757 r
F P
0 g
s
.45231 .51709 m .44691 .46398 L .55295 .45837 L p .687 .522 .658 r
F P
0 g
s
.54842 .56635 m .54507 .61806 L .47035 .62166 L p .692 .605 .755 r
F P
0 g
s
.47035 .62166 m .46037 .57072 L .54842 .56635 L p .692 .605 .755 r
F P
0 g
s
.55295 .45837 m .55113 .51202 L .45231 .51709 L p .687 .522 .658 r
F P
0 g
s
.55113 .51202 m .54842 .56635 L .46037 .57072 L p .691 .567 .71 r
F P
0 g
s
.46037 .57072 m .45231 .51709 L .55113 .51202 L p .691 .567 .71 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
KOooool@o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0GOoo
ool?o`0000coD@0000Co0000og@00?md003oM0001_l0000Sooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Iooooo`?o000000?o2`00o`000?mA00004_mA000;o`0000GoM0001ol0000Looooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1Eooooo`?o00000ol;00000ol0003oD@00oe400003oe4000oo00001on862L0
1?l0003oZS8RojXb8_nZ<R85o`0000OoM0001_l0000Fooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1@
ooooo`Co00000ol;0009o`0001KoR1PW00?o0000ojXb8_nZ<R801_nZ<R86o`0000OoM0001?l0000B
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09oooool002Wooooo0_l0000Joooo
o`03o`000?oooooooooo04cooooo0ol00004o`/000?o00000_mD01H00ol0003oR1PWohPH9`0JohPH
9`03o`000?nZ<R;oZS8R00coZS8R1_l00005og@000;o00004Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0B?ooool3o`0000Co2`000ol00004oe@05P03o`000?n862OoR1PW01coR1PW00?o0000ojXb8_nZ
<R804OnZ<R85o`000003og@00?l0003o000000;o00003_ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
A?ooool3o`0000Co2`000ol00007oe@05P03o`000?n862OoR1PW01coR1PW00?o0000ojXb8_nZ<R80
5_nZ<R84o`000003ogD00?l0003o000000cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Uooooo`00:Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo0ol0
0003o`/000Co00002_mD01H00ol0003oR1PWohPH9`0LohPH9`03o`000?nZ<R;oZS8R01SoZS8R00Go
0000okhm0_l0003o0000ogD00002o`0000[ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03kooooo00Co
0000o`/00?l;003o2`000ol0000=oe@05P03o`000?n862OoR1PW00goR1PW5?l0000HojXb8P03o`00
0?nn?@;o_Sd200;o000000?oM@00o`000?l000002?ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02Cooooo000Xooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>ooo
ool2o`000004o`/00?l0003o0000o`0000koE00F4_l0000@oim8H004o`000?nkGeko^emNok]OGPKo
00004_nZ<R800ol0003o_Sd2okhm0P02okhm0P;o000000?oM@00o`000?l000001_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0003ooooo
ooooo`0iooooo`Co00003_mD01H3o`0000;oN2MH00?o0000oim8H?nOB6007OnOB6000ol0003o^emN
ok]OGP07ok]OGPOo00003?nZ<R800ol0003o_Sd2okhm0P03okhm0P;o000000CoM@00o`000?l0003o
00000oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0=_ooool3o`0000koE00F0ol00005ogPWF003o`00
0?nOB63oWdQP01goWdQP00?o0000ok]OG_nkGeh03_nkGeh6o`0000OoZS8R00?o0000okhm0_nn?@80
1?nn?@83o`000005ogD00?l0003o0000ooooool00000>oooool00ol0003oooooooooo`0Rooooo`00
:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03?ooooo1?l0000<oe@05P?o0000
2?mh9eP00ol0003oWdQPoim8H00Moim8H003o`000?nkGeko^emN01Co^emN1_l000000onZ<R;o0000
okhm0P08okhm0P;o000000?oM@00o`000?l00000??ooool00ol0003oooooooooo`0Qooooo`00:?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo1?l0000:oe@05P?o00002omh
9eP00ol0003oWdQPoim8H00Moim8H003o`000?nkGeko^emN01[o^emN1?l00009okhm0PCo0000>ooo
ool00ol0003oooooooooo`0Qooooo`009oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo02kooooo1_l00007oe@05P?o00003_mh9eP00ol0003oWdQPoim8H00Moim8H003o`000?nkGeko
^emN01co^emN00Co0000omEaCol0003o00002Onn?@84o`0003[ooooo00?o0000ooooooooool08?oo
ool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0/ooooo`Ko00001OmD01H3
o`00013oN2MH00?o0000oim8H?nOB6007_nOB6000ol0003o^emNok]OGP0Lok]OGP04o`000?oELDoo
eG5?omEaC`?o00001_nn?@800ol0003o_Sd2o`000002o`0003Wooooo00?o0000ooooooooool08?oo
ool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Yooooo`Oo00000omD01H3
o`0001?oN2MH00?o0000oim8H?nOB6007_nOB6000ol0003o^emNok]OGP0Mok]OGP03o`000?oELDoo
eG5?00?oeG5?0_l00004okhm0P04o`000?nn?@;o_Sd2okhm0P;o0000>Oooool00ol0003ooooooooo
o`0Oooooo`009oooool2o`0002Wooooo00?o0000ooooooooool09oooool;o`0001KoN2MH00?o0000
oim8H?nOB6005_nOB60<o`0001co^emN00?o0000omEaCooELDl01OoELDl2o`0000;o_Sd200?o0000
okhm0_nn?@800onn?@82o`0003Sooooo00?o0000ooooooooool07_ooool002Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Tooooo`[o00006Omh9eP00ol0003oWdQPoim8H005oim8
H17o00002?nXI8801?l0003o`GV1ol5iPOo1NH45o`0001Oo^emN00?o0000omEaCooELDl01ooELDl3
o`0000Go_Sd200?o0000ojd[0?l00000=oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo02;ooooo2?l000000olg03ko0000ogPWF00GogPW
F0[o00006OnXI8800ol0003o`GV1ol5iP@06ol5iP@Ko00004OnkGeh00ol0003oeG5?omEaC`09omEa
C`?o00001?nn?@800ol0003o[B/0o`00000gooooo`03o`000?oooooooooo01gooooo000Wooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool08?ooool8o`0000;o=`0n00?o0000ogPWF?mh
9eP04omh9eP3o`0000;oRTan00?o0000ojQTP_nXI8807_nXI8800ol0003o`GV1ol5iP@0<ol5iP@Go
00003?nkGeh00ol0003oeG5?omEaC`09omEaC`03o`000?oELDooeG5?00;o00000onn?@800ol0003o
[B/0o`00000fooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool07Oooool8o`0000?o=`0n00?o0000ogPWF?mh9eP04Omh9eP3o`0000GoRTan
00?o0000ojQTP_nXI8807_nXI8800ol0003o`GV1ol5iP@0Aol5iP@Ko00001onkGeh00ol0003oeG5?
omEaC`08omEaC`03o`000?oELDooeG5?00;oeG5?0_l00002okhm0P03o`000?n]:`3o000003Kooooo
00?o0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`0Kooooo`Oo00001Olg03h00ol0003oN2MHogPWF00=ogPWF0Co00002?n:C7h00ol0003oZ6B2ojQT
PP0NojQTPP03o`000?o1NH7o`GV101Oo`GV11Ol00002ok]OGP03o`000?oELDooeG5?00SoeG5?00?o
0000omEaCooELDl01?oELDl4o`000003ojd[0?l0003ooooo03Gooooo00?o0000ooooooooool06ooo
ool002Kooooo0ol0000_ooooo`03o`000?oooooooooo01Wooooo1ol00006ocL0?P03o`000?mh9eSo
N2MH00[oN2MH0ol0000<ohY<OP03o`000?nXI8;oZ6B201koZ6B200?o0000ol5iPOo1NH407?o1NH44
o`0000[oeG5?00?o0000omEaCooELDl01_oELDl2o`000003ojd[0?l0003ooooo03Cooooo00?o0000
ooooooooool06oooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Goooo
o`Ko00001olg03h00ol0003oN2MHogPWF008ogPWF0?o00003on:C7h00ol0003oZ6B2ojQTPP0NojQT
PP03o`000?o1NH7o`GV101ko`GV100Co0000omV=Nol0003o00002?oELDl00ol0003oeG5?omEaC`08
omEaC`Co0000=?ooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01Kooooo1Ol00008ocL0?P03o`000?mh9eSoN2MH00CoN2MH1?l0
000BohY<OP03o`000?nXI8;oZ6B201koZ6B200?o0000ol5iPOo1NH407_o1NH401?l0003ofHekomV=
NooISG/2o`0000KoeG5?00?o0000omEaCooELDl02?oELDl01Ol0003oiW/So`000?n]:`3o000003?o
oooo00?o0000ooooooooool06_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05?ooool4o`0000[o=`0n00Co0000ogPWF?mh9eSoN2MH0ol0000EohY<OP03o`000?nXI8;oZ6B2
01ooZ6B200?o0000ol5iPOo1NH407_o1NH400ol0003ofHekomV=N`03omV=N`?o00000ooELDl00ol0
003oeG5?omEaC`08omEaC`06o`000?oVNb?oiW/So`000?n]:`3o0000<oooool00ol0003ooooooooo
o`0Iooooo`000oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`Co00002_lg
03h00ol0003oN2MHo`000002o`0001SoRTan00?o0000ojQTP_nXI8807onXI8800ol0003o`GV1ol5i
P@0Nol5iP@03o`000?oISG_ofHek00KofHek0_l000000ooELDoo0000omEaC`0:omEaC`06o`000?oV
Nb?oiW/So`000?n]:`3o0000<oooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo013ooooo0ol0000;ocL0?P?o00006on:C7h00ol0003oZ6B2ojQTPP0OojQTPP03
o`000?o1NH7o`GV101ko`GV100?o0000omV=NooISG/02?oISG/2o`0000_oeG5?00Oo0000onIk8ooV
Nb?oiW/So`000?n]:`3o000003;ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00kooooo0_l0000<ocL0?P03o`000?mK9WCo000001coRTan00?o
0000ojQTP_nXI8807onXI8800ol0003o`GV1ol5iP@0Nol5iP@03o`000?oISG_ofHek00WofHek0ol0
0009omEaC`03o`000?oVNb?oiW/S00;oiW/S00?o0000ojd[0?l00000<_ooool00ol0003ooooooooo
o`0Gooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool2o`0003Sooooo00?o0000ooooooooool03?ooool2o`0000_o=`0n0_l00002oe/VM003o`000?n:
C7koRTan01[oRTan00?o0000ojQTP_nXI8805onXI88<o`0001go`GV100?o0000omV=NooISG/02OoI
SG/00ol0003ofHekomV=N`02o`0000SoeG5?00?o0000onIk8ooVNb<00_oVNb<00ol0003o[B/0o`00
000aooooo`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02_oo
ool00ol0003o=`0nocL0?P09ocL0?P;o00001?mK9W@00ol0003oRTanohY<OP0JohY<OP03o`000?nX
I8;oZ6B200KoZ6B24Ol00008ojegV004o`000?o2RIOo`XVGol:9U`Go00006?o1NH400ol0003ofHek
omV=N`09omV=N`03o`000?oISG_ofHek00;ofHek0_l00006omEaC`03o`000?oVNb?oiW/S00?oiW/S
00?o0000ojd[0?l00000<Oooool00ol0003oooooooooo`0Fooooo`002oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
2?ooool00ol0003o=`0nocL0?P09ocL0?P03o`000?mK9WCoFbId00CoFbId00?o0000ohY<O_n:C7h0
6?n:C7h;o`0001Wo[GNH00?o0000ol:9Uoo2RIL01_o2RIL6o`0001;o`GV100?o0000omV=NooISG/0
2OoISG/00ol0003ofHekomV=N`04omV=N`?o00000ooELDl00ol0003oiW/SonIk8`04onIk8`;o0000
<?ooool3o`0001Oooooo000Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?oo
ool00ol0003o=`0nocL0?P07ocL0?P;o00001omK9W@00ol0003oRTanohY<OP0EohY<OP?o00000_nD
I9L00ol0003o[GNHojegV00OojegV003o`000?o2RIOo`XVG00co`XVG1Ol0000=ol5iP@03o`000?oI
SG_ofHek00WofHek00?o0000omV=NooISG/01ooISG/2o`000003omEaCol0003oiW/S00KoiW/S0_l0
000/ooooo`?o00000_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00Kooooo00?o0000ocL0?_lg03h01_lg03h2o`0000WoFbId00?o0000
ohY<O_n:C7h04_n:C7h3o`0000GoU6BG00?o0000ojegV?n]MiP07on]MiP00ol0003o`XVGol:9U`0A
ol:9U`Ko00001oo1NH400ol0003ofHekomV=N`09omV=N`03o`000?oISG_ofHek00WofHek0ol00007
onIk8`;o0000:?ooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`04ooooo`;o00001olg03h00ol0003oFbIdoe/VM008oe/V
M003o`000?n:C7koRTan00ooRTan1?l00008oiATU`03o`000?n]MiSo[GNH01oo[GNH00?o0000ol:9
Uoo2RIL05oo2RIL5o`0000;o`GV100?o0000omV=NooISG/02OoISG/00ol0003ofHekomV=N`0;omV=
N`;o00001ooVNb<2o`0002Cooooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool2o`0000Go=`0n0_l0000;oe/VM003
o`000?n:C7koRTan00coRTan0ol0000<oiATU`03o`000?n]MiSo[GNH01oo[GNH00?o0000ol:9Uoo2
RIL07?o2RIL4o`0000[ofHek00?o0000omV=NooISG/02ooISG/00ol0003olZ9Xo`000007onIk8`;o
00008?ooool3o`0000_ooooo00?o0000ooooooooool05Oooool002Cooooo0_l0000oooooo`04o`00
0?ooooooooooooooo`;o00001?lg03h2o`0000goFbId00?o0000ohY<O_n:C7h02On:C7h3o`0000oo
U6BG00?o0000ojegV?n]MiP07on]MiP00ol0003o`XVGol:9U`0Nol:9U`04o`000?oHW9Ko0000o`00
00SofHek00?o0000omV=NooISG/02ooISG/01?l0003olZ9Xoo:RJ?l00007onIk8`03o`000?oooooo
oooo01_ooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000Tooooo`03o`000?oooooooooo
03oooooo00?o0000ooooool000000_l00003ocL0?P03o`000?mK9WCoFbId00goFbId00?o0000ohY<
O_n:C7h01On:C7h4o`0001;oU6BG00?o0000ojegV?n]MiP07on]MiP00ol0003o`XVGol:9U`0Nol:9
U`04o`000?oHW9Kof9bFomRLUP?o00001OoISG/00ol0003ofHekomV=N`0;omV=N`05o`000?obXVSo
lZ9Xoo:RJ?l000001ooVNb<00ol0003oooooooooo`0Gooooo`?o00004_ooool00ol0003ooooooooo
o`0Dooooo`008oooool00ol0003oooooooooo`11ooooo`?o00000_lg03h2o`00013oFbId00?o0000
ohY<O_n:C7h00_n:C7h3o`0001KoU6BG00?o0000ojegV?n]MiP07on]MiP00ol0003o`XVGol:9U`0N
ol:9U`03o`000?oHW9Kof9bF00Cof9bF0_l00003omV=N`03o`000?oISG_ofHek00_ofHek00?o0000
oo:RJ?obXVP00_obXVP00ol0003oiW/SonIk8`05onIk8`03o`000?oooooooooo01?ooooo0ol0000E
ooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo047ooooo1Ol0000Boe/V
M003o`000?n:C7ko000000;o00006_nDI9L00ol0003o[GNHojegV00NojegV003o`000?o2RIOo`XVG
01ko`XVG00?o0000omRLU_oHW9H01_oHW9H2o`000003omV=Nol0003ofHek00cofHek00?o0000oo:R
J?obXVP00oobXVP00ol0003oiW/SonIk8`05onIk8`03o`000?oooooooooo00oooooo0ol0000Hoooo
o`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo043ooooo1?l0000Coe/VM0?o
00007OnDI9L00ol0003o[GNHojegV00NojegV003o`000?o2RIOo`XVG01ko`XVG00?o0000omRLU_oH
W9H02?oHW9H3o`0000cofHek00?o0000oo:RJ?obXVP01?obXVP00ol0003oiW/SonIk8`04onIk8`03
o`000?oooooooooo00cooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`00
0?oooooooooo03oooooo1?l0000Coe/VM003o`000?m`BYCo000001koU6BG00?o0000ojegV?n]MiP0
7_n]MiP00ol0003o`XVGol:9U`0Nol:9U`03o`000?oHW9Kof9bF00[of9bF0ol0000;omV=N`03o`00
0?obXVSolZ9X00ColZ9X00?o0000onIk8ooVNb<01?oVNb<00ol0003oooooooooo`08ooooo`?o0000
7_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0oooooo`Co00004OmK
9W@2o`0000;oL4ZD00?o0000oiATUonDI9L07?nDI9L00ol0003o[GNHojegV00NojegV003o`000?o2
RIOo`XVG01ko`XVG00?o0000omRLU_oHW9H02_oHW9H00ol0003of9bFomRLUP02o`0000WofHek00?o
0000oo:RJ?obXVP01OobXVP2o`0000CoiW/S00?o0000ooooooooool01Oooool3o`00027ooooo00?o
0000ooooooooool05?ooool002?ooooo0_l0000oooooo`Go00003omK9W@2o`0000CoL4ZD00?o0000
oiATUonDI9L07?nDI9L00ol0003o[GNHojegV00NojegV003o`000?o2RIOo`XVG01go`XVG00?o0000
omRLU_oHW9H02ooHW9H00ol0003of9bFomRLUP02omRLUP;o00001ooISG/00ol0003olZ9Xoo:RJ007
oo:RJ005o`000?oVNb?oiW/SonIk8ol000001?ooool3o`0002Gooooo00?o0000ooooooooool04ooo
ool002?ooooo00?o0000ooooooooool0?Oooool4o`000003o`00Dol0003oFbId00goFbId00?o0000
og1:U?m`BY@01?m`BY@00ol0003oU6BGoiATU`0LoiATU`03o`000?n]MiSo[GNH01ko[GNH00?o0000
ol:9Uoo2RIL07Oo2RIL00ol0003of9bFomRLUP0;omRLUP03o`000?oHW9Kof9bF00Cof9bF0_l00005
omV=N`03o`000?obXVSolZ9X00SolZ9X00Co0000onIk8ooVNb?oiW/S1?l0000Xooooo`03o`000?oo
oooooooo01?ooooo000Rooooo`03o`000?oooooooooo03gooooo1Ol000000ol005?o0000oe/VM00;
oe/VM0;o00001om`BY@00ol0003oU6BGoiATU`0LoiATU`03o`000?n]MiSo[GNH00ko[GNH5?l0000L
ol:9U`03o`000?oHW9Kof9bF00_of9bF00?o0000omRLU_oHW9H01_oHW9H3o`0000;ofHek00?o0000
oo:RJ?obXVP02OobXVP01?l0003oiW/SonIk8ol0000[ooooo`03o`000?oooooooooo01?ooooo000R
ooooo`03o`000?oooooooooo03gooooo1?l00002o`00D`03o`000?mK9WCoFbId00SoFbId0_l00009
og1:U003o`000?nDI9OoU6BG01[oU6BG4ol0000@ojn5Z004o`000?o2UJSo`YFXol:EZ0Oo00005Oo2
RIL00ol0003of9bFomRLUP0;omRLUP03o`000?oHW9Kof9bF00Wof9bF0ol0000<oo:RJ004o`000?oV
Nb?o0000o`0002[ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0??oo
ool4o`0000?o001C00?o0000oe/VM?mK9W@01omK9W@00ol0003oL4ZDog1:U009og1:U003o`000?nD
I9OoU6BG01OoU6BG0ol00002oiYfZ003o`000?n_QJSo[hFX01ko[hFX00?o0000ol:EZ?o2UJP02?o2
UJP6o`0000oo`XVG00?o0000omRLU_oHW9H02ooHW9H00ol0003of9bFomRLUP0;omRLUP;o00003?ob
XVP00ol0003oiW/So`00000Zooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooo
oooo03_ooooo1Ol00002o`00D`03o`000?mK9WCoFbId00KoFbId0_l0000=og1:U003o`000?nDI9Oo
U6BG01?oU6BG0ol00005oiYfZ003o`000?n_QJSo[hFX01ko[hFX00?o0000ol:EZ?o2UJP03_o2UJP6
o`0000Wo`XVG00?o0000omRLU_oHW9H02ooHW9H00ol0003of9bFomRLUP0;omRLUP03o`000?o_]I7o
000000colZ9X0_l0000Zooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
03_ooooo1?l00003o`00D`03o`000?mK9WCoFbId00CoFbId0_l0000?og1:U003o`000?nDI9OoU6BG
00ooU6BG1?l00008oiYfZ003o`000?n_QJSo[hFX01ko[hFX00?o0000ol:EZ?o2UJP05?o2UJP7o`00
00;o`XVG00?o0000omRLU_oHW9H02ooHW9H00ol0003of9bFomRLUP0;omRLUP04o`000?o_]I7okkFA
o`0000colZ9X0_l0000Yooooo`03o`000?oooooooooo01?ooooo000Qooooo`?o0000>oooool4o`00
00Co001C00?o0000oe/VM?mK9W@00omK9W@00ol0003oL4ZDog1:U00?og1:U003o`000?nDI9OoU6BG
00coU6BG0ol0000<oiYfZ003o`000?n_QJSo[hFX01ko[hFX00?o0000ol:EZ?o2UJP06oo2UJP4o`00
00cof9bF00?o0000omRLU_oHW9H02ooHW9H01Ol0003okkFAonneTOo_]I7o000000colZ9X00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0koooo
o`Co00001?l005<01?l0003oFbIdoe/VM?mK9W@2o`0001;oL4ZD00?o0000oiATUonDI9L02OnDI9L3
o`00013oVWJX00?o0000ojn5Z?n_QJP07On_QJP00ol0003o`YFXol:EZ00Mol:EZ003o`000?oDYjWo
000000;o00002OoHW9H00ol0003of9bFomRLUP0;omRLUP03o`000?o_]I7okkFA00;okkFA00?o0000
oo:RJ?obXVP02OobXVP00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01;ooooo000Qoooo
o`03o`000?oooooooooo03_ooooo0ol00005o`00D`04o`000?mK9WCo0000o`0001CoL4ZD00?o0000
oiATUonDI9L01OnDI9L4o`0001?oVWJX00?o0000ojn5Z?n_QJP07On_QJP00ol0003o`YFXol:EZ00M
ol:EZ003o`000?oDYjWoe:NY00;oe:NY0_l00007omRLUP03o`000?oHW9Kof9bF00_of9bF00?o0000
onneTOo_]I400oo_]I400ol0003olZ9Xoo:RJ008oo:RJ0;o0000:Oooool00ol0003oooooooooo`0B
ooooo`008Oooool00ol0003oooooooooo`0jooooo`?o00001_l005<2o`0001KoL4ZD00?o0000oiAT
UonDI9L00_nDI9L3o`0001OoVWJX00?o0000ojn5Z?n_QJP07On_QJP00ol0003o`YFXol:EZ00Mol:E
Z003o`000?oDYjWoe:NY00Coe:NY0ol00004omRLUP03o`000?oHW9Kof9bF00_of9bF00?o0000onne
TOo_]I401?o_]I400ol0003olZ9Xoo:RJ007oo:RJ0;o0000:Oooool00ol0003oooooooooo`0Boooo
o`008Oooool00ol0003oooooooooo`0jooooo`?o00001_l005<00ol0003oL4ZDog1:U00Eog1:U003
o`000?nDI9Oo000000;o00006_nJMZP00ol0003o[hFXojn5Z00Mojn5Z003o`000?o2UJSo`YFX01co
`YFX00?o0000omBWZOoDYjT02?oDYjT2o`0000;of9bF00?o0000omRLU_oHW9H02ooHW9H00ol0003o
kkFAonneT@05onneT@03o`000?obXVSolZ9X00KolZ9X0ol0000Xooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo03[ooooo0_l00007o`00D`03o`000?m`BYCoL4ZD01CoL4ZD
0ol0000MoiYfZ003o`000?n_QJSo[hFX01go[hFX00?o0000ol:EZ?o2UJP07?o2UJP00ol0003oe:NY
omBWZ@0:omBWZ@?o00003?oHW9H00ol0003okkFAonneT@07onneT@;o00001_obXVP00ol0003okJL/
o`00000Xooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03Wooooo0_l0
0007o`00D`;o00005?m`BY@2o`000003ogiTZ_l0003oVWJX01goVWJX00?o0000ojn5Z?n_QJP07On_
QJP00ol0003o`YFXol:EZ00Lol:EZ003o`000?oDYjWoe:NY00coe:NY0ol0000:omRLUP03o`000?o_
]I7okkFA00WokkFA00?o0000oo:RJ?obXVP00oobXVP00ol0003okJL/o`00000Xooooo`03o`000?oo
oooooooo01;ooooo000Pooooo`?o0000>_ooool2o`0000Ko001C00?o0000oc0NR_l000004om`BY@0
1Ol0003oOVBZogiTZ_mnI:[o000001koVWJX00?o0000ojn5Z?n_QJP07On_QJP00ol0003o`YFXol:E
Z00Lol:EZ003o`000?oDYjWoe:NY00coe:NY00?o0000omBWZOoDYjT00_l00008omRLUP03o`000?o_
]I7okkFA00[okkFA00?o0000oo:RJ?obXVP00oobXVP00ol0003okJL/o`00000Xooooo`03o`000?oo
oooooooo017ooooo000Pooooo`03o`000?oooooooooo03[ooooo00?o0000o`00Dol005<01Ol005<0
1?l0003o<1j:oc0NR_l0000@og1:U0;o00001OmnI:X00ol0003oVWJXoiYfZ00KoiYfZ003o`000?n_
QJSo[hFX01go[hFX00?o0000ol:EZ?o2UJP07?o2UJP00ol0003oe:NYomBWZ@0=omBWZ@04o`000?oD
YjWoe:NYomBWZ@?o00001OoHW9H00ol0003okkFAonneT@0;onneT@03o`000?obXVSolZ9X00;olZ9X
00?o0000onfW;?l00000:?ooool00ol0003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0>Oooool00ol0003o001Co`00D`05o`00D`05o`00
0?l`7X[o<1j:oc0NR_l000003_m`BY@2o`0000OoOVBZ00?o0000oiYfZ?nJMZP06onJMZP00ol0003o
[hFXojn5Z00Mojn5Z003o`000?o2UJSo`YFX01_o`YFX00?o0000omBWZOoDYjT03_oDYjT00ol0003o
e:NYomBWZ@04omBWZ@;o00000ooHW9H00ol0003okkFAonneT@0<onneT@06o`000?obXVSolZ9Xoo:R
J?l0003okJL/0_l0000Wooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`0iooooo`03o`000?l005?o001C00Co001C00?o0000
oc0NR_l`7XX00_l`7XX00ol0003oL4ZDog1:U00;og1:U003o`000?mnI:[oOVBZ00OoOVBZ00?o0000
oiYfZ?nJMZP07?nJMZP00ol0003o[hFXojn5Z00Lojn5Z003o`000?o2UJSo`YFX01_o`YFX00?o0000
omBWZOoDYjT03_oDYjT00ol0003oe:NYomBWZ@06omBWZ@Co00003oo_]I401?l0003olZ9Xoo:RJ?l0
0002onfW;003o`000?oooooooooo02Gooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03Wooooo00?o0000o`00Dol005<01?l0
05<00ol0003o<1j:oc0NRP02oc0NRP03o`000?m`BYCoL4ZD00WoL4ZD0_l0000:ogiTZP03o`000?nJ
MZSoVWJX01coVWJX00?o0000ojn5Z?n_QJP07?n_QJP00ol0003o`YFXol:EZ00Kol:EZ003o`000?oD
YjWoe:NY00koe:NY00?o0000omBWZOoDYjT02OoDYjT2o`0000ookkFA00?o0000oo:RJ?l000000_o]
Yb`00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`0iooooo`03o`000?l005?o001C00?o001C00?o
0000oc0NR_l`7XX00ol`7XX00ol0003oL4ZDog1:U007og1:U0;o00003OmnI:X00ol0003oVWJXoiYf
Z00KoiYfZ003o`000?n_QJSo[hFX00go[hFX5?l0000Iol:EZ003o`000?oDYjWoe:NY00koe:NY00?o
0000omBWZOoDYjT02OoDYjT00ol0003oj;jZo`00000?onneT@;o00000_o]Yb`2o`0002Kooooo00?o
0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo03[ooooo00?o0000o`00Dol005<00_l005<00ol0003o<1j:oc0NRP04oc0NRP03o`000?m`
BYCoL4ZD00KoL4ZD00?o0000ogiTZ_mnI:X03OmnI:X00ol0003oVWJXoiYfZ00IoiYfZ1;o00003on`
TKD00ol0003o`9jfol2N]P02ol2N]POo00004_o2UJP00ol0003oe:NYomBWZ@0>omBWZ@03o`000?oD
YjWoe:NY00Soe:NY00Go0000onRnZ_oX_Z[oj;jZo`00000?onneT@05o`000?o]YbcokJL/onfW;?l0
00009_ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Go
oooo0_l0000kooooo`03o`000?l005?o001C00;o001C00?o0000oc0NR_l`7XX01?l`7XX00ol0003o
L4ZDog1:U004og1:U0;o00004?mnI:X00ol0003oVWJXoiYfZ00FoiYfZ0?o00000_nNQ;L00ol0003o
/96eok2A]@0Lok2A]@03o`000?o0W[Ko`9jf00Wo`9jf1ol0000:ol:EZ003o`000?oDYjWoe:NY00oo
e:NY00?o0000omBWZOoDYjT02?oDYjT00ol0003oj;jZonRnZP02onRnZP03o`000?o_]I7okkFA00co
kkFA00Go0000onfW;?o]YbcokJL/o`00000Vooooo`03o`000?oooooooooo017ooooo000Eooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0iooooo`;o00000ol005<00ol0
003o<1j:oc0NRP06oc0NRP04o`000?m`BYCoL4ZDog1:U0;o00004_mnI:X00ol0003oVWJXoiYfZ00B
oiYfZ0Co00001OnNQ;L00ol0003o/96eok2A]@0Lok2A]@03o`000?o0W[Ko`9jf013o`9jf1ol00003
ol:EZ003o`000?oDYjWoe:NY00ooe:NY00?o0000omBWZOoDYjT02?oDYjT00ol0003oj;jZonRnZP03
onRnZP03o`000?o_]I7okkFA00_okkFA0_l00003onfW;003o`000?oooooooooo02Cooooo00?o0000
ooooooooool04?ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo03Wooooo00Go0000o`00Dol005?o001Co`000009oc0NRP04o`000?m`BYCoL4ZDo`0001GoOVBZ
00?o0000oiYfZ?nJMZP03_nJMZP3o`0000WoWXBg00?o0000ok2A]On`TKD07?n`TKD00ol0003o`9jf
ol2N]P0Gol2N]PGo00004?oDYjT00ol0003oe:NYomBWZ@07omBWZ@03o`000?oX_Z[oj;jZ00Goj;jZ
00?o0000onneTOo_]I402_o_]I42o`0000?okJL/00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0@ooooo`007oooool00ol0003oooooooooo`0iooooo`05o`000?l005?o001Co`00Dol00000
2Ol`7XX3o`0001KoOVBZ00?o0000oiYfZ?nJMZP02_nJMZP4o`0000coWXBg00?o0000ok2A]On`TKD0
7?n`TKD00ol0003o`9jfol2N]P0Jol2N]P03o`000?o@[[So000000;o00003OoDYjT00ol0003oe:NY
omBWZ@07omBWZ@03o`000?oX_Z[oj;jZ00Koj;jZ00?o0000onneTOo_]I402?o_]I400ol0003oolmj
o`000003onfW;003o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool001oooooo00?o
0000ooooooooool0>Oooool01?l0003o001Co`00Dol0000:oc0NRP03o`000?mnI:[oOVBZ01KoOVBZ
00?o0000oiYfZ?nJMZP01onJMZP3o`00017oWXBg00?o0000ok2A]On`TKD06on`TKD00ol0003o`9jf
ol2N]P0Jol2N]P03o`000?o@[[Sod:jh00;od:jh0_l0000;omBWZ@03o`000?oDYjWoe:NY00Ooe:NY
00?o0000onRnZ_oX_ZX01ooX_ZX2o`0000SokkFA00Co0000ooo?N_oocg[o00000oo]Yb`00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03Wooooo
00?o0000o`00Dol000002ol`7XX00ol0003oOVBZogiTZP0FogiTZP03o`000?nJMZSoVWJX00?oVWJX
1?l0000Doij4]`03o`000?n`TKGo/96e01_o/96e00?o0000ol2N]_o0W[H06Oo0W[H00ol0003od:jh
om2^^005om2^^0?o00002?oDYjT00ol0003oe:NYomBWZ@06omBWZ@03o`000?oX_Z[oj;jZ00[oj;jZ
00?o0000onneTOo_]I401Oo_]I401?l0003oolmjooo?N_l00003onfW;003o`000?oooooooooo02?o
oooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooooooool0>_ooool00ol0003o001C
o`00000:oc0NRP03o`000?m@BJ[o000001SoOVBZ00?o0000oiYfZ?l000000_l0000Hoij4]`03o`00
0?n`TKGo/96e01_o/96e00?o0000ol2N]_o0W[H06Oo0W[H00ol0003od:jhom2^^008om2^^0;o0000
1_oDYjT00ol0003oe:NYomBWZ@06omBWZ@03o`000?oX_Z[oj;jZ00_oj;jZ00?o0000onneTOo_]I40
1?o_]I401Ol0003oolmjooo?N_oocg[o000000;okJL/00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`0jooooo`;o00002_l`7XX01?l0003oD4VZ
oe19Z_l0000GogiTZP?o00006onNQ;L00ol0003o/96eok2A]@0Jok2A]@03o`000?o0W[Ko`9jf01[o
`9jf00?o0000om2^^?o@[[P02_o@[[P3o`0000?oe:NY00?o0000omBWZOoDYjT01_oDYjT00ol0003o
j;jZonRnZP0<onRnZP03o`000?o_]I7okkFA00?okkFA00Go0000ooo?N_oocg[oolmjo`000002onfW
;003o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool001kooooo0_l0000kooooo`03
o`000?l`7X[o<1j:00Wo<1j:00Co0000oe19Z_m@BJ[o00005OmnI:X2o`000003ohQg^_l0003oWXBg
01_oWXBg00?o0000ok2A]On`TKD06_n`TKD00ol0003o`9jfol2N]P0Jol2N]P03o`000?o@[[Sod:jh
00god:jh0_l000000ooDYjWo0000omBWZ@06omBWZ@03o`000?oX_Z[oj;jZ00koj;jZ00?o0000onne
TOo_]I400_o_]I401Ol0003oolmjooo?N_oocg[o000000;okJL/00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0jooooo`03o`000?l`7X[o<1j:
00So<1j:00?o0000oe19Z_m@BJX00_m@BJX00ol0003oOVBZogiTZP0AogiTZP03o`000?n8Mk[oR7Nj
00;oR7Nj00?o0000oij4]onNQ;L06OnNQ;L00ol0003o/96eok2A]@0Jok2A]@03o`000?o0W[Ko`9jf
01Wo`9jf00?o0000om2^^?o@[[P04?o@[[P3o`0000Koe:NY00?o0000onRnZ_oX_ZX03ooX_ZX01Ol0
003okkFAonneTOo_]I7o000000Coolmj00?o0000onfW;?l000009_ooool00ol0003oooooooooo`0?
ooooo`007_ooool00ol0003oooooooooo`0iooooo`;o00002Ol`7XX00ol0003oD4VZoe19ZP03oe19
ZP03o`000?mnI:[oOVBZ00ooOVBZ0_l00005ohQg^P03o`000?nNQ;OoWXBg01WoWXBg00?o0000ok2A
]On`TKD06_n`TKD00ol0003o`9jfol2N]P0Iol2N]P03o`000?o@[[Sod:jh017od:jh00Co0000om2^
^?l0003o00001?oDYjT00ol0003oj;jZonRnZP0@onRnZP03o`000?o_]I7o000000Goolmj00?o0000
onfW;?l000009_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o00002?l`7XX00ol0003oD4VZoe19ZP04oe19ZP03o`000?mnI:[oOVBZ00goOVBZ0_l00007ohQg
^P03o`000?nNQ;OoWXBg01WoWXBg00?o0000ok2A]On`TKD06_n`TKD00ol0003o`9jfol2N]P0Iol2N
]P03o`000?o@[[Sod:jh017od:jh00Co0000om2^^?o@[[Sod:jh1?l0000DonRnZP;o00001OoocgX0
1?l0003okJL/onfW;?l0000Uooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo03[ooooo00?o0000o`00FOl000001ol`7XX00ol0003oD4VZoe19ZP05oe19ZP03o`000?mnI:[o
OVBZ00[oOVBZ0_l0000:ohQg^P03o`000?nNQ;OoWXBg01SoWXBg00?o0000ok2A]On`TKD06_n`TKD0
0ol0003o`9jfol2N]P0Iol2N]P03o`000?o@[[Sod:jh017od:jh00?o0000om2^^?o@[[P01?o@[[P2
o`0001Coj;jZ00?o0000ooo?N_oocgX01?oocgX00ol0003okJL/o`00000Uooooo`03o`000?oooooo
oooo00oooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000o`00FOl000001_l`7XX00ol0
003oD4VZoe19ZP06oe19ZP03o`000?mnI:[oOVBZ00WoOVBZ00?o0000ohQg^_n8MkX02_n8MkX00ol0
003oWXBgoij4]`0Ioij4]`03o`000?n`TKGo/96e01Wo/96e00?o0000ol2N]_o0W[H06Oo0W[H00ol0
003od:jhom2^^00Bom2^^003o`000?o@[[Sod:jh00?od:jh00?o0000on33_?l000004ooX_ZX00ol0
003oolmjooo?NP04ooo?NP03o`000?o]Ybco000002Gooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool0>_ooool00ol0003o001Io`000005oc0NRP03o`000?m@BJ[oD4VZ00Oo
D4VZ00?o0000ogiTZ_mnI:X01omnI:X2o`0000koR7Nj00?o0000oij4]onNQ;L06?nNQ;L00ol0003o
/96eok2A]@0Iok2A]@03o`000?o0W[Ko`9jf01So`9jf00?o0000om2^^?o@[[P04oo@[[P00ol0003o
d:jhom2^^002om2^^005o`000?oP`kcoh<>lon33_?l000004OoX_ZX00ol0003on]bWo`000006ooo?
NP;o00009Oooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0003_ooooo00?o0000o`00FOl0
00001Ol`7XX00ol0003oD4VZoe19ZP08oe19ZP03o`000?mnI:[oOVBZ00CoOVBZ0_l0000@ohQg^P03
o`000?nNQ;OoWXBg01SoWXBg00?o0000ok2A]On`TKD02on`TKDBo`0001Oo`9jf00?o0000om2^^?o@
[[P04oo@[[P00ol0003od:jhom2^^002om2^^003o`000?oP`kcoh<>l00;oh<>l00?o0000onRnZ_oX
_ZX03_oX_ZX00ol0003on]bWo`000006ooo?NP;o00009_ooool00ol0003oooooooooo`0>ooooo`00
7Oooool00ol0003oooooooooo`0jooooo`03o`000?l005Wo000000Co<1j:00?o0000oe19Z_m@BJX0
2Om@BJX00ol0003oOVBZogiTZP02ogiTZP;o00004_n8MkX00ol0003oWXBgoij4]`0Foij4]a3o0000
3_naV/401?l0003o_ZK1okjV`OnnY/47o`00013o`9jf00?o0000om2^^?o@[[P04oo@[[P01Ol0003o
d:jhom2^^?o@[[So000000Koh<>l00?o0000onRnZ_oX_ZX03OoX_ZX00ol0003on]bWo`000006ooo?
NP;o00009_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0jooooo`03
o`000?l005Wo000000?o<1j:00?o0000oe19Z_m@BJX02_m@BJX01Ol0003oOVBZogiTZ_mnI:[o0000
01GoR7Nj00?o0000oij4]onNQ;L04OnNQ;L4o`0000;oXY3200?o0000ok6J`OnaV/406OnaV/400ol0
003o_ZK1okjV`@08okjV`@Ko00002_o0W[H00ol0003od:jhom2^^00Com2^^005o`000?o@[[Sod:jh
om2^^?l000001ooP`k`2o`0000coj;jZ00Go0000oo[LYoojg:Oon]bWo`000006ooo?NP03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0>oooool0
0ol0003o001Io`000002oc0NRP03o`000?m@BJ[oD4VZ00coD4VZ0ol0000FohQg^P03o`000?nNQ;Oo
WXBg00goWXBg1?l00006oj:@`P03o`000?naV/7o/I[101Wo/I[100?o0000okjV`OnnY/403_nnY/47
o`0000;o`9jf00?o0000om2^^?o@[[P05?o@[[P01?l0003od:jhom2^^?l0000:on33_003o`000?oX
_Z[oj;jZ00Woj;jZ00Go0000oo[LYoojg:Oon]bWo`000006ooo?NP03o`000?oooooooooo02Cooooo
00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0>oooool01_l0003o001Io`00
FOl0003o<1j:o`0000koD4VZ00?o0000ohQg^_n8MkX05on8MkX00ol0003oWXBgoij4]`08oij4]`Co
00002_nRT<800ol0003o/I[1ok6J`@0Iok6J`@03o`000?nnY/7o_ZK101Go_ZK11?l0000Eom2^^004
o`000?o@[[Sod:jho`0000_oh<>l00?o0000onRnZ_oX_ZX02?oX_ZX00ol0003on]bWoo[LY`02oo[L
Y`03o`000?oocg[oolmj00?oolmj00?o0000ooooooooool09?ooool00ol0003oooooooooo`0>oooo
o`007?ooool00ol0003oooooooooo`0kooooo`03o`000?l005Wo001I00;o00003om@BJX00ol0003o
R7NjohQg^P0GohQg^P03o`000?nNQ;OoWXBg00CoWXBg1?l0000?oj:@`P03o`000?naV/7o/I[101So
/I[100?o0000okjV`OnnY/405onnY/400ol0003obkC4o`000002o`0001;od:jh00?o0000om2^^?l0
00003OoP`k`00ol0003oj;jZonRnZP06onRnZP03o`000?ojg:Oon]bW00?on]bW00?o0000ooo?N_oo
cgX00ooocgX00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo000Looooo`03o`00
0?oooooooooo03[ooooo0_l00002o`00F@03o`000?m@BJ[oD4VZ00goD4VZ00?o0000ofIW_ol00000
6?n8MkX00ol0003oWXBgoij4]`04o`0001?oXY3200?o0000ok6J`OnaV/406?naV/400ol0003o_ZK1
okjV`@0FokjV`@03o`000?o;]<CobkC400?obkC40ol0000=om2^^0?o000000?od:jho`000?oP`k`0
3OoP`k`2o`0000Koj;jZ00?o0000oo[LYoojg:L00oojg:L00ol0003oolmjooo?NP02ooo?NP03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0>_oo
ool01Ol0003o001Io`00FOl005Wo000000koD4VZ00Co0000ofIW_omVIkoo00006?n8MkX3o`0001Oo
XY3200?o0000ok6J`OnaV/406?naV/400ol0003o_ZK1okjV`@0FokjV`@03o`000?o;]<CobkC400Ko
bkC40ol00007om2^^0?o00000_o@[[P00ol0003od:jho`00000@on33_003o`000?oX_Z[oj;jZ00?o
j;jZ00?o0000oo[LYoojg:L01?ojg:L01Ol0003oolmjooo?N_oocg[o000002Sooooo00?o0000oooo
ooooool03Oooool001cooooo0_l0000kooooo`06o`000?l005Wo001Io`00FOl05Ico00003?m@BJX0
0ol0003oIVNoofIW_`02ofIW_`03o`000?n8Mk[oR7Nj01?oR7Nj0_l000000on?QlKo0000oj:@`P0G
oj:@`P03o`000?naV/7o/I[101So/I[100?o0000okjV`OnnY/405_nnY/400ol0003obkC4ol^da009
ol^da0;o00000_o@[[P3o`0000Kod:jh00?o0000on33_?oP`k`04?oP`k`01Ol0003oj;jZonRnZ_oX
_Z[o000000Oon]bW00Go0000ooo?N_oocg[oolmjo`00000Xooooo`03o`000?oooooooooo00gooooo
000Kooooo`03o`000?oooooooooo03_ooooo00Ko0000o`00FOl005Wo001Io`0EW?l0000<oe19ZP03
o`000?mVIkooIVNo00?oIVNo00?o0000ohQg^_n8MkX04On8MkX00ol0003oShO6ohn7aP02ohn7aP03
o`000?nRT<;oXY3201GoXY3200?o0000ok6J`OnaV/405onaV/400ol0003o_ZK1okjV`@0FokjV`@03
o`000?o;]<CobkC400_obkC41?l00008om2^^0;o00004_oP`k`01?l0003oj;jZonRnZ_l00007oo[L
Y`05o`000?oocg[oolmjooo?N_l00000:?ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0
003oooooooooo`0kooooo`04o`000?l005Wo001Io`00F@;o01FL00?o0000oe19Z_m@BJX02?m@BJX0
0ol0003oIVNoofIW_`04ofIW_`03o`000?n8Mk[oR7Nj00ooR7Nj0_l00005ohn7aP03o`000?nRT<;o
XY3201KoXY3200?o0000ok6J`OnaV/405_naV/400ol0003o_ZK1okjV`@0FokjV`@03o`000?o;]<Co
bkC400OobkC41?l00004ol^da0?o00001?o@[[P01?l0003oh<>lon33_?l0000Bon33_003o`000?oX
_Z[o000000Son]bW00Co0000ooo?N_oocg[o0000:?ooool00ol0003oooooooooo`0=ooooo`006ooo
ool00ol0003oooooooooo`0kooooo`04o`000?l005Wo001Io`0000;o01FL00?o0000oe19Z_m@BJX0
1om@BJX00ol0003oIVNoofIW_`06ofIW_`03o`000?n8Mk[oR7Nj00coR7Nj0_l00007ohn7aP03o`00
0?nRT<;oXY3201KoXY3200?o0000ok6J`OnaV/405_naV/400ol0003o_ZK1okjV`@0FokjV`@03o`00
0?o;]<CobkC400CobkC40ol0000;ol^da0?o000000?od:jho`000?oP`k`00_oP`k`00ol0003oh<>l
on33_00@on33_003o`000?ojg:Oon]bW00Oon]bW00Co0000ooo?N_oocg[o0000:?ooool00ol0003o
ooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?l005Wo001Io`0000?o
01FL00?o0000oe19Z_m@BJX01Om@BJX00ol0003oIVNoofIW_`07ofIW_`03o`000?n8Mk[oR7Nj00[o
R7Nj0_l0000:ohn7aP03o`000?nRT<;oXY3201GoXY3200?o0000ok6J`OnaV/405_naV/400ol0003o
_ZK1okjV`@0EokjV`@03o`000?o;]<CobkC400;obkC40ol0000Aol^da0;o00000ooP`k`00ol0003o
h<>lon33_00@on33_003o`000?ojg:Oon]bW00Son]bW00?o0000ooo?N_l00000:?ooool00ol0003o
ooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0kooooo`04o`000?l005Wo001Io`0000?o
01FL00?o0000oe19Z_m@BJX01Om@BJX00ol0003oIVNoofIW_`08ofIW_`03o`000?n8Mk[oR7Nj00So
R7Nj00?o0000ohn7a_n?QlH02_n?QlH00ol0003oXY32oj:@`P0Eoj:@`P03o`000?naV/7o/I[101Ko
/I[100?o0000okjV`OnnY/405OnnY/400ol0003obkC4o`000002o`0001CobkC400?o0000omO6bOl0
00000ooP`k`00ol0003oh<>lon33_00>on33_003o`000?o^gl7o000000Won]bW0_l0000Yooooo`03
o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03_ooooo00Co0000o`00FOl005Wo
00000ol05I`00ol0003oD4VZoe19ZP04oe19ZP03o`000?mVIkooIVNo00WoIVNo00?o0000ohQg^_n8
MkX01_n8MkX2o`0000koShO600?o0000oj:@`_nRT<805?nRT<800ol0003o/I[1ok6J`@0Fok6J`@03
o`000?nnY/7o_ZK101?o_ZK11?l0000Fol^da005o`000?oGa/WoelK9omO6bOl000000ooP`k`00ol0
003oh<>lon33_00<on33_004o`000?o^gl7ok]o1o`0000Won]bW0_l0000Yooooo`03o`000?oooooo
oooo00gooooo000Kooooo`;o0000?Oooool00ol0003o001Io`000004o`0EW003o`000?m@BJ[oD4VZ
00;oD4VZ00?o0000ofIW_omVIkl02omVIkl00ol0003oR7NjohQg^P03ohQg^P;o00004?n?QlH00ol0
003oXY32oj:@`P0Eoj:@`P03o`000?naV/7o/I[101Go/I[100?o0000okjV`OnnY/404?nnY/43o`00
0003okjV`Ol0003obkC401OobkC400?o0000omO6bOoGa/T00_oGa/T01Ol0003oh<>lon33_?oP`kco
000000goh<>l00Co0000onkO`Oo^gl7o00002_ojg:L00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00cooooo000Jooooo`03o`000?oooooooooo03gooooo00?o0000o`00FOl000001?l05I`0
0ol0003oD4VZoe19ZP02oe19ZP03o`000?mVIkooIVNo00coIVNo00Go0000ohQg^_n8Mk[oR7Njo`00
000Bohn7aP03o`000?nRT<;oXY3201GoXY3200?o0000ok6J`OnaV/402OnaV/4Ao`0000_o_ZK10ol0
0004okjV`@03o`000?o;]<CobkC401GobkC400?o0000omO6bOoGa/T01?oGa/T2o`0000;oh<>l00?o
0000on33_?oP`k`02OoP`k`00ol0003ok]o1onkO`@02onkO`@03o`000?ojg:Oon]bW00Oon]bW00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03gooooo
00?o0000o`00FOl000001Ol05I`01?l0003oD4VZoe19Z_l0000?ofIW_`04o`000?n8Mk[o0000o`00
01CoShO600?o0000oj:@`_nRT<804_nRT<8>o`0000co/:C;00?o0000ok^]c?nk[L`00_nk[L`7o`00
0004okjV`Ol0003o0000o`0000Oo_ZK100?o0000ol^da?o;]<@05?o;]<@00ol0003oelK9omO6b@07
omO6b@04o`000?oP`kcoh<>lo`0000Woh<>l00?o0000onkO`Oo^gl400oo^gl400ol0003on]bWoo[L
Y`06oo[LY`;o0000:_ooool00ol0003oooooooooo`0<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0mooooo`03o`000?l0
05Wo000000Go01FL00?o0000oe19Z_l000004OmVIkl00ol0003oShO6ohn7aP0Dohn7aP03o`000?nR
T<;oXY3200koXY321?l00002ojBKc@03o`000?n`Y<_o/:C;01Go/:C;00?o0000ok^]c?nk[L`01_nk
[L`:o`0000?o_ZK100?o0000ol^da?o;]<@05Oo;]<@00ol0003oelK9omO6b@08omO6b@03o`000?oP
`kco000000Soh<>l00?o0000onkO`Oo^gl401?o^gl400ol0003on]bWoo[LY`06oo[LY`;o0000:_oo
ool00ol0003oooooooooo`0<ooooo`000oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0?Oooool00ol0003o001Io`000006o`0EW003o`000?mVIkoo
IVNo013oIVNo00?o0000ohn7a_n?QlH05On?QlH00ol0003oXY32oj:@`P08oj:@`PGo00001_nTVld0
0ol0003o/:C;ok2Tb`0Eok2Tb`03o`000?nk[Lco^jg<00?o^jg<0ol0000:ok^]c0Co00005_o;]<@0
0ol0003oelK9omO6b@0:omO6b@03o`000?oP`kco000000Ooh<>l00?o0000onkO`Oo^gl401Oo^gl40
0ol0003on]bWoo[LY`04oo[LY`;o0000:oooool00ol0003oooooooooo`0<ooooo`000oooool00ol0
003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0?Oooool2o`00
00Oo01FL00?o0000ofIW_omVIkl03omVIkl00ol0003oMWg=o`00000Fohn7aP03o`000?nRT<;oXY32
00CoXY321?l0000<ojBKc@03o`000?n`Y<_o/:C;01Co/:C;00?o0000ok^]c?nk[L`00ol0000@ok^]
c003o`000?o5^Loo000000;o00004_o;]<@00ol0003oelK9omO6b@0;omO6b@?o00001OoP`k`00ol0
003ok]o1onkO`@06onkO`@03o`000?ojg:Oon]bW00Con]bW0_l0000[ooooo`03o`000?oooooooooo
00cooooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005oooo
o`03o`000?oooooooooo03kooooo00?o0000o`0EW?l05I`01Ol05I`00ol/CL7o0000ofIW_`0>ofIW
_`05o`000?mfOLgoMWg=ogImcOl000005On?QlH00ol0003oXY32oj:@`P04o`00013oY9_=00?o0000
ok2Tbon`Y</05?n`Y</3o`0001;o^jg<00?o0000olFicoo5^Ll00oo5^Ll3o`0000kobkC400?o0000
omO6bOoGa/T03_oGa/T2o`0000?oh<>l00?o0000onkO`Oo^gl402?o^gl400ol0003on]bWoo[LY`02
oo[LY`03o`000?oSjH;o000002_ooooo00?o0000ooooooooool03?ooool000?ooooo00?o410@oooo
ooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03oooooo00?o0000o`0E
W?l05I`01Ol05I`00ol0003o;4g1o`00000=ofIW_`03o`000?mfOLgoMWg=00;oMWg=00?o0000ohn7
a_n?QlH04on?QlH3o`0001CoY9_=00?o0000ok2Tbon`Y</04?n`Y</5o`0001Co^jg<00?o0000olFi
coo5^Ll01_o5^Ll3o`0000_obkC400?o0000omO6bOoGa/T03ooGa/T2o`0000;oh<>l00?o0000onkO
`Oo^gl402?o^gl400ol0003on]bWoo[LY`02oo[LY`03o`000?oSjH;o000002cooooo00?o0000oooo
ooooool02oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`00
043ooooo00?o0000o`0EW?l05I`01Ol05I`00ol0003o;4g1o`00000<ofIW_`03o`000?mfOLgoMWg=
00CoMWg=00?o0000ohn7a_n?QlH04?n?QlH2o`000003oiFEdOl0003oY9_=01GoY9_=00?o0000ok2T
bon`Y</03?n`Y</3o`0000Co/:C;00?o0000ok^]c?nk[L`04_nk[L`00ol0003oaKW?olFic`09olFi
c`;o00002?o;]<@00ol0003oelK9omO6b@0AomO6b@03o`000?oP`kco000000_ok]o100Go0000oo[L
Yoojg:Oon]bWo`000002on?YPP03o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool0
0004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo03oooooo00?o0000
o`0EW?l05I`01?l05I`01Ol0003o;4g1oba=`Ol/CL7o000000[oIVNo00?o0000ogImcOmfOLd01_mf
OLd00ol0003oShO6ohn7aP0>ohn7aP03o`000?nEUM7oUIGA00;oUIGA00?o0000ojBKcOnTVld04onT
Vld00ol0003o/:C;ok2Tb`09ok2Tb`?o00001_n`Y</00ol0003o^jg<ok^]c00Bok^]c003o`000?o5
^LooaKW?00coaKW?0ol00004ol^da003o`000?oGa/WoelK901?oelK900?o0000onkO`Oo^gl402oo^
gl401_l0003on]bWoo[LYol0003ohnV2o`0002gooooo00?o0000ooooooooool02oooool001Wooooo
00?o0000ooooooooool0@?ooool00ol0003o01FLo`0EW003o`0EW003o`000?l/CL7o;4g100;o;4g1
00?o0000ofIW_omVIkl01_mVIkl00ol0003oMWg=ogImc@08ogImc@03o`000?n?QlKoShO600_oShO6
0_l00006oiFEd@03o`000?nTVlgoY9_=01;oY9_=00?o0000ok2Tbon`Y</01_n`Y</3o`0000Wo/:C;
00?o0000ok^]c?nk[L`04_nk[L`00ol0003oaKW?olFic`0?olFic`?o000000?obkC4o`000?oGa/T0
5?oGa/T2o`0000cok]o100?o0000oo[LYol000000_oSjH800ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo043ooooo00?o0000o`0EW?l05I`00ol0
5I`00ol0003o;4g1oba=`@02oba=`@03o`000?mVIkooIVNo00KoIVNo00?o0000ogImcOmfOLd02?mf
OLd00ol0003oShO6ohn7aP09ohn7aP;o00002?nEUM400ol0003oY9_=ojBKc@0BojBKc@03o`000?n`
Y<_o/:C;00;o/:C;1?l0000<ok2Tb`03o`000?nk[Lco^jg<01;o^jg<00?o0000olFicoo5^Ll04_o5
^Ll2o`0001CoelK900Co0000on7MdOl0003o00002oo^gl400ol0003on]bWo`000002on?YPP03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0@Ooo
ool00ol0003o01FLo`0EW002o`0EW003o`000?l/CL7o;4g100?o;4g100?o0000ofIW_omVIkl01?mV
Ikl00ol0003oMWg=ogImc@0:ogImc@03o`000?n?QlKoShO600KoShO60_l0000;oiFEd@03o`000?nT
VlgoY9_=01;oY9_=1?l0000@ok2Tb`03o`000?nk[Lco^jg<017o^jg<00?o0000olFicoo5^Ll04oo5
^Ll00ol0003oc/SDo`00000BomO6b@06o`000?oQgM7ohMgAo`000?o^gl7o00002oo^gl401Ol0003o
hnV2on?YP_oSjH;o000002gooooo00?o0000ooooooooool02oooool001Sooooo00?o0000oooooooo
ool0@_ooool00ol0003o01FLo`0EW002o`0EW003o`000?l/CL7o;4g100Co;4g100?o0000ofIW_omV
Ikl00_mVIkl00ol0003oMWg=ogImc@0<ogImc@03o`000?n?QlKoShO600?oShO60_l0000=oiFEd@03
o`000?nTVlgoY9_=013oY9_=0ol0000Cok2Tb`03o`000?nk[Lco^jg<017o^jg<00?o0000olFicoo5
^Ll04_o5^Ll01Ol0003oc/SDolk8e?o>b=Co0000013oelK900?o0000on7MdOoQgM400_oQgM400ol0
003ok]o1o`00000:onkO`@05o`000?oSjH;ohnV2on?YP_l00000;Oooool00ol0003oooooooooo`0;
ooooo`006?ooool00ol0003oooooooooo`13ooooo`05o`000?l05Ico01FLo`0EW?l000001_l/CL40
1Ol0003oIVNoofIW_omVIkoo000000ooMWg=00?o0000ohn7a_n?QlH00_n?QlH00ol0003oUIGAoiFE
d@0>oiFEd@03o`000?nTVlgoY9_=00coY9_=0ol00002ojBKc@03o`000?n`Y<_o/:C;017o/:C;00?o
0000ok^]c?nk[L`04Onk[L`00ol0003oaKW?olFic`0AolFic`03o`000?o>b=Coc/SD00?oc/SD0_l0
000=omO6b@03o`000?oQgM7ohMgA00?ohMgA00?o0000onkO`Ol000002Oo^gl42o`0000?ohnV200?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`13
ooooo`05o`000?l05Ico01FLo`0EW?l000001ol/CL400ol0003oIVNoo`00000AogImc@04o`000?n?
QlKo0000o`0001;oUIGA00?o0000ojBKcOnTVld01onTVld4o`0000KoY9_=00?o0000ok2Tbon`Y</0
1on`Y</=o`0000oo^jg<00?o0000olFicoo5^Ll04_o5^Ll00ol0003oc/SDolk8e005olk8e003o`00
0?oGa/WoelK900WoelK900?o0000on7MdOoQgM401OoQgM400ol0003ok]o1o`000007onkO`@03o`00
0?o[n[_o000000;ohnV200?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`006?oo
ool2o`0004Gooooo00Co0000o`0EW?l05Ico00002?l/CL400ol0003oMWg=ogImc@0AogImc@03o`00
0?nEUM7oUIGA01;oUIGA00?o0000ojBKcOnTVld01?nTVld3o`0000SoY9_=3?l00009ojn/e@04o`00
0?ng]=Ko]kCFokNdePKo00002Onk[L`00ol0003oaKW?olFic`0AolFic`03o`000?o>b=Coc/SD00Oo
c/SD00?o0000omO6bOoGa/T02?oGa/T00ol0003ohMgAon7Md@05on7Md@04o`000?o^gl7ok]o1o`00
00Gok]o100Co0000on_j^oo[n[_o00000_oSjH800ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00[ooooo000Hooooo`03o`000?oooooooooo04Cooooo00?o0000o`0EW?l000002Ol/CL400om@
L]Go0000ogImc@0AogImc@03oh:@f?l0003oUIGA01?oUIGA00?o0000ojBKcOnTVld00ol00007ojBK
c@Co00000_nUY]L00ol0003o[jcEojn/e@0@ojn/e@03o`000?ng]=Ko]kCF00Oo]kCF1_l00003ok^]
c003o`000?o5^LooaKW?013oaKW?00?o0000olk8e?o>b=@02Oo>b=@00ol0003oelK9omO6b@06omO6
b@03o`000?oQgM7ohMgA00OohMgA00Co0000onkO`Oo^gl7o00001?o^gl400ol0003ojoZko`000003
on?YPP03o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool001Sooooo00?o0000oooo
ooooool0A?ooool3o`0000Wo;4g100?o0000oe1beOl000004?mfOLd01?l0003oPY3Hoh:@f?l0000C
oiFEd@?o00001OnTVld5o`0000KoYJKG00?o0000ojn/eOn_[=D04?n_[=D00ol0003o]kCFokNdeP0=
okNdeP?o00004_o5^Ll00ol0003oc/SDolk8e00;olk8e0;o00001OoGa/T00ol0003ohMgAon7Md@08
on7Md@05o`000?o^gl7ok]o1onkO`Ol000000_o^gl401?l0003ojoZkon_j^ol00003on?YPP03o`00
0?oooooooooo02gooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0A_oo
ool2o`0000Wo;4g100Co0000oe1beOm@L]Go00003_mfOLd00ol0003oPY3Hoh:@f002oh:@f003o`00
0?nEUM7oUIGA00coUIGA1?l000001?nEUM7o0000ojBKcOnTVld4o`0000coYJKG00?o0000ojn/eOn_
[=D03_n_[=D00ol0003o]kCFokNdeP0@okNdeP03o`000?no_MSo000000;o00003_o5^Ll00ol0003o
c/SDolk8e00=olk8e005o`000?oGa/WoelK9omO6bOl000003?oQgM401_l0003ok]o1onkO`Ol0003o
k]o1o`0000?ojoZk00Co0000on?YP_oSjH;o0000<?ooool00ol0003oooooooooo`0:ooooo`005ooo
ool00ol0003oooooooooo`16ooooo`;o00002?l/CL400ol0003oD7;Eoe1be@02oe1be@03o`000?mf
OLgoMWg=00[oMWg=00?o0000oh:@f?n2T=P01?n2T=P00ol0003oUIGAoiFEd@08oiFEd@?o00001OnE
UM43o`00013oYJKG00?o0000ojn/eOn_[=D03_n_[=D00ol0003o]kCFokNdeP0?okNdeP03o`000?no
_MSo_kgH00?o_kgH0_l0000;olFic`03o`000?o>b=Coc/SD00ooc/SD00?o0000omO6bOl000003OoQ
gM401?l0003ok]o1onkO`Oo^gl42o`0000?ojoZk00Co0000on?YP_oSjH;o0000<?ooool00ol0003o
ooooooooo`0:ooooo`005oooool00ol0003oooooooooo`17ooooo`03o`000?l/CL7o;4g100Ko;4g1
00?o0000oe1beOm@L]D00om@L]D00ol0003oMWg=ogImc@08ogImc@03o`000?n2T=SoPY3H00KoPY3H
00?o0000oiFEdOnEUM401?nEUM43o`0000KoUIGA0_l000000onIXM[o0000ojFVe`0@ojFVe`03o`00
0?n_[=Go[jcE00ko[jcE00?o0000okNde_ng]=H03ong]=H00ol0003o_kgHoknmf005oknmf0?o0000
1oo5^Ll00ol0003oc/SDolk8e00Aolk8e003o`000?oQgM7ohMgA00gohMgA00?o0000onkO`Oo^gl40
0_l00003on_j^`03o`000?oSjH;o000003;ooooo00?o0000ooooooooool02Oooool001Oooooo00?o
0000ooooooooool0Aoooool2o`0000Oo;4g100?o0000oe1beOm@L]D01?m@L]D00ol0003oMWg=ogIm
c@06ogImc@03o`000?n2T=SoPY3H00SoPY3H00?o0000oiFEdOnEUM400ol00007oiFEd@;o00001?nI
XMX00ol0003oYJKGojFVe`0>ojFVe`03o`000?n_[=Go[jcE00ko[jcE00?o0000okNde_ng]=H03_ng
]=H00ol0003o_kgHoknmf009oknmf0;o00001Oo5^Ll00ol0003oc/SDolk8e00@olk8e0;o00003ooQ
gM400ol0003ok]o1o`000002on_j^`06o`000?o[n[_ojoZko`000?oSjH;o0000<_ooool00ol0003o
ooooooooo`09ooooo`005oooool00ol0003oooooooooo`18ooooo`;o00001_l/CL400ol0003oD7;E
oe1be@05oe1be@03o`000?mfOLgoMWg=00GoMWg=00?o0000oh:@f?n2T=P01on2T=P4o`0000SoUIGA
0_l00007oiVQfP03o`000?nUY]OoYJKG00koYJKG00?o0000ojn/eOn_[=D03On_[=D00ol0003o]kCF
okNdeP0>okNdeP03o`000?no_MSo_kgH00_o_kgH0ol000000oo5^Loo0000olk8e00Aolk8e004o`00
0?oDf]coe=[Lo`0000oohMgA00?o0000on_j^oo[n[/00_o[n[/01?l0003ojoZko`000?l0000coooo
o`03o`000?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo04Sooooo00?o001@o`0KZ?l0
00001Ol/CL400ol0003oD7;Eoe1be@06oe1be@03o`000?mfOLgoMWg=00?oMWg=00?o0000oh:@f?n2
T=P01On2T=P3o`0000?oPY3H00?o0000oiFEdOnEUM401OnEUM400ol0003oVJ7JoiVQfP07oiVQfP03
o`000?nUY]OoYJKG00koYJKG00?o0000ojn/eOn_[=D03On_[=D00ol0003o]kCFokNdeP0=okNdeP03
o`000?no_MSo_kgH00oo_kgH00?o0000olk8e?o>b=@04?o>b=@01Ol0003oe=[LomCJg?oDf]co0000
00gohMgA00?o0000on7gf?l000001?o[n[/01?l0003ojoZko`000?l0000cooooo`03o`000?oooooo
oooo00Wooooo000Gooooo`;o0000B_ooool00ol0003o01^Xo`000004oba=`@03o`000?m@L]GoD7;E
00OoD7;E00Go0000ogImcOmfOLgoMWg=o`000005oh:@f0?o00001on2T=P00ol0003oUIGAoiFEd@02
oiFEd@;o00002onIXMX00ol0003oYJKGojFVe`0=ojFVe`03o`000?n_[=Go[jcE00go[jcE00?o0000
okNde_ng]=H03Ong]=H00ol0003o_kgHoknmf00>oknmf004o`000?o5bMgoaLWMo`0000ooc/SD00?o
0000omCJg?oDf]`00ooDf]`00ol0003ohMgAon7Md@09on7Md@04o`000?oQmmSohOOHo`0000GojoZk
00?o0000on?YP_l00000<oooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003ooooooooo
o`1:ooooo`03o`00D?l06jSo000000Co;4g100?o0000oe1beOm@L]D02?m@L]D00ol0003oMWg=o`00
0003oh:@f0?o00002on2T=P01?l0003oUIGAo`000?l0000>oiVQfP03o`000?nUY]OoYJKG00coYJKG
00?o0000ojn/eOn_[=D03?n_[=D00ol0003o]kCFokNdeP0=okNdeP03o`000?no_MSo_kgH00ko_kgH
00?o0000olG9gOo5bMd00_o5bMd00ol0003oc/SDolk8e00;olk8e003o`000?oDf]coe=[L00Coe=[L
00?o0000on7MdOoQgM402?oQgM401Ol0003ohOOHon7gf?oQmmSo000000GojoZk0_l0000dooooo`03
o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04_ooooo00?o0000o`0KZ?l00000
0_l/CL400ol0003oD7;Eoe1be@0:oe1be@Go00003on2T=P2o`0000ooVJ7J00?o0000ojFVeonUY]L0
3?nUY]L00ol0003o[jcEojn/e@0<ojn/e@03o`000?ng]=Ko]kCF00go]kCF00?o0000oknmf?no_MP0
3Ono_MP00ol0003oaLWMolG9g@04olG9g@;o00002_o>b=@00ol0003oe=[LomCJg006omCJg003o`00
0?oQgM7ohMgA00KohMgA00Go0000on7gf?oQmmSohOOHo`000006on_j^`?o0000<oooool00ol0003o
ooooooooo`09ooooo`005_ooool00ol0003oooooooooo`1;ooooo`06o`00D?l0003o01^Xo`000?l/
CL7o00002_m@L]D3o`000003ofV<hOl0003oPY3H013oPY3H00?o0000ohbOh?l000003onIXMX00ol0
003oYJKGojFVe`0<ojFVe`03o`000?n_[=Go[jcE00Co[jcE3?l0000:okNdeP03o`000?no_MSo_kgH
00go_kgH00?o0000olG9gOo5bMd01oo5bMd00ol0003oc/SDolk8e006olk8e003o`000?oDf]coe=[L
00Ooe=[L00?o0000on7MdOoQgM401OoQgM400ol0003ohOOHon7gf002on7gf003o`000?o[n[_ojoZk
00CojoZk00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0
003oooooooooo`1<ooooo`03o`000?l06jSo01^X00;o00001om@L]D3o`0000;oD7;E00Co0000ofV<
hOmYS>7o00003on2T=P01Ol0003oS9oPohbOh?n<Wn3o000000ooVJ7J00?o0000ojFVeonUY]L02OnU
Y]L9o`0000Oo[;CN00?o0000ok>jg_nc^]h00_nc^]h7o`0000?o]kCF00?o0000oknmf?no_MP03?no
_MP00ol0003oaLWMolG9g@09olG9g@;o00001Oo>b=@00ol0003oe=[LomCJg009omCJg003o`000?oQ
gM7ohMgA00?ohMgA00?o0000on7gf?oQmmP00ooQmmP00ol0003ojoZkon_j^`04on_j^`05o`000?oo
ooooooooooooool00000<_ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003ooooooooo
o`1<ooooo`04o`000?l06jSo01^Xo`0KZ0;o00000om@L]D3o`0000GoD7;E00Co0000ofV<hOmYS>7o
JHcQ0_l0000<oh:@f003o`000?n<Wn3oS9oP00?oS9oP00?o0000oiVQf_nIXMX03?nIXMX00ol0003o
YJKGojFVe`05ojFVe`Co00000_nU[ml00ol0003o[;CNojbdgP0;ojbdgP03o`000?nc^]ko/k[N00Wo
/k[N0ol0000>oknmf003o`000?o5bMgoaLWM00coaLWM00Go0000olk8e?o>b=Coc/SDo`00000<omCJ
g003o`000?oQgM7ohMgA00;ohMgA00?o0000on7gf?oQmmP01?oQmmP00ol0003ojoZkon_j^`03on_j
^`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08oooo
o`005_ooool00ol0003oooooooooo`1=ooooo`04o`000?l06jSo01^Xoa5NePCo00001om@L]D00ol0
003oJHcQofV<h@04ofV<h@03o`000?n2T=SoPY3H00SoPY3H00?o0000ohbOh?n<Wn001On<Wn000ol0
003oVJ7JoiVQfP0<oiVQfP03o`000?nUY]OoYJKG00Co00001onU[ml00ol0003o[;CNojbdgP0:ojbd
gP03o`000?nc^]ko/k[N00_o/k[N00?o0000okS1hOl000000_l00009oknmf003o`000?o5bMgoaLWM
00koaLWM00?o0000olk8e?l000003_oDf]`01?l0003ohMgAon7MdOl00007on7gf003o`000?o[n[_o
joZk00;ojoZk00?o0000ooooooooool01?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Sooooo000Eooooo`03o`000?oooooooooo04kooooo1?l00002oa5NeP03o`000?m@L]GoD7;E
00KoD7;E00?o0000ofV<hOmYS>401OmYS>400ol0003oPY3Hoh:@f006oh:@f003o`000?n<Wn3oS9oP
00OoS9oP00?o0000oiVQf_nIXMX02onIXMX3o`0000_oYJoO00?o0000ojbdg_n/]=h02_n/]=h00ol0
003o/k[Nok>jgP0:ok>jgP03o`000?nh`N7o^<7Q00?o^<7Q0ol00005oknmf003o`000?o5bMgoaLWM
013oaLWM00?o0000omCJg?oDf]`03OoDf]`00ol0003ohMgAo`000008on7gf005o`000?o[n[_ojoZk
on_j^ol000002?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo000Eoooo
o`?o0000C?ooool4o`0000;o01^X00Co0000oa5Ne_lAG]Ko00001om@L]D00ol0003oJHcQofV<h@06
ofV<h@;o00001On2T=P00ol0003oS9oPohbOh009ohbOh003o`000?nIXM[oVJ7J00SoVJ7J0_l00000
0onM[N;o0000ojF_g`0;ojF_g`03o`000?n/]=ko[;CN00[o[;CN00?o0000ok>jg_nc^]h02Onc^]h0
0ol0003o^<7QokS1h@07okS1h@?o000000?o_kgHo`000?o5bMd04?o5bMd00ol0003ob=KTo`00000@
omCJg003o`000?oQmmSohOOH00OohOOH00Co0000on_j^oo[n[_o00002_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Wooooo0ol00003
ooooo`05o`000?l06jSo01^Xo`0KZ?l000000_lAG]H2o`0000GoD7;E00?o0000ofV<hOmYS>402?mY
S>401Ol0003oPY3Hoh:@f?n2T=So000000goS9oP00?o0000oiVQf_nIXMX01OnIXMX2o`0000CoWJgR
00?o0000ojF_gonU[ml02_nU[ml00ol0003o[;CNojbdgP08ojbdgP03o`000?nc^]ko/k[N00[o/k[N
00?o0000okS1hOnh`N402_nh`N400ol0003oaLWMolG9g@0>olG9g@;o00000oo8e^@00ol0003oe=[L
omCJg00;omCJg003o`000?oCkNGo000000SohOOH00?o0000on_j^oo[n[/00_l0000;ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0AOoo
ool4o`0000Oooooo00Co0000o`0KZ?l06jSo00001?lAG]H00ol0003oD7;Eoe1be@02oe1be@03o`00
0?mYS>7oJHcQ00WoJHcQ00?o0000oh:@f?l000003on<Wn000ol0003oVJ7JoiVQfP02oiVQfP;o0000
1onM[N800ol0003oYJoOojF_g`09ojF_g`03o`000?n/]=ko[;CN00So[;CN00?o0000ok>jg_nc^]h0
2Onc^]h00ol0003o^<7QokS1h@0:okS1h@04o`000?nlbNCo_<WTo`0000coaLWM0_l00005olSFi003
o`000?oDf]coe=[L00Woe=[L0_l00002om?]i@03o`000?oQmmSohOOH00KohOOH00Co0000on_j^ol0
003o00003?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03
o`000?oooooooooo04;ooooo0ol0000;ooooo`05o`000?l06jSo01^Xo`0KZ?l000001?lAG]H01Ol0
003oD7;Eoe1beOm@L]Go000000coJHcQ0_l0000@ohbOh004o`000?nIXM[o0000o`0000[oWJgR00?o
0000ojF_gonU[ml02OnU[ml00ol0003o[;CNojbdgP07ojbdgP03o`000?nc^]ko/k[N00Wo/k[N00?o
0000okS1hOnh`N402Onh`N400ol0003o_<WTokc9i002okc9i003o`000?o5bMgoaLWM00SoaLWM00?o
0000olSFi?o8e^@01_o8e^@00ol0003oe=[LomCJg006omCJg0;o00001?oCkND00ol0003ohOOHon7g
f006on7gf0?o00003_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo000E
ooooo`03o`000?oooooooooo03oooooo0ol0000?ooooo`04o`000?l06jSo01^Xo`0000Go4EkF00?o
0000oe1beOl000003OmYS>42ogbNj0;o00003on<Wn02o`0000coWJgR00?o0000ojF_gonU[ml02?nU
[ml00ol0003o[;CNojbdgP07ojbdgP03o`000?nc^]ko/k[N00So/k[N00?o0000okS1hOnh`N402Onh
`N400ol0003o_<WTokc9i004okc9i0;o00001_o5bMd2o`0000Wob=KT00?o0000omCJg?oDf]`01OoD
f]`00ol0003odngUom?]i@03om?]i@03o`000?oQmmSohOOH00KohOOH0ol0000@ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0?Oooool3
o`0001?ooooo00?o0000o`0KZ?l000001_lAG]H00om@L]Go0000ofV<h@0<ofV<h@04o`000?mlW^So
O9kXogbNj0;o00003?n<Wn001?l0003oU:cWoiB/iol0000<oif]hP03o`000?nU[mooYJoO00OoYJoO
00?o0000ojbdg_n/]=h01on/]=h00ol0003o/k[Nok>jgP07ok>jgP03o`000?nh`N7o^<7Q00Wo^<7Q
00?o0000okc9i?nlbN@01onlbN@01?l0003oaLWMolG9gOo5bMd2o`0000_ob=KT00?o0000omCJg?oD
f]`00ooDf]`2o`0000KodngU00?o0000on7gf?oQmmP01OoQmmP01?l0003o^oc;o`000?l0000Aoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool0>Oooool4o`0001Oooooo00?o0000o`0KZ?l000001_lAG]H2o`0000_oJHcQ00?o0000ogbNj?ml
W^P01?mlW^P2o`0000WoS9oP00?o0000oiB/ionD[>L00_nD[>L00ol0003oWJgRoif]hP0:oif]hP03
o`000?nU[mooYJoO00GoYJoO4Ol00004ok>jgP03o`000?nh`N7o^<7Q00So^<7Q00?o0000okc9i?nl
bN@02OnlbN@00ol0003oaLWMo`00000>olSFi003o`000?oDf]coe=[L00;o00002?oCkND00ol0003o
hOOHon7gf004on7gf004o`000?nko<_o0000o`0001?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0fooooo`?o00007?ooool2o`0000Ko
4EkF00Co0000odJ7jOl0003o00002OmYS>400ol0003oO9kXogbNj006ogbNj003o`000?n<Wn3oS9oP
00GoS9oP00?o0000oiB/ionD[>L01?nD[>L2o`0000_oWJgR00?o0000ojF_gonU[ml01?l00002ojFi
i`03o`000?nY^nKoZK_V00KoZK_V00?o0000ojfoion]_nL00on]_nL5o`0000Wo^<7Q00?o0000okc9
i?nlbN@02onlbN@00ol0003ob=KTolSFi00=olSFi003o`000?oDf]co000000[odngU00?o0000on7g
f?oQmmP00_oQmmP2o`000003ok_lbol0003o000001Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Pooooo`03o`0KZ?l0003o4EkF00Go
4EkF00?o0000odJ7jOm6QnT00_l00007ofV<h@03o`000?mlW^SoO9kX00OoO9kX0_l00004ohbOh003
o`000?nD[>OoU:cW00OoU:cW00?o0000oif]h_nM[N802?nM[N83o`0000OoYKWW00?o0000ojVki_nY
^nH01OnY^nH00ol0003o[KoWojfoi`06ojfoi`03o`000?n``nSo000000;o00001Onh`N400ol0003o
_<WTokc9i009okc9i0;o000000?o_M7Yo`000?o8e^@03oo8e^@00ol0003odngUom?]i@09om?]i@05
o`000?oQmmSohOOHon7gf?l000000_nko</2o`0001Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00009?ooool00ol0003o
4EkFoa5NeP04oa5NeP03o`000?m6QnWoAXOY00;oAXOY0_l00005ofV<h@03o`000?mlW^SoO9kX00Wo
O9kX0_l000000on<Wn3o0000oiB/i`0:oiB/i`;o00001_nM[N82o`000003oingjOl0003oYKWW00Oo
YKWW00?o0000ojVki_nY^nH01OnY^nH00ol0003o[KoWojfoi`05ojfoi`03o`000?n``nSo/<?X00?o
/<?X0ol000000onh`N7o0000okc9i00:okc9i003o`000?nmdNWo_M7Y00;o_M7Y00?o0000olSFi?o8
e^@02_o8e^@2o`000003olKSk?l0003odngU00[odngU00Co0000on7gf?l0003o00000_nko</2o`00
01Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool4o`0002Sooooo0_l00005oa5NeP03
o`000?m6QnWoAXOY00?oAXOY0_l00003ofV<h@03o`000?mlW^SoO9kX00_oO9kX0_l0000=oiB/i`03
o`000?nM[N;oWJgR00;oWJgR00?o0000oingjOnO]nT00_nO]nT00ol0003oYKWWojFii`05ojFii`03
o`000?nY^nKoZK_V00GoZK_V00?o0000ojfoion]_nL01?n]_nL00ol0003o/<?Xok33j007ok33j003
o`000?nlbNCo_<WT00So_<WT0_l00005okgAj@03o`000?o8e^Cob=KT00Sob=KT0_l00003olKSk003
o`000?oCkNGodngU00SodngU00?o0000on7gf?l000000onko</2o`0001[ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02[ooooo0ol0000^ooooo`03o`000?lAG]Ko4EkF00;o4EkF00?o0000odJ7jOm6QnT0
1Om6QnT00ol0003oJHcQo`00000>ogbNj004o`000?n:[>go0000o`0000coU:cW00Co0000oif]h_l0
003o00001_nO]nT00ol0003oYKWWojFii`05ojFii`03o`000?nY^nKoZK_V00?oZK_V00?o0000ojfo
ion]_nL01On]_nL00ol0003o/<?Xok33j006ok33j0?o//SZ00?o0000okc9i?nlbN@01?nlbN@2o`00
00So_M7Y00?o0000olSFi?o8e^@01?o8e^@3o`0000Goa^?/00?o0000om?]iOoCkND02?oCkND2o`00
00Co^oc;00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0003;o
oooo0_l00003oa5NeP03o`000?m6QnWoAXOY00KoAXOY0_l0000=ogbNj004o`000?n:[>goRZc]ohZ/
k@;o00002onD[>L2o`0000SoWkOY00?o0000ojFiionU^NL01?nU^NL00ol0003oZK_VojVkiP03ojVk
iP03o`000?n]_nOo[KoW00Co[KoW00?o0000ok33j?n``nP01?n``nP2o`0000Go//SZ00?o0000okc9
i?nlbN@00_nlbN@00ol0003o_M7YokgAj@09okgAj@04o`000?o8e^Cob=KTolSFi0;o00002?o6hn`0
0ol0003odngUom?]i@07om?]i@;o00001?nko</00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Tooooo`?o0000=_ooool01Ol0?;?o0000oa5Ne_lAG]Ko000000SoAXOY00?o0000
ofROl?l000000_l00009ogbNj003o`000?n:[>goRZc]00CoRZc]0ol00007oiB/i`03o`000?nJ]nco
V[O/00;o00001onO]nT00ol0003oYKWWojFii`03ojFii`03o`000?nY^nKoZK_V00?oZK_V00?o0000
ojfoion]_nL00on]_nL00ol0003o/<?Xok33j004ok33j003o`000?nbb>[o//SZ00Ko//SZ00Co0000
okc9i?l0003o00003?nmdNT01?l0003ob=KTo`000?l00009olKSk003o`000?oCkNGodngU00GodngU
0ol000000oo1n^[o0000ok_lb`02ok_lb`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo023ooooo1?l0000jooooo`04o`0l/ol0003o4EkFo`0000WoAXOY00Co0000ofROl?mXWo3o
J9o`0ol00006ogbNj003o`000?n:[>goRZc]00OoRZc]0_l00004oiB/i`03o`000?nJ]ncoV[O/00?o
V[O/0_l00006oingj@03o`000?nU^NOoYKWW00?oYKWW00?o0000ojVki_nY^nH00_nY^nH00ol0003o
[KoWojfoi`03ojfoi`03o`000?n``nSo/<?X00?o/<?X00?o0000ok;8j_nbb>X02?nbb>X00ol0003o
_M7YokgAj@0=okgAj@03o`000?o6hncoa^?/00Woa^?/00?o0000om?]iOoCkND00ooCkND2o`0000?o
`O[Z00Go0000ok_lbonko<_o^oc;o`00000Qooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`?o
0000?oooool2o`000003oa5Ne_l0003oAXOY00OoAXOY00?o0000ofROl?mXWo001?mXWo02o`0000Co
O9kX00?o0000ohZ/kOn:[>d02On:[>d2o`000003oiB/iol0003oV[O/00OoV[O/00?o0000oingjOnO
]nT01?nO]nT00ol0003oYKWWojFii`0:o`0000;o[KoW00?o0000ok33j?n``nP00_n``nP2o`0000Wo
//SZ00?o0000ok;=k_l000002_nmdNT3o`0000;o^m[`00?o0000olKSk?o6hn`02Oo6hn`01?l0003o
dngUom?]iOoCkND2o`0000Co`O[Z00Go0000ok_lbonko<_o^oc;o`00000Sooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Jooooo`?o0000@oooool00ol0003o03bco`000008odJ7j@03o`000?mXWo3oJ9o`
00KoJ9o`0_l000000omlW^So0000ohZ/k@0=ohZ/k@?o00002?nJ]n`2o`0000CoWkOY0ol00002oj?1
kP03o`000?nU`^koYL;^00;oYL;^00?o0000ojK3k_nV`nh01?l00002ok33j003o`000?nbb>[o//SZ
00Go//SZ0_l00005ok;=kP03o`000?nmdNWo_M7Y00Co_M7Y0ol00005ok_Jl003o`000?o6hncoa^?/
00Woa^?/1?l00005ol7jjP03o`000?nko<_o^oc;00;o00009Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o
0000Aoooool01?l0003o03bco`000?l00007odJ7j@03o`000?mXWo3oJ9o`00SoJ9o`0ol0000<ohZ/
k@03o`000?nE^>ooUKS_00?o00001onJ]n`2o`000003oingjOl0003oXL7_00;oXL7_00Co0000oj?1
k_nS`Nko00000onU`^h01Ol0003oY/?^ojK3k_nV`nko000000;oYlG_0_l00006ok;8jP;o00002?nb
cNh00ol0003o_M7YokgAj@03o`0000So^m[`00?o0000olKSk?o6hn`02Oo6hn`00ol0003o`O[Zol7j
jP05ol7jjP04o`000?nko<_o^oc;o`0002Sooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`06ooooo`004_ooool00ol0003oooooooooo`0Dooooo`Co0000Boooool00ol0003o03bco`0l
/`02o`0000GoAXOY00?o0000ofROl?mXWo002?mXWo000ol0003oP:ocoh2_l`05o`0000OoRZc]00?o
0000oiFhkonE^>l00onE^>l3o`0000KoV[O/0_l00004oj71k`03o`000?nS`Nko000000?oYL;^00Co
0000ojK3k_nV`nko00000_nWaNl01_l0003oZ<K`ojS6l?nXa_3o0000ok;8jP?o00002onbcNh2o`00
00_o^m[`00?o0000olKSk?o6hn`01Oo6hn`3o`000003ok_]m?l0003o`O[Z00Ko`O[Z0ol0000Yoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooooooo
ool04Oooool3o`00053ooooo00?o0000o`0l/ol0?;<01?l00003odJ7j@03o`000?mXWo3oJ9o`00So
J9o`00?o0000oh2_lon0[o<01?n0[o<5o`000003ohZ/kOl0003oUKS_00SoUKS_0ol00002oiZgk003
o`000?nO`O3oWl7`00;o00000onQ`Nl00ol0003oXl7^o`000002ojG2kP04o`000?nV`nko0000ojO5
k`;o00001?nXa_02o`0000Oo//g^1Ol00002ok3Al@03o`000?nkf_3o^m[`00[o^m[`00?o0000olKS
k?o6hn`00_o6hn`3o`0000?o^ngd00?o0000ol7jj_o1n^X01Oo1n^X2o`0002cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o
0000E?ooool01?l0003o03bco`0l/ol00002oaR0i`;o000000?oAXOYo`000?mXWo002OmXWo000ol0
003oP:ocoh2_l`09oh2_l`Go00002OnE^>l4o`0000?oWl7`0ol000002OnQ`Noo0000o`000?nU`^ko
0000ojK3k_l0003oYlG_o`000003ojS6l0?o000000CoYlSao`000?nbcNko//g^1Ol00007ok3Al@03
o`000?nkf_3o^m[`00[o^m[`00?o0000olKSk?l000000_l00005ok_]m003o`000?o1n^[o`O[Z00Go
`O[Z0_l0000^ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo
00?o0000ooooooooool02oooool3o`0005Sooooo00Co0000o`0l/ol0?;?o00000olHP>L2o`0000_o
J9o`00?o0000oh2_lon0[o<02On0[o<01?l0003oT;[coi2jlon@^_<7o`0000?oUKS_00?o0000oik1
lOnN`O401Ol000000onO`O3o0000o`000003o`000004ojK3k_l0003o0000ojS6l0?o00000_nWb?45
o`0000_o/=7a00?o0000ok_Jl?nkf_002?nkf_02o`000003ok_Jl?l0003o000000So^ngd00?o0000
ol7jj_o1n^X01?o1n^X00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01Oooool001;ooooo00?o0000ooooooooool01oooool4o`0005cooooo0_l000000ol0
?;?o0000oaR0i`03oaR0i`Co00001omXWo000ol0003oP:ocoh2_l`0:oh2_l`03o`000?n@^_?oT;[c
00OoT;[c2_l000000onN`O7o0000o`00000=o`0000?oYlWb00?o0000ok3AlOn`dO402_n`dO401?l0
003o^m[`ok_Jl?nkf_07o`0000?o/n3f00?o0000ok_]m?nkkO@01_nkkO@00ol0003o`O[Zol7jjP03
ol7jjP;o0000<oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Boooo
o`03o`000?oooooooooo00Cooooo0ol0001Rooooo`03o`000?l0?;?o000000Go683W0_mCXoH6o`00
0003ofROl?l0003oP:oc00_oP:oc00?o0000oi2jlon@^_<02On@^_<00ol0003oW<;boic2lP05oic2
lQko00000_n`dO44o`0000Wo/n3f00?o0000ok_]m?nkkO@01_nkkO@01?l0003o`O[Zol7jj_o1n^X3
o`0003Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0
003oooooooooo`02ooooo`?o0000I_ooool3o`0000Go683W00?o0000oe>Sm_mCXoH01?mCXoH:o`00
00CoP:oc00?o0000oi2jlon@^_<01?n@^_<5o`000003oi2jlol0003o000000[o000000?oW<Oeo`00
0?l000002?l00003ojG:l`03o`000?n/e?Go[=Ce00[o[=Ce00?o0000ok?Pm_nch?H02Onch?H00ol0
003o^ngdok_]m007ok_]m003o`000?o1n^[o000000;o0000>?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooo000000;o0000Joooool2o`0000Go
683W0_l00008oe>SmP03o`000?mf]?WoM[Ci00?oM[Ci2ol00007ohfnm`03o`000?nL`oCoW<?d00?o
00000_nLaO@2o`000006oic7mOl0003o0000oio9m_l0003oXL[e0ol00003oj?;m0Ko00002On/e?D0
0ol0003o/n3fok?PmP09ok?PmP03o`000?nkkOCo^ngd00Oo^ngd1Ol0000jooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01?ooool0017ooooo0_l0001`ooooo`03o`000?lHP>Oo683W
00Co683W00?o0000oe>Sm_mCXoH01_mCXoH00ol0003oM[CiogJdn@08ogJdn@03o`000?n=__OoSKkg
00[oSKkg0_l00004oic5m004o`000?nLaoGoW<Oeoic7m@;o00000_nObOH01?l0003oXL[eoj7:mOnQ
b_D2o`000003oj?;m?l0003oY]Kh00CoY]Kh1?l00004ojcDm@03o`000?nch?Ko/n3f00Wo/n3f00?o
0000ok_]m?nkkO@00_nkkO@6o`000003oho_gOl0003o000003gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`04ooooo`004oooool00ol0003oooooooooo`1^ooooo`?o00001?lHP>L0
0ol0003oDj?foe>SmP06oe>SmP03o`000?mf]?WoM[Ci00SoM[Ci00?o0000ohfnmon=__L01?n=__L3
o`0000CoRl;j0_l000000onLaOCo0000oic7m@02oic7m@04o`000?nMb?KoWLSfo`0000;oWlWf00?o
0000oj7:mOnQb_D01Ol00009ojKFn1Co00000_nSkoL2o`000003oho_gOl0003o0000043ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`005?ooool2o`00073ooooo00?o07C?
o`000?l000001?l00008oe>SmP03o`000?mf]?WoM[Ci00SoM[Ci00?o0000ohfnmon=__L00ol00009
oh_2nP?o00000_nLaoD01Ol0003oWLSfoig8m_l0003oWlWf00Co00001OnNe?/3o`0000GoY]Kh0_l0
000:ojORn`;o00001onSkoL2o`0000;oSnoM00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`000?oooooo000006oooooo00Co0000
o`1dcol0M<oo07C?1ol00003oe>SmP03o`000?mf]?WoM[Ci00?oM[Ci1?l000000omf]?Wo0000o`00
0009oh_2nP;o00001?n<b?`7o`0000?oU]7l00?o0000oikDnonNe?/01_nNe?/2o`0000;oY]Kh00?o
0000ojORnonWh_/02?nWh_/2o`0000SoXnog00?o0000oho_gOn?kmd00_l00014ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01?ooool001Oooooo0_l0001booooo`05o`000?l0M<oo
07C?o`1dcol000000om0YoH9o`0000OoL;_m0_l00005oh_2nP;o00001on<b?`01Ol0003oT<gloi3=
o?n@cOco000000GoU]7l00?o0000oikDnonNe?/01onNe?/4o`0000SoYn;k00?o0000oj?_monSkoL0
1_nSkoL5o`0004Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`006?oo
ool2o`0007?ooooo0_l00002o`1dc`;o00001_m0YoH3o`0000WoL;_m0_l000000on;`_[o0000o`00
0008ohc8o003o`000?n@cOcoT<gl00;oT<gl00?o0000oiKAo?nFdO`01?nFdO`00ol0003oW]CkoikD
n`03oikDn`?o00001?nFgoh4o`0000;oYn;k0_l00007oj?_m`Go0000B_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo07;ooooo0_l00002
o`1dc`?o00001_m0YoH2o`0000WoL;_m00?o0000ohc8o?l000001on<b?`00ol0003oT<gloi3=o004
oi3=o003o`000?nFdOcoU]7l00CoU]7l00?o0000oikDnol000000_l0000;oiKOoPgo0000C_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`00
0?ooool0LOooool3o`0000;o07C?0_l00006od2WmP?o00000_m`^od3o`0000CoKlCo1?l00002ohc8
o003o`000?n@cOcoT<gl00GoT<gl00Co0000oiKAo?nFdOcoU]7l1_l0000:oiKOoP?o00001_moho@4
o`0005;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007Oooool2o`00
07;ooooo00?o0000ooooooooool00ol000000ol0M<oo0000o`000004od2WmP;o000000?o@:Ofo`00
0?l000002om_a?l>o`0000KoQ=So0_l00006oiKOoP;o00001_moho@4o`0005Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`03ooooo`007_ooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo00?ooooo1ol00006ocN_l0Co00001_m_a?l00ol0003oM/koogK>o`07ogK>o`03
o`000?n4f?ooQ=So00WoQ=So0_l000001?nFgoko0000o`000?l00005ogoSm0Co0000FOooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003o
ooooooooo`08ooooo`04o`000?lY003o0000o`0000So=jo`0ol00002ofo4o`03o`000?mfc_ooM/ko
00WoM/ko00?o0000ohCHoon4f?l01?n4f?l9o`0000?oOn?d1?l0001Mooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003o
ooooooooo`0=ooooo`03o`000?lY003o000000Co00000olg[o02o`000003ogK>ool0003o0000013o
00001_mIcnh7o`00067ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`00
8_ooool3o`0006cooooo00?o0000ooooooooool04_ooool00ol0003o:@00o`000002o`0000Ko?kc/
0_l00006ocnlk003o`000?mIcnkoFLo^00;oFLo^2?l0001Yooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0J_ooool00ol0003ooooooooo
o`0Nooooo`03oal00?l0003o000000[o0000LOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo000Uooooo`;o0000J_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`2Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool002So
oooo00?o0000ooooool00000I_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04ooooo`;o0000
I_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
0_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo0:3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Oooool6
o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool03?ooool2o`00063o
oooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007o
oooo000Pooooo`03o`000?oooooooooo00gooooo0_l0001Oooooo`03o`000?oooooooooo0:?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0YOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo007ooooo000Nooooo`03oeEEEOmVIVKo000001;ooooo0_l00000
0ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wooooo00?o0000ooooooooool0Y_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000fooooo`;o0000F?ooool00ol0003o
ooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003Sooooo
00Go0000ooooooooooooooooo`00001Cooooo`03o`000?oooooooooo0:Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`01ooooo`00>Oooool01?l0003oooooooooool0001Cooooo`03
o`000?oooooooooo0:Wooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool003[ooooo
0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool02?ooool1o`00007ooooo
0Oooool003cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Zooooo`03o`000?oo
oooooooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o0000DOooool00ol0003oooooooooo`2[
ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo000oooooo`03o`000?oooooo0000
04kooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00@?ooool2o`0004kooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`05ooooo`7o
00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o0000ooooooooool0[_ooool00ol0003ooooo
ooooo`04ooooo`7o00000Oooool1ooooo`00@oooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0014ooooo`;o000000?ooooo
o`000?ooool0Aoooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`00A_ooool2o`0004Sooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`03oooo
o`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4
A4Co0000o`000?lb<S82o`0004Oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`02
ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool0
1?mgMgOo<S8booooool00016ooooo`03o`000?oooooooooo0;;ooooo00Go0000oooooooooooooooo
o`000001ooooo`00:_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00?o0000@oooool00ol0003oooooooooo`2cooooo`04o`000?ooooooooooo`00007o
oooo000booooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001oooo
o`00<_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`01
o`000000<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool02?ooool2
o`00043ooooo00?o0000ooooooooool0]Oooool1o`00007ooooo0Ol0000003;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0_l0000nooooo`03o`000?oooooo
oooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00002_ooool2
o`0003gooooo00?o0000ooooooooool0]Oooool3o`000000Doooool01Ol0003ooooooooooooooooo
000003Sooooo00?o0000ooooooooool0/?ooool5o`0000?ooooo001Dooooo`04o`000?oooooooooo
o`0003Sooooo00?o0000ooooooooool0[?ooool4o`0000Sooooo001Eooooo`?o0000>?ooool00ol0
003oooooooooo`2Xooooo`Co00003?ooool005Oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0000eooooo`03o`000?oooooooooo0:3ooooo
1?l0000Eooooo`00F_ooool00ol0003oooooo`00000booooo`03o`000?oooooooooo09cooooo1?l0
000Iooooo`00Foooool2o`0003;ooooo00?o0000ooooooooool0Uoooool5o`0001gooooo001Moooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Toooool4o`0002;ooooo001Nooooo`04
o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0S_ooool5o`0002Kooooo001Oooooo`?o
0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000:oooool0067ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`26ooooo`Co0000;oooool005?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0:ooooo`;o0000:oooool00ol0003oooooooooo`21ooooo`Go0000<oooool005?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo000002Sooooo00?o0000ooooooooool0
OOooool4o`0003Sooooo001Cooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`0002Sooooo
00?o0000ooooooooool0NOooool4o`0003cooooo001Cooooo`05o`000?ooooooooooooooool00000
3oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1Ol00010ooooo`00Dooo
ool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo00008oooool00ol0003o
ooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go410@oooooooooooooooooa0@400Aooooo`?o
00008oooool00ol0003oooooooooo`1[ooooo`Go0000BOooool005?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Booooo`;o00008oooool00ol0003oooooooooo`1Wooooo`Co0000C_ooool005?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?oooooo`000?ooool07_ooool00ol0003o
ooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0000Oooooo`03o`000?oooooooooo05kooooo
1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05[ooooo1?l0
001Kooooo`00L?ooool2o`0001gooooo00?o0000ooooooooool0E_ooool4o`0005oooooo001boooo
o`03o`000?oooooo000001[ooooo00?o0000ooooooooool0DOooool5o`0006?ooooo001cooooo`;o
00006_ooool00ol0003oooooooooo`1=ooooo`Co0000J?ooool007Gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`19ooooo`Co0000K?ooool007Kooooo0_l000000ooooooo0000oooo
o`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`ooooo`00N?ooool2o`0001Gooooo00?o0000
ooooooooool0@?ooool4o`0007Gooooo001iooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0>oooool5o`0007Wooooo001jooooo`;o000000?oooooo`000?ooool04?ooool00ol0003o
ooooooooo`0gooooo`Co0000O_ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0_l0000Aooooo`03o`000?oooooooooo
03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo1Ol00026oooo
o`00Hoooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo1?l0002;ooooo`00Hoooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool3o`0000_ooooo00?o0000oooo
ooooool09oooool4o`0008oooooo001Sooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0R
ooooo`Go0000Toooool006?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00cooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Nooooo`Co0000V?oo
ool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00gooooo0ol0
0007ooooo`03o`000?oooooooooo01Wooooo1Ol0002Looooo`00Hoooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000YOooool0
08Wooooo0_l00003ooooo`03o`000?oooooooooo00cooooo1Ol0002Yooooo`00R_ooool01Ol0003o
oooooooooooooooo000000[ooooo1?l0002^ooooo`00Roooool2o`000003ooooool0003ooooo00Go
oooo1?l0002booooo`00SOooool2o`000003ooooool0003o000000?o0000]_ooool008kooooo0_l0
002kooooo`00oooooom<ooooo`00oooooom<ooooo`00Q?ooool4o`000003oa0@4?oooooooooo0<3o
oooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026
ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03
o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0024ooooo`03oeEEEOmV
IVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48205 .55242 m .47484 .5927 L .5437 .59604 L p .717 .612 .738 r
F P
0 g
s
.5437 .59604 m .54127 .55536 L .48205 .55242 L p .717 .612 .738 r
F P
0 g
s
.54574 .6381 m .5437 .59604 L .47484 .5927 L p .72 .585 .704 r
F P
0 g
s
.54127 .55536 m .5437 .59604 L .61109 .58603 L p .673 .578 .74 r
F P
0 g
s
.5437 .59604 m .54574 .6381 L .62108 .6272 L p .668 .545 .705 r
F P
0 g
s
.62108 .6272 m .61109 .58603 L .5437 .59604 L p .668 .545 .705 r
F P
0 g
s
.47484 .5927 m .4688 .63448 L .54574 .6381 L p .72 .585 .704 r
F P
0 g
s
.54727 .68022 m .54574 .6381 L .4688 .63448 L p .72 .555 .665 r
F P
0 g
s
.54574 .6381 m .54727 .68022 L .62861 .66876 L p .661 .509 .666 r
F P
0 g
s
.62861 .66876 m .62108 .6272 L .54574 .6381 L p .661 .509 .666 r
F P
0 g
s
.42676 .53794 m .41038 .57624 L .47484 .5927 L p .759 .652 .744 r
F P
0 g
s
.47484 .5927 m .48205 .55242 L .42676 .53794 L p .759 .652 .744 r
F P
0 g
s
.4688 .63448 m .47484 .5927 L .41038 .57624 L p .768 .631 .709 r
F P
0 g
s
.41038 .57624 m .39662 .61652 L .4688 .63448 L p .768 .631 .709 r
F P
0 g
s
.46425 .67641 m .4688 .63448 L .39662 .61652 L p .776 .606 .669 r
F P
0 g
s
.4688 .63448 m .46425 .67641 L .54727 .68022 L p .72 .555 .665 r
F P
0 g
s
.4901 .51458 m .48205 .55242 L .54127 .55536 L p .713 .636 .77 r
F P
0 g
s
.54127 .55536 m .53856 .51704 L .4901 .51458 L p .713 .636 .77 r
F P
0 g
s
.53856 .51704 m .54127 .55536 L .59917 .54655 L p .676 .608 .772 r
F P
0 g
s
.61109 .58603 m .59917 .54655 L .54127 .55536 L p .673 .578 .74 r
F P
0 g
s
.5482 .72076 m .54727 .68022 L .46425 .67641 L p .718 .52 .62 r
F P
0 g
s
.54727 .68022 m .5482 .72076 L .63316 .7091 L p .652 .467 .621 r
F P
0 g
s
.63316 .7091 m .62861 .66876 L .54727 .68022 L p .652 .467 .621 r
F P
0 g
s
.44499 .50248 m .42676 .53794 L .48205 .55242 L p .747 .671 .776 r
F P
0 g
s
.48205 .55242 m .4901 .51458 L .44499 .50248 L p .747 .671 .776 r
F P
0 g
s
.59917 .54655 m .61109 .58603 L .67113 .56331 L p .623 .548 .749 r
F P
0 g
s
.61109 .58603 m .62108 .6272 L .68847 .60239 L p .61 .508 .713 r
F P
0 g
s
.68847 .60239 m .67113 .56331 L .61109 .58603 L p .61 .508 .713 r
F P
0 g
s
.39662 .61652 m .38625 .65752 L .46425 .67641 L p .776 .606 .669 r
F P
0 g
s
.4615 .71688 m .46425 .67641 L .38625 .65752 L p .781 .575 .621 r
F P
0 g
s
.46425 .67641 m .4615 .71688 L .5482 .72076 L p .718 .52 .62 r
F P
0 g
s
.62108 .6272 m .62861 .66876 L .70156 .64264 L p .593 .463 .672 r
F P
0 g
s
.70156 .64264 m .68847 .60239 L .62108 .6272 L p .593 .463 .672 r
F P
0 g
s
.59917 .54655 m .58589 .50967 L .53856 .51704 L p .676 .608 .772 r
F P
0 g
s
.58589 .50967 m .59917 .54655 L .65054 .5266 L p .635 .585 .781 r
F P
0 g
s
.67113 .56331 m .65054 .5266 L .59917 .54655 L p .623 .548 .749 r
F P
0 g
s
.49871 .47969 m .4901 .51458 L .53856 .51704 L p .707 .659 .8 r
F P
0 g
s
.53856 .51704 m .53565 .48161 L .49871 .47969 L p .707 .659 .8 r
F P
0 g
s
.53565 .48161 m .53856 .51704 L .58589 .50967 L p .677 .637 .802 r
F P
0 g
s
.46442 .4703 m .44499 .50248 L .4901 .51458 L p .734 .687 .805 r
F P
0 g
s
.4901 .51458 m .49871 .47969 L .46442 .4703 L p .734 .687 .805 r
F P
0 g
s
.62861 .66876 m .63316 .7091 L .7095 .68249 L p .573 .409 .622 r
F P
0 g
s
.7095 .68249 m .70156 .64264 L .62861 .66876 L p .573 .409 .622 r
F P
0 g
s
.38053 .51294 m .35614 .54771 L .41038 .57624 L p .799 .701 .757 r
F P
0 g
s
.41038 .57624 m .42676 .53794 L .38053 .51294 L p .799 .701 .757 r
F P
0 g
s
.39662 .61652 m .41038 .57624 L .35614 .54771 L p .817 .686 .72 r
F P
0 g
s
.54845 .75801 m .5482 .72076 L .4615 .71688 L p .713 .476 .565 r
F P
0 g
s
.5482 .72076 m .54845 .75801 L .6344 .7465 L p .638 .415 .564 r
F P
0 g
s
.6344 .7465 m .63316 .7091 L .5482 .72076 L p .638 .415 .564 r
F P
0 g
s
.40754 .48169 m .38053 .51294 L .42676 .53794 L p .779 .712 .789 r
F P
0 g
s
.42676 .53794 m .44499 .50248 L .40754 .48169 L p .779 .712 .789 r
F P
0 g
s
.58589 .50967 m .5717 .47588 L .53565 .48161 L p .677 .637 .802 r
F P
0 g
s
.5717 .47588 m .58589 .50967 L .62767 .49304 L p .645 .62 .81 r
F P
0 g
s
.65054 .5266 m .62767 .49304 L .58589 .50967 L p .635 .585 .781 r
F P
0 g
s
.35614 .54771 m .33555 .58531 L .39662 .61652 L p .817 .686 .72 r
F P
0 g
s
.38625 .65752 m .39662 .61652 L .33555 .58531 L p .833 .667 .677 r
F P
0 g
s
.38625 .65752 m .37996 .69766 L .4615 .71688 L p .781 .575 .621 r
F P
0 g
s
.46076 .75418 m .4615 .71688 L .37996 .69766 L p .784 .536 .562 r
F P
0 g
s
.4615 .71688 m .46076 .75418 L .54845 .75801 L p .713 .476 .565 r
F P
0 g
s
.43618 .45423 m .40754 .48169 L .44499 .50248 L p .758 .72 .817 r
F P
0 g
s
.44499 .50248 m .46442 .4703 L .43618 .45423 L p .758 .72 .817 r
F P
0 g
s
.50767 .44789 m .49871 .47969 L .53565 .48161 L p .7 .681 .829 r
F P
0 g
s
.53565 .48161 m .53262 .44921 L .50767 .44789 L p .7 .681 .829 r
F P
0 g
s
.53262 .44921 m .53565 .48161 L .5717 .47588 L p .677 .665 .83 r
F P
0 g
s
.33555 .58531 m .31999 .62461 L .38625 .65752 L p .833 .667 .677 r
F P
0 g
s
.37996 .69766 m .38625 .65752 L .31999 .62461 L p .847 .64 .623 r
F P
0 g
s
.48459 .44145 m .46442 .4703 L .49871 .47969 L p .719 .702 .833 r
F P
0 g
s
.49871 .47969 m .50767 .44789 L .48459 .44145 L p .719 .702 .833 r
F P
0 g
s
.65054 .5266 m .67113 .56331 L .71811 .52943 L p .565 .523 .767 r
F P
0 g
s
.67113 .56331 m .68847 .60239 L .74159 .56525 L p .538 .472 .729 r
F P
0 g
s
.74159 .56525 m .71811 .52943 L .67113 .56331 L p .538 .472 .729 r
F P
0 g
s
.63316 .7091 m .6344 .7465 L .71166 .72023 L p .545 .343 .558 r
F P
0 g
s
.71166 .72023 m .7095 .68249 L .63316 .7091 L p .545 .343 .558 r
F P
0 g
s
.62767 .49304 m .65054 .5266 L .69037 .49698 L p .589 .569 .799 r
F P
0 g
s
.71811 .52943 m .69037 .49698 L .65054 .5266 L p .565 .523 .767 r
F P
0 g
s
.5717 .47588 m .55694 .44527 L .53262 .44921 L p .677 .665 .83 r
F P
0 g
s
.55694 .44527 m .5717 .47588 L .60336 .46299 L p .653 .653 .837 r
F P
0 g
s
.62767 .49304 m .60336 .46299 L .5717 .47588 L p .645 .62 .81 r
F P
0 g
s
.68847 .60239 m .70156 .64264 L .75939 .6034 L p .505 .411 .683 r
F P
0 g
s
.75939 .6034 m .74159 .56525 L .68847 .60239 L p .505 .411 .683 r
F P
0 g
s
.60336 .46299 m .62767 .49304 L .65974 .46848 L p .61 .61 .826 r
F P
0 g
s
.69037 .49698 m .65974 .46848 L .62767 .49304 L p .589 .569 .799 r
F P
0 g
s
.54799 .7903 m .54845 .75801 L .46076 .75418 L p .701 .418 .491 r
F P
0 g
s
.54845 .75801 m .54799 .7903 L .63215 .77928 L p .615 .347 .488 r
F P
0 g
s
.63215 .77928 m .6344 .7465 L .54845 .75801 L p .615 .347 .488 r
F P
0 g
s
.46572 .43047 m .43618 .45423 L .46442 .4703 L p .736 .727 .843 r
F P
0 g
s
.46442 .4703 m .48459 .44145 L .46572 .43047 L p .736 .727 .843 r
F P
0 g
s
.37996 .69766 m .37825 .7352 L .46076 .75418 L p .784 .536 .562 r
F P
0 g
s
.46211 .78663 m .46076 .75418 L .37825 .7352 L p .78 .481 .482 r
F P
0 g
s
.46076 .75418 m .46211 .78663 L .54799 .7903 L p .701 .418 .491 r
F P
0 g
s
.31999 .62461 m .31052 .66411 L .37996 .69766 L p .847 .64 .623 r
F P
0 g
s
.37825 .7352 m .37996 .69766 L .31052 .66411 L p .858 .603 .552 r
F P
0 g
s
.3817 .45394 m .34817 .47935 L .38053 .51294 L p .807 .761 .811 r
F P
0 g
s
.38053 .51294 m .40754 .48169 L .3817 .45394 L p .807 .761 .811 r
F P
0 g
s
.35614 .54771 m .38053 .51294 L .34817 .47935 L p .836 .761 .779 r
F P
0 g
s
.70156 .64264 m .7095 .68249 L .77022 .64245 L p .464 .338 .623 r
F P
0 g
s
.77022 .64245 m .75939 .6034 L .70156 .64264 L p .464 .338 .623 r
F P
0 g
s
.51688 .41902 m .50767 .44789 L .53262 .44921 L p .69 .702 .856 r
F P
0 g
s
.53262 .44921 m .52951 .4197 L .51688 .41902 L p .69 .702 .856 r
F P
0 g
s
.52951 .4197 m .53262 .44921 L .55694 .44527 L p .676 .691 .857 r
F P
0 g
s
.60336 .46299 m .57819 .43644 L .55694 .44527 L p .653 .653 .837 r
F P
0 g
s
.57819 .43644 m .60336 .46299 L .62739 .44407 L p .629 .647 .849 r
F P
0 g
s
.65974 .46848 m .62739 .44407 L .60336 .46299 L p .61 .61 .826 r
F P
0 g
s
.50524 .41571 m .48459 .44145 L .50767 .44789 L p .702 .715 .859 r
F P
0 g
s
.50767 .44789 m .51688 .41902 L .50524 .41571 L p .702 .715 .859 r
F P
0 g
s
.34817 .47935 m .31769 .50917 L .35614 .54771 L p .836 .761 .779 r
F P
0 g
s
.33555 .58531 m .35614 .54771 L .31769 .50917 L p .865 .756 .74 r
F P
0 g
s
.41698 .43292 m .3817 .45394 L .40754 .48169 L p .777 .759 .836 r
F P
0 g
s
.40754 .48169 m .43618 .45423 L .41698 .43292 L p .777 .759 .836 r
F P
0 g
s
.55694 .44527 m .5418 .41768 L .52951 .4197 L p .676 .691 .857 r
F P
0 g
s
.5418 .41768 m .55694 .44527 L .57819 .43644 L p .661 .685 .862 r
F P
0 g
s
.6344 .7465 m .63215 .77928 L .70774 .75413 L p .504 .255 .47 r
F P
0 g
s
.70774 .75413 m .71166 .72023 L .6344 .7465 L p .504 .255 .47 r
F P
0 g
s
.4958 .41011 m .46572 .43047 L .48459 .44145 L p .712 .73 .865 r
F P
0 g
s
.48459 .44145 m .50524 .41571 L .4958 .41011 L p .712 .73 .865 r
F P
0 g
s
.31769 .50917 m .29181 .54294 L .33555 .58531 L p .865 .756 .74 r
F P
0 g
s
.31999 .62461 m .33555 .58531 L .29181 .54294 L p .894 .745 .69 r
F P
0 g
s
.4531 .41601 m .41698 .43292 L .43618 .45423 L p .747 .754 .858 r
F P
0 g
s
.43618 .45423 m .46572 .43047 L .4531 .41601 L p .747 .754 .858 r
F P
0 g
s
.57819 .43644 m .55248 .41315 L .5418 .41768 L p .661 .685 .862 r
F P
0 g
s
.55248 .41315 m .57819 .43644 L .59414 .42356 L p .646 .682 .87 r
F P
0 g
s
.62739 .44407 m .59414 .42356 L .57819 .43644 L p .629 .647 .849 r
F P
0 g
s
.7095 .68249 m .71166 .72023 L .77317 .68068 L p .409 .242 .541 r
F P
0 g
s
.77317 .68068 m .77022 .64245 L .7095 .68249 L p .409 .242 .541 r
F P
0 g
s
.62739 .44407 m .65974 .46848 L .67849 .43813 L p .572 .607 .849 r
F P
0 g
s
.65974 .46848 m .69037 .49698 L .71415 .46012 L p .536 .559 .826 r
F P
0 g
s
.71415 .46012 m .67849 .43813 L .65974 .46848 L p .536 .559 .826 r
F P
0 g
s
.69037 .49698 m .71811 .52943 L .7467 .48698 L p .493 .502 .795 r
F P
0 g
s
.7467 .48698 m .71415 .46012 L .69037 .49698 L p .493 .502 .795 r
F P
0 g
s
.54684 .81624 m .54799 .7903 L .46211 .78663 L p .677 .333 .385 r
F P
0 g
s
.54799 .7903 m .54684 .81624 L .62647 .806 L p .577 .25 .378 r
F P
0 g
s
.62647 .806 m .63215 .77928 L .54799 .7903 L p .577 .25 .378 r
F P
0 g
s
.48959 .40277 m .4531 .41601 L .46572 .43047 L p .717 .747 .875 r
F P
0 g
s
.46572 .43047 m .4958 .41011 L .48959 .40277 L p .717 .747 .875 r
F P
0 g
s
.31052 .66411 m .30795 .70208 L .37825 .7352 L p .858 .603 .552 r
F P
0 g
s
.38136 .76846 m .37825 .7352 L .30795 .70208 L p .861 .545 .451 r
F P
0 g
s
.37825 .7352 m .38136 .76846 L .46211 .78663 L p .78 .481 .482 r
F P
0 g
s
.59414 .42356 m .62739 .44407 L .64112 .42086 L p .604 .648 .867 r
F P
0 g
s
.67849 .43813 m .64112 .42086 L .62739 .44407 L p .572 .607 .849 r
F P
0 g
s
.29181 .54294 m .27215 .57978 L .31999 .62461 L p .894 .745 .69 r
F P
0 g
s
.31052 .66411 m .31999 .62461 L .27215 .57978 L p .92 .724 .621 r
F P
0 g
s
.71811 .52943 m .74159 .56525 L .77443 .51846 L p .44 .433 .754 r
F P
0 g
s
.77443 .51846 m .7467 .48698 L .71811 .52943 L p .44 .433 .754 r
F P
0 g
s
.52951 .4197 m .52632 .39284 L .51688 .41902 L closepath p .677 .722 .883 r
F P
0 g
s
.5418 .41768 m .52632 .39284 L .52951 .4197 L closepath p .672 .718 .884 r
F P
0 g
s
.51688 .41902 m .52632 .39284 L .50524 .41571 L closepath p .682 .727 .884 r
F P
0 g
s
.46554 .81283 m .46211 .78663 L .38136 .76846 L p .763 .397 .363 r
F P
0 g
s
.46211 .78663 m .46554 .81283 L .54684 .81624 L p .677 .333 .385 r
F P
0 g
s
.55248 .41315 m .52632 .39284 L .5418 .41768 L closepath p .667 .716 .885 r
F P
0 g
s
.50524 .41571 m .52632 .39284 L .4958 .41011 L closepath p .685 .732 .887 r
F P
0 g
s
.59414 .42356 m .56041 .4066 L .55248 .41315 L p .646 .682 .87 r
F P
0 g
s
.56041 .4066 m .59414 .42356 L .60302 .40788 L p .632 .684 .881 r
F P
0 g
s
.64112 .42086 m .60302 .40788 L .59414 .42356 L p .604 .648 .867 r
F P
0 g
s
.56041 .4066 m .52632 .39284 L .55248 .41315 L closepath p .662 .716 .888 r
F P
0 g
s
.74159 .56525 m .75939 .6034 L .79556 .55378 L p .374 .344 .697 r
F P
0 g
s
.79556 .55378 m .77443 .51846 L .74159 .56525 L p .374 .344 .697 r
F P
0 g
s
.4482 .39952 m .40914 .40841 L .41698 .43292 L p .752 .782 .878 r
F P
0 g
s
.41698 .43292 m .4531 .41601 L .4482 .39952 L p .752 .782 .878 r
F P
0 g
s
.3817 .45394 m .41698 .43292 L .40914 .40841 L p .787 .801 .863 r
F P
0 g
s
.40914 .40841 m .37065 .42175 L .3817 .45394 L p .787 .801 .863 r
F P
0 g
s
.34817 .47935 m .3817 .45394 L .37065 .42175 L p .825 .819 .843 r
F P
0 g
s
.4958 .41011 m .52632 .39284 L .48959 .40277 L closepath p .686 .738 .89 r
F P
0 g
s
.63215 .77928 m .62647 .806 L .69784 .78265 L p .439 .127 .338 r
F P
0 g
s
.69784 .78265 m .70774 .75413 L .63215 .77928 L p .439 .127 .338 r
F P
0 g
s
.48731 .39448 m .4482 .39952 L .4531 .41601 L p .718 .763 .888 r
F P
0 g
s
.4531 .41601 m .48959 .40277 L .48731 .39448 L p .718 .763 .888 r
F P
0 g
s
.56471 .39867 m .52632 .39284 L .56041 .4066 L closepath p .657 .717 .892 r
F P
0 g
s
.60302 .40788 m .56471 .39867 L .56041 .4066 L p .632 .684 .881 r
F P
0 g
s
.37065 .42175 m .33376 .4401 L .34817 .47935 L p .825 .819 .843 r
F P
0 g
s
.31769 .50917 m .34817 .47935 L .33376 .4401 L p .866 .835 .813 r
F P
0 g
s
.27215 .57978 m .26015 .6183 L .31052 .66411 L p .92 .724 .621 r
F P
0 g
s
.30795 .70208 m .31052 .66411 L .26015 .6183 L p .941 .685 .522 r
F P
0 g
s
.71166 .72023 m .70774 .75413 L .76782 .71629 L p .328 .108 .421 r
F P
0 g
s
.76782 .71629 m .77317 .68068 L .71166 .72023 L p .328 .108 .421 r
F P
0 g
s
.48959 .40277 m .52632 .39284 L .48731 .39448 L closepath p .686 .743 .894 r
F P
0 g
s
.56471 .39867 m .60302 .40788 L .60371 .391 L p .62 .691 .895 r
F P
0 g
s
.60302 .40788 m .64112 .42086 L .64269 .39567 L p .581 .657 .889 r
F P
0 g
s
.64269 .39567 m .60371 .391 L .60302 .40788 L p .581 .657 .889 r
F P
0 g
s
.33376 .4401 m .29996 .4638 L .31769 .50917 L p .866 .835 .813 r
F P
0 g
s
.29181 .54294 m .31769 .50917 L .29996 .4638 L p .909 .847 .77 r
F P
0 g
s
.56488 .39022 m .52632 .39284 L .56471 .39867 L closepath p .654 .719 .897 r
F P
0 g
s
.60371 .391 m .56488 .39022 L .56471 .39867 L p .62 .691 .895 r
F P
0 g
s
.64112 .42086 m .67849 .43813 L .68126 .40491 L p .533 .614 .879 r
F P
0 g
s
.68126 .40491 m .64269 .39567 L .64112 .42086 L p .533 .614 .879 r
F P
0 g
s
.75939 .6034 m .77022 .64245 L .80848 .59168 L p .285 .227 .615 r
F P
0 g
s
.80848 .59168 m .79556 .55378 L .75939 .6034 L p .285 .227 .615 r
F P
0 g
s
.30795 .70208 m .31262 .73675 L .38136 .76846 L p .861 .545 .451 r
F P
0 g
s
.38919 .79595 m .38136 .76846 L .31262 .73675 L p .843 .448 .297 r
F P
0 g
s
.38136 .76846 m .38919 .79595 L .46554 .81283 L p .763 .397 .363 r
F P
0 g
s
.48731 .39448 m .52632 .39284 L .48925 .3861 L closepath p .684 .747 .899 r
F P
0 g
s
.56085 .38216 m .52632 .39284 L .56488 .39022 L closepath p .652 .724 .901 r
F P
0 g
s
.553 .37538 m .52632 .39284 L .56085 .38216 L closepath p .652 .729 .906 r
F P
0 g
s
.54217 .37065 m .52632 .39284 L .553 .37538 L closepath p .654 .735 .909 r
F P
0 g
s
.52957 .36853 m .52632 .39284 L .54217 .37065 L closepath p .658 .74 .911 r
F P
0 g
s
.51659 .36925 m .52632 .39284 L .52957 .36853 L closepath p .663 .745 .911 r
F P
0 g
s
.50472 .37273 m .52632 .39284 L .51659 .36925 L closepath p .669 .749 .91 r
F P
0 g
s
.49526 .37857 m .52632 .39284 L .50472 .37273 L closepath p .675 .75 .907 r
F P
0 g
s
.48925 .3861 m .52632 .39284 L .49526 .37857 L closepath p .68 .749 .904 r
F P
0 g
s
.4482 .39952 m .48731 .39448 L .48925 .3861 L p .713 .776 .902 r
F P
0 g
s
.67849 .43813 m .71415 .46012 L .7184 .41943 L p .473 .559 .863 r
F P
0 g
s
.7184 .41943 m .68126 .40491 L .67849 .43813 L p .473 .559 .863 r
F P
0 g
s
.54504 .83488 m .54684 .81624 L .46554 .81283 L p .623 .199 .216 r
F P
0 g
s
.54684 .81624 m .54504 .83488 L .61763 .82565 L p .505 .098 .203 r
F P
0 g
s
.61763 .82565 m .62647 .806 L .54684 .81624 L p .505 .098 .203 r
F P
0 g
s
.48925 .3861 m .45175 .38272 L .4482 .39952 L p .713 .776 .902 r
F P
0 g
s
.40914 .40841 m .4482 .39952 L .45175 .38272 L p .746 .808 .902 r
F P
0 g
s
.56488 .39022 m .60371 .391 L .59592 .37476 L p .612 .703 .909 r
F P
0 g
s
.59592 .37476 m .56085 .38216 L .56488 .39022 L p .612 .703 .909 r
F P
0 g
s
.47088 .83181 m .46554 .81283 L .38919 .79595 L p .712 .258 .173 r
F P
0 g
s
.46554 .81283 m .47088 .83181 L .54504 .83488 L p .623 .199 .216 r
F P
0 g
s
.29996 .4638 m .27105 .49278 L .29181 .54294 L p .909 .847 .77 r
F P
0 g
s
.27215 .57978 m .29181 .54294 L .27105 .49278 L p .953 .85 .703 r
F P
0 g
s
.71415 .46012 m .7467 .48698 L .75258 .43977 L p .395 .486 .834 r
F P
0 g
s
.75258 .43977 m .7184 .41943 L .71415 .46012 L p .395 .486 .834 r
F P
0 g
s
.45175 .38272 m .48925 .3861 L .49526 .37857 L p .702 .786 .916 r
F P
0 g
s
.45175 .38272 m .41395 .38322 L .40914 .40841 L p .746 .808 .902 r
F P
0 g
s
.37065 .42175 m .40914 .40841 L .41395 .38322 L p .783 .842 .897 r
F P
0 g
s
.60371 .391 m .64269 .39567 L .63143 .37119 L p .561 .674 .914 r
F P
0 g
s
.63143 .37119 m .59592 .37476 L .60371 .391 L p .561 .674 .914 r
F P
0 g
s
.56085 .38216 m .59592 .37476 L .5803 .36098 L p .609 .719 .923 r
F P
0 g
s
.5803 .36098 m .553 .37538 L .56085 .38216 L p .609 .719 .923 r
F P
0 g
s
.26015 .6183 m .25688 .65682 L .30795 .70208 L p .941 .685 .522 r
F P
0 g
s
.31262 .73675 m .30795 .70208 L .25688 .65682 L p .943 .611 .37 r
F P
0 g
s
.77022 .64245 m .77317 .68068 L .812 .63051 L p .16 .063 .487 r
F P
0 g
s
.812 .63051 m .80848 .59168 L .77022 .64245 L p .16 .063 .487 r
F P
0 g
s
.46359 .36748 m .49526 .37857 L .50472 .37273 L p .685 .789 .929 r
F P
0 g
s
.49526 .37857 m .46359 .36748 L .45175 .38272 L p .702 .786 .916 r
F P
0 g
s
.62647 .806 m .61763 .82565 L .68248 .80469 L p .323 0 .123 r
F P
0 g
s
.68248 .80469 m .69784 .78265 L .62647 .806 L p .323 0 .123 r
F P
0 g
s
.70774 .75413 m .69784 .78265 L .75432 .74762 L p .2 0 .23 r
F P
0 g
s
.75432 .74762 m .76782 .71629 L .70774 .75413 L p .2 0 .23 r
F P
0 g
s
.41395 .38322 m .37637 .38838 L .37065 .42175 L p .783 .842 .897 r
F P
0 g
s
.33376 .4401 m .37065 .42175 L .37637 .38838 L p .825 .88 .884 r
F P
0 g
s
.553 .37538 m .5803 .36098 L .55848 .35132 L p .614 .737 .934 r
F P
0 g
s
.55848 .35132 m .54217 .37065 L .553 .37538 L p .614 .737 .934 r
F P
0 g
s
.7467 .48698 m .77443 .51846 L .78191 .46608 L p .29 .384 .786 r
F P
0 g
s
.78191 .46608 m .75258 .43977 L .7467 .48698 L p .29 .384 .786 r
F P
0 g
s
.41395 .38322 m .45175 .38272 L .46359 .36748 L p .727 .827 .927 r
F P
0 g
s
.64269 .39567 m .68126 .40491 L .66689 .37234 L p .494 .634 .915 r
F P
0 g
s
.66689 .37234 m .63143 .37119 L .64269 .39567 L p .494 .634 .915 r
F P
0 g
s
.48255 .35557 m .50472 .37273 L .51659 .36925 L p .665 .784 .938 r
F P
0 g
s
.50472 .37273 m .48255 .35557 L .46359 .36748 L p .685 .789 .929 r
F P
0 g
s
.54217 .37065 m .55848 .35132 L .53292 .34696 L p .626 .757 .941 r
F P
0 g
s
.53292 .34696 m .52957 .36853 L .54217 .37065 L p .626 .757 .941 r
F P
0 g
s
.27105 .49278 m .24896 .52645 L .27215 .57978 L p .953 .85 .703 r
F P
0 g
s
.26015 .6183 m .27215 .57978 L .24896 .52645 L p .989 .834 .597 r
F P
0 g
s
.50658 .34844 m .51659 .36925 L .52957 .36853 L p .643 .773 .942 r
F P
0 g
s
.51659 .36925 m .50658 .34844 L .48255 .35557 L p .665 .784 .938 r
F P
0 g
s
.52957 .36853 m .53292 .34696 L .50658 .34844 L p .643 .773 .942 r
F P
0 g
s
.59592 .37476 m .63143 .37119 L .60815 .35028 L p .551 .701 .939 r
F P
0 g
s
.60815 .35028 m .5803 .36098 L .59592 .37476 L p .551 .701 .939 r
F P
0 g
s
.37637 .38838 m .34004 .39906 L .33376 .4401 L p .825 .88 .884 r
F P
0 g
s
.29996 .4638 m .33376 .4401 L .34004 .39906 L p .872 .92 .857 r
F P
0 g
s
.31262 .73675 m .32441 .76655 L .38919 .79595 L p .843 .448 .297 r
F P
0 g
s
.40137 .81662 m .38919 .79595 L .32441 .76655 L p .769 .274 .044 r
F P
0 g
s
.38919 .79595 m .40137 .81662 L .47088 .83181 L p .712 .258 .173 r
F P
0 g
s
.46359 .36748 m .43139 .36017 L .41395 .38322 L p .727 .827 .927 r
F P
0 g
s
.37637 .38838 m .41395 .38322 L .43139 .36017 L p .756 .876 .934 r
F P
0 g
s
.77443 .51846 m .79556 .55378 L .8044 .49796 L p .142 .236 .702 r
F P
0 g
s
.8044 .49796 m .78191 .46608 L .77443 .51846 L p .142 .236 .702 r
F P
0 g
s
.68126 .40491 m .7184 .41943 L .70133 .37921 L p .399 .572 .907 r
F P
0 g
s
.70133 .37921 m .66689 .37234 L .68126 .40491 L p .399 .572 .907 r
F P
0 g
s
.43139 .36017 m .46359 .36748 L .48255 .35557 L p .695 .835 .95 r
F P
0 g
s
.54268 .84578 m .54504 .83488 L .47088 .83181 L p .494 0 0 r
F P
0 g
s
.54504 .83488 m .54268 .84578 L .6061 .83778 L p .352 0 0 r
F P
0 g
s
.6061 .83778 m .61763 .82565 L .54504 .83488 L p .352 0 0 r
F P
0 g
s
.77317 .68068 m .76782 .71629 L .80561 .66836 L p 0 0 .279 r
F P
0 g
s
.80561 .66836 m .812 .63051 L .77317 .68068 L p 0 0 .279 r
F P
0 g
s
.25688 .65682 m .26282 .69349 L .31262 .73675 L p .943 .611 .37 r
F P
0 g
s
.32441 .76655 m .31262 .73675 L .26282 .69349 L p .89 .463 .122 r
F P
0 g
s
.5803 .36098 m .60815 .35028 L .57521 .33551 L p .553 .734 .96 r
F P
0 g
s
.57521 .33551 m .55848 .35132 L .5803 .36098 L p .553 .734 .96 r
F P
0 g
s
.47786 .84312 m .47088 .83181 L .40137 .81662 L p .571 .014 0 r
F P
0 g
s
.47088 .83181 m .47786 .84312 L .54268 .84578 L p .494 0 0 r
F P
0 g
s
.24896 .52645 m .23543 .56366 L .26015 .6183 L p .989 .834 .597 r
F P
0 g
s
.25688 .65682 m .26015 .6183 L .23543 .56366 L p .996 .771 .418 r
F P
0 g
s
.34004 .39906 m .30646 .416 L .29996 .4638 L p .872 .92 .857 r
F P
0 g
s
.27105 .49278 m .29996 .4638 L .30646 .416 L p .918 .953 .799 r
F P
0 g
s
.63143 .37119 m .66689 .37234 L .63617 .34428 L p .463 .667 .952 r
F P
0 g
s
.63617 .34428 m .60815 .35028 L .63143 .37119 L p .463 .667 .952 r
F P
0 g
s
.69784 .78265 m .68248 .80469 L .73346 .77334 L p 0 0 0 r
F P
0 g
s
.73346 .77334 m .75432 .74762 L .69784 .78265 L p 0 0 0 r
F P
0 g
s
.45987 .34202 m .48255 .35557 L .50658 .34844 L p .652 .827 .967 r
F P
0 g
s
.48255 .35557 m .45987 .34202 L .43139 .36017 L p .695 .835 .95 r
F P
0 g
s
.7184 .41943 m .75258 .43977 L .73328 .39274 L p .257 .473 .877 r
F P
0 g
s
.73328 .39274 m .70133 .37921 L .7184 .41943 L p .257 .473 .877 r
F P
0 g
s
.61763 .82565 m .6061 .83778 L .6625 .81966 L p .109 0 0 r
F P
0 g
s
.6625 .81966 m .68248 .80469 L .61763 .82565 L p .109 0 0 r
F P
0 g
s
.43139 .36017 m .39912 .35757 L .37637 .38838 L p .756 .876 .934 r
F P
0 g
s
.34004 .39906 m .37637 .38838 L .39912 .35757 L p .785 .932 .929 r
F P
0 g
s
.55848 .35132 m .57521 .33551 L .53636 .32881 L p .573 .771 .972 r
F P
0 g
s
.53636 .32881 m .53292 .34696 L .55848 .35132 L p .573 .771 .972 r
F P
0 g
s
.79556 .55378 m .80848 .59168 L .8182 .5344 L p 0 .015 .549 r
F P
0 g
s
.8182 .5344 m .8044 .49796 L .79556 .55378 L p 0 .015 .549 r
F P
0 g
s
.4963 .33109 m .50658 .34844 L .53292 .34696 L p .608 .804 .975 r
F P
0 g
s
.50658 .34844 m .4963 .33109 L .45987 .34202 L p .652 .827 .967 r
F P
0 g
s
.53292 .34696 m .53636 .32881 L .4963 .33109 L p .608 .804 .975 r
F P
0 g
s
.39912 .35757 m .43139 .36017 L .45987 .34202 L p .699 .89 .967 r
F P
0 g
s
.30646 .416 m .27753 .43956 L .27105 .49278 L p .918 .953 .799 r
F P
0 g
s
.24896 .52645 m .27105 .49278 L .27753 .43956 L p .946 .958 .678 r
F P
0 g
s
.32441 .76655 m .34267 .79026 L .40137 .81662 L p .769 .274 .044 r
F P
0 g
s
.41724 .82997 m .40137 .81662 L .34267 .79026 L p .555 0 0 r
F P
0 g
s
.40137 .81662 m .41724 .82997 L .47786 .84312 L p .571 .014 0 r
F P
0 g
s
.76782 .71629 m .75432 .74762 L .78954 .70336 L p 0 0 0 r
F P
0 g
s
.78954 .70336 m .80561 .66836 L .76782 .71629 L p 0 0 0 r
F P
0 g
s
.23543 .56366 m .23174 .6028 L .25688 .65682 L p .996 .771 .418 r
F P
0 g
s
.26282 .69349 m .25688 .65682 L .23174 .6028 L p .913 .607 .122 r
F P
0 g
s
.26282 .69349 m .27775 .72654 L .32441 .76655 L p .89 .463 .122 r
F P
0 g
s
.34267 .79026 m .32441 .76655 L .27775 .72654 L p .702 .191 0 r
F P
0 g
s
.60815 .35028 m .63617 .34428 L .59212 .32434 L p .451 .715 .98 r
F P
0 g
s
.59212 .32434 m .57521 .33551 L .60815 .35028 L p .451 .715 .98 r
F P
0 g
s
.66689 .37234 m .70133 .37921 L .66359 .34427 L p .32 .601 .947 r
F P
0 g
s
.66359 .34427 m .63617 .34428 L .66689 .37234 L p .32 .601 .947 r
F P
0 g
s
.75258 .43977 m .78191 .46608 L .7609 .41354 L p .038 .307 .796 r
F P
0 g
s
.7609 .41354 m .73328 .39274 L .75258 .43977 L p .038 .307 .796 r
F P
0 g
s
.39912 .35757 m .36766 .36086 L .34004 .39906 L p .785 .932 .929 r
F P
0 g
s
.30646 .416 m .34004 .39906 L .36766 .36086 L p .805 .985 .89 r
F P
0 g
s
.80848 .59168 m .812 .63051 L .82197 .57385 L p 0 0 .279 r
F P
0 g
s
.82197 .57385 m .8182 .5344 L .80848 .59168 L p 0 0 .279 r
F P
0 g
s
.5399 .84909 m .54268 .84578 L .47786 .84312 L p .212 0 0 r
F P
0 g
s
.54268 .84578 m .5399 .84909 L .59244 .84248 L p .059 0 0 r
F P
0 g
s
.59244 .84248 m .6061 .83778 L .54268 .84578 L p .059 0 0 r
F P
0 g
s
.43699 .33314 m .45987 .34202 L .4963 .33109 L p .618 .874 .99 r
F P
0 g
s
.45987 .34202 m .43699 .33314 L .39912 .35757 L p .699 .89 .967 r
F P
0 g
s
.68248 .80469 m .6625 .81966 L .70646 .79267 L p 0 0 0 r
F P
0 g
s
.70646 .79267 m .73346 .77334 L .68248 .80469 L p 0 0 0 r
F P
0 g
s
.48613 .84689 m .47786 .84312 L .41724 .82997 L p .257 0 0 r
F P
0 g
s
.47786 .84312 m .48613 .84689 L .5399 .84909 L p .212 0 0 r
F P
0 g
s
.57521 .33551 m .59212 .32434 L .53986 .31526 L p .473 .772 .996 r
F P
0 g
s
.53986 .31526 m .53636 .32881 L .57521 .33551 L p .473 .772 .996 r
F P
0 g
s
.36766 .36086 m .39912 .35757 L .43699 .33314 L p .682 .946 .96 r
F P
0 g
s
.27753 .43956 m .25529 .46959 L .24896 .52645 L p .946 .958 .678 r
F P
0 g
s
.23543 .56366 m .24896 .52645 L .25529 .46959 L p .898 .874 .438 r
F P
0 g
s
.6061 .83778 m .59244 .84248 L .63893 .82754 L p 0 0 0 r
F P
0 g
s
.63893 .82754 m .6625 .81966 L .6061 .83778 L p 0 0 0 r
F P
0 g
s
.48588 .31834 m .4963 .33109 L .53636 .32881 L p .533 .83 .999 r
F P
0 g
s
.4963 .33109 m .48588 .31834 L .43699 .33314 L p .618 .874 .99 r
F P
0 g
s
.53636 .32881 m .53986 .31526 L .48588 .31834 L p .533 .83 .999 r
F P
0 g
s
.78191 .46608 m .8044 .49796 L .7822 .44167 L p 0 .029 .6 r
F P
0 g
s
.7822 .44167 m .7609 .41354 L .78191 .46608 L p 0 .029 .6 r
F P
0 g
s
.75432 .74762 m .73346 .77334 L .76481 .73392 L p .561 .82 .453 r
F P
0 g
s
.76481 .73392 m .78954 .70336 L .75432 .74762 L p .561 .82 .453 r
F P
0 g
s
.70133 .37921 m .73328 .39274 L .6892 .35158 L p .075 .46 .886 r
F P
0 g
s
.6892 .35158 m .66359 .34427 L .70133 .37921 L p .075 .46 .886 r
F P
0 g
s
.23174 .6028 m .23844 .64191 L .26282 .69349 L p .913 .607 .122 r
F P
0 g
s
.27775 .72654 m .26282 .69349 L .23844 .64191 L p .661 .299 0 r
F P
0 g
s
.36766 .36086 m .33835 .37115 L .30646 .416 L p .805 .985 .89 r
F P
0 g
s
.27753 .43956 m .30646 .416 L .33835 .37115 L p .773 .989 .758 r
F P
0 g
s
.63617 .34428 m .66359 .34427 L .60876 .31929 L p .261 .647 .965 r
F P
0 g
s
.60876 .31929 m .59212 .32434 L .63617 .34428 L p .261 .647 .965 r
F P
0 g
s
.34267 .79026 m .36637 .80722 L .41724 .82997 L p .555 0 0 r
F P
0 g
s
.41724 .82997 m .436 .83603 L .48613 .84689 L p .257 0 0 r
F P
0 g
s
.436 .83603 m .41724 .82997 L .36637 .80722 L p 0 .386 .742 r
F P
0 g
s
.27775 .72654 m .30078 .75454 L .34267 .79026 L p .702 .191 0 r
F P
0 g
s
.36637 .80722 m .34267 .79026 L .30078 .75454 L p 0 .169 .642 r
F P
0 g
s
.812 .63051 m .80561 .66836 L .81513 .6143 L p 0 0 0 r
F P
0 g
s
.81513 .6143 m .82197 .57385 L .812 .63051 L p 0 0 0 r
F P
0 g
s
.25529 .46959 m .24161 .50522 L .23543 .56366 L p .898 .874 .438 r
F P
0 g
s
.23174 .6028 m .23543 .56366 L .24161 .50522 L p 0 0 0 r
F P
0 g
s
.41454 .33034 m .43699 .33314 L .48588 .31834 L p .52 .896 .963 r
F P
0 g
s
.43699 .33314 m .41454 .33034 L .36766 .36086 L p .682 .946 .96 r
F P
0 g
s
.6625 .81966 m .63893 .82754 L .6748 .80543 L p .525 .918 .82 r
F P
0 g
s
.6748 .80543 m .70646 .79267 L .6625 .81966 L p .525 .918 .82 r
F P
0 g
s
.33835 .37115 m .36766 .36086 L .41454 .33034 L p .593 .949 .858 r
F P
0 g
s
.53678 .8454 m .5399 .84909 L .48613 .84689 L p .165 .691 .87 r
F P
0 g
s
.5399 .84909 m .53678 .8454 L .57722 .8403 L p .281 .778 .881 r
F P
0 g
s
.57722 .8403 m .59244 .84248 L .5399 .84909 L p .281 .778 .881 r
F P
0 g
s
.8044 .49796 m .8182 .5344 L .79533 .47646 L p .676 .345 0 r
F P
0 g
s
.79533 .47646 m .7822 .44167 L .8044 .49796 L p .676 .345 0 r
F P
0 g
s
.49535 .8437 m .48613 .84689 L .436 .83603 L p .133 .641 .9 r
F P
0 g
s
.48613 .84689 m .49535 .8437 L .53678 .8454 L p .165 .691 .87 r
F P
0 g
s
.59212 .32434 m .60876 .31929 L .5433 .30788 L p .265 .713 .958 r
F P
0 g
s
.5433 .30788 m .53986 .31526 L .59212 .32434 L p .265 .713 .958 r
F P
0 g
s
.23844 .64191 m .25526 .67901 L .27775 .72654 L p .661 .299 0 r
F P
0 g
s
.30078 .75454 m .27775 .72654 L .25526 .67901 L p 0 .06 .621 r
F P
0 g
s
.73328 .39274 m .7609 .41354 L .71149 .36728 L p 0 .178 .666 r
F P
0 g
s
.71149 .36728 m .6892 .35158 L .73328 .39274 L p 0 .178 .666 r
F P
0 g
s
.73346 .77334 m .70646 .79267 L .733 .75897 L p .72 .977 .757 r
F P
0 g
s
.733 .75897 m .76481 .73392 L .73346 .77334 L p .72 .977 .757 r
F P
0 g
s
.33835 .37115 m .31294 .38931 L .27753 .43956 L p .773 .989 .758 r
F P
0 g
s
.25529 .46959 m .27753 .43956 L .31294 .38931 L p .603 .83 .445 r
F P
0 g
s
.59244 .84248 m .57722 .8403 L .61281 .82881 L p .455 .878 .923 r
F P
0 g
s
.61281 .82881 m .63893 .82754 L .59244 .84248 L p .455 .878 .923 r
F P
0 g
s
.47561 .31176 m .48588 .31834 L .53986 .31526 L p .359 .803 .955 r
F P
0 g
s
.48588 .31834 m .47561 .31176 L .41454 .33034 L p .52 .896 .963 r
F P
0 g
s
.80561 .66836 m .78954 .70336 L .79798 .65364 L p .88 .899 .481 r
F P
0 g
s
.79798 .65364 m .81513 .6143 L .80561 .66836 L p .88 .899 .481 r
F P
0 g
s
.53986 .31526 m .5433 .30788 L .47561 .31176 L p .359 .803 .955 r
F P
0 g
s
.30078 .75454 m .33051 .77657 L .36637 .80722 L p 0 .169 .642 r
F P
0 g
s
.39425 .81733 m .36637 .80722 L .33051 .77657 L p .025 .454 .873 r
F P
0 g
s
.36637 .80722 m .39425 .81733 L .436 .83603 L p 0 .386 .742 r
F P
0 g
s
.66359 .34427 m .6892 .35158 L .62439 .32198 L p 0 .446 .808 r
F P
0 g
s
.62439 .32198 m .60876 .31929 L .66359 .34427 L p 0 .446 .808 r
F P
0 g
s
.45686 .83533 m .436 .83603 L .39425 .81733 L p .181 .621 .942 r
F P
0 g
s
.436 .83603 m .45686 .83533 L .49535 .8437 L p .133 .641 .9 r
F P
0 g
s
.24161 .50522 m .23787 .54496 L .23174 .6028 L p 0 0 0 r
F P
0 g
s
.23844 .64191 m .23174 .6028 L .23787 .54496 L p 0 0 .334 r
F P
0 g
s
.8182 .5344 m .82197 .57385 L .79893 .51648 L p .929 .655 .176 r
F P
0 g
s
.79893 .51648 m .79533 .47646 L .8182 .5344 L p .929 .655 .176 r
F P
0 g
s
.41454 .33034 m .3935 .33509 L .33835 .37115 L p .593 .949 .858 r
F P
0 g
s
.31294 .38931 m .33835 .37115 L .3935 .33509 L p 0 0 0 r
F P
0 g
s
.3935 .33509 m .41454 .33034 L .47561 .31176 L p .271 .773 .749 r
F P
0 g
s
.63893 .82754 m .61281 .82881 L .63995 .81189 L p .626 .942 .954 r
F P
0 g
s
.63995 .81189 m .6748 .80543 L .63893 .82754 L p .626 .942 .954 r
F P
0 g
s
.25526 .67901 m .28109 .71233 L .30078 .75454 L p 0 .06 .621 r
F P
0 g
s
.33051 .77657 m .30078 .75454 L .28109 .71233 L p .02 .331 .815 r
F P
0 g
s
.31294 .38931 m .29328 .41562 L .25529 .46959 L p .603 .83 .445 r
F P
0 g
s
.24161 .50522 m .25529 .46959 L .29328 .41562 L p 0 0 0 r
F P
0 g
s
.70646 .79267 m .6748 .80543 L .69599 .778 L p .756 .987 .899 r
F P
0 g
s
.69599 .778 m .733 .75897 L .70646 .79267 L p .756 .987 .899 r
F P
0 g
s
.7609 .41354 m .7822 .44167 L .72877 .39187 L p .709 .208 0 r
F P
0 g
s
.72877 .39187 m .71149 .36728 L .7609 .41354 L p .709 .208 0 r
F P
0 g
s
.78954 .70336 m .76481 .73392 L .77172 .6899 L p .92 .976 .712 r
F P
0 g
s
.77172 .6899 m .79798 .65364 L .78954 .70336 L p .92 .976 .712 r
F P
0 g
s
.53344 .8355 m .53678 .8454 L .49535 .8437 L p .421 .799 .992 r
F P
0 g
s
.53678 .8454 m .53344 .8355 L .56094 .83201 L p .486 .845 .993 r
F P
0 g
s
.56094 .83201 m .57722 .8403 L .53678 .8454 L p .486 .845 .993 r
F P
0 g
s
.50524 .83434 m .49535 .8437 L .45686 .83533 L p .392 .756 .993 r
F P
0 g
s
.49535 .8437 m .50524 .83434 L .53344 .8355 L p .421 .799 .992 r
F P
0 g
s
.60876 .31929 m .62439 .32198 L .54654 .30841 L p 0 .471 .698 r
F P
0 g
s
.54654 .30841 m .5433 .30788 L .60876 .31929 L p 0 .471 .698 r
F P
0 g
s
.23787 .54496 m .24465 .58678 L .23844 .64191 L p 0 0 .334 r
F P
0 g
s
.25526 .67901 m .23844 .64191 L .24465 .58678 L p 0 .061 .595 r
F P
0 g
s
.33051 .77657 m .36523 .79229 L .39425 .81733 L p .025 .454 .873 r
F P
0 g
s
.42505 .82098 m .39425 .81733 L .36523 .79229 L p .278 .612 .956 r
F P
0 g
s
.39425 .81733 m .42505 .82098 L .45686 .83533 L p .181 .621 .942 r
F P
0 g
s
.57722 .8403 m .56094 .83201 L .58499 .82417 L p .571 .882 .992 r
F P
0 g
s
.58499 .82417 m .61281 .82881 L .57722 .8403 L p .571 .882 .992 r
F P
0 g
s
.47561 .31176 m .46596 .31302 L .3935 .33509 L p .271 .773 .749 r
F P
0 g
s
.46596 .31302 m .47561 .31176 L .5433 .30788 L p 0 0 0 r
F P
0 g
s
.6892 .35158 m .71149 .36728 L .63804 .33383 L p .517 0 0 r
F P
0 g
s
.63804 .33383 m .62439 .32198 L .6892 .35158 L p .517 0 0 r
F P
0 g
s
.47912 .82861 m .45686 .83533 L .42505 .82098 L p .401 .72 .988 r
F P
0 g
s
.45686 .83533 m .47912 .82861 L .50524 .83434 L p .392 .756 .993 r
F P
0 g
s
.5433 .30788 m .54654 .30841 L .46596 .31302 L p 0 0 0 r
F P
0 g
s
.82197 .57385 m .81513 .6143 L .79241 .55966 L p .999 .807 .469 r
F P
0 g
s
.79241 .55966 m .79893 .51648 L .82197 .57385 L p .999 .807 .469 r
F P
0 g
s
.28109 .71233 m .3142 .7406 L .33051 .77657 L p .02 .331 .815 r
F P
0 g
s
.36523 .79229 m .33051 .77657 L .3142 .7406 L p .237 .501 .901 r
F P
0 g
s
.76481 .73392 m .733 .75897 L .73817 .72159 L p .89 .97 .83 r
F P
0 g
s
.73817 .72159 m .77172 .6899 L .76481 .73392 L p .89 .97 .83 r
F P
0 g
s
.6748 .80543 m .63995 .81189 L .65559 .79109 L p .74 .942 .95 r
F P
0 g
s
.65559 .79109 m .69599 .778 L .6748 .80543 L p .74 .942 .95 r
F P
0 g
s
.61281 .82881 m .58499 .82417 L .60311 .8127 L p .651 .898 .982 r
F P
0 g
s
.60311 .8127 m .63995 .81189 L .61281 .82881 L p .651 .898 .982 r
F P
0 g
s
.3935 .33509 m .37515 .34866 L .31294 .38931 L p 0 0 0 r
F P
0 g
s
.29328 .41562 m .31294 .38931 L .37515 .34866 L p 0 0 0 r
F P
0 g
s
.29328 .41562 m .28114 .44958 L .24161 .50522 L p 0 0 0 r
F P
0 g
s
.23787 .54496 m .24161 .50522 L .28114 .44958 L p 0 0 .327 r
F P
0 g
s
.7822 .44167 m .79533 .47646 L .73945 .42504 L p .904 .492 .157 r
F P
0 g
s
.73945 .42504 m .72877 .39187 L .7822 .44167 L p .904 .492 .157 r
F P
0 g
s
.37515 .34866 m .3935 .33509 L .46596 .31302 L p .096 0 0 r
F P
0 g
s
.24465 .58678 m .26164 .6284 L .25526 .67901 L p 0 .061 .595 r
F P
0 g
s
.28109 .71233 m .25526 .67901 L .26164 .6284 L p .148 .278 .742 r
F P
0 g
s
.36523 .79229 m .4033 .80191 L .42505 .82098 L p .278 .612 .956 r
F P
0 g
s
.45774 .81885 m .42505 .82098 L .4033 .80191 L p .435 .693 .974 r
F P
0 g
s
.42505 .82098 m .45774 .81885 L .47912 .82861 L p .401 .72 .988 r
F P
0 g
s
.52994 .82016 m .53344 .8355 L .50524 .83434 L p .548 .805 .993 r
F P
0 g
s
.53344 .8355 m .52994 .82016 L .54392 .81836 L p .578 .827 .992 r
F P
0 g
s
.54392 .81836 m .56094 .83201 L .53344 .8355 L p .578 .827 .992 r
F P
0 g
s
.51559 .81956 m .50524 .83434 L .47912 .82861 L p .53 .781 .99 r
F P
0 g
s
.50524 .83434 m .51559 .81956 L .52994 .82016 L p .548 .805 .993 r
F P
0 g
s
.81513 .6143 m .79798 .65364 L .77611 .60358 L p .982 .86 .642 r
F P
0 g
s
.77611 .60358 m .79241 .55966 L .81513 .6143 L p .982 .86 .642 r
F P
0 g
s
.56094 .83201 m .54392 .81836 L .55606 .81435 L p .614 .841 .986 r
F P
0 g
s
.55606 .81435 m .58499 .82417 L .56094 .83201 L p .614 .841 .986 r
F P
0 g
s
.3142 .7406 m .35257 .76314 L .36523 .79229 L p .237 .501 .901 r
F P
0 g
s
.4033 .80191 m .36523 .79229 L .35257 .76314 L p .381 .605 .937 r
F P
0 g
s
.62439 .32198 m .63804 .33383 L .54938 .31845 L p .5 0 0 r
F P
0 g
s
.54938 .31845 m .54654 .30841 L .62439 .32198 L p .5 0 0 r
F P
0 g
s
.733 .75897 m .69599 .778 L .69945 .74784 L p .84 .937 .89 r
F P
0 g
s
.69945 .74784 m .73817 .72159 L .733 .75897 L p .84 .937 .89 r
F P
0 g
s
.50235 .81662 m .47912 .82861 L .45774 .81885 L p .526 .758 .981 r
F P
0 g
s
.47912 .82861 m .50235 .81662 L .51559 .81956 L p .53 .781 .99 r
F P
0 g
s
.71149 .36728 m .72877 .39187 L .64867 .35572 L p .761 .266 .046 r
F P
0 g
s
.64867 .35572 m .63804 .33383 L .71149 .36728 L p .761 .266 .046 r
F P
0 g
s
.63995 .81189 m .60311 .8127 L .61327 .79872 L p .71 .889 .962 r
F P
0 g
s
.61327 .79872 m .65559 .79109 L .63995 .81189 L p .71 .889 .962 r
F P
0 g
s
.26164 .6284 m .28759 .66766 L .28109 .71233 L p .148 .278 .742 r
F P
0 g
s
.3142 .7406 m .28109 .71233 L .28759 .66766 L p .292 .424 .824 r
F P
0 g
s
.28114 .44958 m .27782 .48985 L .23787 .54496 L p 0 0 .327 r
F P
0 g
s
.24465 .58678 m .23787 .54496 L .27782 .48985 L p .184 .11 .533 r
F P
0 g
s
.45751 .32368 m .46596 .31302 L .54654 .30841 L p .36 0 0 r
F P
0 g
s
.46596 .31302 m .45751 .32368 L .37515 .34866 L p .096 0 0 r
F P
0 g
s
.58499 .82417 m .55606 .81435 L .56509 .80852 L p .65 .846 .975 r
F P
0 g
s
.56509 .80852 m .60311 .8127 L .58499 .82417 L p .65 .846 .975 r
F P
0 g
s
.37515 .34866 m .36089 .37176 L .29328 .41562 L p 0 0 0 r
F P
0 g
s
.28114 .44958 m .29328 .41562 L .36089 .37176 L p .226 0 .26 r
F P
0 g
s
.79533 .47646 m .79893 .51648 L .74239 .46554 L p .947 .636 .411 r
F P
0 g
s
.74239 .46554 m .73945 .42504 L .79533 .47646 L p .947 .636 .411 r
F P
0 g
s
.54654 .30841 m .54938 .31845 L .45751 .32368 L p .36 0 0 r
F P
0 g
s
.4033 .80191 m .44337 .80597 L .45774 .81885 L p .435 .693 .974 r
F P
0 g
s
.49161 .81164 m .45774 .81885 L .44337 .80597 L p .535 .737 .968 r
F P
0 g
s
.45774 .81885 m .49161 .81164 L .50235 .81662 L p .526 .758 .981 r
F P
0 g
s
.69599 .778 m .65559 .79109 L .65758 .76843 L p .789 .899 .92 r
F P
0 g
s
.65758 .76843 m .69945 .74784 L .69599 .778 L p .789 .899 .92 r
F P
0 g
s
.35257 .76314 m .39426 .7799 L .4033 .80191 L p .381 .605 .937 r
F P
0 g
s
.44337 .80597 m .4033 .80191 L .39426 .7799 L p .48 .674 .95 r
F P
0 g
s
.79798 .65364 m .77172 .6899 L .75128 .64585 L p .939 .873 .744 r
F P
0 g
s
.75128 .64585 m .77611 .60358 L .79798 .65364 L p .939 .873 .744 r
F P
0 g
s
.36089 .37176 m .37515 .34866 L .45751 .32368 L p .351 0 .12 r
F P
0 g
s
.28759 .66766 m .32063 .70281 L .3142 .7406 L p .292 .424 .824 r
F P
0 g
s
.35257 .76314 m .3142 .7406 L .32063 .70281 L p .394 .527 .872 r
F P
0 g
s
.60311 .8127 m .56509 .80852 L .57001 .80147 L p .679 .84 .961 r
F P
0 g
s
.57001 .80147 m .61327 .79872 L .60311 .8127 L p .679 .84 .961 r
F P
0 g
s
.52632 .79983 m .52994 .82016 L .51559 .81956 L closepath p .613 .786 .964 r
F P
0 g
s
.52632 .79983 m .54392 .81836 L .52994 .82016 L closepath p .621 .792 .964 r
F P
0 g
s
.52632 .79983 m .51559 .81956 L .50235 .81662 L closepath p .607 .779 .963 r
F P
0 g
s
.27782 .48985 m .28385 .53433 L .24465 .58678 L p .184 .11 .533 r
F P
0 g
s
.26164 .6284 m .24465 .58678 L .28385 .53433 L p .307 .273 .656 r
F P
0 g
s
.52632 .79983 m .55606 .81435 L .54392 .81836 L closepath p .63 .795 .962 r
F P
0 g
s
.52632 .79983 m .50235 .81662 L .49161 .81164 L closepath p .604 .771 .96 r
F P
0 g
s
.65559 .79109 m .61327 .79872 L .61416 .78363 L p .741 .861 .936 r
F P
0 g
s
.61416 .78363 m .65758 .76843 L .65559 .79109 L p .741 .861 .936 r
F P
0 g
s
.39426 .7799 m .43771 .79125 L .44337 .80597 L p .48 .674 .95 r
F P
0 g
s
.48453 .80512 m .44337 .80597 L .43771 .79125 L p .552 .722 .952 r
F P
0 g
s
.44337 .80597 m .48453 .80512 L .49161 .81164 L p .535 .737 .968 r
F P
0 g
s
.77172 .6899 m .73817 .72159 L .71977 .68448 L p .891 .868 .809 r
F P
0 g
s
.71977 .68448 m .75128 .64585 L .77172 .6899 L p .891 .868 .809 r
F P
0 g
s
.52632 .79983 m .56509 .80852 L .55606 .81435 L closepath p .64 .797 .958 r
F P
0 g
s
.32063 .70281 m .3586 .7328 L .35257 .76314 L p .394 .527 .872 r
F P
0 g
s
.39426 .7799 m .35257 .76314 L .3586 .7328 L p .469 .603 .903 r
F P
0 g
s
.72877 .39187 m .73945 .42504 L .65526 .38763 L p .837 .452 .321 r
F P
0 g
s
.65526 .38763 m .64867 .35572 L .72877 .39187 L p .837 .452 .321 r
F P
0 g
s
.63804 .33383 m .64867 .35572 L .5516 .33905 L p .676 .22 .163 r
F P
0 g
s
.5516 .33905 m .54938 .31845 L .63804 .33383 L p .676 .22 .163 r
F P
0 g
s
.52632 .79983 m .49161 .81164 L .48453 .80512 L closepath p .605 .764 .955 r
F P
0 g
s
.79893 .51648 m .79241 .55966 L .73707 .51121 L p .937 .705 .562 r
F P
0 g
s
.73707 .51121 m .74239 .46554 L .79893 .51648 L p .937 .705 .562 r
F P
0 g
s
.36089 .37176 m .35205 .40424 L .28114 .44958 L p .226 0 .26 r
F P
0 g
s
.27782 .48985 m .28114 .44958 L .35205 .40424 L p .359 .152 .456 r
F P
0 g
s
.52632 .79983 m .57001 .80147 L .56509 .80852 L closepath p .648 .795 .953 r
F P
0 g
s
.61327 .79872 m .57001 .80147 L .57023 .79394 L p .697 .826 .944 r
F P
0 g
s
.57023 .79394 m .61416 .78363 L .61327 .79872 L p .697 .826 .944 r
F P
0 g
s
.3586 .7328 m .39947 .75721 L .39426 .7799 L p .469 .603 .903 r
F P
0 g
s
.43771 .79125 m .39426 .7799 L .39947 .75721 L p .527 .663 .923 r
F P
0 g
s
.43771 .79125 m .4819 .79774 L .48453 .80512 L p .552 .722 .952 r
F P
0 g
s
.52632 .79983 m .48453 .80512 L .4819 .79774 L closepath p .609 .758 .95 r
F P
0 g
s
.73817 .72159 m .69945 .74784 L .68372 .71817 L p .843 .857 .854 r
F P
0 g
s
.68372 .71817 m .71977 .68448 L .73817 .72159 L p .843 .857 .854 r
F P
0 g
s
.28385 .53433 m .29891 .58044 L .26164 .6284 L p .307 .273 .656 r
F P
0 g
s
.28759 .66766 m .26164 .6284 L .29891 .58044 L p .391 .389 .737 r
F P
0 g
s
.45093 .34473 m .45751 .32368 L .54938 .31845 L p .547 .12 .182 r
F P
0 g
s
.45751 .32368 m .45093 .34473 L .36089 .37176 L p .351 0 .12 r
F P
0 g
s
.52632 .79983 m .57023 .79394 L .57001 .80147 L closepath p .655 .791 .947 r
F P
0 g
s
.39947 .75721 m .44164 .77622 L .43771 .79125 L p .527 .663 .923 r
F P
0 g
s
.4819 .79774 m .43771 .79125 L .44164 .77622 L p .574 .712 .936 r
F P
0 g
s
.54938 .31845 m .5516 .33905 L .45093 .34473 L p .547 .12 .182 r
F P
0 g
s
.69945 .74784 m .65758 .76843 L .64509 .74635 L p .796 .842 .886 r
F P
0 g
s
.64509 .74635 m .68372 .71817 L .69945 .74784 L p .796 .842 .886 r
F P
0 g
s
.44164 .77622 m .48409 .79027 L .4819 .79774 L p .574 .712 .936 r
F P
0 g
s
.52632 .79983 m .4819 .79774 L .48409 .79027 L closepath p .615 .754 .944 r
F P
0 g
s
.35205 .40424 m .36089 .37176 L .45093 .34473 L p .477 .164 .357 r
F P
0 g
s
.52632 .79983 m .55674 .7807 L .56566 .78675 L closepath p .659 .778 .937 r
F P
0 g
s
.52632 .79983 m .5444 .77648 L .55674 .7807 L closepath p .657 .771 .933 r
F P
0 g
s
.52632 .79983 m .53002 .77457 L .5444 .77648 L closepath p .653 .764 .931 r
F P
0 g
s
.52632 .79983 m .51523 .77522 L .53002 .77457 L closepath p .647 .758 .931 r
F P
0 g
s
.52632 .79983 m .50168 .77833 L .51523 .77522 L closepath p .639 .754 .932 r
F P
0 g
s
.52632 .79983 m .49091 .78355 L .50168 .77833 L closepath p .631 .752 .935 r
F P
0 g
s
.52632 .79983 m .48409 .79027 L .49091 .78355 L closepath p .622 .752 .939 r
F P
0 g
s
.52632 .79983 m .56566 .78675 L .57023 .79394 L closepath p .658 .785 .942 r
F P
0 g
s
.79241 .55966 m .77611 .60358 L .72382 .55936 L p .911 .742 .66 r
F P
0 g
s
.72382 .55936 m .73707 .51121 L .79241 .55966 L p .911 .742 .66 r
F P
0 g
s
.65758 .76843 m .61416 .78363 L .60541 .76907 L p .75 .825 .91 r
F P
0 g
s
.60541 .76907 m .64509 .74635 L .65758 .76843 L p .75 .825 .91 r
F P
0 g
s
.29891 .58044 m .3218 .62557 L .28759 .66766 L p .391 .389 .737 r
F P
0 g
s
.32063 .70281 m .28759 .66766 L .3218 .62557 L p .453 .477 .794 r
F P
0 g
s
.61416 .78363 m .57023 .79394 L .56566 .78675 L p .705 .806 .928 r
F P
0 g
s
.56566 .78675 m .60541 .76907 L .61416 .78363 L p .705 .806 .928 r
F P
0 g
s
.455 .76255 m .49091 .78355 L .48409 .79027 L p .598 .708 .92 r
F P
0 g
s
.48409 .79027 m .44164 .77622 L .455 .76255 L p .598 .708 .92 r
F P
0 g
s
.35205 .40424 m .34963 .44491 L .27782 .48985 L p .359 .152 .456 r
F P
0 g
s
.28385 .53433 m .27782 .48985 L .34963 .44491 L p .439 .287 .577 r
F P
0 g
s
.73945 .42504 m .74239 .46554 L .65708 .42844 L p .851 .551 .482 r
F P
0 g
s
.65708 .42844 m .65526 .38763 L .73945 .42504 L p .851 .551 .482 r
F P
0 g
s
.3218 .62557 m .35075 .66749 L .32063 .70281 L p .453 .477 .794 r
F P
0 g
s
.3586 .7328 m .32063 .70281 L .35075 .66749 L p .501 .548 .837 r
F P
0 g
s
.60541 .76907 m .56566 .78675 L .55674 .7807 L p .704 .784 .914 r
F P
0 g
s
.41898 .73637 m .455 .76255 L .44164 .77622 L p .571 .661 .898 r
F P
0 g
s
.44164 .77622 m .39947 .75721 L .41898 .73637 L p .571 .661 .898 r
F P
0 g
s
.64867 .35572 m .65526 .38763 L .55297 .37035 L p .736 .38 .377 r
F P
0 g
s
.55297 .37035 m .5516 .33905 L .64867 .35572 L p .736 .38 .377 r
F P
0 g
s
.35075 .66749 m .38376 .70467 L .3586 .7328 L p .501 .548 .837 r
F P
0 g
s
.39947 .75721 m .3586 .7328 L .38376 .70467 L p .539 .608 .871 r
F P
0 g
s
.47651 .75184 m .50168 .77833 L .49091 .78355 L p .622 .709 .908 r
F P
0 g
s
.49091 .78355 m .455 .76255 L .47651 .75184 L p .622 .709 .908 r
F P
0 g
s
.38376 .70467 m .41898 .73637 L .39947 .75721 L p .539 .608 .871 r
F P
0 g
s
.77611 .60358 m .75128 .64585 L .70371 .60714 L p .88 .763 .728 r
F P
0 g
s
.70371 .60714 m .72382 .55936 L .77611 .60358 L p .88 .763 .728 r
F P
0 g
s
.55674 .7807 m .58772 .75671 L .60541 .76907 L p .704 .784 .914 r
F P
0 g
s
.58772 .75671 m .55674 .7807 L .5444 .77648 L p .696 .763 .903 r
F P
0 g
s
.64509 .74635 m .60541 .76907 L .58772 .75671 L p .744 .787 .887 r
F P
0 g
s
.50385 .74542 m .51523 .77522 L .50168 .77833 L p .645 .716 .9 r
F P
0 g
s
.50168 .77833 m .47651 .75184 L .50385 .74542 L p .645 .716 .9 r
F P
0 g
s
.5444 .77648 m .56293 .74802 L .58772 .75671 L p .696 .763 .903 r
F P
0 g
s
.56293 .74802 m .5444 .77648 L .53002 .77457 L p .683 .744 .897 r
F P
0 g
s
.44684 .37623 m .45093 .34473 L .5516 .33905 L p .625 .291 .386 r
F P
0 g
s
.45093 .34473 m .44684 .37623 L .35205 .40424 L p .477 .164 .357 r
F P
0 g
s
.53383 .74409 m .53002 .77457 L .51523 .77522 L p .665 .728 .896 r
F P
0 g
s
.51523 .77522 m .50385 .74542 L .53383 .74409 L p .665 .728 .896 r
F P
0 g
s
.53002 .77457 m .53383 .74409 L .56293 .74802 L p .683 .744 .897 r
F P
0 g
s
.75128 .64585 m .71977 .68448 L .67835 .65211 L p .848 .775 .78 r
F P
0 g
s
.67835 .65211 m .70371 .60714 L .75128 .64585 L p .848 .775 .78 r
F P
0 g
s
.34963 .44491 m .35403 .49161 L .28385 .53433 L p .439 .287 .577 r
F P
0 g
s
.29891 .58044 m .28385 .53433 L .35403 .49161 L p .491 .383 .659 r
F P
0 g
s
.34963 .44491 m .35205 .40424 L .44684 .37623 L p .542 .299 .496 r
F P
0 g
s
.68372 .71817 m .64509 .74635 L .61891 .72741 L p .781 .786 .857 r
F P
0 g
s
.58772 .75671 m .61891 .72741 L .64509 .74635 L p .744 .787 .887 r
F P
0 g
s
.45109 .71992 m .47651 .75184 L .455 .76255 L p .611 .666 .879 r
F P
0 g
s
.455 .76255 m .41898 .73637 L .45109 .71992 L p .611 .666 .879 r
F P
0 g
s
.5516 .33905 m .55297 .37035 L .44684 .37623 L p .625 .291 .386 r
F P
0 g
s
.71977 .68448 m .68372 .71817 L .64954 .69249 L p .815 .783 .822 r
F P
0 g
s
.64954 .69249 m .67835 .65211 L .71977 .68448 L p .815 .783 .822 r
F P
0 g
s
.61891 .72741 m .64954 .69249 L .68372 .71817 L p .781 .786 .857 r
F P
0 g
s
.74239 .46554 m .73707 .51121 L .65379 .47597 L p .845 .611 .584 r
F P
0 g
s
.65379 .47597 m .65708 .42844 L .74239 .46554 L p .845 .611 .584 r
F P
0 g
s
.61891 .72741 m .58772 .75671 L .56293 .74802 L p .728 .752 .872 r
F P
0 g
s
.42605 .68228 m .45109 .71992 L .41898 .73637 L p .596 .621 .846 r
F P
0 g
s
.41898 .73637 m .38376 .70467 L .42605 .68228 L p .596 .621 .846 r
F P
0 g
s
.35403 .49161 m .36497 .54151 L .29891 .58044 L p .491 .383 .659 r
F P
0 g
s
.3218 .62557 m .29891 .58044 L .36497 .54151 L p .528 .457 .72 r
F P
0 g
s
.4923 .70999 m .50385 .74542 L .47651 .75184 L p .646 .678 .866 r
F P
0 g
s
.47651 .75184 m .45109 .71992 L .4923 .70999 L p .646 .678 .866 r
F P
0 g
s
.65526 .38763 m .65708 .42844 L .55335 .4113 L p .756 .474 .505 r
F P
0 g
s
.55335 .4113 m .55297 .37035 L .65526 .38763 L p .756 .474 .505 r
F P
0 g
s
.56293 .74802 m .5817 .71401 L .61891 .72741 L p .728 .752 .872 r
F P
0 g
s
.5817 .71401 m .56293 .74802 L .53383 .74409 L p .705 .722 .863 r
F P
0 g
s
.40242 .63916 m .42605 .68228 L .38376 .70467 L p .578 .572 .81 r
F P
0 g
s
.38376 .70467 m .35075 .66749 L .40242 .63916 L p .578 .572 .81 r
F P
0 g
s
.36497 .54151 m .38156 .59159 L .3218 .62557 L p .528 .457 .72 r
F P
0 g
s
.35075 .66749 m .3218 .62557 L .38156 .59159 L p .556 .518 .769 r
F P
0 g
s
.5377 .70792 m .53383 .74409 L .50385 .74542 L p .678 .697 .861 r
F P
0 g
s
.50385 .74542 m .4923 .70999 L .5377 .70792 L p .678 .697 .861 r
F P
0 g
s
.64954 .69249 m .61891 .72741 L .5817 .71401 L p .754 .738 .838 r
F P
0 g
s
.53383 .74409 m .5377 .70792 L .5817 .71401 L p .705 .722 .863 r
F P
0 g
s
.38156 .59159 m .40242 .63916 L .35075 .66749 L p .556 .518 .769 r
F P
0 g
s
.73707 .51121 m .72382 .55936 L .64562 .52729 L p .832 .65 .657 r
F P
0 g
s
.64562 .52729 m .65379 .47597 L .73707 .51121 L p .832 .65 .657 r
F P
0 g
s
.44684 .37623 m .44572 .41713 L .34963 .44491 L p .542 .299 .496 r
F P
0 g
s
.35403 .49161 m .34963 .44491 L .44572 .41713 L p .579 .389 .588 r
F P
0 g
s
.44572 .41713 m .44684 .37623 L .55297 .37035 L p .66 .395 .508 r
F P
0 g
s
.48088 .66868 m .4923 .70999 L .45109 .71992 L p .644 .64 .831 r
F P
0 g
s
.45109 .71992 m .42605 .68228 L .48088 .66868 L p .644 .64 .831 r
F P
0 g
s
.55297 .37035 m .55335 .4113 L .44572 .41713 L p .66 .395 .508 r
F P
0 g
s
.67835 .65211 m .64954 .69249 L .60023 .6742 L p .778 .722 .801 r
F P
0 g
s
.5817 .71401 m .60023 .6742 L .64954 .69249 L p .754 .738 .838 r
F P
0 g
s
.72382 .55936 m .70371 .60714 L .63327 .57921 L p .816 .68 .713 r
F P
0 g
s
.63327 .57921 m .64562 .52729 L .72382 .55936 L p .816 .68 .713 r
F P
0 g
s
.60023 .6742 m .5817 .71401 L .5377 .70792 L p .722 .698 .827 r
F P
0 g
s
.70371 .60714 m .67835 .65211 L .61776 .62888 L p .798 .703 .76 r
F P
0 g
s
.60023 .6742 m .61776 .62888 L .67835 .65211 L p .778 .722 .801 r
F P
0 g
s
.65708 .42844 m .65379 .47597 L .55266 .4597 L p .761 .535 .59 r
F P
0 g
s
.55266 .4597 m .55335 .4113 L .65708 .42844 L p .761 .535 .59 r
F P
0 g
s
.61776 .62888 m .63327 .57921 L .70371 .60714 L p .798 .703 .76 r
F P
0 g
s
.54153 .66585 m .5377 .70792 L .4923 .70999 L p .686 .666 .825 r
F P
0 g
s
.4923 .70999 m .48088 .66868 L .54153 .66585 L p .686 .666 .825 r
F P
0 g
s
.44572 .41713 m .44775 .46524 L .35403 .49161 L p .579 .389 .588 r
F P
0 g
s
.36497 .54151 m .35403 .49161 L .44775 .46524 L p .603 .456 .655 r
F P
0 g
s
.5377 .70792 m .54153 .66585 L .60023 .6742 L p .722 .698 .827 r
F P
0 g
s
.47006 .62186 m .48088 .66868 L .42605 .68228 L p .639 .6 .794 r
F P
0 g
s
.42605 .68228 m .40242 .63916 L .47006 .62186 L p .639 .6 .794 r
F P
0 g
s
.44775 .46524 m .44572 .41713 L .55335 .4113 L p .677 .465 .591 r
F P
0 g
s
.44775 .46524 m .45282 .51754 L .36497 .54151 L p .603 .456 .655 r
F P
0 g
s
.38156 .59159 m .36497 .54151 L .45282 .51754 L p .619 .51 .708 r
F P
0 g
s
.61776 .62888 m .60023 .6742 L .54153 .66585 L p .736 .673 .789 r
F P
0 g
s
.46047 .57074 m .47006 .62186 L .40242 .63916 L p .631 .557 .753 r
F P
0 g
s
.40242 .63916 m .38156 .59159 L .46047 .57074 L p .631 .557 .753 r
F P
0 g
s
.55335 .4113 m .55266 .4597 L .44775 .46524 L p .677 .465 .591 r
F P
0 g
s
.45282 .51754 m .46047 .57074 L .38156 .59159 L p .619 .51 .708 r
F P
0 g
s
.65379 .47597 m .64562 .52729 L .55096 .51251 L p .759 .579 .653 r
F P
0 g
s
.55096 .51251 m .55266 .4597 L .65379 .47597 L p .759 .579 .653 r
F P
0 g
s
.54517 .61824 m .54153 .66585 L .48088 .66868 L p .69 .633 .787 r
F P
0 g
s
.48088 .66868 m .47006 .62186 L .54517 .61824 L p .69 .633 .787 r
F P
0 g
s
.54153 .66585 m .54517 .61824 L .61776 .62888 L p .736 .673 .789 r
F P
0 g
s
.63327 .57921 m .61776 .62888 L .54517 .61824 L p .746 .646 .749 r
F P
0 g
s
.64562 .52729 m .63327 .57921 L .54839 .56637 L p .754 .615 .705 r
F P
0 g
s
.54839 .56637 m .55096 .51251 L .64562 .52729 L p .754 .615 .705 r
F P
0 g
s
.45282 .51754 m .44775 .46524 L .55266 .4597 L p .686 .518 .653 r
F P
0 g
s
.54517 .61824 m .54839 .56637 L .63327 .57921 L p .746 .646 .749 r
F P
0 g
s
.54839 .56637 m .54517 .61824 L .47006 .62186 L p .692 .598 .747 r
F P
0 g
s
.47006 .62186 m .46047 .57074 L .54839 .56637 L p .692 .598 .747 r
F P
0 g
s
.55266 .4597 m .55096 .51251 L .45282 .51754 L p .686 .518 .653 r
F P
0 g
s
.46047 .57074 m .45282 .51754 L .55096 .51251 L p .691 .561 .703 r
F P
0 g
s
.55096 .51251 m .54839 .56637 L .46047 .57074 L p .691 .561 .703 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
KOooool@o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0GOoo
ool?o`0000coG00000Co0000ogl00?mo003oO`001ol0000Rooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1Iooooo`?o00000_lH00000ol0003oG000oe`0000Goe`00003o`000?mo003oO`0000KoO`002?l0
000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Eooooo`?o00001?lH00000ol0003oG000oe`0000A
oe`000_o00003?mo0007o`0001Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0X
ooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo053ooooo1?l00006oaP0
0003o`000?mL003oG00000?oG0003ol00007oh`N;P04o`000?n]>2Wo[CPYojdh:@Go00003Omo0004
o`0001;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`00
01[ooooo00?o0000ooooooooool0C?ooool3o`0000Oo60002Ol0000Foh`N;P03o`000?n]>2Wo[CPY
00Ko[CPY1_l0000:ogl000?o00004Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
02Kooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0B?ooool3o`0000Oo
60000ol00002oeT07P03o`000?n<7RkoS1h^01[oS1h^00?o0000ojdh:On]>2T03?n]>2T6o`0000Go
O`0000?o0000oh@00?l000000_l0000>ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14ooooo`?o0000
1_lH0004o`0000CoF@0N00?o0000oh`N;_n<7Rh07?n<7Rh00ol0003o[CPYojdh:@0Aojdh:@Go0000
00?oO`00o`000?n400000_n40002o`0000cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Uooooo`00:Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo0ol0
0005oaP000Co00002?mI01h00ol0003oS1h^oh`N;P0Loh`N;P03o`000?n]>2Wo[CPY01Ko[CPY1?l0
0003oh@000;o00002_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003o6000oaP00003
oaP000?o00003?mI01h00ol0003oS1h^oh`N;P0Doh`N;Pco00005on]>2T01?l0003o`T@;o`000?l0
0003oh@000;o00002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000X
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool2o`0000;o60001?l0000>
oeT07P03o`000?n<7RkoS1h^00GoS1h^4?l00008oim:HP04o`000?nlHF3o_65PokaQH0Go00004on]
>2T00ol0003o`T@;ol942`03o`0000;oQ0000_l00006ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03o`000?oooooooooo03Wooooo1Ol0000@
oeT07P[o00006?nOBV800ol0003o_65PokaQH006okaQH0Go00003_n]>2T00ol0003o`T@;ol942`03
ol942`;o00000_n40003o`0000?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0S
ooooo`00:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Kooooo1?l0000@oeT0
7P?o00000_mj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P00_o_65P1Ol0000:ojdh
:@03o`000?o2A0_o`T@;00Co`T@;0_l00003oh@000;o000000?oooooo`000?ooool0>_ooool00ol0
003oooooooooo`0Rooooo`00:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03?o
oooo1Ol0000>oeT07P?o00001Omj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P013o
_65P1Ol00005ojdh:@03o`000?o2A0_o`T@;00Ko`T@;0ol00002oh@000;o0000??ooool00ol0003o
ooooooooo`0Qooooo`00:?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo037ooooo
1Ol0000<oeT07P?o00002?mj:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P01Go_65P
1_l0000;ol942`;o000000?oQ000o`000?l00000>oooool00ol0003oooooooooo`0Qooooo`009ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo1_l0000:oeT07P?o00002omj
:E/00ol0003oWdYRoim:HP0Moim:HP03o`000?nlHF3o_65P01[o_65P0ol0000;ol942`;o000000?o
Q000o`000?l00000>_ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02cooooo1ol00007oeT07P?o00003_mj:E/00ol0003oWdYRoim:HP0M
oim:HP03o`000?nlHF3o_65P01_o_65P00Co0000omIcD_l0003o00002_o2A0/5o`0003Wooooo00?o
0000ooooooooool08?ooool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Y
ooooo`So00001OmI01h3o`00013oNRUK00?o0000oim:H_nOBV807_nOBV800ol0003o_65PokaQH00K
okaQH004o`000?oFLe;oeW=BomIcDP?o00001oo2A0/01?l0003o`T@;ol942oo2A0/2o`0003Wooooo
00?o0000ooooooooool07oooool002Oooooo0_l0000Yooooo`03o`000?oooooooooo02Oooooo2Ol0
0002oeT07P?o00004omj:E/00ol0003oWdYRoim:HP0Noim:HP03o`000?nlHF3o_65P01co_65P00?o
0000omIcD_oFLe800ooFLe82o`0000Go`T@;00?o0000ol942oo2A0/00oo2A0/00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09?ooool=o`0001KoNRUK00?o0000oim:H_nOBV805_nOBV8<o`0001_o_65P00?o0000
omIcD_oFLe801OoFLe82o`0000?o`T@;00?o0000ol942oo2A0/00oo2A0/2o`0003Sooooo00?o0000
ooooooooool07_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Roooo
o`_o00006Omj:E/00ol0003oWdYRoim:HP05oim:HQ7o00002?nXIH801?l0003o`GV1ol5iPOo1NH45
o`0001Ko_65P00?o0000omIcD_oFLe801ooFLe84o`0000Ko`T@;0_l0000hooooo`03o`000?oooooo
oooo01gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool08?ooool9o`00
0003ocT0@_l0003oNRUK01OoNRUK2_l0000IojQUPP03o`000?o1NH7o`GV100Ko`GV11Ol0000AokaQ
H003o`000?oFLe;oeW=B00[oeW=B0_l00006ol942`;o0000=oooool00ol0003oooooooooo`0Moooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01gooooo2_l00002ocT0@P03
o`000?mj:E_oNRUK01?oNRUK0ol00002ohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1
NH402oo1NH46o`0000_o_65P00?o0000omIcD_oFLe802_oFLe801?l0003oeW=Bo`000?l00004ol94
2`03o`000?ne=@3o000003Oooooo00?o0000ooooooooool07?ooool002Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Kooooo`Wo00000oli04800ol0003oNRUKogXYF`0AogXYF`?o
00001On:C7h00ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV1017o`GV11Ol00007okaQH003
o`000?oFLe;oeW=B00WoeW=B00Co0000omIcD_oFLe;oeW=B0_l00003ol942`03o`000?ne=@3o0000
03Oooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_ooooo`03o`000?oooooooooo01Wo
oooo2?l00005ocT0@P03o`000?mj:E_oNRUK00goNRUK1?l00008ohY<OP03o`000?nXIH;oZ6F201ko
Z6F200?o0000ol5iPOo1NH405_o1NH45o`0000;o_65P00?o0000omIcD_oFLe802_oFLe800ol0003o
eW=BomIcDP02omIcDPCo00000_ne=@000ol0003oooooooooo`0dooooo`03o`000?oooooooooo01_o
oooo000Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05oooool8o`0000Ko>@12
00?o0000ogXYFomj:E/02_mj:E/3o`0000coRTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1
ol5iP@0Kol5iP@Co00002ooFLe800ol0003oeW=BomIcDP05omIcDP;o00000_ne=@000ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool05_ooool6o`0000Oo>@1200?o0000ogXYFomj:E/02?mj:E/3o`0000oo
RTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Mol5iP@03o`000?oISG_o000000;o
00002?oFLe800ol0003oeW=BomIcDP07omIcDP;o000000?o]CD0o`000?ooool0=?ooool00ol0003o
ooooooooo`0Jooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`Go
00002Oli04800ol0003oNRUKogXYF`04ogXYF`Co00004_n:C7h00ol0003oZ6F2ojQUPP0NojQUPP03
o`000?o1NH7o`GV101go`GV100?o0000omV=NooISG/00_oISG/2o`0000KoeW=B00?o0000omIcD_oF
Le801ooFLe801Ol0003oigdXo`000?ne=@3o000003Gooooo00?o0000ooooooooool06Oooool000?o
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool04_ooool5o`0000[o>@1200Co0000ogXY
Fomj:E_oNRUK0ol0000FohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1NH407Oo1NH40
0ol0003ofHekomV=N`04omV=N`?o00000ooFLe800ol0003oeW=BomIcDP08omIcDP05o`000?oWOBSo
0000okDe0?l00000=Oooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo013ooooo1?l0000;ocT0@P03o`000?mj:E_o000000;o00006On:C7h00ol0003oZ6F2ojQU
PP0NojQUPP03o`000?o1NH7o`GV101go`GV100?o0000omV=NooISG/01ooISG/2o`000003omIcD_l0
003oeW=B00WoeW=B00Ko0000onMm:?oWOBSo0000okDe0?l0000dooooo`03o`000?oooooooooo01So
oooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`?o00002oli0483o`00
01coRTan00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Mol5iP@03o`000?oISG_ofHek
00WofHek0ol00009omIcDP07o`000?oWOBSoigdXonMm:?l0003o]CD0o`00000dooooo`03o`000?oo
oooooooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`06ooooo`;o0000>?ooool00ol0003oooooooooo`0=ooooo`;o00003?li04800ol0003oFbIdo`00
000MohY<OP03o`000?nXIH;oZ6F201koZ6F200?o0000ol5iPOo1NH407Oo1NH400ol0003ofHekomV=
N`0:omV=N`04o`000?oISG_o0000o`0000SoeW=B00Oo0000onMm:?oWOBSoigdXo`000?ne=@3o0000
03?ooooo00?o0000ooooooooool05oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0;oooo
o`03o`000?li04;o>@1200[o>@120_l00002oe/VM003o`000?n:C7koRTan01_oRTan00?o0000ojQU
P_nXIH805_nXIH8<o`0001go`GV100?o0000omV=NooISG/02OoISG/01?l0003ofHekomV=NooISG/2
o`0000KoeW=B00?o0000onMm:?oWOBP00_oWOBP00ol0003o]CD0o`00000cooooo`03o`000?oooooo
oooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`09ooooo`03o`000?li04;o>@1200Wo>@120_l00004
oe/VM003o`000?n:C7koRTan01_oRTan00?o0000ojQUP_nXIH801OnXIH8Ao`0000So[GNG00Co0000
ol:8Uoo2R9Oo`XRG1ol0000Fol5iP@03o`000?oISG_ofHek00WofHek00?o0000omV=NooISG/00ooI
SG/3o`0000CoeW=B00?o0000onMm:?oWOBP00_oWOBP00ol0003o]CD0o`00000aooooo`?o00005ooo
ool002Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03o`000?li04;o
>@1200So>@1200?o0000oe/VM?mK9W@01?mK9W@00ol0003oRTanohY<OP0IohY<OP[o00006On]MiL0
0ol0003o`XRGol:8U`08ol:8U`Oo00003oo1NH400ol0003ofHekomV=N`09omV=N`03o`000?oISG_o
fHek00KofHek0_l00002omIcDP03o`000?oWOBSoigdX00?oigdX0_l0000^ooooo`?o00000_ooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00Oooooo00?o0000ocT0@_li04801oli0482o`0000OoFbId00?o0000ohY<O_n:C7h05_n:C7h3o`00
00;oU6>F00?o0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0?ol:8U`Ko00002Oo1NH400ol0
003ofHekomV=N`09omV=N`03o`000?oISG_ofHek00SofHek0ol00006onMm:0;o0000:_ooool3o`00
00Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`05ooooo`;o00002?li04800ol0003oFbIdoe/VM007oe/VM003o`000?n:C7koRTan01?o
RTan0ol00005oiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L05Oo2R9L7o`0000;o
`GV100?o0000omV=NooISG/02OoISG/00ol0003ofHekomV=N`0;omV=N`;o00001OoWOBP2o`0002Ko
oooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool01?ooool2o`0000Ko>@120_l0000:oe/VM003o`000?n:C7koRTan00ooRTan
1?l00008oiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07?o2R9L4o`0000[ofHek
00?o0000omV=NooISG/02ooISG/00ol0003olZ9Yo`000005onMm:0;o00008_ooool3o`0000_ooooo
00?o0000ooooooooool05Oooool002Cooooo0_l0000oooooo`03o`000?oooooooooo00;ooooo0_l0
0006ocT0@P03o`000?mK9WCoFbId00[oFbId00?o0000ohY<O_n:C7h03?n:C7h3o`0000coU6>F00?o
0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0Nol:8U`04o`000?oHW9Go0000o`0000SofHek
00?o0000omV=NooISG/02ooISG/01?l0003olZ9Yoo:RJOl00005onMm:0;o00007_ooool3o`0000oo
oooo00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`03o`0000Co>@120_l0000=oe/VM003o`000?n:C7koRTan00WoRTan0ol0000?oiASUP03o`00
0?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L01?l0003of9bEomRLUOoHW9D2o`0000Ko
fHek00?o0000omV=NooISG/02ooISG/01Ol0003olZ9Yoo:RJOobXVWo000000GoigdX00?o0000oooo
ooooool06Oooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0@Oooool5o`0000;o>@120_l0000?oe/VM003o`000?n:C7koRTan00GoRTan1?l0000BoiASUP03
o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L00ol0003of9bEomRLU@03omRLU@?o
00000ooISG/00ol0003ofHekomV=N`0;omV=N`03o`000?obXVWolZ9Y00;olZ9Y00?o0000onMm:?oW
OBP00ooWOBP00ol0003oooooooooo`0Eooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`00
8oooool00ol0003oooooooooo`12ooooo`?o00000_li04800ol0003oFbIdoe/VM00?oe/VM003o`00
0?n:C7koRTan00;oRTan0ol0000FoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L0
7_o2R9L00ol0003of9bEomRLU@06omRLU@;o000000?ofHeko`000?oISG/03?oISG/00ol0003olZ9Y
oo:RJ@03oo:RJ@03o`000?oWOBSoigdX00?oigdX00?o0000ooooooooool04Oooool3o`0001Sooooo
00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@Oooool6o`0001;oFbId00?o
0000ohY<O_l000000_l0000IoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2
R9L00ol0003of9bEomRLU@08omRLU@?o00003?oISG/00ol0003olZ9Yoo:RJ@04oo:RJ@03o`000?oW
OBSoigdX00?oigdX00?o0000ooooooooool03Oooool3o`0001_ooooo00?o0000ooooooooool05?oo
ool002?ooooo00?o0000ooooooooool0@?ooool5o`0001?oFbId0ol0000LoiASUP03o`000?n]MiOo
[GNG01ko[GNG00?o0000ol:8Uoo2R9L07_o2R9L00ol0003of9bEomRLU@0:omRLU@;o00002ooISG/0
0ol0003olZ9Yoo:RJ@05oo:RJ@03o`000?oWOBSoigdX00;oigdX00?o0000ooooooooool02_ooool3
o`0001kooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@?ooool4o`00
01?oFbId00?o0000og19Tol000007OnDHiH00ol0003o[GNGojegU`0NojegU`03o`000?o2R9Oo`XRG
01ko`XRG00?o0000omRLUOoHW9D02_oHW9D01?l0003of9bEo`000?l00009omV=N`03o`000?obXVWo
lZ9Y00KolZ9Y00?o0000onMm:?oWOBP00_oWOBP00ol0003oooooooooo`06ooooo`?o00008Oooool0
0ol0003oooooooooo`0Dooooo`008oooool2o`00043ooooo1Ol0000Aoe/VM0;o00000_m`BI<00ol0
003oU6>FoiASUP0KoiASUP03o`000?n]MiOo[GNG01ko[GNG00?o0000ol:8Uoo2R9L07Oo2R9L00ol0
003of9bEomRLU@0;omRLU@04o`000?oHW9Gof9bEomRLU@;o00001ooISG/00ol0003olZ9Yoo:RJ@07
oo:RJ@05o`000?oWOBSoigdXonMm:?l000001Oooool3o`0002Gooooo00?o0000ooooooooool04ooo
ool002?ooooo00?o0000ooooooooool0?_ooool6o`0000ooFbId0_l00004og19T`03o`000?nDHiKo
U6>F01_oU6>F00?o0000ojegUon]MiL07_n]MiL00ol0003o`XRGol:8U`0Mol:8U`03o`000?oHW9Go
f9bE00_of9bE00?o0000omRLUOoHW9D00ooHW9D3o`0000CofHek00?o0000oo:RJOobXVT02?obXVT0
1?l0003oigdXonMm:?l00002ooooo`?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_ooool0
0ol0003oooooooooo`0nooooo`Go000000?o001Co`000?mK9W@03OmK9W@00ol0003oL4VCog19T`04
og19T`03o`000?nDHiKoU6>F01_oU6>F00?o0000ojegUon]MiL05_n]MiL<o`0001co`XRG00?o0000
omRLUOoHW9D02ooHW9D00ol0003of9bEomRLU@06omRLU@;o00000_oISG/00ol0003olZ9Yoo:RJ@09
oo:RJ@03o`000?oWOBSoigdX00;o0000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0
003oooooooooo`0nooooo`Go000000?o001Co`000?mK9W@02omK9W@2o`0000OoL4VC00?o0000oiAS
U_nDHiH06onDHiH00ol0003o[GNGojegU`05ojegUa7o00002?n_Q:L01?l0003o`YBWol:DYoo2U:L7
o`0001Go`XRG00?o0000omRLUOoHW9D02ooHW9D00ol0003of9bEomRLU@08omRLU@?o00003?obXVT0
0ol0003oigdXo`00000/ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
03gooooo1Ol00002o`00D`03o`000?mK9WCoFbId00SoFbId0_l00009og19T`03o`000?nDHiKoU6>F
01WoU6>F2_l0000Iojn4Y`03o`000?o2U:Oo`YBW00So`YBW1_l0000?ol:8U`03o`000?oHW9Gof9bE
00_of9bE00?o0000omRLUOoHW9D02_oHW9D2o`0000colZ9Y00?o0000onMm:?l00000:oooool00ol0
003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0looooo`Go00000ol005<00ol0003o
FbIdoe/VM007oe/VM003o`000?m`BI?oL4VC00WoL4VC00?o0000oiASU_nDHiH05_nDHiH3o`0000;o
VWBW00?o0000ojn4Yon_Q:L07_n_Q:L00ol0003o`YBWol:DY`0>ol:DY`Ko00002Oo2R9L00ol0003o
f9bEomRLU@0;omRLU@03o`000?oHW9Gof9bE00[of9bE00?o0000onndSol000003?obXVT2o`0002_o
oooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0??ooool4o`0000?o001C
00?o0000oe/VM?mK9W@01_mK9W@2o`0000goL4VC00?o0000oiASU_nDHiH04OnDHiH4o`0000GoVWBW
00?o0000ojn4Yon_Q:L07_n_Q:L00ol0003o`YBWol:DY`0Dol:DY`Oo00000_o2R9L00ol0003of9bE
omRLU@0;omRLU@03o`000?oHW9Gof9bE00[of9bE00Co0000onndSoo_]8oo00003?obXVT2o`0002[o
oooo00?o0000ooooooooool04oooool0027ooooo0ol0000looooo`Go00000ol005<00ol0003oFbId
oe/VM004oe/VM0;o00003om`BI<00ol0003oU6>FoiASUP0=oiASUPCo00002OnJM:L00ol0003o[hBW
ojn4Y`0Nojn4Y`03o`000?o2U:Oo`YBW01_o`YBW1?l0000<omRLU@03o`000?oHW9Gof9bE00[of9bE
00Go0000onndSoo_]8ookkB?o`00000<oo:RJ@03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04_ooool0027ooooo00?o0000ooooooooool0??ooool4o`0000Co001C00?o0000oe/VM?mK9W@0
0omK9W@00ol0003oL4VCog19T`0?og19T`03o`000?nDHiKoU6>F00[oU6>F0ol0000=oiYdY`03o`00
0?n_Q:Oo[hBW01ko[hBW00?o0000ol:DYoo2U:L07Oo2U:L00ol0003oe:JXo`000002o`0000Wof9bE
00?o0000omRLUOoHW9D02_oHW9D00ol0003okkB?onndS`02onndS`03o`000?obXVWolZ9Y00WolZ9Y
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`0looooo`?o00001Ol005<01?l0003oFbIdoe/VM?mK9W@2o`0001;oL4VC00?o0000oiASU_nDHiH0
1_nDHiH4o`00017oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBWol:DY`0Mol:DY`03o`00
0?oDYZSoe:JX00;oe:JX0_l00007omRLU@03o`000?oHW9Gof9bE00[of9bE00?o0000onndSoo_]8l0
0oo_]8l00ol0003olZ9Yoo:RJ@08oo:RJ@;o0000:_ooool00ol0003oooooooooo`0Booooo`008Ooo
ool00ol0003oooooooooo`0kooooo`Co00001Ol005<01?l0003oFbIdo`000?l0000Dog19T`03o`00
0?nDHiKoU6>F00;oU6>F1?l0000EoiYdY`03o`000?n_Q:Oo[hBW01go[hBW00?o0000ol:DYoo2U:L0
7Oo2U:L00ol0003oe:JXomBVZ004omBVZ0;o00001OoHW9D00ol0003of9bEomRLU@0:omRLU@03o`00
0?o_]8ookkB?00CokkB?00?o0000oo:RJOobXVT01oobXVT2o`0002[ooooo00?o0000ooooooooool0
4_ooool0027ooooo00?o0000ooooooooool0>oooool3o`0000Ko001C0_l0000Fog19T`03o`000?nD
HiKo000000;o00006OnJM:L00ol0003o[hBWojn4Y`0Mojn4Y`03o`000?o2U:Oo`YBW01co`YBW00?o
0000omBVZ?oDYZP01ooDYZP3o`0000;of9bE00?o0000omRLUOoHW9D02_oHW9D00ol0003okkB?onnd
S`05onndS`03o`000?obXVWolZ9Y00KolZ9Y0ol0000Yooooo`03o`000?oooooooooo01;ooooo000Q
ooooo`03o`000?oooooooooo03_ooooo0_l00007o`00D`03o`000?m`BI?oL4VC01CoL4VC0ol0000L
oiYdY`03o`000?n_Q:Oo[hBW01go[hBW00?o0000ol:DYoo2U:L07?o2U:L00ol0003oe:JXomBVZ00:
omBVZ0?o00002ooHW9D00ol0003okkB?onndS`07onndS`;o00001_obXVT00ol0003okJL]o`00000Y
ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03[ooooo0_l00008o`00
D`03o`000?m`BI?oL4VC01?oL4VC00?o0000ogeRZ?l000007OnJM:L00ol0003o[hBWojn4Y`0Mojn4
Y`03o`000?o2U:Oo`YBW01co`YBW00?o0000omBVZ?oDYZP03?oDYZP2o`0000[of9bE00?o0000onnd
Soo_]8l02Oo_]8l00ol0003olZ9Yoo:RJ@03oo:RJ@03o`000?o]Ybgo000002Wooooo00?o0000oooo
ooooool04_ooool0023ooooo0ol0000kooooo`;o00001ol005<2o`0001?oL4VC0_l00002ogeRZ003
o`000?nJM:OoVWBW01_oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBWol:DY`0Lol:DY`03
o`000?oDYZSoe:JX00coe:JX00?o0000omBVZ?l000000_l00007omRLU@03o`000?o_]8ookkB?00[o
kkB?00?o0000oo:RJOobXVT00oobXVT3o`0002Wooooo00?o0000ooooooooool04Oooool0023ooooo
00?o0000ooooooooool0>oooool00ol0003o001Co`00D`05o`00D`03o`000?l_78So0000017oL4VC
0_l00004ogeRZ003o`000?nJM:OoVWBW01_oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0003o`YBW
ol:DY`0Lol:DY`03o`000?oDYZSoe:JX00goe:JX00Co0000omBVZ?oDYZSoe:JX0_l00005omRLU@03
o`000?o_]8ookkB?00_okkB?00?o0000oo:RJOobXVT00_obXVT00ol0003okJL]o`00000Yooooo`03
o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0jooooo`03o`000?l005?o001C00Ko001C00Co0000oblLR?l_78So00003om`BI<00ol0
003oOF:XogeRZ005ogeRZ003o`000?nJM:OoVWBW01[oVWBW00?o0000ojn4Yon_Q:L07On_Q:L00ol0
003o`YBWol:DY`0Kol:DY`03o`000?oDYZSoe:JX00koe:JX00?o0000omBVZ?oDYZP00ooDYZP2o`00
00?of9bE00?o0000onndSoo_]8l03?o_]8l01_l0003olZ9Yoo:RJOobXVWo0000onfW;@;o0000:?oo
ool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0>_ooool00ol0003o001Co`00D`05o`00D`05o`000?l_78So;ab8oblLR?l00000
3Om`BI<2o`0000SoOF:X00?o0000oiYdYonJM:L06onJM:L00ol0003o[hBWojn4Y`0Lojn4Y`03o`00
0?o2U:Oo`YBW01_o`YBW00?o0000omBVZ?oDYZP03_oDYZP00ol0003oe:JXomBVZ005omBVZ0Co0000
3oo_]8l01?l0003olZ9Yoo:RJOl00002onfW;@03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo03[o
oooo00?o0000o`00Dol005<01?l005<00ol0003o;ab8oblLR002oblLR003o`000?m`BI?oL4VC00[o
L4VC00?o0000ogeRZ?mmHZP02?mmHZP00ol0003oVWBWoiYdY`0KoiYdY`03o`000?n_Q:Oo[hBW01co
[hBW00?o0000ol:DYoo2U:L06oo2U:L00ol0003oe:JXomBVZ00>omBVZ003o`000?oDYZSoe:JX00So
e:JX0_l0000?onndS`03o`000?obXVWo000000;okJL]00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0>_ooool00ol0003o001Co`00D`03o`00D`03o`000?l_78So;ab800?o;ab800?o0000og19Tom`
BI<02?m`BI<2o`0000_oOF:X00?o0000oiYdYonJM:L06onJM:L00ol0003o[hBWojn4Y`0=ojn4YaCo
00006Oo2U:L00ol0003oe:JXomBVZ00>omBVZ003o`000?oDYZSoe:JX00Soe:JX00?o0000onVmZ?l0
00003oo_]8l2o`0000;okJL]0_l0000Wooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0kooooo`03o`000?l005?o001C00?o
001C00?o0000oblLR?l_78P00ol_78P00ol0003oL4VCog19T`07og19T`03o`000?mmHZSoOF:X00_o
OF:X00?o0000oiYdYonJM:L06OnJM:LBo`0000oo/8nc00?o0000ol6M]?o1WK@00_o1WK@7o`0001;o
`YBW00?o0000omBVZ?oDYZP03_oDYZP00ol0003oe:JXomBVZ008omBVZ004o`000?oY_JSojKfXo`00
00ookkB?00Go0000onfW;Oo]YbgokJL]o`00000Wooooo`03o`000?oooooooooo017ooooo000Eoooo
o`05oa0@4?ooooooooooooooool@41001Oooool2o`0003cooooo00?o0000o`00Dol005<00_l005<0
0ol0003o;ab8oblLR004oblLR003o`000?m`BI?oL4VC00GoL4VC0_l0000?ogeRZ003o`000?nJM:Oo
VWBW01GoVWBW0ol00002oij2]@03o`000?n`Sk?o/8nc01co/8nc00?o0000ol6M]?o1WK@02Oo1WK@7
o`0000[o`YBW00?o0000omBVZ?oDYZP03ooDYZP00ol0003oe:JXomBVZ007omBVZ003o`000?oY_JSo
jKfX00;ojKfX00?o0000onndSoo_]8l03?o_]8l01Ol0003okJL]onfW;Oo]Ybgo000002Oooooo00?o
0000ooooooooool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oo
oooooooo03[ooooo0_l00003o`00D`03o`000?l_78So;ab800Go;ab800?o0000og19Tom`BI<00om`
BI<2o`00017oOF:X00?o0000oiYdYonJM:L04OnJM:L4o`0000GoWX:e00?o0000ok2?/on`Sk<07?n`
Sk<00ol0003o`Ifdol6M]00@ol6M]0Oo00000oo2U:L00ol0003oe:JXomBVZ00?omBVZ003o`000?oD
YZSoe:JX00Ooe:JX00?o0000onVmZ?oY_JP00ooY_JP00ol0003okkB?onndS`0;onndS`;o00000_o]
Ybd2o`0002Oooooo00?o0000ooooooooool04?ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo03[ooooo00?o0000o`00Dol005<00_l005<00ol0003o;ab8oblL
R006oblLR005o`000?m`BI?oL4VCog19Tol000004ommHZP00ol0003oVWBWoiYdY`0>oiYdY`?o0000
2OnNP[D00ol0003o/8ncok2?/`0Lok2?/`03o`000?o1WKCo`Ifd01Oo`Ifd1Ol0000@omBVZ003o`00
0?oDYZSoe:JX00Ooe:JX00?o0000onVmZ?oY_JP01?oY_JP00ol0003okkB?onndS`0:onndS`;o0000
0oo]Ybd00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oo
oooooooo03[ooooo00Go0000o`00Dol005?o001Co`000009oblLR004o`000?m`BI?o0000o`0001Co
OF:X00?o0000oiYdYonJM:L02_nJM:L4o`0000coWX:e00?o0000ok2?/on`Sk<07?n`Sk<00ol0003o
`Ifdol6M]00Jol6M]003o`000?o@[[Ko000000;o00003OoDYZP00ol0003oe:JXomBVZ007omBVZ003
o`000?oY_JSojKfX00GojKfX00?o0000onndSoo_]8l02?o_]8l00ol0003ooliho`000003onfW;@03
o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
>_ooool01?l0003o001Co`00Dol0000:oblLR0;o00005_mmHZP00ol0003oVWBWoiYdY`07oiYdY`?o
00004OnNP[D00ol0003o/8ncok2?/`0Kok2?/`03o`000?o1WKCo`Ifd01[o`Ifd00?o0000om2^]_o@
[[H00_o@[[H2o`0000_oe:JX00?o0000omBVZ?oDYZP01_oDYZP00ol0003ojKfXonVmZ007onVmZ0;o
00002?o_]8l01?l0003oolihooo>N?l00002onfW;@;o00009_ooool00ol0003oooooooooo`0@oooo
o`007oooool00ol0003oooooooooo`0jooooo`03o`000?l005?o000000_o;ab800?o0000ogeRZ?mm
HZP05_mmHZP00ol0003oVWBWoiYdY`02oiYdY`Co00005?nNP[D00ol0003o/8ncok2?/`0Kok2?/`03
o`000?o1WKCo`Ifd01Wo`Ifd00?o0000om2^]_o@[[H01Oo@[[H3o`0000Soe:JX00?o0000omBVZ?oD
YZP01_oDYZP00ol0003ojKfXonVmZ009onVmZ003o`000?o_]8ookkB?00GokkB?00Co0000ooo>N?oo
cWSo00000oo]Ybd00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo000Nooooo`03
o`000?oooooooooo03_ooooo00?o0000o`00Dol000002ol_78P00ol0003oOF:XogeRZ00FogeRZ003
o`000?nJM:Oo000000;o00006?nNP[D00ol0003o/8ncok2?/`0Kok2?/`03o`000?o1WKCo`Ifd01Wo
`Ifd00?o0000om2^]_o@[[H02?o@[[H2o`0000Koe:JX00?o0000omBVZ?oDYZP01_oDYZP00ol0003o
jKfXonVmZ00:onVmZ003o`000?o_]8ookkB?00CokkB?00Go0000ooo>N?oocWSooliho`000002onfW
;@03o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool001kooooo00?o0000oooooooo
ool0>oooool2o`0000_o;ab800?o0000odi5Yol000005_mmHZP3o`0001_oWX:e00?o0000ok2?/on`
Sk<06_n`Sk<00ol0003o`Ifdol6M]00Jol6M]003o`000?o@[[Kod:jf00[od:jf0ol00003omBVZ003
o`000?oDYZSoe:JX00Goe:JX00?o0000onVmZ?oY_JP03?oY_JP00ol0003okkB?onndS`03onndS`05
o`000?oocWSoolihooo>N?l000000_o]Ybd00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
013ooooo000Nooooo`;o0000??ooool00ol0003o;ab8oblLR009oblLR004o`000?m>AJOoCTFWo`00
01CoOF:X0_l000000on7M;So0000oij2]@0Koij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000ol6M
]?o1WK@06_o1WK@00ol0003od:jfom2^]P0=om2^]P;o000000?oe:JXo`000?oDYZP01_oDYZP00ol0
003ojKfXonVmZ00=onVmZ003o`000?o_]8ookkB?00;okkB?00Go0000ooo>N?oocWSooliho`000002
onfW;@03o`000?oooooooooo02Gooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooo
ooooool0>oooool00ol0003o;ab8oblLR008oblLR005o`000?m>AJOoCTFWodi5Yol000004ommHZP0
0ol0003oQgBhohMd^002ohMd^003o`000?nNP[GoWX:e01WoWX:e00?o0000ok2?/on`Sk<06_n`Sk<0
0ol0003o`Ifdol6M]00Iol6M]003o`000?o@[[Kod:jf013od:jf0ol00006omBVZ003o`000?oY_JSo
jKfX00kojKfX00Go0000onndSoo_]8ookkB?o`000004ooo>N003o`000?o]Ybgo000002Oooooo00?o
0000ooooooooool03oooool001kooooo00?o0000ooooooooool0>_ooool2o`0000[o;ab800?o0000
odi5Yom>AJL00_m>AJL00ol0003oOF:XogeRZ00>ogeRZ0;o00001On7M;P00ol0003oWX:eoij2]@0I
oij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000ol6M]?o1WK@06Oo1WK@00ol0003od:jfom2^]P0A
om2^]P04o`000?o@[[Ko0000o`0000Coe:JX00?o0000onVmZ?oY_JP03ooY_JP00ol0003okkB?o`00
0005ooo>N003o`000?o]Ybgo000002Oooooo00?o0000ooooooooool03oooool001kooooo00?o0000
ooooooooool0>_ooool2o`0000Wo;ab800?o0000odi5Yom>AJL00om>AJL00ol0003oOF:XogeRZ00<
ogeRZ0;o00001on7M;P00ol0003oWX:eoij2]@0Ioij2]@03o`000?n`Sk?o/8nc01[o/8nc00?o0000
ol6M]?o1WK@06Oo1WK@00ol0003od:jfom2^]P0Aom2^]P04o`000?o@[[Kod:jfom2^]PCo00004ooY
_JP2o`0000Goolih00?o0000onfW;Ol000009oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`0kooooo`03o`000?l005Go000000Oo;ab800?o0000odi5Yom>AJL01?m>AJL0
0ol0003oOF:XogeRZ00;ogeRZ003o`000?n7M;SoQgBh00SoQgBh00?o0000oij2]OnNP[D06?nNP[D0
0ol0003o/8ncok2?/`0Jok2?/`03o`000?o1WKCo`Ifd01Wo`Ifd00?o0000om2^]_o@[[H04Oo@[[H0
0ol0003od:jfom2^]P04om2^]P;o00004ooY_JP00ol0003oolihooo>N004ooo>N003o`000?o]Ybgo
000002Kooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0>oooool00ol0
003o001Eo`000006oblLR003o`000?m>AJOoCTFW00KoCTFW00?o0000ogeRZ?mmHZP02?mmHZP2o`00
00_oQgBh00?o0000oij2]OnNP[D06OnNP[D00ol0003o/8ncok2?/`0Iok2?/`03o`000?o1WKCo`Ifd
01Wo`Ifd00?o0000om2^]_o@[[H04_o@[[H00ol0003od:jfom2^]P03om2^]P03o`000?oQ`k[o0000
01;ojKfX00?o0000ooo>N?oocWP01?oocWP00ol0003okJL]o`00000Vooooo`03o`000?oooooooooo
00oooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000o`00EOl000001_l_78P00ol0003o
CTFWodi5Y`06odi5Y`03o`000?mmHZSoOF:X00KoOF:X0_l0000>ohMd^003o`000?nNP[GoWX:e01So
WX:e00?o0000ok2?/on`Sk<06On`Sk<00ol0003o`Ifdol6M]00Hol6M]003o`000?o@[[Kod:jf01?o
d:jf00?o0000om2^]_o@[[H00_o@[[H01Ol0003ohL>jon73^_oQ`k[o0000013ojKfX00?o0000oo_L
Y?l000001_oocWP2o`0002Kooooo00?o0000ooooooooool03oooool001gooooo0_l0000looooo`03
o`000?l005Go000000Go;ab800?o0000odi5Yom>AJL01om>AJL00ol0003oOF:XogeRZ005ogeRZ003
o`000?n7M;SoQgBh00koQgBh00?o0000oij2]OnNP[D06?nNP[D00ol0003o/8ncok2?/`0;ok2?/a;o
00005oo1WK@00ol0003od:jfom2^]P0Com2^]P03o`000?o@[[Kod:jf00;od:jf00?o0000on73^_oQ
`kX00_oQ`kX00ol0003ojKfXonVmZ00=onVmZ003o`000?okg:Co000000Koolih0_l0000Wooooo`03
o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000o`00EOl00000
1?l_78P00ol0003oCTFWodi5Y`09odi5Y`03o`000?mmHZSoOF:X00;oOF:X0_l0000AohMd^003o`00
0?nNP[GoWX:e01KoWX:e4?l0000>ok6I_`04o`000?nnYKoo_ZFookjU_`Oo00004?o1WK@00ol0003o
d:jfom2^]P0Com2^]P05o`000?o@[[Kod:jfom2^]_l000001_oQ`kX00ol0003ojKfXonVmZ00<onVm
Z003o`000?okg:Co000000Koolih0_l0000Wooooo`03o`000?oooooooooo00kooooo000Mooooo`03
o`000?oooooooooo03_ooooo00?o0000o`00EOl000000ol_78P00ol0003oCTFWodi5Y`0:odi5Y`03
o`000?mmHZSoOF:X00;o00005?n7M;P00ol0003oWX:eoij2]@0Aoij2]@Co00000_nQS/000ol0003o
/IVook6I_`0Iok6I_`03o`000?nnYKoo_ZFo00So_ZFo1_l0000:ol6M]003o`000?o@[[Kod:jf01?o
d:jf00Go0000om2^]_o@[[Kod:jfo`000007on73^P03o`000?oY_JSojKfX00[ojKfX00Go0000oo_L
Y?okg:ConmbTo`000006ooo>N003o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool0
01cooooo00?o0000ooooooooool0??ooool00ol0003o001Eo`000003oblLR003o`000?m>AJOoCTFW
00[oCTFW00?o0000ogeRZ?l000005_n7M;P00ol0003oWX:eoij2]@0=oij2]@Co00001_nQS/000ol0
003o/IVook6I_`0Iok6I_`03o`000?nnYKoo_ZFo00ko_ZFo1ol00002ol6M]003o`000?o@[[Kod:jf
01Cod:jf00Co0000om2^]_o@[[Ko00002OoQ`kX00ol0003ojKfXonVmZ009onVmZ005o`000?okg:Co
nmbToo_LY?l000001_oocWP00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo03cooooo00Ko0000o`00EOl005Go0000oblLR?l0000>odi5Y`03o`00
0?n7M;SoQgBh01KoQgBh00?o0000oij2]OnNP[D02?nNP[D4o`0000[oXHk000?o0000ok6I_onaVKl0
6OnaVKl00ol0003o_ZFookjU_`0EokjU_`Co00005Oo@[[H01?l0003od:jfom2^]_l0000:on73^P;o
00002OoY_JP00ol0003onmbToo_LY002oo_LY003o`000?oocWSoolih00?oolih00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0looooo`03o`00
0?l005Go001E00;o00003om>AJL00ol0003oQgBhohMd^00FohMd^003o`000?nNP[GoWX:e00CoWX:e
1?l0000?oj6>`003o`000?naVKoo/IVo01So/IVo00?o0000okjU_onnYKl05onnYKl00ol0003oc;?2
o`000002o`0001;od:jf00?o0000om2^]_l000003OoQ`kX00ol0003ojKfXonVmZ005onVmZ003o`00
0?okg:ConmbT00?onmbT00?o0000ooo>N?oocWP00ooocWP00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00kooooo000Looooo`03o`000?oooooooooo03_ooooo0_l00002o`00E@03o`000?m>
AJOoCTFW00goCTFW00?o0000ofAS_?l000005on7M;P00ol0003oWX:eoij2]@04o`0001?oXHk000?o
0000ok6I_onaVKl06?naVKl00ol0003o_ZFookjU_`0FokjU_`03o`000?o</l;oc;?200?oc;?20ol0
000=om2^]P?o000000?od:jfo`000?oQ`kX03OoQ`kX00ol0003ojKfXonVmZ004onVmZ003o`000?ok
g:ConmbT00?onmbT00?o0000ooo>N?oocWP00_oocWP00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo03_ooooo00Go0000o`00EOl005Go001Eo`00
000>odi5Y`04o`000?mTHkcoI6>lo`0001OoQgBh0ol0000Goj6>`003o`000?naVKoo/IVo01So/IVo
00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P06olbc`P?o00001oo@[[H3o`0000;od:jf
00?o0000om2^]_l000003ooQ`kX00ol0003ojKfXonVmZ003onVmZ003o`000?okg:ConmbT00ConmbT
00Go0000ooo>N?oocWSooliho`00000Yooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000
??ooool01_l0003o001Eo`00EOl005Go00nHo`0000coCTFW00?o0000ofAS_?mTHk`00_mTHk`00ol0
003oQgBhohMd^00BohMd^0;o000000?oSXC4o`000?nQS/005onQS/000ol0003o/IVook6I_`0Hok6I
_`03o`000?nnYKoo_ZFo01Ko_ZFo00?o0000olbc`_o</l802Oo</l82o`0000;od:jf0ol00006om2^
]P03o`000?oQ`k[ohL>j00oohL>j00Go0000onVmZ?oY_JSojKfXo`000007oo_LY005o`000?oocWSo
olihooo>N?l00000:Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0l
ooooo`06o`000?l005Go001Eo`00EOl03iSo00002om>AJL00ol0003oI6>lofAS_003ofAS_003o`00
0?n7M;SoQgBh017oQgBh00?o0000ohj4a?n>Q<@00_n>Q<@00ol0003oXHk0oj6>`00Eoj6>`003o`00
0?naVKoo/IVo01Oo/IVo00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P0;olbc`PCo0000
2?o@[[H2o`00017ohL>j00Co0000onVmZ?oY_JSo00001ookg:@01Ol0003oolihooo>N?oocWSo0000
02Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0??ooool01_l0003o
001Eo`00EOl005Go00nHo`0000_oCTFW00?o0000ofAS_?mTHk`01?mTHk`00ol0003oQgBhohMd^00>
ohMd^0;o00001On>Q<@00ol0003oXHk0oj6>`00Foj6>`003o`000?naVKoo/IVo01Ko/IVo00?o0000
okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P07olbc`PCo00001?o</l83o`0000Cod:jf00Co0000
on73^_oQ`k[o00004OoQ`kX00ol0003ojKfXo`000008oo_LY004o`000?oocWSooliho`0002Wooooo
00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0??ooool01?l0003o001Eo`00
EOl00002o`0?V003o`000?m>AJOoCTFW00OoCTFW00?o0000ofAS_?mTHk`01OmTHk`00ol0003oQgBh
ohMd^00<ohMd^0;o00001on>Q<@00ol0003oXHk0oj6>`00Foj6>`003o`000?naVKoo/IVo01Ko/IVo
00?o0000okjU_onnYKl05_nnYKl00ol0003oc;?2olbc`P04olbc`P?o00002oo</l83o`000003om2^
]_l0003ohL>j00;ohL>j00?o0000on73^_oQ`kX03ooQ`kX00ol0003onmbToo_LY007oo_LY004o`00
0?oocWSooliho`0002Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
??ooool01?l0003o001Eo`00EOl00002o`0?V003o`000?m>AJOoCTFW00KoCTFW00?o0000ofAS_?mT
Hk`01omTHk`00ol0003oQgBhohMd^009ohMd^0;o00002_n>Q<@00ol0003oXHk0oj6>`00Eoj6>`003
o`000?naVKoo/IVo01Ko/IVo00?o0000okjU_onnYKl05OnnYKl00ol0003oc;?2olbc`P02olbc`P?o
00004Oo</l82o`0000?ohL>j00?o0000on73^_oQ`kX03ooQ`kX00ol0003onmbToo_LY008oo_LY003
o`000?oocWSo000002Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
??ooool01?l0003o001Eo`00EOl00003o`0?V003o`000?m>AJOoCTFW00CoCTFW00?o0000ofAS_?mT
Hk`02?mTHk`00ol0003oQgBhohMd^008ohMd^003o`000?n>Q<CoSXC400[oSXC400?o0000oj6>`?nQ
S/005OnQS/000ol0003o/IVook6I_`0Fok6I_`03o`000?nnYKoo_ZFo01Go_ZFo00?o0000olbc`_l0
00000_l0000Dolbc`P03o`000?oIa/Oo000000?ohL>j00?o0000on73^_oQ`kX03OoQ`kX00ol0003o
l=nno`000009oo_LY0;o0000:_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003ooooo
ooooo`0looooo`04o`000?l005Go001Eo`0000?o00nH00?o0000odi5Yom>AJL00om>AJL00ol0003o
I6>lofAS_00:ofAS_003o`000?n7M;SoQgBh00GoQgBh0_l0000>ohj4a003o`000?nQS/3oXHk001Co
XHk000?o0000ok6I_onaVKl05_naVKl00ol0003o_ZFookjU_`0CokjU_`Co00005_o</l801Ol0003o
fLK7omW6aooIa/Oo000000?ohL>j00?o0000on73^_oQ`kX02ooQ`kX01?l0003ol=nnoo3O__l00009
oo_LY0;o0000:_ooool00ol0003oooooooooo`0=ooooo`006oooool2o`0003kooooo00?o0000o`00
EOl000000ol03iP00ol0003oCTFWodi5Y`03odi5Y`03o`000?mTHkcoI6>l00[oI6>l00?o0000ohMd
^?n7M;P00on7M;P2o`00013oSXC400?o0000oj6>`?nQS/005OnQS/000ol0003o/IVook6I_`0Eok6I
_`03o`000?nnYKoo_ZFo013o_ZFo0ol000000onnYKoo0000olbc`P0Golbc`P03o`000?oIa/OofLK7
00;ofLK700Go0000on73^_oQ`k[ohL>jo`00000<on73^P05o`000?o`gkkol=nnoo3O__l000002Ook
g:@00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooo
oooo03kooooo00?o0000o`00EOl000001?l03iP01Ol0003oCTFWodi5Yom>AJOo000000koI6>l00Go
0000ohMd^?n7M;SoQgBho`00000Bohj4a003o`000?nQS/3oXHk001GoXHk000?o0000ok6I_onaVKl0
2OnaVKlAo`0000_o_ZFo0ol00004okjU_`03o`000?o</l;oc;?201Goc;?200?o0000omW6aooIa/L0
1?oIa/L2o`0000;ohL>j00?o0000on73^_oQ`kX02?oQ`kX00ol0003ol=nnoo3O_P02oo3O_P03o`00
0?okg:ConmbT00OonmbT00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`0000Co
<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03kooooo00?o0000o`00EOl000001?l03iP01?l0003oCTFWodi5Yol0000?ofAS
_004o`000?n7M;So0000o`0001CoSXC400?o0000oj6>`?nQS/004_nQS/0>o`0000co/:;900?o0000
okb/bOnl[<T00_nl[<T7o`000004okjU_ol0003o0000o`0000Oo_ZFo00?o0000olbc`_o</l805?o<
/l800ol0003ofLK7omW6a`07omW6a`04o`000?oQ`k[ohL>jo`0000WohL>j00?o0000oo3O__o`gkh0
0_o`gkh00ol0003onmbToo_LY006oo_LY0;o0000:oooool00ol0003oooooooooo`0<ooooo`0000Co
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0nooooo`03o`000?l005Go000000Co00nH00?o0000odi5Yol000004OmTHk`00ol0003oSXC4
ohj4a00Dohj4a003o`000?nQS/3oXHk000koXHk01?l00002oj>Ib`03o`000?n`X/Wo/:;901Go/:;9
00?o0000okb/bOnl[<T01_nl[<T:o`0000?o_ZFo00?o0000olbc`_o</l805Oo</l800ol0003ofLK7
omW6a`08omW6a`03o`000?oQ`k[o000000SohL>j00?o0000oo3O__o`gkh01?o`gkh00ol0003onmbT
oo_LY005oo_LY0;o0000:oooool00ol0003oooooooooo`0<ooooo`000oooool00ol@413ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003o001Eo`00
0005o`0?V003o`000?mTHkcoI6>l013oI6>l00?o0000ohj4a?n>Q<@05On>Q<@00ol0003oXHk0oj6>
`008oj6>`0Go00001_nSVL/00ol0003o/:;9ok2Rb@0Eok2Rb@03o`000?nl[<Wo_:c900?o_:c90ol0
000:okb/b@Co00005_o</l800ol0003ofLK7omW6a`0:omW6a`03o`000?oQ`k[o000000KohL>j00?o
0000oo3O__o`gkh01Oo`gkh00ol0003onmbToo_LY005oo_LY003o`000?oooooooooo02[ooooo00?o
0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo03kooooo0_l00006o`0?V003o`000?mTHkcoI6>l00ooI6>l00?o0000
og=jbol000005_n>Q<@00ol0003oXHk0oj6>`004oj6>`0Co00003?nSVL/00ol0003o/:;9ok2Rb@0D
ok2Rb@03o`000?nl[<Wo_:c900?o00004?nl[<T00ol0003oakS=o`000002o`0001;oc;?200?o0000
omW6aooIa/L02ooIa/L3o`0000GohL>j00?o0000oo3O__o`gkh01_o`gkh00ol0003onmbToo_LY003
oo_LY0;o0000;?ooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0:oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0oooooo`03o`000?l03iSo
00nH00Co00nH00?o9DNmo`000?mTHk`03_mTHk`01Ol0003oLg[;og=jbomcN/_o000001GoSXC400?o
0000oj6>`?nQS/001?l0000@oj>Ib`03o`000?n`X/Wo/:;901Co/:;90ol0000Bokb/b@03o`000?o7
^<goakS=00?oakS=0ol0000>olbc`P03o`000?oIa/OofLK700kofLK70_l00003on73^P03o`000?o`
gkkol=nn00Ool=nn00?o0000oo_LY?okg:@00ookg:@2o`0002cooooo00?o0000ooooooooool03?oo
ool000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo043ooooo00?o0000o`0?V?l03iP01?l03iP00ol0003o9DNmo`00000=ofAS_003o`000?mcN/_o
Lg[;00;oLg[;00?o0000ohj4a?n>Q<@04on>Q<@3o`0001CoXiW;00?o0000ok2RbOn`X/T04?n`X/T5
o`0001Co_:c900?o0000olNhcOo7^<d01_o7^<d3o`0000_oc;?200?o0000omW6aooIa/L03ooIa/L2
o`0000;ohL>j00?o0000oo3O__o`gkh02?o`gkh01ol0003onmbToo_LY?okg:Co0000on7VNol00000
;Oooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003ooooo
ooooo`06ooooo`;o0000@Oooool00ol0003o00nHo`0?V004o`0?V003o`000?lUAkgo000000coI6>l
00?o0000og=jbomcN//01?mcN//00ol0003oSXC4ohj4a00@ohj4a0;o000000?oTi;?o`000?nSVL/0
5?nSVL/00ol0003o/:;9ok2Rb@0=ok2Rb@?o00001?n`X/T00ol0003o_:c9okb/b@0Bokb/b@03o`00
0?o7^<goakS=00WoakS=0_l00008olbc`P03o`000?oIa/OofLK7017ofLK700?o0000on73^_l00000
2oo`gkh01ol0003onmbToo_LY?okg:Co0000on7VNol00000;Oooool00ol0003oooooooooo`0;oooo
o`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo00?o0000ooooooooool0@?ooool00ol0
003o00nHo`0?V003o`0?V005o`000?lUAkgo9DNmobE7_Ol000002_mTHk`00ol0003oLg[;og=jb`06
og=jb`03o`000?n>Q<CoSXC400koSXC400?o0000oi>BconCT/l00_nCT/l00ol0003oXiW;oj>Ib`0C
oj>Ib`03o`000?n`X/Wo/:;900Wo/:;90ol00006ok2Rb@03o`000?nl[<Wo_:c901;o_:c900?o0000
olNhcOo7^<d03?o7^<d3o`0000Coc;?200?o0000omW6aooIa/L04ooIa/L00ol0003ol=nnoo3O_P0:
oo3O_P06o`000?okg:ConmbTo`000?oQiW_o0000;_ooool00ol0003oooooooooo`0;ooooo`006Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?l03iSo00nH00;o00nH00?o0000obE7_OlUAkd00_lU
Akd00ol0003oI6>lofAS_006ofAS_003o`000?mcN/_oLg[;00SoLg[;00?o0000ohj4a?n>Q<@02on>
Q<@2o`0000GoTi;?00?o0000oj>IbonSVL/04onSVL/00ol0003o/:;9ok2Rb@06ok2Rb@?o00002On`
X/T00ol0003o_:c9okb/b@0Bokb/b@03o`000?o7^<goakS=00ooakS=0ol000000oo</l;o0000omW6
a`0DomW6a`;o00003?o`gkh01Ol0003onmbTo`000?oQiW_o000002kooooo00?o0000ooooooooool0
2oooool001Wooooo00?o0000ooooooooool0@Oooool00ol0003o00nHo`0?V002o`0?V003o`000?lU
Akgo9DNm00;o9DNm00?o0000ofAS_?mTHk`01_mTHk`00ol0003oLg[;og=jb`08og=jb`03o`000?n>
Q<CoSXC400WoSXC40_l00008oi>Bc`03o`000?nSVL_oXiW;01;oXiW;00?o0000ok2RbOn`X/T00_n`
X/T4o`0000co/:;900?o0000okb/bOnl[<T04_nl[<T00ol0003oakS=olNhc@0BolNhc@;o00005?oI
a/L01?l0003oi=k?o`000?l0000;oo3O_P05o`000?okg:Co0000on7VNol00000;_ooool00ol0003o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`11ooooo`03o`000?l03iSo00nH00;o00nH
00?o0000obE7_OlUAkd00olUAkd00ol0003oI6>lofAS_004ofAS_003o`000?mcN/_oLg[;00[oLg[;
00?o0000ohj4a?n>Q<@01_n>Q<@2o`0000[oTi;?00?o0000oj>IbonSVL/04onSVL/4o`00013o/:;9
00?o0000okb/bOnl[<T04Onl[<T00ol0003oakS=olNhc@0ColNhc@03o`000?o@b=;o000001;ofLK7
00Ko0000onCNcooTg/oo0000oo3O__l0000;oo3O_P04o`000?oQiW_ohNIko`0002kooooo00?o0000
ooooooooool02oooool001Sooooo00?o0000ooooooooool0@oooool01Ol0003o00nHo`0?V?l03iSo
000000Ko9DNm00?o0000ofAS_?mTHk`00_mTHk`00ol0003oLg[;og=jb`0<og=jb`03o`000?n>Q<Co
SXC400?oSXC40_l0000=oi>Bc`03o`000?nSVL_oXiW;013oXiW;0ol0000Cok2Rb@03o`000?nl[<Wo
_:c9017o_:c900?o0000olNhcOo7^<d04_o7^<d01Ol0003od<SBom38d_o@b=;o0000013ofLK700?o
0000onCNcooTg/l00_oTg/l00ol0003ol=nno`00000:oo3O_P04o`000?oQiW_ohNIko`0002kooooo
00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool0@oooool01Ol0003o00nHo`0?
V?l03iSo000000Ko9DNm00Go0000ofAS_?mTHkcoI6>lo`00000?og=jb`03o`000?n>Q<CoSXC400;o
SXC400?o0000oi>BconCT/l03OnCT/l00ol0003oXiW;oj>Ib`0=oj>Ib`?o00000_nSVL/00ol0003o
/:;9ok2Rb@0Aok2Rb@03o`000?nl[<Wo_:c9017o_:c900?o0000olNhcOo7^<d04Oo7^<d00ol0003o
d<SBom38dP03om38dP03o`000?oIa/OofLK700gofLK700?o0000onCNcooTg/l00_oTg/l00ol0003o
l=nno`000009oo3O_P;o000000?ohNIko`000?ooool0;oooool00ol0003oooooooooo`0:ooooo`00
6?ooool00ol0003oooooooooo`14ooooo`04o`000?l03iSo00nHo`0000Oo9DNm00?o0000ofAS_?l0
00004OmcN//01?l0003oSXC4o`000?l0000Aoi>Bc`03o`000?nSVL_oXiW;00SoXiW;1?l00005oj>I
b`03o`000?n`X/Wo/:;9017o/:;900?o0000okb/bOnl[<T04?nl[<T00ol0003oakS=olNhc@0BolNh
c@03o`000?o@b=;od<SB00Cod<SB00?o0000omW6aooIa/L02ooIa/L00ol0003oi=k?onCNc`04onCN
c`03o`000?o`gkko000000Ool=nn0_l00002on7VN`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02_ooool001Sooooo0_l00015ooooo`04o`000?l03iSo00nHo`0000So9DNm00?o0000og=j
bomcN//04OmcN//00ol0003oTi;?oi>Bc`0Aoi>Bc`03o`000?nSVL_oXiW;00GoXiW;0ol0000:oj>I
b`03o`000?n`X/Wo/:;900Oo/:;93ol0000=okb/b@03o`000?o7^<goakS=017oakS=00?o0000om38
d_o@b=801_o@b=82o`0000[ofLK700?o0000onCNcooTg/l01OoTg/l01?l0003ol=nnoo3O__l00005
oo3O_P03o`000?o[nKKo000000;ohNIk00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:
ooooo`006?ooool00ol0003oooooooooo`15ooooo`;o00002OlUAkd00ol0003oLg[;og=jb`0Aog=j
b`03o`000?nCT/ooTi;?01;oTi;?00Co0000oj>IbonSVL_oXiW;0ol0000;oj>Ib`co00002On_Z]<0
0ol0003o^;;CokRbd`03okRbd`Wo00001?nl[<T00ol0003oakS=olNhc@0@olNhc@03o`000?o@b=;o
d<SB00Wod<SB00?o0000omW6aooIa/L01_oIa/L00ol0003oi=k?onCNc`07onCNc`04o`000?o`gkko
l=nno`0000Col=nn00?o0000on_i]_l000000_oQiW/00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00[ooooo000Hooooo`03o`000?oooooooooo04Gooooo0_l00009obE7_@;o00004OmcN//0
0ol0003oP8cFo`00000Coi>Bc`Co00002OnSVL/5o`0000;oY:?D00?o0000ojnZdon_Z]<04?n_Z]<0
0ol0003o^;;CokRbd`0<okRbd`Co00004_o7^<d00ol0003od<SBom38dP0;om38dP03o`000?oIa/Oo
fLK700CofLK700?o0000onCNcooTg/l02?oTg/l01Ol0003ol=nnoo3O__o`gkko000000;ol=nn00Ko
0000on_i]_o[nKKo0000on7VNol0000aooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`00
0?oooooooooo04Kooooo0_l00009obE7_@03o`000?m:K=;o000000ooLg[;00Go0000oh2<e_n0S=Ko
P8cFo`00000?oi>Bc`Go00001onSVL/4o`0000OoY:?D00?o0000ojnZdon_Z]<04?n_Z]<00ol0003o
^;;CokRbd`0?okRbd`03o`000?o1_=Ko000000;o00003_o7^<d00ol0003od<SBom38dP0<om38dP03
o`000?oIa/OofLK700?ofLK700?o0000onCNcooTg/l02OoTg/l01_l0003ol=nnoo3O__l0003ol=nn
o`0000?ojoVf00?o0000on7VNol00000<Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0
003oooooooooo`17ooooo`03o`000?lUAkgo9DNm00Ko9DNm00Go0000odY/d_m:K=;oBVcBo`00000=
og=jb`03o`000?n0S=KoP8cF00?oP8cF00?o0000oi>BconCT/l02OnCT/l3o`0000CoTi;?00?o0000
oj>IbonSVL/01Ol0000<ojBSe003o`000?n_Z]?o[j[C00ko[j[C00?o0000okRbdonh/]<03onh/]<0
0ol0003o`KcFol6leP03ol6leP;o00002oo7^<d00ol0003od<SBom38dP0>om38dP05o`000?oIa/Oo
fLK7omW6aol000003?oTg/l01?l0003ol=nnoo3O__o`gkh2o`0000;ojoVf00?o0000on7VNol00000
<_ooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`17ooooo`03o`000?lU
Akgo9DNm00Ko9DNm00?o0000odY/d_m:K=800_m:K=800ol0003oLg[;og=jb`09og=jb`03o`000?n0
S=KoP8cF00GoP8cF00?o0000oi>BconCT/l01OnCT/l3o`0000OoTi;?0ol0000AojBSe003o`000?n_
Z]?o[j[C00ko[j[C00?o0000okRbdonh/]<03onh/]<00ol0003o`KcFol6leP05ol6leP?o00001oo7
^<d00ol0003od<SBom38dP0@om38dP03o`000?oIa/Oo000000koi=k?00?o0000oo3O__o`gkh00_l0
0002on_i]P03o`000?oQiW_o000003?ooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000
ooooooooool0B?ooool00ol0003o9DNmobE7_@05obE7_@03o`000?m:K=;oBVcB00?oBVcB00?o0000
og=jbomcN//01omcN//00ol0003oP8cFoh2<eP07oh2<eP04o`000?nCT/ooTi;?oi>Bc`?o00002?nC
T/l2o`000003oiRNf?l0003oY:?D017oY:?D00?o0000ojnZdon_Z]<03_n_Z]<00ol0003o^;;CokRb
d`0>okRbd`03o`000?o1_=Ko`KcF00Wo`KcF0_l00005olNhc@03o`000?o@b=;od<SB017od<SB00?o
0000onCNcooTg/l03OoTg/l00ol0003ol=nno`000002on_i]P04o`000?o[nKKo0000o`0003Cooooo
00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0B?ooool2o`0000Ko9DNm00?o
0000odY/d_m:K=801?m:K=800ol0003oLg[;og=jb`05og=jb`03o`000?n0S=KoP8cF00SoP8cF1?l0
0009oi>Bc`;o00001?nHW]P00ol0003oY:?DojBSe00?ojBSe003o`000?n_Z]?o[j[C00ko[j[C00?o
0000okRbdonh/]<03_nh/]<00ol0003o`KcFol6leP0;ol6leP?o000000?oakS=o`000?o@b=804Oo@
b=800ol0003oem_Jo`00000@onCNc`03o`000?o[nKKojoVf00;ojoVf0ol0000dooooo`03o`000?oo
oooooooo00Wooooo000Gooooo`03o`000?oooooooooo04Wooooo00?o00nNo`000?lUAkd01?lUAkd0
0ol0003oBVcBodY/dP05odY/dP03o`000?mcN/_oLg[;00?oLg[;00?o0000oh2<e_n0S=H01_n0S=H3
o`000003oh2<e_l0003oTi;?00SoTi;?0_l00007oiRNf003o`000?nTXmCoY:?D00ooY:?D00?o0000
ojnZdon_Z]<03On_Z]<00ol0003o^;;CokRbd`0=okRbd`03o`000?o1_=Ko`KcF00oo`KcF0_l0000A
om38dP05o`000?oGfm[oem_JomOKf_l000003OoTg/l00ol0003ohoSDo`000004on_i]P?o0000=?oo
ool00ol0003oooooooooo`09ooooo`005oooool2o`0004[ooooo00?o0000o`0?W_l000001?lUAkd0
0ol0003oBVcBodY/dP06odY/dP05o`000?mcN/_oLg[;og=jbol000001_n0S=H3o`0000GoP8cF00?o
0000oi>BconCT/l01OnCT/l00ol0003oV9kHoiRNf007oiRNf003o`000?nTXmCoY:?D00ooY:?D00?o
0000ojnZdon_Z]<03On_Z]<00ol0003o^;;CokRbd`0=okRbd`03o`000?o1_=Ko`KcF00oo`KcF00?o
0000olO9fol000003oo@b=800ol0003oem_JomOKfP02omOKfP03o`000?oTg/ooi=k?00[oi=k?00Co
0000on?he?oSn=Co00001?o[nKH2o`0003Gooooo00?o0000ooooooooool02Oooool001Kooooo00?o
0000ooooooooool0Boooool00ol03iko0000obE7_@03obE7_@03o`000?m:K=;oBVcB00OoBVcB00?o
0000og=jbol000001?n0S=H3o`0000WoP8cF00?o0000oi>BconCT/l00_nCT/l2o`0000_oV9kH00?o
0000ojBSe?nTXm@03_nTXm@00ol0003o[j[CojnZd`0=ojnZd`03o`000?nh/]?o^;;C00go^;;C00?o
0000ol6le_o1_=H03_o1_=H01Ol0003oalWKolO9foo7bM_o000000god<SB00?o0000omOKf_oGfmX0
1?oGfmX00ol0003oi=k?onCNc`08onCNc`05o`000?oSn=CohoSDon?he?l000001?o[nKH3o`0003Co
oooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0Boooool00ol0003o00nN
o`000002obE7_@03o`000?m:K=;oBVcB00WoBVcB1_l0000=oh2<eP04o`000?nCT/oo0000o`0000ko
V9kH00?o0000ojBSe?nTXm@03OnTXm@00ol0003o[j[CojnZd`0<ojnZd`03o`000?nh/]?o^;;C00go
^;;C00?o0000ol6le_o1_=H03_o1_=H00ol0003oalWKolO9f`03olO9f`;o00002_o@b=800ol0003o
em_JomOKfP05omOKfP03o`000?oTg/ooi=k?00Ooi=k?00Go0000on?he?oSn=CohoSDo`000005on_i
]P04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooo
ooooool0C?ooool01Ol0003o00nNo`000?lUAkgo000000[oBVcB1?l0000Aoh2<eP;o00003onHW]P0
0ol0003oY:?DojBSe00>ojBSe003o`000?n_Z]?o[j[C00_o[j[C00?o0000okRbdonh/]<03Onh/]<0
0ol0003o`KcFol6leP0=ol6leP03o`000?o7bM_oalWK00KoalWK00?o0000om38d_o@b=801_o@b=80
0ol0003oem_JomOKfP07omOKfP03o`000?oTg/ooi=k?00Goi=k?00?o0000on?he?oSn=@00_oSn=@0
0ol0003ojoVfon_i]P03on_i]P05o`000?ooooooooooooooool00000<_ooool00ol0003ooooooooo
o`09ooooo`005_ooool00ol0003oooooooooo`1<ooooo`03o`000?l03iko00nN00;o00001om:K=83
o`000005odY/d_l0003oI8KOofB6gol000004?n0S=H2ohVKgP03o`000?nHW]SoV9kH00goV9kH00?o
0000ojBSe?nTXm@02onTXm@Eo`0000[o^;;C00?o0000ol6le_o1_=H03Oo1_=H00ol0003oalWKolO9
f`08olO9f`;o00001Oo@b=800ol0003oem_JomOKfP09omOKfP03o`000?oTg/ooi=k?00?oi=k?00?o
0000on?he?oSn=@00ooSn=@00ol0003ojoVfon_i]P02on_i]P03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1<
ooooo`04o`000?l03iko00nNo`0?WP;o00000om:K=83o`0000CoBVcB00Go0000ofB6gomTQ]ooI8KO
o`00000>oh2<eP05o`000?n9VmkoRI_NohVKg_l000003onHW]P00ol0003oY:?DojBSe007ojBSe0?o
00000_nU[Md00ol0003o[K;Lojfbg00;ojfbg003o`000?nd^=co];SL00;o];SL1ol00003okRbd`03
o`000?o1_=Ko`KcF00co`KcF00?o0000olO9foo7bM/02oo7bM/01Ol0003od<SBom38d_o@b=;o0000
00coem_J00?o0000onCNcooTg/l00_oTg/l00ol0003ohoSDon?he004on?he005o`000?o[nKKojoVf
on_i]_l000001_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Foooo
o`03o`000?oooooooooo04gooooo00Co0000o`0?W_l03iko1EC@1?l00006odY/dP03o`000?mTQ]oo
I8KO00?oI8KO00?o0000oh2<e_n0S=H02_n0S=H00ol0003oRI_NohVKgP03ohVKgP03o`000?nHW]So
V9kH00coV9kH00?o0000ojBSe?nTXm@01?nTXm@3o`0000KoYJgM00?o0000ojfbg?n]/]`02_n]/]`0
0ol0003o];SLokBhg009okBhg0?o000000?o`KcFo`000?o1_=H03?o1_=H00ol0003oalWKolO9f`0<
olO9f`03o`000?o@b=;o000000koem_J00Co0000onCNcooTg/oo00001ooSn=@01Ol0003ojoVfon_i
]_o[nKKo000000Oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`005Ooo
ool00ol0003oooooooooo`1>ooooo`Co00000_l5E=000ol0003oBVcBodY/dP05odY/dP03o`000?mT
Q]ooI8KO00CoI8KO0_l00009oh2<eP03o`000?n9VmkoRI_N00GoRI_N00?o0000oiRNf?nHW]P03?nH
W]P00ol0003oY:?DojBSe003o`0000WoYJgM00?o0000ojfbg?n]/]`02_n]/]`00ol0003o];SLokBh
g00;okBhg003o`000?nj`=oo^/3O00?o00002Oo1_=H00ol0003oalWKolO9f`0>olO9f`03o`000?oG
fm[oem_J00goem_J00?o0000onCNcol000002?oSn=@01?l0003ojoVfon_i]_l00009ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001<ooooo`Co00000_l0
3ih01?l0003o1EC@o`EDd?l00006odY/dP03o`000?mTQ]ooI8KO00KoI8KO00?o0000oh2<e_n0S=H0
1On0S=H00ol0003oRI_NohVKgP07ohVKgP03o`000?nHW]SoV9kH00_oV9kH0ol0000<ojF]g@03o`00
0?n]/]co[K;L00[o[K;L00?o0000okBhg?nd^=`02_nd^=`00ol0003o^/3Ook[0g`04ok[0g`?o0000
1Oo1_=H00ol0003oalWKolO9f`0=olO9f`03o`000?o;en;o0000013oem_J00?o0000on?he?oSn=@0
1ooSn=@00ol0003ojoVfo`00000;ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000?ooooo00Go0000o`0?W_l03iko00nN
o`000002o`EDd003o`000?m:K=;oBVcB00?oBVcB00?o0000ofB6gomTQ]l01omTQ]l00ol0003oP8cF
oh2<eP03oh2<eP03o`000?n9VmkoRI_N00WoRI_N00?o0000oiRNf?nHW]P02?nHW]P2o`000003oibZ
hOl0003oYJgM00goYJgM00?o0000ojfbg?n]/]`02On]/]`00ol0003o];SLokBhg009okBhg003o`00
0?nj`=oo^/3O00So^/3O0ol000000oo1_=Ko0000olO9f`0>olO9f`05o`000?o;en;obmORol_Gh_l0
00003OoGfmX00ol0003oenoSo`000008on?he003o`000?o[nKKo000000gooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co0000
1oooool01?l0003o00nNo`0?W_l00003o`EDd003o`000?m:K=;oBVcB00;oBVcB00?o0000ofB6gomT
Q]l02?mTQ]l01Ol0003oP8cFoh2<e_n0S=Ko000000goRI_N00?o0000oiRNf?nHW]P01OnHW]P2o`00
00CoW:[Q00?o0000ojF]gOnU[Md02onU[Md00ol0003o[K;Lojfbg008ojfbg003o`000?nd^=co];SL
00[o];SL00?o0000ok[0gonj`=l02onj`=l00ol0003oalWKolO9f`0<olO9f`;o00001?o;en800ol0
003oem_JomOKfP09omOKfP;o00000_oGkn<00ol0003ohoSDon?he006on?he003o`000?o[nKKo0000
00gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`12ooooo`?o00002oooool01Ol0003o00nNo`0?W_l03iko000000?o1EC@00Go0000odY/
d_m:K=;oBVcBo`00000;ofB6g`03o`000?n0S=Ko000000ooRI_N00?o0000oiRNf?nHW]P00_nHW]P2
o`0000OoW:[Q00?o0000ojF]gOnU[Md02_nU[Md00ol0003o[K;Lojfbg008ojfbg003o`000?nd^=co
];SL00Wo];SL00?o0000ok[0gonj`=l02onj`=l3okk9h`03o`000?o7bM_oalWK00WoalWK00?o0000
ol_Gh_o;en801Oo;en800ol0003oem_JomOKfP07omOKfP03o`000?oGkn?oenoS00;oenoS00?o0000
on?he?oSn=@01_oSn=@2o`0000oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07
ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00003oooool01?l0003o00nNo`0?W_l00004
o`EDd003o`000?m:K=;o000000goI8KO0_l0000@ohVKgP04o`000?nHW]So0000o`0000[oW:[Q00?o
0000ojF]gOnU[Md02_nU[Md00ol0003o[K;Lojfbg007ojfbg003o`000?nd^=co];SL00Wo];SL00?o
0000ok[0gonj`=l02Onj`=l00ol0003o_/WSokk9h`03okk9h`03o`000?o7bM_oalWK00OoalWK00?o
0000ol_Gh_o;en801oo;en800ol0003oem_JomOKfP04omOKfP;o00001OoGkn<00ol0003ohoSDon?h
e005on?he0;o00004Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo000D
ooooo`03o`000?oooooooooo03gooooo0ol0000Cooooo`03o`000?l03iko000000Go1EC@00?oBVcB
o`000?mTQ]l03?mTQ]l2ogRJi`;o00003on9Vmh2o`0000coW:[Q00?o0000ojF]gOnU[Md02OnU[Md0
0ol0003o[K;Lojfbg007ojfbg003o`000?nd^=co];SL00So];SL00?o0000ok[0gonj`=l02Onj`=l0
0ol0003o_/WSokk9h`05okk9h`;o00001Oo7bM/2o`0000[obmOR00?o0000omOKf_oGfmX00ooGfmX0
0ol0003oenoSomO_h`05omO_h`03o`000?oSn=CohoSD00CohoSD00?o0000okSj`Ol000004_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo
03Wooooo1?l0000Gooooo`03o`000?l03iko000000Go1EC@0_l0000<ofB6g`04o`000?mhV^OoN9[W
ogRJi`;o00003?n9Vmh01?l0003oTZWUoi:YiOl0000;oibZh@03o`000?nU[MgoYJgM00WoYJgM00?o
0000ojfbg?n]/]`01on]/]`00ol0003o];SLokBhg007okBhg003o`000?nj`=oo^/3O00Wo^/3O00?o
0000okk9honnbN<02?nnbN<01Ol0003oalWKolO9foo7bM_o000000gobmOR00?o0000omOKf_oGfmX0
0_l00008omO_h`03o`000?oSn=CohoSD00?ohoSD00?o0000okSj`Ol000005?ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Kooooo0ol0
000Looooo`;o00001Ol5E=001?l0003o?83Vo`000?l00009ofB6g`03o`000?mhV^OoN9[W00CoN9[W
0_l00009ohVKgP03o`000?nBZNGoTZWU00;oTZWU0_l0000:oibZh@03o`000?nU[MgoYJgM00WoYJgM
00?o0000ojfbg?n]/]`00_n]/]`:o`0000Co];SL00?o0000ok[0gonj`=l02?nj`=l00ol0003o_/WS
okk9h`0:okk9h`03o`000?o7bM_o000000kobmOR00?o0000omOKf_l000002OoGkn<00ol0003ohoSD
on?he003on?he003o`000?nhn/7o000001Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Pooooo`03o`0?W_l0003o1EC@00Co1EC@00Co
0000ocb0i_llP>Ko00002?mTQ]l00ol0003oN9[WogRJi`06ogRJi`03o`000?n9VmkoRI_N00GoRI_N
00?o0000oi:YiOnBZND01OnBZND00ol0003oW:[QoibZh@08oibZh@03o`000?nU[MgoYJgM00KoYJgM
1ol00004ojZji@03o`000?n^_^Go[[kU00?o[[kU1?l0000:ok[0g`03o`000?nnbN?o_/WS00co_/WS
00?o0000ol_Gh_o;en803_o;en800ol0003oenoSomO_h`08omO_h`04o`000?oSn=CohoSDon?he0;o
000000?o^?[1o`000?ooool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oo
oooo000Dooooo`03o`000?oooooooooo033ooooo0ol0000Tooooo`03o`000?l5E=3o1EC@00?o1EC@
00Co0000ocb0i_llP>Ko?83V0_l00006ofB6g`03o`000?mhV^OoN9[W00OoN9[W0_l00004ohVKgP03
o`000?nBZNGoTZWU00OoTZWU0_l00009oibZh@03o`000?nU[MgoYJgM00Go00000_nU]nH00ol0003o
Z[[UojZji@06ojZji@03o`000?n^_^Go[[kU00Ko[[kU00?o0000ok;3iol000000_l00005ok[0g`03
o`000?nnbN?o_/WS00[o_/WS0_l000000onodnSo0000ol_GhP0<ol_GhP;o000000?obNK[o`000?oG
kn<02OoGkn<01?l0003ohoSDon?he?l00002okSj`@03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0;?ooool4o`0002Sooooo0_l00004o`EDd003o`000?llP>Ko?83V00;o
?83V0_l00004ofB6g`03o`000?mhV^OoN9[W00WoN9[W0_l000000on9Vmko0000oi:Yi@0;oi:Yi@03
o`000?nLZ^7oW:[Q00KoW:[Q0ol00008ojFgiP03o`000?nZ^^GoZ[[U00GoZ[[U00?o0000ojjniOn^
_^D01On^_^D00ol0003o//?Wok;3i`03ok;3i`?o000000?o^/3Oo`000?nnbN<02onnbN<00ol0003o
_m?XokoCj002okoCj003o`000?o;en;obmOR00SobmOR0_l00003olWVj`03o`000?oGkn?oenoS00So
enoS00?o0000on?he?l000000_nhn/400ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Zooooo`?o0000;_ooool01Ol0003o1EC@o`EDd?l5E=3o000000Ko?83V00Go0000ofB6gomT
Q]ooI8KOo`00000=ogRJi`;o00003OnBZND2o`0000CoW:[Q0_l00002oinej003o`000?nU]nKoYKOV
00KoYKOV00?o0000ojZjiOnZ^^D01OnZ^^D00ol0003o[[kUojjni@05ojjni@03o`000?nb`nOo//?W
00Ko//?W00?o0000okk9honnbN<02OnnbN<2o`0000Go_m?X00?o0000ol_Gh_o;en801_o;en82o`00
00GobNK[00?o0000omO_hooGkn<02?oGkn<2o`0000?o^?[100?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool09oooool3o`0003;ooooo0_l00002o`EDd003o`000?llP>Ko?83V00Co
?83V00?o0000ofB6gol000003_mhV^L01?l0003oQZW/o`000?l0000=oi:Yi@04o`000?nLZ^7o0000
o`0000GoWkGX00?o0000ojFgi_nU]nH01OnU]nH00ol0003oZ[[UojZji@05ojZji@03o`000?n^_^Go
[[kU00Co[[kU00?o0000ok;3ionb`nL01_nb`nL3okC8j@03o`000?nnbN?o_/WS00Go_/WS0_l00008
okoCj003o`000?o;en;obmOR00CobmOR00?o0000olWVjoo9i^/01Oo9i^/00ol0003oenoSomO_h`07
omO_h`;o00000onhn/400ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Toooo
o`?o0000=_ooool01Ol0:jCo0000o`EDd?l5E=3o000000Oo?83V0_l0000=ogRJi`04o`000?n6ZNco
QZW/ohJYk0;o00002onBZND3o`0000OoWkGX00?o0000ojFgi_nU]nH01OnU]nH00ol0003oZ[[UojZj
i@03ojZji@03o`000?n^_^Go[[kU00Co[[kU00?o0000ok;3ionb`nL01Onb`nL00ol0003o]<SYokC8
j@03okC8j@;o00001?nnbN<00ol0003o_m?XokoCj009okoCj004o`000?o;en;obmORol_GhP;o0000
2?o9i^/00ol0003oenoSomO_h`05omO_h`;o000000Go`OcVo`000?nhn/7o^?[1o`00000Oooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Pooooo`Co0000>_ooool01?l0:jCo0000o`EDd?l00007ocb0iP03
o`000?mQV^oo000000;o00002_mhV^L00ol0003oQZW/ohJYk003ohJYk0?o00001onBZND01Ol0003o
VKG[oiVejonI]N_o000000OoWkGX00?o0000ojFgi_nU]nH01?nU]nH00ol0003oZ[[UojZji@03ojZj
i@03o`000?n^_^Go[[kU00Co[[kU00?o0000ok;3ionb`nL01?nb`nL00ol0003o]<SYokC8j@06okC8
j@04o`000?nnbN?o0000o`0000co_m?X00Co0000ol_Gh_l0003o00002Oo9i^/00ol0003oenoSomO_
h`04omO_h`;o00000_o1o>H01?l0003o^?[1okSj`Ol0000Qooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Mooooo`?o0000?oooool2o`000003o`EDd?l0003o?83V00Ko?83V00Co0000of6JkomQV^ooHI[_
0ol00006ogRJi`03o`000?n6ZNcoQZW/00OoQZW/0_l00004oi:Yi@03o`000?nI]N_oVKG[00?oVKG[
0_l00006oinej003o`000?nU]nKoYKOV00?oYKOV00?o0000ojZjiOnZ^^D00onZ^^D00ol0003o[[kU
ojjni@03ojjni@03o`000?nb`nOo//?W00?o//?W0_l0000:okC8j@03o`000?nodnSo_m?X00go_m?X
00?o0000olWVjoo9i^/02Oo9i^/00ol0003oenoSomO_h`02omO_h`;o00000oo1o>H01?l0003o^?[1
okSj`Ol0000Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool000cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Jooooo`?o0000@oooool00ol0003o02^T
o`000007ocb0iP03o`000?mQV^ooHI[_00CoHI[_0ol00003ogRJi`03o`000?n6ZNcoQZW/00WoQZW/
0_l000000onBZNGo0000oiVej`07oiVej`;o00001OnO]NP00ol0003oYKOVojFgiP03ojFgiP03o`00
0?nZ^^GoZ[[U00;oZ[[U00?o0000ojjniOn^_^D00on^_^D00ol0003o//?Wok;3i`02ok;3i`03o`00
0?ndb>Wo]<SY00So]<SY00?o0000okC>kOl000002onodnP3o`000003okgLkol0003obNK[00[obNK[
00?o0000omO_hooGkn<00_l00004ol7liP04o`000?nhn/7o0000o`0002Gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`06ooooo`002_ooool00omEEEGoIVIVo`000006ooooo`;o0000
6?ooool3o`0004Oooooo00Co0000o`0[Y?l0003o00001_llP>H00ol0003oHI[_of6Jk`06of6Jk`;o
000000?oN9[Wo`000?n6ZN`03?n6ZN`2o`0000[oVKG[00?o0000oinej?nO]NP00onO]NP00ol0003o
YKOVojFgiP0>o`0000?o//?W00?o0000okC8jOndb>T01_ndb>T2o`0000Co]<k]00?o0000okoCj?no
dnP01OnodnP3o`0000Co_Mc_00?o0000olWVjoo9i^/02Oo9i^/3o`0000Go`OcV00?o0000okSj`Ol0
0000:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Booooo`03o`00
0?oooooooooo01Cooooo1?l0001;ooooo`03o`000?l0:jCo02^T00;o00001?llP>H00ol0003oHI[_
of6Jk`09of6Jk`?o00002on6ZN`00ol0003oT[K_o`000002o`0000SoVKG[0_l00003oinej0?o0000
0_nS`Nh00ol0003oYL;^ojG2kP02ojG2kP03o`000?nW`nkoYl?^00;oYl?^00Go0000ojS5k_l0003o
//?Wo`000006okC8j@?o00001_ndc^d00ol0003o_m?XokoCj002okoCj0?o00001onmg>l00ol0003o
bNK[olWVj`07olWVj`03o`000?o9i^_o000000Ko`OcV0ol0000Yooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`00053ooooo
00Co0000o`0[Y?l0:jCo1WCO0_l00002ocb0iP03o`000?mQV^ooHI[_00WoHI[_00?o0000ogZ/lomj
[?<00ol00008ohJYk003o`000?nB]^ooT[K_00;oT[K_0ol00007oiVej`03o`000?nO]NSo000000?o
XL3_00Co0000oj?1k_nS`Nko00000onU`^h01Ol0003oYl?^ojO3k_nW`nko000000;oZ<G^0_l00005
okC8j@;o00002Ondc^d00ol0003o_m?Xo`000002o`0000Wo_Mc_00?o0000olWVjoo9i^/01Oo9i^/3
o`0000;o_O7c00?o0000ol7li_o1o>H00oo1o>H2o`0002cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000E?ooool01Ol0
003o02^To`0[Y?l0003o1WCO00;o000000?o?83Vo`000?mQV^l02OmQV^l00ol0003oNZccogZ/l`03
ogZ/l`?o00001?n6ZN`00ol0003oT[K_oi:fk`06oi:fk`?o00001OnI]N/2o`0000CoXL3_00?o0000
oj?1k_l000000onU`^h01?l0003oYl?^ojO3k_l00002ojS5kP06o`000?nXanooZ<O_ojS7kol0003o
]<SY0_l0000<okC>k@03o`000?nmg>oo_Mc_00[o_Mc_00?o0000olWVjoo9i^/00_o9i^/3o`0000Co
_O7c00?o0000ol7li_o1o>H00oo1o>H2o`0002kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0;ooooo`?o0000F?ooool01?l0003o02^T
o`0[Y?l00002o`Idg`;o00002omQV^l00ol0003oNZccogZ/l`05ogZ/l`?o000000?oQZW/o`000?nB
]^l02_nB]^l3o`000004oiVejol0003oWl3`oio0l0;o00000onQ`>l00ol0003oXl7^o`000002ojG2
kP04o`000?nW`nko0000ojS5kP;o00001?nXanl2o`0000Oo]<k]1Ol00002ok;Cl@03o`000?nmg>oo
_Mc_00[o_Mc_00?o0000olWVjol000000_l00006okgal`03o`000?o1o>Ko`OcV00?o`OcV00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Boooo
o`03o`000?oooooooooo00Oooooo1?l0001Looooo`;o000000?o02^To`000?l6M=l00_l6M=l3o`00
00SoHI[_00?o0000ogZ/lomj[?<02?mj[?<6o`0000[oT[K_0ol00003oio0l0?o000000GoXL3_o`00
0?l0003oYL;^o`000002ojO3kP;o00000onXanl3o`0000;oZ<Sa00?o0000okC>kOndc^d01?l00007
ok;Cl@03o`000?nmg>oo_Mc_00Oo_Mc_00?o0000okgLkonmg>l00_l00008okgal`03o`000?o1o>Ko
`OcV00;o`OcV0_l0000cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool0
01;ooooo00?o0000ooooooooool01?ooool3o`0006;ooooo00?o0000o`0[Y?l000001?l6M=l00om7
W?Co0000o`000002o`0000CoHI[_00?o0000ogZ/lomj[?<02Omj[?<00ol0003oSKScohfhl`02ohfh
l`Oo00000onB]^l00ol0003oWL7aoig1l@05o`000003oio0l?l0003o000000?o000000CoYl?^o`00
0?l0003oZ<O_0ol00003ojS8l@Go00002onbdo400ol0003o_Mc_okgLk`07o`0000?o]N?f00?o0000
okgalonmlO<01_nmlO<00ol0003o`OcVol7liP03o`0003Kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000I_ooool3o`00
00Co1WCO00Co0000odNLm?m7W?CoAicd1?l000000omQV^oo0000ogZ/l`0:ogZ/l`03o`000?n=^??o
SKSc00SoSKSc2_l000000onM`O7o0000o`00000>o`0000?oYl[b00?o0000ok;ClOnbdo401?nbdo40
0ol0003o/]?aok;Cl@03ok;Cl@?o00002OnehoH00ol0003o_O7cokgal`06okgal`03o`000?o1o>Ko
000000?o0000=oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aoooo
o`03o`000?oooooo000000;o0000Joooool2o`0000Co1WCO00?o0000odNLm?m7W?@01?m7W?@5o`00
00SoNZcc00?o0000ohfhlon=^?<02_n=^?<00ol0003oVl;coi_2l`05oi_2la_o00001_n]eoH00ol0
003o]N?fokGSmP08okGSmP03o`000?nmlO?o_O7c00Ko_O7c0ol000000on6jm7o0000ooooo`0ioooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool0017ooooo0_l0001`ooooo`03
o`000?l6M=oo1WCO00;o1WCO0_l00007odNLm0;oKk7i1ol000000omj[??o0000ohfhl`06ohfhl`Go
000000?oSKSco`000?l000002_l000000onKaoKo0000o`000008o`0000?oYL_c00?o0000ojgGm_n]
eoH02_n]eoH00ol0003o]N?fokGSmP08okGSmP03o`000?nmlO?o_O7c00?o_O7c1?l00002ohK[d@;o
0000??ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`00
0?oooooooooo06kooooo0ol00003o`Idg`03o`000?m7W?CoAicd00GoAicd00?o0000ofnanOm_/OT0
1Om_/OT9o`0000OoR;cg00?o0000oi[3m?nJ`o@00ol00002oi[5m@;o000000KoVlOfo`000?l0003o
W/[fo`000?nQboH3o`0000?oXlce1_l00009ojgGmP03o`000?nehoKo]N?f00So]N?f00?o0000okga
lol000001?l000001?nPlOCo0000ohK[dOn6jm42o`0003oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`005?ooool2o`00073ooooo00Ko06:mo`000?l0003o0000o`Idgol0
0007odNLm003o`000?m_/OWoKk7i00OoKk7i00?o0000ohRlmon8_?L02on8_?L2o`0000?oV/Ge0_l0
0003oi_7mP;o00000_nNb_H01?l0003oXL_foj7;m_nQboH2o`000003oj?<mOl0003oY]Si00CoY]Si
1Ol00004ojgGmP03o`000?nehoKo]N?f00;o]N?f2?l00004oj3am0;o00000_n6jm400ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Kooooo00?o
0000ooooool00000Koooool00ol0003o06:mo`000002o`0000OoAicd00?o0000ofnanOm_/OT01om_
/OT00ol0003oR;cgohRlm`04ohRlm`Co00001?n6`_/00ol0003oV/Geo`000004oi_7mP04o`000?nL
bOKoW<Wfo`0000;oW/[f00?o0000oj7;m_nQboH01Ol0000:ojKHn@So00000onViO/00ol0003oX?7d
oj3am004oj3am0;o00000_n6jm42o`0004?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`04ooooo`005oooool2o`0007;ooooo0_l0H[d6o`0000;oAicd00?o0000ofnanOm_/OT01om_
/OT00ol0003oR;cgohRlm`03o`0000WoQ/;k1?l00002oi_7mP05o`000?nLbOKoW<Wfo`000?nNb_H0
1?l00005oigGo0?o00001_nVf?T2o`0000WoY^Gk00?o0000oj3am?nPlO@01?nPlO@01Ol0003oQ^_A
ohK[dOn6jm7o000004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
6?ooool2o`0007?ooooo00?o0000o`1R_Ol000000ol^W_4?o`0000WoQ/;k0_l00005ohO7o@Oo0000
1?nCdod00ol0003oWMOloigGo005oigGo0;o00000_nVf?T2o`0000WoY^Gk0_l00005oj3am0;o0000
00CoQ^_Ao`000?l0003o0000B?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Co
oooo000Jooooo`03o`000?oooooooooo07;ooooo00Co0000o`1R_Ol0003o00001Ol^W_42o`0000So
I[Sl0ol00005ohK2n`03o`000?n7aogoQlOm00GoQlOm00?o0000ohc>o_n<c_h00_n<c_h00ol0003o
Tm?moi?Co@04oi?Co@03o`000?nMeocoWMOl00KoWMOl1?l00008ojKUn`03o`000?nPlOCoX?7d00Co
X?7d1?l0001<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool001_ooooo
0_l000000ooooooo0000ooooo`1aooooo`03o`000?l0H[go000000;o00001?l^W_42o`0000WoI[Sl
0_l000000on6`__o0000o`000007ohO7o@03o`000?n<c_koS<kn00?oS<kn00?o0000oi?CoOnCdod0
1OnCdod00ol0003oWMOloigGo002oigGo0?o00001?nBhOd5o`0000;oY^Gk00?o0000oj3am?nPlO@0
1_l0001@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001gooooo0_l0
001booooo`05o`000?ooooooooooo`000?l0H[d00_l00004objNl@;o00002OmV^?`00ol0003oQlOm
o`000002o`0000CoQlOm00?o0000ohc>o_n<c_h01On<c_h00ol0003oTm?moi?Co@05oi?Co@04o`00
0?nMeoco0000o`0000_oT^7m2Ol0001Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00oooool001kooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`03ooooo`03o`1R
_Ol0003o000000Co;Yka0_l00002ofJho0?o00001omT`Oh9o`0000?oS<kn00?o0000oi?CoOnCdod0
0_nCdod6o`0000SoT^7m1?l00003ogCPk0?o0000Eoooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003oooooooooo`06ooooo`Go000000?o
;Ykao`000?l000003?mT`Oh00ol0003oJlcmof_<o@04of_<o@So00001_mlf?h3o`0000;oT^7m0ol0
0004ogCPk0?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Q
ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool02_ooool2o`0000Co8ZCV1_l00003
ofC1oP03o`000?m[c?goJlcm00SoJlcm00?o0000ogcHo_mlf?h02?mlf?h7o`0000;oM>3/0ol0001O
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001/oooo
o`03o`000?oooooooooo00oooooo1Ol00002ob:TiP?o00000_m[c?d5o`0000GoJlcm00?o0000ogcH
o_mlf?h01ol00004odO7h@Go0000Hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo000Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05?ooool3o`0000Wo
:[3N2?l00002odO7h@Wo0000JOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;o
oooo000Uooooo`;o0000J_ooool00ol0003oooooooooo`0Oooooo`_o0000L_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Wooooo`03o`000?oooooooooo06Oooooo00?o
0000ooooooooool0WOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo000X
ooooo`03o`000?oooooo000006Kooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00;ooooo000Nooooo`Co000000?o410@ooooooooool01?ooool2o`00
06Kooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool001Gooooo
1_l00005ooooo`03o`000?oooooooooo00Wooooo0_l0001Sooooo`03o`000?oooooooooo0:3ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`008?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00cooooo0_l0001P
ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01
ooooo`008?ooool00ol0003oooooooooo`0=ooooo`;o0000Goooool00ol0003oooooooooo`2Soooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0023ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o0000
00?oooooo`000?ooool0F?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00Oooool003Gooooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000
ooooooooool0Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000hoooo
o`05o`000?ooooooooooooooool00000Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00Oooool003Wooooo00Co0000oooooooooooo0000Doooool0
0ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000joooo
o`?o0000Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`7ooooo000looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`08ooooo`7o00000Oooool1ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0
Zoooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00
001>ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Ooo
ool0043ooooo0_l0001>ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1
o`00007ooooo0Oooool0047ooooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000oooo
ooooool01?ooool1o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003oooo
ool0003ooooo04Oooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`04ooooo`7o0000
0Oooool004Kooooo0_l00018ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Co
A4A4o`000?l0003o<S8b0_l00017ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo000booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00CoMgMgoc8b<_oooooo0000A_ooool00ol0003oooooooooo`2booooo`05o`000?oooooooooooooo
ool000000Oooool002[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`03o`0004?ooooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001
ooooo`00<_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Ooo
ool003;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0
0Ol0000003;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo
0_l00010ooooo`03o`000?oooooooooo0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o0000?_ooool00ol0003ooooo
ooooo`2fooooo`;o0000000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo
0_l0000mooooo`03o`000?oooooooooo0;Gooooo0ol0000005?ooooo00Go0000oooooooooooooooo
o`00000hooooo`03o`000?oooooooooo0;3ooooo1Ol00003ooooo`00E?ooool01?l0003ooooooooo
ool0000hooooo`03o`000?oooooooooo0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o
0000ooooooooool0Z?ooool4o`0000cooooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0Y?ooool5o`00013ooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Poooo
o`Co00005Oooool005[ooooo00?o0000ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co
00006Oooool005_ooooo0_l0000booooo`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOoo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool0
1?l0003oooooooooool0000]ooooo`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3
o`0002gooooo00?o0000ooooooooool0R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02_ooool2o`0002_ooooo00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo
07gooooo1?l0000hooooo`00Doooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Xoooo
o`03o`000?oooooooooo07Wooooo1?l0000looooo`00Doooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?o
oooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000
ooooooooool0L?ooool4o`0004Gooooo001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3
o`0002?ooooo00?o0000ooooooooool0Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04_ooool2o`0002?ooooo00?o0000ooooooooool0Ioooool4o`0004kooooo001Coooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0003ooooo01kooooo00?o0000
ooooooooool0Hoooool4o`0005;ooooo001^ooooo`;o00007oooool00ol0003oooooooooo`1Noooo
o`Go0000E_ooool006oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co
0000Foooool0073ooooo0_l0000Mooooo`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_oo
ool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2
o`0001[ooooo00?o0000ooooooooool0COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0BOooool4o`0006cooooo001fooooo`;o000000?oooooo`000?oo
ool05?ooool00ol0003oooooooooo`14ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`00
0?oooooooooo043ooooo1?l0001eooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo03_ooooo1Ol0001iooooo`00N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000
ooooooooool0=oooool4o`0007kooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o00004Oooool00ol0003ooooooooo
o`0cooooo`Co0000P_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_oo
ool006?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oo
oooooooo02Oooooo1?l0002?ooooo`00Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool5o`0009?ooooo001Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07_ooool4o`0009So
oooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o
00001oooool00ol0003oooooooooo`0Iooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo1?l0002Qooooo`00Qoooool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo
0029ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000
ooooooooooooooooo`00000:ooooo`Co0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05
ooooo`Co0000/_ooool008gooooo0_l000000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o
0000^oooool00?ooooooC?ooool00?ooooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30
ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00
Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool0
0ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGo
IVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48157 .55209 m .47499 .59268 L .54365 .596 L p .719 .599 .722 r
F P
0 g
s
.54365 .596 m .54143 .55506 L .48157 .55209 L p .719 .599 .722 r
F P
0 g
s
.54546 .63733 m .54365 .596 L .47499 .59268 L p .72 .574 .689 r
F P
0 g
s
.54143 .55506 m .54365 .596 L .61084 .58602 L p .671 .562 .724 r
F P
0 g
s
.54365 .596 m .54546 .63733 L .61973 .62657 L p .666 .531 .691 r
F P
0 g
s
.61973 .62657 m .61084 .58602 L .54365 .596 L p .666 .531 .691 r
F P
0 g
s
.48917 .51282 m .48157 .55209 L .54143 .55506 L p .716 .623 .752 r
F P
0 g
s
.54143 .55506 m .53887 .51534 L .48917 .51282 L p .716 .623 .752 r
F P
0 g
s
.53887 .51534 m .54143 .55506 L .59996 .54615 L p .674 .591 .754 r
F P
0 g
s
.61084 .58602 m .59996 .54615 L .54143 .55506 L p .671 .562 .724 r
F P
0 g
s
.47499 .59268 m .46961 .63375 L .54546 .63733 L p .72 .574 .689 r
F P
0 g
s
.5468 .67806 m .54546 .63733 L .46961 .63375 L p .72 .546 .654 r
F P
0 g
s
.54546 .63733 m .5468 .67806 L .62632 .66684 L p .659 .498 .655 r
F P
0 g
s
.62632 .66684 m .61973 .62657 L .54546 .63733 L p .659 .498 .655 r
F P
0 g
s
.42567 .53745 m .41072 .57626 L .47499 .59268 L p .764 .642 .727 r
F P
0 g
s
.47499 .59268 m .48157 .55209 L .42567 .53745 L p .764 .642 .727 r
F P
0 g
s
.46961 .63375 m .47499 .59268 L .41072 .57626 L p .771 .622 .694 r
F P
0 g
s
.44288 .5004 m .42567 .53745 L .48157 .55209 L p .754 .66 .758 r
F P
0 g
s
.48157 .55209 m .48917 .51282 L .44288 .5004 L p .754 .66 .758 r
F P
0 g
s
.41072 .57626 m .39848 .61604 L .46961 .63375 L p .771 .622 .694 r
F P
0 g
s
.46564 .67432 m .46961 .63375 L .39848 .61604 L p .778 .598 .657 r
F P
0 g
s
.46961 .63375 m .46564 .67432 L .5468 .67806 L p .72 .546 .654 r
F P
0 g
s
.49759 .47553 m .48917 .51282 L .53887 .51534 L p .711 .646 .782 r
F P
0 g
s
.53887 .51534 m .53603 .47752 L .49759 .47553 L p .711 .646 .782 r
F P
0 g
s
.53603 .47752 m .53887 .51534 L .58742 .50778 L p .677 .62 .784 r
F P
0 g
s
.59996 .54615 m .58742 .50778 L .53887 .51534 L p .674 .591 .754 r
F P
0 g
s
.59996 .54615 m .61084 .58602 L .67071 .56337 L p .617 .529 .732 r
F P
0 g
s
.61084 .58602 m .61973 .62657 L .68613 .60212 L p .604 .491 .698 r
F P
0 g
s
.68613 .60212 m .67071 .56337 L .61084 .58602 L p .604 .491 .698 r
F P
0 g
s
.54761 .7171 m .5468 .67806 L .46564 .67432 L p .718 .514 .613 r
F P
0 g
s
.5468 .67806 m .54761 .7171 L .6303 .70573 L p .65 .46 .613 r
F P
0 g
s
.6303 .70573 m .62632 .66684 L .5468 .67806 L p .65 .46 .613 r
F P
0 g
s
.58742 .50778 m .59996 .54615 L .6519 .52598 L p .629 .565 .763 r
F P
0 g
s
.67071 .56337 m .6519 .52598 L .59996 .54615 L p .617 .529 .732 r
F P
0 g
s
.46191 .46573 m .44288 .5004 L .48917 .51282 L p .742 .677 .788 r
F P
0 g
s
.48917 .51282 m .49759 .47553 L .46191 .46573 L p .742 .677 .788 r
F P
0 g
s
.61973 .62657 m .62632 .66684 L .69757 .64128 L p .588 .449 .66 r
F P
0 g
s
.69757 .64128 m .68613 .60212 L .61973 .62657 L p .588 .449 .66 r
F P
0 g
s
.39848 .61604 m .38941 .65584 L .46564 .67432 L p .778 .598 .657 r
F P
0 g
s
.46323 .71332 m .46564 .67432 L .38941 .65584 L p .782 .57 .614 r
F P
0 g
s
.46564 .67432 m .46323 .71332 L .54761 .7171 L p .718 .514 .613 r
F P
0 g
s
.58742 .50778 m .57353 .47155 L .53603 .47752 L p .677 .62 .784 r
F P
0 g
s
.57353 .47155 m .58742 .50778 L .63031 .49069 L p .639 .599 .793 r
F P
0 g
s
.6519 .52598 m .63031 .49069 L .58742 .50778 L p .629 .565 .763 r
F P
0 g
s
.40443 .47904 m .37892 .51216 L .42567 .53745 L p .79 .706 .771 r
F P
0 g
s
.42567 .53745 m .44288 .5004 L .40443 .47904 L p .79 .706 .771 r
F P
0 g
s
.41072 .57626 m .42567 .53745 L .37892 .51216 L p .808 .694 .74 r
F P
0 g
s
.37892 .51216 m .35664 .54781 L .41072 .57626 L p .808 .694 .74 r
F P
0 g
s
.39848 .61604 m .41072 .57626 L .35664 .54781 L p .823 .679 .704 r
F P
0 g
s
.50668 .44073 m .49759 .47553 L .53603 .47752 L p .704 .669 .812 r
F P
0 g
s
.53603 .47752 m .53296 .44212 L .50668 .44073 L p .704 .669 .812 r
F P
0 g
s
.53296 .44212 m .53603 .47752 L .57353 .47155 L p .678 .649 .814 r
F P
0 g
s
.62632 .66684 m .6303 .70573 L .70451 .67978 L p .569 .401 .614 r
F P
0 g
s
.70451 .67978 m .69757 .64128 L .62632 .66684 L p .569 .401 .614 r
F P
0 g
s
.48237 .43392 m .46191 .46573 L .49759 .47553 L p .728 .693 .817 r
F P
0 g
s
.49759 .47553 m .50668 .44073 L .48237 .43392 L p .728 .693 .817 r
F P
0 g
s
.43249 .44896 m .40443 .47904 L .44288 .5004 L p .771 .715 .8 r
F P
0 g
s
.44288 .5004 m .46191 .46573 L .43249 .44896 L p .771 .715 .8 r
F P
0 g
s
.54785 .75331 m .54761 .7171 L .46323 .71332 L p .713 .476 .564 r
F P
0 g
s
.54761 .7171 m .54785 .75331 L .63148 .74207 L p .637 .415 .563 r
F P
0 g
s
.63148 .74207 m .6303 .70573 L .54761 .7171 L p .637 .415 .563 r
F P
0 g
s
.35664 .54781 m .33834 .58528 L .39848 .61604 L p .823 .679 .704 r
F P
0 g
s
.38941 .65584 m .39848 .61604 L .33834 .58528 L p .837 .661 .663 r
F P
0 g
s
.57353 .47155 m .55857 .43796 L .53296 .44212 L p .678 .649 .814 r
F P
0 g
s
.55857 .43796 m .57353 .47155 L .60649 .4581 L p .649 .634 .822 r
F P
0 g
s
.63031 .49069 m .60649 .4581 L .57353 .47155 L p .639 .599 .793 r
F P
0 g
s
.38941 .65584 m .38391 .69456 L .46323 .71332 L p .782 .57 .614 r
F P
0 g
s
.46252 .74957 m .46323 .71332 L .38391 .69456 L p .784 .536 .561 r
F P
0 g
s
.46323 .71332 m .46252 .74957 L .54785 .75331 L p .713 .476 .564 r
F P
0 g
s
.63031 .49069 m .6519 .52598 L .6922 .49602 L p .576 .543 .781 r
F P
0 g
s
.6519 .52598 m .67071 .56337 L .71754 .52959 L p .553 .499 .749 r
F P
0 g
s
.71754 .52959 m .6922 .49602 L .6519 .52598 L p .553 .499 .749 r
F P
0 g
s
.67071 .56337 m .68613 .60212 L .73841 .56551 L p .526 .449 .712 r
F P
0 g
s
.73841 .56551 m .71754 .52959 L .67071 .56337 L p .526 .449 .712 r
F P
0 g
s
.46248 .42231 m .43249 .44896 L .46191 .46573 L p .749 .723 .828 r
F P
0 g
s
.46191 .46573 m .48237 .43392 L .46248 .42231 L p .749 .723 .828 r
F P
0 g
s
.60649 .4581 m .63031 .49069 L .66327 .46546 L p .598 .585 .81 r
F P
0 g
s
.6922 .49602 m .66327 .46546 L .63031 .49069 L p .576 .543 .781 r
F P
0 g
s
.33834 .58528 m .32473 .62365 L .38941 .65584 L p .837 .661 .663 r
F P
0 g
s
.38391 .69456 m .38941 .65584 L .32473 .62365 L p .849 .636 .614 r
F P
0 g
s
.6303 .70573 m .63148 .74207 L .70656 .71645 L p .544 .342 .557 r
F P
0 g
s
.70656 .71645 m .70451 .67978 L .6303 .70573 L p .544 .342 .557 r
F P
0 g
s
.5163 .40888 m .50668 .44073 L .53296 .44212 L p .694 .692 .844 r
F P
0 g
s
.53296 .44212 m .52971 .4096 L .5163 .40888 L p .694 .692 .844 r
F P
0 g
s
.52971 .4096 m .53296 .44212 L .55857 .43796 L p .677 .68 .845 r
F P
0 g
s
.68613 .60212 m .69757 .64128 L .75396 .60293 L p .495 .393 .668 r
F P
0 g
s
.75396 .60293 m .73841 .56551 L .68613 .60212 L p .495 .393 .668 r
F P
0 g
s
.50393 .40534 m .48237 .43392 L .50668 .44073 L p .71 .709 .847 r
F P
0 g
s
.50668 .44073 m .5163 .40888 L .50393 .40534 L p .71 .709 .847 r
F P
0 g
s
.60649 .4581 m .58095 .42863 L .55857 .43796 L p .649 .634 .822 r
F P
0 g
s
.58095 .42863 m .60649 .4581 L .63156 .43835 L p .619 .626 .836 r
F P
0 g
s
.66327 .46546 m .63156 .43835 L .60649 .4581 L p .598 .585 .81 r
F P
0 g
s
.55857 .43796 m .54276 .40744 L .52971 .4096 L p .677 .68 .845 r
F P
0 g
s
.54276 .40744 m .55857 .43796 L .58095 .42863 L p .658 .671 .851 r
F P
0 g
s
.54749 .78554 m .54785 .75331 L .46252 .74957 L p .703 .426 .502 r
F P
0 g
s
.54785 .75331 m .54749 .78554 L .6297 .77474 L p .619 .357 .499 r
F P
0 g
s
.6297 .77474 m .63148 .74207 L .54785 .75331 L p .619 .357 .499 r
F P
0 g
s
.37785 .4505 m .34616 .47818 L .37892 .51216 L p .823 .761 .794 r
F P
0 g
s
.37892 .51216 m .40443 .47904 L .37785 .4505 L p .823 .761 .794 r
F P
0 g
s
.35664 .54781 m .37892 .51216 L .34616 .47818 L p .851 .759 .761 r
F P
0 g
s
.41245 .4267 m .37785 .4505 L .40443 .47904 L p .795 .76 .821 r
F P
0 g
s
.40443 .47904 m .43249 .44896 L .41245 .4267 L p .795 .76 .821 r
F P
0 g
s
.4939 .39935 m .46248 .42231 L .48237 .43392 L p .722 .728 .855 r
F P
0 g
s
.48237 .43392 m .50393 .40534 L .4939 .39935 L p .722 .728 .855 r
F P
0 g
s
.38391 .69456 m .38229 .73105 L .46252 .74957 L p .784 .536 .561 r
F P
0 g
s
.46359 .78195 m .46252 .74957 L .38229 .73105 L p .781 .489 .493 r
F P
0 g
s
.46252 .74957 m .46359 .78195 L .54749 .78554 L p .703 .426 .502 r
F P
0 g
s
.34616 .47818 m .31832 .50939 L .35664 .54781 L p .851 .759 .761 r
F P
0 g
s
.33834 .58528 m .35664 .54781 L .31832 .50939 L p .877 .753 .722 r
F P
0 g
s
.44915 .407 m .41245 .4267 L .43249 .44896 L p .764 .756 .845 r
F P
0 g
s
.43249 .44896 m .46248 .42231 L .44915 .407 L p .764 .756 .845 r
F P
0 g
s
.32473 .62365 m .31647 .66187 L .38391 .69456 L p .849 .636 .614 r
F P
0 g
s
.38229 .73105 m .38391 .69456 L .31647 .66187 L p .858 .603 .551 r
F P
0 g
s
.69757 .64128 m .70451 .67978 L .76341 .64079 L p .456 .325 .613 r
F P
0 g
s
.76341 .64079 m .75396 .60293 L .69757 .64128 L p .456 .325 .613 r
F P
0 g
s
.58095 .42863 m .55411 .40261 L .54276 .40744 L p .658 .671 .851 r
F P
0 g
s
.55411 .40261 m .58095 .42863 L .59778 .41499 L p .639 .667 .861 r
F P
0 g
s
.63156 .43835 m .59778 .41499 L .58095 .42863 L p .619 .626 .836 r
F P
0 g
s
.63148 .74207 m .6297 .77474 L .70347 .7501 L p .51 .267 .483 r
F P
0 g
s
.70347 .7501 m .70656 .71645 L .63148 .74207 L p .51 .267 .483 r
F P
0 g
s
.31832 .50939 m .29532 .54354 L .33834 .58528 L p .877 .753 .722 r
F P
0 g
s
.32473 .62365 m .33834 .58528 L .29532 .54354 L p .902 .741 .673 r
F P
0 g
s
.4873 .39152 m .44915 .407 L .46248 .42231 L p .73 .749 .867 r
F P
0 g
s
.46248 .42231 m .4939 .39935 L .4873 .39152 L p .73 .749 .867 r
F P
0 g
s
.63156 .43835 m .66327 .46546 L .68258 .43424 L p .552 .579 .835 r
F P
0 g
s
.66327 .46546 m .6922 .49602 L .71629 .45872 L p .513 .528 .809 r
F P
0 g
s
.71629 .45872 m .68258 .43424 L .66327 .46546 L p .513 .528 .809 r
F P
0 g
s
.52971 .4096 m .52632 .38036 L .5163 .40888 L closepath p .68 .718 .878 r
F P
0 g
s
.54276 .40744 m .52632 .38036 L .52971 .4096 L closepath p .674 .713 .878 r
F P
0 g
s
.5163 .40888 m .52632 .38036 L .50393 .40534 L closepath p .686 .724 .879 r
F P
0 g
s
.59778 .41499 m .63156 .43835 L .64591 .41409 L p .588 .625 .857 r
F P
0 g
s
.68258 .43424 m .64591 .41409 L .63156 .43835 L p .552 .579 .835 r
F P
0 g
s
.55411 .40261 m .52632 .38036 L .54276 .40744 L closepath p .667 .71 .88 r
F P
0 g
s
.6922 .49602 m .71754 .52959 L .74603 .48728 L p .468 .47 .776 r
F P
0 g
s
.74603 .48728 m .71629 .45872 L .6922 .49602 L p .468 .47 .776 r
F P
0 g
s
.50393 .40534 m .52632 .38036 L .4939 .39935 L closepath p .69 .731 .882 r
F P
0 g
s
.59778 .41499 m .56253 .3956 L .55411 .40261 L p .639 .667 .861 r
F P
0 g
s
.56253 .3956 m .59778 .41499 L .60718 .39838 L p .621 .669 .874 r
F P
0 g
s
.64591 .41409 m .60718 .39838 L .59778 .41499 L p .588 .625 .857 r
F P
0 g
s
.56253 .3956 m .52632 .38036 L .55411 .40261 L closepath p .66 .709 .884 r
F P
0 g
s
.70451 .67978 m .70656 .71645 L .7662 .67793 L p .407 .24 .54 r
F P
0 g
s
.7662 .67793 m .76341 .64079 L .70451 .67978 L p .407 .24 .54 r
F P
0 g
s
.71754 .52959 m .73841 .56551 L .77067 .51944 L p .416 .401 .734 r
F P
0 g
s
.77067 .51944 m .74603 .48728 L .71754 .52959 L p .416 .401 .734 r
F P
0 g
s
.54653 .81276 m .54749 .78554 L .46359 .78195 L p .685 .359 .417 r
F P
0 g
s
.54749 .78554 m .54653 .81276 L .62497 .80265 L p .589 .279 .411 r
F P
0 g
s
.62497 .80265 m .6297 .77474 L .54749 .78554 L p .589 .279 .411 r
F P
0 g
s
.4939 .39935 m .52632 .38036 L .4873 .39152 L closepath p .692 .738 .887 r
F P
0 g
s
.31647 .66187 m .31403 .69876 L .38229 .73105 L p .858 .603 .551 r
F P
0 g
s
.38474 .76414 m .38229 .73105 L .31403 .69876 L p .862 .554 .466 r
F P
0 g
s
.38229 .73105 m .38474 .76414 L .46359 .78195 L p .781 .489 .493 r
F P
0 g
s
.29532 .54354 m .27815 .57985 L .32473 .62365 L p .902 .741 .673 r
F P
0 g
s
.31647 .66187 m .32473 .62365 L .27815 .57985 L p .924 .721 .609 r
F P
0 g
s
.44395 .38952 m .40421 .40107 L .41245 .4267 L p .771 .791 .869 r
F P
0 g
s
.41245 .4267 m .44915 .407 L .44395 .38952 L p .771 .791 .869 r
F P
0 g
s
.37785 .4505 m .41245 .4267 L .40421 .40107 L p .81 .811 .851 r
F P
0 g
s
.48486 .38264 m .44395 .38952 L .44915 .407 L p .732 .769 .883 r
F P
0 g
s
.44915 .407 m .4873 .39152 L .48486 .38264 L p .732 .769 .883 r
F P
0 g
s
.46645 .8094 m .46359 .78195 L .38474 .76414 L p .769 .423 .399 r
F P
0 g
s
.46359 .78195 m .46645 .8094 L .54653 .81276 L p .685 .359 .417 r
F P
0 g
s
.56711 .38713 m .52632 .38036 L .56253 .3956 L closepath p .654 .71 .889 r
F P
0 g
s
.60718 .39838 m .56711 .38713 L .56253 .3956 L p .621 .669 .874 r
F P
0 g
s
.40421 .40107 m .36643 .41737 L .37785 .4505 L p .81 .811 .851 r
F P
0 g
s
.34616 .47818 m .37785 .4505 L .36643 .41737 L p .848 .828 .827 r
F P
0 g
s
.4873 .39152 m .52632 .38036 L .48486 .38264 L closepath p .692 .745 .892 r
F P
0 g
s
.73841 .56551 m .75396 .60293 L .7891 .55448 L p .351 .315 .678 r
F P
0 g
s
.7891 .55448 m .77067 .51944 L .73841 .56551 L p .351 .315 .678 r
F P
0 g
s
.36643 .41737 m .33154 .43845 L .34616 .47818 L p .848 .828 .827 r
F P
0 g
s
.31832 .50939 m .34616 .47818 L .33154 .43845 L p .887 .841 .794 r
F P
0 g
s
.56711 .38713 m .60718 .39838 L .60795 .38049 L p .605 .677 .891 r
F P
0 g
s
.60718 .39838 m .64591 .41409 L .64762 .38774 L p .556 .634 .883 r
F P
0 g
s
.64762 .38774 m .60795 .38049 L .60718 .39838 L p .556 .634 .883 r
F P
0 g
s
.56731 .37809 m .52632 .38036 L .56711 .38713 L closepath p .649 .714 .895 r
F P
0 g
s
.60795 .38049 m .56731 .37809 L .56711 .38713 L p .605 .677 .891 r
F P
0 g
s
.6297 .77474 m .62497 .80265 L .69522 .7796 L p .459 .164 .377 r
F P
0 g
s
.69522 .7796 m .70347 .7501 L .6297 .77474 L p .459 .164 .377 r
F P
0 g
s
.55469 .36221 m .52632 .38036 L .56303 .36947 L closepath p .647 .727 .907 r
F P
0 g
s
.48691 .37369 m .52632 .38036 L .49329 .36563 L closepath p .684 .754 .904 r
F P
0 g
s
.48486 .38264 m .52632 .38036 L .48691 .37369 L closepath p .689 .75 .898 r
F P
0 g
s
.56303 .36947 m .52632 .38036 L .56731 .37809 L closepath p .647 .72 .901 r
F P
0 g
s
.54318 .35714 m .52632 .38036 L .55469 .36221 L closepath p .649 .734 .911 r
F P
0 g
s
.52977 .35487 m .52632 .38036 L .54318 .35714 L closepath p .654 .742 .914 r
F P
0 g
s
.51598 .35564 m .52632 .38036 L .52977 .35487 L closepath p .661 .748 .914 r
F P
0 g
s
.50334 .35937 m .52632 .38036 L .51598 .35564 L closepath p .669 .753 .913 r
F P
0 g
s
.49329 .36563 m .52632 .38036 L .50334 .35937 L closepath p .677 .754 .909 r
F P
0 g
s
.64591 .41409 m .68258 .43424 L .68551 .40003 L p .5 .583 .87 r
F P
0 g
s
.68551 .40003 m .64762 .38774 L .64591 .41409 L p .5 .583 .87 r
F P
0 g
s
.44395 .38952 m .48486 .38264 L .48691 .37369 L p .727 .788 .901 r
F P
0 g
s
.27815 .57985 m .26769 .6173 L .31647 .66187 L p .924 .721 .609 r
F P
0 g
s
.31403 .69876 m .31647 .66187 L .26769 .6173 L p .942 .686 .521 r
F P
0 g
s
.70656 .71645 m .70347 .7501 L .76199 .71308 L p .338 .127 .438 r
F P
0 g
s
.76199 .71308 m .7662 .67793 L .70656 .71645 L p .338 .127 .438 r
F P
0 g
s
.33154 .43845 m .30066 .46417 L .31832 .50939 L p .887 .841 .794 r
F P
0 g
s
.29532 .54354 m .31832 .50939 L .30066 .46417 L p .927 .85 .747 r
F P
0 g
s
.48691 .37369 m .44765 .3717 L .44395 .38952 L p .727 .788 .901 r
F P
0 g
s
.40421 .40107 m .44395 .38952 L .44765 .3717 L p .766 .825 .899 r
F P
0 g
s
.56731 .37809 m .60795 .38049 L .59977 .36325 L p .594 .691 .91 r
F P
0 g
s
.59977 .36325 m .56303 .36947 L .56731 .37809 L p .594 .691 .91 r
F P
0 g
s
.68258 .43424 m .71629 .45872 L .72064 .41752 L p .432 .52 .848 r
F P
0 g
s
.72064 .41752 m .68551 .40003 L .68258 .43424 L p .432 .52 .848 r
F P
0 g
s
.75396 .60293 m .76341 .64079 L .80036 .59144 L p .268 .206 .6 r
F P
0 g
s
.80036 .59144 m .7891 .55448 L .75396 .60293 L p .268 .206 .6 r
F P
0 g
s
.44765 .3717 m .48691 .37369 L .49329 .36563 L p .713 .801 .919 r
F P
0 g
s
.31403 .69876 m .31771 .73309 L .38474 .76414 L p .862 .554 .466 r
F P
0 g
s
.39127 .79273 m .38474 .76414 L .31771 .73309 L p .852 .479 .343 r
F P
0 g
s
.38474 .76414 m .39127 .79273 L .46645 .8094 L p .769 .423 .399 r
F P
0 g
s
.44765 .3717 m .40916 .3747 L .40421 .40107 L p .766 .825 .899 r
F P
0 g
s
.36643 .41737 m .40421 .40107 L .40916 .3747 L p .807 .864 .89 r
F P
0 g
s
.54498 .8341 m .54653 .81276 L .46645 .8094 L p .649 .258 .291 r
F P
0 g
s
.54653 .81276 m .54498 .8341 L .61735 .8249 L p .538 .165 .28 r
F P
0 g
s
.61735 .8249 m .62497 .80265 L .54653 .81276 L p .538 .165 .28 r
F P
0 g
s
.56303 .36947 m .59977 .36325 L .58331 .34862 L p .589 .712 .928 r
F P
0 g
s
.58331 .34862 m .55469 .36221 L .56303 .36947 L p .589 .712 .928 r
F P
0 g
s
.60795 .38049 m .64762 .38774 L .63595 .3621 L p .528 .653 .915 r
F P
0 g
s
.63595 .3621 m .59977 .36325 L .60795 .38049 L p .528 .653 .915 r
F P
0 g
s
.71629 .45872 m .74603 .48728 L .75187 .44022 L p .347 .44 .814 r
F P
0 g
s
.75187 .44022 m .72064 .41752 L .71629 .45872 L p .347 .44 .814 r
F P
0 g
s
.47106 .83104 m .46645 .8094 L .39127 .79273 L p .738 .321 .258 r
F P
0 g
s
.46645 .8094 m .47106 .83104 L .54498 .8341 L p .649 .258 .291 r
F P
0 g
s
.46011 .35553 m .49329 .36563 L .50334 .35937 L p .69 .805 .936 r
F P
0 g
s
.49329 .36563 m .46011 .35553 L .44765 .3717 L p .713 .801 .919 r
F P
0 g
s
.30066 .46417 m .27498 .49417 L .29532 .54354 L p .927 .85 .747 r
F P
0 g
s
.27815 .57985 m .29532 .54354 L .27498 .49417 L p .964 .849 .679 r
F P
0 g
s
.55469 .36221 m .58331 .34862 L .56028 .33835 L p .594 .736 .943 r
F P
0 g
s
.56028 .33835 m .54318 .35714 L .55469 .36221 L p .594 .736 .943 r
F P
0 g
s
.40916 .3747 m .37223 .383 L .36643 .41737 L p .807 .864 .89 r
F P
0 g
s
.33154 .43845 m .36643 .41737 L .37223 .383 L p .851 .902 .871 r
F P
0 g
s
.40916 .3747 m .44765 .3717 L .46011 .35553 L p .743 .852 .931 r
F P
0 g
s
.48011 .34287 m .50334 .35937 L .51598 .35564 L p .662 .8 .949 r
F P
0 g
s
.50334 .35937 m .48011 .34287 L .46011 .35553 L p .69 .805 .936 r
F P
0 g
s
.26769 .6173 m .26461 .65471 L .31403 .69876 L p .942 .686 .521 r
F P
0 g
s
.31771 .73309 m .31403 .69876 L .26461 .65471 L p .945 .624 .392 r
F P
0 g
s
.64762 .38774 m .68551 .40003 L .67081 .36647 L p .443 .6 .912 r
F P
0 g
s
.67081 .36647 m .63595 .3621 L .64762 .38774 L p .443 .6 .912 r
F P
0 g
s
.54318 .35714 m .56028 .33835 L .53329 .33371 L p .609 .762 .952 r
F P
0 g
s
.53329 .33371 m .52977 .35487 L .54318 .35714 L p .609 .762 .952 r
F P
0 g
s
.62497 .80265 m .61735 .8249 L .68199 .80399 L p .375 .014 .218 r
F P
0 g
s
.68199 .80399 m .69522 .7796 L .62497 .80265 L p .375 .014 .218 r
F P
0 g
s
.76341 .64079 m .7662 .67793 L .80368 .62913 L p .156 .059 .485 r
F P
0 g
s
.80368 .62913 m .80036 .59144 L .76341 .64079 L p .156 .059 .485 r
F P
0 g
s
.50547 .33529 m .51598 .35564 L .52977 .35487 L p .633 .785 .954 r
F P
0 g
s
.51598 .35564 m .50547 .33529 L .48011 .34287 L p .662 .8 .949 r
F P
0 g
s
.70347 .7501 m .69522 .7796 L .75076 .74504 L p .237 0 .288 r
F P
0 g
s
.75076 .74504 m .76199 .71308 L .70347 .7501 L p .237 0 .288 r
F P
0 g
s
.74603 .48728 m .77067 .51944 L .77792 .46791 L p .237 .332 .759 r
F P
0 g
s
.77792 .46791 m .75187 .44022 L .74603 .48728 L p .237 .332 .759 r
F P
0 g
s
.52977 .35487 m .53329 .33371 L .50547 .33529 L p .633 .785 .954 r
F P
0 g
s
.59977 .36325 m .63595 .3621 L .61171 .34017 L p .509 .685 .946 r
F P
0 g
s
.61171 .34017 m .58331 .34862 L .59977 .36325 L p .509 .685 .946 r
F P
0 g
s
.27498 .49417 m .25572 .52783 L .27815 .57985 L p .964 .849 .679 r
F P
0 g
s
.26769 .6173 m .27815 .57985 L .25572 .52783 L p .993 .829 .576 r
F P
0 g
s
.37223 .383 m .33784 .39689 L .33154 .43845 L p .851 .902 .871 r
F P
0 g
s
.30066 .46417 m .33154 .43845 L .33784 .39689 L p .895 .938 .833 r
F P
0 g
s
.42729 .35054 m .46011 .35553 L .48011 .34287 L p .699 .863 .96 r
F P
0 g
s
.46011 .35553 m .42729 .35054 L .40916 .3747 L p .743 .852 .931 r
F P
0 g
s
.37223 .383 m .40916 .3747 L .42729 .35054 L p .774 .908 .933 r
F P
0 g
s
.31771 .73309 m .32753 .76372 L .39127 .79273 L p .852 .479 .343 r
F P
0 g
s
.40176 .81589 m .39127 .79273 L .32753 .76372 L p .808 .353 .155 r
F P
0 g
s
.39127 .79273 m .40176 .81589 L .47106 .83104 L p .738 .321 .258 r
F P
0 g
s
.68551 .40003 m .72064 .41752 L .70342 .37678 L p .327 .522 .894 r
F P
0 g
s
.70342 .37678 m .67081 .36647 L .68551 .40003 L p .327 .522 .894 r
F P
0 g
s
.77067 .51944 m .7891 .55448 L .79752 .50006 L p .088 .183 .669 r
F P
0 g
s
.79752 .50006 m .77792 .46791 L .77067 .51944 L p .088 .183 .669 r
F P
0 g
s
.58331 .34862 m .61171 .34017 L .57735 .32468 L p .506 .726 .972 r
F P
0 g
s
.57735 .32468 m .56028 .33835 L .58331 .34862 L p .506 .726 .972 r
F P
0 g
s
.54288 .84888 m .54498 .8341 L .47106 .83104 L p .572 .097 .09 r
F P
0 g
s
.54498 .8341 m .54288 .84888 L .60705 .84081 L p .441 0 .071 r
F P
0 g
s
.60705 .84081 m .61735 .8249 L .54498 .8341 L p .441 0 .071 r
F P
0 g
s
.26461 .65471 m .26927 .69078 L .31771 .73309 L p .945 .624 .392 r
F P
0 g
s
.32753 .76372 m .31771 .73309 L .26927 .69078 L p .913 .511 .196 r
F P
0 g
s
.7662 .67793 m .76199 .71308 L .79866 .66624 L p 0 0 .309 r
F P
0 g
s
.79866 .66624 m .80368 .62913 L .7662 .67793 L p 0 0 .309 r
F P
0 g
s
.47729 .8462 m .47106 .83104 L .40176 .81589 L p .657 .151 .032 r
F P
0 g
s
.47106 .83104 m .47729 .8462 L .54288 .84888 L p .572 .097 .09 r
F P
0 g
s
.45698 .33151 m .48011 .34287 L .50547 .33529 L p .639 .852 .981 r
F P
0 g
s
.48011 .34287 m .45698 .33151 L .42729 .35054 L p .699 .863 .96 r
F P
0 g
s
.63595 .3621 m .67081 .36647 L .63928 .33752 L p .389 .634 .952 r
F P
0 g
s
.63928 .33752 m .61171 .34017 L .63595 .3621 L p .389 .634 .952 r
F P
0 g
s
.33784 .39689 m .30715 .41653 L .30066 .46417 L p .895 .938 .833 r
F P
0 g
s
.27498 .49417 m .30066 .46417 L .30715 .41653 L p .933 .961 .761 r
F P
0 g
s
.25572 .52783 m .24394 .56423 L .26769 .6173 L p .993 .829 .576 r
F P
0 g
s
.26461 .65471 m .26769 .6173 L .24394 .56423 L p .995 .77 .413 r
F P
0 g
s
.69522 .7796 m .68199 .80399 L .73279 .77272 L p .081 0 .056 r
F P
0 g
s
.73279 .77272 m .75076 .74504 L .69522 .7796 L p .081 0 .056 r
F P
0 g
s
.56028 .33835 m .57735 .32468 L .53681 .31765 L p .528 .774 .988 r
F P
0 g
s
.53681 .31765 m .53329 .33371 L .56028 .33835 L p .528 .774 .988 r
F P
0 g
s
.42729 .35054 m .39554 .35124 L .37223 .383 L p .774 .908 .933 r
F P
0 g
s
.33784 .39689 m .37223 .383 L .39554 .35124 L p .8 .964 .913 r
F P
0 g
s
.72064 .41752 m .75187 .44022 L .73261 .39335 L p .161 .402 .846 r
F P
0 g
s
.73261 .39335 m .70342 .37678 L .72064 .41752 L p .161 .402 .846 r
F P
0 g
s
.61735 .8249 m .60705 .84081 L .66414 .82251 L p .23 0 0 r
F P
0 g
s
.66414 .82251 m .68199 .80399 L .61735 .8249 L p .23 0 0 r
F P
0 g
s
.49498 .32003 m .50547 .33529 L .53329 .33371 L p .576 .82 .991 r
F P
0 g
s
.50547 .33529 m .49498 .32003 L .45698 .33151 L p .639 .852 .981 r
F P
0 g
s
.53329 .33371 m .53681 .31765 L .49498 .32003 L p .576 .82 .991 r
F P
0 g
s
.7891 .55448 m .80036 .59144 L .80952 .53585 L p 0 0 .517 r
F P
0 g
s
.80952 .53585 m .79752 .50006 L .7891 .55448 L p 0 0 .517 r
F P
0 g
s
.39554 .35124 m .42729 .35054 L .45698 .33151 L p .695 .924 .968 r
F P
0 g
s
.32753 .76372 m .34326 .7896 L .40176 .81589 L p .808 .353 .155 r
F P
0 g
s
.41594 .83292 m .40176 .81589 L .34326 .7896 L p .684 .139 0 r
F P
0 g
s
.40176 .81589 m .41594 .83292 L .47729 .8462 L p .657 .151 .032 r
F P
0 g
s
.30715 .41653 m .28147 .44184 L .27498 .49417 L p .933 .961 .761 r
F P
0 g
s
.25572 .52783 m .27498 .49417 L .28147 .44184 L p .943 .948 .626 r
F P
0 g
s
.61171 .34017 m .63928 .33752 L .59401 .31694 L p .356 .685 .98 r
F P
0 g
s
.59401 .31694 m .57735 .32468 L .61171 .34017 L p .356 .685 .98 r
F P
0 g
s
.76199 .71308 m .75076 .74504 L .78531 .70142 L p 0 0 .045 r
F P
0 g
s
.78531 .70142 m .79866 .66624 L .76199 .71308 L p 0 0 .045 r
F P
0 g
s
.67081 .36647 m .70342 .37678 L .66525 .34137 L p .199 .535 .925 r
F P
0 g
s
.66525 .34137 m .63928 .33752 L .67081 .36647 L p .199 .535 .925 r
F P
0 g
s
.26927 .69078 m .28169 .72426 L .32753 .76372 L p .913 .511 .196 r
F P
0 g
s
.34326 .7896 m .32753 .76372 L .28169 .72426 L p .795 .311 0 r
F P
0 g
s
.24394 .56423 m .24046 .60221 L .26461 .65471 L p .995 .77 .413 r
F P
0 g
s
.26927 .69078 m .26461 .65471 L .24046 .60221 L p .93 .634 .163 r
F P
0 g
s
.75187 .44022 m .77792 .46791 L .75713 .41627 L p 0 .212 .737 r
F P
0 g
s
.75713 .41627 m .73261 .39335 L .75187 .44022 L p 0 .212 .737 r
F P
0 g
s
.39554 .35124 m .36574 .35818 L .33784 .39689 L p .8 .964 .913 r
F P
0 g
s
.30715 .41653 m .33784 .39689 L .36574 .35818 L p .8 .999 .842 r
F P
0 g
s
.43445 .32603 m .45698 .33151 L .49498 .32003 L p .575 .895 .986 r
F P
0 g
s
.45698 .33151 m .43445 .32603 L .39554 .35124 L p .695 .924 .968 r
F P
0 g
s
.54028 .85669 m .54288 .84888 L .47729 .8462 L p .398 0 0 r
F P
0 g
s
.54288 .84888 m .54028 .85669 L .59433 .84993 L p .247 0 0 r
F P
0 g
s
.59433 .84993 m .60705 .84081 L .54288 .84888 L p .247 0 0 r
F P
0 g
s
.80036 .59144 m .80368 .62913 L .81307 .57412 L p 0 0 .272 r
F P
0 g
s
.81307 .57412 m .80952 .53585 L .80036 .59144 L p 0 0 .272 r
F P
0 g
s
.48498 .85444 m .47729 .8462 L .41594 .83292 L p .462 0 0 r
F P
0 g
s
.47729 .8462 m .48498 .85444 L .54028 .85669 L p .398 0 0 r
F P
0 g
s
.68199 .80399 m .66414 .82251 L .70867 .79525 L p 0 0 0 r
F P
0 g
s
.70867 .79525 m .73279 .77272 L .68199 .80399 L p 0 0 0 r
F P
0 g
s
.57735 .32468 m .59401 .31694 L .54025 .30756 L p .371 .751 .989 r
F P
0 g
s
.54025 .30756 m .53681 .31765 L .57735 .32468 L p .371 .751 .989 r
F P
0 g
s
.36574 .35818 m .39554 .35124 L .43445 .32603 L p .648 .961 .922 r
F P
0 g
s
.28147 .44184 m .2621 .47244 L .25572 .52783 L p .943 .948 .626 r
F P
0 g
s
.24394 .56423 m .25572 .52783 L .2621 .47244 L p .876 .847 .387 r
F P
0 g
s
.48472 .31075 m .49498 .32003 L .53681 .31765 L p .451 .828 .99 r
F P
0 g
s
.49498 .32003 m .48472 .31075 L .43445 .32603 L p .575 .895 .986 r
F P
0 g
s
.60705 .84081 m .59433 .84993 L .6422 .83464 L p 0 0 0 r
F P
0 g
s
.6422 .83464 m .66414 .82251 L .60705 .84081 L p 0 0 0 r
F P
0 g
s
.53681 .31765 m .54025 .30756 L .48472 .31075 L p .451 .828 .99 r
F P
0 g
s
.70342 .37678 m .73261 .39335 L .68866 .35234 L p 0 .342 .805 r
F P
0 g
s
.68866 .35234 m .66525 .34137 L .70342 .37678 L p 0 .342 .805 r
F P
0 g
s
.77792 .46791 m .79752 .50006 L .77567 .44528 L p 0 0 .514 r
F P
0 g
s
.77567 .44528 m .75713 .41627 L .77792 .46791 L p 0 0 .514 r
F P
0 g
s
.75076 .74504 m .73279 .77272 L .76403 .73343 L p 0 0 0 r
F P
0 g
s
.76403 .73343 m .78531 .70142 L .75076 .74504 L p 0 0 0 r
F P
0 g
s
.24046 .60221 m .24571 .64042 L .26927 .69078 L p .93 .634 .163 r
F P
0 g
s
.28169 .72426 m .26927 .69078 L .24571 .64042 L p .74 .388 0 r
F P
0 g
s
.36574 .35818 m .33897 .37184 L .30715 .41653 L p .8 .999 .842 r
F P
0 g
s
.28147 .44184 m .30715 .41653 L .33897 .37184 L p .726 .953 .659 r
F P
0 g
s
.63928 .33752 m .66525 .34137 L .60978 .31605 L p .088 .558 .906 r
F P
0 g
s
.60978 .31605 m .59401 .31694 L .63928 .33752 L p .088 .558 .906 r
F P
0 g
s
.34326 .7896 m .36443 .80995 L .41594 .83292 L p .684 .139 0 r
F P
0 g
s
.4334 .84333 m .41594 .83292 L .36443 .80995 L p .408 0 0 r
F P
0 g
s
.41594 .83292 m .4334 .84333 L .48498 .85444 L p .462 0 0 r
F P
0 g
s
.28169 .72426 m .30152 .75398 L .34326 .7896 L p .795 .311 0 r
F P
0 g
s
.36443 .80995 m .34326 .7896 L .30152 .75398 L p .535 .01 0 r
F P
0 g
s
.80368 .62913 m .79866 .66624 L .80771 .6135 L p 0 0 0 r
F P
0 g
s
.80771 .6135 m .81307 .57412 L .80368 .62913 L p 0 0 0 r
F P
0 g
s
.41317 .32724 m .43445 .32603 L .48472 .31075 L p .406 .858 .879 r
F P
0 g
s
.43445 .32603 m .41317 .32724 L .36574 .35818 L p .648 .961 .922 r
F P
0 g
s
.2621 .47244 m .25021 .50758 L .24394 .56423 L p .876 .847 .387 r
F P
0 g
s
.24046 .60221 m .24394 .56423 L .25021 .50758 L p 0 0 0 r
F P
0 g
s
.66414 .82251 m .6422 .83464 L .67918 .81198 L p .404 .826 .652 r
F P
0 g
s
.67918 .81198 m .70867 .79525 L .66414 .82251 L p .404 .826 .652 r
F P
0 g
s
.33897 .37184 m .36574 .35818 L .41317 .32724 L p .492 .888 .73 r
F P
0 g
s
.53726 .85731 m .54028 .85669 L .48498 .85444 L p .069 0 0 r
F P
0 g
s
.54028 .85669 m .53726 .85731 L .57954 .85202 L p 0 0 0 r
F P
0 g
s
.57954 .85202 m .59433 .84993 L .54028 .85669 L p 0 0 0 r
F P
0 g
s
.79752 .50006 m .80952 .53585 L .78707 .47974 L p .73 .402 0 r
F P
0 g
s
.78707 .47974 m .77567 .44528 L .79752 .50006 L p .73 .402 0 r
F P
0 g
s
.48498 .85444 m .49395 .85555 L .53726 .85731 L p .069 0 0 r
F P
0 g
s
.49395 .85555 m .48498 .85444 L .4334 .84333 L p 0 .479 .731 r
F P
0 g
s
.59401 .31694 m .60978 .31605 L .54351 .30447 L p .069 .609 .853 r
F P
0 g
s
.54351 .30447 m .54025 .30756 L .59401 .31694 L p .069 .609 .853 r
F P
0 g
s
.24571 .64042 m .25969 .67744 L .28169 .72426 L p .74 .388 0 r
F P
0 g
s
.30152 .75398 m .28169 .72426 L .25969 .67744 L p 0 0 .507 r
F P
0 g
s
.73261 .39335 m .75713 .41627 L .70844 .37084 L p .484 0 0 r
F P
0 g
s
.70844 .37084 m .68866 .35234 L .73261 .39335 L p .484 0 0 r
F P
0 g
s
.73279 .77272 m .70867 .79525 L .7356 .76118 L p .66 .924 .629 r
F P
0 g
s
.7356 .76118 m .76403 .73343 L .73279 .77272 L p .66 .924 .629 r
F P
0 g
s
.33897 .37184 m .31641 .39247 L .28147 .44184 L p .726 .953 .659 r
F P
0 g
s
.2621 .47244 m .28147 .44184 L .31641 .39247 L p 0 0 0 r
F P
0 g
s
.59433 .84993 m .57954 .85202 L .61679 .8401 L p .313 .802 .786 r
F P
0 g
s
.61679 .8401 m .6422 .83464 L .59433 .84993 L p .313 .802 .786 r
F P
0 g
s
.47499 .3084 m .48472 .31075 L .54025 .30756 L p .183 .713 .837 r
F P
0 g
s
.48472 .31075 m .47499 .3084 L .41317 .32724 L p .406 .858 .879 r
F P
0 g
s
.79866 .66624 m .78531 .70142 L .79347 .65247 L p .851 .856 .4 r
F P
0 g
s
.79347 .65247 m .80771 .6135 L .79866 .66624 L p .851 .856 .4 r
F P
0 g
s
.54025 .30756 m .54351 .30447 L .47499 .3084 L p .183 .713 .837 r
F P
0 g
s
.30152 .75398 m .32808 .77897 L .36443 .80995 L p .535 .01 0 r
F P
0 g
s
.36443 .80995 m .39039 .82418 L .4334 .84333 L p .408 0 0 r
F P
0 g
s
.39039 .82418 m .36443 .80995 L .32808 .77897 L p 0 .306 .762 r
F P
0 g
s
.66525 .34137 m .68866 .35234 L .62406 .32285 L p .307 0 0 r
F P
0 g
s
.62406 .32285 m .60978 .31605 L .66525 .34137 L p .307 0 0 r
F P
0 g
s
.25021 .50758 m .2467 .54613 L .24046 .60221 L p 0 0 0 r
F P
0 g
s
.24571 .64042 m .24046 .60221 L .2467 .54613 L p 0 0 .294 r
F P
0 g
s
.45368 .84687 m .4334 .84333 L .39039 .82418 L p 0 .495 .843 r
F P
0 g
s
.4334 .84333 m .45368 .84687 L .49395 .85555 L p 0 .479 .731 r
F P
0 g
s
.80952 .53585 m .81307 .57412 L .79045 .51855 L p .933 .658 .183 r
F P
0 g
s
.79045 .51855 m .78707 .47974 L .80952 .53585 L p .933 .658 .183 r
F P
0 g
s
.41317 .32724 m .39394 .33591 L .33897 .37184 L p .492 .888 .73 r
F P
0 g
s
.31641 .39247 m .33897 .37184 L .39394 .33591 L p 0 0 0 r
F P
0 g
s
.39394 .33591 m .41317 .32724 L .47499 .3084 L p 0 0 0 r
F P
0 g
s
.6422 .83464 m .61679 .8401 L .64524 .82254 L p .574 .94 .889 r
F P
0 g
s
.64524 .82254 m .67918 .81198 L .6422 .83464 L p .574 .94 .889 r
F P
0 g
s
.25969 .67744 m .28191 .7119 L .30152 .75398 L p 0 0 .507 r
F P
0 g
s
.32808 .77897 m .30152 .75398 L .28191 .7119 L p 0 .212 .737 r
F P
0 g
s
.31641 .39247 m .29931 .41995 L .2621 .47244 L p 0 0 0 r
F P
0 g
s
.25021 .50758 m .2621 .47244 L .29931 .41995 L p 0 0 .05 r
F P
0 g
s
.75713 .41627 m .77567 .44528 L .72346 .39688 L p .786 .303 0 r
F P
0 g
s
.72346 .39688 m .70844 .37084 L .75713 .41627 L p .786 .303 0 r
F P
0 g
s
.70867 .79525 m .67918 .81198 L .70109 .78386 L p .744 .993 .833 r
F P
0 g
s
.70109 .78386 m .7356 .76118 L .70867 .79525 L p .744 .993 .833 r
F P
0 g
s
.78531 .70142 m .76403 .73343 L .77088 .68954 L p .918 .96 .641 r
F P
0 g
s
.77088 .68954 m .79347 .65247 L .78531 .70142 L p .918 .96 .641 r
F P
0 g
s
.53387 .85071 m .53726 .85731 L .49395 .85555 L p .287 .754 .944 r
F P
0 g
s
.53726 .85731 m .53387 .85071 L .56303 .84705 L p .381 .823 .949 r
F P
0 g
s
.56303 .84705 m .57954 .85202 L .53726 .85731 L p .381 .823 .949 r
F P
0 g
s
.60978 .31605 m .62406 .32285 L .54647 .30933 L p .329 0 0 r
F P
0 g
s
.54647 .30933 m .54351 .30447 L .60978 .31605 L p .329 0 0 r
F P
0 g
s
.50397 .84949 m .49395 .85555 L .45368 .84687 L p .256 .705 .957 r
F P
0 g
s
.49395 .85555 m .50397 .84949 L .53387 .85071 L p .287 .754 .944 r
F P
0 g
s
.2467 .54613 m .25201 .58668 L .24571 .64042 L p 0 0 .294 r
F P
0 g
s
.25969 .67744 m .24571 .64042 L .25201 .58668 L p 0 0 .542 r
F P
0 g
s
.32808 .77897 m .36044 .79852 L .39039 .82418 L p 0 .306 .762 r
F P
0 g
s
.42037 .83198 m .39039 .82418 L .36044 .79852 L p .133 .527 .917 r
F P
0 g
s
.39039 .82418 m .42037 .83198 L .45368 .84687 L p 0 .495 .843 r
F P
0 g
s
.57954 .85202 m .56303 .84705 L .58856 .83881 L p .512 .89 .966 r
F P
0 g
s
.58856 .83881 m .61679 .8401 L .57954 .85202 L p .512 .89 .966 r
F P
0 g
s
.46616 .31393 m .47499 .3084 L .54351 .30447 L p .193 0 0 r
F P
0 g
s
.47499 .3084 m .46616 .31393 L .39394 .33591 L p 0 0 0 r
F P
0 g
s
.68866 .35234 m .70844 .37084 L .63617 .33801 L p .642 .082 0 r
F P
0 g
s
.63617 .33801 m .62406 .32285 L .68866 .35234 L p .642 .082 0 r
F P
0 g
s
.81307 .57412 m .80771 .6135 L .78535 .56028 L p .997 .794 .441 r
F P
0 g
s
.78535 .56028 m .79045 .51855 L .81307 .57412 L p .997 .794 .441 r
F P
0 g
s
.54351 .30447 m .54647 .30933 L .46616 .31393 L p .193 0 0 r
F P
0 g
s
.47627 .84348 m .45368 .84687 L .42037 .83198 L p .284 .674 .972 r
F P
0 g
s
.45368 .84687 m .47627 .84348 L .50397 .84949 L p .256 .705 .957 r
F P
0 g
s
.28191 .7119 m .3115 .7426 L .32808 .77897 L p 0 .212 .737 r
F P
0 g
s
.36044 .79852 m .32808 .77897 L .3115 .7426 L p .121 .413 .86 r
F P
0 g
s
.76403 .73343 m .7356 .76118 L .74089 .72338 L p .909 .979 .782 r
F P
0 g
s
.74089 .72338 m .77088 .68954 L .76403 .73343 L p .909 .979 .782 r
F P
0 g
s
.29931 .41995 m .28878 .45374 L .25021 .50758 L p 0 0 .05 r
F P
0 g
s
.2467 .54613 m .25021 .50758 L .28878 .45374 L p .001 0 .332 r
F P
0 g
s
.39394 .33591 m .37766 .35256 L .31641 .39247 L p 0 0 0 r
F P
0 g
s
.29931 .41995 m .31641 .39247 L .37766 .35256 L p .071 0 .037 r
F P
0 g
s
.67918 .81198 m .64524 .82254 L .66169 .80092 L p .751 .973 .926 r
F P
0 g
s
.66169 .80092 m .70109 .78386 L .67918 .81198 L p .751 .973 .926 r
F P
0 g
s
.77567 .44528 m .78707 .47974 L .73272 .43003 L p .917 .52 .205 r
F P
0 g
s
.73272 .43003 m .72346 .39688 L .77567 .44528 L p .917 .52 .205 r
F P
0 g
s
.61679 .8401 m .58856 .83881 L .60781 .82677 L p .639 .927 .973 r
F P
0 g
s
.60781 .82677 m .64524 .82254 L .61679 .8401 L p .639 .927 .973 r
F P
0 g
s
.25201 .58668 m .2661 .62764 L .25969 .67744 L p 0 0 .542 r
F P
0 g
s
.28191 .7119 m .25969 .67744 L .2661 .62764 L p .079 .206 .696 r
F P
0 g
s
.37766 .35256 m .39394 .33591 L .46616 .31393 L p .217 0 0 r
F P
0 g
s
.36044 .79852 m .39754 .81217 L .42037 .83198 L p .133 .527 .917 r
F P
0 g
s
.45356 .83323 m .42037 .83198 L .39754 .81217 L p .35 .653 .968 r
F P
0 g
s
.42037 .83198 m .45356 .83323 L .47627 .84348 L p .284 .674 .972 r
F P
0 g
s
.80771 .6135 m .79347 .65247 L .77184 .60323 L p .99 .851 .606 r
F P
0 g
s
.77184 .60323 m .78535 .56028 L .80771 .6135 L p .99 .851 .606 r
F P
0 g
s
.5302 .83696 m .53387 .85071 L .50397 .84949 L p .499 .808 1 r
F P
0 g
s
.53387 .85071 m .5302 .83696 L .54517 .83506 L p .543 .839 .999 r
F P
0 g
s
.54517 .83506 m .56303 .84705 L .53387 .85071 L p .543 .839 .999 r
F P
0 g
s
.51483 .83633 m .50397 .84949 L .47627 .84348 L p .476 .776 .997 r
F P
0 g
s
.50397 .84949 m .51483 .83633 L .5302 .83696 L p .499 .808 1 r
F P
0 g
s
.62406 .32285 m .63617 .33801 L .54899 .32292 L p .591 .064 0 r
F P
0 g
s
.54899 .32292 m .54647 .30933 L .62406 .32285 L p .591 .064 0 r
F P
0 g
s
.3115 .7426 m .34729 .76861 L .36044 .79852 L p .121 .413 .86 r
F P
0 g
s
.39754 .81217 m .36044 .79852 L .34729 .76861 L p .297 .547 .919 r
F P
0 g
s
.7356 .76118 m .70109 .78386 L .70476 .7529 L p .869 .958 .861 r
F P
0 g
s
.70476 .7529 m .74089 .72338 L .7356 .76118 L p .869 .958 .861 r
F P
0 g
s
.56303 .84705 m .54517 .83506 L .55818 .83081 L p .597 .861 .993 r
F P
0 g
s
.55818 .83081 m .58856 .83881 L .56303 .84705 L p .597 .861 .993 r
F P
0 g
s
.70844 .37084 m .72346 .39688 L .6454 .3618 L p .793 .33 .139 r
F P
0 g
s
.6454 .3618 m .63617 .33801 L .70844 .37084 L p .793 .33 .139 r
F P
0 g
s
.28878 .45374 m .28566 .49279 L .2467 .54613 L p .001 0 .332 r
F P
0 g
s
.25201 .58668 m .2467 .54613 L .28566 .49279 L p .167 .086 .513 r
F P
0 g
s
.2661 .62764 m .28842 .66736 L .28191 .7119 L p .079 .206 .696 r
F P
0 g
s
.3115 .7426 m .28191 .7119 L .28842 .66736 L p .228 .359 .789 r
F P
0 g
s
.64524 .82254 m .60781 .82677 L .61865 .81207 L p .726 .921 .959 r
F P
0 g
s
.61865 .81207 m .66169 .80092 L .64524 .82254 L p .726 .921 .959 r
F P
0 g
s
.50065 .83322 m .47627 .84348 L .45356 .83323 L p .476 .746 .988 r
F P
0 g
s
.47627 .84348 m .50065 .83322 L .51483 .83633 L p .476 .776 .997 r
F P
0 g
s
.45867 .32806 m .46616 .31393 L .54647 .30933 L p .454 0 0 r
F P
0 g
s
.46616 .31393 m .45867 .32806 L .37766 .35256 L p .217 0 0 r
F P
0 g
s
.37766 .35256 m .36527 .37736 L .29931 .41995 L p .071 0 .037 r
F P
0 g
s
.28878 .45374 m .29931 .41995 L .36527 .37736 L p .253 0 .297 r
F P
0 g
s
.78707 .47974 m .79045 .51855 L .73547 .46929 L p .947 .636 .414 r
F P
0 g
s
.73547 .46929 m .73272 .43003 L .78707 .47974 L p .947 .636 .414 r
F P
0 g
s
.54647 .30933 m .54899 .32292 L .45867 .32806 L p .454 0 0 r
F P
0 g
s
.58856 .83881 m .55818 .83081 L .56787 .82464 L p .65 .87 .982 r
F P
0 g
s
.56787 .82464 m .60781 .82677 L .58856 .83881 L p .65 .87 .982 r
F P
0 g
s
.79347 .65247 m .77088 .68954 L .75049 .64563 L p .957 .87 .71 r
F P
0 g
s
.75049 .64563 m .77184 .60323 L .79347 .65247 L p .957 .87 .71 r
F P
0 g
s
.70109 .78386 m .66169 .80092 L .66388 .77733 L p .819 .924 .905 r
F P
0 g
s
.66388 .77733 m .70476 .7529 L .70109 .78386 L p .819 .924 .905 r
F P
0 g
s
.36527 .37736 m .37766 .35256 L .45867 .32806 L p .396 .018 .2 r
F P
0 g
s
.34729 .76861 m .38797 .78928 L .39754 .81217 L p .297 .547 .919 r
F P
0 g
s
.43826 .8197 m .39754 .81217 L .38797 .78928 L p .424 .638 .945 r
F P
0 g
s
.39754 .81217 m .43826 .8197 L .45356 .83323 L p .35 .653 .968 r
F P
0 g
s
.48914 .82795 m .45356 .83323 L .43826 .8197 L p .493 .722 .973 r
F P
0 g
s
.45356 .83323 m .48914 .82795 L .50065 .83322 L p .476 .746 .988 r
F P
0 g
s
.28842 .66736 m .31795 .70438 L .3115 .7426 L p .228 .359 .789 r
F P
0 g
s
.34729 .76861 m .3115 .7426 L .31795 .70438 L p .338 .472 .848 r
F P
0 g
s
.28566 .49279 m .29037 .53564 L .25201 .58668 L p .167 .086 .513 r
F P
0 g
s
.2661 .62764 m .25201 .58668 L .29037 .53564 L p .281 .237 .63 r
F P
0 g
s
.60781 .82677 m .56787 .82464 L .57315 .81717 L p .69 .862 .964 r
F P
0 g
s
.57315 .81717 m .61865 .81207 L .60781 .82677 L p .69 .862 .964 r
F P
0 g
s
.52632 .81621 m .5302 .83696 L .51483 .83633 L closepath p .602 .791 .972 r
F P
0 g
s
.52632 .81621 m .54517 .83506 L .5302 .83696 L closepath p .613 .799 .971 r
F P
0 g
s
.77088 .68954 m .74089 .72338 L .72233 .68582 L p .915 .872 .781 r
F P
0 g
s
.72233 .68582 m .75049 .64563 L .77088 .68954 L p .915 .872 .781 r
F P
0 g
s
.72346 .39688 m .73272 .43003 L .65111 .39392 L p .841 .47 .351 r
F P
0 g
s
.65111 .39392 m .6454 .3618 L .72346 .39688 L p .841 .47 .351 r
F P
0 g
s
.52632 .81621 m .51483 .83633 L .50065 .83322 L closepath p .594 .781 .97 r
F P
0 g
s
.79045 .51855 m .78535 .56028 L .73132 .51317 L p .939 .698 .547 r
F P
0 g
s
.73132 .51317 m .73547 .46929 L .79045 .51855 L p .939 .698 .547 r
F P
0 g
s
.63617 .33801 m .6454 .3618 L .55092 .34563 L p .7 .275 .235 r
F P
0 g
s
.55092 .34563 m .54899 .32292 L .63617 .33801 L p .7 .275 .235 r
F P
0 g
s
.52632 .81621 m .55818 .83081 L .54517 .83506 L closepath p .626 .804 .968 r
F P
0 g
s
.66169 .80092 m .61865 .81207 L .61966 .79618 L p .767 .884 .929 r
F P
0 g
s
.61966 .79618 m .66388 .77733 L .66169 .80092 L p .767 .884 .929 r
F P
0 g
s
.36527 .37736 m .35762 .40995 L .28878 .45374 L p .253 0 .297 r
F P
0 g
s
.28566 .49279 m .28878 .45374 L .35762 .40995 L p .362 .155 .458 r
F P
0 g
s
.52632 .81621 m .50065 .83322 L .48914 .82795 L closepath p .591 .771 .966 r
F P
0 g
s
.38797 .78928 m .4322 .80421 L .43826 .8197 L p .424 .638 .945 r
F P
0 g
s
.48153 .82104 m .43826 .8197 L .4322 .80421 L p .521 .704 .954 r
F P
0 g
s
.43826 .8197 m .48153 .82104 L .48914 .82795 L p .493 .722 .973 r
F P
0 g
s
.31795 .70438 m .3534 .73744 L .34729 .76861 L p .338 .472 .848 r
F P
0 g
s
.38797 .78928 m .34729 .76861 L .3534 .73744 L p .424 .559 .887 r
F P
0 g
s
.52632 .81621 m .56787 .82464 L .55818 .83081 L closepath p .64 .806 .963 r
F P
0 g
s
.29037 .53564 m .30285 .58048 L .2661 .62764 L p .281 .237 .63 r
F P
0 g
s
.28842 .66736 m .2661 .62764 L .30285 .58048 L p .363 .349 .709 r
F P
0 g
s
.52632 .81621 m .48914 .82795 L .48153 .82104 L closepath p .592 .762 .96 r
F P
0 g
s
.45295 .35113 m .45867 .32806 L .54899 .32292 L p .576 .178 .251 r
F P
0 g
s
.45867 .32806 m .45295 .35113 L .36527 .37736 L p .396 .018 .2 r
F P
0 g
s
.74089 .72338 m .70476 .7529 L .68865 .7224 L p .87 .865 .831 r
F P
0 g
s
.68865 .7224 m .72233 .68582 L .74089 .72338 L p .87 .865 .831 r
F P
0 g
s
.61865 .81207 m .57315 .81717 L .57341 .80919 L p .715 .843 .943 r
F P
0 g
s
.57341 .80919 m .61966 .79618 L .61865 .81207 L p .715 .843 .943 r
F P
0 g
s
.52632 .81621 m .57315 .81717 L .56787 .82464 L closepath p .651 .804 .956 r
F P
0 g
s
.54899 .32292 m .55092 .34563 L .45295 .35113 L p .576 .178 .251 r
F P
0 g
s
.3534 .73744 m .39333 .76564 L .38797 .78928 L p .424 .559 .887 r
F P
0 g
s
.4322 .80421 m .38797 .78928 L .39333 .76564 L p .493 .631 .914 r
F P
0 g
s
.35762 .40995 m .36527 .37736 L .45295 .35113 L p .49 .189 .382 r
F P
0 g
s
.4322 .80421 m .4787 .81321 L .48153 .82104 L p .521 .704 .954 r
F P
0 g
s
.52632 .81621 m .48153 .82104 L .4787 .81321 L closepath p .598 .754 .953 r
F P
0 g
s
.78535 .56028 m .77184 .60323 L .72035 .55977 L p .918 .734 .638 r
F P
0 g
s
.72035 .55977 m .73132 .51317 L .78535 .56028 L p .918 .734 .638 r
F P
0 g
s
.70476 .7529 m .66388 .77733 L .65088 .75431 L p .824 .852 .868 r
F P
0 g
s
.65088 .75431 m .68865 .7224 L .70476 .7529 L p .824 .852 .868 r
F P
0 g
s
.52632 .81621 m .57341 .80919 L .57315 .81717 L closepath p .66 .799 .949 r
F P
0 g
s
.39333 .76564 m .43631 .78837 L .4322 .80421 L p .493 .631 .914 r
F P
0 g
s
.4787 .81321 m .4322 .80421 L .43631 .78837 L p .553 .693 .932 r
F P
0 g
s
.30285 .58048 m .32252 .62542 L .28842 .66736 L p .363 .349 .709 r
F P
0 g
s
.31795 .70438 m .28842 .66736 L .32252 .62542 L p .425 .436 .768 r
F P
0 g
s
.35762 .40995 m .35534 .44938 L .28566 .49279 L p .362 .155 .458 r
F P
0 g
s
.29037 .53564 m .28566 .49279 L .35534 .44938 L p .432 .273 .564 r
F P
0 g
s
.73272 .43003 m .73547 .46929 L .65281 .43348 L p .85 .552 .483 r
F P
0 g
s
.65281 .43348 m .65111 .39392 L .73272 .43003 L p .85 .552 .483 r
F P
0 g
s
.43631 .78837 m .48103 .80529 L .4787 .81321 L p .553 .693 .932 r
F P
0 g
s
.52632 .81621 m .4787 .81321 L .48103 .80529 L closepath p .606 .749 .945 r
F P
0 g
s
.52632 .81621 m .55896 .79512 L .56852 .80155 L closepath p .666 .781 .935 r
F P
0 g
s
.52632 .81621 m .54573 .79064 L .55896 .79512 L closepath p .663 .772 .93 r
F P
0 g
s
.52632 .81621 m .5303 .78861 L .54573 .79064 L closepath p .657 .763 .928 r
F P
0 g
s
.52632 .81621 m .51441 .7893 L .5303 .78861 L closepath p .649 .755 .927 r
F P
0 g
s
.52632 .81621 m .49988 .79261 L .51441 .7893 L closepath p .639 .749 .929 r
F P
0 g
s
.52632 .81621 m .48834 .79815 L .49988 .79261 L closepath p .628 .746 .933 r
F P
0 g
s
.52632 .81621 m .48103 .80529 L .48834 .79815 L closepath p .617 .746 .938 r
F P
0 g
s
.52632 .81621 m .56852 .80155 L .57341 .80919 L closepath p .665 .791 .942 r
F P
0 g
s
.66388 .77733 m .61966 .79618 L .61041 .78084 L p .776 .836 .898 r
F P
0 g
s
.61041 .78084 m .65088 .75431 L .66388 .77733 L p .776 .836 .898 r
F P
0 g
s
.6454 .3618 m .65111 .39392 L .5521 .37726 L p .741 .397 .4 r
F P
0 g
s
.5521 .37726 m .55092 .34563 L .6454 .3618 L p .741 .397 .4 r
F P
0 g
s
.61966 .79618 m .57341 .80919 L .56852 .80155 L p .724 .816 .922 r
F P
0 g
s
.56852 .80155 m .61041 .78084 L .61966 .79618 L p .724 .816 .922 r
F P
0 g
s
.32252 .62542 m .34841 .66861 L .31795 .70438 L p .425 .436 .768 r
F P
0 g
s
.3534 .73744 m .31795 .70438 L .34841 .66861 L p .474 .509 .814 r
F P
0 g
s
.77184 .60323 m .75049 .64563 L .70307 .60706 L p .892 .756 .704 r
F P
0 g
s
.70307 .60706 m .72035 .55977 L .77184 .60323 L p .892 .756 .704 r
F P
0 g
s
.45046 .77395 m .48834 .79815 L .48103 .80529 L p .585 .689 .913 r
F P
0 g
s
.48103 .80529 m .43631 .78837 L .45046 .77395 L p .585 .689 .913 r
F P
0 g
s
.34841 .66861 m .37926 .70851 L .3534 .73744 L p .474 .509 .814 r
F P
0 g
s
.39333 .76564 m .3534 .73744 L .37926 .70851 L p .516 .573 .852 r
F P
0 g
s
.61041 .78084 m .56852 .80155 L .55896 .79512 L p .721 .787 .905 r
F P
0 g
s
.44942 .38293 m .45295 .35113 L .55092 .34563 L p .632 .31 .408 r
F P
0 g
s
.45295 .35113 m .44942 .38293 L .35762 .40995 L p .49 .189 .382 r
F P
0 g
s
.41371 .7439 m .45046 .77395 L .43631 .78837 L p .552 .632 .884 r
F P
0 g
s
.43631 .78837 m .39333 .76564 L .41371 .7439 L p .552 .632 .884 r
F P
0 g
s
.37926 .70851 m .41371 .7439 L .39333 .76564 L p .516 .573 .852 r
F P
0 g
s
.35534 .44938 m .35877 .49413 L .29037 .53564 L p .432 .273 .564 r
F P
0 g
s
.30285 .58048 m .29037 .53564 L .35877 .49413 L p .48 .361 .64 r
F P
0 g
s
.35534 .44938 m .35762 .40995 L .44942 .38293 L p .543 .3 .498 r
F P
0 g
s
.47332 .76265 m .49988 .79261 L .48834 .79815 L p .616 .692 .897 r
F P
0 g
s
.48834 .79815 m .45046 .77395 L .47332 .76265 L p .616 .692 .897 r
F P
0 g
s
.55092 .34563 m .5521 .37726 L .44942 .38293 L p .632 .31 .408 r
F P
0 g
s
.75049 .64563 m .72233 .68582 L .6804 .65304 L p .864 .77 .756 r
F P
0 g
s
.6804 .65304 m .70307 .60706 L .75049 .64563 L p .864 .77 .756 r
F P
0 g
s
.73547 .46929 m .73132 .51317 L .65025 .47895 L p .846 .604 .573 r
F P
0 g
s
.65025 .47895 m .65281 .43348 L .73547 .46929 L p .846 .604 .573 r
F P
0 g
s
.55896 .79512 m .59164 .76779 L .61041 .78084 L p .721 .787 .905 r
F P
0 g
s
.59164 .76779 m .55896 .79512 L .54573 .79064 L p .71 .76 .892 r
F P
0 g
s
.65088 .75431 m .61041 .78084 L .59164 .76779 L p .765 .788 .872 r
F P
0 g
s
.5024 .75586 m .51441 .7893 L .49988 .79261 L p .645 .701 .887 r
F P
0 g
s
.49988 .79261 m .47332 .76265 L .5024 .75586 L p .645 .701 .887 r
F P
0 g
s
.72233 .68582 m .68865 .7224 L .65347 .69598 L p .835 .779 .799 r
F P
0 g
s
.65347 .69598 m .6804 .65304 L .72233 .68582 L p .835 .779 .799 r
F P
0 g
s
.54573 .79064 m .56528 .75861 L .59164 .76779 L p .71 .76 .892 r
F P
0 g
s
.56528 .75861 m .54573 .79064 L .5303 .78861 L p .692 .736 .884 r
F P
0 g
s
.68865 .7224 m .65088 .75431 L .62349 .73454 L p .802 .785 .837 r
F P
0 g
s
.59164 .76779 m .62349 .73454 L .65088 .75431 L p .765 .788 .872 r
F P
0 g
s
.53432 .75445 m .5303 .78861 L .51441 .7893 L p .67 .716 .883 r
F P
0 g
s
.51441 .7893 m .5024 .75586 L .53432 .75445 L p .67 .716 .883 r
F P
0 g
s
.5303 .78861 m .53432 .75445 L .56528 .75861 L p .692 .736 .884 r
F P
0 g
s
.62349 .73454 m .65347 .69598 L .68865 .7224 L p .802 .785 .837 r
F P
0 g
s
.44736 .72672 m .47332 .76265 L .45046 .77395 L p .602 .641 .862 r
F P
0 g
s
.45046 .77395 m .41371 .7439 L .44736 .72672 L p .602 .641 .862 r
F P
0 g
s
.35877 .49413 m .36784 .54225 L .30285 .58048 L p .48 .361 .64 r
F P
0 g
s
.32252 .62542 m .30285 .58048 L .36784 .54225 L p .515 .43 .698 r
F P
0 g
s
.65111 .39392 m .65281 .43348 L .55246 .41695 L p .756 .474 .506 r
F P
0 g
s
.55246 .41695 m .5521 .37726 L .65111 .39392 L p .756 .474 .506 r
F P
0 g
s
.62349 .73454 m .59164 .76779 L .56528 .75861 L p .743 .746 .854 r
F P
0 g
s
.73132 .51317 m .72035 .55977 L .64349 .52829 L p .835 .641 .64 r
F P
0 g
s
.64349 .52829 m .65025 .47895 L .73132 .51317 L p .835 .641 .64 r
F P
0 g
s
.44942 .38293 m .44836 .42258 L .35534 .44938 L p .543 .3 .498 r
F P
0 g
s
.35877 .49413 m .35534 .44938 L .44836 .42258 L p .576 .379 .578 r
F P
0 g
s
.42284 .68546 m .44736 .72672 L .41371 .7439 L p .585 .592 .826 r
F P
0 g
s
.41371 .7439 m .37926 .70851 L .42284 .68546 L p .585 .592 .826 r
F P
0 g
s
.36784 .54225 m .38208 .59156 L .32252 .62542 L p .515 .43 .698 r
F P
0 g
s
.34841 .66861 m .32252 .62542 L .38208 .59156 L p .543 .489 .746 r
F P
0 g
s
.44836 .42258 m .44942 .38293 L .5521 .37726 L p .66 .396 .51 r
F P
0 g
s
.4906 .71633 m .5024 .75586 L .47332 .76265 L p .645 .657 .848 r
F P
0 g
s
.47332 .76265 m .44736 .72672 L .4906 .71633 L p .645 .657 .848 r
F P
0 g
s
.40073 .63992 m .42284 .68546 L .37926 .70851 L p .566 .542 .787 r
F P
0 g
s
.37926 .70851 m .34841 .66861 L .40073 .63992 L p .566 .542 .787 r
F P
0 g
s
.38208 .59156 m .40073 .63992 L .34841 .66861 L p .543 .489 .746 r
F P
0 g
s
.5521 .37726 m .55246 .41695 L .44836 .42258 L p .66 .396 .51 r
F P
0 g
s
.56528 .75861 m .58446 .72054 L .62349 .73454 L p .743 .746 .854 r
F P
0 g
s
.58446 .72054 m .56528 .75861 L .53432 .75445 L p .715 .71 .844 r
F P
0 g
s
.65347 .69598 m .62349 .73454 L .58446 .72054 L p .769 .729 .816 r
F P
0 g
s
.53827 .71417 m .53432 .75445 L .5024 .75586 L p .682 .68 .842 r
F P
0 g
s
.5024 .75586 m .4906 .71633 L .53827 .71417 L p .682 .68 .842 r
F P
0 g
s
.72035 .55977 m .70307 .60706 L .63288 .57923 L p .822 .669 .693 r
F P
0 g
s
.63288 .57923 m .64349 .52829 L .72035 .55977 L p .822 .669 .693 r
F P
0 g
s
.53432 .75445 m .53827 .71417 L .58446 .72054 L p .715 .71 .844 r
F P
0 g
s
.65281 .43348 m .65025 .47895 L .55192 .46316 L p .761 .528 .581 r
F P
0 g
s
.55192 .46316 m .55246 .41695 L .65281 .43348 L p .761 .528 .581 r
F P
0 g
s
.44836 .42258 m .44995 .46853 L .35877 .49413 L p .576 .379 .578 r
F P
0 g
s
.36784 .54225 m .35877 .49413 L .44995 .46853 L p .598 .44 .639 r
F P
0 g
s
.6804 .65304 m .65347 .69598 L .60261 .67714 L p .79 .712 .778 r
F P
0 g
s
.58446 .72054 m .60261 .67714 L .65347 .69598 L p .769 .729 .816 r
F P
0 g
s
.47941 .67146 m .4906 .71633 L .44736 .72672 L p .641 .616 .809 r
F P
0 g
s
.44736 .72672 m .42284 .68546 L .47941 .67146 L p .641 .616 .809 r
F P
0 g
s
.70307 .60706 m .6804 .65304 L .61901 .62951 L p .807 .692 .738 r
F P
0 g
s
.61901 .62951 m .63288 .57923 L .70307 .60706 L p .807 .692 .738 r
F P
0 g
s
.60261 .67714 m .61901 .62951 L .6804 .65304 L p .79 .712 .778 r
F P
0 g
s
.44995 .46853 m .44836 .42258 L .55246 .41695 L p .676 .457 .582 r
F P
0 g
s
.60261 .67714 m .58446 .72054 L .53827 .71417 L p .731 .684 .805 r
F P
0 g
s
.44995 .46853 m .45414 .51872 L .36784 .54225 L p .598 .44 .639 r
F P
0 g
s
.38208 .59156 m .36784 .54225 L .45414 .51872 L p .614 .49 .689 r
F P
0 g
s
.46928 .62239 m .47941 .67146 L .42284 .68546 L p .635 .576 .771 r
F P
0 g
s
.42284 .68546 m .40073 .63992 L .46928 .62239 L p .635 .576 .771 r
F P
0 g
s
.55246 .41695 m .55192 .46316 L .44995 .46853 L p .676 .457 .582 r
F P
0 g
s
.54203 .66854 m .53827 .71417 L .4906 .71633 L p .689 .646 .803 r
F P
0 g
s
.4906 .71633 m .47941 .67146 L .54203 .66854 L p .689 .646 .803 r
F P
0 g
s
.65025 .47895 m .64349 .52829 L .55052 .51378 L p .76 .569 .638 r
F P
0 g
s
.55052 .51378 m .55192 .46316 L .65025 .47895 L p .76 .569 .638 r
F P
0 g
s
.53827 .71417 m .54203 .66854 L .60261 .67714 L p .731 .684 .805 r
F P
0 g
s
.45414 .51872 m .46071 .57079 L .38208 .59156 L p .614 .49 .689 r
F P
0 g
s
.40073 .63992 m .38208 .59156 L .46071 .57079 L p .626 .535 .732 r
F P
0 g
s
.46071 .57079 m .46928 .62239 L .40073 .63992 L p .626 .535 .732 r
F P
0 g
s
.61901 .62951 m .60261 .67714 L .54203 .66854 L p .742 .658 .767 r
F P
0 g
s
.45414 .51872 m .44995 .46853 L .55192 .46316 L p .685 .505 .638 r
F P
0 g
s
.64349 .52829 m .63288 .57923 L .54831 .56644 L p .756 .602 .686 r
F P
0 g
s
.54831 .56644 m .55052 .51378 L .64349 .52829 L p .756 .602 .686 r
F P
0 g
s
.54543 .61873 m .54203 .66854 L .47941 .67146 L p .691 .614 .765 r
F P
0 g
s
.47941 .67146 m .46928 .62239 L .54543 .61873 L p .691 .614 .765 r
F P
0 g
s
.63288 .57923 m .61901 .62951 L .54543 .61873 L p .75 .631 .728 r
F P
0 g
s
.54203 .66854 m .54543 .61873 L .61901 .62951 L p .742 .658 .767 r
F P
0 g
s
.55192 .46316 m .55052 .51378 L .45414 .51872 L p .685 .505 .638 r
F P
0 g
s
.54543 .61873 m .54831 .56644 L .63288 .57923 L p .75 .631 .728 r
F P
0 g
s
.46071 .57079 m .45414 .51872 L .55052 .51378 L p .689 .545 .684 r
F P
0 g
s
.54831 .56644 m .54543 .61873 L .46928 .62239 L p .692 .58 .726 r
F P
0 g
s
.46928 .62239 m .46071 .57079 L .54831 .56644 L p .692 .58 .726 r
F P
0 g
s
.55052 .51378 m .54831 .56644 L .46071 .57079 L p .689 .545 .684 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo06oooooo3ol0000Yooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:_ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo067ooooo3Ol00005oc40017o00008_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02Wooooo000Qooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Mooooo`Co00001?la000=o`0000KoM00000Co0000oiL@0?nG403oUa00
1_l000000omD003o0000o`000005o`0001_ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Yooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Wooooo2ol0
000Cog@00003o`000?nG403oUa0000OoUa001_l00002oe@000Co00005oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0E?ooool7o`0000;o=`0000?o0000og@00?md00005omd00000ol0003oUa00oiL@000<
oiL@00So00005Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Yoooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D?ooool6o`0000Go=`0000?o0000og@0
0?md00004Omd000;o`00017oUa001?l0000Cooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool09oooool002Wooooo0_l0000Jooooo`03o`000?oooooooooo04cooooo1Ol00009ocL00003
o`000?md003oM00000?oM0003_l00007oi<]@004o`000?ncASco/dHlok=6?0Go00003_nG40001?l0
003oY1@0o`000?l0000Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool0
02Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`18ooooo`Go00002Olg0009o`00
01GoTbe000?o0000ok=6??ncAS`01_ncAS`6o`0000WoUa0000?o0000oj@D0?nT50000ol0000?oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`14ooooo`Co00002_lg0003o`0000;oI@@c00?o0000oi<]@?nC
;D006OnC;D000ol0003o/dHlok=6?00<ok=6?0Go00001OnG40001?l0003oY1@0oj@D0?nT5003o`00
00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Uooooo`00:Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo043ooooo0ol0000;ocL000?o00001OmU13<00ol0003o
Tbe0oi<]@00Joi<]@003o`000?ncASco/dHl013o/dHl1Ol000000onG403o0000oj@D0003oj@D00?o
00002oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000Xooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0?_ooool3o`0000Wo=`000ol00007ofD4<`03o`00
0?nC;D3oTbe001_oTbe000?o0000ok=6??ncAS`05OncAS`4o`0000CoY1@00ol00009ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0kooooo`Co00001_lg0004o`0000[oI@@c00?o0000oi<]@?nC;D006onC
;D000ol0003o/dHlok=6?00Gok=6?004o`000?o;E2?o0000o`0000GoY1@00_l00007ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03o`000?oo
oooooooo03Wooooo1?l00004ocL000?o00003_mU13<00ol0003oTbe0oi<]@00Coi<]@0_o00006?nc
AS`00ol0003obe@Sol]D8`03o`0000CoY1@00_l00005ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0g
ooooo`Co00000_lg0003o`00013oI@@c00?o0000oi<]@?nC;D001OnC;D0?o`0000SoXDmX00?o0000
okeUI_nmIFH01Ol0000Cok=6?003o`000?o;E2?obe@S00?obe@S0_l00004oj@D00;o00000oooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0=?ooool8o`00017oI@@c2_l0000Goj5?J003o`000?nmIFKo_FEV
00Go_FEV1Ol0000>ok=6?003o`000?o;E2?obe@S00Gobe@S0_l00004oj@D00;o000000?oooooo`00
0?ooool0>oooool00ol0003oooooooooo`0Qooooo`00:?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03;ooooo1_l0000AofD4<`?o00000_mm<6400ol0003oXDmXoj5?J00Loj5?J003
o`000?nmIFKo_FEV00[o_FEV1Ol0000:ok=6?003o`000?o;E2?obe@S00Kobe@S0ol00003oj@D00;o
0000??ooool00ol0003oooooooooo`0Qooooo`009oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02oooooo1Ol000000olB00Wo0000ofD4<`0=ofD4<`Co00001Omm<6400ol0003oXDmX
oj5?J00Loj5?J003o`000?nmIFKo_FEV00oo_FEV1Ol00005ok=6?003o`000?o;E2?obe@S00Wobe@S
0_l00002oj@D00;o0000??ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02gooooo1Ol000000olB00Wo0000ofD4<`0;ofD4<`?o00002Omm
<6400ol0003oXDmXoj5?J00Loj5?J003o`000?nmIFKo_FEV01Co_FEV1_l0000=ol]D8`?o000000?o
Y1@0o`000?ooool0>_ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02_ooooo1?l00003oa802@03o`000?mU13?oI@@c00KoI@@c1?l0000<
ogd`H@03o`000?nQCfSoXDmX01coXDmX00?o0000okeUI_nmIFH06OnmIFH3o`0000gobe@S1?l0000k
ooooo`03o`000?oooooooooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0Xoooo
o`Co00001?lB00T00ol0003oI@@cofD4<`04ofD4<`?o00004?mm<6400ol0003oXDmXoj5?J00Loj5?
J003o`000?nmIFKo_FEV01[o_FEV00?o0000omMhFOl000000_l0000:ol]D8`03o`000?o;E2?obe@S
00;o0000>oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Kooooo1?l00004oa802@04o`000?mU13?oI@@cofD4<`Co00004_mm<6400ol0
003oXDmXoj5?J00Moj5?J003o`000?nmIFKo_FEV01[o_FEV00?o0000omMhFOoGN5T00_oGN5T2o`00
00Sobe@S00?o0000ol]D8oo;E2<00_o;E2<00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool08oooool4o`0000Ko
4P091?l0000Fogd`H@03o`000?nQCfSoXDmX01goXDmX00?o0000okeUI_nmIFH06onmIFH00ol0003o
egQIomMhF@03omMhF@?o00001Oo;E2<00ol0003obe@Sol]D8`02ol]D8`;o0000>_ooool00ol0003o
ooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo027ooooo
1?l00005oa802@?o00006Omm<6400ol0003oXDmXoj5?J00Eoj5?J0co00006_nmIFH00ol0003oegQI
omMhF@06omMhF@;o00000oo;E2<00ol0003obe@Sol]D8`03ol]D8`;o0000>Oooool00ol0003ooooo
ooooo`0Mooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01oooooo0ol0
0006oa802@03o`000?m004co000001[oOC1Q00?o0000oj5?J?nQCfP01OnQCfP@o`0000SoZ6F200Co
0000ol5iPOo1NH7o`GV11Ol0000EokeUIP03o`000?oGN5WoegQI00SoegQI1?l00006ol]D8`;o0000
>Oooool00ol0003oooooooooo`0Looooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01gooooo0ol00005oa802@;o00000_m004`00ol0003oOC1Qogd`H@0Fogd`H@[o00006?nX
IH800ol0003o`GV1ol5iP@06ol5iP@Go00004?nmIFH00ol0003oegQIomMhF@0;omMhF@;o00001Oo;
E2<00ol0003obDd0o`00000iooooo`03o`000?oooooooooo01_ooooo000Vooooo`?o0000;oooool0
0ol0003oooooooooo`0Kooooo`;o00001_lB00T00ol0003o@01<od00C002od00C003o`000?mm<67o
OC1Q01?oOC1Q0ol00002oh]<O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH402oo1NH45
o`0000_o_FEV00?o0000omMhFOoGN5T03?oGN5T4o`0000?obe@S00?o0000olU=0?l00000>?ooool0
0ol0003oooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
01Wooooo00?o0000oa802OlB00T01OlB00T00ol0003o@01<od00C002od00C003o`000?mm<67oOC1Q
017oOC1Q0ol00005oh]<O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH404?o1NH45o`00
00Oo_FEV00?o0000omMhFOoGN5T02ooGN5T01?l0003oegQIomMhFOoGN5T2o`000005ol]D8ol0003o
bDd0olU=0?l00000>?ooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Oooooo00?o0000oa802OlB00T01?lB00T2o`0000Go@01<
00?o0000ogd`HOmm<6403_mm<643o`0000SoRdao00?o0000ojQUP_nXIH807OnXIH800ol0003o`GV1
ol5iP@0Eol5iP@Go00000_nmIFH00ol0003oegQIomMhF@0;omMhF@03o`000?oGN5WoegQI00?oegQI
0ol00002olU=0003o`000?oooooooooo03Gooooo00?o0000ooooooooool06_ooool000_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool05_ooool00ol0003o4P09oa802@03oa802@03o`00
0?m004co@01<00Go@01<00?o0000ogd`HOmm<6402_mm<644o`0000_oRdao00?o0000ojQUP_nXIH80
7OnXIH800ol0003o`GV1ol5iP@0Jol5iP@Co00003?oGN5T00ol0003oegQIomMhF@06omMhF@04o`00
0?o9C@3obDd0o`0003Oooooo00?o0000ooooooooool06Oooool000?ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool05?ooool00ol0003o4P09oa802@02oa802@;o00002?m004`00ol0003o
OC1Qogd`H@07ogd`H@?o00003on;C7l00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101co
`GV100Co0000omV=Nol0003o00002_oGN5T00ol0003oegQIomMhF@06omMhF@;o00000_o9C@000ol0
003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool04_ooool2o`0000?o4P0900?o0000od00C?m004`02?m004`00ol0003oOC1Qogd`H@04ogd`
H@?o00004_n;C7l00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101co`GV100Co0000omV=
NooISG_ofHek0ol00007omMhF@03o`000?oGN5WoegQI00KoegQI00?o0000onZ5=?l000000_o9C@00
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?lB00Wo4P0900;o00002_m004`00ol0003oOC1Qogd`
H@02ogd`H@?o00005?n;C7l00ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV101co`GV100?o
0000omV=NooISG/01?oISG/2o`0000GoegQI00?o0000omMhFOoGN5T01_oGN5T01?l0003ojXDdonZ5
=?l00002olU=0003o`000?oooooooooo03Cooooo00?o0000ooooooooool05oooool000_ooooo00Go
410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000hooooo`03o`00
0?oooooooooo00oooooo00Co0000oa802OlB00Wo00003?m004`00ol0003oOC1Qo`000002o`0001Oo
Rdao00?o0000ojQUP_nXIH807_nXIH800ol0003o`GV1ol5iP@0Lol5iP@03o`000?oISG_ofHek00Ko
fHek0_l00003omMhF@03o`000?oGN5WoegQI00OoegQI00Co0000onZ5=?oZQCCo00000_o9C@000ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool03Oooool2o`000003oa802Ol0003o@01<00_o@01<0ol0000Joh]<O`03o`000?nXIH;oZ6F2
01koZ6F200?o0000ol5iPOo1NH407?o1NH400ol0003ofHekomV=N`08omV=N`Co00002OoGN5T01Ol0
003ojXDdonZ5=?oZQCCo000000;obDd000?o0000ooooooooool0<oooool00ol0003oooooooooo`0F
ooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool03?ooool3o`0000co@01<00?o0000oe`WMOl000006on;C7l0
0ol0003oZ6F2ojQUPP0NojQUPP03o`000?o1NH7o`GV101co`GV100?o0000omV=NooISG/02ooISG/2
o`0000SoegQI00?o0000onZ5=?oZQC@00_oZQC@01?l0003obDd0olU=0?l0000cooooo`?o00005ooo
ool002Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0;ooooo`;o00003?m004`2
o`0000;oG2Me00?o0000oh]<Oon;C7l06On;C7l00ol0003oZ6F2ojQUPP0FojQUPPco00006oo1NH40
0ol0003ofHekomV=N`0;omV=N`04o`000?oISG_o0000o`0000KoegQI00?o0000onZ5=?oZQC@00ooZ
QC@01?l0003obDd0olU=0?l0000_ooooo`?o00000_ooool00ol0003oooooooooo`0Eooooo`009?oo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00Wooooo0_l0000;od00C0;o00001?mL
9gD00ol0003oRdaooh]<O`0Ioh]<O`03o`000?nXIH;oZ6F200GoZ6F24Ol00008ojedU004o`000?o2
QiCo`XNDol:7U0Ko00005Oo1NH400ol0003ofHekomV=N`0;omV=N`04o`000?oISG_ofHekomV=N`;o
00001?oGN5T00ol0003ojXDdonZ5=004onZ5=003o`000?o9C@3o000002cooooo0ol00005ooooo`03
o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
1oooool3o`0000[o@01<00?o0000oe`WMOmL9gD01?mL9gD00ol0003oRdaooh]<O`0Goh]<O`[o0000
6On]M9@00ol0003o`XNDol:7U007ol:7U0Oo00003_o1NH400ol0003ofHekomV=N`0;omV=N`03o`00
0?oISG_ofHek00?ofHek0ol00002omMhF@03o`000?oZQCCojXDd00CojXDd00?o0000olU=0?l00000
:?ooool3o`0000Sooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`06ooooo`?o00002?m004`2o`0000OoG2Me00?o0000oh]<Oon;C7l05?n;
C7l3o`0000;oTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7U00>ol:7U0Ko00002?o1
NH400ol0003ofHekomV=N`0;omV=N`03o`000?oISG_ofHek00KofHek0ol00007onZ5=003o`000?o9
C@3o000002Cooooo0ol0000;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool0
0ol0003oooooooooo`04ooooo`?o00001om004`2o`0000WoG2Me00?o0000oh]<Oon;C7l04?n;C7l4
o`0000GoTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7U00Dol:7U0Ko00000_o1NH40
0ol0003ofHekomV=N`0;omV=N`03o`000?oISG_ofHek00SofHek0_l00007onZ5=0;o00008Oooool3
o`0000oooooo00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`02ooooo`;o000000?o000<o`000?m004`01Om004`00ol0003oG2Meoe`WM@08oe`W
M@03o`000?n;C7ooRdao00goRdao1?l00009oi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7
U?o2Qi@06_o2Qi@4o`0000cofHek00?o0000omV=NooISG/02?oISG/00ol0003olZ9Yo`000007onZ5
=0;o00007Oooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0@Oooool01?l0003oooooooooooooool2o`000003o`003?l0003o@01<00?o@01<0_l0000;oe`W
M@03o`000?n;C7ooRdao00[oRdao0ol0000=oi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7
U?o2Qi@07?o2Qi@00ol0003of9ZBo`000002o`0000WofHek00?o0000omV=NooISG/02?oISG/01?l0
003olZ9Yoo:RJOl00007onZ5=0;o00006Oooool3o`0001Gooooo00?o0000ooooooooool05?ooool0
02?ooooo00?o0000ooooooooool0@_ooool01_l0003oooooo`000?l0003o000<o`0000Co@01<00?o
0000oe`WMOmL9gD02omL9gD00ol0003oRdaooh]<O`06oh]<O`Co00004?nCHI<00ol0003o[GBDojed
U00NojedU003o`000?o2QiCo`XND01co`XND00?o0000omRJT_oHVY800_oHVY82o`0000OofHek00?o
0000omV=NooISG/02?oISG/01Ol0003olZ9Yoo:RJOobXVWo000000OojXDd00?o0000ooooooooool0
5?ooool3o`0001Sooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@ooo
ool2o`0000;o000<00?o0000od00C?m004`00_l0000>oe`WM@03o`000?n;C7ooRdao00;oRdao1?l0
000Doi=QT`03o`000?n]M9Co[GBD01ko[GBD00?o0000ol:7U?o2Qi@07?o2Qi@00ol0003of9ZBomRJ
TP04omRJTP;o00001_oISG/00ol0003ofHekomV=N`07omV=N`03o`000?obXVWolZ9Y00;olZ9Y00?o
0000onZ5=?oZQC@01OoZQC@00ol0003oooooooooo`0@ooooo`?o00006oooool00ol0003ooooooooo
o`0Dooooo`008oooool00ol0003oooooooooo`13ooooo`04o`000?l000co000<o`0030?o00004?mL
9gD00ol0003oRdaoo`000002o`0001SoTf6C00?o0000ojedU?n]M9@07_n]M9@00ol0003o`XNDol:7
U00Lol:7U003o`000?oHVY;of9ZB00Kof9ZB0ol00003omV=N`03o`000?oISG_ofHek00OofHek00?o
0000oo:RJOobXVT00oobXVT00ol0003ojXDdonZ5=005onZ5=003o`000?oooooooooo00cooooo0ol0
000Nooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04;ooooo0_l00002
o`0030;o00004OmL9gD3o`0001coTf6C00?o0000ojedU?n]M9@07On]M9@00ol0003o`XNDol:7U00L
ol:7U003o`000?oHVY;of9ZB00Wof9ZB0_l000000ooISG_o0000omV=N`08omV=N`03o`000?obXVWo
lZ9Y00ColZ9Y00?o0000onZ5=?oZQC@01?oZQC@00ol0003oooooooooo`09ooooo`?o00008Oooool0
0ol0003oooooooooo`0Dooooo`008oooool2o`0004;ooooo0_l00003o`003003o`000?mL9gGoG2Me
00ooG2Me00?o0000ofi5T?l000007OnCHI<00ol0003o[GBDojedU00MojedU003o`000?o2QiCo`XND
01co`XND00?o0000omRJT_oHVY802ooHVY82o`0000[ofHek00?o0000oo:RJOobXVT01?obXVT2o`00
00CojXDd0_l00007ooooo`?o00009Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003o
ooooooooo`11ooooo`03o`000?l000co000<00;o000<00?o0000oe`WMOmL9gD03OmL9gD2o`0000;o
KTF@00?o0000oi=QTonCHI<06onCHI<00ol0003o[GBDojedU00MojedU003o`000?o2QiCo`XND01co
`XND00?o0000omRJT_oHVY803?oHVY84o`0000OofHek00?o0000oo:RJOobXVT01_obXVT00ol0003o
jXDdonZ5=002onZ5=003o`000?oooooooooo00;ooooo0ol0000Xooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo047ooooo00?o0000o`003?l000`00_l000`2o`0000koG2Me
00?o0000ofi5T?m^AI000_m^AI000ol0003oTf6Coi=QT`0Koi=QT`03o`000?n]M9Co[GBD01go[GBD
00?o0000ol:7U?o2Qi@07?o2Qi@00ol0003of9ZBomRJTP0<omRJTP04o`000?oHVY;of9ZBomRJTP;o
00001OoISG/00ol0003olZ9Yoo:RJ@07oo:RJ@06o`000?oZQCCojXDdonZ5=?l0003ooooo0ol0000[
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo043ooooo0_l00003o`00
3003o`000?l005Co000000coG2Me0_l00005ofi5T003o`000?nCHI?oTf6C01_oTf6C00?o0000ojed
U?n]M9@05On]M9@<o`0001_o`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZBomRJTP03omRJ
TP;o00000ooISG/00ol0003olZ9Yoo:RJ@08oo:RJ@03o`000?oZQCCojXDd00;o0000;_ooool00ol0
003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`10ooooo`05o`000?l000co000<o`00
3?l000000_l005@00ol0003oG2Meoe`WM@09oe`WM@03o`000?m^AI3oKTF@00GoKTF@00?o0000oi=Q
TonCHI<06onCHI<00ol0003o[GBDojedU005ojedU13o00002?n_PJ<01?l0003o`Y6Sol:AXoo2TJ<6
o`0001Go`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZBomRJTP05omRJTPCo00002oobXVT0
1?l0003ojXDdonZ5=?l0000^ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooo
oooo03oooooo00?o0000o`003?l000`00_l000`01?l0003o001Do`00E?l00009oe`WM@;o00002?m^
AI000ol0003oTf6Coi=QT`0Ioi=QT`[o00006?n_PJ<00ol0003o`Y6Sol:AX`07ol:AX`Oo00003_o2
Qi@00ol0003of9ZBomRJTP0<omRJTP03o`000?oHVY;of9ZB00Sof9ZB0_l0000;oo:RJ@04o`000?oZ
QCCo0000o`0002gooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0?_oo
ool00ol0003o000<o`003002o`003005o`000?l005Co001Do`00E?l000002?mL9gD00ol0003oKTF@
ofi5T008ofi5T003o`000?nCHI?oTf6C01KoTf6C0ol00002oiU`X`03o`000?n_PJ?o[h6S01go[h6S
00?o0000ol:AXoo2TJ<03_o2TJ<6o`0000So`XND00?o0000omRJT_oHVY803?oHVY800ol0003of9ZB
omRJTP08omRJTP03o`000?o`/Xco000000_olZ9Y0ol0000]ooooo`03o`000?oooooooooo01?ooooo
000Qooooo`?o0000?oooool01Ol0003o000<o`003?l000co000000?o001D00?o0000oe`WMOmL9gD0
1OmL9gD2o`0000coKTF@00?o0000oi=QTonCHI<04OnCHI<4o`0000GoVG2S00?o0000ojn1Xon_PJ<0
7On_PJ<00ol0003o`Y6Sol:AX`0Dol:AX`Ko00000_o2Qi@00ol0003of9ZBomRJTP0<omRJTP03o`00
0?oHVY;of9ZB00Sof9ZB00Co0000oo2bS?o`/Xco00002oobXVT3o`0002gooooo00?o0000oooooooo
ool04_ooool0027ooooo00?o0000ooooooooool0?_ooool01Ol0003o000<o`003?l000co000000Co
001D00?o0000oe`WMOmL9gD01?mL9gD00ol0003oKTF@ofi5T00<ofi5T003o`000?nCHI?oTf6C00go
Tf6C1?l00009oiU`X`03o`000?n_PJ?o[h6S01go[h6S00?o0000ol:AXoo2TJ<06_o2TJ<4o`0000go
f9ZB00?o0000omRJT_oHVY802?oHVY801Ol0003ol;:<oo2bS?o`/Xco000000_olZ9Y0_l0000]oooo
o`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03kooooo00Co0000o`003?l0
00co00001Ol005@00ol0003oG2Meoe`WM@02oe`WM@;o00003om^AI000ol0003oTf6Coi=QT`0:oi=Q
T`?o00003OnIL:<00ol0003o[h6Sojn1X`0Mojn1X`03o`000?o2TJ?o`Y6S01co`Y6S00Co0000omFT
Xol0003o00002ooHVY800ol0003of9ZBomRJTP08omRJTP03o`000?o`/Xcol;:<00;ol;:<00?o0000
oo:RJOobXVT02?obXVT2o`0002gooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooo
ooooool0?_ooool01?l0003o000<o`003?l00005o`00E005o`000?mL9gGoG2Meoe`WMOl000004Om^
AI000ol0003oTf6Coi=QT`06oi=QT`Co00004?nIL:<00ol0003o[h6Sojn1X`0Mojn1X`03o`000?o2
TJ?o`Y6S01co`Y6S00Co0000omFTXooEY:?oeJBS0ol00008omRJTP03o`000?oHVY;of9ZB00Sof9ZB
00?o0000oo2bS?o`/X`00oo`/X`00ol0003olZ9Yoo:RJ@07oo:RJ@?o0000;?ooool00ol0003ooooo
ooooo`0Booooo`008Oooool00ol0003oooooooooo`0mooooo`04o`000?l000co000<o`0000Ko001D
00Co0000oe`WMOl0003o00004_m^AI000ol0003oTf6Coi=QT`02oi=QT`Co00005?nIL:<00ol0003o
[h6Sojn1X`0Mojn1X`03o`000?o2TJ?o`Y6S01co`Y6S00?o0000omFTXooEY:<01?oEY:<2o`0000Ko
f9ZB00?o0000omRJT_oHVY802?oHVY800ol0003ol;:<oo2bS004oo2bS003o`000?obXVWolZ9Y00Ko
lZ9Y0ol0000/ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03gooooo
00?o0000o`003?l000001ol005@2o`0001CoKTF@00?o0000oi=QTol000000_l0000HoiU`X`03o`00
0?n_PJ?o[h6S01co[h6S00?o0000ol:AXoo2TJ<07Oo2TJ<00ol0003oeJBSomFTX`06omFTX`;o0000
1?oHVY800ol0003of9ZBomRJTP08omRJTP03o`000?o`/Xcol;:<00Gol;:<00?o0000oo:RJOobXVT0
1_obXVT3o`0002_ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0?Ooo
ool2o`0000So001D00?o0000ofi5T?m^AI004_m^AI03o`0001_oVG2S00?o0000ojn1Xon_PJ<07?n_
PJ<00ol0003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00WoeJBS0ol000000ooHVY;o0000omRJ
TP08omRJTP03o`000?o`/Xcol;:<00Ool;:<0_l00006oo:RJ@?o0000:oooool00ol0003ooooooooo
o`0Booooo`008?ooool3o`0003gooooo00?o0000o`003?l000002?l005@00ol0003oKTF@ofi5T00A
ofi5T003o`000?mjG:?o000001goVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0003o`Y6Sol:AX`0L
ol:AX`03o`000?oEY:?oeJBS00coeJBS0_l00009omRJTP03o`000?o`/Xcol;:<00Wol;:<00?o0000
oo:RJOobXVT00oobXVT3o`0002cooooo00?o0000ooooooooool04Oooool0023ooooo00?o0000oooo
ooooool0?Oooool2o`0000So001D0_l0000Aofi5T0;o00000_mjG:<00ol0003oVG2SoiU`X`0KoiU`
X`03o`000?n_PJ?o[h6S01_o[h6S00?o0000ol:AXoo2TJ<07?o2TJ<00ol0003oeJBSomFTX`0>omFT
X`;o00001ooHVY800ol0003ol;:<oo2bS00:oo2bS003o`000?obXVWolZ9Y00;olZ9Y00Co0000onjX
;_l0003o0000:oooool00ol0003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool0?Oooool00ol0003o001Do`00E006o`00E003o`000?lZ5X?o
000000ooKTF@0_l00005ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<0
0ol0003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00Co0000omFTXol0003o00001OoH
VY800ol0003ol;:<oo2bS00;oo2bS006o`000?obXVWolZ9Yoo:RJOl0003okZP^0_l0000[ooooo`03
o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`0looooo`03o`000?l005Co001D00Ko001D00Co0000obXFPolZ5X?o00003_m^AI000ol0
003oNUbSogYLX`05ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0
003o`Y6Sol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00Co0000omFTXooEY:?oeJBS0ol00002
omRJTP03o`000?o`/Xcol;:<00col;:<00Co0000oo:RJOobXVWo00000_o^Z2h2o`0002[ooooo00?o
0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo03cooooo00?o0000o`00E?l005@01Ol005@01Ol0003o:QJ3obXFPolZ5X?o000000coKTF@
0_l00008ogYLX`03o`000?nIL:?oVG2S01[oVG2S00?o0000ojn1Xon_PJ<06on_PJ<00ol0003o`Y6S
ol:AX`0Lol:AX`03o`000?oEY:?oeJBS00koeJBS00?o0000omFTXooEY:<01?oEY:<3o`0000ool;:<
00?o0000oo:RJOl000000_o^Z2h2o`0002[ooooo00?o0000ooooooooool04Oooool001Gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03cooooo00?o0000o`00E?l005@0
1Ol005@01Ol0003o:QJ3obXFPolZ5X?o000000[oKTF@0_l0000:ogYLX`03o`000?nIL:?oVG2S01[o
VG2S00?o0000ojn1Xon_PJ<05?n_PJ<;o`0001_o`Y6S00?o0000omFTXooEY:<03_oEY:<00ol0003o
eJBSomFTX`06omFTX`;o00003oo`/X`00ol0003olZ9Yo`000002onjX;P03o`000?oooooooooo02So
oooo00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo03gooooo00?o0000o`00E?l005@01?l005@00ol0003o:QJ3obXFP`03obXFP`03
o`000?m^AI3oKTF@00KoKTF@00?o0000ogYLXomjG:<02_mjG:<00ol0003oVG2SoiU`X`0JoiU`X`03
o`000?n_PJ?o[h6S00Go[h6S3ol00007ok2;[`04o`000?o1VZoo`IZ_ol6J[`Ko00005Oo2TJ<00ol0
003oeJBSomFTX`0>omFTX`03o`000?oEY:?oeJBS00KoeJBS00?o0000on^kXol000003oo`/X`2o`00
00;okZP^0_l0000Yooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oooooooooooooo
ool@41001Oooool2o`0003kooooo00?o0000o`00E?l005@00ol005@00ol0003o:QJ3obXFP`04obXF
P`03o`000?m^AI3oKTF@00CoKTF@0_l0000>ogYLX`03o`000?nIL:?oVG2S01OoVG2S2_l0000Fok2;
[`03o`000?o1VZoo`IZ_00Oo`IZ_1_l0000>ol:AX`03o`000?oEY:?oeJBS00ooeJBS00?o0000omFT
XooEY:<01_oEY:<01?l0003ojk^Son^kXol0000?oo2bS005o`000?o^Z2kokZP^onjX;_l00000:Ooo
ool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool0??ooool2o`0000Co001D00?o0000obXFPolZ5X<01OlZ5X<00ol0003oKTF@ofi5
T003ofi5T003o`000?mjG:?oNUbS00koNUbS00?o0000oiU`XonIL:<04onIL:<4o`0000;oWGf`00?o
0000ok2;[on`Rjl06on`Rjl00ol0003o`IZ_ol6J[`0=ol6J[`Ko00002?o2TJ<00ol0003oeJBSomFT
X`0?omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[^j<00_o[^j<00ol0003ol;:<oo2b
S00<oo2bS005o`000?o^Z2kokZP^onjX;_l00000:_ooool00ol0003oooooooooo`0@ooooo`005Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0??ooool2o`0000?o001D
00?o0000obXFPolZ5X<01_lZ5X<01?l0003oKTF@ofi5T?m^AI02o`00017oNUbS00?o0000oiU`XonI
L:<03onIL:<4o`0000KoWGf`00?o0000ok2;[on`Rjl06on`Rjl00ol0003o`IZ_ol6J[`0Col6J[`Ko
00000_o2TJ<00ol0003oeJBSomFTX`0?omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[
^j<00oo[^j<00ol0003ol;:<oo2bS00;oo2bS0;o00000_o^Z2h2o`0002Wooooo00?o0000oooooooo
ool04?ooool001oooooo00?o0000ooooooooool0??ooool01Ol0003o001Do`00E?l005Co000000Wo
:QJ300Co0000ofi5T?l0003o00004omjG:<00ol0003oVG2SoiU`X`0;oiU`X`Co00002_nMOK000ol0
003o/8^_ok2;[`0Kok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_1?l0000@omFTX`03o`000?oEY:?oeJBS
00GoeJBS00?o0000on^kXoo[^j<01?o[^j<00ol0003ol;:<oo2bS00:oo2bS0;o00000oo^Z2h00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03co
oooo00Go0000o`00E?l005Co001Do`000009obXFP`;o00005OmjG:<00ol0003oVG2SoiU`X`08oiU`
X`?o00003_nMOK000ol0003o/8^_ok2;[`0Kok2;[`03o`000?o1VZoo`IZ_01_o`IZ_00?o0000om:[
/Ol000000_l0000=omFTX`03o`000?oEY:?oeJBS00GoeJBS00?o0000on^kXoo[^j<01Oo[^j<00ol0
003ol;:<oo2bS008oo2bS003o`000?oobg3o000000?okZP^00?o0000ooooooooool09oooool00ol0
003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`0looooo`04o`000?l005Co001Do`00
00[o:QJ300?o0000ogYLXomjG:<05OmjG:<00ol0003oVG2SoiU`X`03oiU`X`Co00004_nMOK000ol0
003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01_o`IZ_00?o0000om:[/OoBZk400_oBZk43o`00
00[oeJBS00?o0000omFTXooEY:<01OoEY:<00ol0003ojk^Son^kX`06on^kX`;o00002?o`/X`01?l0
003ool]`ooo;L?l00003onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
01kooooo00?o0000ooooooooool0?Oooool00ol0003o001Do`00000;obXFP`03o`000?mjG:?oNUbS
01GoNUbS00?o0000oiU`Xol000000ol0000Foiem/003o`000?n`Rjoo/8^_01[o/8^_00?o0000ol6J
[oo1VZl06_o1VZl00ol0003odZ^aom:[/@06om:[/@;o00002?oEY:<00ol0003oeJBSomFTX`04omFT
X`03o`000?o[^j?ojk^S00Wojk^S00?o0000oo2bS?o`/X`01Oo`/X`01?l0003ool]`ooo;L?l00003
onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool001kooooo00?o0000oooo
ooooool0?Oooool2o`0000_o:QJ30_l0000FogYLX`?o00006_nMOK000ol0003o/8^_ok2;[`0Jok2;
[`03o`000?o1VZoo`IZ_01[o`IZ_00?o0000om:[/OoBZk402?oBZk43o`0000GoeJBS00?o0000omFT
XooEY:<01?oEY:<00ol0003ojk^Son^kX`0:on^kX`03o`000?o`/Xcol;:<00Col;:<00Go0000ooo;
L?oobg3ool]`o`000002onjX;P03o`000?oooooooooo02Kooooo00?o0000ooooooooool04?ooool0
01kooooo0_l0000nooooo`03o`000?lZ5X?o:QJ300Wo:QJ300Co0000odLlXOm7?:7o00004omjG:<2
o`000003oh=^/_l0003oWGf`01[oWGf`00?o0000ok2;[on`Rjl06_n`Rjl00ol0003o`IZ_ol6J[`0J
ol6J[`03o`000?oBZk7odZ^a00_odZ^a0ol00002omFTX`03o`000?oEY:?oeJBS00CoeJBS00?o0000
on^kXoo[^j<02oo[^j<00ol0003ol;:<oo2bS003oo2bS005o`000?oobg3ool]`ooo;L?l000000_o^
Z2h00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooo
oooo03gooooo00?o0000obXFPolZ5X<02?lZ5X<01Ol0003oAcbQodLlXOm7?:7o000001;oNUbS00?o
0000oh=^/_n3K[800_n3K[800ol0003oWGf`oiem/00Hoiem/003o`000?n`Rjoo/8^_01[o/8^_00?o
0000ol6J[oo1VZl06_o1VZl00ol0003odZ^aom:[/@0>om:[/@?o00001_oEY:<00ol0003ojk^Son^k
X`0<on^kX`03o`000?o`/Xcol;:<00;ol;:<00?o0000ooo;L?oobg000_oobg000ol0003okZP^o`00
000Yooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03cooooo0_l0000:
obXFP`05o`000?m7?:7oAcbQodLlXOl000004?mjG:<2o`0000GoPfjb00?o0000oiem/?nMOK006?nM
OK000ol0003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_00?o0000om:[/OoBZk404OoB
Zk43o`0000CoeJBS00?o0000on^kXoo[^j<03Oo[^j<01Ol0003ol;:<oo2bS?o`/Xco000000Cool]`
00?o0000onjX;_l00000:Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooooooo
o`0looooo`;o00002OlZ5X<00ol0003oAcbQodLlX@03odLlX@03o`000?mjG:?oNUbS00_oNUbS0_l0
0007oh=^/P03o`000?nMOK3oWGf`01SoWGf`00?o0000ok2;[on`Rjl06_n`Rjl00ol0003o`IZ_ol6J
[`0Iol6J[`03o`000?oBZk7odZ^a017odZ^a00?o0000om:[/OoBZk401?l0000Aon^kX`03o`000?o`
/Xco000000Gool]`00?o0000onjX;_l00000:Oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`0mooooo`03o`000?l004_o000000Oo:QJ300?o0000odLlXOm7?:401?m7?:40
0ol0003oNUbSogYLX`0:ogYLX`03o`000?n3K[;oPfjb00SoPfjb00?o0000oiem/?nMOK005onMOK00
0ol0003o/8^_ok2;[`0Jok2;[`03o`000?o1VZoo`IZ_01Wo`IZ_00?o0000om:[/OoBZk404OoBZk40
0ol0003odZ^aom:[/@03om:[/@;o00004Oo[^j<2o`0000Kool]`00?o0000onjX;_l00000:?ooool0
0ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?l004_o0000
00Ko:QJ300?o0000odLlXOm7?:401Om7?:400ol0003oNUbSogYLX`08ogYLX`;o00002on3K[800ol0
003oWGf`oiem/00Hoiem/003o`000?n`Rjoo/8^_01Wo/8^_00?o0000ol6J[oo1VZl06Oo1VZl00ol0
003odZ^aom:[/@0Bom:[/@03o`000?oBZk7odZ^a00;odZ^a00?o0000onC1]?l000004Oo[^j<00ol0
003ool]`ooo;L004ooo;L003o`000?o^Z2ko000002Sooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003o001;o`000006obXFP`03o`000?m7?:7oAcbQ00Go
AcbQ00?o0000ogYLXomjG:<01_mjG:<2o`0000goPfjb00?o0000oiem/?nMOK006?nMOK000ol0003o
/8^_ok2;[`0Iok2;[`03o`000?o1VZoo`IZ_01So`IZ_00?o0000om:[/OoBZk404ooBZk401Ol0003o
dZ^aom:[/OoBZk7o000000?oi<6d00?o0000on^kXoo[^j<03_o[^j<00ol0003ool]`ooo;L005ooo;
L0;o0000:?ooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0003kooooo00?o0000o`00Bol0
00001OlZ5X<00ol0003oAcbQodLlX@07odLlX@03o`000?mjG:?oNUbS00CoNUbS00?o0000oh=^/_n3
K[803_n3K[800ol0003oWGf`oiem/00Goiem/003o`000?n`Rjoo/8^_00_o/8^_4_l0000Gol6J[`03
o`000?oBZk7odZ^a01?odZ^a00Go0000om:[/OoBZk7odZ^ao`000004onC1]003o`000?o[^j?ojk^S
00gojk^S0_l00006ooo;L0;o0000:Oooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003o
ooooooooo`0mooooo`03o`000?l004_o000000Co:QJ300?o0000odLlXOm7?:402?m7?:400ol0003o
NUbSogYLX`02ogYLX`;o00004On3K[800ol0003oWGf`oiem/00Eoiem/13o00003_naU;T01?l0003o
_j6joknQ^_noXKX7o`00013o`IZ_00?o0000om:[/OoBZk404ooBZk401Ol0003odZ^aom:[/OoBZk7o
000000Goi<6d00?o0000on^kXoo[^j<02oo[^j<00ol0003ooMVKo`000006ooo;L0;o0000:Oooool0
0ol0003oooooooooo`0>ooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?l004_o0000
00?o:QJ300?o0000odLlXOm7?:402Om7?:400ol0003oNUbSogYLX`02o`0001?oPfjb00?o0000oiem
/?nMOK004OnMOK04o`0000;oX8Rk00?o0000ok6D^OnaU;T06OnaU;T00ol0003o_j6joknQ^P08oknQ
^PKo00002_o1VZl00ol0003odZ^aom:[/@0Com:[/@04o`000?oBZk7odZ^ao`0000Ooi<6d00?o0000
on^kXoo[^j<02_o[^j<01?l0003ooMVKoogIVol00006ooo;L003o`000?oooooooooo02Oooooo00?o
0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0?_ooool00ol0003o001;o`000003
obXFP`03o`000?m7?:7oAcbQ00[oAcbQ0_l0000Foh=^/P03o`000?nMOK3oWGf`00coWGf`1?l00006
oj28^`03o`000?naU;Wo/IBi01Wo/IBi00?o0000oknQ^_noXKX03_noXKX7o`0000;o`IZ_00?o0000
om:[/OoBZk405?oBZk401?l0003odZ^aom:[/Ol00008onC1]003o`000?o[^j?ojk^S00Wojk^S00Co
0000oogIVoomfI_o00001_oobg000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o0000obXFPol0000=odLlX@03
o`000?n3K[;oPfjb01GoPfjb00?o0000oiem/?nMOK002?nMOK04o`0000[oX8Rk00?o0000ok6D^Ona
U;T06OnaU;T00ol0003o_j6joknQ^P0EoknQ^PCo00005OoBZk400ol0003odZ^ao`00000:onC1]0;o
00002?o[^j<01Ol0003ooMVKoogIVoomfI_o000000Kool]`00?o0000ooooooooool09oooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0nooooo`03o`000?l004_o001;00;o
00003_m7?:400ol0003oPfjboh=^/P0Eoh=^/P03o`000?nMOK3oWGf`00CoWGf`1?l0000?oj28^`03
o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_noXKX05onoXKX00ol0003oc[6lo`000002o`0001;o
dZ^a00?o0000om:[/Ol000003?oT`K@00ol0003ojk^Son^kX`05on^kX`03o`000?omfI_ooMVK00;o
oMVK00?o0000ooo;L?oobg000ooobg000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo03gooooo0_l00002o`00B`03o`000?m7?:7oAcbQ00coAcbQ
00?o0000oeaI]Ol000005on3K[800ol0003oWGf`o`000003o`0001?oX8Rk00?o0000ok6D^OnaU;T0
6?naU;T00ol0003o_j6joknQ^P0GoknQ^P03o`000?o>/Kcoc[6l00;oc[6l0ol0000=om:[/@?o0000
00?odZ^ao`000?oT`K@03?oT`K@00ol0003ojk^Son^kX`04on^kX`03o`000?omfI_ooMVK00;ooMVK
00?o0000ooo;L?oobg000_oobg000ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03gooooo00Go0000o`00Bol004_o001;o`00000=odLlX@04o`00
0?mLFKGoG5Veo`0001KoPfjb0ol0000Goj28^`03o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_no
XKX05_noXKX00ol0003oc[6lolja_006olja_0?o00001ooBZk43o`0000;odZ^a0_l0000?onC1]003
o`000?o[^j?ojk^S00;ojk^S00?o0000oogIVoomfI/01?omfI/01Ol0003ool]`ooo;L?oobg3o0000
02_ooooo00?o0000ooooooooool03Oooool001cooooo0_l0000nooooo`05o`000?l004_o001;o`00
Bol000003?m7?:400ol0003oG5VeoeaI]@02oeaI]@03o`000?n3K[;oPfjb017oPfjb0_l000000on;
OKko0000oj28^`0Goj28^`03o`000?naU;Wo/IBi01So/IBi00?o0000oknQ^_noXKX05_noXKX00ol0
003oc[6lolja_009olja_0;o00000_oBZk43o`0000KodZ^a00?o0000onC1]?oT`K@03_oT`K@01Ol0
003ojk^Son^kXoo[^j?o000000KooMVK00Go0000ooo;L?oobg3ool]`o`00000[ooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o001;o`00
R_l0000:odLlX@03o`000?mLFKGoG5Ve00?oG5Ve00?o0000oh=^/_n3K[804?n3K[800ol0003oRgfn
oh]m_P02oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000ok6D^OnaU;T05onaU;T00ol0003o_j6j
oknQ^P0GoknQ^P03o`000?o>/Kcoc[6l00[oc[6l1?l00007om:[/@03o`000?oT`KCo0000013oi<6d
00Co0000on^kXoo[^j?o00001oomfI/01?l0003ool]`ooo;L?l0000[ooooo`03o`000?oooooooooo
00gooooo000Kooooo`03o`000?oooooooooo03kooooo00Ko0000o`00Bol004_o001;o`00R_l0000:
odLlX@03o`000?mLFKGoG5Ve00?oG5Ve00?o0000oh=^/_n3K[803_n3K[82o`0000GoRgfn00?o0000
oj28^onPR;/05_nPR;/00ol0003o/IBiok6D^@0Fok6D^@03o`000?noXK[o_j6j01Oo_j6j00?o0000
olja_?o>/K`01_o>/K`4o`0000Coc[6l0ol00004om:[/@04o`000?oT`KCoi<6do`00013oi<6d0_l0
0008oogIV`04o`000?oobg3ool]`o`0002_ooooo00?o0000ooooooooool03Oooool001_ooooo00?o
0000ooooooooool0?_ooool01_l0003o001;o`00Bol0003o002:o`0000WoAcbQ00?o0000oeaI]OmL
FKD01OmLFKD00ol0003oPfjboh=^/P0;oh=^/P;o00001on;OKh00ol0003oX8Rkoj28^`0Foj28^`03
o`000?naU;Wo/IBi01Ko/IBi00?o0000oknQ^_noXKX05_noXKX00ol0003oc[6lolja_004olja_0?o
00002oo>/K`3o`000003om:[/Ol0003oi<6d00;oi<6d00?o0000onC1]?oT`K@03_oT`K@00ol0003o
oMVKoogIV`06oogIV`04o`000?oobg3ool]`o`0002_ooooo00?o0000ooooooooool03Oooool001_o
oooo00?o0000ooooooooool0?_ooool01?l0003o001;o`00Bol00002o`00RP03o`000?m7?:7oAcbQ
00GoAcbQ00?o0000oeaI]OmLFKD01_mLFKD00ol0003oPfjboh=^/P09oh=^/P;o00002_n;OKh00ol0
003oX8Rkoj28^`0Eoj28^`03o`000?naU;Wo/IBi01Ko/IBi00?o0000oknQ^_noXKX05_noXKX01?l0
003oc[6lolja_?o>/K`3o`00017oc[6l0_l00003onC1]003o`000?oT`KCoi<6d00koi<6d00?o0000
oogIVoomfI/01oomfI/2o`0002cooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0?_ooool01?l0003o001;o`00Bol00002o`00RP03o`000?m7?:7oAcbQ00CoAcbQ00?o0000
oeaI]OmLFKD02?mLFKD00ol0003oPfjboh=^/P07oh=^/P03o`000?n;OKkoRgfn00[oRgfn00?o0000
oj28^onPR;/05OnPR;/00ol0003o/IBiok6D^@0Fok6D^@03o`000?noXK[o_j6j01Ko_j6j1?l0000D
olja_003o`000?oMaL7o000000?oi<6d00?o0000onC1]?oT`K@03?oT`K@00ol0003om=jeo`000008
oogIV`;o0000;?ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0noooo
o`04o`000?l004_o001;o`0000;o002:00?o0000odLlXOm7?:400om7?:400ol0003oG5VeoeaI]@09
oeaI]@03o`000?n3K[;oPfjb00GoPfjb0_l0000=oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000
ok6D^OnaU;T05_naU;T00ol0003o_j6joknQ^P0CoknQ^PCo00005_o>/K`01Ol0003ogLG1omg5`OoM
aL7o000000?oi<6d00?o0000onC1]?oT`K@02ooT`K@00ol0003om=jeo`000009oogIV`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool03Oooool001_ooooo0_l00010ooooo`03o`000?l004_o
000000?o002:00?o0000odLlXOm7?:400_m7?:400ol0003oG5VeoeaI]@0:oeaI]@03o`000?n3K[;o
Pfjb00;oPfjb0_l0000@oh]m_P03o`000?nPR;_oX8Rk01GoX8Rk00?o0000ok6D^OnaU;T05OnaU;T0
0ol0003o_j6joknQ^P0@oknQ^P?o00000_noXKX00ol0003oc[6lolja_00Eolja_003o`000?oMaL7o
gLG100;ogLG100Go0000onC1]?oT`KCoi<6do`00000;onC1]004o`000?odg[Gom=jeo`0000WooMVK
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003ooooooooo
o`10ooooo`03o`000?l004_o000000?o002:00Go0000odLlXOm7?:7oAcbQo`00000=oeaI]@05o`00
0?n3K[;oPfjboh=^/_l000004_n;OKh00ol0003oX8Rkoj28^`0Eoj28^`03o`000?naU;Wo/IBi00Wo
/IBi4Ol0000;oknQ^P?o00001OnoXKX00ol0003oc[6lolja_00Dolja_003o`000?oMaL7ogLG100Co
gLG10_l00002onC1]003o`000?oT`KCoi<6d00Soi<6d00Go0000ooCN]Oodg[Gom=jeo`000007oogI
V`;o0000;Oooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo043ooooo00?o0000
o`00Bol000000ol008X01?l0003oAcbQodLlXOl0000>oeaI]@04o`000?n3K[;o0000o`0001CoRgfn
00?o0000oj28^onPR;/04_nPR;/>o`0000co/9g300?o0000okfXa?nmZ<@00_nmZ<@;o`0000So_j6j
00?o0000olja_?o>/K`05?o>/K`00ol0003ogLG1omg5`@06omg5`@04o`000?oT`KCoi<6do`0000So
i<6d00?o0000ooCN]Oodg[D00_odg[D00ol0003ooMVKoogIV`05oogIV`;o0000;Oooool00ol0003o
ooooooooo`0<ooooo`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`10ooooo`03o`000?l004_o000000Co002:0_l0000@oeaI]@03
o`000?n;OKkoRgfn01CoRgfn00?o0000oj28^onPR;/03onPR;/3o`0000;oXY?500?o0000ok2M`on`
WL<05On`WL<00ol0003o_JS4okfXa006okfXa0_o00000onoXKX00ol0003oc[6lolja_00Dolja_003
o`000?oMaL7ogLG100SogLG100?o0000onC1]?l000001ooT`K@00ol0003om=jeooCN]@04ooCN]@03
o`000?omfI_ooMVK00CooMVK00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0<ooooo`00
0oooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
@?ooool00ol0003o001;o`000004o`00RP03o`000?mLFKGoG5Ve00ooG5Ve00?o0000oh]m__n;OKh0
5?n;OKh00ol0003oX8Rkoj28^`0;oj28^`Co00001OnRTlD00ol0003o/9g3ok2M``0Eok2M``03o`00
0?nmZ<Co_JS400?o_JS40ol0000;okfXa0Go00005Oo>/K`00ol0003ogLG1omg5`@09omg5`@03o`00
0?oT`KCo000000Koi<6d00?o0000ooCN]Oodg[D01?odg[D00ol0003ooMVKoogIV`03oogIV`;o0000
;_ooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0@?ooool2o`0000Go002:00?o0000oeaI]OmLFKD03_mL
FKD00ol0003oK6o4o`00000Foh]m_P03o`000?nPR;_oX8Rk00OoX8Rk0ol0000:oj:Ca@03o`000?n`
WL?o/9g301Co/9g300?o0000okfXa?nmZ<@00ol0000AokfXa003o`000?o:]/Oo000000;o00004Oo>
/K`00ol0003ogLG1omg5`@0;omg5`@?o00001?oT`K@00ol0003om=jeooCN]@05ooCN]@03o`000?om
fI_ooMVK00?ooMVK0_l0000^ooooo`03o`000?oooooooooo00cooooo0003ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo047ooooo00?o
0000o`00R_l008X00ol008X00olD=;;o0000oeaI]@0=oeaI]@04o`000?m/KlCoK6o4o`0001KoRgfn
00?o0000oj28^onPR;/00onPR;/4o`0000goXY?500?o0000ok2M`on`WL<05?n`WL<3o`0001?o_JS4
00?o0000olZfaoo:]/L00oo:]/L2o`0000ooc[6l00?o0000omg5`OoMaL403OoMaL42o`0000?oi<6d
00?o0000ooCN]Oodg[D01_odg[D01ol0003ooMVKoogIVoomfI_o0000omWKI_l00000;_ooool00ol0
003oooooooooo`0<ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@_ooool00ol0003o002:o`00RP03o`00RP03oa@d/_l0003oG5Ve00co
G5Ve00?o0000ofa_a?m/Kl@00_m/Kl@00ol0003oRgfnoh]m_P0Coh]m_P03o`000?nPR;_oX8Rk00?o
00004OnRTlD00ol0003o/9g3ok2M``0@ok2M``Go00005OnmZ<@00ol0003ob[K7olZfa`05olZfa`;o
00003Oo>/K`00ol0003ogLG1omg5`@0>omg5`@;o000000?oi<6do`000?odg[D02?odg[D01ol0003o
oMVKoogIVoomfI_o0000omWKI_l00000;oooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooo
oonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`;o0000@oooool00ol0003o002:o`00RP03
o`00RP03o`000?lD=;;o000000_oG5Ve00?o0000ofa_a?m/Kl@01?m/Kl@00ol0003oRgfnoh]m_P0B
oh]m_P?o00005?nRTlD00ol0003o/9g3ok2M``0=ok2M``?o00001?n`WL<00ol0003o_JS4okfXa00C
okfXa003o`000?o:]/Oob[K700Oob[K70ol00009olja_003o`000?oMaL7ogLG1013ogLG100?o0000
onC1]?l000002_odg[D01Ol0003ooMVKo`000?oIffKo0000033ooooo00?o0000ooooooooool02ooo
ool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo04;ooooo00?o
0000o`00R_l008X00_l008X01Ol0003o53Bboa@d/_lD=;;o000000WoG5Ve00?o0000ofa_a?m/Kl@0
1Om/Kl@00ol0003oRgfnoh]m_P0@oh]m_P;o000000?oT8[9o`000?nRTlD05?nRTlD00ol0003o/9g3
ok2M``0:ok2M``?o00001on`WL<00ol0003o_JS4okfXa00BokfXa003o`000?o:]/Oob[K700_ob[K7
0_l00007olja_003o`000?oMaL7ogLG1017ogLG100?o0000ooCN]Oodg[D02Oodg[D01Ol0003ooMVK
o`000?oIffKo0000033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0
@oooool01Ol0003o002:o`00R_l008[o000000?o53Bb00?o0000oeaI]OmLFKD01_mLFKD00ol0003o
K6o4ofa_a007ofa_a003o`000?n;OKkoRgfn00goRgfn0_l00004oi2:b@03o`000?nRTlGoXY?501?o
XY?500?o0000ok2M`on`WL<01_n`WL<3o`0000Wo/9g300?o0000okfXa?nmZ<@04onmZ<@00ol0003o
b[K7olZfa`0=olZfa`;o00001?o>/K`00ol0003ogLG1omg5`@0Bomg5`@;o00002_odg[D01Ol0003o
oMVKo`000?oIffKo0000033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0@oooool01Ol0003o002:o`00R_l008[o000000Co53Bb00?o0000oeaI]OmLFKD01OmLFKD00ol0
003oK6o4ofa_a007ofa_a003o`000?n;OKkoRgfn00_oRgfn0_l00006oi2:b@03o`000?nRTlGoXY?5
01?oXY?500?o0000ok2M`on`WL<00_n`WL<4o`0000co/9g300?o0000okfXa?nmZ<@04onmZ<@00ol0
003ob[K7olZfa`0?olZfa`?o000000?oc[6lo`000?oMaL404_oMaL401?l0003oj]o7o`000?l0000:
ooCN]@04o`000?oIffKofM]Vo`00033ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000
ooooooooool0@oooool01Ol0003o002:o`00R_l008[o000000Co53Bb00?o0000oeaI]OmLFKD01?mL
FKD00ol0003oK6o4ofa_a009ofa_a003o`000?n;OKkoRgfn00SoRgfn0_l00009oi2:b@03o`000?nR
TlGoXY?501;oXY?500?o0000ok2M`ol000000_l0000@ok2M``03o`000?nmZ<Co_JS401;o_JS400?o
0000olZfaoo:]/L04oo:]/L2o`0001;ogLG100Ko0000on[OaooZglOo0000ooCN]Ol00009ooCN]@04
o`000?oIffKofM]Vo`00033ooooo00?o0000ooooooooool02oooool001Sooooo00?o0000oooooooo
ool0AOooool01?l0003o002:o`00R_l00005oa@d/P03o`000?mLFKGoG5Ve00;oG5Ve00?o0000ofa_
a?m/Kl@02_m/Kl@00ol0003oRgfnoh]m_P07oh]m_P03o`000?n@R/WoT8[900WoT8[900?o0000oj:C
aOnRTlD04OnRTlD3o`0001?o/9g300?o0000okfXa?nmZ<@04_nmZ<@00ol0003ob[K7olZfa`0ColZf
a`03o`000?oEalco0000017ogLG100Oo0000on[OaooZglOoj]o7o`000?odg[Go000000Oom=je0_l0
0002omWKIP03o`000?oooooooooo02kooooo00?o0000ooooooooool02oooool001Sooooo00?o0000
ooooooooool0AOooool01?l0003o002:o`00R_l00006oa@d/P04o`000?mLFKGoG5Veo`0000koK6o4
00?o0000oh]m__n;OKh01?n;OKh2o`0000coT8[900?o0000oj:CaOnRTlD03_nRTlD3o`000003oj:C
aOl0003o/9g301?o/9g300?o0000okfXa?nmZ<@04_nmZ<@00ol0003ob[K7olZfa`0BolZfa`05o`00
0?oEalcoeLO<omG7c?l000003ooMaL400ol0003oj]o7on[Oa`02on[Oa`03o`000?odg[Go000000Oo
m=je0_l000000ooIffKo0000ooooo`0aooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`00
0?oooooooooo04Gooooo00Co0000o`00R_l008[o00001_lD=;800ol0003oG5Veo`00000@ofa_a004
o`000?n;OKkoRgfnoh]m_P;o00003on@R/T00ol0003oXY?5oj:Ca@09oj:Ca@Co00001OnRTlD00ol0
003o/9g3ok2M``0Aok2M``03o`000?nmZ<Co_JS4017o_JS400?o0000olZfaoo:]/L04_o:]/L00ol0
003oeLO<omG7c003omG7c0;o00003?oMaL400ol0003oj]o7on[Oa`03on[Oa`04o`000?odg[Gom=je
o`0000Gom=je00Go0000on_eY?l0003ofM]Vo`00000booooo`03o`000?oooooooooo00[ooooo000H
ooooo`;o0000Aoooool2o`0000So53Bb00?o0000ofa_a?m/Kl@03om/Kl@01?l0003oRgfno`000?l0
000Aoi2:b@03o`000?nRTlGoXY?500KoXY?50ol00009oj:Ca@03o`000?n`WL?o/9g3017o/9g300?o
0000okfXa?nmZ<@04OnmZ<@00ol0003ob[K7olZfa`0BolZfa`03o`000?oEalcoeLO<00GoeLO<00?o
0000omg5`OoMaL402?oMaL400ol0003oj]o7on[Oa`05on[Oa`04o`000?odg[Gom=jeo`0000?om=je
00?o0000on_eY?l000000_oIffH00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04Kooooo0_l00008oa@d/P03o`000?m/KlCoK6o4013oK6o400?o
0000oi2:bOn@R/T04_n@R/T00ol0003oXY?5oj:Ca@02oj:Ca@?o00002_nRTlDLo`0000ko_JS400?o
0000olZfaoo:]/L04Oo:]/L00ol0003oeLO<omG7c007omG7c003o`000?oMaL7ogLG100OogLG100?o
0000on[OaooZglL01OoZglL01Ol0003om=jeooCN]Oodg[Go000000;om=je00?o0000on_eY?l00000
0_oIffH00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`000?oo
oooooooo04Kooooo0_l00008oa@d/P;o00004Om/Kl@00ol0003oT8[9oi2:b@0Boi2:b@03o`000?nR
TlGo000000;o00002_nRTlD3o`0000;oY9g?00?o0000ok2UcOn`YLd04On`YLd00ol0003o^jo>ok^_
cP03ok^_cPWo00001?nmZ<@00ol0003ob[K7olZfa`0BolZfa`03o`000?oEalcoeLO<00SoeLO<00?o
0000omg5`OoMaL401OoMaL400ol0003oj]o7on[Oa`07on[Oa`04o`000?odg[Gom=jeooCN]@;o0000
0_o[mJ@00ol0003ofM]Vo`00000cooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oo
oooooooo04Sooooo00?o0000oa@d/_lD=;801_lD=;800ol0003o>U_9o`00000?ofa_a003o`000?mi
P]3o0000017oT8[91?l00009oj:Ca@Co00001OnTWLl00ol0003o/:G=ok2Uc@0Aok2Uc@03o`000?nk
[lko^jo>00co^jo>1Ol0000ColZfa`03o`000?oEalcoeLO<00[oeLO<0_l00004omg5`@03o`000?oZ
glOoj]o700Soj]o700Co0000ooCN]Oodg[Gom=je0_l00002on_eY003o`000?oIffKo000003?ooooo
00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0B?ooool00ol0003o53Bboa@d
/P05oa@d/P05o`000?ljFlWo>U_9ocYKbOl000003Om/Kl@01Ol0003oNH;@ogV2d?miP]3o000000go
T8[90ol00003oi2:b@03o`000?nRTlGoXY?500?oXY?51?l0000:ojBMc`03o`000?n`YLgo/:G=013o
/:G=00?o0000ok^_c_nk[lh04?nk[lh00ol0003oa;[@o`000002o`0000kob[K700?o0000omG7c?oE
al`03OoEal`01Ol0003ogLG1omg5`OoMaL7o000000_oj]o700?o0000ooCN]Oodg[D00_l00002on_e
Y003o`000?oIffKo000003?ooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000oooooooo
ool0BOooool00ol0003o53Bboa@d/P04oa@d/P03o`000?ljFlWo>U_900;o>U_900?o0000ofa_a?m/
Kl@02Om/Kl@00ol0003oNH;@ogV2d003ogV2d003o`000?n@R/WoT8[900OoT8[90ol00006oi2:b@03
o`000?nRTlGoXY?500?o00003_nTWLl00ol0003o/:G=ok2Uc@0@ok2Uc@03o`000?nk[lko^jo>00oo
^jo>00?o0000olBjd?o4^]000oo4^]03o`0000_ob[K700?o0000omG7c?oEal`03_oEal`00ol0003o
gLG1o`00000<on[Oa`03o`000?odg[Go000000;ojoFT00Co0000on_eY?l0003o0000=Oooool00ol0
003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`19ooooo`03o`00POl0003o53Bb00Co
53Bb00?o0000ocYKbOljFlT00oljFlT00ol0003oK6o4ofa_a007ofa_a003o`000?miP]3oNH;@00Go
NH;@00?o0000oi2:bOn@R/T00on@R/T3o`0000WoT8[90ol0000AojBMc`03o`000?n`YLgo/:G=013o
/:G=00?o0000ok^_c_nk[lh03onk[lh00ol0003oa;[@olBjd006olBjd0;o00002?o:]/L00ol0003o
eLO<omG7c00@omG7c003o`000?oZglOoj]o700_oj]o700?o0000ooCN]Ol000000oo[mJ@3o`0003Go
oooo00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0B_ooool00ol0003o53Bb
oa@d/P03oa@d/P03o`000?ljFlWo>U_900?o>U_900?o0000ofa_a?m/Kl@01_m/Kl@00ol0003oNH;@
ogV2d007ogV2d0Go00002_n@R/T2o`000003oiFGdol0003oY9g?01;oY9g?00?o0000ok2UcOn`YLd0
3on`YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@00Woa;[@0ol00005olZfa`03o`00
0?oEalcoeLO<013oeLO<00?o0000on[OaooZglL03?oZglL00ol0003ojoFTon_eY003on_eY0;o0000
=Oooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1:ooooo`;o00001?lD
=;800ol0003o>U_9ocYKb@04ocYKb@03o`000?m/KlCoK6o400GoK6o400?o0000ogV2d?miP]001Omi
P]03o`0000coT8[90_l00004oiFGd`03o`000?nTWLooY9g?013oY9g?00?o0000ok2UcOn`YLd03on`
YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@00coa;[@0ol000000oo:]/Oo0000omG7
c00AomG7c003o`000?oNgMCo000000goj]o700?o0000on_eY?o[mJ@00_o[mJ@2o`0003Kooooo00?o
0000ooooooooool02Oooool001Oooooo0_l0001<ooooo`03o`00POl0003o53Bb00;o53Bb00?o0000
ocYKbOljFlT01OljFlT00ol0003oK6o4ofa_a003ofa_a003o`000?miP]3oNH;@00?oNH;@0ol00003
ogV2d003o`000?n@R/WoT8[900OoT8[90_l00007oiFGd`03o`000?nTWLooY9g?00ooY9g?00?o0000
ok2UcOn`YLd03_n`YLd00ol0003o^jo>ok^_cP0?ok^_cP03o`000?o4^]3oa;[@00ooa;[@0_l0000A
omG7c004o`000?oNgMCog]gDo`0000coj]o70_l00004on_eY0?o0000=Oooool00ol0003ooooooooo
o`09ooooo`005_ooool00ol0003oooooooooo`1<ooooo`;o00000olD=;800ol0003o>U_9ocYKb@06
ocYKb@05o`000?m/KlCoK6o4ofa_a?l000000omiP]03o`0000OoNH;@00?o0000oi2:bOn@R/T01On@
R/T00ol0003oUIOCoiFGd`07oiFGd`03o`000?nTWLooY9g?00ooY9g?00?o0000ok2UcOn`YLd03_n`
YLd00ol0003o^jo>ok^_cP0>ok^_cP03o`000?o4^]3oa;[@013oa;[@00?o0000olg8e_l000003ooE
al`00ol0003og]gDomkMe002omkMe003o`000?oZglOoj]o700Soj]o700?o0000onSjb?l000001?o[
mJ@2o`000003ooooool0003ooooo03?ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0COooool01?l0087o0000oa@d/_l0000:ocYKb@03o`000?m/KlCo000000Co00002omi
P]000ol0003oT8[9oi2:b@02oi2:b@;o00002onEUm<00ol0003oY9g?ojBMc`0?ojBMc`03o`000?n`
YLgo/:G=00go/:G=00?o0000ok^_c_nk[lh03_nk[lh00ol0003oa;[@olBjd00?olBjd005o`000?o=
b=KocLSFolg8e_l000003OoEal`00ol0003og]gDomkMe003omkMe003o`000?oZglOoj]o700Ooj]o7
00?o0000onSjb?l000001Oo[mJ@01Ol0003ooooooooooooooooo000003?ooooo00?o0000oooooooo
ool02Oooool001Kooooo00?o0000ooooooooool0COooool2o`000003oa@d/_l0003o>U_900Wo>U_9
0ol0000@ogV2d004o`000?n@R/Wo0000o`0000goUIOC00?o0000ojBMconTWLl03onTWLl00ol0003o
/:G=ok2Uc@0=ok2Uc@03o`000?nk[lko^jo>00go^jo>00?o0000olBjd?o4^]003oo4^]000ol0003o
cLSFolg8eP03olg8eP;o00002_oEal`00ol0003og]gDomkMe005omkMe003o`000?oZglOoj]o700Go
j]o700Co0000onSjb?oXn/So00001Oo[mJ@00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0COooool01?l0003o
0021o`000?l00007ocYKb@?o000000Co>U_9oeIhfOmFN=Wo00004?miP]000ol0003oUIOCoiFGd`0>
oiFGd`03o`000?nTWLooY9g?00koY9g?00?o0000ok2UcOn`YLd03On`YLd00ol0003o^jo>ok^_cP0=
ok^_cP03o`000?o4^]3oa;[@00koa;[@00?o0000olg8e_o=b=H01_o=b=H00ol0003oeLO<omG7c006
omG7c003o`000?oNgMCog]gD00Kog]gD00?o0000on[OaooZglL01?oZglL01Ol0003oj?[8onSjb?oX
n/So000000CojoFT00?o0000ooooooooool01?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo000Fooooo`03o`000?oooooooooo04kooooo00?o0000o`00POl000001?ljFlT3
o`0000Co>U_900Co0000oeIhfOmFN=Wo00003omiP]000on4T][o0000oiFGd`0?oiFGd`03o`000?nT
WLooY9g?00koY9g?00?o0000ok2UcOn`YLd03?n`YLd00ol0003o^jo>ok^_cP0<ok^_cP03o`000?o4
^]3oa;[@00koa;[@00?o0000olg8e_o=b=H02?o=b=H2o`0000GoeLO<00?o0000omkMe?oNgM@02?oN
gM@00ol0003oj]o7on[Oa`03on[Oa`05o`000?oXn/Soj?[8onSjb?l000000oo[mJ@00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool001Kooooo00?o
0000ooooooooool0C_ooool00ol0003o0021o`0f_004o`0000Oo>U_900Go0000oeIhfOmFN=WoEWSI
o`00000=ogV2d004o`000?n4T][oQ9;Jo`0000ooUIOC00?o0000ojBMconTWLl03?nTWLlFo`0000[o
^jo>00?o0000olBjd?o4^]003Oo4^]000ol0003ocLSFolg8eP0;olg8eP05o`000?oEalcoeLO<omG7
c?l000002ooNgM@00ol0003oj]o7on[Oa`02on[Oa`03o`000?oXn/Soj?[800;oj?[800Go0000on_e
Y?o[mJCojoFTo`000008ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool0
01Gooooo00?o0000ooooooooool0Coooool3o`000003o`0f_?l0003o>U_900Oo>U_900?o0000oeIh
fOmFN=T00omFN=T00ol0003oNH;@ogV2d009ogV2d003o`000?n4T][oQ9;J00;oQ9;J00?o0000oiFG
donEUm<03OnEUm<00ol0003oY9g?ojBMc`08ojBMc`?o00000_nUZ=T00ol0003o[ZkGojj^e`0<ojj^
e`03o`000?ng]MSo]kGH00;o]kGH1ol00003ok^_cP03o`000?o4^]3oa;[@00goa;[@00?o0000olg8
e_o=b=H03?o=b=H00ol0003oeLO<o`00000=omkMe004o`000?oZglOoj]o7o`0000Goj?[800Co0000
on_eY?o[mJCo00002_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`?o0000C?ooool3o`000006ooooool0003o0021o`000?l0=[co00001oljFlT00ol0003oEWSI
oeIhf@04oeIhf@03o`000?miP]3oNH;@00OoNH;@00?o0000ohBBf_n4T]X01?n4T]X00ol0003oUIOC
oiFGd`0<oiFGd`03o`000?nTWLooY9g?00CoY9g?1?l00005ojFXf@03o`000?n^[]Oo[ZkG00co[ZkG
00?o0000okNef?ng]MP02Ong]MP5o`0000goa;[@00?o0000olg8e_o=b=H03_o=b=H00ol0003og]gD
omkMe00<omkMe003o`000?oZglOo000000Koj?[800?o0000on_eY?l000003?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Wooooo0ol0
0005ooooo`05o`000?l0087o0000o`0f_?l000001_ljFlT00ol0003oEWSIoeIhf@05oeIhf@03o`00
0?miP]3oNH;@00GoNH;@00?o0000ohBBf_n4T]X01_n4T]X00ol0003oUIOCoiFGd`0<oiFGd`03o`00
0?nTWLooY9g?00?o00002_nUZ=T00ol0003o[ZkGojj^e`0;ojj^e`03o`000?ng]MSo]kGH00_o]kGH
00?o0000okjnf_nn_]X00ol00009olBjd003o`000?o=b=KocLSF00gocLSF00?o0000om;Jg_l00000
3ooNgM@00ol0003oj?[8onSjb004onSjb003o`000?o[mJCo000000kooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002?oo
ool00ol0003o0021o`000002o`0f_003o`000?ljFlWo>U_900?o>U_900?o0000oeIhfOmFN=T01_mF
N=T00ol0003oNH;@ogV2d003ogV2d003o`000?n4T][oQ9;J00SoQ9;J00?o0000oiFGdonEUm<02onE
Um<3o`0000goYJSI00?o0000ojj^eon^[]L02_n^[]L00ol0003o]kGHokNef00;okNef003o`000?nn
_][o_[kJ00Co_[kJ0ol00005olBjd003o`000?o=b=KocLSF00gocLSF00Go0000om;Jg_oBf]kod][N
o`00000<omkMe003o`000?oNmMco000000Koj?[800?o0000on_eY?l000003_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo0ol0
000=ooooo`03o`000?l0087o000000;o03Jl00?o0000ocYKbOljFlT00_ljFlT00ol0003oEWSIoeIh
f@07oeIhf@05o`000?miP]3oNH;@ogV2d?l000003?n4T]X00ol0003oUIOCoiFGd`08oiFGd`;o0000
00?oVZCLo`000?nUZ=T03OnUZ=T00ol0003o[ZkGojj^e`0:ojj^e`03o`000?ng]MSo]kGH00_o]kGH
00?o0000okjnf_nn_]X01onn_]X3o`000003olBjd?l0003ocLSF00kocLSF00?o0000om;Jg_oBf]h0
0_oBf]h00ol0003og]gDomkMe009omkMe004o`000?oNmMcog_GLo`0000Koj?[80_l0000@ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool01oooool001Gooooo00?o0000ooooooooool0
?oooool3o`00017ooooo00?o0000o`00POl000000_l0=[`01Ol0003o>U_9ocYKbOljFlWo000000[o
EWSI00?o0000ogV2d?l000003_n4T]X00ol0003oUIOCoiFGd`05oiFGd`;o00001?nJY=`00ol0003o
YJSIojFXf@0;ojFXf@03o`000?n^[]Oo[ZkG00[o[ZkG00?o0000okNef?ng]MP02_ng]MP00ol0003o
_[kJokjnfP0;okjnfP03o`000?o=b=KocLSF00gocLSF00?o0000om;Jg_oBf]h01?oBf]h00ol0003o
g]gDomkMe007omkMe005o`000?oNmMcog_GLomkeg?l000001_oXn/P00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool0?Oooool3o`0001Gooooo0_l00003o`0f_003o`000?ljFlWo000000coEWSI0_l0000?ohBBfP03
o`000?nEUm?oUIOC00;oUIOC0_l00007oiZTg003o`000?nUZ=WoYJSI00_oYJSI00?o0000ojj^eon^
[]L02On^[]L00ol0003o]kGHokNef00:okNef003o`000?nn_][o_[kJ00_o_[kJ00?o0000ol?9gol0
00002oo=b=H2o`0000Ood][N00?o0000omkMe?oNgM@01OoNgM@2o`0000?og_GL00?o0000onSjb?oX
n/P01?oXn/P2o`0001?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0iooooo`Co00006Oooool00ol0087o0000o`0f_002o`0f_0;o0000
3?mFN=T2ofb?h`03o`000?n4T][oQ9;J00goQ9;J00Co0000oiFGdol0003o00002_nJY=`00ol0003o
YJSIojFXf@0:ojFXf@03o`000?n^[]Oo[ZkG00Wo[ZkG00?o0000okNef?ng]MP02Ong]MP00ol0003o
_[kJokjnfP0;okjnfP04o`000?o3bMoo`lWOol?9g`;o00002?o=b=H00ol0003od][Nom;JgP08om;J
gP03o`000?oNgMCog]gD00?og]gD00?o0000omkeg?oNmM`00ooNmM`00ol0003oj?[8onSjb003onSj
b0;o00005Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03
o`000?oooooooooo03Kooooo0ol0000Mooooo`;o00001?l0=[`2o`0000_oEWSI00Co0000ofb?hom/
Sn?o00003on4T]X2o`0000_oVZCL00?o0000ojFXfOnUZ=T02_nUZ=T00ol0003o[ZkGojj^e`09ojj^
e`03o`000?ng]MSo]kGH00Wo]kGH00?o0000okjnf_nn_]X02_nn_]X00ol0003o`lWOol?9g`04ol?9
g`03o`000?o=b=KocLSF00CocLSF00?o0000om;Jg_oBf]h02OoBf]h00ol0003og]gDomkMe002omkM
e003o`000?oNmMcog_GL00Cog_GL00?o0000onSjb?oXn/P00_oXn/P2o`0001Kooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Qooooo`;o
00000ol0=[`2oaiYg003o`000?mFN=WoEWSI00OoEWSI00?o0000ofb?hom/Sn<00_m/Sn<2o`0000co
Q9;J00Co0000ohfQh_n=XN;o00002onJY=`00ol0003oYJSIojFXf@09ojFXf@03o`000?n^[]Oo[ZkG
00So[ZkG00?o0000okNef?ng]MP02Ong]MP00ol0003o_[kJokjnfP0:okjnfP03o`000?o3bMoo`lWO
00Ko`lWO0_l00003olg8eP03o`000?oBf]kod][N00_od][N00Co0000omkMe?oNgMCo00001ooNmM`0
1?l0003oj?[8onSjb?oXn/P2o`0001Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00009Oooool00ol0003o03Jlo`0f_002
o`0f_0;o7VWL00?o0000oeIhfOmFN=T01_mFN=T00ol0003oK8oSofb?h`04ofb?h`03o`000?n4T][o
Q9;J00SoQ9;J00?o0000ohfQh_n=XN800_n=XN800ol0003oVZCLoiZTg009oiZTg003o`000?nUZ=Wo
YJSI00SoYJSI00?o0000ojj^eon^[]L02?n^[]L00ol0003o]kGHokNef009okNef003o`000?nn_][o
_[kJ00Wo_[kJ00?o0000ol?9goo3bMl02Oo3bMl00ol0003ocLSFo`00000>om;JgP03o`000?oNgMCo
000000Sog_GL00?o0000onSjb?oXn/P00_l0000Jooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
02cooooo1?l0000Yooooo`05o`000?l0=[co03Jlo`0f_?l000000_lNJM`2o`0000KoEWSI00?o0000
ofb?hom/Sn<01Om/Sn<00ol0003oQ9;JohBBfP06ohBBfP03o`000?n=XN;oSJ7R00CoSJ7R00?o0000
oiZTg?nJY=`02?nJY=`00ol0003oYJSIojFXf@09ojFXf@03o`000?n^[]Oo[ZkG00;o[ZkG2Ol00007
okNef003o`000?nn_][o_[kJ00Wo_[kJ00?o0000ol?9goo3bMl02oo3bMl00ol0003od][Nom;JgP0>
om;JgP03o`000?oNmMcog_GL00Oog_GL00Co0000onSjb?l0003o00007?ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0:_ooool3o`0002kooooo00Go0000o`0f_?l0=[co03Jlo`000003oaiYg003o`000?mF
N=WoEWSI00?oEWSI00?o0000ofb?hom/Sn<01_m/Sn<2o`0000GoQ9;J00?o0000ohfQh_n=XN801_n=
XN800ol0003oVZCLoiZTg008oiZTg003o`000?nUZ=WoYJSI00KoYJSI1ol00005oj^ghP04o`000?na
_>;o/KcRok6lhPGo00000_ng]MP00ol0003o_[kJokjnfP08okjnfP03o`000?o3bMoo`lWO00[o`lWO
00?o0000olKFiOl000003_oBf]h00ol0003odNcWo`000008omkeg005o`000?oXn/So0000ojS/XOl0
00007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0003;ooooo00Co0000o`0f_?l0=[co
00001?lNJM`2o`0000?oEWSI00?o0000ofb?hom/Sn<02?m/Sn<01Ol0003oQ9;JohBBf_n4T][o0000
00[oSJ7R00?o0000oiZTg?nJY=`02?nJY=`00ol0003oYJSIojFXf@05o`0000;oYK?S00?o0000oj^g
h_n[]n801on[]n800ol0003o/KcRok6lhP06ok6lhP?o00002Onn_]X00ol0003o`lWOol?9g`09ol?9
g`;o00000oo6e^D00ol0003od][Nom;JgP09om;JgP;o00000_oAk>L00ol0003og_GLomkeg006omke
g0;o000000?oZ>bQo`000?ooool07_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool3o`0003Ko
oooo00Co0000o`0f_?l0=[co00001OlNJM`00ol0003oEWSIo`00000<ofb?h`03o`000?n4T][o0000
00coSJ7R00?o0000oiZTg?nJY=`01onJY=`3o`0000SoYK?S00?o0000oj^gh_n[]n801_n[]n800ol0
003o/KcRok6lhP07ok6lhP03o`000?ne`^Co000000;o00001Onn_]X00ol0003o`lWOol?9g`09ol?9
g`03o`000?o6e^Goa]KU00?oa]KU00?o0000om;Jg_oBf]h01ooBf]h2o`0000CodNcW00?o0000omke
g?oNmM`01OoNmM`2o`000003ojS/XOl0003ooooo01oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023o
oooo1?l0000jooooo`03o`000?l0=[co000000Ko7VWL00?oEWSIo`000?m/Sn<03?m/Sn<2o`0000go
SJ7R00?o0000oiZTg?nJY=`01?nJY=`2o`0000;oWK7U00?o0000ojFchonU/n<01_nU/n<00ol0003o
ZkORoj^ghP06oj^ghP03o`000?na_>;o/KcR00Ko/KcR00?o0000okG2i?ne`^@00one`^@3o`000003
okjnf_l0003o`lWO00Wo`lWO0_l00007olKFi@03o`000?oBf]kod][N00God][N00?o0000om7/iooA
k>L01?oAk>L00ol0003og_GLomkeg004omkeg004o`000?nno]Go0000o`0002;ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01gooooo0ol0000oooooo`;o00001olNJM`2o`0000coK8oS00Co0000ogjQjOl0
003o00003?n=XN800ol0003oVZCLoiZTg002oiZTg003o`000?nM/NGoWK7U00?oWK7U00?o0000ojFc
honU/n<01OnU/n<00ol0003oZkORoj^ghP06oj^ghP03o`000?na_>;o/KcR00Go/KcR00?o0000okG2
i?ne`^@01one`^@00ol0003o`lWOol?9g`08ol?9g`03o`000?o6e^Goa]KU00Ooa]KU00?o0000om;J
g_oBf]h00ooBf]h2o`0000OodNcW00?o0000omkeg?oNmM`00_oNmM`2o`000003okkneOl0003o0000
02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01[ooooo0ol00013ooooo`03o`0f_?l0003o7VWL00Go
7VWL00Co0000odb<jol0003o00002_m/Sn<01?l0003oOZ7YogjQjOmnXNT2o`0000_oSJ7R00Co0000
oiZTg?l0003o00001onM/ND00ol0003oYK?SojFch`05ojFch`03o`000?n[]n;oZkOR00CoZkOR00?o
0000ok6lh_na_>801_na_>800ol0003o]L;TokG2i006okG2i0?o^<WW00?o0000ol?9goo3bMl01Oo3
bMl00ol0003oa]KUolKFi@09olKFi@03o`000?oBf]kod][N00;o00002?oAk>L00ol0003og_GLomke
g002omkeg003o`000?nno]Go__kE00;o00009_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000Aoooool0
0ol0003o7VWLoaiYg005oaiYg003o`000?m<S>_oC8c[00;o00002?m/Sn<00ol0003oOZ7YogjQj@03
ogjQj@;o00002_n=XN82o`0000WoWK7U00?o0000ojFchonU/n<01?nU/n<00ol0003oZkORoj^ghP04
oj^ghP03o`000?na_>;o/KcR00Go/KcR00?o0000okG2i?ne`^@01One`^@00ol0003o^<WWokS9i`03
okS9i`;o00000oo3bMl2o`0000coa]KU00?o0000om;Jg_l000002_oAk>L01Ol0003og_GLomkeg?oN
mMco000000;o__kE0_l0000Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_oo
ool001;ooooo00?o0000ooooooooool05?ooool4o`0004_ooooo0_l00005oaiYg003o`000?m<S>_o
C8c[00;oC8c[0ol00004ofb?h`03o`000?mnXNWoOZ7Y00KoOZ7Y0_l00007ohfQhP03o`000?nE/>Wo
UK3Y00;o00002?nM/ND00ol0003oYK?SojFch`04ojFch`03o`000?n[]n;oZkOR00?oZkOR00?o0000
ok6lh_na_>801Ona_>800ol0003o]L;TokG2i004okG2i003o`000?nhbNOo^<WW00Ko^<WW00?o0000
ol?9gol000003oo6e^D00ol0003odNcWom7/i`09om7/i`04o`000?oNmMco0000o`0000;o__kE0_l0
000Yooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000
ooooooooool04Oooool3o`00057ooooo0_l00004oaiYg003o`000?m<S>_oC8c[00CoC8c[0_l00002
ofb?h`03o`000?mnXNWoOZ7Y00SoOZ7Y0_l00004ohfQhP03o`000?nE/>WoUK3Y00?oUK3Y00?o0000
oifaiOnM/ND01_nM/ND00ol0003oYK?SojFch`03ojFch`03o`000?n[]n;oZkOR00?oZkOR00?o0000
ok6lh_na_>801?na_>800ol0003o]L;TokG2i003okG2i0;o00002_nhbNL00ol0003oa]KUolKFi@0:
olKFi@?o000000?oa>;]o`000?oAk>L02_oAk>L2o`0000Co__kE00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo
00kooooo0ol0001Eooooo`03o`1>`ol0003o7VWL00;o7VWL00?o0000odb<jom<S>/01_m<S>/00ol0
003oK8oSo`00000<ogjQj@;o000000?oSJ7Ro`000?nE/>T01_nE/>T2o`0000OoWK7U00?o0000ojFc
honU/n<00_nU/n<00ol0003oZkORoj^ghP03oj^ghP03o`000?na_>;o/KcR00?o/KcR00?o0000okG2
i?ne`^@00one`^@00ol0003o^<WWokS9i`08okS9i`03o`000?nid>co000000Woa]KU0ol00004olCR
k@03o`000?oAk>OodNcW00WodNcW00?o0000okkneOnno]D00_nno]D00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooooooo
ool02oooool3o`0005Wooooo00Go04k3o`000?l0003o7VWLo`00000:odb<j`;o00003OmnXNT2o`00
00WoUK3Y0_l00006oifai@03o`000?nU/n?oYK?S00_o00000_na_>800ol0003o]L;TokG2i002okG2
i003o`000?nhbNOo^<WW00Ko^<WW0_l00004okW@k003o`000?o6e^Goa]KU00?oa]KU0ol00007olCR
k@03o`000?oAk>OodNcW00GodNcW0ol000000oo0nNgo0000okkne@02okkne@03o`000?oooooooooo
02gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`Co0000GOooool01Ol0003o04k3o`000?lNJMco000000WoC8c[00?o0000ofbS
lOl000000_l0000:ogjQj@03o`000?n=/Nko000000;o00002?nE/>T00ol0003oWK7Uoifai@03oifa
i@?o00000_nS_nd00ol0003oY/7]ojK1k@02ojK1k@04o`000?nX`ngoZ<?]ojS3k@Co00000_ne`^@0
0ol0003o^<WWokS9i`04okS9i`?o00001onid>`00ol0003oa]KUo`000002o`0000Woa>;]00?o0000
om7/iooAk>L00ooAk>L3o`0000?o`?W]00Go0000okkneOnno]Go__kEo`00000aooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3
o`0006;ooooo00Co0000o`1>`ol0C/?o00002_m<S>/01?l0003oK:?aofbSlOm/Xo43o`0000KoOZ7Y
00?o0000ohfak_n=/Nh00on=/Nh3o`0000KoUK3Y0_l000000onM/NGo0000o`000002oj2nkP05o`00
0?nS_ngoXko]oj>okOl000000onV`Nd00ol0003oZ<?]ojS3k@02ojS3k@03o`000?nYaNkoZLG^00;o
00001OnhbNL2o`0000_o^M3/00?o0000olCRkOo4h^d02_o4h^d01?l0003odNcWom7/iooAk>L2o`00
00Go`?W]00?o0000okkneOnno]D00_l0000cooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01Oooool0017ooooo00?o0000ooooooooool00_ooool3o`0006Kooooo00?o0000o`1>`ol0
C/<00ol00007odb<j`03o`000?m/Xo7oK:?a00CoK:?a0_l00004ogjQj@03o`000?n=/NkoSK7^00Ko
SK7^0ol00005oiF`j@;o00001?nP_^h01?l0003oXko]oj>okOl00003ojK1k@05o`000?nX`ngoZ<?]
ojS3kOl000000_nYaNh01_l0003oZ/O_oj[7konZanoo0000okS9i`;o00002Onid>`3o`000003okOG
lOl0003oa>;]00_oa>;]1?l00006ol3ik@04o`000?nno]Go0000o`0003Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0006[ooooo
00Go0000o`1>`ol0C/?o04k3ob:6jP03o`0000GoC8c[00?o0000ofbSlOm/Xo401Om/Xo42o`0000;o
OZ7Y00?o0000ohfak_n=/Nh02On=/Nh3o`000004oiF`jOl0003oWKk`oifnl0;o00000onP_^h01?l0
003oXko]oj>okOl00002ojK1k@05o`000?nX`ngoZ<?]o`000?nYaNh00_l00004oj[7k`;o00002?ni
d>`3o`0000Co]mOa00?o0000olCRkOo4h^d02_o4h^d00ol0003o`?W]ol3ik@06ol3ik@Co0000=ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo000Aooooo`;o0000K_ooool0
1Ol0003o04k3o`1>`ol0C/?o000000;o8XKZ0ol00002odb<j`03o`000?m/Xo7oK:?a00SoK:?a1?l0
000<ohfakP?o00000onM__02o`0000;oX;k^00Go0000oj>okOl0003oY/7]o`000002ojS3k@03o`00
0?nYaNko000000?oZ/O_0ol000000onZb_7o0000okW@k004okW@k0?o00001ongeo400ol0003oa>;]
olCRk@03olCRk@Go00000_nijoD00ol0003o`?W]ol3ik@05ol3ik@?o0000>_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06cooooo00Go
0000o`1>`ol0C/?o04k3o`000004ob:6jP?o00002_m/Xo401?l0003oQKCdohFdm?n5]?@5o`0000Oo
SK7^00?o0000oi^olOnK_o400ol00002oifnl0;o000000GoX;k^o`000?l0003oY/7]o`000002ojS3
k@;o000000CoZ/O_o`000?l0003o00001OnZb_400ol0003o^M3/o`000002o`0000[o]mOa00?o0000
olCRkOl000000ol00006okW[m@03o`000?o0nNgo`?W]00Go`?W]0ol0000looooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool01?ooool001Cooooo0_l0001]ooooo`;o00000_l0C/<00ol0
003o8XKZob:6jP04ob:6jP?o00002?m/Xo400ol0003oQKCdohFdm005ohFdm0Go000000?oSK7^o`00
0?nK_o401OnK_o49o`000003ojS3kOl0003o000000;o00001OnZb_45o`0000go]mOa0_l00009okW[
m@03o`000?o0nNgo`?W]00Co`?W]0ol0000oooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01?ooool001Kooooo00?o0000ooooool00000K?ooool2o`000003o`1>`ol0003o8XKZ00Go
8XKZ00?o0000oeVWmol000000ol00004ofbSl@03o`000?n5]?CoQKCd00[oQKCd2_l00002oi^ol@oo
00001?nXc?801?l0003o]mOaokOGlOngeo47o`0000?o/=cf00?o0000okW[mOnijoD01onijoD00ol0
003o`?W]ol3ik@02ol3ik@Co0000@Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Cooooo000Gooooo`;o0000K_ooool3o`0000Ko8XKZ00?o0000oeVWmomIYoL00_mIYoL5o`0000go
QKCd00?o0000oiW1lonI`O<01OnI`O<Jo`0000Wo/=cf00?o0000okW[mOnijoD02?nijoD00ol0003o
`?W]o`000005o`0004?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`04ooooo`00
6?ooool2o`0006oooooo0_l00006ob:6jP03o`000?mIYoOoFJOg00GoFJOg3_l000000on5]?Co0000
o`000005o`000003oiO3mOl0003o000000?o000000?oV<Oho`000?l000002Ol00003ojK=m003o`00
0?n`g?Ko/=cf00[o/=cf00?o0000okW[mOnijoD02?nijoD3o`0000;oT_3S0_l00016ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool01?ooool001[ooooo00?o0000ooooooooool0K_oo
ool3o`0000Co8XKZ00?o0000oeVWmomIYoL01omIYoL00ol0003oO[Siogjhn@0:ogjhn@03o`000?nG
`oGoUl?e00Co00000_nGaOL2o`000005oiS7n?l0003o0000oic<n?l000000_nPcOL2o`0000CoXlkf
2Ol00006ok3LmP03o`000?nijoGo^N_e00;o^N_e1ol00003oi;`h`?o0000B?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0KOoo
ool01?l0O]Oo0000o`000?l00002ob:6jP03o`000?mIYoOoFJOg00OoFJOg00?o0000ogjhnOmn^?T0
2_mn^?T2o`0000CoUlGg0_l00002oiS7n003o`000?nJb_So000000;oW<ch00Co0000oj3=monPcOOo
X<gg0ol000000onSc_Ko0000ojKNn`07ojKNn`Co000000?o/=cfo`000?l000001?l00003oj?]n@;o
00001?nBl><2o`0004_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00
7Oooool2o`00077ooooo00Go07kGo`000?l0003o8XKZo`000009oeVWm`04o`000?mn^?WoO[Siogjh
n@Go00001Omi__`2o`000003oiO5mol0003oV<Oh00?oV<Oh00Co0000oi[:n?nJb_So00000_nLc?P0
0ol0003oX<ggoj3=m`02oj3=m`Co00002_nVg_/00ol0003oXngioj?]n@06oj?]n@;o00001?nBl><2
o`0004gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007_ooool00ol0
003oooooooooo`1`ooooo`;o000000?o07kGo`000?l000003?l0000<ogVno0?o00000_nHaoP01Ol0
003oV/[hoi[:n?nJb_So000000?oW<ch00Co0000oj3=mol0003o00001?nHg?h3o`0000GoY]kk0_l0
0008oj?]n@03o`000?nBl>?oT_3S00?oT_3S0_l0001?ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00oooool001oooooo0_l0001`ooooo`03o`000?oooooooooo00;o000000?o07kG
o`000?l000002?m8[?P3o`0000KoNKkl0ol00004ogW6o`go00002?nHg?h2o`0000;oY]kk00?o0000
oj?]nOnSkOT01_nSkOT2o`000003oi;`hol0003o000000?o0000D_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool00oooool2o`000003o`1neol0003o000000SoB:ch0_l000001?mi__co0000o`000?l00008
ogW6o`03o`000?moc_ooOlko00;oOlko00?o0000oh_Foon;e_l01?n;e_l2o`0000OoV=cn4Ol0001F
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001/oooo
o`03o`000?oooooooooo00Gooooo1_l00004odR/n004o`000?m8[?SoB:cho`0000[oNLKo00?o0000
ogo>oomoc_l00omoc_l00ol0003oRmKooh_Fo`06oh_Fo`03o`000?nHg?koV=cn00Co00001on3hoL6
o`0005_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`009?ooool00ol0
003oooooooooo`1Zooooo`03o`000?oooooooooo00Sooooo00?o07Zko`000?l000001?l00006od6d
m0Go00000_mia_l00ol0003oOlkoogo>o`05ogo>o`03o`000?n;e_ooRmKo00CoRmKo1Ol00007oh?S
m`Ko0000Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o
0000J_ooool00ol0003oooooooooo`0<ooooo`03o`000?l0N[_o000000Co00001om1]?@7o`0000?o
Olko00?o0000oh_Fool000001?l00005of7BlP?o000000?oPn?go`000?l000000ol0001Sooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0@ooooo`;o000000?o07Zko`000?l000000_l00002od6dm003o`00
0?m9`O7oBL7a00GoBL7a1Ol0000:of7BlPGo0000J?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo000Xooooo`03o`000?oooooo000006Kooooo00?o0000ooooooooool05?oo
ool5o`0000GoBL7a0_l00004odW1l@03o`000?mQd_;oHM;b00;oHM;b1ol0001^ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04
ooooo`;o0000I_ooool00ol0003oooooooooo`0Nooooo`;o4@002Ol0001fooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?o
oooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0023ooooo00?o
0000ooooooooool03?ooool2o`00063ooooo00?o0000ooooooooool0X_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo00gooooo0_l0001O
ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01
ooooo`008?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Nooooo`03
oeEEEOmVIVKo000001;ooooo0_l000000ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
000fooooo`;o0000F?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003Sooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00>Oooool0
1?l0003oooooooooool0001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool02Ooo
ool1o`00007ooooo0Oooool003[ooooo0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000
ooooooooool02?ooool1o`00007ooooo0Oooool003cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o
0000DOooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo000oooooo`03o`000?oooooo000004kooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool1ooooo`00@?ooool2o`0004kooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o0000
ooooooooool0[_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00
007ooooo0014ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`00A_ooool2o`0004Sooooo00?o0000ooooooooool0
/?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`0004Oooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool00016ooooo`03o`000?oooooooooo
0;;ooooo00Go0000ooooooooooooooooo`000001ooooo`00:_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o0000@oooool00ol0003oooooooooo`2c
ooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0/ooo
ool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0]?ooool00ol0003oooooooooo`01o`000000<_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool02?ooool2o`00043ooooo00?o0000ooooooooool0]Oooool1o`00007o
oooo0Ol0000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[o
oooo0_l0000nooooo`03o`000?oooooooooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00002_ooool2o`0003gooooo00?o0000ooooooooool0]Oooool3o`000000
Doooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool0/?ooool5o`0000?o
oooo001Dooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0[?ooool4o`0000So
oooo001Eooooo`?o0000>?ooool00ol0003oooooooooo`2Xooooo`Co00003?ooool005Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0000e
ooooo`03o`000?oooooooooo0:3ooooo1?l0000Eooooo`00F_ooool00ol0003oooooo`00000boooo
o`03o`000?oooooooooo09cooooo1?l0000Iooooo`00Foooool2o`0003;ooooo00?o0000oooooooo
ool0Uoooool5o`0001gooooo001Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Toooool4o`0002;ooooo001Nooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0
S_ooool5o`0002Kooooo001Oooooo`?o0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000:ooo
ool0067ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000;oooool0
05?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o0000:oooool00ol0003oooooooooo`21
ooooo`Go0000<oooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
000002Sooooo00?o0000ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?oooooooooo
ooooool@41003Oooool2o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo001Coooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo07Cooooo1Ol00010ooooo`00Doooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000
oooooooooooo00008oooool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go410@
oooooooooooooooooa0@400Aooooo`?o00008oooool00ol0003oooooooooo`1[ooooo`Go0000BOoo
ool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00008oooool00ol0003ooooooooo
o`1Wooooo`Co0000C_ooool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?o
ooooo`000?ooool07_ooool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0000O
ooooo`03o`000?oooooooooo05kooooo1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05[ooooo1?l0001Kooooo`00L?ooool2o`0001gooooo00?o0000oooooooo
ool0E_ooool4o`0005oooooo001booooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0
DOooool5o`0006?ooooo001cooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000J?oo
ool007Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000K?ooool0
07Kooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`oooo
o`00N?ooool2o`0001Gooooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0>oooool5o`0007Wooooo001jooooo`;o000000?o
ooooo`000?ooool04?ooool00ol0003oooooooooo`0gooooo`Co0000O_ooool006?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo
0_l0000Aooooo`03o`000?oooooooooo03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03o`00
0?oooooooooo02oooooo1Ol00026ooooo`00Hoooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo
1?l0002;ooooo`00Hoooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1_ooool3o`0000_ooooo00?o0000ooooooooool09oooool4o`0008oooooo001Sooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Rooooo`Go0000Toooool006?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`0Nooooo`Co0000V?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00gooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1Ol0002Loooo
o`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0003o
ooooooooo`0Aooooo`Co0000YOooool008Wooooo0_l00003ooooo`03o`000?oooooooooo00cooooo
1Ol0002Yooooo`00R_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002^ooooo`00Rooo
ool2o`000003ooooool0003ooooo00Gooooo1?l0002booooo`00SOooool2o`000003ooooool0003o
000000?o0000]_ooool008kooooo0_l0002kooooo`00oooooom<ooooo`00oooooom<ooooo`00Q?oo
ool4o`000003oa0@4?oooooooooo0<3ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026oooo
o`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`00
0?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooo
oooo0<;ooooo0024ooooo`03oeEEEOmVIVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48803 .51066 m .48098 .55168 L .54163 .55469 L p .718 .606 .731 r
F P
0 g
s
.54163 .55469 m .53926 .51326 L .48803 .51066 L p .718 .606 .731 r
F P
0 g
s
.54359 .59595 m .54163 .55469 L .48098 .55168 L p .72 .583 .701 r
F P
0 g
s
.53926 .51326 m .54163 .55469 L .60094 .54566 L p .672 .571 .733 r
F P
0 g
s
.54163 .55469 m .54359 .59595 L .61054 .58601 L p .668 .542 .703 r
F P
0 g
s
.61054 .58601 m .60094 .54566 L .54163 .55469 L p .668 .542 .703 r
F P
0 g
s
.48098 .55168 m .47517 .59264 L .54359 .59595 L p .72 .583 .701 r
F P
0 g
s
.54512 .63636 m .54359 .59595 L .47517 .59264 L p .72 .559 .67 r
F P
0 g
s
.54359 .59595 m .54512 .63636 L .61806 .62579 L p .662 .513 .672 r
F P
0 g
s
.61806 .62579 m .61054 .58601 L .54359 .59595 L p .662 .513 .672 r
F P
0 g
s
.44029 .49784 m .42433 .53684 L .48098 .55168 L p .761 .648 .736 r
F P
0 g
s
.48098 .55168 m .48803 .51066 L .44029 .49784 L p .761 .648 .736 r
F P
0 g
s
.47517 .59264 m .48098 .55168 L .42433 .53684 L p .769 .629 .706 r
F P
0 g
s
.49623 .47042 m .48803 .51066 L .53926 .51326 L p .714 .63 .762 r
F P
0 g
s
.53926 .51326 m .53649 .47251 L .49623 .47042 L p .714 .63 .762 r
F P
0 g
s
.53649 .47251 m .53926 .51326 L .58931 .50545 L p .675 .6 .764 r
F P
0 g
s
.60094 .54566 m .58931 .50545 L .53926 .51326 L p .672 .571 .733 r
F P
0 g
s
.42433 .53684 m .41113 .57628 L .47517 .59264 L p .769 .629 .706 r
F P
0 g
s
.47063 .63284 m .47517 .59264 L .41113 .57628 L p .775 .609 .674 r
F P
0 g
s
.47517 .59264 m .47063 .63284 L .54512 .63636 L p .72 .559 .67 r
F P
0 g
s
.54622 .67537 m .54512 .63636 L .47063 .63284 L p .719 .534 .638 r
F P
0 g
s
.54512 .63636 m .54622 .67537 L .62347 .66445 L p .656 .483 .639 r
F P
0 g
s
.62347 .66445 m .61806 .62579 L .54512 .63636 L p .656 .483 .639 r
F P
0 g
s
.45883 .46013 m .44029 .49784 L .48803 .51066 L p .75 .666 .768 r
F P
0 g
s
.48803 .51066 m .49623 .47042 L .45883 .46013 L p .75 .666 .768 r
F P
0 g
s
.58931 .50545 m .60094 .54566 L .65358 .52521 L p .621 .54 .742 r
F P
0 g
s
.60094 .54566 m .61054 .58601 L .67019 .56344 L p .608 .505 .71 r
F P
0 g
s
.67019 .56344 m .65358 .52521 L .60094 .54566 L p .608 .505 .71 r
F P
0 g
s
.41113 .57628 m .40078 .61545 L .47063 .63284 L p .775 .609 .674 r
F P
0 g
s
.46736 .67174 m .47063 .63284 L .40078 .61545 L p .78 .588 .64 r
F P
0 g
s
.47063 .63284 m .46736 .67174 L .54622 .67537 L p .719 .534 .638 r
F P
0 g
s
.61054 .58601 m .61806 .62579 L .68322 .60177 L p .595 .468 .678 r
F P
0 g
s
.68322 .60177 m .67019 .56344 L .61054 .58601 L p .595 .468 .678 r
F P
0 g
s
.58931 .50545 m .57578 .46624 L .53649 .47251 L p .675 .6 .764 r
F P
0 g
s
.57578 .46624 m .58931 .50545 L .63355 .48781 L p .633 .576 .773 r
F P
0 g
s
.65358 .52521 m .63355 .48781 L .58931 .50545 L p .621 .54 .742 r
F P
0 g
s
.50547 .43198 m .49623 .47042 L .53649 .47251 L p .708 .655 .795 r
F P
0 g
s
.53649 .47251 m .53336 .43346 L .50547 .43198 L p .708 .655 .795 r
F P
0 g
s
.53336 .43346 m .53649 .47251 L .57578 .46624 L p .678 .632 .797 r
F P
0 g
s
.47965 .42471 m .45883 .46013 L .49623 .47042 L p .736 .684 .8 r
F P
0 g
s
.49623 .47042 m .50547 .43198 L .47965 .42471 L p .736 .684 .8 r
F P
0 g
s
.54689 .71255 m .54622 .67537 L .46736 .67174 L p .717 .507 .604 r
F P
0 g
s
.54622 .67537 m .54689 .71255 L .62674 .70153 L p .647 .451 .603 r
F P
0 g
s
.62674 .70153 m .62347 .66445 L .54622 .67537 L p .647 .451 .603 r
F P
0 g
s
.61806 .62579 m .62347 .66445 L .69262 .6396 L p .58 .43 .642 r
F P
0 g
s
.69262 .6396 m .68322 .60177 L .61806 .62579 L p .58 .43 .642 r
F P
0 g
s
.4006 .47577 m .37693 .51121 L .42433 .53684 L p .802 .698 .749 r
F P
0 g
s
.42433 .53684 m .44029 .49784 L .4006 .47577 L p .802 .698 .749 r
F P
0 g
s
.41113 .57628 m .42433 .53684 L .37693 .51121 L p .818 .685 .717 r
F P
0 g
s
.42796 .44249 m .4006 .47577 L .44029 .49784 L p .784 .709 .781 r
F P
0 g
s
.44029 .49784 m .45883 .46013 L .42796 .44249 L p .784 .709 .781 r
F P
0 g
s
.57578 .46624 m .56056 .42902 L .53336 .43346 L p .678 .632 .797 r
F P
0 g
s
.56056 .42902 m .57578 .46624 L .61034 .45211 L p .644 .615 .805 r
F P
0 g
s
.63355 .48781 m .61034 .45211 L .57578 .46624 L p .633 .576 .773 r
F P
0 g
s
.40078 .61545 m .39333 .65375 L .46736 .67174 L p .78 .588 .64 r
F P
0 g
s
.46538 .70888 m .46736 .67174 L .39333 .65375 L p .783 .564 .603 r
F P
0 g
s
.46736 .67174 m .46538 .70888 L .54689 .71255 L p .717 .507 .604 r
F P
0 g
s
.37693 .51121 m .35726 .54794 L .41113 .57628 L p .818 .685 .717 r
F P
0 g
s
.40078 .61545 m .41113 .57628 L .35726 .54794 L p .831 .67 .683 r
F P
0 g
s
.45851 .41231 m .42796 .44249 L .45883 .46013 L p .761 .718 .812 r
F P
0 g
s
.45883 .46013 m .47965 .42471 L .45851 .41231 L p .761 .718 .812 r
F P
0 g
s
.35726 .54794 m .34179 .58524 L .40078 .61545 L p .831 .67 .683 r
F P
0 g
s
.39333 .65375 m .40078 .61545 L .34179 .58524 L p .843 .652 .645 r
F P
0 g
s
.62347 .66445 m .62674 .70153 L .69831 .67642 L p .563 .389 .603 r
F P
0 g
s
.69831 .67642 m .69262 .6396 L .62347 .66445 L p .563 .389 .603 r
F P
0 g
s
.51558 .39647 m .50547 .43198 L .53336 .43346 L p .699 .683 .831 r
F P
0 g
s
.53336 .43346 m .52995 .39725 L .51558 .39647 L p .699 .683 .831 r
F P
0 g
s
.52995 .39725 m .53336 .43346 L .56056 .42902 L p .678 .667 .832 r
F P
0 g
s
.61034 .45211 m .63355 .48781 L .6676 .46174 L p .584 .558 .791 r
F P
0 g
s
.63355 .48781 m .65358 .52521 L .69446 .49484 L p .56 .513 .759 r
F P
0 g
s
.69446 .49484 m .6676 .46174 L .63355 .48781 L p .56 .513 .759 r
F P
0 g
s
.65358 .52521 m .67019 .56344 L .71683 .52979 L p .536 .467 .726 r
F P
0 g
s
.71683 .52979 m .69446 .49484 L .65358 .52521 L p .536 .467 .726 r
F P
0 g
s
.50233 .39266 m .47965 .42471 L .50547 .43198 L p .717 .702 .835 r
F P
0 g
s
.50547 .43198 m .51558 .39647 L .50233 .39266 L p .717 .702 .835 r
F P
0 g
s
.54711 .74746 m .54689 .71255 L .46538 .70888 L p .713 .475 .564 r
F P
0 g
s
.54689 .71255 m .54711 .74746 L .62784 .73657 L p .637 .414 .563 r
F P
0 g
s
.62784 .73657 m .62674 .70153 L .54689 .71255 L p .637 .414 .563 r
F P
0 g
s
.56056 .42902 m .54393 .39492 L .52995 .39725 L p .678 .667 .832 r
F P
0 g
s
.54393 .39492 m .56056 .42902 L .58434 .41906 L p .656 .656 .839 r
F P
0 g
s
.61034 .45211 m .58434 .41906 L .56056 .42902 L p .644 .615 .805 r
F P
0 g
s
.58434 .41906 m .61034 .45211 L .63666 .43133 L p .608 .604 .821 r
F P
0 g
s
.6676 .46174 m .63666 .43133 L .61034 .45211 L p .584 .558 .791 r
F P
0 g
s
.67019 .56344 m .68322 .60177 L .73447 .56583 L p .509 .419 .689 r
F P
0 g
s
.73447 .56583 m .71683 .52979 L .67019 .56344 L p .509 .419 .689 r
F P
0 g
s
.39333 .65375 m .38882 .69072 L .46538 .70888 L p .783 .564 .603 r
F P
0 g
s
.46472 .74384 m .46538 .70888 L .38882 .69072 L p .784 .535 .56 r
F P
0 g
s
.46538 .70888 m .46472 .74384 L .54711 .74746 L p .713 .475 .564 r
F P
0 g
s
.49158 .3862 m .45851 .41231 L .47965 .42471 L p .732 .725 .844 r
F P
0 g
s
.47965 .42471 m .50233 .39266 L .49158 .3862 L p .732 .725 .844 r
F P
0 g
s
.34179 .58524 m .33062 .62247 L .39333 .65375 L p .843 .652 .645 r
F P
0 g
s
.38882 .69072 m .39333 .65375 L .33062 .62247 L p .852 .63 .601 r
F P
0 g
s
.40688 .41906 m .37311 .44627 L .4006 .47577 L p .813 .76 .803 r
F P
0 g
s
.4006 .47577 m .42796 .44249 L .40688 .41906 L p .813 .76 .803 r
F P
0 g
s
.37693 .51121 m .4006 .47577 L .37311 .44627 L p .842 .76 .772 r
F P
0 g
s
.58434 .41906 m .55609 .38971 L .54393 .39492 L p .656 .656 .839 r
F P
0 g
s
.55609 .38971 m .58434 .41906 L .60224 .4045 L p .633 .651 .85 r
F P
0 g
s
.63666 .43133 m .60224 .4045 L .58434 .41906 L p .608 .604 .821 r
F P
0 g
s
.44431 .39596 m .40688 .41906 L .42796 .44249 L p .781 .757 .832 r
F P
0 g
s
.42796 .44249 m .45851 .41231 L .44431 .39596 L p .781 .757 .832 r
F P
0 g
s
.68322 .60177 m .69262 .6396 L .74722 .60234 L p .48 .367 .647 r
F P
0 g
s
.74722 .60234 m .73447 .56583 L .68322 .60177 L p .48 .367 .647 r
F P
0 g
s
.37311 .44627 m .34369 .47674 L .37693 .51121 L p .842 .76 .772 r
F P
0 g
s
.35726 .54794 m .37693 .51121 L .34369 .47674 L p .868 .756 .737 r
F P
0 g
s
.62674 .70153 m .62784 .73657 L .70022 .71176 L p .543 .341 .556 r
F P
0 g
s
.70022 .71176 m .69831 .67642 L .62674 .70153 L p .543 .341 .556 r
F P
0 g
s
.48449 .37774 m .44431 .39596 L .45851 .41231 L p .743 .75 .858 r
F P
0 g
s
.45851 .41231 m .49158 .3862 L .48449 .37774 L p .743 .75 .858 r
F P
0 g
s
.52995 .39725 m .52632 .36507 L .51558 .39647 L closepath p .683 .713 .871 r
F P
0 g
s
.54393 .39492 m .52632 .36507 L .52995 .39725 L closepath p .675 .707 .872 r
F P
0 g
s
.51558 .39647 m .52632 .36507 L .50233 .39266 L closepath p .69 .721 .873 r
F P
0 g
s
.54687 .77963 m .54711 .74746 L .46472 .74384 L p .706 .437 .515 r
F P
0 g
s
.54711 .74746 m .54687 .77963 L .62666 .7691 L p .623 .369 .513 r
F P
0 g
s
.62666 .7691 m .62784 .73657 L .54711 .74746 L p .623 .369 .513 r
F P
0 g
s
.34369 .47674 m .3191 .50966 L .35726 .54794 L p .868 .756 .737 r
F P
0 g
s
.34179 .58524 m .35726 .54794 L .3191 .50966 L p .891 .748 .697 r
F P
0 g
s
.55609 .38971 m .52632 .36507 L .54393 .39492 L closepath p .666 .704 .875 r
F P
0 g
s
.60224 .4045 m .63666 .43133 L .6518 .40578 L p .569 .6 .844 r
F P
0 g
s
.63666 .43133 m .6676 .46174 L .68761 .42945 L p .528 .546 .818 r
F P
0 g
s
.68761 .42945 m .6518 .40578 L .63666 .43133 L p .528 .546 .818 r
F P
0 g
s
.50233 .39266 m .52632 .36507 L .49158 .3862 L closepath p .695 .729 .877 r
F P
0 g
s
.38882 .69072 m .38731 .7259 L .46472 .74384 L p .784 .535 .56 r
F P
0 g
s
.46543 .77612 m .46472 .74384 L .38731 .7259 L p .782 .499 .508 r
F P
0 g
s
.46472 .74384 m .46543 .77612 L .54687 .77963 L p .706 .437 .515 r
F P
0 g
s
.6676 .46174 m .69446 .49484 L .71894 .45699 L p .483 .489 .787 r
F P
0 g
s
.71894 .45699 m .68761 .42945 L .6676 .46174 L p .483 .489 .787 r
F P
0 g
s
.69262 .6396 m .69831 .67642 L .75497 .63874 L p .446 .307 .599 r
F P
0 g
s
.75497 .63874 m .74722 .60234 L .69262 .6396 L p .446 .307 .599 r
F P
0 g
s
.33062 .62247 m .32385 .6591 L .38882 .69072 L p .852 .63 .601 r
F P
0 g
s
.38731 .7259 m .38882 .69072 L .32385 .6591 L p .859 .603 .55 r
F P
0 g
s
.56513 .38215 m .52632 .36507 L .55609 .38971 L closepath p .658 .702 .879 r
F P
0 g
s
.60224 .4045 m .56513 .38215 L .55609 .38971 L p .633 .651 .85 r
F P
0 g
s
.56513 .38215 m .60224 .4045 L .61228 .38674 L p .61 .652 .867 r
F P
0 g
s
.6518 .40578 m .61228 .38674 L .60224 .4045 L p .569 .6 .844 r
F P
0 g
s
.49158 .3862 m .52632 .36507 L .48449 .37774 L closepath p .698 .738 .882 r
F P
0 g
s
.69446 .49484 m .71683 .52979 L .74519 .48764 L p .435 .426 .75 r
F P
0 g
s
.74519 .48764 m .71894 .45699 L .69446 .49484 L p .435 .426 .75 r
F P
0 g
s
.3191 .50966 m .29967 .54429 L .34179 .58524 L p .891 .748 .697 r
F P
0 g
s
.33062 .62247 m .34179 .58524 L .29967 .54429 L p .912 .735 .65 r
F P
0 g
s
.62784 .73657 m .62666 .7691 L .69818 .74511 L p .517 .283 .499 r
F P
0 g
s
.69818 .74511 m .70022 .71176 L .62784 .73657 L p .517 .283 .499 r
F P
0 g
s
.57006 .373 m .52632 .36507 L .56513 .38215 L closepath p .651 .704 .886 r
F P
0 g
s
.61228 .38674 m .57006 .373 L .56513 .38215 L p .61 .652 .867 r
F P
0 g
s
.48186 .36815 m .43873 .37726 L .44431 .39596 L p .747 .776 .877 r
F P
0 g
s
.44431 .39596 m .48449 .37774 L .48186 .36815 L p .747 .776 .877 r
F P
0 g
s
.40688 .41906 m .44431 .39596 L .43873 .37726 L p .792 .801 .859 r
F P
0 g
s
.43873 .37726 m .39816 .39205 L .40688 .41906 L p .792 .801 .859 r
F P
0 g
s
.37311 .44627 m .40688 .41906 L .39816 .39205 L p .835 .821 .836 r
F P
0 g
s
.48449 .37774 m .52632 .36507 L .48186 .36815 L closepath p .698 .747 .889 r
F P
0 g
s
.71683 .52979 m .73447 .56583 L .766 .52065 L p .381 .356 .705 r
F P
0 g
s
.766 .52065 m .74519 .48764 L .71683 .52979 L p .381 .356 .705 r
F P
0 g
s
.39816 .39205 m .36123 .41199 L .37311 .44627 L p .835 .821 .836 r
F P
0 g
s
.34369 .47674 m .37311 .44627 L .36123 .41199 L p .875 .837 .805 r
F P
0 g
s
.69831 .67642 m .70022 .71176 L .75756 .67451 L p .404 .237 .538 r
F P
0 g
s
.75756 .67451 m .75497 .63874 L .69831 .67642 L p .404 .237 .538 r
F P
0 g
s
.57028 .36323 m .52632 .36507 L .57006 .373 L closepath p .645 .708 .893 r
F P
0 g
s
.57006 .373 m .61228 .38674 L .61315 .36759 L p .589 .661 .888 r
F P
0 g
s
.61315 .36759 m .57028 .36323 L .57006 .373 L p .589 .661 .888 r
F P
0 g
s
.54615 .80845 m .54687 .77963 L .46543 .77612 L p .694 .387 .453 r
F P
0 g
s
.54687 .77963 m .54615 .80845 L .6231 .79849 L p .602 .312 .448 r
F P
0 g
s
.6231 .79849 m .62666 .7691 L .54687 .77963 L p .602 .312 .448 r
F P
0 g
s
.61228 .38674 m .6518 .40578 L .65368 .37798 L p .528 .607 .876 r
F P
0 g
s
.65368 .37798 m .61315 .36759 L .61228 .38674 L p .528 .607 .876 r
F P
0 g
s
.29967 .54429 m .28559 .57995 L .33062 .62247 L p .912 .735 .65 r
F P
0 g
s
.32385 .6591 m .33062 .62247 L .28559 .57995 L p .929 .716 .592 r
F P
0 g
s
.55677 .34605 m .52632 .36507 L .5657 .3539 L closepath p .642 .724 .908 r
F P
0 g
s
.54442 .34057 m .52632 .36507 L .55677 .34605 L closepath p .645 .733 .913 r
F P
0 g
s
.53003 .3381 m .52632 .36507 L .54442 .34057 L closepath p .651 .743 .917 r
F P
0 g
s
.49088 .34975 m .52632 .36507 L .50166 .34298 L closepath p .68 .759 .911 r
F P
0 g
s
.48405 .35847 m .52632 .36507 L .49088 .34975 L closepath p .689 .758 .904 r
F P
0 g
s
.48186 .36815 m .52632 .36507 L .48405 .35847 L closepath p .695 .753 .897 r
F P
0 g
s
.5657 .3539 m .52632 .36507 L .57028 .36323 L closepath p .642 .715 .901 r
F P
0 g
s
.51522 .33894 m .52632 .36507 L .53003 .3381 L closepath p .66 .751 .918 r
F P
0 g
s
.50166 .34298 m .52632 .36507 L .51522 .33894 L closepath p .67 .757 .915 r
F P
0 g
s
.32385 .6591 m .32158 .69464 L .38731 .7259 L p .859 .603 .55 r
F P
0 g
s
.38893 .75877 m .38731 .7259 L .32158 .69464 L p .862 .565 .484 r
F P
0 g
s
.38731 .7259 m .38893 .75877 L .46543 .77612 L p .782 .499 .508 r
F P
0 g
s
.43873 .37726 m .48186 .36815 L .48405 .35847 L p .741 .8 .899 r
F P
0 g
s
.46758 .80514 m .46543 .77612 L .38893 .75877 L p .776 .451 .439 r
F P
0 g
s
.46543 .77612 m .46758 .80514 L .54615 .80845 L p .694 .387 .453 r
F P
0 g
s
.6518 .40578 m .68761 .42945 L .69074 .39402 L p .458 .544 .856 r
F P
0 g
s
.69074 .39402 m .65368 .37798 L .6518 .40578 L p .458 .544 .856 r
F P
0 g
s
.36123 .41199 m .3288 .43642 L .34369 .47674 L p .875 .837 .805 r
F P
0 g
s
.3191 .50966 m .34369 .47674 L .3288 .43642 L p .913 .848 .766 r
F P
0 g
s
.73447 .56583 m .74722 .60234 L .78111 .55535 L p .319 .274 .65 r
F P
0 g
s
.78111 .55535 m .766 .52065 L .73447 .56583 L p .319 .274 .65 r
F P
0 g
s
.57028 .36323 m .61315 .36759 L .60449 .34912 L p .573 .678 .911 r
F P
0 g
s
.60449 .34912 m .5657 .3539 L .57028 .36323 L p .573 .678 .911 r
F P
0 g
s
.48405 .35847 m .44262 .35818 L .43873 .37726 L p .741 .8 .899 r
F P
0 g
s
.39816 .39205 m .43873 .37726 L .44262 .35818 L p .789 .845 .894 r
F P
0 g
s
.62666 .7691 m .6231 .79849 L .69198 .77583 L p .48 .207 .422 r
F P
0 g
s
.69198 .77583 m .69818 .74511 L .62666 .7691 L p .48 .207 .422 r
F P
0 g
s
.44262 .35818 m .48405 .35847 L .49088 .34975 L p .724 .817 .922 r
F P
0 g
s
.68761 .42945 m .71894 .45699 L .72341 .41517 L p .377 .467 .826 r
F P
0 g
s
.72341 .41517 m .69074 .39402 L .68761 .42945 L p .377 .467 .826 r
F P
0 g
s
.3288 .43642 m .30152 .46462 L .3191 .50966 L p .913 .848 .766 r
F P
0 g
s
.29967 .54429 m .3191 .50966 L .30152 .46462 L p .948 .852 .713 r
F P
0 g
s
.5657 .3539 m .60449 .34912 L .587 .33342 L p .565 .703 .934 r
F P
0 g
s
.587 .33342 m .55677 .34605 L .5657 .3539 L p .565 .703 .934 r
F P
0 g
s
.44262 .35818 m .40327 .36422 L .39816 .39205 L p .789 .845 .894 r
F P
0 g
s
.36123 .41199 m .39816 .39205 L .40327 .36422 L p .836 .888 .878 r
F P
0 g
s
.61315 .36759 m .65368 .37798 L .6415 .35091 L p .487 .626 .913 r
F P
0 g
s
.6415 .35091 m .60449 .34912 L .61315 .36759 L p .487 .626 .913 r
F P
0 g
s
.28559 .57995 m .27703 .61607 L .32385 .6591 L p .929 .716 .592 r
F P
0 g
s
.32158 .69464 m .32385 .6591 L .27703 .61607 L p .943 .686 .519 r
F P
0 g
s
.70022 .71176 m .69818 .74511 L .75478 .7091 L p .352 .15 .46 r
F P
0 g
s
.75478 .7091 m .75756 .67451 L .70022 .71176 L p .352 .15 .46 r
F P
0 g
s
.45583 .34083 m .49088 .34975 L .50166 .34298 L p .696 .824 .944 r
F P
0 g
s
.49088 .34975 m .45583 .34083 L .44262 .35818 L p .724 .817 .922 r
F P
0 g
s
.74722 .60234 m .75497 .63874 L .79031 .59113 L p .244 .176 .578 r
F P
0 g
s
.79031 .59113 m .78111 .55535 L .74722 .60234 L p .244 .176 .578 r
F P
0 g
s
.55677 .34605 m .587 .33342 L .5625 .3224 L p .569 .734 .953 r
F P
0 g
s
.5625 .3224 m .54442 .34057 L .55677 .34605 L p .569 .734 .953 r
F P
0 g
s
.32158 .69464 m .32401 .72856 L .38893 .75877 L p .862 .565 .484 r
F P
0 g
s
.39384 .78874 m .38893 .75877 L .32401 .72856 L p .858 .512 .395 r
F P
0 g
s
.38893 .75877 m .39384 .78874 L .46758 .80514 L p .776 .451 .439 r
F P
0 g
s
.71894 .45699 m .74519 .48764 L .75099 .44078 L p .279 .374 .781 r
F P
0 g
s
.75099 .44078 m .72341 .41517 L .71894 .45699 L p .279 .374 .781 r
F P
0 g
s
.54491 .83314 m .54615 .80845 L .46758 .80514 L p .672 .318 .365 r
F P
0 g
s
.54615 .80845 m .54491 .83314 L .617 .82397 L p .569 .232 .358 r
F P
0 g
s
.617 .82397 m .6231 .79849 L .54615 .80845 L p .569 .232 .358 r
F P
0 g
s
.40327 .36422 m .44262 .35818 L .45583 .34083 L p .761 .881 .932 r
F P
0 g
s
.4771 .32725 m .50166 .34298 L .51522 .33894 L p .658 .817 .96 r
F P
0 g
s
.50166 .34298 m .4771 .32725 L .45583 .34083 L p .696 .824 .944 r
F P
0 g
s
.54442 .34057 m .5625 .3224 L .53375 .31741 L p .587 .767 .965 r
F P
0 g
s
.53375 .31741 m .53003 .3381 L .54442 .34057 L p .587 .767 .965 r
F P
0 g
s
.40327 .36422 m .36712 .37637 L .36123 .41199 L p .836 .888 .878 r
F P
0 g
s
.3288 .43642 m .36123 .41199 L .36712 .37637 L p .882 .927 .847 r
F P
0 g
s
.47127 .83009 m .46758 .80514 L .39384 .78874 L p .758 .382 .341 r
F P
0 g
s
.46758 .80514 m .47127 .83009 L .54491 .83314 L p .672 .318 .365 r
F P
0 g
s
.30152 .46462 m .27985 .49589 L .29967 .54429 L p .948 .852 .713 r
F P
0 g
s
.28559 .57995 m .29967 .54429 L .27985 .49589 L p .978 .845 .643 r
F P
0 g
s
.50411 .3191 m .51522 .33894 L .53003 .3381 L p .619 .797 .967 r
F P
0 g
s
.51522 .33894 m .50411 .3191 L .4771 .32725 L p .658 .817 .96 r
F P
0 g
s
.65368 .37798 m .69074 .39402 L .67565 .35922 L p .374 .553 .902 r
F P
0 g
s
.67565 .35922 m .6415 .35091 L .65368 .37798 L p .374 .553 .902 r
F P
0 g
s
.53003 .3381 m .53375 .31741 L .50411 .3191 L p .619 .797 .967 r
F P
0 g
s
.60449 .34912 m .6415 .35091 L .61609 .32771 L p .453 .661 .951 r
F P
0 g
s
.61609 .32771 m .587 .33342 L .60449 .34912 L p .453 .661 .951 r
F P
0 g
s
.27703 .61607 m .27417 .65209 L .32158 .69464 L p .943 .686 .519 r
F P
0 g
s
.32401 .72856 m .32158 .69464 L .27417 .65209 L p .947 .639 .42 r
F P
0 g
s
.6231 .79849 m .617 .82397 L .68138 .80313 L p .425 .102 .312 r
F P
0 g
s
.68138 .80313 m .69198 .77583 L .6231 .79849 L p .425 .102 .312 r
F P
0 g
s
.74519 .48764 m .766 .52065 L .77298 .47017 L p .159 .255 .715 r
F P
0 g
s
.77298 .47017 m .75099 .44078 L .74519 .48764 L p .159 .255 .715 r
F P
0 g
s
.69818 .74511 m .69198 .77583 L .74635 .74186 L p .279 .034 .352 r
F P
0 g
s
.74635 .74186 m .75478 .7091 L .69818 .74511 L p .279 .034 .352 r
F P
0 g
s
.75497 .63874 m .75756 .67451 L .79339 .62742 L p .15 .054 .481 r
F P
0 g
s
.79339 .62742 m .79031 .59113 L .75497 .63874 L p .15 .054 .481 r
F P
0 g
s
.42224 .33869 m .45583 .34083 L .4771 .32725 L p .702 .896 .967 r
F P
0 g
s
.45583 .34083 m .42224 .33869 L .40327 .36422 L p .761 .881 .932 r
F P
0 g
s
.36712 .37637 m .40327 .36422 L .42224 .33869 L p .793 .944 .923 r
F P
0 g
s
.36712 .37637 m .33512 .39421 L .3288 .43642 L p .882 .927 .847 r
F P
0 g
s
.30152 .46462 m .3288 .43642 L .33512 .39421 L p .922 .955 .792 r
F P
0 g
s
.27985 .49589 m .26408 .52953 L .28559 .57995 L p .978 .845 .643 r
F P
0 g
s
.27703 .61607 m .28559 .57995 L .26408 .52953 L p .997 .822 .545 r
F P
0 g
s
.69074 .39402 m .72341 .41517 L .706 .37378 L p .221 .446 .866 r
F P
0 g
s
.706 .37378 m .67565 .35922 L .69074 .39402 L p .221 .446 .866 r
F P
0 g
s
.587 .33342 m .61609 .32771 L .57999 .31131 L p .439 .71 .98 r
F P
0 g
s
.57999 .31131 m .5625 .3224 L .587 .33342 L p .439 .71 .98 r
F P
0 g
s
.32401 .72856 m .33138 .76021 L .39384 .78874 L p .858 .512 .395 r
F P
0 g
s
.40225 .81499 m .39384 .78874 L .33138 .76021 L p .838 .429 .267 r
F P
0 g
s
.39384 .78874 m .40225 .81499 L .47127 .83009 L p .758 .382 .341 r
F P
0 g
s
.766 .52065 m .78111 .55535 L .78901 .50266 L p .01 .104 .616 r
F P
0 g
s
.78901 .50266 m .77298 .47017 L .766 .52065 L p .01 .104 .616 r
F P
0 g
s
.4534 .31854 m .4771 .32725 L .50411 .3191 L p .615 .878 .99 r
F P
0 g
s
.4771 .32725 m .4534 .31854 L .42224 .33869 L p .702 .896 .967 r
F P
0 g
s
.54312 .85272 m .54491 .83314 L .47127 .83009 L p .629 .211 .232 r
F P
0 g
s
.54491 .83314 m .54312 .85272 L .60822 .84455 L p .512 .112 .219 r
F P
0 g
s
.60822 .84455 m .617 .82397 L .54491 .83314 L p .512 .112 .219 r
F P
0 g
s
.6415 .35091 m .67565 .35922 L .64312 .32918 L p .279 .578 .941 r
F P
0 g
s
.64312 .32918 m .61609 .32771 L .6415 .35091 L p .279 .578 .941 r
F P
0 g
s
.47658 .85 m .47127 .83009 L .40225 .81499 L p .717 .271 .191 r
F P
0 g
s
.47127 .83009 m .47658 .85 L .54312 .85272 L p .629 .211 .232 r
F P
0 g
s
.27417 .65209 m .27724 .68744 L .32401 .72856 L p .947 .639 .42 r
F P
0 g
s
.33138 .76021 m .32401 .72856 L .27724 .68744 L p .932 .562 .28 r
F P
0 g
s
.5625 .3224 m .57999 .31131 L .53735 .30386 L p .461 .77 .997 r
F P
0 g
s
.53735 .30386 m .53375 .31741 L .5625 .3224 L p .461 .77 .997 r
F P
0 g
s
.75756 .67451 m .75478 .7091 L .79009 .66361 L p .028 0 .347 r
F P
0 g
s
.79009 .66361 m .79339 .62742 L .75756 .67451 L p .028 0 .347 r
F P
0 g
s
.33512 .39421 m .30802 .41718 L .30152 .46462 L p .922 .955 .792 r
F P
0 g
s
.27985 .49589 m .30152 .46462 L .30802 .41718 L p .944 .961 .696 r
F P
0 g
s
.49335 .30639 m .50411 .3191 L .53375 .31741 L p .525 .831 1 r
F P
0 g
s
.50411 .3191 m .49335 .30639 L .4534 .31854 L p .615 .878 .99 r
F P
0 g
s
.42224 .33869 m .39113 .34342 L .36712 .37637 L p .793 .944 .923 r
F P
0 g
s
.33512 .39421 m .36712 .37637 L .39113 .34342 L p .806 .993 .873 r
F P
0 g
s
.53375 .31741 m .53735 .30386 L .49335 .30639 L p .525 .831 1 r
F P
0 g
s
.72341 .41517 m .75099 .44078 L .73179 .3941 L p .014 .288 .785 r
F P
0 g
s
.73179 .3941 m .706 .37378 L .72341 .41517 L p .014 .288 .785 r
F P
0 g
s
.26408 .52953 m .25446 .56493 L .27703 .61607 L p .997 .822 .545 r
F P
0 g
s
.27417 .65209 m .27703 .61607 L .25446 .56493 L p .995 .769 .408 r
F P
0 g
s
.69198 .77583 m .68138 .80313 L .73197 .77197 L p .173 0 .192 r
F P
0 g
s
.73197 .77197 m .74635 .74186 L .69198 .77583 L p .173 0 .192 r
F P
0 g
s
.617 .82397 m .60822 .84455 L .66617 .82603 L p .334 0 .143 r
F P
0 g
s
.66617 .82603 m .68138 .80313 L .617 .82397 L p .334 0 .143 r
F P
0 g
s
.39113 .34342 m .42224 .33869 L .4534 .31854 L p .675 .955 .95 r
F P
0 g
s
.78111 .55535 m .79031 .59113 L .7988 .53764 L p 0 0 .47 r
F P
0 g
s
.7988 .53764 m .78901 .50266 L .78111 .55535 L p 0 0 .47 r
F P
0 g
s
.61609 .32771 m .64312 .32918 L .59633 .30779 L p .202 .618 .949 r
F P
0 g
s
.59633 .30779 m .57999 .31131 L .61609 .32771 L p .202 .618 .949 r
F P
0 g
s
.33138 .76021 m .34398 .78879 L .40225 .81499 L p .838 .429 .267 r
F P
0 g
s
.41433 .83657 m .40225 .81499 L .34398 .78879 L p .778 .291 .067 r
F P
0 g
s
.40225 .81499 m .41433 .83657 L .47658 .85 L p .717 .271 .191 r
F P
0 g
s
.30802 .41718 m .28635 .44465 L .27985 .49589 L p .944 .961 .696 r
F P
0 g
s
.26408 .52953 m .27985 .49589 L .28635 .44465 L p .927 .921 .541 r
F P
0 g
s
.67565 .35922 m .706 .37378 L .66731 .33779 L p .009 .417 .858 r
F P
0 g
s
.66731 .33779 m .64312 .32918 L .67565 .35922 L p .009 .417 .858 r
F P
0 g
s
.75478 .7091 m .74635 .74186 L .78008 .69903 L p 0 0 .155 r
F P
0 g
s
.78008 .69903 m .79009 .66361 L .75478 .7091 L p 0 0 .155 r
F P
0 g
s
.27724 .68744 m .28656 .72145 L .33138 .76021 L p .932 .562 .28 r
F P
0 g
s
.34398 .78879 m .33138 .76021 L .28656 .72145 L p .873 .432 .074 r
F P
0 g
s
.75099 .44078 m .77298 .47017 L .75247 .41963 L p 0 .065 .629 r
F P
0 g
s
.75247 .41963 m .73179 .3941 L .75099 .44078 L p 0 .065 .629 r
F P
0 g
s
.39113 .34342 m .36338 .35487 L .33512 .39421 L p .806 .993 .873 r
F P
0 g
s
.30802 .41718 m .33512 .39421 L .36338 .35487 L p .765 .984 .739 r
F P
0 g
s
.25446 .56493 m .25123 .60149 L .27417 .65209 L p .995 .769 .408 r
F P
0 g
s
.27724 .68744 m .27417 .65209 L .25123 .60149 L p .949 .667 .215 r
F P
0 g
s
.43131 .31724 m .4534 .31854 L .49335 .30639 L p .486 .889 .941 r
F P
0 g
s
.4534 .31854 m .43131 .31724 L .39113 .34342 L p .675 .955 .95 r
F P
0 g
s
.54076 .86608 m .54312 .85272 L .47658 .85 L p .534 .032 .009 r
F P
0 g
s
.54312 .85272 m .54076 .86608 L .59668 .85913 L p .398 0 0 r
F P
0 g
s
.59668 .85913 m .60822 .84455 L .54312 .85272 L p .398 0 0 r
F P
0 g
s
.79031 .59113 m .79339 .62742 L .80208 .57446 L p 0 0 .263 r
F P
0 g
s
.80208 .57446 m .7988 .53764 L .79031 .59113 L p 0 0 .263 r
F P
0 g
s
.48356 .86377 m .47658 .85 L .41433 .83657 L p .615 .081 0 r
F P
0 g
s
.47658 .85 m .48356 .86377 L .54076 .86608 L p .534 .032 .009 r
F P
0 g
s
.68138 .80313 m .66617 .82603 L .7114 .79843 L p .01 0 0 r
F P
0 g
s
.7114 .79843 m .73197 .77197 L .68138 .80313 L p .01 0 0 r
F P
0 g
s
.57999 .31131 m .59633 .30779 L .54073 .29805 L p .199 .682 .929 r
F P
0 g
s
.54073 .29805 m .53735 .30386 L .57999 .31131 L p .199 .682 .929 r
F P
0 g
s
.36338 .35487 m .39113 .34342 L .43131 .31724 L p .559 .932 .814 r
F P
0 g
s
.48328 .30136 m .49335 .30639 L .53735 .30386 L p .301 .779 .922 r
F P
0 g
s
.49335 .30639 m .48328 .30136 L .43131 .31724 L p .486 .889 .941 r
F P
0 g
s
.60822 .84455 m .59668 .85913 L .64624 .84341 L p .17 0 0 r
F P
0 g
s
.64624 .84341 m .66617 .82603 L .60822 .84455 L p .17 0 0 r
F P
0 g
s
.28635 .44465 m .27052 .47596 L .26408 .52953 L p .927 .921 .541 r
F P
0 g
s
.25446 .56493 m .26408 .52953 L .27052 .47596 L p .84 .805 .315 r
F P
0 g
s
.53735 .30386 m .54073 .29805 L .48328 .30136 L p .301 .779 .922 r
F P
0 g
s
.706 .37378 m .73179 .3941 L .688 .35329 L p 0 .147 .637 r
F P
0 g
s
.688 .35329 m .66731 .33779 L .706 .37378 L p 0 .147 .637 r
F P
0 g
s
.77298 .47017 m .78901 .50266 L .76761 .44973 L p 0 0 .382 r
F P
0 g
s
.76761 .44973 m .75247 .41963 L .77298 .47017 L p 0 0 .382 r
F P
0 g
s
.74635 .74186 m .73197 .77197 L .76305 .73281 L p 0 0 0 r
F P
0 g
s
.76305 .73281 m .78008 .69903 L .74635 .74186 L p 0 0 0 r
F P
0 g
s
.25123 .60149 m .25469 .63858 L .27724 .68744 L p .949 .667 .215 r
F P
0 g
s
.28656 .72145 m .27724 .68744 L .25469 .63858 L p .826 .493 0 r
F P
0 g
s
.36338 .35487 m .33972 .37269 L .30802 .41718 L p .765 .984 .739 r
F P
0 g
s
.28635 .44465 m .30802 .41718 L .33972 .37269 L p .626 .857 .487 r
F P
0 g
s
.64312 .32918 m .66731 .33779 L .61103 .31203 L p 0 .382 .745 r
F P
0 g
s
.61103 .31203 m .59633 .30779 L .64312 .32918 L p 0 .382 .745 r
F P
0 g
s
.34398 .78879 m .36203 .81331 L .41433 .83657 L p .778 .291 .067 r
F P
0 g
s
.43018 .85235 m .41433 .83657 L .36203 .81331 L p .621 .054 0 r
F P
0 g
s
.41433 .83657 m .43018 .85235 L .48356 .86377 L p .615 .081 0 r
F P
0 g
s
.28656 .72145 m .30242 .75329 L .34398 .78879 L p .873 .432 .074 r
F P
0 g
s
.36203 .81331 m .34398 .78879 L .30242 .75329 L p .722 .216 0 r
F P
0 g
s
.79339 .62742 m .79009 .66361 L .79856 .61251 L p 0 0 0 r
F P
0 g
s
.79856 .61251 m .80208 .57446 L .79339 .62742 L p 0 0 0 r
F P
0 g
s
.43131 .31724 m .41148 .32342 L .36338 .35487 L p .559 .932 .814 r
F P
0 g
s
.41148 .32342 m .43131 .31724 L .48328 .30136 L p 0 0 0 r
F P
0 g
s
.27052 .47596 m .26083 .51048 L .25446 .56493 L p .84 .805 .315 r
F P
0 g
s
.25123 .60149 m .25446 .56493 L .26083 .51048 L p 0 0 0 r
F P
0 g
s
.66617 .82603 m .64624 .84341 L .6846 .8201 L p 0 0 0 r
F P
0 g
s
.6846 .8201 m .7114 .79843 L .66617 .82603 L p 0 0 0 r
F P
0 g
s
.33972 .37269 m .36338 .35487 L .41148 .32342 L p 0 0 0 r
F P
0 g
s
.53785 .87206 m .54076 .86608 L .48356 .86377 L p .313 0 0 r
F P
0 g
s
.54076 .86608 m .53785 .87206 L .58242 .86654 L p .16 0 0 r
F P
0 g
s
.58242 .86654 m .59668 .85913 L .54076 .86608 L p .16 0 0 r
F P
0 g
s
.78901 .50266 m .7988 .53764 L .77689 .48377 L p .793 .471 0 r
F P
0 g
s
.77689 .48377 m .76761 .44973 L .78901 .50266 L p .793 .471 0 r
F P
0 g
s
.4922 .87022 m .48356 .86377 L .43018 .85235 L p .366 0 0 r
F P
0 g
s
.48356 .86377 m .4922 .87022 L .53785 .87206 L p .313 0 0 r
F P
0 g
s
.59633 .30779 m .61103 .31203 L .54377 .30025 L p .208 0 0 r
F P
0 g
s
.54377 .30025 m .54073 .29805 L .59633 .30779 L p .208 0 0 r
F P
0 g
s
.25469 .63858 m .26515 .6755 L .28656 .72145 L p .826 .493 0 r
F P
0 g
s
.30242 .75329 m .28656 .72145 L .26515 .6755 L p 0 0 .338 r
F P
0 g
s
.73179 .3941 m .75247 .41963 L .70467 .37523 L p .675 .167 0 r
F P
0 g
s
.70467 .37523 m .688 .35329 L .73179 .3941 L p .675 .167 0 r
F P
0 g
s
.73197 .77197 m .7114 .79843 L .73881 .76391 L p 0 0 0 r
F P
0 g
s
.73881 .76391 m .76305 .73281 L .73197 .77197 L p 0 0 0 r
F P
0 g
s
.33972 .37269 m .32071 .39636 L .28635 .44465 L p .626 .857 .487 r
F P
0 g
s
.27052 .47596 m .28635 .44465 L .32071 .39636 L p 0 0 0 r
F P
0 g
s
.59668 .85913 m .58242 .86654 L .62171 .8541 L p 0 0 0 r
F P
0 g
s
.62171 .8541 m .64624 .84341 L .59668 .85913 L p 0 0 0 r
F P
0 g
s
.47421 .30426 m .48328 .30136 L .54073 .29805 L p .076 0 0 r
F P
0 g
s
.48328 .30136 m .47421 .30426 L .41148 .32342 L p 0 0 0 r
F P
0 g
s
.79009 .66361 m .78008 .69903 L .78791 .65102 L p .798 .785 .284 r
F P
0 g
s
.78791 .65102 m .79856 .61251 L .79009 .66361 L p .798 .785 .284 r
F P
0 g
s
.54073 .29805 m .54377 .30025 L .47421 .30426 L p .076 0 0 r
F P
0 g
s
.30242 .75329 m .32507 .78194 L .36203 .81331 L p .722 .216 0 r
F P
0 g
s
.36203 .81331 m .38561 .83266 L .43018 .85235 L p .621 .054 0 r
F P
0 g
s
.38561 .83266 m .36203 .81331 L .32507 .78194 L p 0 .088 .561 r
F P
0 g
s
.66731 .33779 m .688 .35329 L .62365 .32393 L p .547 0 0 r
F P
0 g
s
.62365 .32393 m .61103 .31203 L .66731 .33779 L p .547 0 0 r
F P
0 g
s
.26083 .51048 m .25758 .54757 L .25123 .60149 L p 0 0 0 r
F P
0 g
s
.25469 .63858 m .25123 .60149 L .25758 .54757 L p 0 0 .239 r
F P
0 g
s
.44974 .86117 m .43018 .85235 L .38561 .83266 L p .294 0 0 r
F P
0 g
s
.43018 .85235 m .44974 .86117 L .4922 .87022 L p .366 0 0 r
F P
0 g
s
.7988 .53764 m .80208 .57446 L .78001 .5211 L p .937 .662 .192 r
F P
0 g
s
.78001 .5211 m .77689 .48377 L .7988 .53764 L p .937 .662 .192 r
F P
0 g
s
.41148 .32342 m .39448 .33692 L .33972 .37269 L p 0 0 0 r
F P
0 g
s
.32071 .39636 m .33972 .37269 L .39448 .33692 L p 0 0 0 r
F P
0 g
s
.39448 .33692 m .41148 .32342 L .47421 .30426 L p .125 0 0 r
F P
0 g
s
.26515 .6755 m .28292 .71136 L .30242 .75329 L p 0 0 .338 r
F P
0 g
s
.32507 .78194 m .30242 .75329 L .28292 .71136 L p 0 .036 .601 r
F P
0 g
s
.64624 .84341 m .62171 .8541 L .6518 .83576 L p .465 .878 .743 r
F P
0 g
s
.6518 .83576 m .6846 .8201 L .64624 .84341 L p .465 .878 .743 r
F P
0 g
s
.32071 .39636 m .30675 .42529 L .27052 .47596 L p 0 0 0 r
F P
0 g
s
.26083 .51048 m .27052 .47596 L .30675 .42529 L p 0 0 .126 r
F P
0 g
s
.75247 .41963 m .76761 .44973 L .71692 .40306 L p .858 .408 .031 r
F P
0 g
s
.71692 .40306 m .70467 .37523 L .75247 .41963 L p .858 .408 .031 r
F P
0 g
s
.78008 .69903 m .76305 .73281 L .76985 .68909 L p .897 .919 .526 r
F P
0 g
s
.76985 .68909 m .78791 .65102 L .78008 .69903 L p .897 .919 .526 r
F P
0 g
s
.7114 .79843 m .6846 .8201 L .70741 .79112 L p .694 .957 .702 r
F P
0 g
s
.70741 .79112 m .73881 .76391 L .7114 .79843 L p .694 .957 .702 r
F P
0 g
s
.53441 .86959 m .53785 .87206 L .4922 .87022 L p .086 .64 .809 r
F P
0 g
s
.53785 .87206 m .53441 .86959 L .56563 .86572 L p .212 .736 .825 r
F P
0 g
s
.56563 .86572 m .58242 .86654 L .53785 .87206 L p .212 .736 .825 r
F P
0 g
s
.25758 .54757 m .26107 .58656 L .25469 .63858 L p 0 0 .239 r
F P
0 g
s
.26515 .6755 m .25469 .63858 L .26107 .58656 L p 0 0 .462 r
F P
0 g
s
.61103 .31203 m .62365 .32393 L .54639 .31047 L p .522 0 0 r
F P
0 g
s
.54639 .31047 m .54377 .30025 L .61103 .31203 L p .522 0 0 r
F P
0 g
s
.50239 .8683 m .4922 .87022 L .44974 .86117 L p .054 .593 .851 r
F P
0 g
s
.4922 .87022 m .50239 .8683 L .53441 .86959 L p .086 .64 .809 r
F P
0 g
s
.32507 .78194 m .3545 .80623 L .38561 .83266 L p 0 .088 .561 r
F P
0 g
s
.38561 .83266 m .41456 .84563 L .44974 .86117 L p .294 0 0 r
F P
0 g
s
.41456 .84563 m .38561 .83266 L .3545 .80623 L p 0 .386 .825 r
F P
0 g
s
.58242 .86654 m .56563 .86572 L .59299 .85702 L p .406 .857 .884 r
F P
0 g
s
.59299 .85702 m .62171 .8541 L .58242 .86654 L p .406 .857 .884 r
F P
0 g
s
.688 .35329 m .70467 .37523 L .63386 .34317 L p .745 .237 .006 r
F P
0 g
s
.63386 .34317 m .62365 .32393 L .688 .35329 L p .745 .237 .006 r
F P
0 g
s
.46641 .31505 m .47421 .30426 L .54377 .30025 L p .383 0 0 r
F P
0 g
s
.47421 .30426 m .46641 .31505 L .39448 .33692 L p .125 0 0 r
F P
0 g
s
.80208 .57446 m .79856 .61251 L .77666 .56105 L p .993 .775 .403 r
F P
0 g
s
.77666 .56105 m .78001 .5211 L .80208 .57446 L p .993 .775 .403 r
F P
0 g
s
.54377 .30025 m .54639 .31047 L .46641 .31505 L p .383 0 0 r
F P
0 g
s
.47272 .86196 m .44974 .86117 L .41456 .84563 L p .114 .585 .915 r
F P
0 g
s
.44974 .86117 m .47272 .86196 L .50239 .8683 L p .054 .593 .851 r
F P
0 g
s
.30675 .42529 m .29819 .45886 L .26083 .51048 L p 0 0 .126 r
F P
0 g
s
.25758 .54757 m .26083 .51048 L .29819 .45886 L p .009 0 .338 r
F P
0 g
s
.28292 .71136 m .30816 .74508 L .32507 .78194 L p 0 .036 .601 r
F P
0 g
s
.3545 .80623 m .32507 .78194 L .30816 .74508 L p 0 .28 .783 r
F P
0 g
s
.76305 .73281 m .73881 .76391 L .74427 .72559 L p .921 .974 .699 r
F P
0 g
s
.74427 .72559 m .76985 .68909 L .76305 .73281 L p .921 .974 .699 r
F P
0 g
s
.39448 .33692 m .38077 .35737 L .32071 .39636 L p 0 0 0 r
F P
0 g
s
.30675 .42529 m .32071 .39636 L .38077 .35737 L p .159 0 .16 r
F P
0 g
s
.76761 .44973 m .77689 .48377 L .72445 .43617 L p .929 .552 .262 r
F P
0 g
s
.72445 .43617 m .71692 .40306 L .76761 .44973 L p .929 .552 .262 r
F P
0 g
s
.6846 .8201 m .6518 .83576 L .66928 .81314 L p .749 .993 .871 r
F P
0 g
s
.66928 .81314 m .70741 .79112 L .6846 .8201 L p .749 .993 .871 r
F P
0 g
s
.26107 .58656 m .2716 .62669 L .26515 .6755 L p 0 0 .462 r
F P
0 g
s
.28292 .71136 m .26515 .6755 L .2716 .62669 L p 0 .1 .623 r
F P
0 g
s
.38077 .35737 m .39448 .33692 L .46641 .31505 L p .332 0 .085 r
F P
0 g
s
.62171 .8541 m .59299 .85702 L .61367 .84428 L p .605 .943 .937 r
F P
0 g
s
.61367 .84428 m .6518 .83576 L .62171 .8541 L p .605 .943 .937 r
F P
0 g
s
.79856 .61251 m .78791 .65102 L .76657 .6028 L p .998 .835 .553 r
F P
0 g
s
.76657 .6028 m .77666 .56105 L .79856 .61251 L p .998 .835 .553 r
F P
0 g
s
.3545 .80623 m .39038 .82491 L .41456 .84563 L p 0 .386 .825 r
F P
0 g
s
.44836 .85112 m .41456 .84563 L .39038 .82491 L p .23 .589 .947 r
F P
0 g
s
.41456 .84563 m .44836 .85112 L .47272 .86196 L p .114 .585 .915 r
F P
0 g
s
.62365 .32393 m .63386 .34317 L .54851 .32844 L p .664 .196 .131 r
F P
0 g
s
.54851 .32844 m .54639 .31047 L .62365 .32393 L p .664 .196 .131 r
F P
0 g
s
.70467 .37523 m .71692 .40306 L .64138 .36927 L p .82 .397 .239 r
F P
0 g
s
.64138 .36927 m .63386 .34317 L .70467 .37523 L p .82 .397 .239 r
F P
0 g
s
.29819 .45886 m .29531 .49641 L .25758 .54757 L p .009 0 .338 r
F P
0 g
s
.26107 .58656 m .25758 .54757 L .29531 .49641 L p .144 .054 .486 r
F P
0 g
s
.73881 .76391 m .70741 .79112 L .71136 .75918 L p .899 .976 .81 r
F P
0 g
s
.71136 .75918 m .74427 .72559 L .73881 .76391 L p .899 .976 .81 r
F P
0 g
s
.53052 .8579 m .53441 .86959 L .50239 .8683 L p .427 .8 .993 r
F P
0 g
s
.53441 .86959 m .53052 .8579 L .54672 .85587 L p .488 .844 .994 r
F P
0 g
s
.54672 .85587 m .56563 .86572 L .53441 .86959 L p .488 .844 .994 r
F P
0 g
s
.30816 .74508 m .34075 .7754 L .3545 .80623 L p 0 .28 .783 r
F P
0 g
s
.39038 .82491 m .3545 .80623 L .34075 .7754 L p .18 .461 .885 r
F P
0 g
s
.51389 .85722 m .50239 .8683 L .47272 .86196 L p .4 .76 .994 r
F P
0 g
s
.50239 .8683 m .51389 .85722 L .53052 .8579 L p .427 .8 .993 r
F P
0 g
s
.2716 .62669 m .28943 .667 L .28292 .71136 L p 0 .1 .623 r
F P
0 g
s
.30816 .74508 m .28292 .71136 L .28943 .667 L p .136 .265 .733 r
F P
0 g
s
.77689 .48377 m .78001 .5211 L .72698 .47391 L p .946 .636 .418 r
F P
0 g
s
.72698 .47391 m .72445 .43617 L .77689 .48377 L p .946 .636 .418 r
F P
0 g
s
.38077 .35737 m .37067 .38425 L .30675 .42529 L p .159 0 .16 r
F P
0 g
s
.29819 .45886 m .30675 .42529 L .37067 .38425 L p .284 .03 .341 r
F P
0 g
s
.56563 .86572 m .54672 .85587 L .56082 .85134 L p .568 .879 .993 r
F P
0 g
s
.56082 .85134 m .59299 .85702 L .56563 .86572 L p .568 .879 .993 r
F P
0 g
s
.4601 .33345 m .46641 .31505 L .54639 .31047 L p .534 .095 .152 r
F P
0 g
s
.46641 .31505 m .4601 .33345 L .38077 .35737 L p .332 0 .085 r
F P
0 g
s
.6518 .83576 m .61367 .84428 L .62536 .8287 L p .739 .954 .945 r
F P
0 g
s
.62536 .8287 m .66928 .81314 L .6518 .83576 L p .739 .954 .945 r
F P
0 g
s
.54639 .31047 m .54851 .32844 L .4601 .33345 L p .534 .095 .152 r
F P
0 g
s
.49853 .85391 m .47272 .86196 L .44836 .85112 L p .407 .726 .99 r
F P
0 g
s
.47272 .86196 m .49853 .85391 L .51389 .85722 L p .4 .76 .994 r
F P
0 g
s
.78791 .65102 m .76985 .68909 L .74952 .64536 L p .977 .862 .659 r
F P
0 g
s
.74952 .64536 m .76657 .6028 L .78791 .65102 L p .977 .862 .659 r
F P
0 g
s
.37067 .38425 m .38077 .35737 L .4601 .33345 L p .442 .099 .286 r
F P
0 g
s
.59299 .85702 m .56082 .85134 L .57132 .84475 L p .645 .895 .984 r
F P
0 g
s
.57132 .84475 m .61367 .84428 L .59299 .85702 L p .645 .895 .984 r
F P
0 g
s
.70741 .79112 m .66928 .81314 L .67173 .78842 L p .853 .95 .878 r
F P
0 g
s
.67173 .78842 m .71136 .75918 L .70741 .79112 L p .853 .95 .878 r
F P
0 g
s
.29531 .49641 m .2984 .53725 L .26107 .58656 L p .144 .054 .486 r
F P
0 g
s
.2716 .62669 m .26107 .58656 L .2984 .53725 L p .245 .187 .591 r
F P
0 g
s
.28943 .667 m .31463 .70631 L .30816 .74508 L p .136 .265 .733 r
F P
0 g
s
.34075 .7754 m .30816 .74508 L .31463 .70631 L p .263 .396 .809 r
F P
0 g
s
.34075 .7754 m .38015 .80094 L .39038 .82491 L p .18 .461 .885 r
F P
0 g
s
.4319 .83679 m .39038 .82491 L .38015 .80094 L p .352 .59 .934 r
F P
0 g
s
.39038 .82491 m .4319 .83679 L .44836 .85112 L p .23 .589 .947 r
F P
0 g
s
.48605 .84828 m .44836 .85112 L .4319 .83679 L p .439 .7 .976 r
F P
0 g
s
.44836 .85112 m .48605 .84828 L .49853 .85391 L p .407 .726 .99 r
F P
0 g
s
.78001 .5211 m .77666 .56105 L .72426 .51557 L p .941 .688 .526 r
F P
0 g
s
.72426 .51557 m .72698 .47391 L .78001 .5211 L p .941 .688 .526 r
F P
0 g
s
.71692 .40306 m .72445 .43617 L .64601 .40165 L p .844 .492 .386 r
F P
0 g
s
.64601 .40165 m .64138 .36927 L .71692 .40306 L p .844 .492 .386 r
F P
0 g
s
.76985 .68909 m .74427 .72559 L .72549 .68747 L p .943 .872 .738 r
F P
0 g
s
.72549 .68747 m .74952 .64536 L .76985 .68909 L p .943 .872 .738 r
F P
0 g
s
.63386 .34317 m .64138 .36927 L .55008 .35371 L p .721 .332 .313 r
F P
0 g
s
.55008 .35371 m .54851 .32844 L .63386 .34317 L p .721 .332 .313 r
F P
0 g
s
.37067 .38425 m .36445 .41696 L .29819 .45886 L p .284 .03 .341 r
F P
0 g
s
.29531 .49641 m .29819 .45886 L .36445 .41696 L p .365 .159 .461 r
F P
0 g
s
.61367 .84428 m .57132 .84475 L .57707 .83677 L p .702 .887 .966 r
F P
0 g
s
.57707 .83677 m .62536 .8287 L .61367 .84428 L p .702 .887 .966 r
F P
0 g
s
.52632 .83667 m .53052 .8579 L .51389 .85722 L closepath p .588 .797 .979 r
F P
0 g
s
.52632 .83667 m .54672 .85587 L .53052 .8579 L closepath p .603 .807 .978 r
F P
0 g
s
.66928 .81314 m .62536 .8287 L .62652 .81185 L p .796 .909 .918 r
F P
0 g
s
.62652 .81185 m .67173 .78842 L .66928 .81314 L p .796 .909 .918 r
F P
0 g
s
.52632 .83667 m .51389 .85722 L .49853 .85391 L closepath p .578 .784 .977 r
F P
0 g
s
.2984 .53725 m .30771 .58054 L .2716 .62669 L p .245 .187 .591 r
F P
0 g
s
.28943 .667 m .2716 .62669 L .30771 .58054 L p .323 .293 .67 r
F P
0 g
s
.45544 .359 m .4601 .33345 L .54851 .32844 L p .604 .24 .325 r
F P
0 g
s
.4601 .33345 m .45544 .359 L .37067 .38425 L p .442 .099 .286 r
F P
0 g
s
.31463 .70631 m .34694 .74321 L .34075 .7754 L p .263 .396 .809 r
F P
0 g
s
.38015 .80094 m .34075 .7754 L .34694 .74321 L p .366 .502 .863 r
F P
0 g
s
.52632 .83667 m .56082 .85134 L .54672 .85587 L closepath p .621 .814 .975 r
F P
0 g
s
.38015 .80094 m .42532 .82036 L .4319 .83679 L p .352 .59 .934 r
F P
0 g
s
.4778 .8409 m .4319 .83679 L .42532 .82036 L p .483 .682 .954 r
F P
0 g
s
.4319 .83679 m .4778 .8409 L .48605 .84828 L p .439 .7 .976 r
F P
0 g
s
.52632 .83667 m .49853 .85391 L .48605 .84828 L closepath p .574 .771 .972 r
F P
0 g
s
.54851 .32844 m .55008 .35371 L .45544 .359 L p .604 .24 .325 r
F P
0 g
s
.36445 .41696 m .37067 .38425 L .45544 .359 L p .505 .218 .413 r
F P
0 g
s
.74427 .72559 m .71136 .75918 L .69478 .72766 L p .902 .871 .798 r
F P
0 g
s
.69478 .72766 m .72549 .68747 L .74427 .72559 L p .902 .871 .798 r
F P
0 g
s
.52632 .83667 m .57132 .84475 L .56082 .85134 L closepath p .639 .817 .968 r
F P
0 g
s
.77666 .56105 m .76657 .6028 L .71608 .56028 L p .926 .721 .607 r
F P
0 g
s
.71608 .56028 m .72426 .51557 L .77666 .56105 L p .926 .721 .607 r
F P
0 g
s
.52632 .83667 m .48605 .84828 L .4778 .8409 L closepath p .577 .759 .965 r
F P
0 g
s
.36445 .41696 m .36236 .45486 L .29531 .49641 L p .365 .159 .461 r
F P
0 g
s
.2984 .53725 m .29531 .49641 L .36236 .45486 L p .422 .254 .547 r
F P
0 g
s
.72445 .43617 m .72698 .47391 L .64757 .43968 L p .85 .552 .485 r
F P
0 g
s
.64757 .43968 m .64601 .40165 L .72445 .43617 L p .85 .552 .485 r
F P
0 g
s
.62536 .8287 m .57707 .83677 L .57737 .82823 L p .733 .861 .941 r
F P
0 g
s
.57737 .82823 m .62652 .81185 L .62536 .8287 L p .733 .861 .941 r
F P
0 g
s
.34694 .74321 m .38568 .77614 L .38015 .80094 L p .366 .502 .863 r
F P
0 g
s
.42532 .82036 m .38015 .80094 L .38568 .77614 L p .452 .592 .901 r
F P
0 g
s
.52632 .83667 m .57707 .83677 L .57132 .84475 L closepath p .654 .814 .96 r
F P
0 g
s
.30771 .58054 m .32342 .62523 L .28943 .667 L p .323 .293 .67 r
F P
0 g
s
.31463 .70631 m .28943 .667 L .32342 .62523 L p .386 .382 .732 r
F P
0 g
s
.71136 .75918 m .67173 .78842 L .6581 .76424 L p .856 .863 .845 r
F P
0 g
s
.6581 .76424 m .69478 .72766 L .71136 .75918 L p .856 .863 .845 r
F P
0 g
s
.42532 .82036 m .4747 .83253 L .4778 .8409 L p .483 .682 .954 r
F P
0 g
s
.52632 .83667 m .4778 .8409 L .4747 .83253 L closepath p .585 .75 .956 r
F P
0 g
s
.64138 .36927 m .64601 .40165 L .55104 .38574 L p .745 .417 .428 r
F P
0 g
s
.55104 .38574 m .55008 .35371 L .64138 .36927 L p .745 .417 .428 r
F P
0 g
s
.38568 .77614 m .42965 .80355 L .42532 .82036 L p .452 .592 .901 r
F P
0 g
s
.4747 .83253 m .42532 .82036 L .42965 .80355 L p .528 .671 .928 r
F P
0 g
s
.52632 .83667 m .57737 .82823 L .57707 .83677 L closepath p .665 .807 .951 r
F P
0 g
s
.76657 .6028 m .74952 .64536 L .70229 .60695 L p .906 .744 .67 r
F P
0 g
s
.70229 .60695 m .71608 .56028 L .76657 .6028 L p .906 .744 .67 r
F P
0 g
s
.32342 .62523 m .34551 .67001 L .31463 .70631 L p .386 .382 .732 r
F P
0 g
s
.34694 .74321 m .31463 .70631 L .34551 .67001 L p .44 .459 .783 r
F P
0 g
s
.67173 .78842 m .62652 .81185 L .61666 .79554 L p .804 .848 .884 r
F P
0 g
s
.61666 .79554 m .6581 .76424 L .67173 .78842 L p .804 .848 .884 r
F P
0 g
s
.45258 .39116 m .45544 .359 L .55008 .35371 L p .64 .332 .434 r
F P
0 g
s
.45544 .359 m .45258 .39116 L .36445 .41696 L p .505 .218 .413 r
F P
0 g
s
.42965 .80355 m .4772 .82406 L .4747 .83253 L p .528 .671 .928 r
F P
0 g
s
.52632 .83667 m .4747 .83253 L .4772 .82406 L closepath p .596 .743 .946 r
F P
0 g
s
.36236 .45486 m .36445 .41696 L .45258 .39116 L p .544 .302 .499 r
F P
0 g
s
.52632 .83667 m .56173 .81317 L .5721 .82006 L closepath p .672 .785 .934 r
F P
0 g
s
.52632 .83667 m .54738 .80836 L .56173 .81317 L closepath p .669 .773 .928 r
F P
0 g
s
.52632 .83667 m .53064 .8062 L .54738 .80836 L closepath p .661 .761 .924 r
F P
0 g
s
.52632 .83667 m .5134 .80693 L .53064 .8062 L closepath p .651 .752 .923 r
F P
0 g
s
.52632 .83667 m .49763 .81048 L .5134 .80693 L closepath p .638 .745 .926 r
F P
0 g
s
.52632 .83667 m .48511 .81642 L .49763 .81048 L closepath p .624 .741 .93 r
F P
0 g
s
.52632 .83667 m .4772 .82406 L .48511 .81642 L closepath p .61 .74 .938 r
F P
0 g
s
.52632 .83667 m .5721 .82006 L .57737 .82823 L closepath p .671 .797 .942 r
F P
0 g
s
.36236 .45486 m .36461 .49722 L .2984 .53725 L p .422 .254 .547 r
F P
0 g
s
.30771 .58054 m .2984 .53725 L .36461 .49722 L p .464 .33 .613 r
F P
0 g
s
.62652 .81185 m .57737 .82823 L .5721 .82006 L p .743 .827 .916 r
F P
0 g
s
.5721 .82006 m .61666 .79554 L .62652 .81185 L p .743 .827 .916 r
F P
0 g
s
.55008 .35371 m .55104 .38574 L .45258 .39116 L p .64 .332 .434 r
F P
0 g
s
.72698 .47391 m .72426 .51557 L .6459 .4826 L p .846 .595 .558 r
F P
0 g
s
.6459 .4826 m .64757 .43968 L .72698 .47391 L p .846 .595 .558 r
F P
0 g
s
.34551 .67001 m .37365 .71329 L .34694 .74321 L p .44 .459 .783 r
F P
0 g
s
.38568 .77614 m .34694 .74321 L .37365 .71329 L p .487 .531 .828 r
F P
0 g
s
.74952 .64536 m .72549 .68747 L .68294 .65419 L p .883 .761 .723 r
F P
0 g
s
.68294 .65419 m .70229 .60695 L .74952 .64536 L p .883 .761 .723 r
F P
0 g
s
.4448 .78821 m .48511 .81642 L .4772 .82406 L p .571 .668 .905 r
F P
0 g
s
.4772 .82406 m .42965 .80355 L .4448 .78821 L p .571 .668 .905 r
F P
0 g
s
.37365 .71329 m .40714 .7533 L .38568 .77614 L p .487 .531 .828 r
F P
0 g
s
.42965 .80355 m .38568 .77614 L .40714 .7533 L p .53 .6 .868 r
F P
0 g
s
.40714 .7533 m .4448 .78821 L .42965 .80355 L p .53 .6 .868 r
F P
0 g
s
.61666 .79554 m .5721 .82006 L .56173 .81317 L p .738 .79 .894 r
F P
0 g
s
.64601 .40165 m .64757 .43968 L .55137 .42389 L p .756 .475 .507 r
F P
0 g
s
.55137 .42389 m .55104 .38574 L .64601 .40165 L p .756 .475 .507 r
F P
0 g
s
.36461 .49722 m .37136 .54315 L .30771 .58054 L p .464 .33 .613 r
F P
0 g
s
.32342 .62523 m .30771 .58054 L .37136 .54315 L p .498 .394 .668 r
F P
0 g
s
.72549 .68747 m .69478 .72766 L .65835 .70032 L p .856 .774 .77 r
F P
0 g
s
.65835 .70032 m .68294 .65419 L .72549 .68747 L p .856 .774 .77 r
F P
0 g
s
.46933 .77618 m .49763 .81048 L .48511 .81642 L p .61 .674 .886 r
F P
0 g
s
.48511 .81642 m .4448 .78821 L .46933 .77618 L p .61 .674 .886 r
F P
0 g
s
.56173 .81317 m .59654 .78165 L .61666 .79554 L p .738 .79 .894 r
F P
0 g
s
.59654 .78165 m .56173 .81317 L .54738 .80836 L p .723 .757 .879 r
F P
0 g
s
.6581 .76424 m .61666 .79554 L .59654 .78165 L p .787 .789 .854 r
F P
0 g
s
.45258 .39116 m .45161 .42926 L .36236 .45486 L p .544 .302 .499 r
F P
0 g
s
.36461 .49722 m .36236 .45486 L .45161 .42926 L p .571 .366 .565 r
F P
0 g
s
.72426 .51557 m .71608 .56028 L .64086 .52951 L p .839 .628 .616 r
F P
0 g
s
.64086 .52951 m .6459 .4826 L .72426 .51557 L p .839 .628 .616 r
F P
0 g
s
.69478 .72766 m .6581 .76424 L .6292 .74345 L p .825 .783 .813 r
F P
0 g
s
.6292 .74345 m .65835 .70032 L .69478 .72766 L p .825 .783 .813 r
F P
0 g
s
.45161 .42926 m .45258 .39116 L .55104 .38574 L p .66 .397 .511 r
F P
0 g
s
.50059 .76894 m .5134 .80693 L .49763 .81048 L p .644 .685 .874 r
F P
0 g
s
.49763 .81048 m .46933 .77618 L .50059 .76894 L p .644 .685 .874 r
F P
0 g
s
.59654 .78165 m .6292 .74345 L .6581 .76424 L p .787 .789 .854 r
F P
0 g
s
.54738 .80836 m .56823 .77187 L .59654 .78165 L p .723 .757 .879 r
F P
0 g
s
.56823 .77187 m .54738 .80836 L .53064 .8062 L p .702 .728 .87 r
F P
0 g
s
.37136 .54315 m .38273 .59152 L .32342 .62523 L p .498 .394 .668 r
F P
0 g
s
.34551 .67001 m .32342 .62523 L .38273 .59152 L p .526 .452 .715 r
F P
0 g
s
.55104 .38574 m .55137 .42389 L .45161 .42926 L p .66 .397 .511 r
F P
0 g
s
.53493 .76744 m .53064 .8062 L .5134 .80693 L p .675 .704 .869 r
F P
0 g
s
.5134 .80693 m .50059 .76894 L .53493 .76744 L p .675 .704 .869 r
F P
0 g
s
.53064 .8062 m .53493 .76744 L .56823 .77187 L p .702 .728 .87 r
F P
0 g
s
.44269 .73521 m .46933 .77618 L .4448 .78821 L p .592 .614 .843 r
F P
0 g
s
.4448 .78821 m .40714 .7533 L .44269 .73521 L p .592 .614 .843 r
F P
0 g
s
.64757 .43968 m .6459 .4826 L .55102 .4674 L p .76 .519 .568 r
F P
0 g
s
.55102 .4674 m .55137 .42389 L .64757 .43968 L p .76 .519 .568 r
F P
0 g
s
.38273 .59152 m .39865 .64086 L .34551 .67001 L p .526 .452 .715 r
F P
0 g
s
.37365 .71329 m .34551 .67001 L .39865 .64086 L p .55 .506 .759 r
F P
0 g
s
.71608 .56028 m .70229 .60695 L .6324 .57924 L p .83 .654 .665 r
F P
0 g
s
.6324 .57924 m .64086 .52951 L .71608 .56028 L p .83 .654 .665 r
F P
0 g
s
.41883 .68943 m .44269 .73521 L .40714 .7533 L p .572 .559 .801 r
F P
0 g
s
.40714 .7533 m .37365 .71329 L .41883 .68943 L p .572 .559 .801 r
F P
0 g
s
.6292 .74345 m .59654 .78165 L .56823 .77187 L p .759 .738 .834 r
F P
0 g
s
.39865 .64086 m .41883 .68943 L .37365 .71329 L p .55 .506 .759 r
F P
0 g
s
.45161 .42926 m .45265 .47258 L .36461 .49722 L p .571 .366 .565 r
F P
0 g
s
.37136 .54315 m .36461 .49722 L .45265 .47258 L p .591 .419 .617 r
F P
0 g
s
.48848 .72427 m .50059 .76894 L .46933 .77618 L p .642 .635 .827 r
F P
0 g
s
.46933 .77618 m .44269 .73521 L .48848 .72427 L p .642 .635 .827 r
F P
0 g
s
.45265 .47258 m .45161 .42926 L .55137 .42389 L p .673 .447 .569 r
F P
0 g
s
.70229 .60695 m .68294 .65419 L .62056 .63028 L p .817 .677 .709 r
F P
0 g
s
.62056 .63028 m .6324 .57924 L .70229 .60695 L p .817 .677 .709 r
F P
0 g
s
.65835 .70032 m .6292 .74345 L .58791 .7287 L p .784 .719 .791 r
F P
0 g
s
.56823 .77187 m .58791 .7287 L .6292 .74345 L p .759 .738 .834 r
F P
0 g
s
.58791 .7287 m .56823 .77187 L .53493 .76744 L p .725 .696 .823 r
F P
0 g
s
.55137 .42389 m .55102 .4674 L .45265 .47258 L p .673 .447 .569 r
F P
0 g
s
.53899 .72199 m .53493 .76744 L .50059 .76894 L p .686 .662 .821 r
F P
0 g
s
.50059 .76894 m .48848 .72427 L .53899 .72199 L p .686 .662 .821 r
F P
0 g
s
.68294 .65419 m .65835 .70032 L .60558 .6808 L p .802 .699 .75 r
F P
0 g
s
.60558 .6808 m .62056 .63028 L .68294 .65419 L p .802 .699 .75 r
F P
0 g
s
.58791 .7287 m .60558 .6808 L .65835 .70032 L p .784 .719 .791 r
F P
0 g
s
.53493 .76744 m .53899 .72199 L .58791 .7287 L p .725 .696 .823 r
F P
0 g
s
.45265 .47258 m .45576 .52017 L .37136 .54315 L p .591 .419 .617 r
F P
0 g
s
.38273 .59152 m .37136 .54315 L .45576 .52017 L p .606 .464 .663 r
F P
0 g
s
.6459 .4826 m .64086 .52951 L .54997 .51535 L p .76 .554 .617 r
F P
0 g
s
.54997 .51535 m .55102 .4674 L .6459 .4826 L p .76 .554 .617 r
F P
0 g
s
.47758 .67491 m .48848 .72427 L .44269 .73521 L p .637 .589 .784 r
F P
0 g
s
.44269 .73521 m .41883 .68943 L .47758 .67491 L p .637 .589 .784 r
F P
0 g
s
.45576 .52017 m .461 .57084 L .38273 .59152 L p .606 .464 .663 r
F P
0 g
s
.39865 .64086 m .38273 .59152 L .461 .57084 L p .618 .506 .704 r
F P
0 g
s
.45576 .52017 m .45265 .47258 L .55102 .4674 L p .682 .488 .618 r
F P
0 g
s
.60558 .6808 m .58791 .7287 L .53899 .72199 L p .739 .667 .78 r
F P
0 g
s
.46833 .62305 m .47758 .67491 L .41883 .68943 L p .628 .547 .744 r
F P
0 g
s
.41883 .68943 m .39865 .64086 L .46833 .62305 L p .628 .547 .744 r
F P
0 g
s
.461 .57084 m .46833 .62305 L .39865 .64086 L p .618 .506 .704 r
F P
0 g
s
.64086 .52951 m .6324 .57924 L .54821 .56651 L p .759 .584 .661 r
F P
0 g
s
.54821 .56651 m .54997 .51535 L .64086 .52951 L p .759 .584 .661 r
F P
0 g
s
.55102 .4674 m .54997 .51535 L .45576 .52017 L p .682 .488 .618 r
F P
0 g
s
.54264 .67188 m .53899 .72199 L .48848 .72427 L p .691 .625 .778 r
F P
0 g
s
.48848 .72427 m .47758 .67491 L .54264 .67188 L p .691 .625 .778 r
F P
0 g
s
.53899 .72199 m .54264 .67188 L .60558 .6808 L p .739 .667 .78 r
F P
0 g
s
.62056 .63028 m .60558 .6808 L .54264 .67188 L p .748 .64 .74 r
F P
0 g
s
.6324 .57924 m .62056 .63028 L .54575 .61933 L p .755 .612 .701 r
F P
0 g
s
.54575 .61933 m .54821 .56651 L .6324 .57924 L p .755 .612 .701 r
F P
0 g
s
.461 .57084 m .45576 .52017 L .54997 .51535 L p .687 .524 .66 r
F P
0 g
s
.54264 .67188 m .54575 .61933 L .62056 .63028 L p .748 .64 .74 r
F P
0 g
s
.54575 .61933 m .54264 .67188 L .47758 .67491 L p .692 .591 .738 r
F P
0 g
s
.47758 .67491 m .46833 .62305 L .54575 .61933 L p .692 .591 .738 r
F P
0 g
s
.54997 .51535 m .54821 .56651 L .461 .57084 L p .687 .524 .66 r
F P
0 g
s
.46833 .62305 m .461 .57084 L .54821 .56651 L p .691 .558 .699 r
F P
0 g
s
.54821 .56651 m .54575 .61933 L .46833 .62305 L p .691 .558 .699 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo077ooooo3_l0000Z
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool002?ooooo00?o0000oooo
ooooool01?ooool2o`0001;ooooo00?o0000ooooooooool0IOooool@o`0000GoHP0000Co0000ohD0
0?n5003oQ@001Ol0000Uooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool0
02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
067ooooo2?l0000Aof800003o`000?n5003oQ@0000GoQ@001_l0000Oooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0:_ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo05gooooo1?l000000olO003o0000of80000?of8000Wo
00002_n50006o`0001[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`00
8Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
FOooool4o`0000?o7`0000?o0000of800?mR00000_mR000=o`0000KoR1PV00?o0000ojTb8OnY<R40
1Ol0000:ohD000Co00005oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0EOooool4o`0000?o7`002?l0
000CohPH9P03o`000?nY<R7oZC8Q00GoZC8Q1Ol00008ohD000?o00005Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0DOooool3o`0000Co7`000ol00002oe@05@03o`000?n862KoR1PV01KoR1PV00?o0000
ojTb8OnY<R402_nY<R45o`0000CoQ@0000?o0000oh`00?l000000_l0000Booooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1=ooooo`?o00001?lO0003o`0000CoE00E00?o0000ohPH9_n862H06?n862H00ol0
003oZC8QojTb8@0>ojTb8@Ko00000on<0002o`00013ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Wooooo`00:Oooool2o`0001[ooooo00?o0000ooooooooool0BOooool3o`0000Co
7`000ol00007oe@05@03o`000?n862KoR1PV01SoR1PV00?o0000ojTb8OnY<R404onY<R43o`0000?o
S0000_l0000?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`;o00001?lO0003o`0000[oE00E
00?o0000ohPH9_n862H04On862H;o`0001?oZC8Q00Co0000okhl0Ol0003o00000on<0002o`0000go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04Cooooo0_l00002oal000?o00003?mD01D00ol0003oR1PV
ohPH9P04ohPH9Pko00001onJ?E<01?l0003o^5A@okQDD?nhE505o`0000ooZC8Q00?o0000okhl0Onn
?0400ol00002oh`000?o00002_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Go
oooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool6o`0000goE00E
2Ol0000EoiXmD`03o`000?nhE53o^5A@00Ko^5A@1_l0000:ojTb8@03o`000?nn?07o_S`100;o_S`1
0_l00003oh`000;o00002?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo
000Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool5o`0000goE00E0ol0
0002og4IB@03o`000?nJ?E?oVSeC01WoVSeC00?o0000okQDD?nhE5003?nhE505o`0000GoZC8Q00?o
0000okhl0Onn?0401?nn?042o`0000?oS0000_l00006ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0l
ooooo`Go00002_mD01D4o`0000GoLAU900?o0000oiXmDonJ?E<06OnJ?E<00ol0003o^5A@okQDD00A
okQDD0Go000000?oZC8Qo`000?nn?0401_nn?042o`0000?oS00000?o0000ooooooooool00oooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0
003oooooooooo`0iooooo`Ko00001omD01D4o`0000WoLAU900?o0000oiXmDonJ?E<06OnJ?E<00ol0
003o^5A@okQDD00FokQDD0Co00001onn?042o`0000;oS00000?o0000ooooooooool00_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0=_ooool7o`0000GoE00E0ol0000=og4IB@03o`000?nJ?E?oVSeC01Wo
VSeC00?o0000okQDD?nhE5006?nhE5001?l0003odFDmo`000?l00007okhl0@Co00000oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0=?ooool7o`0000;oE00E1?l0000?og4IB@03o`000?nJ?E?oVSeC01[o
VSeC00?o0000okQDD?nhE5006?nhE5001?l0003odFDmom5U?OoAICd3o`0000Oo_S`10_l00002oooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08Oooool002Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0aooooo`_o00004oma6DT00ol0003oVSeCoiXmD`0CoiXmD`_o
00006?nhE5000ol0003odFDmom5U?@03om5U?@;o00001onn?043o`0003cooooo00?o0000oooooooo
ool08Oooool002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0_ooooo`Wo0000
5_ma6DT00ol0003oVSeCoiXmD`04oiXmD`oo00001onSE6l01?l0003o_VY]okiZKOnnJVd6o`0001;o
^5A@00?o0000om5U?OoAICd01OoAICd2o`0000Go_S`100?o0000oj`Z0?l00000?Oooool00ol0003o
ooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo
1ol000000olX02So0000og4IB@0Dog4IB@Wo00005_nSE6l00ol0003o_VY]okiZK@07okiZK@Ko0000
3?nhE5000ol0003odFDmom5U?@07om5U?@;o00001?nn?043o`0003cooooo00?o0000ooooooooool0
8?ooool002Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Zooooo`So000000?o
:00Xo`000?ma6DT04_ma6DT3o`0000;oPCMY00?o0000oj=DKonSE6l06_nSE6l00ol0003o_VY]okiZ
K@0=okiZK@Go00001onhE5000ol0003odFDmom5U?@09om5U?@;o00000onn?0400ol0003o[2X0o`00
000looooo`03o`000?oooooooooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0X
ooooo`Oo00000olX02P00ol0003oLAU9og4IB@0>og4IB@?o00001On1=fT00ol0003oXeA_oj=DK`0J
oj=DK`03o`000?nnJVgo_VY]01;o_VY]1_l00002okQDD003o`000?oAICgodFDm00[odFDm1Ol00000
0on/:P3o0000ooooo`0kooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09_ooool7o`0000Co:00X00?o0000og4IBOma6DT02_ma6DT4o`00
00SoPCMY00?o0000oj=DKonSE6l06_nSE6l00ol0003o_VY]okiZK@0HokiZK@Co00003_oAICd3o`00
0003oj`Z0?l0003ooooo03[ooooo00?o0000ooooooooool07_ooool002Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Tooooo`Ko00001OlX02P00ol0003oLAU9og4IB@08og4IB@?o
00003?n1=fT00ol0003oXeA_oj=DK`0Koj=DK`03o`000?nnJVgo_VY]01Wo_VY]00?o0000omQmH_l0
00000_l0000;om5U?@06o`000?oAICgo0000o`000?n/:P3o0000>oooool00ol0003oooooooooo`0M
ooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02?ooooo1Ol00006obP0
:003o`000?ma6DWoLAU900CoLAU91?l0000?oh4gJ@03o`000?nSE6ooXeA_01_oXeA_00?o0000okiZ
KOnnJVd06OnnJVd00ol0003of7eRomQmHP02omQmHP;o00002OoAICd01?l0003odFDmom5U?OoAICd3
o`0003[ooooo00?o0000ooooooooool07Oooool002Kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Qooooo`Co00002?lX02P01?l0003oLAU9og4IBOma6DT3o`0001;oPCMY00?o0000
oj=DKonSE6l07?nSE6l00ol0003o_VY]okiZK@0IokiZK@03o`000?oHOF;of7eR00Cof7eR0_l00007
om5U?@06o`000?oAICgodFDmom5U?Ol0003offP70_l0000jooooo`03o`000?oooooooooo01cooooo
000Vooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07oooool4o`0000So:00X00?o
0000og4IBOl000000_l0000Eoh4gJ@03o`000?nSE6ooXeA_01coXeA_00?o0000okiZKOnnJVd06Onn
JVd00ol0003of7eRomQmHP06omQmHP?o00001?oAICd00ol0003odFDmom5U?@02om5U?@04o`000?oK
J0Oo0000o`0003[ooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_ooooo`03o`000?oo
oooooooo01gooooo0ol00009obP0:0?o00006?n1=fT00ol0003oXeA_oj=DK`0Doj=DK`co00006?nn
JVd00ol0003of7eRomQmHP09omQmHP;o00000ooAICd01Ol0003odFDmom5U?OoAICgo000000;offP7
0_l0000iooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool07?ooool2o`0000So:00X0_l000000om81eOo0000oh4gJ@0Hoh4gJ@03o`000?nS
E6ooXeA_00GoXeA_3ol00008ojQUPP04o`000?o1NH7o`GV1ol5iP@Ko00004onnJVd00ol0003of7eR
omQmHP0:omQmHPCo00001?oAICd00ol0003offP7om]X1`02o`0003Wooooo00?o0000ooooooooool0
6_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Jooooo`03
o`000?lX02So:00X00Oo:00X00Go0000odP7Eom81eOoB0MGo`00000Goh4gJ@[o00005onXIH800ol0
003o`GV1ol5iP@07ol5iP@Ko00003OnnJVd00ol0003of7eRomQmHP0=omQmHP;o00000ooAICd01?l0
003offP7om]X1ooKJ0L2o`0003Sooooo00?o0000ooooooooool06_ooool000_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06?ooool00ol0003o:00XobP0:006obP0:0;o00000om81eL0
0ol0003oPCMYoh4gJ@0Coh4gJ@?o00000_n;CGl00ol0003oZ6F2ojQUPP0LojQUPP03o`000?o1NH7o
`GV100go`GV11Ol00008okiZK@03o`000?oHOF;of7eR00gof7eR00Co0000omQmH_l0003o00000_oA
ICd01?l0003offP7om]X1ooKJ0L2o`0003Sooooo00?o0000ooooooooool06Oooool000?ooooo1_l0
0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool05oooool00ol0003o:00XobP0:004obP0:0;o0000
1Om81eL00ol0003oPCMYoh4gJ@0?oh4gJ@Co00001On;CGl00ol0003oZ6F2ojQUPP0LojQUPP03o`00
0?o1NH7o`GV101;o`GV11_l00002okiZK@03o`000?oHOF;of7eR00gof7eR00Co0000omQmH_oHOF;o
f7eR0ol00004om]X1`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06?ooool000_ooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Eooooo`03o`000?lX02So:00X00Co:00X00?o0000odP7Eom8
1eL01Om81eL00ol0003oPCMYoh4gJ@0<oh4gJ@?o00002On;CGl00ol0003oZ6F2ojQUPP0LojQUPP03
o`000?o1NH7o`GV101So`GV11?l0000>omQmHP03o`000?oHOF;of7eR00Cof7eR00?o0000om]X1ooK
J0L00_oKJ0L00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Cooooo`;o00001?lX02P2o`0000SoB0MG00?o0000oh4g
JOn1=fT02?n1=fT4o`0000coRdeo00?o0000ojQUP_nXIH807?nXIH800ol0003o`GV1ol5iP@0Jol5i
P@04o`000?oISGco0000o`0000cof7eR00?o0000omQmH_oHOF801?oHOF82o`0000CoffP700?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Gooooo`002oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o0000ooooooooool04Oooool2
o`0000?o:00X0_l0000:odP7E`03o`000?n1=fWoPCMY00GoPCMY0ol0000@oh]=O`03o`000?nXIH;o
Z6F201coZ6F200?o0000ol5iPOo1NH406_o1NH401?l0003ofHelomV=O?oISG`3o`0000Wof7eR00?o
0000omQmH_oHOF801?oHOF800ol0003okHe3o`000004om]X1`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool05oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0@ooooo`05o`000?lX
02So:00XobP0:?l000002om81eL00ol0003oPCMYoh4gJ@02oh4gJ@Co00004on;CGl00ol0003oZ6F2
ojQUPP0LojQUPP03o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oISG`01?oISG`2o`0000Oof7eR
00?o0000omQmH_oHOF801?oHOF801?l0003okHe3onf=@ol00004om]X1`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00kooooo0_l000000olX02So
0000o`00000<odP7E`03o`000?n1=fWo000000;o00005_n;CGl00ol0003oZ6F2ojQUPP0MojQUPP03
o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oISG`01_oISG`2o`0000Gof7eR00?o0000omQmH_oH
OF801OoHOF801?l0003okHe3onf=@ol00004om]X1`03o`000?oooooooooo03?ooooo0ol0000Goooo
o`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00gooooo1?l0000=odP7E`?o
00006On;CGl00ol0003oZ6F2ojQUPP0MojQUPP03o`000?o1NH7o`GV101[o`GV100?o0000omV=O?oI
SG`02?oISG`3o`0000;of7eR00?o0000omQmH_oHOF801OoHOF801Ol0003okHe3onf=@oo]SD?o0000
00CoffP700?o0000ooooooooool0;oooool3o`0000;ooooo00?o0000ooooooooool05Oooool002Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`?o00003_m81eL00ol0003o
GBQfo`00000Joh]=O`03o`000?nXIH;oZ6F201goZ6F200?o0000ol5iPOo1NH406_o1NH400ol0003o
fHelomV=O00;omV=O0?o00001ooHOF800ol0003okHe3onf=@`02onf=@`03o`000?oKJ0OoffP700;o
ffP700?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0:ooooo`;o00003Om81eL2o`0000;oGBQf
00?o0000oh]=Oon;CGl06?n;CGl00ol0003oZ6F2ojQUPP0EojQUPPco00006_o1NH400ol0003ofHel
omV=O00<omV=O0;o00001_oHOF800ol0003okHe3onf=@`03onf=@`05o`000?oKJ0OoffP7om]X1ol0
0000:_ooool3o`0000Sooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`08ooooo`?o00002om81eL2o`0000CoGBQf00?o0000oh]=Oon;CGl0
6?n;CGl00ol0003oZ6F2ojQUPP05ojQUPQ3o00002?n/LY401?l0003o`XBAol:4TOo2Q946o`0001Co
`GV100?o0000omV=O?oISG`03?oISG`01?l0003ofHelo`000?l00004omQmHP03o`000?o]SD?okHe3
00CokHe300Go0000om]X1ooKJ0OoffP7o`00000Vooooo`?o00002oooool00ol0003oooooooooo`0E
ooooo`009?ooool2o`0003oooooo00?o0000ooooooooool01_ooool4o`0000[oB0MG00?o0000oedX
M_mM:7H01?mM:7H00ol0003oRdeooh]=O`0Foh]=O`[o00006?n/LY400ol0003o`XBAol:4T@07ol:4
T@Ko00003_o1NH400ol0003ofHelomV=O00<omV=O004o`000?oISGcofHelomV=O0?o00000_oHOF80
0ol0003okHe3onf=@`04onf=@`04o`000?oKJ0OoffP7o`0002?ooooo0ol0000?ooooo`03o`000?oo
oooooooo01Cooooo000Tooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01Oooool3
o`0000WoB0MG0_l00007oedXMP03o`000?n;CGooRdeo01?oRdeo0ol00002oi9MT003o`000?n/LY7o
[7:A01go[7:A00?o0000ol:4TOo2Q9403Oo2Q946o`0000So`GV100?o0000omV=O?oISG`03?oISG`0
0ol0003ofHelomV=O004omV=O0?o00001oo]SD<01?l0003offP7om]X1ol0000Oooooo`?o00004_oo
ool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00?ooooo1?l00007odP7E`;o00002OmM:7H00ol0003oRdeooh]=O`0@oh]=O`?o00001OnBGI00
0ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o`XBA01?o`XBA1_l00002ol5iP@03o`000?oISGco
fHel00cofHel00?o0000omV=O?oISG`01_oISG`2o`0000OokHe300?o0000om]X1ol000007?ooool3
o`0001Gooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@_ooool01?l0
003oooooooooooooool3o`000003o`008?l0003oB0MG00GoB0MG00?o0000oedXM_mM:7H02OmM:7H0
0ol0003oRdeooh]=O`0<oh]=O`Co00002?nBGI000ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o
`XBA01Wo`XBA1?l0000=omV=O003o`000?oISGcofHel00KofHel00?o0000oo:RJol000001oo]SD<2
o`0001Wooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooool000000_l000000ol0023o0000odP7E`04odP7E`;o00003?mM:7H00ol0
003oRdeooh]=O`09oh]=O`?o00003?nBGI000ol0003o[7:AojabT@0MojabT@03o`000?o2Q97o`XBA
01_o`XBA00Co0000omRHS_l0003o00003?oISG`00ol0003ofHelomV=O005omV=O004o`000?obXV_o
lZ9[o`0000OokHe30_l0000Eooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool0
0ol0003oooooooooo`14ooooo`Co000000?o000Po`000?m81eL00om81eL00ol0003oGBQfoedXMP0<
oedXMP03o`000?n;CGooRdeo00GoRdeo1?l0000?oi9MT003o`000?n/LY7o[7:A01go[7:A00?o0000
ol:4TOo2Q9406oo2Q9401?l0003of9R>omRHS_oHV8h3o`0000WofHel00?o0000omV=O?oISG`01OoI
SG`01Ol0003olZ9[oo:RJoobXV_o000000OokHe300?o0000ooooooooool04?ooool3o`0001kooooo
00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0A?ooool3o`0000;o000P00?o
0000odP7Eom81eL00_l0000?oedXMP03o`000?n;CGooRdeo00;oRdeo0ol0000Coi9MT003o`000?n/
LY7o[7:A01go[7:A00?o0000ol:4TOo2Q9406oo2Q9400ol0003of9R>omRHSP04omRHSP;o00001ooI
SG`00ol0003ofHelomV=O005omV=O003o`000?obXV_olZ9[00;olZ9[00?o0000onf=@oo]SD<01Oo]
SD<00ol0003oooooooooo`0<ooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2
o`0004Gooooo0_l00003o`0080?o00004OmM:7H00ol0003oRdeoo`000002o`0001OoTUf@00?o0000
ojabTOn/LY407?n/LY400ol0003o`XBAol:4T@0Kol:4T@03o`000?oHV8kof9R>00Kof9R>0_l00005
omV=O003o`000?oISGcofHel00GofHel00?o0000oo:RJoobXV/00oobXV/00ol0003okHe3onf=@`04
onf=@`03o`000?oooooooooo00Wooooo0ol0000Uooooo`03o`000?oooooooooo01?ooooo000Soooo
o`03o`000?oooooooooo04?ooooo0_l00003o`0080;o00004_mM:7H3o`0001[oTUf@00?o0000ojab
TOn/LY407?n/LY400ol0003o`XBAol:4T@0Kol:4T@03o`000?oHV8kof9R>00Sof9R>0ol00002omV=
O003o`000?oISGcofHel00GofHel00?o0000oo:RJoobXV/01?obXV/00ol0003okHe3onf=@`03onf=
@`;o00001oooool3o`0002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooooooo
ool0A?ooool2o`0000?o000P00?o0000oedXM_mM:7H04?mM:7H00ol0003oK46<o`00000Koi9MT003
o`000?n/LY7o[7:A01co[7:A00?o0000ol:4TOo2Q9406oo2Q9400ol0003of9R>omRHSP0;omRHSP?o
00002?oISG`00ol0003olZ9[oo:RJ`04oo:RJ`03o`000?o]SD?okHe300?okHe300?o0000oooooooo
ool00_ooool3o`0002_ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0
@oooool2o`0000Co000P00?o0000oedXM_mM:7H03_mM:7H2o`0000;oK46<00?o0000oi9MT?nBGI00
6OnBGI000ol0003o[7:AojabT@0LojabT@03o`000?o2Q97o`XBA01[o`XBA00?o0000omRHS_oHV8h0
3_oHV8h2o`0000OofHel00?o0000oo:RJoobXV/01OobXV/00ol0003okHe3onf=@`02onf=@`03o`00
0?oooooo000000;o0000;_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooooooo
o`13ooooo`03o`000?l0023o000P00;o000P0_l0000>oedXMP;o00001?m/@H`00ol0003oTUf@oi9M
T00Ioi9MT003o`000?n/LY7o[7:A01co[7:A00?o0000ol:4TOo2Q9406_o2Q9400ol0003of9R>omRH
SP0>omRHSP04o`000?oHV8ko0000o`0000GofHel00?o0000oo:RJoobXV/01_obXV/01?l0003okHe3
onf=@oo]SD<2o`00037ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0
@_ooool2o`0000?o000P00?o0000o`80E_l000003OmM:7H00ol0003oK46<ofa1S004ofa1S003o`00
0?nBGI3oTUf@01WoTUf@00?o0000ojabTOn/LY403On/LY4Do`0001So`XBA00?o0000omRHS_oHV8h0
3_oHV8h01?l0003of9R>omRHS_oHV8h3o`0000;ofHel00?o0000oo:RJoobXV/01oobXV/01Ol0003o
kHe3onf=@oo]SD?o0000037ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooooooo
ool0@_ooool00ol0003o000Po`008002o`008003o`000?l205Ko000000_oGBQf0_l00007ofa1S003
o`000?nBGI3oTUf@01OoTUf@4_l0000?ojilWP03o`000?o2SIgo`XfM00;o`XfM1ol0000Aol:4T@03
o`000?oHV8kof9R>00kof9R>00?o0000omRHS_oHV8h01?oHV8h3o`0000[olZ9[00?o0000onf=@oo]
SD<00_l0000`ooooo`03o`000?oooooooooo01?ooooo000Qooooo`?o0000@_ooool00ol0003o000P
o`008002o`008004o`000?l205Ko0P1Fo`0000WoGBQf0_l00009ofa1S003o`000?nBGI3oTUf@01Co
TUf@0ol00002oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2SId02Oo2SId7o`0000[o
`XBA00?o0000omRHS_oHV8h03_oHV8h00ol0003of9R>omRHSP06omRHSP;o00002_obXV/01?l0003o
kHe3o`000?l0000aooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04;o
oooo00Go0000o`008?l0023o000Po`000003o`80EP03o`000?mM:7KoGBQf00KoGBQf00?o0000ofa1
S?m/@H`02Om/@H`00ol0003oTUf@oi9MT00@oi9MT0Co00001OnGJid00ol0003o[WbNojilWP0Lojil
WP03o`000?o2SIgo`XfM013o`XfM1ol00003ol:4T@03o`000?oHV8kof9R>00kof9R>00?o0000omRH
S_oHV8h01_oHV8h00ol0003ol;26o`00000:oo:RJ`;o000000?obgP0o`000?ooool0;oooool00ol0
003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`12ooooo`05o`000?l0023o000Po`00
8?l000000ol205H00ol0003oGBQfoedXMP04oedXMP;o00003?m/@H`00ol0003oTUf@oi9MT00=oi9M
T0?o00002OnGJid00ol0003o[WbNojilWP0LojilWP03o`000?o2SIgo`XfM01Oo`XfM1Ol0000?omRH
SP03o`000?oHV8kof9R>00Kof9R>00Co0000oo2`Q_o`/8Ko00002_obXV/3o`00033ooooo00?o0000
ooooooooool04_ooool0027ooooo00?o0000ooooooooool0@Oooool01Ol0003o000Po`008?l0023o
000000Co0P1F00?o0000oedXM_mM:7H00omM:7H00ol0003oK46<ofa1S00<ofa1S003o`000?nBGI3o
TUf@00WoTUf@1?l0000<oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2SId06_o2SId0
1?l0003oeZ2Mo`000?l0000=omRHSP03o`000?oHV8kof9R>00Kof9R>00Go0000oo2`Q_o`/8Kol;26
o`00000:oo:RJ`;o0000<?ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`11ooooo`04o`000?l0023o000Po`0000Go0P1F00Co0000oedXM_mM:7KoGBQf0_l0000?ofa1S003
o`000?nBGI3oTUf@00KoTUf@0ol0000@oiM[W@03o`000?n^O9ko[WbN01co[WbN00?o0000ol:=WOo2
SId06_o2SId01?l0003oeZ2MomJPWOoFX9d3o`0000[of9R>00?o0000omRHS_oHV8h01_oHV8h00ol0
003ol;26oo2`QP02oo2`QP03o`000?obXV_olZ9[00OolZ9[00?o0000ol]h0?l00000;oooool00ol0
003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?l0023o000000Ko
0P1F00Co0000oedXM_l0003o00004Om/@H`00ol0003oTUf@oi9MT002oi9MT0Co00004onGJid00ol0
003o[WbNojilWP0LojilWP03o`000?o2SIgo`XfM01[o`XfM00?o0000omJPWOoFX9d01?oFX9d2o`00
00Sof9R>00?o0000omRHS_oHV8h01_oHV8h00ol0003ol;26oo2`QP03oo2`QP03o`000?obXV_olZ9[
00KolZ9[0ol0000_ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo043o
oooo00Co0000o`008?l0023o00001_l205H2o`0001?oK46<00?o0000oi9MT?l000000_l0000GoiM[
W@03o`000?n^O9ko[WbN01_o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2MomJPW@06omJP
W@;o00001_oHV8h00ol0003of9R>omRHSP06omRHSP03o`000?o`/8Kol;2600Col;2600?o0000oo:R
JoobXV/01OobXV/2o`000003ol]h0?l0003ooooo02gooooo00?o0000ooooooooool04_ooool0023o
oooo0ol00011ooooo`03o`000?l0023o000000Oo0P1F00?o0000ofa1S?m/@H`04Om/@H`3o`0001_o
Uf^M00?o0000ojilW_n^O9h06_n^O9h00ol0003o`XfMol:=W@0Kol:=W@03o`000?oFX9goeZ2M00So
eZ2M0ol00003omRHSP03o`000?oHV8kof9R>00Gof9R>00?o0000oo2`Q_o`/8H01_o`/8H2o`0000Go
lZ9[0_l000000oo;N03o0000ooooo`0^ooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`00
0?oooooooooo047ooooo0_l00008o`80EP03o`000?m/@HcoK46<00ooK46<0_l000000omfE9co0000
oiM[W@0KoiM[W@03o`000?n^O9ko[WbN01[o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2M
omJPW@0;omJPW@;o00000_oHV8h00ol0003of9R>omRHSP04omRHSP03o`000?o`/8Kol;2600Sol;26
00?o0000oo:RJoobXV/00_obXV/01?l0003okjTao`000?l0000_ooooo`03o`000?oooooooooo017o
oooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`11ooooo`;o
00001ol205H2o`00013oK46<00Go0000ogIDW?mfE9coMUBLo`00000LoiM[W@03o`000?n^O9ko[WbN
01[o[WbN00?o0000ol:=WOo2SId06oo2SId00ol0003oeZ2MomJPW@0=omJPW@?o00001_oHV8h00ol0
003ol;26oo2`QP09oo2`QP03o`000?obXV_olZ9[00;olZ9[0_l000000oo;N03o0000ooooo`0]oooo
o`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`10ooooo`;o00001ol205H00ol0003o90elo`00000>ofa1S0;o00001?mfE9`00ol0
003oUf^MoiM[W@0JoiM[W@03o`000?n^O9ko[WbN01[o[WbN00?o0000ol:=WOo2SId06_o2SId00ol0
003oeZ2MomJPW@0@omJPW@;o00001OoHV8h00ol0003ol;26oo2`QP0:oo2`QP06o`000?obXV_olZ9[
oo:RJol0003okjTa0_l0000^ooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`10ooooo`03o`000?l205Ko0P1F00Go0P1F00Co
0000ob@=O?lT3Gco00003?m/@H`2o`0000OoMUBL00?o0000oiM[WOnGJid06OnGJid00ol0003o[WbN
ojilWP0JojilWP03o`000?o2SIgo`XfM01[o`XfM00?o0000omJPWOoFX9d04?oFX9d00ol0003oeZ2M
o`000002o`0000;of9R>00?o0000oo2`Q_o`/8H02oo`/8H01Ol0003olZ9[oo:RJol0003okjTa00;o
0000;_ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0@?ooool00ol0003o0P1Fo`80EP05o`80EP04o`000?lT3Gco90elo`00
00_oK46<00?o0000ogIDW?mfE9`01omfE9`00ol0003oUf^MoiM[W@0IoiM[W@03o`000?n^O9ko[WbN
01[o[WbN00?o0000ol:=WOo2SId06_o2SId00ol0003oeZ2MomJPW@0@omJPW@03o`000?oFX9goeZ2M
00;oeZ2M0ol0000>oo2`QP03o`000?obXV_o000000;okjTa0_l0000]ooooo`03o`000?oooooooooo
017ooooo000Eooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`11oooo
o`03o`000?l205Ko0P1F00Co0P1F00Go0000ob@=O?lT3Gco90elo`000009ofa1S0;o00002_mfE9`0
0ol0003oUf^MoiM[W@0IoiM[W@03o`000?n^O9ko[WbN00co[WbN4ol0000Hol:=W@03o`000?oFX9go
eZ2M013oeZ2M00?o0000omJPWOoFX9d01?oFX9d2o`0000kol;260_l00002onnY<@;o0000;Oooool0
0ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00012
ooooo`03o`000?l205Ko0P1F00?o0P1F00?o0000ob@=O?lT3G`00olT3G`00ol0003oK46<ofa1S004
ofa1S0;o00003?mfE9`00ol0003oUf^MoiM[W@0GoiM[WA7o00003_n_QZP00ol0003o`YFYol:EZ@02
ol:EZ@Oo00004Oo2SId00ol0003oeZ2MomJPW@0@omJPW@03o`000?oFX9goeZ2M00CoeZ2M00?o0000
onfhVol000003_o`/8H00ol0003okjTaonnY<@02o`0002gooooo00?o0000ooooooooool04Oooool0
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo047ooooo00?o0000
o`80E_l205H00_l205H00ol0003o90elob@=O004ob@=O003o`000?m/@HcoK46<00?oK46<00?o0000
ogIDW?mfE9`03?mfE9`00ol0003oUf^MoiM[W@0CoiM[W@Co00000_nKMZT00ol0003o[hJXojn6Z00J
ojn6Z003o`000?o2UJWo`YFY00Wo`YFY1ol0000:ol:=W@03o`000?oFX9goeZ2M013oeZ2M00?o0000
omJPWOoFX9d01?oFX9d01?l0003okKRKonfhVol0000=oo2`QP04o`000?o_ZC7okjTaonnY<@;o0000
;Oooool00ol0003oooooooooo`0@ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool0@?ooool2o`0000Co0P1F00?o0000ob@=O?lT3G`01?lT3G`01?l0003oK46<
ofa1S?m/@H`2o`0000ooMUBL00?o0000oiM[WOnGJid03onGJid4o`0000KoVgJY00?o0000ojn6Z?n_
QZP06_n_QZP00ol0003o`YFYol:EZ@0@ol:EZ@Oo00000oo2SId00ol0003oeZ2MomJPW@0@omJPW@03
o`000?oFX9goeZ2M00?oeZ2M00?o0000onfhVoo]^9/00_o]^9/00ol0003ol;26oo2`QP0:oo2`QP;o
00000_o_ZC42o`0002gooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
@?ooool2o`0000?o0P1F00?o0000ob@=O?lT3G`01OlT3G`01?l0003oK46<o`000?l0000AogIDW003
o`000?nGJigoUf^M00_oUf^M1?l0000:oi]fZ@03o`000?n_QZSo[hJX01[o[hJX00?o0000ol:EZOo2
UJT05oo2UJT5o`00017oeZ2M00?o0000omJPWOoFX9d00ooFX9d00ol0003okKRKonfhV`03onfhV`03
o`000?o`/8Kol;2600Wol;260_l00003onnY<@03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool04?ooool001oooooo00?o0000ooooooooool0@?ooool01Ol0003o0P1Fo`80E_l205Ko000000So
90el0_l0000DogIDW003o`000?nGJigoUf^M00OoUf^M0ol0000>oi]fZ@03o`000?n_QZSo[hJX01[o
[hJX00?o0000ol:EZOo2UJT06_o2UJT01?l0003oe:NZo`000?l0000?omJPW@03o`000?oFX9goeZ2M
00?oeZ2M00?o0000onfhVoo]^9/01?o]^9/00ol0003ol;26oo2`QP08oo2`QP;o00000oo_ZC400ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo043o
oooo00Co0000o`80E_l205Ko00002OlT3G`00ol0003oMUBLogIDW00CogIDW003o`000?nGJigoUf^M
00?oUf^M1?l0000Aoi]fZ@03o`000?n_QZSo[hJX01[o[hJX00?o0000ol:EZOo2UJT06_o2UJT01?l0
003oe:NZomBWZ_oDYjX3o`0000coeZ2M00?o0000omJPWOoFX9d00ooFX9d00ol0003okKRKonfhV`05
onfhV`03o`000?o`/8Kol;2600Ool;2600?o0000ook6Iol000000_o_ZC42o`0002cooooo00?o0000
ooooooooool04?ooool001kooooo00?o0000ooooooooool0@Oooool01?l0003o0P1Fo`80E_l00009
ob@=O003o`000?mfE9coMUBL01?oMUBL00?o0000oiM[WOl000000ol0000Eoi]fZ@03o`000?n_QZSo
[hJX01[o[hJX00?o0000ol:EZOo2UJT06_o2UJT00ol0003oe:NZomBWZP04omBWZP;o00002_oFX9d0
0ol0003oeZ2MomJPW@03omJPW@03o`000?o]^9_okKRK00KokKRK0_l00007oo2`QP03o`000?onaVOo
000000?okjTa00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0
003oooooooooo`11ooooo`03o`000?l205Ko000000Wo90el0_l0000DogIDW0?o00006OnKMZT00ol0
003o[hJXojn6Z00Jojn6Z003o`000?o2UJWo`YFY01Wo`YFY00?o0000omBWZ_oDYjX01ooDYjX2o`00
00SoeZ2M00?o0000omJPWOoFX9d00_oFX9d00ol0003okKRKonfhV`09onfhV`03o`000?o`/8Kol;26
00?ol;2600Go0000ook6IoonaVOoo/IWo`000002onnY<@03o`000?oooooooooo02[ooooo00?o0000
ooooooooool04?ooool001kooooo0_l00012ooooo`;o00002OlT3G`00ol0003o?RnGo`00000BogID
W0;o000000?oOfB[o`000?nKMZT06OnKMZT00ol0003o[hJXojn6Z00Jojn6Z003o`000?o2UJWo`YFY
01Wo`YFY00?o0000omBWZ_oDYjX02OoDYjX3o`0000GoeZ2M00?o0000omJPWOoFX9d00_oFX9d00ol0
003okKRKonfhV`0:onfhV`03o`000?o`/8Kol;2600;ol;2600Go0000ook6IoonaVOoo/IWo`000002
onnY<@03o`000?oooooooooo02_ooooo00?o0000ooooooooool03oooool001kooooo00?o0000oooo
ooooool0@Oooool00ol0003o90elob@=O007ob@=O005o`000?ln;iOo?RnGoch_Uol000004?mfE9`0
1Ol0003oOfB[ogmTZomoI:_o000001_oVgJY00?o0000ojn6Z?n_QZP06On_QZP00ol0003o`YFYol:E
Z@0Iol:EZ@03o`000?oDYj[oe:NZ00coe:NZ0_l00003omJPW@03o`000?oFX9goeZ2M00;oeZ2M00?o
0000onfhVoo]^9/02oo]^9/01Ol0003ol;26oo2`Q_o`/8Ko000000Coo/IW00?o0000onnY<Ol00000
;Oooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`11ooooo`03o`000?lT
3Gco90el00Oo90el00Go0000och_Uoln;iOo?RnGo`00000>ogIDW0;o00001OmoI:/00ol0003oVgJY
oi]fZ@0Hoi]fZ@03o`000?n_QZSo[hJX01Wo[hJX00?o0000ol:EZOo2UJT06Oo2UJT00ol0003oe:NZ
omBWZP0>omBWZP;o000000?oeZ2Mo`000?oFX9d00ooFX9d00ol0003okKRKonfhV`0<onfhV`04o`00
0?o`/8Kol;26o`0000Coo/IW00?o0000onnY<Ol00000;Oooool00ol0003oooooooooo`0?ooooo`00
7_ooool00ol0003oooooooooo`10ooooo`;o00002?lT3G`00ol0003o?RnGoch_U`02och_U`03o`00
0?mfE9coMUBL00[oMUBL0_l00007ogmTZ`03o`000?nKMZWoVgJY01SoVgJY00?o0000ojn6Z?n_QZP0
6On_QZP00ol0003o`YFYol:EZ@0Iol:EZ@03o`000?oDYj[oe:NZ013oe:NZ0ol00003omJPW@03o`00
0?o]^9_okKRK00gokKRK00?o0000oo2`Q_l000001?onaVL00ol0003okjTao`00000]ooooo`03o`00
0?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo047ooooo0_l00007ob@=O003o`000?ln
;iOo?RnG00?o?RnG00?o0000ogIDW?mfE9`02OmfE9`00ol0003oOfB[ogmTZ`07ogmTZ`03o`000?nK
MZWoVgJY01SoVgJY00?o0000ojn6Z?n_QZP06On_QZP00ol0003o`YFYol:EZ@0Hol:EZ@03o`000?oD
Yj[oe:NZ01;oe:NZ00?o0000omBWZ_l000000_l0000AonfhV`;o00001OonaVL00ol0003okjTao`00
000/ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo047ooooo0_l00006
ob@=O003o`000?ln;iOo?RnG00Co?RnG00?o0000ogIDW?mfE9`01omfE9`2o`0000[oOfB[00?o0000
oi]fZOnKMZT06?nKMZT00ol0003o[hJXojn6Z00Iojn6Z003o`000?o2UJWo`YFY01So`YFY00?o0000
omBWZ_oDYjX04ooDYjX00ol0003oe:NZomBWZP02o`00017okKRK00?o0000ook6IoonaVL00oonaVL0
0ol0003okjTao`00000/ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo
047ooooo0_l00006ob@=O003o`000?ln;iOo?RnG00Co?RnG00?o0000ogIDW?mfE9`01OmfE9`2o`00
00goOfB[00?o0000oi]fZOnKMZT05onKMZT00ol0003o[hJXojn6Z00Iojn6Z003o`000?o2UJWo`YFY
01So`YFY00?o0000omBWZ_oDYjX04ooDYjX01_l0003oe:NZomBWZ_l0003oikj[o`00013okKRK00?o
0000ook6IoonaVL01?onaVL2o`0002cooooo00?o0000ooooooooool03oooool001gooooo0_l00012
ooooo`;o00001OlT3G`00ol0003o?RnGoch_U`05och_U`03o`000?mfE9coMUBL00CoMUBL00?o0000
ogmTZomoI:/03OmoI:/00ol0003oVgJYoi]fZ@0Goi]fZ@03o`000?n_QZSo[hJX00_o[hJX4_l0000G
ol:EZ@03o`000?oDYj[oe:NZ01?oe:NZ00Co0000omBWZ_oDYj[o00000_oW_Z/00ol0003okKRKonfh
V`0=onfhV`;o00001OonaVL2o`0002gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool0@Oooool00ol0003o000mo`000003ob@=O003o`000?ln;iOo?RnG00Oo?RnG00Co0000
ogIDW?mfE9coMUBL0_l0000@ogmTZ`03o`000?nKMZWoVgJY01GoVgJY4?l0000>ok2>/P04o`000?o1
W;?o`Ibcol6L/`Oo00004?o2UJT00ol0003oe:NZomBWZP0ComBWZP03o`000?oDYj[o000000Coikj[
00?o0000onfhVoo]^9/02oo]^9/00ol0003oomF=o`000005ook6I`;o0000;Oooool00ol0003ooooo
ooooo`0>ooooo`007Oooool00ol0003oooooooooo`11ooooo`03o`000?l003go000000;o90el00?o
0000och_Uoln;iL02?ln;iL01?l0003oMUBLo`000?l0000CogmTZ`03o`000?nKMZWoVgJY013oVgJY
1?l00002oij1]003o`000?n`S[;o/8jb01Wo/8jb00?o0000ol6L/oo1W;<02?o1W;<6o`0000Wo`YFY
00?o0000omBWZ_oDYjX05?oDYjX00ol0003oe:NZo`000005onNnZ`;o00002oo]^9/01?l0003oomF=
oooESOl00005ook6I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool0@_ooool00ol0003o000mo`000002ob@=O003o`000?ln;iOo?RnG00So?RnG
0_l0000EogmTZ`03o`000?nKMZWoVgJY00coVgJY1?l00006oij1]003o`000?n`S[;o/8jb01Wo/8jb
00?o0000ol6L/oo1W;<03_o1W;<7o`0000;o`YFY00?o0000omBWZ_oDYjX05?oDYjX00ol0003oe:NZ
o`000007onNnZ`03o`000?o]^9_okKRK00SokKRK00Co0000oooESOooeHgo00001OonaVL00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo04;ooooo
00Go0000o`00?Ol0003o90elo`00000;och_U`03o`000?moI:_oOfB[01CoOfB[00?o0000oi]fZOnK
MZT02?nKMZT4o`0000[oWX6d00?o0000ok2>/_n`S[806On`S[800ol0003o`Ibcol6L/`0Eol6L/`Co
00005OoDYjX2o`0000Woikj[00?o0000onfhVoo]^9/01oo]^9/01?l0003oomF=oooESOl00005ook6
I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo00?o0000oooooooo
ool0@_ooool01?l0003o000mo`000?l0000<och_U`03o`000?moI:_oOfB[01CoOfB[00?o0000oi]f
ZOnKMZT01?nKMZT4o`0000ooWX6d00?o0000ok2>/_n`S[806?n`S[800ol0003o`Ibcol6L/`0Gol6L
/`03o`000?oA[KGo000000;o00004_oDYjX2o`0000[oikj[00?o0000onfhVoo]^9/01Oo]^9/00ol0
003oomF=oooES@02oooES@03o`000?onaVOoo/IW00;oo/IW00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`;o000000?o000mo`000?ln
;iL02oln;iL00ol0003oDT^[o`00000FogmTZ`03o`000?nKMZWo000000?o00004onNPK@00ol0003o
/8jbok2>/P0Hok2>/P03o`000?o1W;?o`Ibc01Oo`Ibc00?o0000om6]]OoA[KD00_oA[KD3o`0000go
e:NZ1?l0000;onNnZ`03o`000?o]^9_okKRK00CokKRK00?o0000oooESOooeHd00_ooeHd00ol0003o
o/IWook6I`02ook6I`03o`000?oooooooooo02_ooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool0@Oooool2o`000003o`00?Ol0003o?RnG00[o?RnG00Co0000oe9;ZomBBj_o
00005OmoI:/3o`0001OoWX6d00?o0000ok2>/_n`S[806?n`S[800ol0003o`Ibcol6L/`0Fol6L/`03
o`000?oA[KGodJfe00KodJfe0ol00007omBWZP?o00000_oDYjX2o`0000coikj[0_l00004onfhV`03
o`000?ooeHgoomF=00?oomF=00Go0000ook6IoonaVOoo/IWo`00000^ooooo`03o`000?oooooooooo
00gooooo000Looooo`;o0000@_ooool01?l0003o000mo`00?Ol0000:och_U`05o`000?mBBj_oDT^[
oe9;Zol000004omoI:/2o`000003ohIc]ol0003oWX6d01OoWX6d00?o0000ok2>/_n`S[806?n`S[80
0ol0003o`Ibcol6L/`0Fol6L/`03o`000?oA[KGodJfe00WodJfe0_l00002omBWZP?o00001OoDYjX2
o`0000koikj[00Go0000onfhVoo]^9_okKRKo`000005oooES@05o`000?onaVOoo/IWook6Iol00000
;_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`12ooooo`05o`000?l0
03go000mo`00M_l000002?ln;iL00ol0003oDT^[oe9;Z`03oe9;Z`03o`000?moI:_oOfB[00ooOfB[
00Go0000ohIc]on6LkOoQW>go`00000Hoij1]003o`000?n`S[;o/8jb01Oo/8jb00?o0000ol6L/oo1
W;<05oo1W;<00ol0003odJfeom6]]@0:om6]]@Co00001ooDYjX00ol0003oikj[o`00000>onNnZ`04
o`000?o]^9_okKRKo`0000KoomF=00?o0000ook6Iol00000;oooool00ol0003oooooooooo`0=oooo
o`006oooool00ol0003oooooooooo`12ooooo`05o`000?l003go000mo`00M_l000002?ln;iL00ol0
003oDT^[oe9;Z`03oe9;Z`03o`000?moI:_oOfB[00goOfB[0_l00005ohIc]`03o`000?nNPKCoWX6d
01KoWX6d00?o0000ok2>/_n`S[805_n`S[800ol0003o`Ibcol6L/`0Gol6L/`03o`000?oA[KGodJfe
00KodJfe1?l00004om6]]@?o00001?oDYjX01?l0003oikj[onNnZol0000>onNnZ`;o00001oooeHd0
0ol0003oo/IWo`00000_ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
04;ooooo00Go0000o`00?Ol0003o001fo`000007och_U`03o`000?mBBj_oDT^[00CoDT^[00?o0000
ogmTZomoI:/02omoI:/2o`0000OoQW>g00?o0000oij1]?nNPK@05_nNPK@00ol0003o/8jbok2>/P0F
ok2>/P03o`000?o1W;?o`Ibc01Ko`Ibc00?o0000om6]]OoA[KD01?oA[KD3o`0000_odJfe1?l00004
onNnZ`03o`000?oW_Z_oikj[00coikj[00?o0000oooESOooeHd01OooeHd00ol0003oo/IWo`00000_
ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo04;ooooo00Go0000o`00
?Ol0003o001fo`000006och_U`03o`000?mBBj_oDT^[00KoDT^[00?o0000ogmTZomoI:/02?moI:/2
o`0000WoQW>g00?o0000oij1]?nNPK@05_nNPK@00ol0003o/8jbok2>/P0Fok2>/P03o`000?o1W;?o
`Ibc01Ko`Ibc00Co0000om6]]OoA[KGodJfe0ol0000Aom6]]@;o00000ooW_Z/00ol0003oikj[onNn
Z`0<onNnZ`03o`000?ooeHgoomF=00KoomF=0_l0000_ooooo`03o`000?oooooooooo00gooooo000K
ooooo`03o`000?oooooooooo04;ooooo00?o0000o`00?Ol000000_l007H00ol0003o?RnGoch_U`02
och_U`03o`000?mBBj_oDT^[00OoDT^[00?o0000ogmTZomoI:/01omoI:/00ol0003oQW>gohIc]`0:
ohIc]`03o`000?nNPKCoWX6d01GoWX6d00?o0000ok2>/_n`S[805_n`S[800ol0003o`Ibcol6L/`0F
ol6L/`Co00005?oA[KD00ol0003oh/:io`000003onNnZ`03o`000?oW_Z_oikj[00[oikj[00?o0000
oo[LZ?l000001oooeHd2o`0002oooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0@_ooool00ol0003o000mo`000002o`00MP03o`000?ln;iOo?RnG00;o?RnG00?o0000oe9;
ZomBBj/01omBBj/00ol0003oOfB[ogmTZ`05ogmTZ`;o00003On6LkL00ol0003oWX6doij1]00Eoij1
]003o`000?n`S[;o/8jb01Ko/8jb00?o0000ol6L/oo1W;<04oo1W;<4o`0001KodJfe00Go0000on;2
^OoR`[Woh/:io`000003onNnZ`03o`000?oW_Z_oikj[00Woikj[00?o0000oo[LZ?l000002?ooeHd0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00gooooo000Kooooo`;o0000@oooool00ol0
003o000mo`000002o`00MP05o`000?ln;iOo?RnGoch_Uol000002omBBj/00ol0003oOfB[ogmTZ`02
ogmTZ`;o00003on6LkL00ol0003oWX6doij1]00Foij1]003o`000?n`S[;o/8jb01Go/8jb00?o0000
ol6L/oo1W;<04?o1W;<3o`0000;o`Ibc00?o0000om6]]OoA[KD05OoA[KD00ol0003oh/:ion;2^@02
on;2^@05o`000?oW_Z_oikj[onNnZol000002_oW_Z/01?l0003on]bXoo[LZ?l00007oooES@03o`00
0?oooooooooo02kooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000ooooooooool0@ooo
ool00ol0003o000mo`000002o`00MP04o`000?ln;iOo?RnGo`0000coDT^[00Go0000ogmTZomoI:_o
OfB[o`00000BohIc]`03o`000?nNPKCoWX6d01GoWX6d00?o0000ok2>/_n`S[802On`S[8@o`0000co
`Ibc0ol00005ol6L/`03o`000?oA[KGodJfe01GodJfe00?o0000on;2^OoR`[T00ooR`[T2o`0000;o
ikj[00?o0000onNnZooW_Z/01_oW_Z/01Ol0003on]bXoo[LZ?ojg:So000000OoomF=00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Cooooo00?o000m
o`000?l007H00_l007H2o`0000goDT^[00Co0000ogmTZol0003o00004on6LkL00ol0003oWX6doij1
]00Coij1]0ko00003?naUk`01?l0003o_j>moknS_OnoXkd6o`0000?o`Ibc0ol00008ol6L/`03o`00
0?oA[KGodJfe01CodJfe00?o0000on;2^OoR`[T01_oR`[T01?l0003oikj[onNnZol00007onNnZ`03
o`000?ojg:Son]bX00;on]bX00?o0000oooESOooeHd00oooeHd2o`00033ooooo00?o0000oooooooo
ool03?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0A?ooool00ol003go0000o`00MP02o`00MP03o`000?mBBj_oDT^[00go
DT^[00?o0000ohIc]on6LkL04on6LkL00ol0003oWX6doij1]00?oij1]0Co00000_nPS;h00ol0003o
/INlok6G_00Eok6G_003o`000?noXkgo_j>m00Ko_j>m1_l00009ol6L/`03o`000?oA[KGodJfe01Co
dJfe00?o0000on;2^OoR`[T01ooR`[T00ol0003oikj[o`000006onNnZ`03o`000?ojg:Son]bX00?o
n]bX00?o0000oooESOooeHd00oooeHd00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00co
oooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`14ooooo`03o`000?l007Ko001f00;o001f00?o0000oe9;ZomBBj/03OmBBj/00ol0003oQW>g
ohIc]`0DohIc]`03o`000?nNPKCoWX6d00_oWX6d0ol00006oj2<_P03o`000?naUkco/INl01Go/INl
00?o0000oknS_OnoXkd00onoXkd3o`0000Ko_j>m1_l00002ol6L/`03o`000?oA[KGodJfe01CodJfe
00?o0000on;2^OoR`[T02OoR`[T00ol0003oikj[o`000005onNnZ`03o`000?ojg:Son]bX00Con]bX
00?o0000oooESOooeHd00_ooeHd00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo
0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`14ooooo`03o`000?l007Ko001f00;o001f00?o01VOo`000?mBBj/03?mBBj/00ol0003oHV6ko`00
000EohIc]`03o`000?nNPKCoWX6d00OoWX6d1?l00009oj2<_P03o`000?naUkco/INl01Go/INl00?o
0000oknS_OnoXkd00ol0000?oknS_@Co00005OoA[KD00ol0003oh/:ion;2^@0:on;2^@?o00001?oW
_Z/00ol0003on]bXoo[LZ004oo[LZ003o`000?ooeHgoomF=00;oomF=00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`14ooooo`03o`000?l007Ko001f00;o001f00?o
01VOo`000?mBBj/02omBBj/01?l0003oHV6kof9Q^ol0000EohIc]`03o`000?nNPKCoWX6d00?oWX6d
1?l0000>oj2<_P03o`000?naUkco/INl01Co/INl0ol0000DoknS_@03o`000?o=/[oo000000;o0000
4_oA[KD00ol0003oh/:ion;2^@0<on;2^@;o00000_oW_Z/00ol0003on]bXoo[LZ005oo[LZ004o`00
0?ooeHgoomF=oooES@;o0000<Oooool00ol0003oooooooooo`0<ooooo`000oooool00ol@413ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool00ol0003o001f
o`00MP02o`00MP03o`000?l06Ioo000000[oDT^[00?o0000of9Q^omRHK/00_mRHK/00ol0003oQW>g
ohIc]`0CohIc]`03o`000?nNPKCo000000;o00004_nPS;h00ol0003o/INlok6G_00@ok6G_0Go0000
5_noXkd00ol0003ocK:oolfb_`02olfb_`?o00003_oA[KD00ol0003oh/:ion;2^@0>on;2^@;o0000
00?oikj[o`000?ojg:P01oojg:P00ol0003oomF=oooES@02o`0003;ooooo00?o0000ooooooooool0
2oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`0004Kooooo
00Go0000o`00M_l007Ko001fo`000002o`0IW`03o`000?mBBj_oDT^[00SoDT^[00?o0000of9Q^omR
HK/00_mRHK/00ol0003oQW>gohIc]`0BohIc]`?o00005OnPS;h00ol0003o/INlok6G_00=ok6G_0?o
00001?naUk`00ol0003o_j>moknS_@0CoknS_@03o`000?o=/[oocK:o00KocK:o0ol0000;om6]]@03
o`000?oR`[Woh/:i00ooh/:i00?o0000onNnZol000002?ojg:P01?l0003oomF=oooESOl0000coooo
o`03o`000?oooooooooo00_ooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0
003oooooooooo`15ooooo`05o`000?l007Ko001fo`00M_l000000ol06Il00ol0003oDT^[oe9;Z`06
oe9;Z`03o`000?mRHK_oHV6k00CoHV6k00?o0000ohIc]on6LkL03on6LkL2o`000003ohb1`_l0003o
X8bn01GoX8bn00?o0000ok6G_?naUk`02_naUk`3o`0000Oo/INl00?o0000oknS_OnoXkd04onoXkd0
0ol0003ocK:oolfb_`09olfb_`?o00001ooA[KD00ol0003oh/:ion;2^@0Aon;2^@03o`000?ojg:So
n]bX00Son]bX00?o0000oooESOl00000<oooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0
003oooooooooo`16ooooo`04o`000?l007Ko001fo`0000?o01VO00?o0000oe9;ZomBBj/01OmBBj/0
0ol0003oHV6kof9Q^`05of9Q^`03o`000?n6LkOoQW>g00goQW>g0_l00004ohb1`P03o`000?nPS;ko
X8bn01?oX8bn00?o0000ok6G_?naUk`01onaUk`3o`0000Wo/INl00?o0000oknS_OnoXkd05?noXkd0
0ol0003ocK:oolfb_`0<olfb_`?o00001?oA[KD00ol0003oh/:ion;2^@0Aon;2^@;o00002Oojg:P3
o`0003?ooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0A_ooool01?l0
003o001fo`00M_l00003o`0IW`03o`000?mBBj_oDT^[00CoDT^[00?o0000of9Q^omRHK/01omRHK/0
0ol0003oQW>gohIc]`0:ohIc]`;o00001_n<PL800ol0003oX8bnoj2<_P0Doj2<_P03o`000?naUkco
/INl00;o/INl1?l0000<ok6G_003o`000?noXkgo_j>m01Co_j>m00?o0000olfb_oo=/[l03oo=/[l3
o`000003om6]]Ol0003oh/:i017oh/:i00Co0000oo7O_?l0003o00002Oojg:P2o`0003?ooooo00?o
0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0A_ooool01?l0003o001fo`00M_l0
0004o`0IW`03o`000?mBBj_oDT^[00;oDT^[00?o0000of9Q^omRHK/02?mRHK/00ol0003oQW>gohIc
]`08ohIc]`;o00002?n<PL800ol0003oX8bnoj2<_P0Doj2<_P03o`000?naUkco000000;o00004?na
Uk`00ol0003o_j>moknS_@0CoknS_@03o`000?o=/[oocK:o01?ocK:o0_l0000Aon;2^@06o`000?oa
gkcolMnlo`000?ojg:So00002?ojg:P2o`0003?ooooo00?o0000ooooooooool02oooool001Sooooo
00?o0000ooooooooool0Aoooool01?l0003o001fo`00M_l00004o`0IW`03o`000?mBBj_oDT^[00;o
DT^[00?o0000of9Q^omRHK/02OmRHK/00ol0003oQW>gohIc]`06ohIc]`03o`000?n<PL;oS87200Wo
S87200?o0000oj2<__nPS;h04_nPS;h3o`0001?o/INl00?o0000oknS_OnoXkd04onoXkd00ol0003o
cK:oolfb_`0Colfb_`03o`000?oKa/Go0000013oh/:i00Oo0000oo7O_?oagkcolMnlo`000?ojg:So
000000Kon]bX0_l0000dooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`000?oooooooooo
04Sooooo00?o0000o`00M_l000001Ol06Il01?l0003oDT^[oe9;Zol0000<of9Q^`03o`000?n6LkOo
QW>g00CoQW>g0_l0000<ohb1`P03o`000?nPS;koX8bn00ooX8bn0ol000000onPS;ko0000ok6G_00C
ok6G_003o`000?noXkgo_j>m01?o_j>m00?o0000olfb_oo=/[l04_o=/[l01Ol0003oflK5om_6aOoK
a/Go000000koh/:i00?o0000oo7O_?oagk`00_oagk`00ol0003on]bXo`000006oo[LZ0;o0000=Ooo
ool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`18ooooo`03o`000?l007Ko
000000Go01VO00?o0000oe9;Zol000003_mRHK/01?l0003oQW>gohIc]on6LkL2o`0000ooS87200?o
0000oj2<__nPS;h02_nPS;h4o`0000CoX8bn00?o0000ok6G_?naUk`04_naUk`00ol0003o_j>moknS
_@0BoknS_@03o`000?o=/[oocK:o01?ocK:o00?o0000om_6aOoKa/D00_oKa/D2o`0000coh/:i00?o
0000oo7O_?oagk`00_oagk`01?l0003on]bXoo[LZ?l00004oo[LZ0?o0000=Oooool00ol0003ooooo
ooooo`0:ooooo`006?ooool2o`0004Wooooo0_l00007o`0IW`03o`000?mRHK_oHV6k00goHV6k00Co
0000ohIc]ol0003o00004On<PL800ol0003oX8bnoj2<_P07oj2<_P?o00002?nPS;h00ol0003o/INl
ok6G_00Bok6G_003o`000?noXkgo_j>m01;o_j>m00?o0000olfb_oo=/[l04_o=/[l00ol0003oflK5
om_6a@05om_6a@03o`000?oR`[Woh/:i00Soh/:i00?o0000oo7O_?oagk`01?oagk`01?l0003on]bX
oo[LZ?l00003oo[LZ0?o0000=Oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003ooooo
ooooo`18ooooo`;o00001ol06Il00ol0003oHV6kof9Q^`0>of9Q^`03o`000?n<PL;oS872017oS872
00?o0000oj2<__nPS;h01?nPS;h3o`0000coX8bn00?o0000ok6G_?naUk`04OnaUk`00ol0003o_j>m
oknS_@0BoknS_@03o`000?o=/[oocK:o017ocK:o00?o0000om_6aOoKa/D01ooKa/D00ol0003oh/:i
on;2^@06on;2^@03o`000?oagkcolMnl00GolMnl00So0000oo[LZ?ojg:Son]bXo`000?ojg:So0000
onG[QP;o0000=Oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`19oooo
o`03o`000?l06Ioo01VO00Go01VO00?o8T>ko`000?mRHK/03_mRHK/00ol0003oS872ohb1`P0Bohb1
`P03o`000?nPS;koX8bn00?o00003onPS;h00ol0003o/INlok6G_007ok6G_13o00003onoXkd00ol0
003ocK:oolfb_`0Aolfb_`03o`000?oKa/GoflK500SoflK500?o0000on;2^OoR`[T01OoR`[T00ol0
003olMnloo7O_006oo7O_004o`000?ojg:Son]bXoo[LZ0;o000000?oiN^6o`000?ooool0=Oooool0
0ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1:ooooo`03o`000?l06Ioo01VO
00Go01VO00?o0000ob93^ol000003OmRHK/00ol0003oL7G8o`00000Bohb1`PCo00004?nPS;h<o`00
00[o/9o700?o0000okfZaonmZ/L00onmZ/L:o`0000Co_j>m00?o0000olfb_oo=/[l04Oo=/[l00ol0
003oflK5om_6a@0:om_6a@;o00001?oR`[T00ol0003olMnloo7O_007oo7O_006o`000?ojg:Son]bX
oo[LZ?l0003oiN^60_l0000fooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooo
oooo04[ooooo00?o0000o`0IWol06Il01?l06Il01?l0003o8T>kob93^ol0000<of9Q^`05o`000?m`
MLSoL7G8og1eb?l000003_n<PL83o`0000;oS87200?o0000oj2<__nPS;h02_nPS;h5o`0000;oXiK8
00?o0000ok2Oaon`WlL04On`WlL00ol0003o_J[7okfZa`0=okfZa`Ko00004_o=/[l00ol0003oflK5
om_6a@0<om_6a@05o`000?oR`[Woh/:ion;2^Ol000002_oagk`00ol0003on]bXoo[LZ004o`0003Ko
oooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0Boooool00ol0003o01VO
o`0IW`03o`0IW`05o`000?lR@k_o8T>kob93^ol000002_mRHK/00ol0003oL7G8og1eb002og1eb003
o`000?n<PL;oS87200WoS8720ol00005ohb1`P03o`000?nPS;koX8bn00GoX8bn1Ol00007oj>Fb003
o`000?n`WlOo/9o7017o/9o700?o0000okfZaonmZ/L04OnmZ/L00ol0003ob;S:o`000002o`0000ko
cK:o00?o0000om_6aOoKa/D03_oKa/D00ol0003oh/:io`00000;oo7O_003o`000?ojg:So000000;o
iN^600?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?l06Ioo01VO00?o01VO00?o0000ob93^olR@k/00_lR@k/00ol0003oHV6k
of9Q^`06of9Q^`03o`000?m`MLSoL7G800CoL7G800?o0000ohb1`_n<PL801On<PL83o`0000SoS872
00?o0000oj2<__nPS;h01Ol0000=oj>Fb003o`000?n`WlOo/9o7013o/9o700?o0000okfZaonmZ/L0
4?nmZ/L00ol0003ob;S:olRhbP03olRhbP?o00002oo=/[l00ol0003oflK5om_6a@0?om_6a@03o`00
0?oagkcolMnl00[olMnl00?o0000oo[LZ?l000000_oUjhH2o`0003Oooooo00?o0000ooooooooool0
2Oooool001Oooooo00?o0000ooooooooool0C?ooool00ol0003o01VOo`0IW`02o`0IW`03o`000?lR
@k_o8T>k00;o8T>k00?o0000of9Q^omRHK/01OmRHK/00ol0003oL7G8og1eb006og1eb003o`000?n<
PL;oS87200Co00002on<PL83o`0001;oXiK800?o0000ok2Oaon`WlL04?n`WlL00ol0003o_J[7okfZ
a`0@okfZa`03o`000?o8^<[ob;S:00Kob;S:0_l00008olfb_`03o`000?oKa/GoflK5013oflK500?o
0000oo7O_?oagk`02ooagk`01ol0003oiN^6onG[Q_oUjhKo0000ooooool00000=_ooool00ol0003o
ooooooooo`09ooooo`005oooool00ol0003oooooooooo`1<ooooo`03o`000?l06Ioo01VO00;o01VO
00?o0000ob93^olR@k/00olR@k/00ol0003oHV6kof9Q^`04of9Q^`03o`000?m`MLSoL7G800KoL7G8
0ol0000=ohb1`P;o000000?oTXo=o`000?nSU/P04_nSU/P00ol0003o/9o7ok2Oa`0@ok2Oa`03o`00
0?nmZ/Oo_J[7013o_J[700?o0000olRhb_o8^<X02?o8^<X3o`0000CocK:o00?o0000om_6aOoKa/D0
4?oKa/D00ol0003oi]k<o`00000<oo7O_003o`000?oUjhKoiN^600;o000000?oooooo`000?ooool0
=Oooool00ol0003oooooooooo`09ooooo`005oooool2o`0004kooooo00Go0000o`0IWol06Ioo01VO
o`000006ob93^`03o`000?mRHK_oHV6k00;oHV6k00?o0000og1eb?m`MLP01?m`MLP3o`000003og1e
b?l0003oS87200coS87200?o0000oi:?cOnBSld00_nBSld00ol0003oXiK8oj>Fb00@oj>Fb003o`00
0?n`WlOo/9o7013o/9o700?o0000okfZaonmZ/L03onmZ/L00ol0003ob;S:olRhbP0<olRhbP?o0000
00?ocK:oo`000?oKa/D04?oKa/D01?l0003oi]k<onKNc?l0000;oo7O_0;o00000_oUjhH01Ol0003o
oooooooooooooooo000003Gooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooooooo
ool0C_ooool01Ol005Ko0000o`0IWol06Ioo000000Ko8T>k00Go0000of9Q^omRHK_oHV6ko`000004
og1eb0?o00001?m`MLP00ol0003oS872ohb1`P09ohb1`P;o00001OnBSld00ol0003oXiK8oj>Fb00@
oj>Fb003o`000?n`WlOo/9o700oo/9o700?o0000okfZaonmZ/L04?nmZ/L00ol0003ob;S:olRhbP0?
olRhbP;o00004OoKa/D01Ol0003oi]k<onKNc?oVg/co000000WolMnl00?o0000on_i/_l000000_oU
jhH00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Ooo
ool001Kooooo00?o0000ooooooooool0Coooool00ol0003o01VOo`000008ob93^`04o`000?mRHK_o
0000og1eb0Co00002?m`MLP00ol0003oS872ohb1`P06ohb1`P;o00002?nBSld00ol0003oXiK8oj>F
b00@oj>Fb003o`000?n`WlOo/9o700ko/9o700?o0000okfZaonmZ/L03onmZ/L00ol0003ob;S:olRh
bP0@olRhbP03o`000?oCb=3o000000ooflK500?o0000onKNc?oVg/`00_oVg/`00ol0003olMnloo7O
_006oo7O_003o`000?o[nK;o000000?oiN^600?o0000ooooooooool00oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04oooooo00?o001F
o`000?l000002OlR@k/3o`0000goL7G800?o0000ohb1`_n<PL800on<PL82o`0000_oTXo=00?o0000
oj>Fb?nSU/P03onSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo_J[700oo_J[700?o0000
olRhb_o8^<X03oo8^<X01Ol0003odlS@om?8d?oCb=3o000000goflK500?o0000onKNc?oVg/`01?oV
g/`00ol0003olMnloo7O_005oo7O_003o`000?o[nK;o000000;oiN^600?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooo
oooo053ooooo0_l00006ob93^`Co00003om`MLP00ol0003oS872ohb1`P02ohb1`P03o`000?nBSlgo
TXo=00_oTXo=00?o0000oj>Fb?nSU/P03onSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo
_J[700oo_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d003om?8d0;o00002_oKa/D0
0ol0003oi]k<onKNc005onKNc003o`000?oagkcolMnl00ColMnl00Co0000on_i/_o[nK;o00000_oU
jhH00ol0003oooooooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool001Kooooo00?o0000ooooooooool0D?ooool00ol005Ko0000ob93^`02ob93^`?o00000olR@k/2
o`0000ooL7G800Co0000ohb1`_l0003o00003onBSld00ol0003oXiK8oj>Fb00>oj>Fb003o`000?n`
WlOo/9o700ko/9o700?o0000okfZaonmZ/L03_nmZ/L00ol0003ob;S:olRhbP0?olRhbP03o`000?oC
b=3odlS@00GodlS@00?o0000om_6aOoKa/D01ooKa/D00ol0003oi]k<onKNc006onKNc003o`000?oa
gkcolMnl00;olMnl00Oo0000on_i/_o[nK;ojoVbo`000?oUjhKo000000Wooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1Aooooo`Co0000
1_lR@k/00ol0003o@fG?o`00000?og1eb003o`000?nBSlgoTXo=00ooTXo=00?o0000oj>Fb?nSU/P0
3_nSU/P00ol0003o/9o7ok2Oa`0>ok2Oa`03o`000?nmZ/Oo_J[700ko_J[700?o0000olRhb_o8^<X0
3_o8^<X00ol0003odlS@om?8d007om?8d003o`000?oKa/GoflK500GoflK500?o0000onKNc?oVg/`0
1ooVg/`00ol0003olMnloo7O_002oo7O_007o`000?o[nK;ojoVbon_i/_l0003oiN^6o`00000:oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool0Coooool3o`000003o`00E_l0003o8T>k00Ko8T>k00Go0000od=Ucom3ILoo@fG?o`00000>og1e
b003o`000?nBSlgoTXo=013oTXo=00?o0000oj>Fb?nSU/P03_nSU/P00ol0003o/9o7ok2Oa`0=ok2O
a`03o`000?nmZ/Oo_J[700go_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d009om?8
d0;o00001?oKa/D00ol0003oi]k<onKNc009onKNc004o`000?oagkcolMnlo`0000CojoVb0_l0000<
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001<oooo
o`?o00001?ooool00ol02IWo0000ob93^`05ob93^`03o`000?m3ILoo@fG?00;o@fG?00?o0000og1e
b?m`MLP02_m`MLP00ol0003oO8OCo`00000Aoi:?c@03o`000?nSU/SoXiK800koXiK800?o0000ok2O
aon`WlL01On`WlL=o`0000_o_J[700?o0000olRhb_o8^<X03_o8^<X00ol0003odlS@om?8d00;om?8
d005o`000?oKa/GoflK5om_6aOl000002ooVg/`00ol0003olMnlo`000005on_i/P;o00003Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
04Wooooo0ol00007ooooo`03o`00E_l02IWo000000Go8T>k00?o0000od=Ucom3ILl00om3ILl00ol0
003oL7G8og1eb008og1eb005o`000?mlQm?oO8OCogb7dol000004OnBSld00ol0003oXiK8oj>Fb00;
oj>Fb0[o00002?n_ZM800ol0003o^K;BokVbdP02okVbdPOo00001?nmZ/L00ol0003ob;S:olRhbP0=
olRhbP03o`000?oCb=3odlS@00godlS@00?o0000om_6aOl000003OoVg/`00ol0003ojoVbon_i/P03
on_i/P03o`000?oUjhKo000000kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08
ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002oooool00ol0003o00VIo`000004ob93
^`03o`000?m3ILoo@fG?00?o@fG?00?o0000og1eb?m`MLP01om`MLP00ol0003oO8OCogb7d`03ogb7
d`03o`000?nBSlgoTXo=00ooTXo=00?o0000oj>Fb?nSU/P01OnSU/P5o`0000;oY:;C00?o0000ojnY
d_n_ZM803On_ZM800ol0003o^K;BokVbdP09okVbdPGo00003oo8^<X00ol0003odlS@om?8d00>om?8
d003o`000?oVg/coi]k<00coi]k<00?o0000on_i/_o[nK800oo[nK82o`0000oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`12ooooo`?o
00003oooool00ol005Ko00VIo`000004ob93^`03o`000?m3ILoo@fG?00Co@fG?00?o0000og1eb?m`
MLP01Om`MLP00ol0003oO8OCogb7d`05ogb7d`03o`000?nBSlgoTXo=00koTXo=00?o0000oj>Fb?nS
U/P01Ol00007ojBRd`03o`000?n_ZM;o[jWB00go[jWB00?o0000okVbd_ni/]803?ni/]800ol0003o
`[cEo`000002o`0000_ob;S:00?o0000om?8d?oCb=003OoCb=000ol0003ofmcHo`00000=onKNc0;o
00001Oo[nK82o`00013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`00
5Oooool00ol0003oooooooooo`0oooooo`?o00004oooool00ol0003o00VIo`000003ob93^`03o`00
0?m3ILoo@fG?00Go@fG?00?o0000og1eb?m`MLP00om`MLP00ol0003oO8OCogb7d`07ogb7d`03o`00
0?nBSlgoTXo=00goTXo=0ol0000=ojBRd`03o`000?n_ZM;o[jWB00co[jWB00?o0000okVbd_ni/]80
2oni/]800ol0003o`[cEol:le@03ol:le@?o00001oo8^<X00ol0003odlS@om?8d00=om?8d005o`00
0?oKg=SofmcHom_Lf?l000002ooVg/`00ol0003oi_W?o`000005on_i/P03o`000?oooooooooo013o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0mooooo`?o00005_ooool01_l0003o00VIo`09VOl0003o8T>ko`0000Wo@fG?00Go0000og1e
b?m`MLSoL7G8o`00000;ogb7d`03o`000?nBSlgoTXo=00[oTXo=0_l000000onGWMOo0000ojBRd`0=
ojBRd`03o`000?n_ZM;o[jWB00co[jWB00?o0000okVbd_ni/]802oni/]800ol0003o`[cEol:le@06
ol:le@;o00001Oo8^<X00ol0003odlS@om?8d00<om?8d003o`000?oKg=SofmcH00;ofmcH00?o0000
onKNc?oVg/`02?oVg/`00ol0003oi_W?o`000006on_i/P03o`000?oooooooooo017ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0ioooo
o`Co00006_ooool00ol0003o00VIo`09V@02o`0000[o@fG?00?o0000og1eb?l000003OmlQm<00ol0
003oTXo=oi:?c@07oi:?c@;o00001?nGWML00ol0003oY:;CojBRd`0;ojBRd`03o`000?n_ZM;o[jWB
00co[jWB00?o0000okVbd_ni/]802_ni/]800ol0003o`[cEol:le@09ol:le@?o000000?ob;S:o`00
0?oCb=003OoCb=000ol0003ofmcHom_Lf004om_Lf003o`000?oVg/coi]k<00Koi]k<00Co0000onKi
cooVnLoo00001Oo[nK800ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool01oooool001Cooooo00?o0000ooooooooool0=_ooool3o`0001kooooo00Go0000o`09
VOl02IWo00VIo`00000;od=Uc`;o00003_mlQm<00ol0003oTXo=oi:?c@05oi:?c@03o`000?nGWMOo
UigG00GoUigG00?o0000ojBRdonTX]<02onTX]<00ol0003o[jWBojnYdP0;ojnYdP03o`000?ni/];o
^K;B00[o^K;B00?o0000ol:leOo2_=D03?o2_=D2o`0000godlS@00?o0000om_Lf?oKg=P01OoKg=P0
0ol0003oi]k<onKNc005onKNc005o`000?oVnLooi_W?onKicol000001?o[nK800ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool001Cooooo0ol0000c
ooooo`?o00008_ooool01Ol0003o00VIo`09VOl0AlSo000000[o@fG?0_mMP=`00ol0003oO8OCogb7
d`0<ogb7d`03o`000?nBSlgoTXo=00;oTXo=0_l00008oiNMe`03o`000?nTX]?oY:;C00_oY:;C00?o
0000ojnYd_n_ZM802_n_ZM800ol0003o^K;BokVbdP0;okVbdP03o`000?o2_=Go`[cE00co`[cE00?o
0000olW9f_l000002ooCb=000ol0003ofmcHom_Lf007om_Lf003o`000?oVg/coi]k<00?oi]k<00?o
0000onKicooVnLl00_oVnLl01Ol0003ojoVbon_i/_o[nK;o000001Sooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00009Ooo
ool01_l0003o00VIo`09VOl02IWo04O8o`0000Wo@fG?00Co0000oef0g?mMP=co00003_mlQm<01?l0
003oTXo=o`000?l0000;oiNMe`03o`000?nTX]?oY:;C00[oY:;C00?o0000ojnYd_n_ZM802_n_ZM80
0ol0003o^K;BokVbdP0:okVbdP03o`000?o2_=Go`[cE00co`[cE00Co0000olW9f_o9bM[obLWJ0_l0
0008om?8d003o`000?oKg=SofmcH00SofmcH00?o0000onKNc?oVg/`00_oVg/`00ol0003oi_W?onKi
c`03onKic`04o`000?o[nK;ojoVbo`0001[ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?oo
ool4o`0002Wooooo00Ko0000o`09VOl02IWo0000o`17b?l00007od=Uc`03o`000?mMP=coGH3L00;o
GH3L00?o0000ogb7domlQm<03?mlQm<00ol0003oUigGoiNMe`0;oiNMe`03o`000?nTX]?oY:;C00[o
Y:;C00?o0000ojnYd_n_ZM802_n_ZM800ol0003o^K;BokVbdP0:okVbdP03o`000?o2_=Go`[cE00_o
`[cE00?o0000olW9f_o9bMX01?o9bMX00ol0003odlS@om?8d004om?8d003o`000?oKg=SofmcH00[o
fmcH00Co0000onKNc?oVg/co00001_oVnLl00ol0003ojoVbo`00000Looooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Zooooo`?o0000;Oooool01?l0003o00VIo`09VOl00002o`17b003o`000?m3ILoo@fG?
00Co@fG?00?o0000oef0g?mMP=`00omMP=`00ol0003oO8OCogb7d`0:ogb7d`03o`000?n7VMko0000
00goUigG00?o0000ojBRdonTX]<02_nTX]<00ol0003o[jWBojnYdP09ojnYdP03o`000?ni/];o^K;B
00Wo^K;B00?o0000ol:leOo2_=D02oo2_=D00ol0003obLWJolW9fP06olW9fP;o00000ooCb=000ol0
003ofmcHom_Lf00;om_Lf003o`000?oVg/co000000Koi_W?00Co0000on_i/_l0003o00007Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09oooool3o`00037ooooo00Co0000o`09VOl02IWo00000_l0AlP0
0ol0003o@fG?od=Uc`03od=Uc`03o`000?mMP=coGH3L00CoGH3L0_l00009ogb7d`05o`000?n7VMko
QiWNohNIg_l000003OnGWML00ol0003oY:;CojBRd`09ojBRd`03o`000?n_ZM;o[jWB00Wo[jWB00?o
0000okVbd_ni/]802Oni/]800ol0003o`[cEol:le@0:ol:le@03o`000?o9bM[obLWJ00WobLWJ00?o
0000om?8d?l000003ooKg=P00ol0003oi_W?onKic`05onKic`?o00007oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool09?ooool3o`0003Gooooo00?o0000o`09VOl000000ol0AlP00ol0003o@fG?od=Uc`02
od=Uc`03o`000?mMP=coGH3L00KoGH3L00?o0000ogb7domlQm<01OmlQm<00ol0003oQiWNohNIgP03
ohNIgP03o`000?nGWMOoUigG00[oUigG00?o0000ojBRdonTX]<02OnTX]<00ol0003o[jWBojnYdP09
ojnYdP03o`000?ni/];o^K;B00So^K;B00?o0000ol:leOo2_=D02_o2_=D00ol0003obLWJolW9fP0;
olW9fP03o`000?oKg=SofmcH00cofmcH00?o0000om[ch?l000001ooVnLl2o`00023ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo023ooooo1?l0000iooooo`03o`000?l02IWo000000?o04O800Go0000od=U
com3ILoo@fG?o`000009oef0g003o`000?mlQm?oO8OC00?oO8OC00?o0000ohNIg_n7VMh01On7VMh0
0ol0003oUigGoiNMe`0:oiNMe`03o`000?nTX]?oY:;C00WoY:;C00?o0000ojnYd_n_ZM800on_ZM89
o`0000Oo^K;B00?o0000ol:leOo2_=D02_o2_=D00ol0003obLWJolW9fP09olW9fP03o`000?o=fN;o
000000cofmcH0_l00002om[ch003o`000?oVnLooi_W?00Coi_W?0_l0000Rooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Mooooo`?o0000?_ooool00ol02IWo0000o`17b003o`17b003o`000?m3ILoo0000
00_oGH3L00Go0000ogb7domlQm?oO8OCo`000009ohNIgP03o`000?nGWMOoUigG00WoUigG00?o0000
ojBRdonTX]<01onTX]<8o`0000Go[;CN00Co0000ok>jg_nc^]ko/k[N1Ol00002okVbdP03o`000?o2
_=Go`[cE00Wo`[cE00?o0000olW9f_o9bMX02Oo9bMX01Ol0003ocMWRolgIh_o=fN;o000000[ofmcH
00?o0000om[ch?oJln000_oJln000ol0003oi_W?onKic`03onKic`;o00009?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool06_ooool3o`00047ooooo00?o0000o`09VOl000001?l0AlP00om3ILoo0000oef0
g00;oef0g003o`000?mlQm?o000000_oQiWN00?o0000oiNMeonGWML02OnGWML01?l0003oY:;CojBR
donTX]<5o`0000;oY:oO00?o0000ojbdg_n/]=h02?n/]=h00ol0003o/k[Nok>jgP06ok>jgPCo0000
2Oo2_=D00ol0003obLWJolW9fP08olW9fP;o00001?o=fN800ol0003ofmcHom_Lf006om_Lf0;o0000
1OoJln000ol0003oi_W?onKic`02onKic`;o00009_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000AOoo
ool2o`0000Go04O80_l0000<oef0g0;o00003?n7VMh00ol0003oUigGoiNMe`08oiNMe`Co00002?nT
[ml00ol0003o[;CNojbdgP07ojbdgP03o`000?nc^]ko/k[N00Oo/k[N00?o0000okW1hOni`N400ol0
0005ol:le@03o`000?o9bM[obLWJ00SobLWJ00?o0000olgIh_o=fN801Oo=fN800ol0003ofmcHom_L
f004om_Lf003o`000?oJln3of_?P00Gof_?P00Co0000onKicooVnLooi_W?0ol0000Wooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool001;ooooo00?o0000ooooooooool05?oo
ool4o`0004Wooooo00?o0000o`17b?l0AlP00ol0AlP00ol0003o;WKRo`00000;oef0g0;oLiOV00?o
0000ohNIg_n7VMh02_n7VMh00ol0003oUigGoiNMe`05oiNMe`;o000000?oW:cRo`000?nT[ml02OnT
[ml00ol0003o[;CNojbdgP06ojbdgP03o`000?nc^]ko/k[N00Oo/k[N00?o0000okW1hOni`N401?ni
`N43o`000003ol:leOl0003obLWJ00WobLWJ00?o0000olgIh_o=fN801_o=fN800ol0003ofmcHom_L
f003om_Lf003o`000?oJln3of_?P00Gof_?P00Oo0000onKicooVnLooi_W?o`000?nam;?o000002So
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`0Aooooo`?o0000C_ooool2o`0000Co04O800Co0000obifh_l0003o00002OmMP=`00ol0003o
LiOVog>GiP02o`0000_oQiWN00?o0000oiNMeonGWML00_nGWML2o`0000CoW:cR00?o0000ojB_gonT
[ml01onT[ml00ol0003o[;CNojbdgP06ojbdgP03o`000?nc^]ko/k[N00Ko/k[N00?o0000okW1hOni
`N402?ni`N400ol0003obLWJolW9fP08olW9fP03o`000?o=fN;ocMWR00SocMWR00?o0000om_Lf?oK
g=P00_l00008om[ch006o`000?oVnLooi_W?o`000?nam;?o0000:_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0001Coooo
o`05o`000?l0AlSo04O8o`17b?l000000ol^M^800ol0003oGH3Loef0g005oef0g003o`000?mcUnKo
LiOV00?oLiOV00?o0000ohNIg_n7VMh02On7VMh01?l0003oUigGo`000?l00007oib/hP03o`000?nT
[mooY:oO00OoY:oO00?o0000ojbdg_n/]=h01On/]=h00ol0003o/k[Nok>jgP06ok>jgP03o`000?ni
`N7o^L7Q00Oo^L7Q0onlb^@00ol0003obLWJolW9fP04olW9fP;o00002oo=fN800ol0003ofmcHo`00
000:om[ch005o`000?oVnLoo0000ok7d/ol00000;?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00_ooooo0ol0001Gooooo`04o`000?l0
AlSo04O8o`0000Co;WKR0_l00005oef0g003o`000?mcUnKoLiOV00CoLiOV0_l0000:ohNIgP;o0000
2OnL[>800ol0003oY:oOojB_g`06ojB_g`03o`000?n/]=ko[;CN00Go[;CN00?o0000ok>jg_nc^]h0
1Onc^]h00ol0003o^L7QokW1h@06okW1h@03o`000?nlb^Co_<[T00?o_<[T0_l00003olW9fP03o`00
0?o=fN;ocMWR00cocMWR00?o0000om[ch?oJln002OoJln02o`0000;o/OBc00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oo
oooooooo00Oooooo1?l0001Kooooo`04o`000?l0AlSo04O8o`0000Go;WKR00?o0000oef0g?mMP=`0
0_mMP=`00ol0003oLiOVog>GiP06og>GiP;o00002?n7VMh00ol0003oTZ_Wo`000009oib/hP03o`00
0?nT[mooY:oO00GoY:oO00?o0000ojbdg_n/]=h01On/]=h00ol0003o/k[Nok>jgP04ok>jgP03o`00
0?ni`N7o^L7Q00Ko^L7Q00?o0000okc:i?nlb^@01_nlb^@00ol0003obLWJo`00000<olgIhP;o0000
00?obnS[o`000?oJln002_oJln001?l0003o/OBcok7d/ol0000_ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3o`00063ooooo
00?o0000o`17b?l000001_l^M^82o`0000;oGH3L00?o0000og>Gi_mcUnH02?mcUnH00ol0003oQiWN
ohNIgP04ohNIgP04o`000?nBZnOoTZ_Woi:[i`;o00002?nL[>800ol0003oY:oOojB_g`05ojB_g`03
o`000?n/]=ko[;CN00Co[;CN00?o0000ok>jg_nc^]h01?nc^]h00ol0003o^L7QokW1h@05okW1h@03
o`000?nlb^Co_<[T00So_<[T00?o0000olgIh_o=fN802Oo=fN82o`0000?obnS[00?o0000om[ch?oJ
ln001_oJln02o`000004okong_l0003o/OBco`00037ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000I?ooool00ol0003o
04O8o`000007obifhP03oef0g?l0003oLiOV00_oLiOV0_l00003ohNIgP03o`000?nBZnOoTZ_W00Co
TZ_W00?o0000oib/h_nL[>801OnL[>800ol0003oY:oOojB_g`05ojB_g`03o`000?n/]=ko[;CN00Co
[;CN00?o0000ok>jg_nc^]h00onc^]h00ol0003o^L7QokW1h@05okW1h@03o`000?nlb^Co_<[T00So
_<[T00?o_]?Zo`000?o=fN802?o=fN82o`0000GobnS[00?o0000om[ch?oJln001OoJln000ol0003o
_okNokongP03o`0003;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`00
4Oooool00ol0003oooooo`000002o`0006Sooooo00?o04O8o`000?l^M^801ol^M^82o`0000goLiOV
0_n7VMh00ol0003oTZ_Woi:[i`06oi:[i`;o00001_nL[>800ol0003oY:oOojB_g`04ojB_g`03o`00
0?n/]=ko[;CN00?o[;CN00?o0000ok>jg_nc^]h01?nc^]h00ol0003o^L7QokW1h@04okW1h@03o`00
0?nlb^Co_<[T00Ko_<[T00?o0000okkCj_nndnX00_nndnX00ol0003ocMWRolgIhP04olgIhP;o0000
1oo;j>/00ol0003of_?Pom[ch003om[ch0;o00000_noo]h2o`0003Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0006cooooo00?o0000obifh_l^M^801_l^
M^800ol0003oFYO_o`000002o`0000_oLiOV0_l0000:oi:[i`03o`000?nL[>;oW:cR00CoW:cR00?o
0000ojB_gonT[ml01?nT[ml00ol0003o[;CNojbdgP02ojbdgP03o`000?nc^]ko/k[N00?o/k[N00?o
0000okW1hOni`N401?ni`N400ol0003o_<[Tokc:i005okc:i0;o00001_nndnX01?l0003ocMWRolgI
h_o=fN82o`0000WobnS[00Co0000om[ch?oJln3of_?P0_l00003okongP;o0000=oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06[ooooo
0_l00007obifhP04o`000?mJUnooFYO_oeZGk`;o00002OmcUnH00ol0003oQj_]o`000002o`0000So
TZ_W00?o0000oib/h_nL[>801?nL[>801?l0003oY:oOojB_gonT[ml>o`0000Go^L7Q00?o0000okc:
i?nlb^@01?nlb^@2o`0000So_]?Z00Co0000olgIh_l0003o00002oo;j>/01?l0003of_?Pom[ch?l0
0004okongP;o0000>Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo000D
ooooo`;o0000Joooool3o`0000Go;WKR00?o0000oeZGkomJUnl00omJUnl2o`0000KoLiOV00?o0000
ohN[kOn7Znd00on7Znd2o`0000OoTZ_W0_l00004oib/hPCo00000_nS_^d00ol0003oY/3/ojK0k002
ojK0k003o`000?nY`^coZL;/00;oZL;/00?o0000oj_5kOl000000_l000000oni`N7o0000okc:i004
okc:i0;o00002onndnX00ol0003obnS[ol_Xj`0;ol_Xj`?o00001?noo]h00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Kooooo00?o0000oooo
ool00000JOooool00ol0003o06;Co`000002o`0000?o;WKR00?o0000oeZGkomJUnl01?mJUnl3o`00
00?oLiOV00?o0000ohN[kOn7Znd01On7Znd3o`0000KoTZ_W00Co0000oib/h_l0003o00000onO_Nh0
1Ol0003oXkk]oj>nkOnS_^go000000?oY/3/00Go0000ojW2k?nY`^coZL;/o`000004oj_5k@?o0000
1?nlb^@00ol0003o_]?ZokkCjP08okkCjP;o000000?o^mc`o`000?o;j>/03?o;j>/00ol0003o_okN
okongP03okongP03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`04ooooo`005oooool2o`0006_ooooo00?o0000o`1Rdol0H]<00_l000000ol^M^;o0000oeZG
k`08oeZGk`04o`000?mcUnKoLiOVo`0000[oQj_]0_l00005oi:[i`;o00001OnO_Nh01?l0003oXkk]
oj>nkOl00003ojK0k004o`000?nY`^coZL;/o`0000CoZlG]00Ko0000ojc8kon/b>oo[<S_o`000?nl
b^@2o`0000Oo_]?Z0ol00004ok_Ll003o`000?o;j>_obnS[00OobnS[0ol000000onmm?7o0000okon
gP03okongP03o`000?oooooooooo03gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`04ooooo`006?ooool2o`0006_ooooo0_l00002o`1Rd`;o00002omJUnl3o`0000_oQj_]0ol00000
1?nBZnOo0000oibml?nL_O02o`0000CoWkg^00Co0000oj>nkOnS_^go00000_nV`>`01?l0003oZL;/
ojW2k?l00002oj_5k@;o00001?n/b>l2o`0000Ko_]?Z0ol00007ok_Ll003o`000?o;j>_obnS[00Co
bnS[0ol00003okgdl@04o`000?noo]ko_okNokongP;o0000@Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo06Wooooo0_l00003o`1Rd`?o
00002?mJUnl00ol0003oNjkdog^^m004o`0000[oQj_]0ol00003oibml0;o00000onO_Nh01Ol0003o
Xkk]o`000?nV`>co000000;oZL;/00Co0000oj_5kOl0003o00000on/b>l3o`0000;oZlca00?o0000
okkCj_nndnX00ol0000:ok_Ll004o`000?o;j>_obnS[ol_Xj`?o00001Onmm?400ol0003o_okNokon
gP02o`0004Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`006oooool2
o`000003ooooool0003ooooo06Sooooo00?o0000o`1Rdol0H]<00_l0H]<01?ljU_;o0000o`000?l0
0006oeZGk`03o`000?mk[_CoNjkd00?oNjkd1?l00006ohN[k@03o`000?nH__;oV;kb00Co000000Go
W;g`o`000?l0003o0000oinmkP02o`000006ojK0k?l0003oZL;/o`000?n[aNgo00000_n/b>l3o`00
00?oZlca1Ol0000=ok_Ll0Co00001onmm?401?l0003o_okNo`000?l00017ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool001gooooo0_l0001Zooooo`03o`000?l0H]?o06;C
00;o06;C00?o0000ocZFl_ljU_800ol00003oeZGk`03o`000?mk[_CoNjkd00OoNjkd1?l000000on7
Zngo0000oiRnlP06oiRnlP?o000000?oW;g`o`000?l000000ol000000onY`^co0000o`000003o`00
0003oj_<lOl0003o000000?o00000onZc_<00ol0003o^mc`ok_Ll00<ok_Ll003o`000?nmm?7o_OCa
00Oo_OCa1?l00018ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001ko
oooo00?o0000ooooooooool0JOooool2o`0000?o06;C00?o0000ocZFl_ljU_800_ljU_84o`0000go
Njkd2_l00002oiRnlPgo00002?nZc_<01?l0003o^mc`ok_Ll?nkg?07o`0000Co/n?g00?o0000okgd
lOnmm?401_nmm?43o`0004_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03oooo
o`007oooool2o`0006_ooooo0_l00002o`1Rd`03o`000?ljU_;o>YKb00Co>YKb2_l00005og^^m003
o`000?nE_oCoUKod00KoUKod6ol0000:ok?Sm`03o`000?nmm?7o_OCa00Co_OCa00Co0000okgdlOl0
003o0000C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Qooooo`03
o`000?oooooooooo06[ooooo0_l000000ol0H]?o0000ocZFlP06ocZFlP03o`000?m`/oWoL;?i00Go
L;?i3_l00002oi?2m`Co000000?oTlSjo`000?l000001_l00008ojO@m@03o`000?nchoOo/n?g00[o
/n?g00Co0000okgdlOnmm?7o_OCa1ol0001@ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00oooool002;ooooo0ol0001/ooooo`;o00001oljU_800ol0003oL;?iog2cn@0:og2cn@03
o`000?nC`_OoTl;g00CoTl;g0ol000001?nBaOSo0000o`000?nCb?X2o`000003oi[>n_l0003oW]3i
00?o000000?oXm7go`000?l000000ol00002ojO@m@03o`000?nchoOo/n?g00[o/n?g1Ol00002oi[a
k`?o0000Doooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Tooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooool000000ol00004ocZFlP03o`000?m`/oWoL;?i00[o
L;?i00?o0000oi?2monC`_L00ol00003oi;5n004o`000?nCb?[oTlSjoi?8nP;o00000_nJc_X01?l0
003oW]3ioik@nOnNd?T2o`0000CoXm7g3Ol000000onchoOo0000o`000005oi[ak`;o0000E_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o0000J_ooool01_l0
003ooooooooooooooooo0000oafEjPCo000000?o>YKbo`000?m`/oT01Om`/oT5o`000003og2cnOl0
003o000000CoT/Gh0_l00003oi?8nP04o`000?nFc?[oU/cjo`0000;oV/kj00?o0000oik@nOnNd?T0
0_nNd?T2o`000003oj?Amol0003oYNGk00_oYNGk00?o0000oi[akonJlNl01?nJlNl2o`0005Sooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo00?ooooo0_l00003oafEjPOo00002?mX^Od2o`000003oi;5n?l0
003oTlSj00?oTlSj00Go0000oiK<n_nFc?[oU/cjo`000003oi[>nP04o`000?nNd?WoW]3ioik@n@Ko
00002?nUiO/2o`0000KoV_7_0_l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00_ooool002Sooooo00?o0000ooooool00000I_ooool00ol0003oooooooooo`05ooooo`03od/0
0?l0003o000000?o7IGZ0ol0000;ofRio@Co00000_nCb?X01Ol0003oU/cjoiK<n_nFc?[o000000;o
V/kj1Ol00006oi7QoPCo00000onUiO/01?l0003oV_7_oi[akonJlNl5o`0005gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Co
oooo0_l0001Vooooo`03o`000?oooooooooo00Sooooo0_l00004oafEjP?o00000_mX^Od4o`0000Ko
I/;n2Ol00004ogcHoP;o00002OnAhOh9o`00067ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool02_ooool6o`000003oafEj_l0003o000000WoI/;n00?o0000ofg<o_m]c?h0
1?m]c?h00ol0003oO=SnogcHoP06ogcHoP;o00000_nAhOh9o`0006Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000ooooooooool02Ooo
ool2o`0006?ooooo00?o0000ooooooooool03Oooool2o`0000Go3IOI1Ol00002ofK2oP03o`000?m]
c?koKLcn00KoKLcn00?o0000ogcHo_mlf?h00_mlf?h<o`0006_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
0000063ooooo00?o0000ooooooooool04_ooool4o`0000?o3IOI0_l000000om]c?ko0000o`00000B
o`00077ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`008?ooool00ol0
003oooooooooo`0<ooooo`;o0000H?ooool00ol0003oooooooooo`0Fooooo`?o00001OlFXll;o`00
07Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003o
ooooooooo`0=ooooo`;o0000Goooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`01ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o000000?oooooo`000?ooool0F?oo
ool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Ooo
ool003Gooooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000hooooo`05o`000?oooooooooooooo
ool00000Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool003Wooooo00Co0000oooooooooooo0000Doooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000jooooo`?o0000Doooool00ol0003o
ooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000looooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o0000
0Oooool1ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00001>ooooo`03o`000?oooooo
oooo0:cooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0043ooooo0_l0001>oooo
o`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool0047o
oooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003ooooool0003ooooo04Oooooo00?o
0000ooooooooool0[oooool00ol0003oooooooooo`04ooooo`7o00000Oooool004Kooooo0_l00018
ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo000boooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l0
0017ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool00_ooool1o`00007ooooo000b
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000
A_ooool00ol0003oooooooooo`2booooo`05o`000?ooooooooooooooool000000Oooool002[ooooo
1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03o`0004?o
oooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00Ol0000003;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`03o`000?oo
oooooooo0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`0:ooooo`;o0000?_ooool00ol0003oooooooooo`2fooooo`;o0000000b
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l0000mooooo`03o`000?oo
oooooooo0;Gooooo0ol0000005?ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oo
oooooooo0;3ooooo1Ol00003ooooo`00E?ooool01?l0003oooooooooool0000hooooo`03o`000?oo
oooooooo0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o0000ooooooooool0Z?ooool4
o`0000cooooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y?ooool5o`00
013ooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Pooooo`Co00005Oooool005[ooooo
00?o0000ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co00006Oooool005_ooooo0_l0
000booooo`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool01?l0003oooooooooool0000]
ooooo`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3o`0002gooooo00?o0000oooo
ooooool0R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0002_o
oooo00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo07gooooo1?l0000hooooo`00
Doooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Xooooo`03o`000?oooooooooo07Wo
oooo1?l0000looooo`00Doooool01Ol0003ooooooooooooooooo000000oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0L?ooool4o`00
04Gooooo001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3o`0002?ooooo00?o0000oooo
ooooool0Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`00
02?ooooo00?o0000ooooooooool0Ioooool4o`0004kooooo001Cooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h05?ooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool0Hoooool4o`00
05;ooooo001^ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Go0000E_ooool006oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co0000Foooool0073ooooo0_l0
000Mooooo`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_ooool00ol0003oooooo`00000J
ooooo`03o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2o`0001[ooooo00?o0000oooo
ooooool0COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0BOooool4o`0006cooooo001fooooo`;o000000?oooooo`000?ooool05?ooool00ol0003ooooo
ooooo`14ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`000?oooooooooo043ooooo1?l0
001eooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo1Ol0001i
ooooo`00N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0=oooool4o`00
07kooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@03ooooo`;o00004Oooool00ol0003oooooooooo`0cooooo`Co0000P_ooool0
06?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_ooool006?ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oooooooooo02Oooooo1?l0002?
ooooo`00Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool5o`0009?ooooo001S
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0<ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool07_ooool4o`0009Sooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o00001oooool00ol0003ooooo
ooooo`0Iooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Qooooo`00Qooo
ool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo0029ooooo`;o00000oooool0
0ol0003oooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000ooooooooooooooooo`00000:
ooooo`Co0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05ooooo`Co0000/_ooool008go
oooo0_l000000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o0000^oooool00?ooooooC?oo
ool00?ooooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30ooooo`00Q_ooool00ol0003o
ooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003ooooooooo
o`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32oooo
o`00Q_ooool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGoIVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48711 .50892 m .48051 .55136 L .54179 .5544 L p .719 .594 .715 r
F P
0 g
s
.54179 .5544 m .53957 .51159 L .48711 .50892 L p .719 .594 .715 r
F P
0 g
s
.54354 .59592 m .54179 .5544 L .48051 .55136 L p .72 .57 .684 r
F P
0 g
s
.53957 .51159 m .54179 .5544 L .60172 .54527 L p .67 .556 .717 r
F P
0 g
s
.54179 .5544 m .54354 .59592 L .6103 .586 L p .665 .526 .685 r
F P
0 g
s
.6103 .586 m .60172 .54527 L .54179 .5544 L p .665 .526 .685 r
F P
0 g
s
.49514 .46633 m .48711 .50892 L .53957 .51159 L p .716 .619 .748 r
F P
0 g
s
.53957 .51159 m .53686 .4685 L .49514 .46633 L p .716 .619 .748 r
F P
0 g
s
.53686 .4685 m .53957 .51159 L .59083 .50358 L p .674 .587 .749 r
F P
0 g
s
.60172 .54527 m .59083 .50358 L .53957 .51159 L p .67 .556 .717 r
F P
0 g
s
.43821 .49578 m .42325 .53635 L .48051 .55136 L p .765 .638 .72 r
F P
0 g
s
.48051 .55136 m .48711 .50892 L .43821 .49578 L p .765 .638 .72 r
F P
0 g
s
.47532 .59261 m .48051 .55136 L .42325 .53635 L p .773 .618 .688 r
F P
0 g
s
.48051 .55136 m .47532 .59261 L .54354 .59592 L p .72 .57 .684 r
F P
0 g
s
.54485 .63557 m .54354 .59592 L .47532 .59261 L p .72 .546 .654 r
F P
0 g
s
.54354 .59592 m .54485 .63557 L .6167 .62516 L p .659 .498 .655 r
F P
0 g
s
.6167 .62516 m .6103 .586 L .54354 .59592 L p .659 .498 .655 r
F P
0 g
s
.45636 .45563 m .43821 .49578 L .48711 .50892 L p .755 .657 .753 r
F P
0 g
s
.48711 .50892 m .49514 .46633 L .45636 .45563 L p .755 .657 .753 r
F P
0 g
s
.42325 .53635 m .41147 .5763 L .47532 .59261 L p .773 .618 .688 r
F P
0 g
s
.47145 .63211 m .47532 .59261 L .41147 .5763 L p .778 .599 .657 r
F P
0 g
s
.47532 .59261 m .47145 .63211 L .54485 .63557 L p .72 .546 .654 r
F P
0 g
s
.50451 .42498 m .49514 .46633 L .53686 .4685 L p .711 .646 .783 r
F P
0 g
s
.53686 .4685 m .53369 .42653 L .50451 .42498 L p .711 .646 .783 r
F P
0 g
s
.53369 .42653 m .53686 .4685 L .57758 .46198 L p .677 .621 .785 r
F P
0 g
s
.59083 .50358 m .57758 .46198 L .53686 .4685 L p .674 .587 .749 r
F P
0 g
s
.59083 .50358 m .60172 .54527 L .65494 .5246 L p .615 .521 .725 r
F P
0 g
s
.60172 .54527 m .6103 .586 L .66976 .5635 L p .601 .484 .692 r
F P
0 g
s
.66976 .5635 m .65494 .5246 L .60172 .54527 L p .601 .484 .692 r
F P
0 g
s
.57758 .46198 m .59083 .50358 L .63616 .4855 L p .628 .56 .759 r
F P
0 g
s
.65494 .5246 m .63616 .4855 L .59083 .50358 L p .615 .521 .725 r
F P
0 g
s
.47748 .41734 m .45636 .45563 L .49514 .46633 L p .741 .677 .788 r
F P
0 g
s
.49514 .46633 m .50451 .42498 L .47748 .41734 L p .741 .677 .788 r
F P
0 g
s
.54575 .67319 m .54485 .63557 L .47145 .63211 L p .719 .523 .625 r
F P
0 g
s
.54485 .63557 m .54575 .67319 L .62115 .66251 L p .652 .47 .625 r
F P
0 g
s
.62115 .66251 m .6167 .62516 L .54485 .63557 L p .652 .47 .625 r
F P
0 g
s
.6103 .586 m .6167 .62516 L .68086 .60149 L p .588 .449 .66 r
F P
0 g
s
.68086 .60149 m .66976 .5635 L .6103 .586 L p .588 .449 .66 r
F P
0 g
s
.57758 .46198 m .56215 .42187 L .53369 .42653 L p .677 .621 .785 r
F P
0 g
s
.56215 .42187 m .57758 .46198 L .61343 .4473 L p .641 .601 .793 r
F P
0 g
s
.63616 .4855 m .61343 .4473 L .57758 .46198 L p .628 .56 .759 r
F P
0 g
s
.41147 .5763 m .40265 .61496 L .47145 .63211 L p .778 .599 .657 r
F P
0 g
s
.46876 .66963 m .47145 .63211 L .40265 .61496 L p .781 .579 .626 r
F P
0 g
s
.47145 .63211 m .46876 .66963 L .54575 .67319 L p .719 .523 .625 r
F P
0 g
s
.42433 .4373 m .39752 .47314 L .43821 .49578 L p .792 .703 .766 r
F P
0 g
s
.43821 .49578 m .45636 .45563 L .42433 .4373 L p .792 .703 .766 r
F P
0 g
s
.42325 .53635 m .43821 .49578 L .39752 .47314 L p .811 .691 .732 r
F P
0 g
s
.39752 .47314 m .37532 .51043 L .42325 .53635 L p .811 .691 .732 r
F P
0 g
s
.41147 .5763 m .42325 .53635 L .37532 .51043 L p .826 .677 .698 r
F P
0 g
s
.45533 .40431 m .42433 .4373 L .45636 .45563 L p .769 .714 .801 r
F P
0 g
s
.45636 .45563 m .47748 .41734 L .45533 .40431 L p .769 .714 .801 r
F P
0 g
s
.51501 .38654 m .50451 .42498 L .53369 .42653 L p .701 .676 .822 r
F P
0 g
s
.53369 .42653 m .53014 .38737 L .51501 .38654 L p .701 .676 .822 r
F P
0 g
s
.53014 .38737 m .53369 .42653 L .56215 .42187 L p .678 .659 .823 r
F P
0 g
s
.6167 .62516 m .62115 .66251 L .68859 .63823 L p .573 .414 .627 r
F P
0 g
s
.68859 .63823 m .68086 .60149 L .6167 .62516 L p .573 .414 .627 r
F P
0 g
s
.5463 .70884 m .54575 .67319 L .46876 .66963 L p .716 .5 .595 r
F P
0 g
s
.54575 .67319 m .5463 .70884 L .62385 .69811 L p .645 .443 .595 r
F P
0 g
s
.62385 .69811 m .62115 .66251 L .54575 .67319 L p .645 .443 .595 r
F P
0 g
s
.37532 .51043 m .35776 .54805 L .41147 .5763 L p .826 .677 .698 r
F P
0 g
s
.40265 .61496 m .41147 .5763 L .35776 .54805 L p .838 .661 .663 r
F P
0 g
s
.50105 .38251 m .47748 .41734 L .50451 .42498 L p .722 .697 .826 r
F P
0 g
s
.50451 .42498 m .51501 .38654 L .50105 .38251 L p .722 .697 .826 r
F P
0 g
s
.61343 .4473 m .63616 .4855 L .67109 .45874 L p .574 .537 .776 r
F P
0 g
s
.63616 .4855 m .65494 .5246 L .69628 .49388 L p .548 .489 .742 r
F P
0 g
s
.69628 .49388 m .67109 .45874 L .63616 .4855 L p .548 .489 .742 r
F P
0 g
s
.56215 .42187 m .54487 .3849 L .53014 .38737 L p .678 .659 .823 r
F P
0 g
s
.54487 .3849 m .56215 .42187 L .58705 .4114 L p .654 .647 .83 r
F P
0 g
s
.61343 .4473 m .58705 .4114 L .56215 .42187 L p .641 .601 .793 r
F P
0 g
s
.40265 .61496 m .39652 .65206 L .46876 .66963 L p .781 .579 .626 r
F P
0 g
s
.46713 .70527 m .46876 .66963 L .39652 .65206 L p .784 .558 .594 r
F P
0 g
s
.46876 .66963 m .46713 .70527 L .5463 .70884 L p .716 .5 .595 r
F P
0 g
s
.58705 .4114 m .61343 .4473 L .64077 .42569 L p .601 .587 .81 r
F P
0 g
s
.67109 .45874 m .64077 .42569 L .61343 .4473 L p .574 .537 .776 r
F P
0 g
s
.65494 .5246 m .66976 .5635 L .71626 .52995 L p .521 .441 .706 r
F P
0 g
s
.71626 .52995 m .69628 .49388 L .65494 .5246 L p .521 .441 .706 r
F P
0 g
s
.48972 .37566 m .45533 .40431 L .47748 .41734 L p .739 .723 .836 r
F P
0 g
s
.47748 .41734 m .50105 .38251 L .48972 .37566 L p .739 .723 .836 r
F P
0 g
s
.35776 .54805 m .34459 .5852 L .40265 .61496 L p .838 .661 .663 r
F P
0 g
s
.39652 .65206 m .40265 .61496 L .34459 .5852 L p .847 .644 .628 r
F P
0 g
s
.62115 .66251 m .62385 .69811 L .69327 .67368 L p .559 .378 .593 r
F P
0 g
s
.69327 .67368 m .68859 .63823 L .62115 .66251 L p .559 .378 .593 r
F P
0 g
s
.58705 .4114 m .55768 .37938 L .54487 .3849 L p .654 .647 .83 r
F P
0 g
s
.55768 .37938 m .58705 .4114 L .60582 .39609 L p .628 .64 .843 r
F P
0 g
s
.64077 .42569 m .60582 .39609 L .58705 .4114 L p .601 .587 .81 r
F P
0 g
s
.66976 .5635 m .68086 .60149 L .73127 .5661 L p .494 .392 .668 r
F P
0 g
s
.73127 .5661 m .71626 .52995 L .66976 .5635 L p .494 .392 .668 r
F P
0 g
s
.54651 .7427 m .5463 .70884 L .46713 .70527 L p .713 .475 .563 r
F P
0 g
s
.5463 .70884 m .54651 .7427 L .62488 .7321 L p .637 .413 .562 r
F P
0 g
s
.62488 .7321 m .62385 .69811 L .5463 .70884 L p .637 .413 .562 r
F P
0 g
s
.44043 .3871 m .40241 .41293 L .42433 .4373 L p .792 .758 .821 r
F P
0 g
s
.42433 .4373 m .45533 .40431 L .44043 .3871 L p .792 .758 .821 r
F P
0 g
s
.39752 .47314 m .42433 .4373 L .40241 .41293 L p .827 .76 .789 r
F P
0 g
s
.40241 .41293 m .36929 .44286 L .39752 .47314 L p .827 .76 .789 r
F P
0 g
s
.37532 .51043 m .39752 .47314 L .36929 .44286 L p .856 .758 .753 r
F P
0 g
s
.39652 .65206 m .39281 .68759 L .46713 .70527 L p .784 .558 .594 r
F P
0 g
s
.46651 .73917 m .46713 .70527 L .39281 .68759 L p .784 .535 .56 r
F P
0 g
s
.46713 .70527 m .46651 .73917 L .54651 .7427 L p .713 .475 .563 r
F P
0 g
s
.53014 .38737 m .52632 .35282 L .51501 .38654 L closepath p .685 .71 .867 r
F P
0 g
s
.54487 .3849 m .52632 .35282 L .53014 .38737 L closepath p .676 .703 .868 r
F P
0 g
s
.48224 .36669 m .44043 .3871 L .45533 .40431 L p .752 .751 .851 r
F P
0 g
s
.45533 .40431 m .48972 .37566 L .48224 .36669 L p .752 .751 .851 r
F P
0 g
s
.51501 .38654 m .52632 .35282 L .50105 .38251 L closepath p .693 .718 .869 r
F P
0 g
s
.36929 .44286 m .34168 .47558 L .37532 .51043 L p .856 .758 .753 r
F P
0 g
s
.35776 .54805 m .37532 .51043 L .34168 .47558 L p .881 .752 .715 r
F P
0 g
s
.55768 .37938 m .52632 .35282 L .54487 .3849 L closepath p .666 .699 .871 r
F P
0 g
s
.34459 .5852 m .33541 .6215 L .39652 .65206 L p .847 .644 .628 r
F P
0 g
s
.39281 .68759 m .39652 .65206 L .33541 .6215 L p .854 .625 .59 r
F P
0 g
s
.50105 .38251 m .52632 .35282 L .48972 .37566 L closepath p .698 .728 .873 r
F P
0 g
s
.68086 .60149 m .68859 .63823 L .74176 .60186 L p .466 .343 .628 r
F P
0 g
s
.74176 .60186 m .73127 .5661 L .68086 .60149 L p .466 .343 .628 r
F P
0 g
s
.60582 .39609 m .64077 .42569 L .65653 .39909 L p .556 .582 .835 r
F P
0 g
s
.64077 .42569 m .67109 .45874 L .69167 .42558 L p .509 .521 .804 r
F P
0 g
s
.69167 .42558 m .65653 .39909 L .64077 .42569 L p .509 .521 .804 r
F P
0 g
s
.56721 .37137 m .52632 .35282 L .55768 .37938 L closepath p .657 .698 .876 r
F P
0 g
s
.60582 .39609 m .56721 .37137 L .55768 .37938 L p .628 .64 .843 r
F P
0 g
s
.62385 .69811 m .62488 .7321 L .69507 .70795 L p .542 .34 .556 r
F P
0 g
s
.69507 .70795 m .69327 .67368 L .62385 .69811 L p .542 .34 .556 r
F P
0 g
s
.56721 .37137 m .60582 .39609 L .61637 .3774 L p .602 .641 .861 r
F P
0 g
s
.65653 .39909 m .61637 .3774 L .60582 .39609 L p .556 .582 .835 r
F P
0 g
s
.34168 .47558 m .31973 .50989 L .35776 .54805 L p .881 .752 .715 r
F P
0 g
s
.34459 .5852 m .35776 .54805 L .31973 .50989 L p .902 .742 .673 r
F P
0 g
s
.67109 .45874 m .69628 .49388 L .72107 .4556 L p .459 .456 .768 r
F P
0 g
s
.72107 .4556 m .69167 .42558 L .67109 .45874 L p .459 .456 .768 r
F P
0 g
s
.48972 .37566 m .52632 .35282 L .48224 .36669 L closepath p .702 .738 .879 r
F P
0 g
s
.54637 .77483 m .54651 .7427 L .46651 .73917 L p .708 .446 .526 r
F P
0 g
s
.54651 .7427 m .54637 .77483 L .6242 .76452 L p .626 .379 .524 r
F P
0 g
s
.6242 .76452 m .62488 .7321 L .54651 .7427 L p .626 .379 .524 r
F P
0 g
s
.57241 .36167 m .52632 .35282 L .56721 .37137 L closepath p .649 .699 .883 r
F P
0 g
s
.61637 .3774 m .57241 .36167 L .56721 .37137 L p .602 .641 .861 r
F P
0 g
s
.47946 .35653 m .43454 .36741 L .44043 .3871 L p .757 .78 .872 r
F P
0 g
s
.44043 .3871 m .48224 .36669 L .47946 .35653 L p .757 .78 .872 r
F P
0 g
s
.40241 .41293 m .44043 .3871 L .43454 .36741 L p .807 .807 .851 r
F P
0 g
s
.69628 .49388 m .71626 .52995 L .74452 .48793 L p .406 .388 .726 r
F P
0 g
s
.74452 .48793 m .72107 .4556 L .69628 .49388 L p .406 .388 .726 r
F P
0 g
s
.39281 .68759 m .39139 .7217 L .46651 .73917 L p .784 .535 .56 r
F P
0 g
s
.46692 .7714 m .46651 .73917 L .39139 .7217 L p .783 .508 .519 r
F P
0 g
s
.46651 .73917 m .46692 .7714 L .54637 .77483 L p .708 .446 .526 r
F P
0 g
s
.68859 .63823 m .69327 .67368 L .74811 .63707 L p .436 .291 .586 r
F P
0 g
s
.74811 .63707 m .74176 .60186 L .68859 .63823 L p .436 .291 .586 r
F P
0 g
s
.43454 .36741 m .39329 .38479 L .40241 .41293 L p .807 .807 .851 r
F P
0 g
s
.36929 .44286 m .40241 .41293 L .39329 .38479 L p .853 .828 .822 r
F P
0 g
s
.48224 .36669 m .52632 .35282 L .47946 .35653 L closepath p .702 .748 .887 r
F P
0 g
s
.33541 .6215 m .32984 .65685 L .39281 .68759 L p .854 .625 .59 r
F P
0 g
s
.39139 .7217 m .39281 .68759 L .32984 .65685 L p .86 .603 .549 r
F P
0 g
s
.31973 .50989 m .30319 .54489 L .34459 .5852 L p .902 .742 .673 r
F P
0 g
s
.33541 .6215 m .34459 .5852 L .30319 .54489 L p .92 .729 .628 r
F P
0 g
s
.57266 .35132 m .52632 .35282 L .57241 .36167 L closepath p .642 .704 .892 r
F P
0 g
s
.57241 .36167 m .61637 .3774 L .61733 .35723 L p .578 .65 .884 r
F P
0 g
s
.61733 .35723 m .57266 .35132 L .57241 .36167 L p .578 .65 .884 r
F P
0 g
s
.39329 .38479 m .35703 .40764 L .36929 .44286 L p .853 .828 .822 r
F P
0 g
s
.34168 .47558 m .36929 .44286 L .35703 .40764 L p .895 .843 .785 r
F P
0 g
s
.61637 .3774 m .65653 .39909 L .65855 .37012 L p .507 .586 .869 r
F P
0 g
s
.65855 .37012 m .61733 .35723 L .61637 .3774 L p .507 .586 .869 r
F P
0 g
s
.62488 .7321 m .6242 .76452 L .69388 .74106 L p .522 .295 .512 r
F P
0 g
s
.69388 .74106 m .69507 .70795 L .62488 .7321 L p .522 .295 .512 r
F P
0 g
s
.56785 .34141 m .52632 .35282 L .57266 .35132 L closepath p .638 .712 .9 r
F P
0 g
s
.55843 .33308 m .52632 .35282 L .56785 .34141 L closepath p .638 .722 .908 r
F P
0 g
s
.54541 .32725 m .52632 .35282 L .55843 .33308 L closepath p .642 .733 .915 r
F P
0 g
s
.53023 .32463 m .52632 .35282 L .54541 .32725 L closepath p .649 .744 .919 r
F P
0 g
s
.51461 .32552 m .52632 .35282 L .53023 .32463 L closepath p .659 .753 .92 r
F P
0 g
s
.50031 .32981 m .52632 .35282 L .51461 .32552 L closepath p .671 .759 .917 r
F P
0 g
s
.48894 .337 m .52632 .35282 L .50031 .32981 L closepath p .682 .762 .912 r
F P
0 g
s
.48175 .34626 m .52632 .35282 L .48894 .337 L closepath p .692 .761 .904 r
F P
0 g
s
.47946 .35653 m .52632 .35282 L .48175 .34626 L closepath p .698 .755 .896 r
F P
0 g
s
.71626 .52995 m .73127 .5661 L .76223 .52163 L p .349 .314 .678 r
F P
0 g
s
.76223 .52163 m .74452 .48793 L .71626 .52995 L p .349 .314 .678 r
F P
0 g
s
.43454 .36741 m .47946 .35653 L .48175 .34626 L p .752 .808 .897 r
F P
0 g
s
.65653 .39909 m .69167 .42558 L .69495 .38917 L p .425 .511 .843 r
F P
0 g
s
.69495 .38917 m .65855 .37012 L .65653 .39909 L p .425 .511 .843 r
F P
0 g
s
.57266 .35132 m .61733 .35723 L .60829 .33775 L p .558 .668 .911 r
F P
0 g
s
.60829 .33775 m .56785 .34141 L .57266 .35132 L p .558 .668 .911 r
F P
0 g
s
.69327 .67368 m .69507 .70795 L .75055 .67174 L p .403 .235 .537 r
F P
0 g
s
.75055 .67174 m .74811 .63707 L .69327 .67368 L p .403 .235 .537 r
F P
0 g
s
.54584 .80495 m .54637 .77483 L .46692 .7714 L p .699 .408 .479 r
F P
0 g
s
.54637 .77483 m .54584 .80495 L .62159 .79513 L p .611 .336 .476 r
F P
0 g
s
.62159 .79513 m .6242 .76452 L .54637 .77483 L p .611 .336 .476 r
F P
0 g
s
.48175 .34626 m .43857 .34731 L .43454 .36741 L p .752 .808 .897 r
F P
0 g
s
.39329 .38479 m .43454 .36741 L .43857 .34731 L p .805 .858 .889 r
F P
0 g
s
.35703 .40764 m .32659 .43477 L .34168 .47558 L p .895 .843 .785 r
F P
0 g
s
.31973 .50989 m .34168 .47558 L .32659 .43477 L p .933 .851 .738 r
F P
0 g
s
.30319 .54489 m .29163 .58003 L .33541 .6215 L p .92 .729 .628 r
F P
0 g
s
.32984 .65685 m .33541 .6215 L .29163 .58003 L p .934 .71 .577 r
F P
0 g
s
.32984 .65685 m .32771 .6913 L .39139 .7217 L p .86 .603 .549 r
F P
0 g
s
.39233 .75442 m .39139 .7217 L .32771 .6913 L p .863 .575 .499 r
F P
0 g
s
.39139 .7217 m .39233 .75442 L .46692 .7714 L p .783 .508 .519 r
F P
0 g
s
.43857 .34731 m .48175 .34626 L .48894 .337 L p .733 .829 .924 r
F P
0 g
s
.46849 .80168 m .46692 .7714 L .39233 .75442 L p .779 .472 .468 r
F P
0 g
s
.46692 .7714 m .46849 .80168 L .54584 .80495 L p .699 .408 .479 r
F P
0 g
s
.73127 .5661 m .74176 .60186 L .77463 .55605 L p .288 .235 .622 r
F P
0 g
s
.77463 .55605 m .76223 .52163 L .73127 .5661 L p .288 .235 .622 r
F P
0 g
s
.69167 .42558 m .72107 .4556 L .72565 .41326 L p .328 .42 .804 r
F P
0 g
s
.72565 .41326 m .69495 .38917 L .69167 .42558 L p .328 .42 .804 r
F P
0 g
s
.56785 .34141 m .60829 .33775 L .58998 .32119 L p .547 .695 .937 r
F P
0 g
s
.58998 .32119 m .55843 .33308 L .56785 .34141 L p .547 .695 .937 r
F P
0 g
s
.61733 .35723 m .65855 .37012 L .64598 .34188 L p .454 .604 .91 r
F P
0 g
s
.64598 .34188 m .60829 .33775 L .61733 .35723 L p .454 .604 .91 r
F P
0 g
s
.43857 .34731 m .39852 .35577 L .39329 .38479 L p .805 .858 .889 r
F P
0 g
s
.35703 .40764 m .39329 .38479 L .39852 .35577 L p .857 .905 .866 r
F P
0 g
s
.45239 .32901 m .48894 .337 L .50031 .32981 L p .699 .837 .949 r
F P
0 g
s
.48894 .337 m .45239 .32901 L .43857 .34731 L p .733 .829 .924 r
F P
0 g
s
.6242 .76452 m .62159 .79513 L .68935 .77277 L p .495 .239 .455 r
F P
0 g
s
.68935 .77277 m .69388 .74106 L .6242 .76452 L p .495 .239 .455 r
F P
0 g
s
.32659 .43477 m .30222 .46499 L .31973 .50989 L p .933 .851 .738 r
F P
0 g
s
.30319 .54489 m .31973 .50989 L .30222 .46499 L p .965 .85 .679 r
F P
0 g
s
.55843 .33308 m .58998 .32119 L .56428 .30954 L p .55 .731 .959 r
F P
0 g
s
.56428 .30954 m .54541 .32725 L .55843 .33308 L p .55 .731 .959 r
F P
0 g
s
.47468 .31467 m .50031 .32981 L .51461 .32552 L p .655 .829 .967 r
F P
0 g
s
.50031 .32981 m .47468 .31467 L .45239 .32901 L p .699 .837 .949 r
F P
0 g
s
.29163 .58003 m .28461 .61506 L .32984 .65685 L p .934 .71 .577 r
F P
0 g
s
.32771 .6913 m .32984 .65685 L .28461 .61506 L p .943 .686 .517 r
F P
0 g
s
.69507 .70795 m .69388 .74106 L .74894 .70588 L p .362 .169 .478 r
F P
0 g
s
.74894 .70588 m .75055 .67174 L .69507 .70795 L p .362 .169 .478 r
F P
0 g
s
.39852 .35577 m .43857 .34731 L .45239 .32901 L p .774 .901 .931 r
F P
0 g
s
.72107 .4556 m .74452 .48793 L .75028 .44123 L p .215 .311 .747 r
F P
0 g
s
.75028 .44123 m .72565 .41326 L .72107 .4556 L p .215 .311 .747 r
F P
0 g
s
.54541 .32725 m .56428 .30954 L .53411 .30428 L p .57 .77 .973 r
F P
0 g
s
.53411 .30428 m .53023 .32463 L .54541 .32725 L p .57 .77 .973 r
F P
0 g
s
.50302 .30606 m .51461 .32552 L .53023 .32463 L p .608 .805 .976 r
F P
0 g
s
.51461 .32552 m .50302 .30606 L .47468 .31467 L p .655 .829 .967 r
F P
0 g
s
.74176 .60186 m .74811 .63707 L .78217 .59088 L p .222 .148 .557 r
F P
0 g
s
.78217 .59088 m .77463 .55605 L .74176 .60186 L p .222 .148 .557 r
F P
0 g
s
.53023 .32463 m .53411 .30428 L .50302 .30606 L p .608 .805 .976 r
F P
0 g
s
.32771 .6913 m .32912 .72489 L .39233 .75442 L p .863 .575 .499 r
F P
0 g
s
.39592 .7855 m .39233 .75442 L .32912 .72489 L p .862 .536 .433 r
F P
0 g
s
.39233 .75442 m .39592 .7855 L .46849 .80168 L p .779 .472 .468 r
F P
0 g
s
.39852 .35577 m .363 .37101 L .35703 .40764 L p .857 .905 .866 r
F P
0 g
s
.32659 .43477 m .35703 .40764 L .363 .37101 L p .904 .943 .822 r
F P
0 g
s
.65855 .37012 m .69495 .38917 L .67955 .35337 L p .313 .51 .889 r
F P
0 g
s
.67955 .35337 m .64598 .34188 L .65855 .37012 L p .313 .51 .889 r
F P
0 g
s
.54485 .83236 m .54584 .80495 L .46849 .80168 L p .685 .356 .414 r
F P
0 g
s
.54584 .80495 m .54485 .83236 L .61671 .82322 L p .588 .276 .408 r
F P
0 g
s
.61671 .82322 m .62159 .79513 L .54584 .80495 L p .588 .276 .408 r
F P
0 g
s
.60829 .33775 m .64598 .34188 L .61962 .31766 L p .405 .639 .951 r
F P
0 g
s
.61962 .31766 m .58998 .32119 L .60829 .33775 L p .405 .639 .951 r
F P
0 g
s
.47144 .82932 m .46849 .80168 L .39592 .7855 L p .769 .421 .395 r
F P
0 g
s
.46849 .80168 m .47144 .82932 L .54485 .83236 L p .685 .356 .414 r
F P
0 g
s
.30222 .46499 m .28378 .49728 L .30319 .54489 L p .965 .85 .679 r
F P
0 g
s
.29163 .58003 m .30319 .54489 L .28378 .49728 L p .988 .839 .606 r
F P
0 g
s
.41817 .32912 m .45239 .32901 L .47468 .31467 L p .7 .918 .968 r
F P
0 g
s
.45239 .32901 m .41817 .32912 L .39852 .35577 L p .774 .901 .931 r
F P
0 g
s
.74452 .48793 m .76223 .52163 L .76898 .472 L p .083 .18 .667 r
F P
0 g
s
.76898 .472 m .75028 .44123 L .74452 .48793 L p .083 .18 .667 r
F P
0 g
s
.62159 .79513 m .61671 .82322 L .68089 .80243 L p .456 .16 .374 r
F P
0 g
s
.68089 .80243 m .68935 .77277 L .62159 .79513 L p .456 .16 .374 r
F P
0 g
s
.28461 .61506 m .28192 .64997 L .32771 .6913 L p .943 .686 .517 r
F P
0 g
s
.32912 .72489 m .32771 .6913 L .28192 .64997 L p .948 .651 .442 r
F P
0 g
s
.363 .37101 m .39852 .35577 L .41817 .32912 L p .804 .969 .908 r
F P
0 g
s
.69388 .74106 m .68935 .77277 L .74278 .73929 L p .309 .082 .398 r
F P
0 g
s
.74278 .73929 m .74894 .70588 L .69388 .74106 L p .309 .082 .398 r
F P
0 g
s
.74811 .63707 m .75055 .67174 L .78506 .62603 L p .145 .049 .479 r
F P
0 g
s
.78506 .62603 m .78217 .59088 L .74811 .63707 L p .145 .049 .479 r
F P
0 g
s
.363 .37101 m .33293 .39204 L .32659 .43477 L p .904 .943 .822 r
F P
0 g
s
.30222 .46499 m .32659 .43477 L .33293 .39204 L p .937 .963 .744 r
F P
0 g
s
.69495 .38917 m .72565 .41326 L .70808 .37135 L p .121 .371 .83 r
F P
0 g
s
.70808 .37135 m .67955 .35337 L .69495 .38917 L p .121 .371 .83 r
F P
0 g
s
.58998 .32119 m .61962 .31766 L .58212 .30052 L p .377 .69 .981 r
F P
0 g
s
.58212 .30052 m .56428 .30954 L .58998 .32119 L p .377 .69 .981 r
F P
0 g
s
.28378 .49728 m .27085 .53091 L .29163 .58003 L p .988 .839 .606 r
F P
0 g
s
.28461 .61506 m .29163 .58003 L .27085 .53091 L p .999 .813 .516 r
F P
0 g
s
.32912 .72489 m .33451 .75737 L .39592 .7855 L p .862 .536 .433 r
F P
0 g
s
.40264 .81426 m .39592 .7855 L .33451 .75737 L p .852 .476 .339 r
F P
0 g
s
.39592 .7855 m .40264 .81426 L .47144 .82932 L p .769 .421 .395 r
F P
0 g
s
.45052 .30808 m .47468 .31467 L .50302 .30606 L p .588 .893 .989 r
F P
0 g
s
.47468 .31467 m .45052 .30808 L .41817 .32912 L p .7 .918 .968 r
F P
0 g
s
.64598 .34188 m .67955 .35337 L .64623 .32243 L p .174 .519 .917 r
F P
0 g
s
.64623 .32243 m .61962 .31766 L .64598 .34188 L p .174 .519 .917 r
F P
0 g
s
.76223 .52163 m .77463 .55605 L .78212 .50477 L p 0 .028 .561 r
F P
0 g
s
.78212 .50477 m .76898 .472 L .76223 .52163 L p 0 .028 .561 r
F P
0 g
s
.54331 .85582 m .54485 .83236 L .47144 .82932 L p .656 .277 .314 r
F P
0 g
s
.54485 .83236 m .54331 .85582 L .60917 .84758 L p .548 .186 .304 r
F P
0 g
s
.60917 .84758 m .61671 .82322 L .54485 .83236 L p .548 .186 .304 r
F P
0 g
s
.56428 .30954 m .58212 .30052 L .53779 .29273 L p .395 .757 .993 r
F P
0 g
s
.53779 .29273 m .53411 .30428 L .56428 .30954 L p .395 .757 .993 r
F P
0 g
s
.49204 .29537 m .50302 .30606 L .53411 .30428 L p .472 .831 .995 r
F P
0 g
s
.50302 .30606 m .49204 .29537 L .45052 .30808 L p .588 .893 .989 r
F P
0 g
s
.476 .85308 m .47144 .82932 L .40264 .81426 L p .745 .34 .284 r
F P
0 g
s
.47144 .82932 m .476 .85308 L .54331 .85582 L p .656 .277 .314 r
F P
0 g
s
.53411 .30428 m .53779 .29273 L .49204 .29537 L p .472 .831 .995 r
F P
0 g
s
.33293 .39204 m .30872 .41771 L .30222 .46499 L p .937 .963 .744 r
F P
0 g
s
.28378 .49728 m .30222 .46499 L .30872 .41771 L p .941 .948 .623 r
F P
0 g
s
.28192 .64997 m .2837 .68473 L .32912 .72489 L p .948 .651 .442 r
F P
0 g
s
.33451 .75737 m .32912 .72489 L .2837 .68473 L p .942 .597 .34 r
F P
0 g
s
.41817 .32912 m .38757 .3371 L .363 .37101 L p .804 .969 .908 r
F P
0 g
s
.33293 .39204 m .363 .37101 L .38757 .3371 L p .795 .999 .817 r
F P
0 g
s
.75055 .67174 m .74894 .70588 L .78315 .66149 L p .052 0 .377 r
F P
0 g
s
.78315 .66149 m .78506 .62603 L .75055 .67174 L p .052 0 .377 r
F P
0 g
s
.72565 .41326 m .75028 .44123 L .73113 .39472 L p 0 .172 .709 r
F P
0 g
s
.73113 .39472 m .70808 .37135 L .72565 .41326 L p 0 .172 .709 r
F P
0 g
s
.38757 .3371 m .41817 .32912 L .45052 .30808 L p .641 .962 .911 r
F P
0 g
s
.68935 .77277 m .68089 .80243 L .7313 .77136 L p .231 0 .282 r
F P
0 g
s
.7313 .77136 m .74278 .73929 L .68935 .77277 L p .231 0 .282 r
F P
0 g
s
.27085 .53091 m .26297 .5655 L .28461 .61506 L p .999 .813 .516 r
F P
0 g
s
.28192 .64997 m .28461 .61506 L .26297 .5655 L p .994 .768 .404 r
F P
0 g
s
.61671 .82322 m .60917 .84758 L .66781 .82888 L p .391 .041 .248 r
F P
0 g
s
.66781 .82888 m .68089 .80243 L .61671 .82322 L p .391 .041 .248 r
F P
0 g
s
.77463 .55605 m .78217 .59088 L .79013 .53908 L p 0 0 .425 r
F P
0 g
s
.79013 .53908 m .78212 .50477 L .77463 .55605 L p 0 0 .425 r
F P
0 g
s
.61962 .31766 m .64623 .32243 L .59822 .30039 L p .052 .536 .888 r
F P
0 g
s
.59822 .30039 m .58212 .30052 L .61962 .31766 L p .052 .536 .888 r
F P
0 g
s
.33451 .75737 m .34456 .78813 L .40264 .81426 L p .852 .476 .339 r
F P
0 g
s
.41302 .83952 m .40264 .81426 L .34456 .78813 L p .819 .377 .19 r
F P
0 g
s
.40264 .81426 m .41302 .83952 L .476 .85308 L p .745 .34 .284 r
F P
0 g
s
.67955 .35337 m .70808 .37135 L .66898 .33489 L p 0 .288 .763 r
F P
0 g
s
.66898 .33489 m .64623 .32243 L .67955 .35337 L p 0 .288 .763 r
F P
0 g
s
.30872 .41771 m .2903 .44693 L .28378 .49728 L p .941 .948 .623 r
F P
0 g
s
.27085 .53091 m .28378 .49728 L .2903 .44693 L p .899 .883 .454 r
F P
0 g
s
.74894 .70588 m .74278 .73929 L .77585 .6971 L p 0 0 .237 r
F P
0 g
s
.77585 .6971 m .78315 .66149 L .74894 .70588 L p 0 0 .237 r
F P
0 g
s
.42876 .31013 m .45052 .30808 L .49204 .29537 L p .381 .845 .856 r
F P
0 g
s
.45052 .30808 m .42876 .31013 L .38757 .3371 L p .641 .962 .911 r
F P
0 g
s
.38757 .3371 m .36147 .3522 L .33293 .39204 L p .795 .999 .817 r
F P
0 g
s
.30872 .41771 m .33293 .39204 L .36147 .3522 L p .7 .93 .612 r
F P
0 g
s
.2837 .68473 m .2905 .71918 L .33451 .75737 L p .942 .597 .34 r
F P
0 g
s
.34456 .78813 m .33451 .75737 L .2905 .71918 L p .911 .507 .188 r
F P
0 g
s
.75028 .44123 m .76898 .472 L .7487 .42236 L p 0 0 .509 r
F P
0 g
s
.7487 .42236 m .73113 .39472 L .75028 .44123 L p 0 0 .509 r
F P
0 g
s
.26297 .5655 m .25995 .6009 L .28192 .64997 L p .994 .768 .404 r
F P
0 g
s
.2837 .68473 m .28192 .64997 L .25995 .6009 L p .962 .693 .258 r
F P
0 g
s
.54115 .87368 m .54331 .85582 L .476 .85308 L p .595 .142 .146 r
F P
0 g
s
.54331 .85582 m .54115 .87368 L .59858 .86658 L p .47 .035 .129 r
F P
0 g
s
.59858 .86658 m .60917 .84758 L .54331 .85582 L p .47 .035 .129 r
F P
0 g
s
.58212 .30052 m .59822 .30039 L .54112 .29035 L p .028 .582 .824 r
F P
0 g
s
.54112 .29035 m .53779 .29273 L .58212 .30052 L p .028 .582 .824 r
F P
0 g
s
.48241 .87131 m .476 .85308 L .41302 .83952 L p .682 .198 .094 r
F P
0 g
s
.476 .85308 m .48241 .87131 L .54115 .87368 L p .595 .142 .146 r
F P
0 g
s
.68089 .80243 m .66781 .82888 L .71362 .801 L p .109 0 .098 r
F P
0 g
s
.71362 .801 m .7313 .77136 L .68089 .80243 L p .109 0 .098 r
F P
0 g
s
.78217 .59088 m .78506 .62603 L .79321 .57474 L p 0 0 .256 r
F P
0 g
s
.79321 .57474 m .79013 .53908 L .78217 .59088 L p 0 0 .256 r
F P
0 g
s
.36147 .3522 m .38757 .3371 L .42876 .31013 L p .445 .85 .667 r
F P
0 g
s
.48212 .29376 m .49204 .29537 L .53779 .29273 L p .146 .689 .805 r
F P
0 g
s
.49204 .29537 m .48212 .29376 L .42876 .31013 L p .381 .845 .856 r
F P
0 g
s
.53779 .29273 m .54112 .29035 L .48212 .29376 L p .146 .689 .805 r
F P
0 g
s
.60917 .84758 m .59858 .86658 L .64951 .85052 L p .272 0 .034 r
F P
0 g
s
.64951 .85052 m .66781 .82888 L .60917 .84758 L p .272 0 .034 r
F P
0 g
s
.2903 .44693 m .27732 .47881 L .27085 .53091 L p .899 .883 .454 r
F P
0 g
s
.26297 .5655 m .27085 .53091 L .27732 .47881 L p .803 .762 .248 r
F P
0 g
s
.70808 .37135 m .73113 .39472 L .68747 .35405 L p .546 .032 0 r
F P
0 g
s
.68747 .35405 m .66898 .33489 L .70808 .37135 L p .546 .032 0 r
F P
0 g
s
.76898 .472 m .78212 .50477 L .7611 .45333 L p .664 .326 0 r
F P
0 g
s
.7611 .45333 m .7487 .42236 L .76898 .472 L p .664 .326 0 r
F P
0 g
s
.74278 .73929 m .7313 .77136 L .76226 .73231 L p 0 0 .033 r
F P
0 g
s
.76226 .73231 m .77585 .6971 L .74278 .73929 L p 0 0 .033 r
F P
0 g
s
.64623 .32243 m .66898 .33489 L .61205 .30878 L p .387 0 0 r
F P
0 g
s
.61205 .30878 m .59822 .30039 L .64623 .32243 L p .387 0 0 r
F P
0 g
s
.25995 .6009 m .26195 .6371 L .2837 .68473 L p .962 .693 .258 r
F P
0 g
s
.2905 .71918 m .2837 .68473 L .26195 .6371 L p .884 .57 .062 r
F P
0 g
s
.36147 .3522 m .34033 .37338 L .30872 .41771 L p .7 .93 .612 r
F P
0 g
s
.2903 .44693 m .30872 .41771 L .34033 .37338 L p 0 0 0 r
F P
0 g
s
.34456 .78813 m .36008 .81604 L .41302 .83952 L p .819 .377 .19 r
F P
0 g
s
.42757 .85965 m .41302 .83952 L .36008 .81604 L p .724 .198 0 r
F P
0 g
s
.41302 .83952 m .42757 .85965 L .48241 .87131 L p .682 .198 .094 r
F P
0 g
s
.2905 .71918 m .30316 .75273 L .34456 .78813 L p .911 .507 .188 r
F P
0 g
s
.36008 .81604 m .34456 .78813 L .30316 .75273 L p .821 .349 0 r
F P
0 g
s
.78506 .62603 m .78315 .66149 L .79117 .61171 L p 0 0 .053 r
F P
0 g
s
.79117 .61171 m .79321 .57474 L .78506 .62603 L p 0 0 .053 r
F P
0 g
s
.42876 .31013 m .41011 .32032 L .36147 .3522 L p .445 .85 .667 r
F P
0 g
s
.41011 .32032 m .42876 .31013 L .48212 .29376 L p 0 0 0 r
F P
0 g
s
.27732 .47881 m .26941 .51282 L .26297 .5655 L p .803 .762 .248 r
F P
0 g
s
.25995 .6009 m .26297 .5655 L .26941 .51282 L p 0 0 0 r
F P
0 g
s
.66781 .82888 m .64951 .85052 L .68899 .82668 L p 0 0 0 r
F P
0 g
s
.68899 .82668 m .71362 .801 L .66781 .82888 L p 0 0 0 r
F P
0 g
s
.34033 .37338 m .36147 .3522 L .41011 .32032 L p 0 0 0 r
F P
0 g
s
.53832 .88401 m .54115 .87368 L .48241 .87131 L p .442 0 0 r
F P
0 g
s
.54115 .87368 m .53832 .88401 L .58475 .87831 L p .296 0 0 r
F P
0 g
s
.58475 .87831 m .59858 .86658 L .54115 .87368 L p .296 0 0 r
F P
0 g
s
.78212 .50477 m .79013 .53908 L .76868 .48702 L p .84 .526 0 r
F P
0 g
s
.76868 .48702 m .7611 .45333 L .78212 .50477 L p .84 .526 0 r
F P
0 g
s
.49079 .88211 m .48241 .87131 L .42757 .85965 L p .511 0 0 r
F P
0 g
s
.48241 .87131 m .49079 .88211 L .53832 .88401 L p .442 0 0 r
F P
0 g
s
.59822 .30039 m .61205 .30878 L .54398 .29684 L p .398 0 0 r
F P
0 g
s
.54398 .29684 m .54112 .29035 L .59822 .30039 L p .398 0 0 r
F P
0 g
s
.26195 .6371 m .26957 .67394 L .2905 .71918 L p .884 .57 .062 r
F P
0 g
s
.30316 .75273 m .2905 .71918 L .26957 .67394 L p .729 .378 0 r
F P
0 g
s
.73113 .39472 m .7487 .42236 L .70163 .37877 L p .79 .307 0 r
F P
0 g
s
.70163 .37877 m .68747 .35405 L .73113 .39472 L p .79 .307 0 r
F P
0 g
s
.7313 .77136 m .71362 .801 L .74141 .76612 L p 0 0 0 r
F P
0 g
s
.74141 .76612 m .76226 .73231 L .7313 .77136 L p 0 0 0 r
F P
0 g
s
.34033 .37338 m .32417 .39951 L .2903 .44693 L p 0 0 0 r
F P
0 g
s
.27732 .47881 m .2903 .44693 L .32417 .39951 L p 0 0 0 r
F P
0 g
s
.59858 .86658 m .58475 .87831 L .62571 .86546 L p .042 0 0 r
F P
0 g
s
.62571 .86546 m .64951 .85052 L .59858 .86658 L p .042 0 0 r
F P
0 g
s
.47359 .3009 m .48212 .29376 L .54112 .29035 L p .259 0 0 r
F P
0 g
s
.48212 .29376 m .47359 .3009 L .41011 .32032 L p 0 0 0 r
F P
0 g
s
.78315 .66149 m .77585 .6971 L .78342 .64985 L p .74 .711 .178 r
F P
0 g
s
.78342 .64985 m .79117 .61171 L .78315 .66149 L p .74 .711 .178 r
F P
0 g
s
.54112 .29035 m .54398 .29684 L .47359 .3009 L p .259 0 0 r
F P
0 g
s
.30316 .75273 m .32264 .78435 L .36008 .81604 L p .821 .349 0 r
F P
0 g
s
.38174 .83952 m .36008 .81604 L .32264 .78435 L p .609 .086 0 r
F P
0 g
s
.36008 .81604 m .38174 .83952 L .42757 .85965 L p .724 .198 0 r
F P
0 g
s
.66898 .33489 m .68747 .35405 L .62333 .3248 L p .679 .133 0 r
F P
0 g
s
.62333 .3248 m .61205 .30878 L .66898 .33489 L p .679 .133 0 r
F P
0 g
s
.26941 .51282 m .26636 .54873 L .25995 .6009 L p 0 0 0 r
F P
0 g
s
.26195 .6371 m .25995 .6009 L .26636 .54873 L p 0 0 .189 r
F P
0 g
s
.44655 .87276 m .42757 .85965 L .38174 .83952 L p .474 0 0 r
F P
0 g
s
.42757 .85965 m .44655 .87276 L .49079 .88211 L p .511 0 0 r
F P
0 g
s
.79013 .53908 m .79321 .57474 L .77159 .52316 L p .94 .665 .199 r
F P
0 g
s
.77159 .52316 m .76868 .48702 L .79013 .53908 L p .94 .665 .199 r
F P
0 g
s
.41011 .32032 m .39492 .33775 L .34033 .37338 L p 0 0 0 r
F P
0 g
s
.32417 .39951 m .34033 .37338 L .39492 .33775 L p .078 0 .043 r
F P
0 g
s
.39492 .33775 m .41011 .32032 L .47359 .3009 L p .256 0 0 r
F P
0 g
s
.26957 .67394 m .28375 .71093 L .30316 .75273 L p .729 .378 0 r
F P
0 g
s
.32264 .78435 m .30316 .75273 L .28375 .71093 L p 0 0 .462 r
F P
0 g
s
.32417 .39951 m .31275 .42961 L .27732 .47881 L p 0 0 0 r
F P
0 g
s
.26941 .51282 m .27732 .47881 L .31275 .42961 L p 0 0 .186 r
F P
0 g
s
.64951 .85052 m .62571 .86546 L .65713 .8465 L p 0 0 0 r
F P
0 g
s
.65713 .8465 m .68899 .82668 L .64951 .85052 L p 0 0 0 r
F P
0 g
s
.7487 .42236 m .7611 .45333 L .71165 .40803 L p .897 .478 .14 r
F P
0 g
s
.71165 .40803 m .70163 .37877 L .7487 .42236 L p .897 .478 .14 r
F P
0 g
s
.77585 .6971 m .76226 .73231 L .76902 .68873 L p .858 .862 .411 r
F P
0 g
s
.76902 .68873 m .78342 .64985 L .77585 .6971 L p .858 .862 .411 r
F P
0 g
s
.71362 .801 m .68899 .82668 L .71254 .79702 L p .622 .886 .561 r
F P
0 g
s
.71254 .79702 m .74141 .76612 L .71362 .801 L p .622 .886 .561 r
F P
0 g
s
.26636 .54873 m .26838 .58647 L .26195 .6371 L p 0 0 .189 r
F P
0 g
s
.26957 .67394 m .26195 .6371 L .26838 .58647 L p 0 0 .385 r
F P
0 g
s
.61205 .30878 m .62333 .3248 L .54632 .31139 L p .617 .108 .016 r
F P
0 g
s
.54632 .31139 m .54398 .29684 L .61205 .30878 L p .617 .108 .016 r
F P
0 g
s
.53484 .88494 m .53832 .88401 L .49079 .88211 L p .078 0 0 r
F P
0 g
s
.53832 .88401 m .53484 .88494 L .56774 .8809 L p 0 0 0 r
F P
0 g
s
.56774 .8809 m .58475 .87831 L .53832 .88401 L p 0 0 0 r
F P
0 g
s
.49079 .88211 m .50111 .88359 L .53484 .88494 L p .078 0 0 r
F P
0 g
s
.50111 .88359 m .49079 .88211 L .44655 .87276 L p 0 .472 .721 r
F P
0 g
s
.32264 .78435 m .34968 .81249 L .38174 .83952 L p .609 .086 0 r
F P
0 g
s
.38174 .83952 m .40985 .8567 L .44655 .87276 L p .474 0 0 r
F P
0 g
s
.40985 .8567 m .38174 .83952 L .34968 .81249 L p 0 .251 .714 r
F P
0 g
s
.79321 .57474 m .79117 .61171 L .76966 .56166 L p .987 .757 .367 r
F P
0 g
s
.76966 .56166 m .77159 .52316 L .79321 .57474 L p .987 .757 .367 r
F P
0 g
s
.68747 .35405 m .70163 .37877 L .63199 .34733 L p .794 .332 .143 r
F P
0 g
s
.63199 .34733 m .62333 .3248 L .68747 .35405 L p .794 .332 .143 r
F P
0 g
s
.46662 .31595 m .47359 .3009 L .54398 .29684 L p .482 .003 .042 r
F P
0 g
s
.47359 .3009 m .46662 .31595 L .39492 .33775 L p .256 0 0 r
F P
0 g
s
.58475 .87831 m .56774 .8809 L .59659 .87183 L p .3 .793 .777 r
F P
0 g
s
.59659 .87183 m .62571 .86546 L .58475 .87831 L p .3 .793 .777 r
F P
0 g
s
.54398 .29684 m .54632 .31139 L .46662 .31595 L p .482 .003 .042 r
F P
0 g
s
.31275 .42961 m .30577 .46299 L .26941 .51282 L p 0 0 .186 r
F P
0 g
s
.26636 .54873 m .26941 .51282 L .30577 .46299 L p .016 0 .343 r
F P
0 g
s
.39492 .33775 m .38327 .36126 L .32417 .39951 L p .078 0 .043 r
F P
0 g
s
.31275 .42961 m .32417 .39951 L .38327 .36126 L p .22 0 .246 r
F P
0 g
s
.76226 .73231 m .74141 .76612 L .74701 .72738 L p .915 .951 .611 r
F P
0 g
s
.74701 .72738 m .76902 .68873 L .76226 .73231 L p .915 .951 .611 r
F P
0 g
s
.28375 .71093 m .30546 .74709 L .32264 .78435 L p 0 0 .462 r
F P
0 g
s
.34968 .81249 m .32264 .78435 L .30546 .74709 L p 0 .153 .694 r
F P
0 g
s
.46983 .87698 m .44655 .87276 L .40985 .8567 L p 0 .491 .836 r
F P
0 g
s
.44655 .87276 m .46983 .87698 L .50111 .88359 L p 0 .472 .721 r
F P
0 g
s
.7611 .45333 m .76868 .48702 L .71778 .44111 L p .936 .576 .306 r
F P
0 g
s
.71778 .44111 m .71165 .40803 L .7611 .45333 L p .936 .576 .306 r
F P
0 g
s
.26838 .58647 m .27604 .62593 L .26957 .67394 L p 0 0 .385 r
F P
0 g
s
.28375 .71093 m .26957 .67394 L .27604 .62593 L p 0 .001 .548 r
F P
0 g
s
.38327 .36126 m .39492 .33775 L .46662 .31595 L p .399 .022 .204 r
F P
0 g
s
.68899 .82668 m .65713 .8465 L .67546 .82308 L p .73 .988 .803 r
F P
0 g
s
.67546 .82308 m .71254 .79702 L .68899 .82668 L p .73 .988 .803 r
F P
0 g
s
.62571 .86546 m .59659 .87183 L .61844 .85854 L p .562 .936 .885 r
F P
0 g
s
.61844 .85854 m .65713 .8465 L .62571 .86546 L p .562 .936 .885 r
F P
0 g
s
.79117 .61171 m .78342 .64985 L .76232 .60245 L p 1 .816 .501 r
F P
0 g
s
.76232 .60245 m .76966 .56166 L .79117 .61171 L p 1 .816 .501 r
F P
0 g
s
.62333 .3248 m .63199 .34733 L .54812 .33289 L p .7 .277 .238 r
F P
0 g
s
.54812 .33289 m .54632 .31139 L .62333 .3248 L p .7 .277 .238 r
F P
0 g
s
.30577 .46299 m .30308 .49933 L .26636 .54873 L p .016 0 .343 r
F P
0 g
s
.26838 .58647 m .26636 .54873 L .30308 .49933 L p .123 .024 .46 r
F P
0 g
s
.70163 .37877 m .71165 .40803 L .63814 .37529 L p .833 .442 .309 r
F P
0 g
s
.63814 .37529 m .63199 .34733 L .70163 .37877 L p .833 .442 .309 r
F P
0 g
s
.34968 .81249 m .38456 .83527 L .40985 .8567 L p 0 .251 .714 r
F P
0 g
s
.44412 .86568 m .40985 .8567 L .38456 .83527 L p .125 .526 .915 r
F P
0 g
s
.40985 .8567 m .44412 .86568 L .46983 .87698 L p 0 .491 .836 r
F P
0 g
s
.74141 .76612 m .71254 .79702 L .71672 .76428 L p .914 .98 .757 r
F P
0 g
s
.71672 .76428 m .74701 .72738 L .74141 .76612 L p .914 .98 .757 r
F P
0 g
s
.76868 .48702 m .77159 .52316 L .72015 .47763 L p .945 .637 .421 r
F P
0 g
s
.72015 .47763 m .71778 .44111 L .76868 .48702 L p .945 .637 .421 r
F P
0 g
s
.30546 .74709 m .33543 .78091 L .34968 .81249 L p 0 .153 .694 r
F P
0 g
s
.38456 .83527 m .34968 .81249 L .33543 .78091 L p .077 .382 .844 r
F P
0 g
s
.38327 .36126 m .37501 .3898 L .31275 .42961 L p .22 0 .246 r
F P
0 g
s
.30577 .46299 m .31275 .42961 L .37501 .3898 L p .308 .066 .374 r
F P
0 g
s
.27604 .62593 m .29026 .66671 L .28375 .71093 L p 0 .001 .548 r
F P
0 g
s
.30546 .74709 m .28375 .71093 L .29026 .66671 L p .052 .177 .677 r
F P
0 g
s
.53078 .87498 m .53484 .88494 L .50111 .88359 L p .36 .782 .975 r
F P
0 g
s
.53484 .88494 m .53078 .87498 L .54799 .87285 L p .435 .837 .977 r
F P
0 g
s
.54799 .87285 m .56774 .8809 L .53484 .88494 L p .435 .837 .977 r
F P
0 g
s
.46126 .3378 m .46662 .31595 L .54632 .31139 L p .577 .18 .254 r
F P
0 g
s
.46662 .31595 m .46126 .3378 L .38327 .36126 L p .399 .022 .204 r
F P
0 g
s
.51311 .87427 m .50111 .88359 L .46983 .87698 L p .331 .738 .98 r
F P
0 g
s
.50111 .88359 m .51311 .87427 L .53078 .87498 L p .36 .782 .975 r
F P
0 g
s
.56774 .8809 m .54799 .87285 L .56297 .86809 L p .538 .886 .983 r
F P
0 g
s
.56297 .86809 m .59659 .87183 L .56774 .8809 L p .538 .886 .983 r
F P
0 g
s
.54632 .31139 m .54812 .33289 L .46126 .3378 L p .577 .18 .254 r
F P
0 g
s
.78342 .64985 m .76902 .68873 L .74874 .64514 L p .989 .85 .609 r
F P
0 g
s
.74874 .64514 m .76232 .60245 L .78342 .64985 L p .989 .85 .609 r
F P
0 g
s
.65713 .8465 m .61844 .85854 L .63083 .84227 L p .744 .973 .926 r
F P
0 g
s
.63083 .84227 m .67546 .82308 L .65713 .8465 L p .744 .973 .926 r
F P
0 g
s
.4968 .87079 m .46983 .87698 L .44412 .86568 L p .347 .705 .984 r
F P
0 g
s
.46983 .87698 m .4968 .87079 L .51311 .87427 L p .331 .738 .98 r
F P
0 g
s
.37501 .3898 m .38327 .36126 L .46126 .3378 L p .473 .155 .346 r
F P
0 g
s
.30308 .49933 m .30486 .53855 L .26838 .58647 L p .123 .024 .46 r
F P
0 g
s
.27604 .62593 m .26838 .58647 L .30486 .53855 L p .211 .14 .554 r
F P
0 g
s
.59659 .87183 m .56297 .86809 L .57415 .86117 L p .637 .911 .981 r
F P
0 g
s
.57415 .86117 m .61844 .85854 L .59659 .87183 L p .637 .911 .981 r
F P
0 g
s
.71254 .79702 m .67546 .82308 L .67812 .79745 L p .875 .966 .851 r
F P
0 g
s
.67812 .79745 m .71672 .76428 L .71254 .79702 L p .875 .966 .851 r
F P
0 g
s
.29026 .66671 m .31194 .70788 L .30546 .74709 L p .052 .177 .677 r
F P
0 g
s
.33543 .78091 m .30546 .74709 L .31194 .70788 L p .196 .328 .772 r
F P
0 g
s
.77159 .52316 m .76966 .56166 L .71858 .51751 L p .942 .678 .507 r
F P
0 g
s
.71858 .51751 m .72015 .47763 L .77159 .52316 L p .942 .678 .507 r
F P
0 g
s
.71165 .40803 m .71778 .44111 L .64191 .40786 L p .846 .508 .413 r
F P
0 g
s
.64191 .40786 m .63814 .37529 L .71165 .40803 L p .846 .508 .413 r
F P
0 g
s
.33543 .78091 m .37378 .81043 L .38456 .83527 L p .077 .382 .844 r
F P
0 g
s
.42672 .85072 m .38456 .83527 L .37378 .81043 L p .291 .548 .921 r
F P
0 g
s
.38456 .83527 m .42672 .85072 L .44412 .86568 L p .125 .526 .915 r
F P
0 g
s
.37501 .3898 m .36995 .4226 L .30577 .46299 L p .308 .066 .374 r
F P
0 g
s
.30308 .49933 m .30577 .46299 L .36995 .4226 L p .368 .162 .463 r
F P
0 g
s
.63199 .34733 m .63814 .37529 L .5494 .36022 L p .733 .372 .367 r
F P
0 g
s
.5494 .36022 m .54812 .33289 L .63199 .34733 L p .733 .372 .367 r
F P
0 g
s
.48353 .86488 m .44412 .86568 L .42672 .85072 L p .394 .681 .975 r
F P
0 g
s
.44412 .86568 m .48353 .86488 L .4968 .87079 L p .347 .705 .984 r
F P
0 g
s
.76902 .68873 m .74701 .72738 L .72806 .68882 L p .963 .868 .697 r
F P
0 g
s
.72806 .68882 m .74874 .64514 L .76902 .68873 L p .963 .868 .697 r
F P
0 g
s
.30486 .53855 m .31163 .58058 L .27604 .62593 L p .211 .14 .554 r
F P
0 g
s
.29026 .66671 m .27604 .62593 L .31163 .58058 L p .286 .242 .632 r
F P
0 g
s
.45745 .36535 m .46126 .3378 L .54812 .33289 L p .622 .283 .376 r
F P
0 g
s
.46126 .3378 m .45745 .36535 L .37501 .3898 L p .473 .155 .346 r
F P
0 g
s
.61844 .85854 m .57415 .86117 L .58028 .85278 L p .709 .905 .965 r
F P
0 g
s
.58028 .85278 m .63083 .84227 L .61844 .85854 L p .709 .905 .965 r
F P
0 g
s
.54812 .33289 m .5494 .36022 L .45745 .36535 L p .622 .283 .376 r
F P
0 g
s
.31194 .70788 m .34169 .7479 L .33543 .78091 L p .196 .328 .772 r
F P
0 g
s
.37378 .81043 m .33543 .78091 L .34169 .7479 L p .317 .454 .841 r
F P
0 g
s
.67546 .82308 m .63083 .84227 L .63212 .82464 L p .816 .927 .907 r
F P
0 g
s
.63212 .82464 m .67812 .79745 L .67546 .82308 L p .816 .927 .907 r
F P
0 g
s
.36995 .4226 m .37501 .3898 L .45745 .36535 L p .517 .242 .436 r
F P
0 g
s
.52632 .85341 m .53078 .87498 L .51311 .87427 L closepath p .576 .8 .984 r
F P
0 g
s
.52632 .85341 m .54799 .87285 L .53078 .87498 L closepath p .594 .813 .984 r
F P
0 g
s
.76966 .56166 m .76232 .60245 L .71264 .5607 L p .932 .709 .578 r
F P
0 g
s
.71264 .5607 m .71858 .51751 L .76966 .56166 L p .932 .709 .578 r
F P
0 g
s
.52632 .85341 m .51311 .87427 L .4968 .87079 L closepath p .565 .786 .982 r
F P
0 g
s
.52632 .85341 m .56297 .86809 L .54799 .87285 L closepath p .615 .821 .979 r
F P
0 g
s
.74701 .72738 m .71672 .76428 L .69976 .73194 L p .925 .873 .767 r
F P
0 g
s
.69976 .73194 m .72806 .68882 L .74701 .72738 L p .925 .873 .767 r
F P
0 g
s
.37378 .81043 m .41971 .83355 L .42672 .85072 L p .291 .548 .921 r
F P
0 g
s
.47474 .85713 m .42672 .85072 L .41971 .83355 L p .452 .664 .953 r
F P
0 g
s
.42672 .85072 m .47474 .85713 L .48353 .86488 L p .394 .681 .975 r
F P
0 g
s
.36995 .4226 m .368 .45927 L .30308 .49933 L p .368 .162 .463 r
F P
0 g
s
.30486 .53855 m .30308 .49933 L .368 .45927 L p .413 .237 .531 r
F P
0 g
s
.71778 .44111 m .72015 .47763 L .64337 .44465 L p .849 .553 .487 r
F P
0 g
s
.64337 .44465 m .64191 .40786 L .71778 .44111 L p .849 .553 .487 r
F P
0 g
s
.52632 .85341 m .4968 .87079 L .48353 .86488 L closepath p .561 .771 .976 r
F P
0 g
s
.52632 .85341 m .57415 .86117 L .56297 .86809 L closepath p .637 .824 .972 r
F P
0 g
s
.31163 .58058 m .32414 .62508 L .29026 .66671 L p .286 .242 .632 r
F P
0 g
s
.31194 .70788 m .29026 .66671 L .32414 .62508 L p .352 .334 .699 r
F P
0 g
s
.63814 .37529 m .64191 .40786 L .55019 .39256 L p .748 .433 .449 r
F P
0 g
s
.55019 .39256 m .5494 .36022 L .63814 .37529 L p .748 .433 .449 r
F P
0 g
s
.52632 .85341 m .48353 .86488 L .47474 .85713 L closepath p .565 .757 .968 r
F P
0 g
s
.34169 .7479 m .37944 .7847 L .37378 .81043 L p .317 .454 .841 r
F P
0 g
s
.41971 .83355 m .37378 .81043 L .37944 .7847 L p .42 .561 .89 r
F P
0 g
s
.63083 .84227 m .58028 .85278 L .58062 .84381 L p .747 .875 .939 r
F P
0 g
s
.58062 .84381 m .63212 .82464 L .63083 .84227 L p .747 .875 .939 r
F P
0 g
s
.52632 .85341 m .58028 .85278 L .57415 .86117 L closepath p .656 .821 .963 r
F P
0 g
s
.71672 .76428 m .67812 .79745 L .66399 .77235 L p .878 .869 .825 r
F P
0 g
s
.66399 .77235 m .69976 .73194 L .71672 .76428 L p .878 .869 .825 r
F P
0 g
s
.76232 .60245 m .74874 .64514 L .70166 .60687 L p .916 .733 .639 r
F P
0 g
s
.70166 .60687 m .71264 .5607 L .76232 .60245 L p .916 .733 .639 r
F P
0 g
s
.45512 .39776 m .45745 .36535 L .5494 .36022 L p .646 .35 .455 r
F P
0 g
s
.45745 .36535 m .45512 .39776 L .36995 .4226 L p .517 .242 .436 r
F P
0 g
s
.41971 .83355 m .47144 .84833 L .47474 .85713 L p .452 .664 .953 r
F P
0 g
s
.52632 .85341 m .47474 .85713 L .47144 .84833 L closepath p .575 .746 .958 r
F P
0 g
s
.368 .45927 m .36995 .4226 L .45512 .39776 L p .545 .304 .501 r
F P
0 g
s
.368 .45927 m .36929 .49971 L .30486 .53855 L p .413 .237 .531 r
F P
0 g
s
.31163 .58058 m .30486 .53855 L .36929 .49971 L p .45 .303 .589 r
F P
0 g
s
.32414 .62508 m .34315 .67114 L .31194 .70788 L p .352 .334 .699 r
F P
0 g
s
.34169 .7479 m .31194 .70788 L .34315 .67114 L p .411 .418 .757 r
F P
0 g
s
.37944 .7847 m .42422 .81595 L .41971 .83355 L p .42 .561 .89 r
F P
0 g
s
.47144 .84833 m .41971 .83355 L .42422 .81595 L p .509 .655 .925 r
F P
0 g
s
.5494 .36022 m .55019 .39256 L .45512 .39776 L p .646 .35 .455 r
F P
0 g
s
.72015 .47763 m .71858 .51751 L .6424 .48554 L p .847 .587 .545 r
F P
0 g
s
.6424 .48554 m .64337 .44465 L .72015 .47763 L p .847 .587 .545 r
F P
0 g
s
.52632 .85341 m .58062 .84381 L .58028 .85278 L closepath p .669 .813 .953 r
F P
0 g
s
.67812 .79745 m .63212 .82464 L .62178 .80757 L p .823 .856 .872 r
F P
0 g
s
.62178 .80757 m .66399 .77235 L .67812 .79745 L p .823 .856 .872 r
F P
0 g
s
.42422 .81595 m .47407 .83942 L .47144 .84833 L p .509 .655 .925 r
F P
0 g
s
.52632 .85341 m .47144 .84833 L .47407 .83942 L closepath p .589 .739 .947 r
F P
0 g
s
.74874 .64514 m .72806 .68882 L .685 .65513 L p .896 .752 .695 r
F P
0 g
s
.685 .65513 m .70166 .60687 L .74874 .64514 L p .896 .752 .695 r
F P
0 g
s
.52632 .85341 m .56401 .82796 L .57502 .83521 L closepath p .677 .788 .933 r
F P
0 g
s
.52632 .85341 m .54874 .82289 L .56401 .82796 L closepath p .673 .773 .926 r
F P
0 g
s
.52632 .85341 m .53092 .82061 L .54874 .82289 L closepath p .664 .76 .922 r
F P
0 g
s
.52632 .85341 m .51256 .82138 L .53092 .82061 L closepath p .652 .749 .921 r
F P
0 g
s
.52632 .85341 m .49578 .82512 L .51256 .82138 L closepath p .638 .741 .924 r
F P
0 g
s
.52632 .85341 m .48247 .83138 L .49578 .82512 L closepath p .622 .737 .929 r
F P
0 g
s
.52632 .85341 m .47407 .83942 L .48247 .83138 L closepath p .605 .736 .937 r
F P
0 g
s
.52632 .85341 m .57502 .83521 L .58062 .84381 L closepath p .676 .801 .942 r
F P
0 g
s
.64191 .40786 m .64337 .44465 L .55049 .42946 L p .756 .476 .509 r
F P
0 g
s
.55049 .42946 m .55019 .39256 L .64191 .40786 L p .756 .476 .509 r
F P
0 g
s
.63212 .82464 m .58062 .84381 L .57502 .83521 L p .757 .834 .911 r
F P
0 g
s
.57502 .83521 m .62178 .80757 L .63212 .82464 L p .757 .834 .911 r
F P
0 g
s
.34315 .67114 m .36909 .71719 L .34169 .7479 L p .411 .418 .757 r
F P
0 g
s
.37944 .7847 m .34169 .7479 L .36909 .71719 L p .464 .498 .808 r
F P
0 g
s
.36929 .49971 m .3742 .54388 L .31163 .58058 L p .45 .303 .589 r
F P
0 g
s
.32414 .62508 m .31163 .58058 L .3742 .54388 L p .482 .363 .641 r
F P
0 g
s
.45512 .39776 m .45421 .43463 L .368 .45927 L p .545 .304 .501 r
F P
0 g
s
.36929 .49971 m .368 .45927 L .45421 .43463 L p .566 .355 .552 r
F P
0 g
s
.44016 .79989 m .48247 .83138 L .47407 .83942 L p .56 .654 .898 r
F P
0 g
s
.47407 .83942 m .42422 .81595 L .44016 .79989 L p .56 .654 .898 r
F P
0 g
s
.36909 .71719 m .40176 .76097 L .37944 .7847 L p .464 .498 .808 r
F P
0 g
s
.42422 .81595 m .37944 .7847 L .40176 .76097 L p .513 .575 .855 r
F P
0 g
s
.71858 .51751 m .71264 .5607 L .63875 .5305 L p .842 .615 .595 r
F P
0 g
s
.63875 .5305 m .6424 .48554 L .71858 .51751 L p .842 .615 .595 r
F P
0 g
s
.45421 .43463 m .45512 .39776 L .55019 .39256 L p .661 .398 .512 r
F P
0 g
s
.72806 .68882 m .69976 .73194 L .66233 .70386 L p .871 .768 .746 r
F P
0 g
s
.66233 .70386 m .685 .65513 L .72806 .68882 L p .871 .768 .746 r
F P
0 g
s
.40176 .76097 m .44016 .79989 L .42422 .81595 L p .513 .575 .855 r
F P
0 g
s
.62178 .80757 m .57502 .83521 L .56401 .82796 L p .75 .792 .887 r
F P
0 g
s
.55019 .39256 m .55049 .42946 L .45421 .43463 L p .661 .398 .512 r
F P
0 g
s
.46606 .78726 m .49578 .82512 L .48247 .83138 L p .605 .661 .878 r
F P
0 g
s
.48247 .83138 m .44016 .79989 L .46606 .78726 L p .605 .661 .878 r
F P
0 g
s
.69976 .73194 m .66399 .77235 L .63387 .75073 L p .84 .78 .794 r
F P
0 g
s
.63387 .75073 m .66233 .70386 L .69976 .73194 L p .84 .78 .794 r
F P
0 g
s
.3742 .54388 m .38325 .59149 L .32414 .62508 L p .482 .363 .641 r
F P
0 g
s
.34315 .67114 m .32414 .62508 L .38325 .59149 L p .51 .42 .689 r
F P
0 g
s
.66399 .77235 m .62178 .80757 L .60056 .79301 L p .801 .789 .841 r
F P
0 g
s
.56401 .82796 m .60056 .79301 L .62178 .80757 L p .75 .792 .887 r
F P
0 g
s
.64337 .44465 m .6424 .48554 L .55029 .47081 L p .759 .51 .556 r
F P
0 g
s
.55029 .47081 m .55049 .42946 L .64337 .44465 L p .759 .51 .556 r
F P
0 g
s
.60056 .79301 m .56401 .82796 L .54874 .82289 L p .732 .754 .87 r
F P
0 g
s
.60056 .79301 m .63387 .75073 L .66399 .77235 L p .801 .789 .841 r
F P
0 g
s
.71264 .5607 m .70166 .60687 L .63201 .57926 L p .835 .641 .641 r
F P
0 g
s
.63201 .57926 m .63875 .5305 L .71264 .5607 L p .835 .641 .641 r
F P
0 g
s
.49911 .77967 m .51256 .82138 L .49578 .82512 L p .644 .675 .865 r
F P
0 g
s
.49578 .82512 m .46606 .78726 L .49911 .77967 L p .644 .675 .865 r
F P
0 g
s
.45421 .43463 m .45481 .47582 L .36929 .49971 L p .566 .355 .552 r
F P
0 g
s
.3742 .54388 m .36929 .49971 L .45481 .47582 L p .584 .399 .597 r
F P
0 g
s
.54874 .82289 m .57064 .78274 L .60056 .79301 L p .732 .754 .87 r
F P
0 g
s
.57064 .78274 m .54874 .82289 L .53092 .82061 L p .707 .722 .861 r
F P
0 g
s
.38325 .59149 m .39695 .64163 L .34315 .67114 L p .51 .42 .689 r
F P
0 g
s
.36909 .71719 m .34315 .67114 L .39695 .64163 L p .537 .477 .736 r
F P
0 g
s
.53542 .77809 m .53092 .82061 L .51256 .82138 L p .678 .695 .859 r
F P
0 g
s
.51256 .82138 m .49911 .77967 L .53542 .77809 L p .678 .695 .859 r
F P
0 g
s
.43887 .74216 m .46606 .78726 L .44016 .79989 L p .584 .594 .829 r
F P
0 g
s
.44016 .79989 m .40176 .76097 L .43887 .74216 L p .584 .594 .829 r
F P
0 g
s
.53092 .82061 m .53542 .77809 L .57064 .78274 L p .707 .722 .861 r
F P
0 g
s
.45481 .47582 m .45421 .43463 L .55049 .42946 L p .671 .437 .558 r
F P
0 g
s
.39695 .64163 m .41557 .69266 L .36909 .71719 L p .537 .477 .736 r
F P
0 g
s
.40176 .76097 m .36909 .71719 L .41557 .69266 L p .561 .534 .782 r
F P
0 g
s
.41557 .69266 m .43887 .74216 L .40176 .76097 L p .561 .534 .782 r
F P
0 g
s
.55049 .42946 m .55029 .47081 L .45481 .47582 L p .671 .437 .558 r
F P
0 g
s
.70166 .60687 m .685 .65513 L .62182 .63091 L p .825 .665 .685 r
F P
0 g
s
.62182 .63091 m .63201 .57926 L .70166 .60687 L p .825 .665 .685 r
F P
0 g
s
.63387 .75073 m .60056 .79301 L .57064 .78274 L p .769 .732 .819 r
F P
0 g
s
.6424 .48554 m .63875 .5305 L .54953 .51661 L p .76 .54 .599 r
F P
0 g
s
.54953 .51661 m .55029 .47081 L .6424 .48554 L p .76 .54 .599 r
F P
0 g
s
.45481 .47582 m .45707 .52133 L .3742 .54388 L p .584 .399 .597 r
F P
0 g
s
.38325 .59149 m .3742 .54388 L .45707 .52133 L p .599 .441 .64 r
F P
0 g
s
.48674 .73077 m .49911 .77967 L .46606 .78726 L p .64 .619 .813 r
F P
0 g
s
.46606 .78726 m .43887 .74216 L .48674 .73077 L p .64 .619 .813 r
F P
0 g
s
.685 .65513 m .66233 .70386 L .608 .68378 L p .811 .688 .728 r
F P
0 g
s
.608 .68378 m .62182 .63091 L .685 .65513 L p .811 .688 .728 r
F P
0 g
s
.66233 .70386 m .63387 .75073 L .59073 .73538 L p .793 .71 .773 r
F P
0 g
s
.57064 .78274 m .59073 .73538 L .63387 .75073 L p .769 .732 .819 r
F P
0 g
s
.45707 .52133 m .45481 .47582 L .55029 .47081 L p .679 .472 .599 r
F P
0 g
s
.59073 .73538 m .57064 .78274 L .53542 .77809 L p .73 .686 .808 r
F P
0 g
s
.59073 .73538 m .608 .68378 L .66233 .70386 L p .793 .71 .773 r
F P
0 g
s
.53957 .7284 m .53542 .77809 L .49911 .77967 L p .688 .649 .806 r
F P
0 g
s
.49911 .77967 m .48674 .73077 L .53957 .7284 L p .688 .649 .806 r
F P
0 g
s
.45707 .52133 m .46124 .57089 L .38325 .59149 L p .599 .441 .64 r
F P
0 g
s
.39695 .64163 m .38325 .59149 L .46124 .57089 L p .612 .483 .681 r
F P
0 g
s
.55029 .47081 m .54953 .51661 L .45707 .52133 L p .679 .472 .599 r
F P
0 g
s
.63875 .5305 m .63201 .57926 L .54813 .56657 L p .76 .569 .639 r
F P
0 g
s
.54813 .56657 m .54953 .51661 L .63875 .5305 L p .76 .569 .639 r
F P
0 g
s
.53542 .77809 m .53957 .7284 L .59073 .73538 L p .73 .686 .808 r
F P
0 g
s
.47608 .67773 m .48674 .73077 L .43887 .74216 L p .633 .57 .766 r
F P
0 g
s
.43887 .74216 m .41557 .69266 L .47608 .67773 L p .633 .57 .766 r
F P
0 g
s
.46124 .57089 m .46755 .62359 L .39695 .64163 L p .612 .483 .681 r
F P
0 g
s
.41557 .69266 m .39695 .64163 L .46755 .62359 L p .623 .525 .723 r
F P
0 g
s
.46755 .62359 m .47608 .67773 L .41557 .69266 L p .623 .525 .723 r
F P
0 g
s
.46124 .57089 m .45707 .52133 L .54953 .51661 L p .685 .506 .639 r
F P
0 g
s
.608 .68378 m .59073 .73538 L .53957 .7284 L p .744 .655 .762 r
F P
0 g
s
.63201 .57926 m .62182 .63091 L .54601 .61982 L p .757 .597 .679 r
F P
0 g
s
.54601 .61982 m .54813 .56657 L .63201 .57926 L p .757 .597 .679 r
F P
0 g
s
.54953 .51661 m .54813 .56657 L .46124 .57089 L p .685 .506 .639 r
F P
0 g
s
.54314 .67461 m .53957 .7284 L .48674 .73077 L p .691 .609 .759 r
F P
0 g
s
.48674 .73077 m .47608 .67773 L .54314 .67461 L p .691 .609 .759 r
F P
0 g
s
.62182 .63091 m .608 .68378 L .54314 .67461 L p .752 .625 .719 r
F P
0 g
s
.53957 .7284 m .54314 .67461 L .608 .68378 L p .744 .655 .762 r
F P
0 g
s
.54314 .67461 m .54601 .61982 L .62182 .63091 L p .752 .625 .719 r
F P
0 g
s
.46755 .62359 m .46124 .57089 L .54813 .56657 L p .689 .539 .677 r
F P
0 g
s
.54601 .61982 m .54314 .67461 L .47608 .67773 L p .691 .573 .717 r
F P
0 g
s
.47608 .67773 m .46755 .62359 L .54601 .61982 L p .691 .573 .717 r
F P
0 g
s
.54813 .56657 m .54601 .61982 L .46755 .62359 L p .689 .539 .677 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0MOooool=o`0002[ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0]ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0J?ooool<o`0000Wo@P0000Co0000ofD00?mU003oI@001_l0000Tooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l00005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Tooooo`Co0000
2Om2000?o`0000KoI@001Ol0000Oooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;?ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05oooooo4Ol0000;og/02P04o`000?nM6`CoWA/4oidK10Go00001_mU0004o`0001_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003ooooooooo
o`04ooooo`;o00004_ooool00ol0003oooooooooo`1Kooooo`So000000?o@@00o`000?mk00X05?mk
00X00ol0003oWA/4oidK1006oidK10Ko00001?mU0002o`0001Wooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Eoooool8o`0000?o@@0000?o0000og/02_mk00X05Omk00X0
0ol0003oWA/4oidK100;oidK10Go000000?oI@00o`000?l000005oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo02[ooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1Cooooo`So00001_m100000ol0003oN`0:og/02P0Eog/0
2P03o`000?nM6`CoWA/4013oWA/41_l0000Dooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0:Oooool0027ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo057ooooo1_l00009od400003o`000?mk00[oN`0:00WoN`0:4?l0000AoidK1003
o`000?n]8P3o000000?o00004_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wo
oooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0C_ooool6o`0000So@@00
3ol0000<oi<^@@04o`000?ncASco/dHlok=6?0Ko00003?nM6`@00ol0003o[B80ojdR0004o`00013o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04cooooo1?l00008od4000?o00000_mV1C@00ol0003oTbi1
oi<^@@0Foi<^@@03o`000?ncASco/dHl00Oo/dHl1_l00007oidK1003o`000?n]8P3o[B8000;o[B80
0ol0000>ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`19ooooo`?o00002?m10003o`0000GoIPDd00?o
0000oi<^@OnC;T405_nC;T400ol0003o/dHlok=6?00=ok=6?0Ko000000?oWA/4o`000?n]8P001On]
8P03o`0000cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2
o`0001[ooooo00?o0000ooooooooool0Aoooool3o`0000Ko@@000ol00008ofH5=003o`000?nC;T7o
Tbi101OoTbi100?o0000ok=6??ncAS`04_ncAS`4o`0000Ko[B800ol0000;ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`15ooooo`?o00001?m10003o`0000[oIPDd00?o0000oi<^@OnC;T406?nC;T400ol0
003o/dHlok=6?00Dok=6?004o`000?o;E2Co0000o`0000Ko[B800ol00009ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`Co00000_m10003o`0000goIPDd00?o0000oi<^@OnC;T404OnC;T4;o`00
01Co/dHl00?o0000ol]D9?o;E2@00ol00006ojdR00;o00001oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@?ooool7o`00013oIPDd00?o0000oi<^@OnC;T401?nC;T4=o`0000OoWdQP00Co0000ok]OGOnk
Gego^emM1Ol0000?ok=6?003o`000?o;E2Cobe@T00?obe@T0_l00006ojdR0003o`000?oooooooooo
00Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo03gooooo1_l0000AofH5=0Wo00005?nOB6000ol0003o
^emMok]OG@06ok]OG@Go00002oncAS`00ol0003obe@Tol]D9004ol]D90;o00001?n]8P02o`0000Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03_ooooo1?l000000olC00_o0000ofH5=00>ofH5=0?o0000
0_mi9eP00ol0003oWdQPoim8H00Hoim8H003o`000?nkGego^emM00_o^emM1Ol00006ok=6?003o`00
0?o;E2Cobe@T00Kobe@T0_l00003ojdR00;o00001?ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0003oooooooooo`0hooooo`Go000000?o
4`0;o`000?mV1C@02omV1C@4o`0000GoNBMH00?o0000oim8H?nOB6006?nOB6000ol0003o^emMok]O
G@0@ok]OG@Go000000?o/dHlo`000?o;E2@02Oo;E2@2o`0000;o[B800_l00003ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0eooooo`Go00000olC00/00ol0003oIPDdofH5=006ofH5=0Co00002?mi9eP0
0ol0003oWdQPoim8H00Ioim8H003o`000?nkGego^emM01Go^emM1?l0000:ol]D90Go00000_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0<oooool5o`0000?o4`0;00?o0000ofH5=?mV1C@01?mV1C@3o`00
00coNBMH00?o0000oim8H?nOB6006OnOB6000ol0003o^emMok]OG@0Gok]OG@04o`000?oELDoo0000
o`0000_obe@T0ol000000ooooooo0000ooooo`0kooooo`03o`000?oooooooooo027ooooo000Xoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0<Oooool4o`0000Co4`0;00Co0000ofH5
=?mV1CCoIPDd1?l0000?ogTWF003o`000?nOB63oWdQP01WoWdQP00?o0000ok]OGOnkGed05onkGed0
1?l0003oeG5?omEaCooELDl3o`0000[obe@T0ol0000looooo`03o`000?oooooooooo027ooooo000W
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0;oooool3o`0000Ko4`0;1?l0000C
ogTWF003o`000?nOB63oWdQP01WoWdQP00?o0000ok]OGOnkGed06?nkGed00ol0003oeG5?omEaC`03
omEaC`;o00002?o;E2@00ol0003obTh0o`00000mooooo`03o`000?oooooooooo023ooooo000Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0;Oooool3o`0000Go4`0;0ol0000FogTW
F003o`000?nOB63oWdQP01;oWdQP2ol0000Gok]OG@03o`000?oELDooeG5?00GoeG5?0_l00007ol]D
90?o0000??ooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02_ooooo0_l00006oa<02`03o`000?lh03ko000001KoNBMH00?o0000oim8H?nO
B6001?nOB60?o`0000OoYEUd00Co0000okm^L_noKW;o_fib1Ol0000Bok]OG@03o`000?oELDooeG5?
00OoeG5?0_l00006ol]D9003o`000?o:CP3o000003cooooo00?o0000ooooooooool07oooool002Oo
oooo0_l0000Yooooo`03o`000?oooooooooo02Wooooo0_l00005oa<02`;o00000_lh03h00ol0003o
NBMHogTWF00BogTWF0Wo00005_nUFG@00ol0003o_fibokm^LP06okm^LPKo00003?nkGed00ol0003o
eG5?omEaC`09omEaC`;o00001?o;E2@01?l0003obTh0olY>0?l0000looooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003o
4`0;oa<02`04oa<02`05o`000?lh03ko>00nocP0?_l000004_mi9eP3o`0000;oQ3e_00?o0000ojEI
M?nUFG@06_nUFG@00ol0003o_fibokm^LP0<okm^LPKo00001_nkGed00ol0003oeG5?omEaC`0;omEa
C`?o000000?obe@To`000?l000000_o:CP000ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool09Oooool00ol0003o
4`0;oa<02`03oa<02`;o00001?lh03h00ol0003oNBMHogTWF00<ogTWF0Co00001On4?Fl00ol0003o
YEUdojEIM00JojEIM003o`000?noKW;o_fib01;o_fib1Ol00002ok]OG@03o`000?oELDooeG5?00go
eG5?0ol00003olY>0003o`000?oooooooooo03Wooooo00?o0000ooooooooool07Oooool002Oooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`03o`000?lC00_o4`0;00;o4`0;
00?o0000ocP0?_lh03h01?lh03h00ol0003oNBMHogTWF008ogTWF0Co00002On4?Fl00ol0003oYEUd
ojEIM00JojEIM003o`000?noKW;o_fib01Oo_fib1?l0000?omEaC`?o00000oo:CP000ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08_ooool01?l0003o4`0;oa<02olC00/2o`0000Oo>00n00?o0000ogTWF?mi9eP0
1Omi9eP3o`0000goQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fibokm^LP0Iokm^LP04o`00
0?oHPVWo0000o`0000goeG5?00?o0000omEaCooELDl00_l00002olY>0003o`000?oooooooooo03So
oooo00?o0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Pooooo`05o`000?lC00_o4`0;oa<02ol000002Olh03h01?l0003oNBMHogTWF?mi9eP4o`00
013oQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fibokm^LP0Iokm^LP04o`000?oHPVWof89Y
omR2J@?o00002_oELDl01_l0003oeG5?omEaCol0003oiGXSo`0000;obTh000?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Kooooo`009_ooool3o`0002oooooo00?o0000ooooooooool07_oo
ool2o`000003oa<02ol0003o000000Wo>00n00?o0000ogTWF?l000000_l0000Doh@mK`03o`000?nU
FGCoYEUd01[oYEUd00?o0000okm^L_noKW806OnoKW800ol0003of89YomR2J@04omR2J@;o00002OoE
LDl01_l0003oeG5?omEaCol0003oiGXSo`0000;obTh000?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo
00?o0000oa<02ol000002_lh03h3o`0001OoQ3e_00?o0000ojEIM?nUFG@06_nUFG@00ol0003o_fib
okm^LP0Iokm^LP03o`000?oHPVWof89Y00Kof89Y0_l00007omEaC`04o`000?oELDooeG5?o`0000;o
iGXS00Co0000olY>0?o:CP3o0000>Oooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01_ooooo0ol0000:ocP0?P03o`000?m>45oo
000001SoQ3e_00?o0000ojEIM?nUFG@04onUFG@;o`0001So_fib00?o0000omR2JOoHPVT02?oHPVT3
o`0000CoeG5?00Co0000omEaCooELDoo00000ooUNR<01?l0003obTh0olY>0?l0000hooooo`03o`00
0?oooooooooo01[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Wooooo
0_l0000:ocP0?P;o00000_m>45l00ol0003oQ3e_oh@mK`0Foh@mK`03o`000?nUFGCoYEUd00CoYEUd
3ol00007ojUUP`04o`000?o1NH;o`GV2ol5iPPKo00004onoKW800ol0003of89YomR2J@0:omR2J@;o
00000_oELDl01Ol0003oeG5?omEaCooELDoo000000?oiGXS00Co0000olY>0?o:CP3o0000>?ooool0
0ol0003oooooooooo`0Iooooo`000oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0H
ooooo`03o`000?lh03ko>00n00So>00n00?o0000odh@Gom>45l00_m>45l00ol0003oQ3e_oh@mK`0D
oh@mK`Wo00005_nYIH<00ol0003o`GV2ol5iPP07ol5iPPKo00003OnoKW800ol0003of89YomR2J@0<
omR2J@?o00000ooELDl00ol0003oiGXSonEj8`02onEj8`03o`000?o:CP3o000003Wooooo00?o0000
ooooooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`;o00002?lh03h2
o`0000CoCQ1O00?o0000oh@mKon4?Fl04_n4?Fl3o`0000;oRdf000?o0000ojUUPonYIH<06_nYIH<0
0ol0003o`GV2ol5iPP0=ol5iPPGo00002?noKW800ol0003of89YomR2J@0>omR2J@?o000000?oeG5?
o`000?oUNR<01?oUNR<00ol0003obTh0o`00000hooooo`03o`000?oooooooooo01Sooooo000;oooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`;o00002?lh03h00ol0003oCQ1Oodh@
G`04odh@G`03o`000?n4?FooQ3e_00ooQ3e_0ol00005oh]=P003o`000?nYIH?oZFF301[oZFF300?o
0000ol5iP_o1NH804_o1NH86o`0000;o_fib00?o0000omR2JOoHPVT03_oHPVT00ol0003of89YomR2
J@03o`0000GoiGXS00?o0000olY>0?l00000>?ooool00ol0003oooooooooo`0Gooooo`002oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o
0000ooooooooool04_ooool3o`0000Ko>00n0_l00007odh@G`03o`000?n4?FooQ3e_00_oQ3e_1?l0
0008oh]=P003o`000?nYIH?oZFF301[oZFF300?o0000ol5iP_o1NH806?o1NH84o`0000oof89Y00?o
0000omR2JOoHPVT00_oHPVT2o`0000GoiGXS0_l0000hooooo`03o`000?oooooooooo01Oooooo000;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool04Oooool3o`0000Co>00n0_l00009odh@G`03o`000?n4
?FooQ3e_00SoQ3e_0ol0000<oh]=P003o`000?nYIH?oZFF301[oZFF300?o0000ol5iP_o1NH806_o1
NH800ol0003ofHelo`000002o`0000cof89Y00?o0000omR2JOoHPVT00_oHPVT00ol0003oki=>o`00
0005onEj8`;o0000>?ooool00ol0003oooooooooo`0Fooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03ooo
ool3o`0000Co>00n00?o0000odh@Gom>45l02Om>45l00ol0003oQ3e_oh@mK`04oh@mK`Co00003on;
CH000ol0003oZFF3ojUUP`0JojUUP`03o`000?o1NH;o`GV201[o`GV200?o0000omV=O?oISG`00_oI
SG`2o`0000[of89Y00?o0000omR2JOoHPVT00_oHPVT01?l0003oki=>onnCC_l00005onEj8`03o`00
0?oooooooooo03Gooooo0ol0000Gooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo00kooooo1?l00002ocP0?P;o00002om>45l00ol0003oQ3e_oh@mK`02oh@mK`?o00004_n;
CH000ol0003oZFF3ojUUP`0KojUUP`03o`000?o1NH;o`GV201[o`GV200?o0000omV=O?oISG`01?oI
SG`2o`0000Sof89Y00?o0000omR2JOoHPVT00ooHPVT01?l0003oki=>onnCC_l00005onEj8`03o`00
0?oooooooooo037ooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool03Oooool3o`0000;o>00n00?o0000odh@Gom>45l02om>
45l00ol0003oQ3e_o`000002o`0001GoRdf000?o0000ojUUPonYIH<06onYIH<00ol0003o`GV2ol5i
PP0Jol5iPP03o`000?oISGcofHel00KofHel0ol00005omR2J@03o`000?oHPVWof89Y00?of89Y00Go
0000onnCC_o_Tdkoki=>o`000005onEj8`03o`000?oooooooooo02gooooo0ol00005ooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02ooo
ool6o`0000goCQ1O0ol0000Hoh]=P003o`000?nYIH?oZFF301_oZFF300?o0000ol5iP_o1NH806_o1
NH800ol0003ofHelomV=O009omV=O0;o00000ooHPVT00ol0003of89YomR2J@03omR2J@03o`000?o_
Tdkoki=>00;oki=>00?o0000onEj8ooUNR<00_oUNR<00ol0003oooooooooo`0Zooooo`?o00002?oo
ool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00Wooooo1Ol0000=odh@G`;o000000?oGRUfo`000?n;CH006?n;CH000ol0003oZFF3ojUUP`0K
ojUUP`03o`000?o1NH;o`GV201_o`GV200?o0000omV=O?oISG`02_oISG`4o`0000Gof89Y00?o0000
onnCC_o_Tdh00oo_Tdh00ol0003oiGXSonEj8`02onEj8`03o`000?oooooooooo02Kooooo0ol0000;
ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool00ol0003oooooooooo`08oooo
o`Co00003Om>45l01Ol0003oGRUfoehYM_mN:GKo000001WoRdf000?o0000ojUUPonYIH<03?nYIH<D
o`0001Wo`GV200?o0000omV=O?oISG`03OoISG`2o`0000Cof89Y00?o0000onnCC_o_Tdh01?o_Tdh0
1Ol0003oiGXSonEj8ooUNR?o000002Gooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000T
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool01_ooool5o`0000_oCQ1O0_l00004
oehYMP03o`000?n;CH3oRdf001GoRdf04Ol0000?oj]_SP03o`000?o2PXko`X:>00;o`X:>1ol0000B
ol5iPP03o`000?oISGcofHel00gofHel00Co0000omV=O?l0003o00000ooHPVT00ol0003oki=>onnC
CP04onnCCP03o`000?oUNR?oiGXS00;o00008Oooool3o`0001;ooooo00?o0000ooooooooool05?oo
ool002?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`04ooooo`Ko00002Om>45l2
o`0000KoGRUf00?o0000oh]=P?n;CH004_n;CH03o`0000;oT5Z=00?o0000oj]_S_n[Khh06on[Khh0
0ol0003o`X:>ol:2SP09ol:2SPSo00002_o1NH800ol0003ofHelomV=O00=omV=O004o`000?oISGco
fHelomV=O0Co00001oo_Tdh01?l0003oiGXSonEj8ol0000Nooooo`?o00005Oooool00ol0003ooooo
ooooo`0Dooooo`008oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00?ooooo1Ol0
0009odh@G`03o`000?mN:GKoGRUf00KoGRUf00?o0000oh]=P?n;CH003on;CH03o`0000GoT5Z=00?o
0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Aol:2SPOo00000oo1NH800ol0003ofHelomV=
O00=omV=O003o`000?oISGcofHel00CofHel0_l00007onnCCP03o`000?oUNR?o000001_ooooo0ol0
000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04?ooooo00Co0000
oooooooooooooooo1?l000000ol002oo0000odh@G`06odh@G`;o00002?mN:GH00ol0003oRdf0oh]=
P00<oh]=P0Co00002?n@FXd00ol0003oZfn>oj]_SP0Koj]_SP03o`000?o2PXko`X:>01So`X:>1Ol0
000?omV=O003o`000?oISGcofHel00?ofHel00?o0000oo6SJol000001oo_Tdh00ol0003oiGXSo`00
000Gooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`14
ooooo`03o`000?oooooo000000Co000000?o000_o`000?m>45l01?m>45l2o`0000[oGRUf00?o0000
oh]=P?n;CH002On;CH03o`0000coT5Z=00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0K
ol:2SP04o`000?oHUX_o0000o`0000gofHel00?o0000omV=O?oISG`00ooISG`01?l0003olJ=[oo6S
Jol00007onnCCP;o00005?ooool3o`0001kooooo00?o0000ooooooooool05?ooool002?ooooo00?o
0000ooooooooool0AOooool5o`0000;o000_00?o0000odh@Gom>45l00_m>45l00ol0003oGRUfoehY
MP0:oehYMP03o`000?n;CH3oRdf000GoRdf01?l0000?oi1JS@03o`000?n[KhkoZfn>01_oZfn>00?o
0000ol:2S_o2PXh06oo2PXh01?l0003of9J;omRFRooHUX/2o`0000_ofHel00?o0000omV=O?oISG`0
0ooISG`01Ol0003olJ=[oo6SJooaXf_o000000Ooki=>0_l0000@ooooo`?o00008Oooool00ol0003o
ooooooooo`0Dooooo`008oooool2o`0004Kooooo1?l00003o`00;`03o`000?m>45ooCQ1O00;o0000
3OmN:GH00ol0003oRdf0oh]=P002oh]=P0?o00004on@FXd00ol0003oZfn>oj]_SP0Koj]_SP03o`00
0?o2PXko`X:>01_o`X:>00?o0000omRFRooHUX/00ooHUX/3o`0000SofHel00?o0000omV=O?oISG`0
0ooISG`00ol0003olJ=[oo6SJ`02oo6SJ`03o`000?o_Tdkoki=>00Goki=>00?o0000ooooooooool0
2oooool3o`0002Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0AOoo
ool3o`0000?o000_00Co0000odh@Gol0003o00003omN:GH00ol0003oRdf0o`000002o`0001KoT5Z=
00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Kol:2SP03o`000?oHUX_of9J;00Kof9J;
0_l00006omV=O003o`000?oISGcofHel00?ofHel00?o0000oo6SJooaXf/00ooaXf/00ol0003oki=>
onnCCP04onnCCP;o00002Oooool3o`0002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o
0000ooooooooool0A_ooool3o`0000?o000_0_l0000@oehYMP?o00006On@FXd00ol0003oZfn>oj]_
SP0Koj]_SP03o`000?o2PXko`X:>01_o`X:>00?o0000omRFRooHUX/02?oHUX/2o`0000CofHel00?o
0000omV=O?oISG`00ooISG`00ol0003olJ=[oo6SJ`04oo6SJ`03o`000?o_Tdkoki=>00?oki=>0_l0
0006ooooo`?o0000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`15
ooooo`?o00001?l002l00ol0003oGRUfoehYMP0>oehYMP03o`000?mY?8Oo000001[oT5Z=00?o0000
oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Kol:2SP03o`000?oHUX_of9J;00[of9J;0_l00002
omV=O003o`000?oISGcofHel00CofHel00?o0000oo6SJooaXf/01?oaXf/00ol0003oki=>onnCCP03
onnCCP04o`000?ooooooooooooooo`?o0000;_ooool00ol0003oooooooooo`0Cooooo`008_ooool0
0ol0003oooooooooo`15ooooo`;o00001Ol002l00ol0003oGRUfoehYMP0<oehYMP;o00000_mY?8L0
0ol0003oT5Z=oi1JS@0Hoi1JS@03o`000?n[KhkoZfn>01_oZfn>00?o0000ol:2S_o2PXh06_o2PXh0
0ol0003of9J;omRFR`0=omRFR`?o00001_oISG`00ol0003olJ=[oo6SJ`05oo6SJ`03o`000?o_Tdko
ki=>00;oki=>1?l0000aooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo
04Cooooo0ol00004o`00;`;o00003OmN:GH00ol0003oJCb7ofTlQ`02ofTlQ`03o`000?n@FXgoT5Z=
01SoT5Z=00?o0000oj]_S_n[Khh06on[Khh00ol0003o`X:>ol:2SP0Jol:2SP03o`000?oHUX_of9J;
00oof9J;0ol00004omV=O003o`000?oaXf_olJ=[00KolJ=[00Co0000onnCC_o_Tdkoki=>0_l0000c
ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04Cooooo0_l00004o`00
;`03o`000?l405Oo000000_oGRUf0_l00005ofTlQ`03o`000?n@FXgoT5Z=01SoT5Z=00?o0000oj]_
S_n[Khh03?n[KhhDo`0001So`X:>00?o0000omRFRooHUX/03ooHUX/00ol0003of9J;omRFR`02o`00
00;ofHel00?o0000oo6SJooaXf/01ooaXf/01?l0003oki=>onnCC_o_Tdh2o`0003;ooooo00?o0000
ooooooooool04oooool0027ooooo0ol00015ooooo`03o`000?l002oo000_00;o000_00Co0000o`@0
Eol405Oo00002_mN:GH00ol0003oJCb7ofTlQ`05ofTlQ`03o`000?n@FXgoT5Z=01KoT5Z=4Ol0000?
ojehV@03o`000?o2RYWo`XZI00;o`XZI1ol0000Aol:2SP03o`000?oHUX_of9J;00oof9J;00?o0000
omRFRooHUX/00_oHUX/3o`0000[olJ=[00?o0000onnCC_o_Tdh00_l0000cooooo`03o`000?oooooo
oooo01;ooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000o`00;ol002l00ol002l01?l0
003o101Go`@0Eol00008oehYMP;o00002?mY?8L00ol0003oT5Z=oi1JS@0Coi1JS@?o00000_nEIYP0
0ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI00Wo`XZI1ol0000:ol:2SP03o`000?oHUX_o
f9J;00oof9J;00?o0000omRFRooHUX/01?oHUX/2o`0000[olJ=[00?o0000onnCC_l000000_l0000b
ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000o`00
;ol002l00_l002l01Ol0003o101Go`@0Eol405Oo000000KoGRUf0_l0000;ofTlQ`03o`000?n@FXgo
T5Z=00ooT5Z=0ol00005oiEVV003o`000?n]N9Wo[GRI01_o[GRI00?o0000ol::VOo2RYT04?o2RYT7
o`0000?o`X:>00?o0000omRFRooHUX/03ooHUX/00ol0003of9J;omRFR`04omRFR`03o`000?oa[H7o
000000[olJ=[0_l000000ooGQP3o0000ooooo`0aooooo`03o`000?oooooooooo01;ooooo000Qoooo
o`03o`000?oooooooooo04Cooooo00Go0000o`00;ol002oo000_o`000003o`@0E`03o`000?mN:GKo
GRUf00CoGRUf00?o0000ofTlQomY?8L02omY?8L00ol0003oT5Z=oi1JS@0<oi1JS@?o00002?nEIYP0
0ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01Oo`XZI1Ol0000@omRFR`03o`000?oHUX_o
f9J;00Cof9J;00Co0000oo6]POoa[H7o00002_oaXf/3o`0003;ooooo00?o0000ooooooooool04_oo
ool0027ooooo00?o0000ooooooooool0@oooool01Ol0003o000_o`00;ol002oo000000Co101G00?o
0000oehYM_mN:GH00_mN:GH2o`0000koJCb700?o0000oi1JSOn@FXd02?n@FXd4o`0000_oUFJH00?o
0000ojehVOn]N9T06on]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISo000000;o00003OoH
UX/00ol0003of9J;omRFR`04omRFR`05o`000?oa[H7olJf1oo6]POl000002_oaXf/00ol0003oehH0
o`00000aooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04?ooooo00Go
0000o`00;ol002oo000_o`000004o`@0E`05o`000?mN:GKoGRUfoehYM_l000004?mY?8L00ol0003o
T5Z=oi1JS@05oi1JS@?o00003onEIYP00ol0003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01[o
`XZI00?o0000omNMV?oGWIP00_oGWIP2o`0000_of9J;00?o0000omRFRooHUX/01?oHUX/00ol0003o
lJf1oo6]P@02oo6]P@03o`000?oaXf_olJ=[00OolJ=[00?o0000omN60?l00000<Oooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`13ooooo`04o`000?l002oo000_o`0000Go
101G00Co0000oehYM_l0003o00004OmY?8L00ol0003oT5Z=oi1JS@02oi1JS@?o00004_nEIYP00ol0
003o[GRIojehV@0KojehV@03o`000?o2RYWo`XZI01[o`XZI00?o0000omNMV?oGWIP01?oGWIP2o`00
00Wof9J;00?o0000omRFRooHUX/01?oHUX/00ol0003olJf1oo6]P@03oo6]P@03o`000?oaXf_olJ=[
00KolJ=[1?l0000`ooooo`03o`000?oooooooooo01;ooooo000Pooooo`?o0000@oooool01?l0003o
000_o`00;ol00006o`@0E`;o00004omY?8L00ol0003oT5Z=o`000002o`0001GoUFJH00?o0000ojeh
VOn]N9T06on]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00KoeifH0ol00006omRF
R`03o`000?oHUX_of9J;00Cof9J;00?o0000oo6]POoa[H401?oa[H400ol0003olJ=[oo6SJ`05oo6S
J`;o000000?oehH0o`000?ooool0<?ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003o
ooooooooo`13ooooo`03o`000?l002oo000000Oo101G00?o0000ofTlQomY?8L04OmY?8L3o`0001Wo
UFJH00?o0000ojehVOn]N9T06_n]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00Wo
eifH0_l00005omRFR`03o`000?oHUX_of9J;00;of9J;00?o0000oo6]POoa[H401_oa[H42o`0000Go
lJ=[0_l000000ooGQP3o0000ooooo`0`ooooo`03o`000?oooooooooo017ooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`13ooooo`03o`000?l002oo000000Oo
101G00?o0000ofTlQomY?8L03omY?8L2o`000003og==U_l0003oUFJH01WoUFJH00?o0000ojehVOn]
N9T06_n]N9T00ol0003o`XZIol::V@0Jol::V@03o`000?oGWISoeifH00_oeifH0ol00002omRFR`03
o`000?oHUX_of9J;00;of9J;00?o0000oo6]POoa[H402?oa[H400ol0003olJ=[oo6SJ`02oo6SJ`05
o`000?o`ZS;o0000omN60?l00000<?ooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0@oooool2o`0000Oo101G0_l0000@ofTl
Q`05o`000?mcCIKoLdfFog==U_l000006_nEIYP00ol0003o[GRIojehV@0JojehV@03o`000?o2RYWo
`XZI01[o`XZI00?o0000omNMV?oGWIP03_oGWIP3o`0000Cof9J;00?o0000oo6]POoa[H402Ooa[H40
0ol0003olJ=[oo6SJ`02oo6SJ`;o000000?oehH0o`000?ooool0;oooool00ol0003oooooooooo`0A
ooooo`005Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0@_ooool2
o`0000Oo101G00?o0000oal6MOl000003_mY?8L2o`0000CoLdfF00?o0000oiEVV?nEIYP06?nEIYP0
0ol0003o[GRIojehV@0JojehV@03o`000?o2RYWo`XZI01Wo`XZI00?o0000omNMV?oGWIP04OoGWIP2
o`0000?of9J;00?o0000oo6]POoa[H402_oa[H401?l0003olJ=[oo6SJooaXf/2o`000003omN60?l0
003ooooo02oooooo00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo04;ooooo00?o0000o`@0Eol405L01Ol405L01?l0003o7`Ieoal6
MOl0000<ofTlQ`;o00001_mcCIH00ol0003oUFJHoiEVV00HoiEVV003o`000?n]N9Wo[GRI01[o[GRI
00?o0000ol::VOo2RYT06Oo2RYT00ol0003oeifHomNMV00AomNMV003o`000?oGWISo000000?o0000
3Ooa[H401Ol0003olJ=[oo6SJol0003ol:Xb00;o0000<?ooool00ol0003oooooooooo`0Aooooo`00
5Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0@oooool00ol0003o
101Go`@0E`05o`@0E`04o`000?lO1WGo7`Ieo`0000_oJCb700?o0000og==U_mcCIH01_mcCIH00ol0
003oUFJHoiEVV00HoiEVV003o`000?n]N9Wo[GRI00co[GRI4ol0000Gol::V@03o`000?oGWISoeifH
017oeifH00?o0000omNMV?oGWIP00_oGWIP2o`0000golJf100Oo0000oo6SJol0003ol:Xbo`000?oG
QP3o000002oooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@
4005ooooo`;o0000A?ooool00ol0003o101Go`@0E`04o`@0E`05o`000?lO1WGo7`Ieoal6MOl00000
2OmY?8L2o`0000WoLdfF00?o0000oiEVV?nEIYP05_nEIYPAo`0000ko[h6S00?o0000ol:AXoo2TJ<0
0_o2TJ<7o`00013o`XZI00?o0000omNMV?oGWIP04OoGWIP00ol0003oeifHomNMV002omNMV003o`00
0?o^]I?o000000golJf10_l00002oo2Z<P;o0000;oooool00ol0003oooooooooo`0Aooooo`005Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0@oooool00ol0003o101G
o`@0E`03o`@0E`03o`000?lO1WGo7`Ie00?o7`Ie00?o0000ofTlQomY?8L01?mY?8L2o`0000_oLdfF
00?o0000oiEVV?nEIYP04onEIYP3o`0000;oVG2S00?o0000ojn1Xon_PJ<06_n_PJ<00ol0003o`Y6S
ol:AX`09ol:AX`Oo00002Oo2RYT00ol0003oeifHomNMV00AomNMV003o`000?oGWISoeifH00;oeifH
00Co0000onjeToo^]I?o00003Ooa[H400ol0003ol:Xboo2Z<P02o`00033ooooo00?o0000oooooooo
ool04?ooool001Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo04?o
oooo00?o0000o`@0Eol405L00_l405L00ol0003o7`Ieoal6M@04oal6M@03o`000?mY?8OoJCb700?o
JCb700?o0000og==U_mcCIH03?mcCIH00ol0003oUFJHoiEVV00?oiEVV0?o00001OnIL:<00ol0003o
[h6Sojn1X`0Jojn1X`03o`000?o2TJ?o`Y6S013o`Y6S1ol00002ol::V@03o`000?oGWISoeifH017o
eifH00?o0000omNMV?oGWIP00_oGWIP01Ol0003ok[FConjeToo^]I?o000000colJf100?o0000oo2Z
<_o`ZS800_l0000`ooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo04;o
oooo0_l00004o`@0E`03o`000?lO1WGo7`Ie00Co7`Ie00Co0000ofTlQomY?8OoJCb70_l0000?og==
UP03o`000?nEIYSoUFJH00coUFJH0ol00008oiU`X`03o`000?n_PJ?o[h6S01[o[h6S00?o0000ol:A
Xoo2TJ<05oo2TJ<4o`0001;oeifH00Go0000omNMV?oGWISoeifHo`000005onjeT`03o`000?oa[H7o
lJf100WolJf10_l00002oo2Z<P03o`000?oooooooooo02kooooo00?o0000ooooooooool04?ooool0
01oooooo00?o0000ooooooooool0@_ooool2o`0000?o101G00?o0000oal6MOlO1WD01OlO1WD01?l0
003oJCb7o`000?l0000Aog==UP03o`000?nEIYSoUFJH00SoUFJH1?l0000;oiU`X`03o`000?n_PJ?o
[h6S01[o[h6S00?o0000ol:AXoo2TJ<06Oo2TJ<01?l0003oeJBTo`000?l0000@omNMV005o`000?oG
WISoeifHomNMV?l000001_o^]I<00ol0003olJf1oo6]P@08oo6]P@;o00000_o`ZS82o`0002oooooo
00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0@_ooool2o`0000;o101G00?o
0000oal6MOlO1WD01_lO1WD2o`0001?oLdfF00?o0000oiEVV?nEIYP01OnEIYP3o`00013oVG2S00?o
0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6Sol:AX`0Iol:AX`04o`000?oEY:CoeJBTomFTY0?o0000
3OoGWIP01Ol0003oeifHomNMV?oGWISo000000Ook[FC00?o0000oo6]POoa[H401ooa[H42o`0000;o
l:Xb0_l0000_ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo04?ooooo
0_l00002o`@0E`03o`000?lO1WGo7`Ie00Ko7`Ie00?o0000og==U_mcCIH04_mcCIH00ol0003oUFJH
oiEVV002oiEVV0?o00004onIL:<00ol0003o[h6Sojn1X`0Iojn1X`03o`000?o2TJ?o`Y6S01Wo`Y6S
00?o0000omFTY?oEY:@01?oEY:@2o`0000_oeifH00Go0000omNMV?oGWISoeifHo`000008onjeT`;o
00001ooa[H400ol0003oo<5Mo`000002oo2Z<P03o`000?oooooooooo02gooooo00?o0000oooooooo
ool04?ooool001kooooo00?o0000ooooooooool0@oooool2o`000003o`@0Eol0003o7`Ie00So7`Ie
00?o0000og==U_mcCIH04_mcCIH00ol0003oUFJHo`000002o`0001KoVG2S00?o0000ojn1Xon_PJ<0
6On_PJ<00ol0003o`Y6Sol:AX`0Iol:AX`03o`000?oEY:CoeJBT00KoeJBT0_l00009omNMV005o`00
0?oGWISoeifHomNMV?l000002_o^]I<00ol0003olJf1oo6]P@04oo6]P@03o`000?ol`Ego000000;o
l:Xb00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`007_ooool2o`0004Cooooo
0ol00009oal6M@;o00004omcCIH3o`0001WoVG2S00?o0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6S
ol:AX`0Hol:AX`03o`000?oEY:CoeJBT00WoeJBT0ol00006omNMV005o`000?oGWISoeifHomNMV?l0
00002oo^]I<00ol0003olJf1oo6]P@02oo6]P@04o`000?ol`Egoo<5Mo`0000;ol:Xb00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`13ooooo`;o
00002OlO1WD00ol0003o=R>=o`00000Aog==UP;o000000?oNebTo`000?nIL:<06OnIL:<00ol0003o
[h6Sojn1X`0Iojn1X`03o`000?o2TJ?o`Y6S01So`Y6S00?o0000omFTY?oEY:@03?oEY:@2o`0000Co
eifH00Go0000omNMV?oGWISoeifHo`00000<onjeT`05o`000?oa[H7olJf1oo6]POl000000ool`Ed0
0ol0003ol:Xbo`00000`ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo
04?ooooo0_l00008oal6M@05o`000?lf8hgo=R>=ocHSSOl000003omcCIH01Ol0003oNebTog]LY?mk
G:Co000001[oVG2S00?o0000ojn1Xon_PJ<06On_PJ<00ol0003o`Y6Sol:AX`0Hol:AX`03o`000?oE
Y:CoeJBT00koeJBT0_l00002omNMV004o`000?oGWISoeifHo`0000kok[FC00Co0000oo6]POoa[H7o
00000ool`Ed00ol0003ol:Xbo`00000`ooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`00
0?oooooooooo04;ooooo0ol00007oal6M@03o`000?lf8hgo=R>=00;o=R>=00?o0000og==U_mcCIH0
2omcCIH2o`0000GoNebT00?o0000oiU`XonIL:<05onIL:<00ol0003o[h6Sojn1X`0Iojn1X`03o`00
0?o2TJ?o`Y6S01So`Y6S00?o0000omFTY?oEY:@04?oEY:@3o`0000;oeifH00?o0000onjeToo^]I<0
3Oo^]I<00ol0003olJf1o`000004ooc1G@;o0000<?ooool00ol0003oooooooooo`0?ooooo`007Ooo
ool00ol0003oooooooooo`13ooooo`?o00001olO1WD00ol0003o=R>=ocHSS@02ocHSS@03o`000?mc
CIKoLdfF00WoLdfF0_l00007og]LY003o`000?nIL:?oVG2S01OoVG2S00?o0000ojn1Xon_PJ<06On_
PJ<00ol0003o`Y6Sol:AX`0Hol:AX`03o`000?oEY:CoeJBT01;oeJBT1?l0000@onjeT`;o00001?ol
`Ed00ol0003ol:Xbo`00000_ooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo04?ooooo0ol00006oal6M@03o`000?lf8hgo=R>=00?o=R>=00?o0000og==U_mcCIH01omcCIH2
o`0000WoNebT00?o0000oiU`XonIL:<06?nIL:<00ol0003o[h6Sojn1X`0Hojn1X`03o`000?o2TJ?o
`Y6S01So`Y6S00?o0000omFTY?oEY:@04ooEY:@01?l0003oeJBTo`000?l0000@onjeT`03o`000?ol
`Egoo<5M00;oo<5M00?o0000oo2Z<_l00000;oooool00ol0003oooooooooo`0?ooooo`007Oooool0
0ol0003oooooooooo`13ooooo`?o00001OlO1WD00ol0003o=R>=ocHSS@04ocHSS@03o`000?mcCIKo
LdfF00KoLdfF00?o0000og]LY?mkG:@02OmkG:@00ol0003oVG2SoiU`X`0HoiU`X`03o`000?n_PJ?o
[h6S01So[h6S00?o0000ol:AXoo2TJ<06?o2TJ<00ol0003oeJBTomFTY00ComFTY005o`000?oEY:Co
0000onZkXol000003oo^]I<00ol0003oo<5Mooc1G@03ooc1G@;o0000;oooool00ol0003ooooooooo
o`0?ooooo`007Oooool2o`0004Cooooo0ol00004oal6M@03o`000?lf8hgo=R>=00Go=R>=00?o0000
og==U_mcCIH01?mcCIH2o`0000coNebT00?o0000oiU`XonIL:<06?nIL:<00ol0003o[h6Sojn1X`0;
ojn1Xa7o00005oo2TJ<00ol0003oeJBTomFTY00ComFTY003o`000?oEY:Co000000;oj[^S00?o0000
onjeToo^]I<03?o^]I<2o`0000Coo<5M0_l0000`ooooo`03o`000?oooooooooo00kooooo000Moooo
o`03o`000?oooooooooo04?ooooo0ol00003oal6M@03o`000?lf8hgo=R>=00Ko=R>=00?o0000og==
U_mcCIH00_mcCIH2o`0000ooNebT00?o0000oiU`XonIL:<05OnIL:<@o`0000go/8V]00Co0000ol6H
[Oo1V:go`IR]1ol0000?ol:AX`03o`000?oEY:CoeJBT01CoeJBT0_l00004onZkX`03o`000?o^]I?o
k[FC00_ok[FC0_l00004ooc1G@;o0000<?ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0
003oooooooooo`13ooooo`?o00000olO1WD00ol0003o=R>=ocHSS@07ocHSS@04o`000?mcCIKoLdfF
o`00017oNebT00?o0000oiU`XonIL:<04OnIL:<4o`0000;oW7^^00?o0000ok29[On`RJd06?n`RJd0
0ol0003o`IR]ol6H[@08ol6H[@Ko00002Oo2TJ<00ol0003oeJBTomFTY00DomFTY0;o00001OoZ^j<2
o`0000[ok[FC00Co0000ooo@P?ood83o00001?ol`Ed00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo04Cooooo00?o0000o`00<?l000000_lO1WD0
0ol0003o=R>=ocHSS@08ocHSS@?o00004_mkG:@00ol0003oVG2SoiU`X`0=oiU`X`Co00001_nLNjh0
0ol0003o/8V]ok29[@0Hok29[@03o`000?o1V:go`IR]00ko`IR]1ol00002ol:AX`03o`000?oEY:Co
eJBT01CoeJBT0_l00007onZkX`03o`000?o^]I?ok[FC00Ook[FC00Co0000ooo@P?ood83o00001?ol
`Ed00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooo
oooo04Cooooo00Go0000o`00<?l0003o7`Ieo`00000;ocHSS@03o`000?mkG:CoNebT01;oNebT00?o
0000oiU`XonIL:<02?nIL:<5o`0000[oW7^^00?o0000ok29[On`RJd06?n`RJd00ol0003o`IR]ol6H
[@0Eol6H[@Co00005OoEY:@2o`0000Soj[^S00?o0000onjeToo^]I<01_o^]I<01?l0003oom20ooo@
P?l00004ooc1G@03o`000?oooooooooo02kooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool0A?ooool01?l0003o000`o`000?l0000<ocHSS@03o`000?mkG:CoNebT01;oNebT
00?o0000oiU`XonIL:<01?nIL:<4o`0000ooW7^^00?o0000ok29[On`RJd06?n`RJd00ol0003o`IR]
ol6H[@0Gol6H[@03o`000?oCZZoo000000;o00004_oEY:@2o`0000Woj[^S00?o0000onjeToo^]I<0
1Oo^]I<01Ol0003oom20ooo@P?ood83o000000?oo<5M00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`14ooooo`03o`000?l0033o000000co=R>=
0_l0000Eog]LY003o`000?nIL:?o000000?o00004onLNjh00ol0003o/8V]ok29[@0Hok29[@03o`00
0?o1V:go`IR]01Oo`IR]00?o0000om>Z[ooCZZl00_oCZZl3o`0000goeJBT0ol0000;onZkX`03o`00
0?o^]I?ok[FC00Cok[FC00Go0000ooo@P?ood83oom20o`000003ooc1G@03o`000?oooooooooo02ko
oooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0A?ooool00ol0003o000`
o`00000;ocHSS@04o`000?m9?J7oBCfQo`0001?oNebT0ol0000Goiak[P03o`000?n`RJgo/8V]01So
/8V]00?o0000ol6H[Oo1V:d05oo1V:d00ol0003odjZ_om>Z[`05om>Z[`?o00001ooEY:@3o`0000;o
eJBT00?o0000onZkXooZ^j<02_oZ^j<2o`0000Cok[FC00?o0000ooo@P?ood8000_ood8001?l0003o
o<5Mooc1GOl0000aooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000AOooool00ol0003o
000`o`00000:ocHSS@05o`000?m9?J7oBCfQodTmXOl000004_mkG:@00ol0003oPV^`o`00000Hoiak
[P03o`000?n`RJgo/8V]01So/8V]00?o0000ol6H[Oo1V:d05_o1V:d00ol0003odjZ_om>Z[`09om>Z
[`;o00000_oEY:@3o`0000GoeJBT0_l0000=onZkX`05o`000?o^]I?ok[FConjeTol000001?ood800
1?l0003oo<5Mooc1GOl0000aooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooo
oooo04Gooooo00Co0000o`00<?l006;o00002?lf8hd00ol0003oBCfQodTmX@02odTmX@03o`000?mk
G:CoNebT00koNebT0_l00002oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o0000ok29[On`RJd05on`
RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00[odjZ_1?l00007omFTY003o`000?oZ
^j?o000000goj[^S00?o0000onjeTol000001_ood8000ol0003oo<5Mo`00000aooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo04Gooooo00Co0000o`00<?l006;o00002?lf
8hd00ol0003oBCfQodTmX@03odTmX@03o`000?mkG:CoNebT00_oNebT0_l00005oh9[/003o`000?nL
NjkoW7^^01KoW7^^00?o0000ok29[On`RJd05_n`RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oC
ZZoodjZ_00KodjZ_1?l00004om>Z[`?o00001?oEY:@01?l0003oj[^SonZkXol0000=onZkX`;o0000
1_ood8000ol0003oo<5Mo`00000aooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oo
oooooooo04Gooooo0_l000000ol006;o0000ocHSS@06ocHSS@03o`000?m9?J7oBCfQ00CoBCfQ00?o
0000og]LY?mkG:@02_mkG:@00ol0003oPV^`oh9[/005oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o
0000ok29[On`RJd05_n`RJd00ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00?odjZ_0ol0
000;om>Z[`Co00001?oZ^j<00ol0003oj[^SonZkX`0;onZkX`03o`000?ood83oom2000Coom2000?o
0000ooc1GOl00000<Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`15
ooooo`;o000000?o001Ro`000?lf8hd01Olf8hd00ol0003oBCfQodTmX@05odTmX@03o`000?mkG:Co
NebT00SoNebT0_l00008oh9[/003o`000?nLNjkoW7^^01KoW7^^00?o0000ok29[On`RJd05_n`RJd0
0ol0003o`IR]ol6H[@0Gol6H[@03o`000?oCZZoodjZ_00?o00004OoCZZl2o`0000?oj[^S00?o0000
onZkXooZ^j<02ooZ^j<00ol0003oom20ooo@P005ooo@P0;o0000<Oooool00ol0003oooooooooo`0=
ooooo`006oooool00ol0003oooooooooo`15ooooo`;o00000_l006800ol0003o=R>=ocHSS@02ocHS
S@03o`000?m9?J7oBCfQ00KoBCfQ00?o0000og]LY?mkG:@01_mkG:@2o`0000[oPV^`00?o0000oiak
[_nLNjh05_nLNjh00ol0003o/8V]ok29[@0Fok29[@03o`000?o1V:go`IR]01Ko`IR]1?l0000Dom>Z
[`03o`000?oU`;7o000000?oj[^S00?o0000onZkXooZ^j<02OoZ^j<00ol0003ooMVKo`000006ooo@
P0;o0000<Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`15ooooo`;o
00000_l006800ol0003o=R>=ocHSS@02ocHSS@03o`000?m9?J7oBCfQ00OoBCfQ00?o0000og]LY?mk
G:@01?mkG:@00ol0003oPV^`oh9[/00;oh9[/003o`000?nLNjkoW7^^01GoW7^^00?o0000ok29[On`
RJd05_n`RJd00ol0003o`IR]ol6H[@0Col6H[@Co00005_oCZZl01Ol0003oiL2aonG0/OoU`;7o0000
00?oj[^S00?o0000onZkXooZ^j<02?oZ^j<00ol0003ooMVKo`000007ooo@P003o`000?oooooooooo
02oooooo00?o0000ooooooooool03Oooool001_ooooo0_l00016ooooo`;o00000_l006801Ol0003o
=R>=ocHSSOlf8hgo000000[oBCfQ00?o0000og]LY?mkG:@00_mkG:@2o`0000koPV^`00?o0000oiak
[_nLNjh05OnLNjh00ol0003o/8V]ok29[@0Fok29[@03o`000?o1V:go`IR]013o`IR]0ol00003ol6H
[@03o`000?oCZZoodjZ_01CodjZ_00?o0000onG0/OoU`;400_oU`;401Ol0003oj[^SonZkXooZ^j?o
000000Woj[^S00?o0000oogIVol000001oood8000ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo04Kooooo0_l00002o`00HP04o`000?lf8hgo=R>=
o`0000_oBCfQ00?o0000og]LY?mkG:@00_l0000@oh9[/003o`000?nLNjkoW7^^01GoW7^^00?o0000
ok29[On`RJd02_n`RJd@o`0000co`IR]0ol00006ol6H[@03o`000?oCZZoodjZ_01CodjZ_00?o0000
onG0/OoU`;400ooU`;401Ol0003oj[^SonZkXooZ^j?o000000Ooj[^S00Go0000oogIVoomfI_ooMVK
o`000006ooo@P003o`000?oooooooooo033ooooo00?o0000ooooooooool03?ooool00004oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`16ooooo`03o`00<?l0003o001R00;o001R0_l0000=odTmX@;o00004_n2Jk000ol0003o
W7^^oiak[P0Coiak[Poo00003?n`T[L01?l0003o`9nhol2O^?o0WkP6o`0000?o`IR]0ol00009ol6H
[@03o`000?oCZZoodjZ_01?odjZ_00?o0000onG0/OoU`;401OoU`;401Ol0003oj[^SonZkXooZ^j?o
000000Koj[^S00Go0000oogIVoomfI_ooMVKo`000005ooo@P003o`000?oooooooooo037ooooo00?o
0000ooooooooool03?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool0A_ooool00ol0033o0000o`00HP02o`00HP03o`000?m9
?J7oBCfQ00coBCfQ00?o0000oh9[/?n2Jk004_n2Jk000ol0003oW7^^oiak[P0>oiak[PCo00000_nO
Q[T00ol0003o/9:gok2B]`0Fok2B]`03o`000?o0WkSo`9nh00Ko`9nh1ol00008ol6H[@03o`000?oC
ZZoodjZ_01CodjZ_00?o0000onG0/OoU`;401_oU`;42o`000003onZkXol0003oj[^S00Coj[^S00?o
0000oogIVoomfI/00oomfI/00ol0003oom20ooo@P002ooo@P003o`000?oooooooooo037ooooo00?o
0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo04Kooooo00?o0000o`00H_l006800_l006800ol0003oBCfQodTmX@0<
odTmX@03o`000?n2Jk3oPV^`01;oPV^`00?o0000oiak[_nLNjh02onLNjh3o`0000KoWhJi00?o0000
ok2B]on`T[L05_n`T[L00ol0003o`9nhol2O^003ol2O^0?o00001oo0WkP6o`0000;o`IR]00?o0000
om>Z[ooCZZl05?oCZZl00ol0003oiL2aonG0/@08onG0/@03o`000?oZ^j?o000000Coj[^S00?o0000
oogIVoomfI/00oomfI/00ol0003oom20ooo@P002ooo@P003o`000?oooooooooo037ooooo00?o0000
ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo04Kooooo00?o0000o`00H_l006800_l006800ol0003oBCfQodTmX@0;odTm
X@03o`000?mJEK;o000001?oPV^`00?o0000oiak[_nLNjh01onLNjh4o`0000WoWhJi00?o0000ok2B
]on`T[L05_n`T[L00ol0003o`9nhol2O^003o`00013o`9nh1?l0000Dom>Z[`03o`000?oU`;7oiL2a
00[oiL2a00?o0000onZkXol000000ooZ^j<00ol0003ooMVKoogIV`03oogIV`03o`000?ood83oom20
00;oom2000?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`000oooool00ol0003o
ooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`16oooo
o`03o`000?l006;o001R00;o001R00?o002<o`000?m9?J402_m9?J401?l0003oFUFboeYE/_l0000C
oh9[/003o`000?nLNjkoW7^^00?oW7^^1?l0000>oin6^@03o`000?n`T[Oo/9:g01Go/9:g0ol0000E
ol2O^003o`000?o?/;[o000000;o00004OoCZZl00ol0003oiL2aonG0/@0;onG0/@05o`000?oZ^j?o
0000onZkXol000001oomfI/00ol0003oom20ooo@P002o`0003?ooooo00?o0000ooooooooool03?oo
ool000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo04Oooooo00?o0000o`00H_l006800_l006800ol008co0000odTmX@09odTmX@03o`000?mJEK;o
FUFb00;oFUFb00?o0000oh9[/?n2Jk004On2Jk000ol0003oW7^^o`000002o`0001;oWhJi00?o0000
ok2B]on`T[L04On`T[L5o`0001Oo`9nh00?o0000oln`^_o?/;X00_o?/;X3o`0000kodjZ_00?o0000
onG0/OoU`;403?oU`;401?l0003oj[^So`000?l00007oogIV`04o`000?ood83oom20o`0003Gooooo
00?o0000ooooooooool02oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool2o`0004Sooooo00Oo0000o`00H_l006;o001Ro`000?l008co000000WoBCfQ00?o0000oeYE
/_mJEK800omJEK800ol0003oPV^`oh9[/00@oh9[/0?o00005OnOQ[T00ol0003o/9:gok2B]`0>ok2B
]`?o00001?n`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[ock2j00Kock2j0ol0000:om>Z
[`03o`000?oU`;7oiL2a00koiL2a0ol00008oogIV`03o`000?ood83o000003Gooooo00?o0000oooo
ooooool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo
04Oooooo00Go0000o`00H_l006;o001Ro`000002o`00S003o`000?m9?J7oBCfQ00GoBCfQ00?o0000
oeYE/_mJEK801?mJEK800ol0003oPV^`oh9[/00>oh9[/0;o000000?oRGZlo`000?nOQ[T05OnOQ[T0
0ol0003o/9:gok2B]`0;ok2B]`?o00001on`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[o
ck2j00Wock2j0ol00007om>Z[`03o`000?oU`;7oiL2a00ooiL2a0_l00008oogIV`03o`000?ood83o
000003Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0B?ooool01?l0
003o001Ro`00H_l00002o`00S003o`000?m9?J7oBCfQ00CoBCfQ00?o0000oeYE/_mJEK801_mJEK80
0ol0003oPV^`oh9[/00<oh9[/003o`000?n9N[coRGZl00;oRGZl00?o0000oin6^OnOQ[T04onOQ[T0
0ol0003o/9:gok2B]`08ok2B]`?o00002On`T[L00ol0003o`9nhol2O^00Eol2O^003o`000?o?/;[o
ck2j00cock2j0ol00004om>Z[`03o`000?oU`;7oiL2a00ooiL2a00?o0000oogIVol000001oomfI/3
o`0003Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0B?ooool01?l0
003o001Ro`00H_l00002o`00S003o`000?m9?J7oBCfQ00CoBCfQ00?o0000oeYE/_mJEK801_mJEK80
0ol0003oPV^`oh9[/00:oh9[/0;o00001On9N[`00ol0003oWhJioin6^@0Doin6^@03o`000?n`T[Oo
/9:g00?o/9:g1?l0000<ok2B]`03o`000?o0WkSo`9nh01Co`9nh00?o0000oln`^_o?/;X04?o?/;X4
o`00017oiL2a00Go0000ooKN/_l0003ooMVKo`000007oogIV`;o0000=Oooool00ol0003ooooooooo
o`0;ooooo`006Oooool00ol0003oooooooooo`18ooooo`04o`000?l006;o001Ro`0000?o002<00?o
0000odTmXOm9?J400_m9?J400ol0003oFUFboeYE/P08oeYE/P03o`000?n2Jk3oPV^`00OoPV^`0_l0
0007ohUj_003o`000?nOQ[WoWhJi01CoWhJi00?o0000ok2B]on`T[L00ol0000@ok2B]`03o`000?o0
WkSo`9nh01Co`9nh00?o0000oln`^_o?/;X04oo?/;X2o`00013oiL2a00?o0000ooKN/_l000000_om
fI/00ol0003ooMVKoogIV`04oogIV`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02ooo
ool001Sooooo00?o0000ooooooooool0B_ooool00ol0003o001Ro`000003o`00S005o`000?m9?J7o
BCfQodTmXOl000002omJEK800ol0003oPV^`oh9[/005oh9[/0;o00002_n9N[`00ol0003oWhJioin6
^@0Coin6^@?o00004on`T[L00ol0003o`9nhol2O^00Dol2O^003o`000?o?/;[ock2j01?ock2j00?o
0000omk4__l000003_oU`;401Ol0003om]jbooKN/_ofg[;o000000;ooMVK00?o0000oogIVoomfI/0
0_omfI/2o`0003Kooooo00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool0B_oo
ool00ol0003o001Ro`000003o`00S004o`000?m9?J7oBCfQo`0000goFUFb00?o0000oh9[/?n2Jk00
0_n2Jk02o`0000coRGZl00?o0000oin6^OnOQ[T04?nOQ[T4o`0001Go/9:g00?o0000ol2O^?o0WkP0
4oo0WkP00ol0003ock2joln`^P0Coln`^P05o`000?oNa;kog/Bnomk4__l000003OoU`;401Ol0003o
m]jbooKN/_ofg[;o000000;ooMVK00?o0000oogIVoomfI/00_omfI/2o`0003Oooooo00?o0000oooo
ooooool02_ooool001Sooooo00?o0000ooooooooool0B_ooool2o`0000Go002<0_l0000>oeYE/P05
o`000?n2Jk3oPV^`oh9[/?l000003_n9N[`00ol0003oWhJioin6^@0<oin6^@Co00000onOQ[T00ol0
003o/9:gok2B]`0Cok2B]`03o`000?o0WkSo`9nh01?o`9nh00?o0000oln`^_o?/;X04oo?/;X00ol0
003og/Bnomk4_P02omk4_P03o`000?oU`;7oiL2a00[oiL2a00?o0000ooKN/_ofg[800_ofg[801?l0
003ooMVKoogIVol00003oogIV`;o0000=oooool00ol0003oooooooooo`0:ooooo`006?ooool2o`00
04_ooooo0_l00005o`00S003o`000?mJEK;oFUFb00goFUFb00Co0000oh9[/?l0003o00004?n9N[`0
0ol0003oWhJioin6^@08oin6^@?o00001onOQ[T00ol0003o/9:gok2B]`0Cok2B]`03o`000?o0WkSo
`9nh01?o`9nh00?o0000oln`^_o?/;X04_o?/;X00ol0003og/Bnomk4_P04omk4_P03o`000?oU`;7o
iL2a00SoiL2a00?o0000ooKN/_ofg[800oofg[801_l0003ooMVKoogIVoomfI_o0000oogIV`?o0000
=oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`1;ooooo`03o`000?l0
08co002<00?o002<00?o0000oeYE/_mJEK803_mJEK800ol0003oRGZlohUj_00@ohUj_003o`000?nO
Q[WoWhJi00GoWhJi0ol0000;oin6^@03o`000?n`T[Oo/9:g01;o/9:g00?o0000ol2O^?o0WkP04_o0
WkP00ol0003ock2joln`^P0Coln`^P03o`000?oNa;kog/Bn00Gog/Bn0_l00008onG0/@03o`000?of
g[;om]jb00Com]jb00Co0000oogIVoomfI_ooMVK1?l0000gooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04_ooooo00?o0000o`00S?l008`00ol008`00ol=;Jgo0000oeYE
/P0>oeYE/P03o`000?n9N[coRGZl017oRGZl00Co0000oin6^OnOQ[WoWhJi0ol0000>oin6^@03o`00
0?n`T[Oo/9:g00So/9:g3_l0000Aol2O^003o`000?o?/;[ock2j01;ock2j00?o0000omk4__oNa;h0
2?oNa;h00ol0003oiL2aonG0/@04onG0/@03o`000?ofg[;om]jb00Gom]jb00?o0000oogIVoomfI/0
0_omfI/2o`0003Sooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0C?oo
ool00ol0003o002<o`00S003o`00S0;o00003_mJEK800ol0003oJF_1o`00000BohUj_0Co00003onO
Q[T=o`0000[o/9_200Co0000okjW`onnYl?o_ZO31ol0000:ol2O^003o`000?o?/;[ock2j01;ock2j
00?o0000omk4__oNa;h02OoNa;h00ol0003oiL2aonG0/@03onG0/@03o`000?ofg[;om]jb00Kom]jb
00?o0000oogIVoomfI/00ol0000hooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oo
oooooooo04gooooo00Go0000o`00S?l008co002<o`000002o`d][@03o`000?mJEK;oFUFb00[oFUFb
00Co0000ofU[`OmYJl7o00003on9N[`4o`0000koWhJi1?l00002oj:Aa003o`000?n`Vl;o/9_201;o
/9_200?o0000okjW`onnYl<02?nnYl<7o`0000;o`9nh00?o0000oln`^_o?/;X04_o?/;X00ol0003o
g/Bnomk4_P0;omk4_P05o`000?oU`;7oiL2aonG0/Ol000002Oofg[801_l0003ooMVKoogIVol0003o
fmaYo`0003Sooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0COooool0
1Ol0003o002<o`00S?l008co000000;o3Bf]00?o0000oeYE/_mJEK802OmJEK800ol0003oJF_1ofU[
`@02ofU[`@03o`000?n9N[coRGZl00WoRGZl0ol00004ohUj_003o`000?nOQ[WoWhJi00OoWhJi1?l0
0006oj:Aa003o`000?n`Vl;o/9_201;o/9_200?o0000okjW`onnYl<03onnYl<4o`0001?ock2j00?o
0000omk4__oNa;h03?oNa;h01?l0003oiL2aonG0/Ol0000:ooKN/P04o`000?omfI_o0000om_LJ@;o
0000>?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1=ooooo`05o`00
0?l008co002<o`00S?l000000ol=;Jd00ol0003oFUFboeYE/P07oeYE/P03o`000?mYJl7oJF_100?o
JF_100?o0000ohUj_?n9N[`01_n9N[`3o`0000OoRGZl00?o0000oin6^OnOQ[T01?nOQ[T3o`0000[o
XY7400?o0000ok2K`_n`Vl804_n`Vl800ol0003o_ZO3okjW``0AokjW``03o`000?o;]LGo000000;o
00003oo?/;X00ol0003og/Bnomk4_P0>omk4_P03o`000?oU`;7o000000[om]jb0_l000001OoKg6Wo
0000o`000?oooooo000003Oooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000oooooooo
ool0C_ooool01?l0003o002<o`00S?l00004o`d][@03o`000?mJEK;oFUFb00GoFUFb00?o0000ofU[
`OmYJl401OmYJl401?l0003oRGZlohUj_?n9N[`4o`0000[oRGZl00?o0000oin6^OnOQ[T01?l0000>
oj:Aa003o`000?n`Vl;o/9_2017o/9_200?o0000okjW`onnYl<04OnnYl<00ol0003obkG5ol^ea@02
ol^ea@;o00003Oo?/;X00ol0003og/Bnomk4_P0?omk4_P03o`000?ofg[;om]jb00[om]jb00?o0000
om_LJOl000000oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Goooo
o`03o`000?oooooooooo04kooooo00Co0000o`00S?l008co00001?l=;Jd00ol0003oFUFboeYE/P05
oeYE/P03o`000?mYJl7oJF_100GoJF_11?l0000>ohUj_0?o00004_nRTL@00ol0003o/9_2ok2K`P0A
ok2K`P03o`000?nnYl?o_ZO3013o_ZO300?o0000ol^eaOo;]LD01Oo;]LD3o`0000Wock2j00?o0000
omk4__oNa;h04?oNa;h00ol0003om]jbooKN/P0:ooKN/P03o`000?oKg6Wo000000?ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`005oooool2o`0004oooooo00Co0000o`00
S?l008co00001Ol=;Jd00ol0003oFUFboeYE/P03oeYE/P03o`000?mYJl7oJF_100CoJF_11?l0000>
ohUj_0;o000000?oShS8o`000?nRTL@04_nRTL@00ol0003o/9_2ok2K`P0Aok2K`P03o`000?nnYl?o
_ZO3013o_ZO300?o0000ol^eaOo;]LD02?o;]LD2o`0000Oock2j00?o0000omk4__oNa;h03ooNa;h0
0ol0003ok=o4o`00000:ooKN/P;o000000?ofmaYo`000?ooool00oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo053ooooo00?o0000o`00
S?l000001Ol=;Jd00ol0003oFUFboeYE/P02oeYE/P03o`000?mYJl7oJF_100;oJF_10ol00004ofU[
`@03o`000?n9N[coRGZl00[oRGZl00?o0000ohn8b?n?R<P00_n?R<P00ol0003oXY74oj:Aa00@oj:A
a003o`000?n`Vl;o/9_2017o/9_200?o0000okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0:ol^e
a@;o00001?o?/;X00ol0003og/Bnomk4_P0?omk4_P04o`000?o/glCok=o4o`0000[om]jb0_l00000
0ooKg6Wo0000ooooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02Oooool0
01Kooooo00?o0000ooooooooool0D?ooool2o`0000Oo3Bf]00Go0000oeYE/_mJEK;o0000ofU[`@04
o`0000OoJF_100?o0000ohUj_?n9N[`02?n9N[`2o`0000GoShS800?o0000oj:Aa?nRTL@04?nRTL@0
0ol0003o/9_2ok2K`P0@ok2K`P03o`000?nnYl?o_ZO3013o_ZO300?o0000ol^eaOo;]LD03Oo;]LD3
o`000003oln`^_l0003og/Bn013og/Bn00Go0000oncOa?o/glCok=o4o`000008ooKN/P;o000000?o
fmaYo`000?ooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo000F
ooooo`03o`000?oooooooooo053ooooo0_l00007o`d][@03o`000?mJEK;o000000;o00003?mYJl40
0ol0003oRGZlohUj_005ohUj_0;o00002?n?R<P00ol0003oXY74oj:Aa00@oj:Aa003o`000?n`Vl;o
/9_200oo/9_200?o0000okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0@ol^ea@;o00004?oNa;h0
0ol0003ok=o4oncOa002oncOa003o`000?ofg[;om]jb00Gom]jb00Go0000on[cW?l0003ofmaYo`00
0008ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0DOooool00ol0003o3Bf]o`d][@04o`d][@?o00003omYJl400ol0003oRGZlohUj_003
ohUj_0;o00002_n?R<P00ol0003oXY74oj:Aa00@oj:Aa003o`000?n`Vl;o/9_200oo/9_200?o0000
okjW`onnYl<04?nnYl<00ol0003obkG5ol^ea@0@ol^ea@03o`000?oGal_o000000kog/Bn00?o0000
oncOa?o/gl@01?o/gl@00ol0003om]jbooKN/P04ooKN/P05o`000?oZlico0000om_LJOl000002Ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooo
oooo057ooooo00Co0000o`d][Ol=;Jgo3Bf]0ol00002o`d][@03o`000?mYJl7oJF_100koJF_100Go
0000ohUj_?n9N[coRGZlo`00000=ohn8b003o`000?nRTLCoXY7400ooXY7400?o0000ok2K`_n`Vl80
3on`Vl800ol0003o_ZO3okjW``0?okjW``03o`000?o;]LGobkG5013obkG500Co0000omO7booGal_o
elO;0_l0000;omk4_P03o`000?o/glCok=o400Gok=o400?o0000ooKN/_ofg[800oofg[800ol0003o
j_>Lon[cW002o`0000[ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00
5_ooool00ol0003oooooooooo`1Aooooo`Co00001Ol=;Jd00olbDlGo0000ofU[`@0>ofU[`@04o`00
0?n9N[co0000o`0000koShS800?o0000oj:Aa?nRTL@03onRTL@00ol0003o/9_2ok2K`P0?ok2K`P03
o`000?nnYl?o_ZO300oo_ZO300?o0000ol^eaOo;]LD04?o;]LD00ol0003oelO;omO7b`03omO7b`03
o`000?oNa;kog/Bn00Sog/Bn00?o0000oncOa?o/gl@01_o/gl@00ol0003om]jbooKN/P02ooKN/P03
o`000?oZlicoj_>L00;o00002oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo04oooooo0ol000000ooooooo0000o`d][@06o`d][@03o`00
0?lbDlGo000000ooJF_100?o0000ohn8b?n?R<P03on?R<P00ol0003oXY74oj:Aa00>oj:Aa003o`00
0?n`Vl;o/9_200oo/9_200?o0000okjW`onnYl<03onnYl<00ol0003obkG5ol^ea@0?ol^ea@03o`00
0?oGal_oelO;00GoelO;0_l00007omk4_P03o`000?o/glCok=o400Ook=o400Go0000ooKN/_ofg[;o
m]jbo`000003on[cW0;o00003?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00So
oooo000Eooooo`?o0000C?ooool3o`0000Cooooo00?o001fo`000?l=;Jd01?l=;Jd01Ol0003o<U?5
oc9CaOlbDlGo000000goJF_10_l0000Aohn8b003o`000?nRTLCoXY7400koXY7400?o0000ok2K`_n`
Vl803on`Vl800ol0003o_ZO3okjW``0>okjW``03o`000?o;]LGobkG500oobkG500?o0000omO7booG
al/02?oGal/00ol0003og/Bnomk4_P03omk4_P03o`000?o/glCok=o400Wok=o400?o0000ooKN/_l0
00001?oZli`00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000Sooooo00?o0000o`d][Ol=;Jd0
0ol=;Jd01Ol0003o<U?5oc9CaOlbDlGo000000coJF_100Co0000ogIoc_mfOlko00004On?R<P00ol0
003oXY74oj:Aa00>oj:Aa003o`000?n`Vl;o/9_200ko/9_200?o0000okjW`onnYl<03_nnYl<00ol0
003obkG5ol^ea@0?ol^ea@03o`000?oGal_oelO;00WoelO;0_l00003omk4_P03o`000?o/glCok=o4
00Wok=o400?o0000ooKN/_l000000ooZli`2o`0000oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co00002oooool00ol007Ko
0000o`d][@03o`d][@03o`000?lbDlGo<U?500;o<U?500?o0000ofU[`OmYJl402?mYJl400ol0003o
MWo>ogIocP02ogIocP03o`000?n?R<SoShS800koShS800?o0000oj:Aa?nRTL@03_nRTL@00ol0003o
/9_2ok2K`P06ok2K`Pgo00003?nnYl<00ol0003obkG5ol^ea@0>ol^ea@03o`000?oGal_oelO;00co
elO;00?o0000omk4__l000003Oo/gl@00ol0003oj_>Lon[cW002on[cW0;o00003oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo
0ol0000@ooooo`03o`00M_l0003o3Bf]00;o3Bf]00?o0000oc9CaOlbDlD00olbDlD00ol0003oJF_1
ofU[`@06ofU[`@03o`000?mfOlkoMWo>00CoMWo>00?o0000ohn8b?n?R<P03_n?R<P00ol0003oXY74
oj:Aa00;oj:Aa0_o00002?n`Y/h00ol0003o^Zo>okZ_cP02okZ_cPSo00000onnYl<00ol0003obkG5
ol^ea@0?ol^ea@03o`000?oGal_oelO;00goelO;00?o0000oncOa?o/gl@03?o/gl@00ol0003oj_>L
on[cW002on[cW003o`000?oooooooooo00oooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`07ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00004oooool00ol007Ko0000o`d]
[@02o`d][@03o`000?lbDlGo<U?500Co<U?500?o0000ofU[`OmYJl401?mYJl400ol0003oMWo>ogIo
cP05ogIocP03o`000?n?R<SoShS800koShS800?o0000oj:Aa?nRTL@02?nRTL@3o`0000;oXik@00?o
0000ok2Vc_n`Y/h03_n`Y/h00ol0003o^Zo>okZ_cP0:okZ_cPGo00003oo;]LD00ol0003oelO;omO7
b`0>omO7b`03o`000?o/glCok=o400_ok=o40_l00004on[cW003o`000?oooooooooo013ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0m
ooooo`?o00005_ooool00ol0003o001fo`000002o`d][@03o`000?lbDlGo<U?500Co<U?500?o0000
ofU[`OmYJl400omYJl400ol0003oMWo>ogIocP07ogIocP03o`000?n?R<SoShS800koShS800?o0000
oj:Aa?nRTL@00onRTL@4o`0000GoXik@00?o0000ok2Vc_n`Y/h03_n`Y/h00ol0003o^Zo>okZ_cP0=
okZ_cP03o`000?o4^m7o000000;o00003?o;]LD00ol0003oelO;omO7b`0=omO7b`03o`000?oPg]?o
000000_ok=o400?o0000onWj`Ol000000ooZli`00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0>Oooool4o`00
01[ooooo00Co001fo`000?l=;Jgo00002?lbDlD01Ol0003oJF_1ofU[`OmYJl7o000000_oMWo>00?o
0000ohn8b?n?R<P03On?R<P00ol0003oXY74oj:Aa003o`0000[oXik@00?o0000ok2Vc_n`Y/h03On`
Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`000?o4^m7oa;_A00?oa;_A0ol00008ol^ea@03o`000?oG
al_oelO;00goelO;00Co0000on3NdooPg]?o00002_o/gl@00ol0003ojO[1o`000003on[cW003o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`005?oo
ool00ol0003oooooooooo`0fooooo`?o00007_ooool01?l0003o001fo`000?l00009oc9Ca@03o`00
0?mYJl7o000000goMWo>00?o0000ohn8b?n?R<P03?n?R<P3o`0000goXik@00?o0000ok2Vc_n`Y/h0
3On`Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`000?o4^m7oa;_A00Koa;_A0ol00004ol^ea@03o`00
0?oGal_oelO;00goelO;00?o0000on3NdooPg]<00_oPg]<00ol0003ok=o4oncOa006oncOa004o`00
0?oYn/7ojO[1o`0000?oj_>L00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo000Dooooo`?o0000<oooool3o`0002;ooooo0_l007H00ol0003o<U?5
oc9Ca@08oc9Ca@03o`000?mfOlkoMWo>00goMWo>00?o0000ohn8b?n?R<P02?n?R<P3o`000003oiFH
e?l0003oXik@00goXik@00?o0000ok2Vc_n`Y/h03On`Y/h00ol0003o^Zo>okZ_cP0<okZ_cP03o`00
0?o4^m7oa;_A00Woa;_A0ol000000oo;]LGo0000omO7b`0=omO7b`03o`000?oPg]?oh=kC00?oh=kC
00?o0000oncOa?o/gl@01Oo/gl@01Ol0003ojO[1onWj`OoYn/7o000000;oj_>L00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`00
0?oooooooooo033ooooo0ol0000Uooooo`03o`000?l007Ko000000[o<U?500?oDGCGo`000?mfOlh0
3OmfOlh00ol0003oShS8ohn8b006ohn8b0;o00001OnEV=@00ol0003oXik@oj>Nd00;oj>Nd003o`00
0?n`Y/ko/:K>00go/:K>00?o0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0=olBkd@;o0000
3OoGal/00ol0003oh=kCon3Nd`05on3Nd`03o`000?o/glCok=o400?ok=o400?o0000onWj`OoYn/40
0_oYn/400ol0003oj_>Lo`00000Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02cooooo1?l0
000Yooooo`03o`000?l007Ko000000Wo<U?500?o0000oe5deol000003_mfOlh00ol0003oShS8ohn8
b003ohn8b0;o00001onEV=@00ol0003oXik@oj>Nd00<oj>Nd003o`000?n`Y/ko/:K>00co/:K>00?o
0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0=olBkd@03o`000?o=bMOo000000_oelO;00?o
0000on3NdooPg]<01_oPg]<00ol0003ok=o4oncOa002oncOa003o`000?oYn/7ojO[100?ojO[100?o
0000on[cW?l000006oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool3o`0002gooooo00Co0000
o`00M_l0003o00002?lbDlD01?l0003oDGCGoe5deol0000>ogIocP03o`000?n?R<So000000;o0000
2_nEV=@00ol0003oXik@oj>Nd00;oj>Nd003o`000?n`Y/ko/:K>00_o/:K>00?o0000okZ_c_nj[lh0
2onj[lh00ol0003oa;_AolBkd@0=olBkd@05o`000?o=bMOocLWGolg9eol000002_oGal/00ol0003o
h=kCon3Nd`07on3Nd`04o`000?o/glCok=o4o`0000KojO[10_l0000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Wooooo`?o0000<Oooool2o`000003o`0W/Ol0003o<U?500Go<U?500?o0000oe5deomA
M=L00_mAM=L00ol0003oMWo>ogIocP0<ogIocP03o`000?nEV=CoUISD00coUISD00?o0000oj>Nd?nS
W]002_nSW]000ol0003o/:K>ok2VcP0;ok2VcP03o`000?nj[lko^Zo>00_o^Zo>00?o0000olBkdOo4
^m403?o4^m400ol0003ocLWGolg9e`03olg9e`;o00001ooGal/00ol0003oh=kCon3Nd`08on3Nd`03
o`000?o/glCo000000KojO[100?o0000on[cW?l000007_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9?ooool3o`0003Gooooo00Co001fo`000?l09k7o00001OlbDlD00ol0003oDGCGoe5de`03oe5de`03
o`000?mfOlkoMWo>00_oMWo>00?o0000oiFHe?nEV=@03?nEV=@00ol0003oXik@oj>Nd00;oj>Nd003
o`000?n`Y/ko/:K>00[o/:K>00?o0000okZ_c_nj[lh02onj[lh00ol0003oa;_AolBkd@0;olBkd@03
o`000?o=bMOocLWG00KocLWG00?o0000omO7booGal/00ooGal/00ol0003oh=kCon3Nd`0:on3Nd`03
o`000?oYn/7ojO[100GojO[10_l0000Oooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`Co0000
>?ooool2o`0000;o02Na00?o0000oc9CaOlbDlD00_lbDlD00ol0003oDGCGoe5de`04oe5de`03o`00
0?mfOlkoMWo>00WoMWo>00?o0000oh>Cf_l000003_nEV=@00ol0003oXik@oj>Nd00:oj>Nd003o`00
0?n`Y/ko/:K>00[o/:K>00?o0000okZ_c_nj[lh02_nj[lh00ol0003oa;_AolBkd@0;olBkd@03o`00
0?o=bMOocLWG00SocLWG00Go0000omO7booGal_oelO;o`00000;on3Nd`03o`000?oOmmWo000000Oo
jO[100?o0000ooooooooool07oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool3o`0003gooooo
00Co001fo`000?l09k7o00001?lbDlD00ol0003oDGCGoe5de`05oe5de`03o`000?mfOlkoMWo>00Oo
MWo>00Go0000oh>Cf_n3Tm[oPi?Jo`00000=oiFHe003o`000?nSW]3oXik@00[oXik@00?o0000ok2V
c_n`Y/h02_n`Y/h00ol0003o^Zo>okZ_cP0:okZ_cP03o`000?o4^m7oa;_A00[oa;_A00?o0000olg9
eoo=bML02_o=bML00ol0003oelO;o`00000;on3Nd`04o`000?oOmmWogoOIo`0000OojO[100?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool3o`00043ooooo0_l00002o`0W
/@05o`000?lbDlGo<U?5oc9CaOl000002?mAM=L00ol0003oMWo>ogIocP05ogIocP03o`000?n3Tm[o
Pi?J00?oPi?J00?o0000oiFHe?nEV=@02onEV=@00ol0003oXik@oj>Nd009oj>Nd003o`000?n`Y/ko
/:K>00[o/:K>00?o0000okZ_c_nj[lh02Onj[lh00ol0003oa;_AolBkd@0:olBkd@03o`000?o=bMOo
cLWG00cocLWG00?o0000on3NdooPg]<02OoPg]<01Ol0003ogoOIomogfOoOmmWo000000KojO[100?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo000:
ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000A?ooool01ol007Ko0000o`0W/Ol0
9k7o0000oc9CaOl000002_mAM=L00ol0003oMWo>ogIocP03ogIocP03o`000?n3Tm[oPi?J00GoPi?J
00?o0000oiFHe?nEV=@02_nEV=@00ol0003oXik@oj>Nd00:oj>Nd003o`000?n`Y/ko/:K>00Wo/:K>
00?o0000okZ_c_nj[lh02Onj[lh00ol0003oa;_AolBkd@0:olBkd@03o`000?o=bMOocLWG00[ocLWG
00?o0000om;Kgol000002_oPg]<00ol0003ogoOIomogf@02omogf@03o`000?oYn/7ojO[100?ojO[1
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo
000Booooo`03o`000?oooooooooo01Cooooo1?l00018ooooo`04o`000?l09k7o02Nao`0W/@;o0000
2omAM=L01Ol0003oMWo>ogIoc_mfOlko000000WoPi?J00?o0000oiFHe?nEV=@02_nEV=@00ol0003o
Xik@oj>Nd007oj>Nd1Go00001Onj[lh00ol0003oa;_AolBkd@09olBkd@03o`000?o=bMOocLWG00[o
cLWG00Go0000om;KgooBfmood]_Oo`000008on3Nd`03o`000?oOmmWogoOI00?ogoOI00?o0000onWj
`OoYn/400_oYn/400ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`0004cooooo00?o0000o`0W/Ol0
9k400_l09k42o`0000_oDGCG00?o0000ogIoc_l000002on3TmX00ol0003oUISDoiFHe00:oiFHe003
o`000?nSW]3oXik@00?oXik@0ol00002ojB/g@03o`000?n]/M_o[K7K00Wo[K7K00?o0000okBhg?nd
^=`01?nd^=`7o`0000Woa;_A00?o0000olg9eoo=bML02_o=bML00ol0003od]_Oom;Kg`02om;Kg`03
o`000?oPg]?oh=kC00Goh=kC00?o0000omogfOoOmmT00ooOmmT00ol0003ojO[1onWj`@02onWj`@03
o`000?oooooooooo02Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00
4_ooool00ol0003oooooooooo`0>ooooo`?o0000D?ooool01?l0003o02Nao`0W/Ol09k42oa=Qf003
o`000?mAM=OoDGCG00WoDGCG0_l0000<oh>CfP03o`000?nEV=CoUISD00WoUISD00?o0000oj>Nd?nS
W]000ol00006ojB/g@03o`000?n]/M_o[K7K00So[K7K00?o0000okBhg?nd^=`02?nd^=`00ol0003o
^l7Nok_1gP03o`0000Goa;_A00?o0000olg9eoo=bML02_o=bML00ol0003od]_Oom;Kg`04om;Kg`03
o`000?oPg]?oh=kC00?oh=kC00?o0000omogfOoOmmT01?oOmmT01Ol0003ojO[1onWj`OoYn/7o0000
02_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003o
ooooooooo`0;ooooo`?o0000E?ooool01?l0003o02Nao`0W/Ol09k42oa=Qf003o`000?mAM=OoDGCG
00SoDGCG0_m[Sn<00ol0003oPi?Joh>CfP0:oh>CfP03o`000?nEV=CoUISD00SoUISD0ol00009ojB/
g@03o`000?n]/M_o[K7K00So[K7K00?o0000okBhg?nd^=`01ond^=`00ol0003o^l7Nok_1gP04ok_1
gP?o000000?oa;_Ao`000?o=bML02_o=bML2o`0000Ood]_O00?o0000on3NdooPg]<00_oPg]<00ol0
003ogoOIomogf@05omogf@03o`000?oYn/7ojO[100;o0000;?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Oooooo1?l0001Hooooo`04
o`000?l09k7o02Nao`0000;o4f7H0_l00008oe5de`03o`000?m[Sn?oJhoS00;o00002on3TmX00ol0
003oUISDoiFHe005oiFHe0;o000000?oVZWPo`000?nT[=d02OnT[=d00ol0003o[K7Kojfaf`07ojfa
f`03o`000?nd^=co];SL00So];SL00?o0000ok_1g_nk`Mh01onk`Mh00ol0003ocLWGolg9e`09olg9
e`03o`000?oBfmood]_O00Sod]_O00Co0000on3NdooPg]?o00002?oOmmT01?l0003ojO[1o`000?l0
000^ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000
ooooooooool01?ooool3o`0005gooooo00Co0000o`0W/Ol09k7o00000olCHMP00ol0003oDGCGoe5d
e`04oe5de`03o`000?m[Sn?oJhoS00?oJhoS00?o0000oh>Cf_n3TmX02On3TmX00ol0003oUISDoiFH
e002oiFHe0;o00001?nJZN000ol0003oY:cMojB/g@08ojB/g@03o`000?n]/M_o[K7K00Ko[K7K00?o
0000okBhg?nd^=`01ond^=`00ol0003o^l7Nok_1gP07ok_1gP04o`000?nob^?o_l[So`0000SocLWG
00?o0000om;KgooBfml02OoBfml00ol0003oh=kCo`000009omogf@?o0000<?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooooooo00;ooooo0ol0
001Qooooo`03o`000?l09k7o000000Co4f7H00?o0000oe5deomAM=L00omAM=L00ol0003oJhoSof^?
h`04of^?h`03o`000?n3Tm[oPi?J00WoPi?J00Co0000oiFHe?l0003o00001onJZN000ol0003oY:cM
ojB/g@07ojB/g@03o`000?n]/M_o[K7K00Ko[K7K00?o0000okBhg?nd^=`01ond^=`00ol0003o^l7N
ok_1gP06ok_1gP03o`000?nob^?o_l[S00;o_l[S0_l00005olg9e`03o`000?oBfmood]_O00_od]_O
00?o0000omogfOoOmmT02?oOmmT2o`00037ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0006Gooooo00?o0000o`0W/Ol000001?lC
HMP2o`0000?oDGCG00?o0000of^?hom[Sn<01Om[Sn<2o`0000[oPi?J0_l00009oiZYh003o`000?nT
[=goY:cM00OoY:cM00?o0000ojfafon]/M/01On]/M/00ol0003o];SLokBhg006okBhg003o`000?nk
`Mko^l7N00Ko^l7N00?o0000oko:honob^<01Onob^<01Ol0003ocLWGolg9eoo=bMOo000000_od]_O
0_l000000oo@kNSo0000omogf@07omogf@03o`000?njo<go000003?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0006Wooooo0_l00006oa=Qf004o`000?mA
M=OoDGCGo`0000WoJhoS00?o0000oh>Cf_n3TmX01_n3TmX01?l0003oSjOUohnWiOl00008oiZYh003
o`000?nT[=goY:cM00OoY:cM00?o0000ojfafon]/M/01On]/M/00ol0003o];SLokBhg005okBhg003
o`000?nk`Mko^l7N00Ko^l7N00?o0000oko:honob^<01onob^<00ol0003ocLWGo`00000;om;Kg`05
o`000?o@kNSod>gXom3]j?l000001ooOmmT01?l0003o^_c=o`000?l0000dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool001?ooooo00?o0000ooooooooool0Ioooool00ol0
9k7o0000oa=Qf005oa=Qf003oe5deol0003oJhoS00[oJhoS0_l00005oh>CfP03o`000?n?YnGoSjOU
00;oSjOU0_l00007oiZYh003o`000?nT[=goY:cM00KoY:cM00?o0000ojfafon]/M/01On]/M/00ol0
003o];SLokBhg005okBhg003o`000?nk`Mko^l7N00Go^l7N00?o0000oko:honob^<02Onob^<00ol0
003od]_Oom;Kg`08om;Kg`;o00001?o@kNP00ol0003ogoOIomogf@03omogf@;o000000?o^_c=o`00
0?l00000=_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo000Dooooo`;o
0000J?ooool00ol0003o4f7Hoa=Qf005oa=Qf0;o00003?m[Sn<01Ol0003oPi?Joh>Cf_n3Tm[o0000
00OoSjOU00?o0000oiZYh?nJZN001OnJZN000ol0003oY:cMojB/g@06ojB/g@03o`000?n]/M_o[K7K
00Co[K7K00?o0000okBhg?nd^=`01?nd^=`00ol0003o^l7Nok_1gP05ok_1gP03o`000?nob^?o_l[S
00Wo_l[S00?o`MGYo`000?oBfml01ooBfml2o`0000Kod>gX00?o0000omogfOoOmmT00_oOmmT00ol0
003o^_c=ok[lc@02o`0003Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04oooo
o`005_ooool00ol0003oooooo`00001Vooooo`;o00001OlCHMP01?l0003oBXc[o`000?l0000;of^?
h`;oPi?J00?o0000ohnWiOn?YnD01on?YnD2o`0000KoVZWP00?o0000ojB/gOnT[=d01OnT[=d00ol0
003o[K7Kojfaf`03ojfaf`03o`000?nd^=co];SL00Go];SL00?o0000ok_1g_nk`Mh01?nk`Mh00ol0
003o_l[Soko:h`07oko:h`03o`000?o1eNWo`MGY00;o`MGY00?o0000om;KgooBfml00ooBfml2o`00
00Sod>gX00?o0000omogfOoOmmT00_l00002ok[lc@;o0000>Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Cooooo000Gooooo`;o0000J?ooool00ol0003o4f7Hoa=Qf003oa=Qf003
o`000?m:S>_oBXc[00;o00002_m[Sn<2o`0000_oSjOU00?o0000oiZYh?nJZN000onJZN000ol0003o
Y:cMojB/g@05ojB/g@03o`000?n]/M_o[K7K00?o[K7K00?o0000okBhg?nd^=`01?nd^=`00ol0003o
^l7Nok_1gP04ok_1gP03o`000?nob^?o_l[S00Ko_l[S0_l00006ol7Ej@05o`000?oBfmood]_Oom;K
gol000002_o@kNP00ol0003ogoOIo`000004ok[lc@03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`04ooooo`006?ooool2o`0006Sooooo0_l00003oa=Qf003
o`000?m:S>_oBXc[00;oBXc[0ol00007of^?h`04o`000?n2Ynco0000o`0000[oSjOU00?o0000oiZY
h?nJZN000onJZN000ol0003oY:cMojB/g@04ojB/g@[o00000ond^=`00ol0003o^l7Nok_1gP03ok_1
gP03o`000?nob^?o_l[S00Go_l[S0_l00008ol7Ej@04o`000?oBfmoo0000o`0000_od>gX0_l00004
ok[lc@03o`000?oooooooooo03_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`006_ooool00ol0003oooooooooo`1Vooooo`03o`10]_l0003o000000;o4f7H00?o0000odZ<
jom:S>/01?m:S>/2o`0000GoJhoS00Co0000oh:Wk?n2YncoPZO/0ol00008ohnWi@;o00001?nJZN00
0ol0003oY:cMojB/g@03o`000003oj>mk?l0003oY[o[00?oY[o[00Co0000ojW2k?nY`^coZL;/1_l0
0002ok_1gP03o`000?nob^?o_l[S00Go_l[S00?o0000ol7EjOo1eNT02Oo1eNT00ol0003od>gXom3]
j00;om3]j003o`000?njo<go^_c=00;o^_c=00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0I?ooool0
1Ol0003o042fo`000?lCHMSo000000SoBXc[0_l00002of^?h`03o`000?n2YncoPZO/00GoPZO/0_l0
0008ohnWi@03o`000?nJZN3oVZWP00Co00001OnS_N`01Ol0003oY[o[ojJojonV_n_o000000GoZL;/
00Co0000ojc5kOn/aNgo[<G]0_l00006oko:h`;o00002_o1eNT00ol0003o_mo`o`000009om3]j0?o
000000?o__W]o`000?njo<d00_njo<d00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00oooool001gooooo0_l0001Wooooo`04o`10]_l0003o4f7Ho`0000Wo
BXc[00?o0000of^?hol000002On2Yn`2o`0000OoSjOU0_l00004oinlk@03o`000?nS_NcoXkg/00;o
Xkg/00Go0000ojJojonV_n_oY[o[o`000004ojW2k005o`000?n/aNgo[<G]ojc5kOl000000_n]bNh0
1?l0003o_l[Soko:honob^<2o`0000Oo`MGY0ol00004okoOl003o`000?o@kNSod>gX00God>gX0_l0
0003okkik@04o`000?njo<go0000o`0004?ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`03ooooo`007_ooool00ol0003oooooooooo`1Vooooo`03o`000?l0@;Ko000000_oBXc[0ol0
0009oh:Wk0?o00001?n?YnD01?l0003oV[c_o`000?l00003oinlk@05o`000?nS_NcoXkg/oj>mk?l0
00000onV_n/01Ol0003oZL;/ojW2k?nY`^co000000;o[<G]0_l00004ojg9kP03o`000?nob^?o0000
00Oo`MGY0_l00007okoOl003o`000?o@kNSod>gX00?od>gX0_l00004okkik@03o`000?njo<go0000
04Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`007oooool2o`0006Oo
oooo00Co0000o`10]_l0003o00002Om:S>/00ol0003oLjWcog>Yl`03o`0000WoPZO/0_l000000on?
YnGo0000oiZlk`03oiZlk`;o00000_nO_>d01Ol0003oXkg/oj>mk?nS_Nco000000;oY[o[00Co0000
ojW2k?nY`^co00000_n/aNd00ol0003o[LW^ojg9kP04ojg9kP;o00001Oo1eNT3o`0000Wo_mo`00?o
0000om3]j?o@kNP00ol00005okkik@?o0000B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo000Qooooo`03o`000?oooooooooo06Gooooo00?o0000o`10]_l0@;H00ol00007
odZ<j`03o`000?mcZO?oLjWc00;oLjWc0ol00008oh:Wk0?o00001OnJ_>l2o`000007oinlkOl0003o
0000oj>mk?l0003oY[o[o`000002ojW2k004o`000?n/aNgo0000o`0000Co[LW^0ol00002ojg=l@03
o`000?o1eNWo000000;o00003?nogo03o`0000Oo__W]0_l0001;ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00oooool002;ooooo0ol0001Vooooo`04o`000?l0@;Ko0000oan6jP?o
00001?m:S>/00ol0003oLjWcog>Yl`05og>Yl`?o00001On2Yn`00ol0003oU[gboiJmlP04o`0000?o
V[c_0_l000000onO_>go0000oj>mk002o`0000;oZL;/0_l00003ojg9kP?o00000on]cO44o`0000oo
_mo`00?o0000okkikOnnnNd01_nnnNd00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0IOooool00ol0003o042f
o`000003oan6jP;o00000_m:S>/00ol0003oLjWcog>Yl`08og>Yl`?o000000?oPZO/o`000?nF_O80
1_nF_O84o`000003oiZlkol0003o000000?o000000CoZL;/o`000?l0003o[LW^2Ol00003oj_@l`03
o`000?nogo3o_mo`00Go_mo`1Ol00003okGWm`03o`000?nnnNgo__W]00Go__W]00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o0000
Ioooool2o`0000Co7hKZ0_l000000om:S>_o0000og>Yl`0;og>Yl`_o00000_nF_O8=o`0000WoZm3c
00?o0000okoOl?nogo001Ol00007okGWm`03o`000?nnnNgo__W]00;o__W]0ol0001Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0I_oo
ool00ol0003o7hKZoan6jP04oan6jPGo00002OmcZO<00ol0003oTkkeoi>nm@07oi>nmA_o00002one
ioL00ol0003o__W]okkik@04o`0005Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`02ooooo`00:?ooool00ol0003oooooo`00001Vooooo`?o00001OlOQ^X00ol0003oI:kiofB^n@07
o`0000?oLjWc00Co0000oi>nmOnC__GoTkke2ol000000on@bO_o0000oiS@n`07o`0000SoYm;f00?o
0000okGWmoneioL02_neioL4o`000003oho_h_l0003o000005Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001V
ooooo`03o`000?oooooo07gF00Co00000_lOQ^X00ol0003oI:kiofB^n@06ofB^n@Oo00000on@`OL4
o`000004oho5nOl0003o0000oi39n`;o00000_nHd?/4o`0000;oXm;h1Ol00002ojOBmP03o`000?ne
ioOo]NOg00?o]NOg1Ol00002okGWm`;o00000_n?kn82o`0005[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool00_ooool2o`1meP;o000000?o7hKZo`000?mT[_T02_mT[_T0
0ol0003oT<7goi31m`03o`0000CoSlGi00Co0000oi39non@bO_oT<Wk0_l00003oiS@n`03o`000?nM
d_[oWM;j00;o00001OnSd_P8o`0000CoXnWk0_l00004oho_hP03o`000?oooooooooo05_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000
ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool01?ooool00ol0003o07gFo`1meP0<
o`000003ofB^nOl0003o000000GoSlGi0_l00003oi39n`04o`000?nCc?_oTlcko`0000?oV=3k00Co
0000oigBn_nMd_[oWM;j0_l000000onSd_So0000o`00000;oj?Yn`04o`000?n?kn;oSnoRoho_hP?o
0000G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`06ooooo`;o0000
0_l0OMH2o`0000[oF;Ck0ol000000on?aOWo0000oi39n`03oi39n`05o`000?nCc?_oTlckoi?<nol0
00001?nHd?/00ol0003oWM;joigBnP09o`0000GoXnWk1_l0001Rooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool03?ooool2o`00063ooooo
00?o0000ooooooooool02Oooool00ol0003o07gFo`1meP02o`0000_oF;Ck1?l00002oi39n`05o`00
0?nCc?_oTlckoi?<nol000000_nHd?/5o`0000WoRN;k2?l0001Vooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03Oooool2o`0005oooooo
00?o0000ooooooooool03?ooool01?l0003o07gFo`000?l00002oeRdn`Go00001_mD_?X9o`0000Go
KmKj0_l00007ohWRn`Go0000J_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007o
oooo000Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0@ooooo`?o00002_mD_?X00ol0003oG<Sioec8n@04oec8n@03o`000?m_e_[oKmKj00OoKmKj
00Co0000ohWRnon9h__oRN;k1Ol0001^ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00Oooool001kooooo00?oEEEEofIVI_l000004_ooool2o`000003ooooool0003ooooo05Sooooo
00?o0000ooooooooool05Oooool5o`0000;oE;cj00?o0000oec8nOmLb?T01_mLb?T00ol0003oKmKj
ofoFnP03ofoFnPSo0000L_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo
000eooooo`;o0000FOooool00ol0003oooooooooo`0Jooooo`;o000000?oG<Sio`000?l000003Ol0
001jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003Kooooo0_l0001H
ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01
ooooo`00>?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000iooooo`04o`000?oooooooooo
o`0005?ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`09ooooo`7o00000Oooool1
ooooo`00>_ooool3o`0005?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00??ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool003gooooo0_l0001Aooooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool003oooooo00?o
0000ooooool00000C_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo0010ooooo`;o0000C_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo0011ooooo`;o0000COooool00ol0003oooooooooo`2^oooo
o`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool004Cooooo
0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0016ooooo`;o0000B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`00<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000Aoooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`04ogMgMolb<S;oooooo`0004Kooooo00?o0000ooooooooool0/_ooool01Ol0003o
oooooooooooooooo0000007ooooo000Zooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00ol00013ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooo
oooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2cooooo`04o`000?oooooo
ooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo007o0000000booooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`08ooooo`;o0000@?ooool00ol0003oooooooooo`2eooooo`7o00000Oooool1o`000000<_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0003kooooo
00?o0000ooooooooool0]_ooool2o`000000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000:ooooo`;o0000?Oooool00ol0003oooooooooo`2eooooo`?o0000001Cooooo`05o`000?oo
ooooooooooooool00000>?ooool00ol0003oooooooooo`2`ooooo`Go00000oooool005Cooooo00Co
0000oooooooooooo0000>?ooool00ol0003oooooooooo`2/ooooo`Co00002?ooool005Gooooo0ol0
000hooooo`03o`000?oooooooooo0:Sooooo1?l0000<ooooo`00Eoooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0:Cooooo1Ol0000@ooooo`00F?ooool2o`0003Gooooo00?o0000oooo
ooooool0X?ooool4o`0001Gooooo001Jooooo`03o`000?oooooo000003;ooooo00?o0000oooooooo
ool0W?ooool4o`0001Wooooo001Kooooo`;o0000<_ooool00ol0003oooooooooo`2Gooooo`Go0000
7Oooool005gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co00008_oo
ool005kooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`2>ooooo`Go00009_oo
ool005oooooo0ol0000]ooooo`03o`000?oooooooooo08[ooooo1?l0000[ooooo`00HOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000_ooooo`00Doooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00[ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo1Ol0000coooo
o`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`1mooooo`Co0000>?ooool005?ooooo00Go410@oooooooooooooooooa0@400=oooo
o`;o0000:?ooool00ol0003oooooooooo`1iooooo`Co0000??ooool005?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool5o`00
043ooooo001Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000S
ooooo`03o`000?oooooooooo073ooooo1?l00015ooooo`00Doooool01Ol@413ooooooooooooooooo
410@017ooooo0ol0000Sooooo`03o`000?oooooooooo06_ooooo1Ol00019ooooo`00Doooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo1?l0001>
ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l000000ooooooo0000ooooo`0N
ooooo`03o`000?oooooooooo06?ooooo1?l0001Booooo`00K_ooool2o`0001oooooo00?o0000oooo
ooooool0G_ooool5o`0005Kooooo001_ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0F_ooool4o`0005_ooooo001`ooooo`;o00007Oooool00ol0003oooooooooo`1Fooooo`Co0000
Goooool007;ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`1Aooooo`Go0000Hooo
ool007?ooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0001Xooooo`00MOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001/ooooo`00M_ooool2o`000003
ooooool0003ooooo01Cooooo00?o0000ooooooooool0A?ooool5o`00073ooooo001hooooo`;o0000
5Oooool00ol0003oooooooooo`10ooooo`Co0000MOooool007Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0kooooo`Go0000NOooool007[ooooo0_l000000ooooooo0000ooooo`0@
ooooo`03o`000?oooooooooo03Oooooo1?l0001nooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool2o`00017ooooo00?o
0000ooooooooool0<oooool4o`0008;ooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool2o`0000oooooo00?o0000ooooooooool0;ooo
ool5o`0008Kooooo001Sooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:oooool4o`0008_ooooo001S
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`?o00002ooo
ool00ol0003oooooooooo`0Wooooo`Co0000Soooool006?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02;ooooo1Ol0002Cooooo`00Hoooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01ko
oooo1?l0002Hooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03Oooool3o`0000Oooooo00?o0000ooooooooool06Oooool5o`0009cooooo001Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000XOooool008Oooooo0_l00005ooooo`03o`000?oooooooooo017ooooo
1?l0002Uooooo`00ROooool2o`0000?ooooo00?o0000ooooooooool03?ooool5o`000:Wooooo002:
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:kooooo002;ooooo`;o000000?ooooo
o`000?ooool01Oooool4o`000;;ooooo002=ooooo`;o000000?oooooo`000?l000000ol0002foooo
o`00S_ooool2o`000;_ooooo003oooooodcooooo003oooooodcooooo0024ooooo`Co000000?o410@
ooooooooool0`?ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000oooooooo
ool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_oo
ool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Co
oooo00?oEEEEofIVI_l00000a?ooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In this ",
  Cell[BoxData[
      \(TraditionalForm\`l = 2, m = 0\)]],
  " mode, water flows from the equator to the poles and back, producing \
elliptical perturbations. The reader is invited to explore the behavior of \
other modes  by reevaluating these animations for different ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  "-values. "
}], "Text"],

Cell[TextData[{
  "\tOscillations with ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  " are also of great importance. Of particular interest is the \
traveling-wave form of the ",
  Cell[BoxData[
      \(TraditionalForm\`l = \(m = 2\)\)]],
  " perturbation, which is an elliptical distortion of the ocean surface that \
travels around the equator. This mode is actually a linear combination of the \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(l = 2\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(m = \(\[PlusMinus]2\)\)\)\)]],
  " spherical harmonics, and can most easily be expressed in terms of the \
associated Legendre functions  making up these harmonics: ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_\(2, \ \(\[PlusMinus]2\)\) \[Proportional] \ \
\(\(P\_2\%\(\(\ \)\(2\)\)\)(
            cos\[Theta])\)\ \
\[ExponentialE]\^\(\[ImaginaryI](\(\[PlusMinus]2\)\ \[Phi]\  - \ \
\(\[Omega]\_2\) t)\)\)]],
  ". [Here we have used the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_2\%\(-2\)\)(cos\[Theta])\)]],
  "is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\(P\_2\%\(\(\ \)\(2\)\)\)(cos\[Theta])\)]],
  "; see Table ",
  ButtonBox["3.2",
    ButtonData:>{"Chapter3.nb", "Table 3.2"},
    ButtonStyle->"Hyperlink"],
  " in Sec. 3.2.4.] The resulting disturbance is shown in Cell ",
  ButtonBox["4.47",
    ButtonData:>"Cell 4.47",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(l = 2; \ m = 2;\), "\n", 
    \(\(Table[
        ParametricPlot3D[\((1\  +  .05  LegendreP[l, m, Cos[\[Theta]]] 
                  Cos[m\ \[Phi]\  - \ \ t])\) {Sin[\[Theta]] Cos[\[Phi]], 
              Sin[\[Theta]] Sin[\[Phi]], Cos[\[Theta]]}, {\[Theta], 0, 
            Pi}, {\[Phi], 0, 2  Pi}, 
          PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-1.2\), 1.2}, {\(-1.2\), 
                1.2}}], {t, 0, 2  Pi - 0.2  Pi,  .2\ Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.47"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.42097 .53532 m .40498 .57592 L .47548 .59258 L p .73 .6 .711 r
F P
0 g
s
.47548 .59258 m .48155 .55207 L .42097 .53532 L p .73 .6 .711 r
F P
0 g
s
.47064 .63283 m .47548 .59258 L .40498 .57592 L p .732 .576 .679 r
F P
0 g
s
.48155 .55207 m .47548 .59258 L .54252 .59515 L p .682 .546 .693 r
F P
0 g
s
.47548 .59258 m .47064 .63283 L .54384 .63271 L p .676 .517 .663 r
F P
0 g
s
.54384 .63271 m .54252 .59515 L .47548 .59258 L p .676 .517 .663 r
F P
0 g
s
.43923 .49678 m .42097 .53532 L .48155 .55207 L p .727 .622 .741 r
F P
0 g
s
.48155 .55207 m .48875 .51204 L .43923 .49678 L p .727 .622 .741 r
F P
0 g
s
.48875 .51204 m .48155 .55207 L .54078 .55627 L p .687 .575 .724 r
F P
0 g
s
.54252 .59515 m .54078 .55627 L .48155 .55207 L p .682 .546 .693 r
F P
0 g
s
.40498 .57592 m .3918 .61777 L .47064 .63283 L p .732 .576 .679 r
F P
0 g
s
.46712 .67209 m .47064 .63283 L .3918 .61777 L p .732 .55 .646 r
F P
0 g
s
.47064 .63283 m .46712 .67209 L .54477 .66861 L p .669 .488 .631 r
F P
0 g
s
.54477 .66861 m .54384 .63271 L .47064 .63283 L p .669 .488 .631 r
F P
0 g
s
.45926 .4609 m .43923 .49678 L .48875 .51204 L p .722 .645 .772 r
F P
0 g
s
.48875 .51204 m .49698 .47325 L .45926 .4609 L p .722 .645 .772 r
F P
0 g
s
.49698 .47325 m .48875 .51204 L .53862 .51667 L p .69 .605 .756 r
F P
0 g
s
.54078 .55627 m .53862 .51667 L .48875 .51204 L p .687 .575 .724 r
F P
0 g
s
.36758 .50671 m .34164 .5447 L .40498 .57592 L p .783 .668 .737 r
F P
0 g
s
.40498 .57592 m .42097 .53532 L .36758 .50671 L p .783 .668 .737 r
F P
0 g
s
.3918 .61777 m .40498 .57592 L .34164 .5447 L p .795 .651 .703 r
F P
0 g
s
.53862 .51667 m .54078 .55627 L .59509 .54859 L p .651 .542 .718 r
F P
0 g
s
.54078 .55627 m .54252 .59515 L .60277 .58574 L p .642 .509 .686 r
F P
0 g
s
.60277 .58574 m .59509 .54859 L .54078 .55627 L p .642 .509 .686 r
F P
0 g
s
.39649 .47226 m .36758 .50671 L .42097 .53532 L p .769 .683 .768 r
F P
0 g
s
.42097 .53532 m .43923 .49678 L .39649 .47226 L p .769 .683 .768 r
F P
0 g
s
.54252 .59515 m .54384 .63271 L .60844 .62131 L p .631 .477 .655 r
F P
0 g
s
.60844 .62131 m .60277 .58574 L .54252 .59515 L p .631 .477 .655 r
F P
0 g
s
.53862 .51667 m .53605 .47725 L .49698 .47325 L p .69 .605 .756 r
F P
0 g
s
.53605 .47725 m .53862 .51667 L .58524 .51047 L p .66 .577 .751 r
F P
0 g
s
.59509 .54859 m .58524 .51047 L .53862 .51667 L p .651 .542 .718 r
F P
0 g
s
.34164 .5447 m .31983 .5855 L .3918 .61777 L p .795 .651 .703 r
F P
0 g
s
.38196 .6598 m .3918 .61777 L .31983 .5855 L p .806 .63 .664 r
F P
0 g
s
.3918 .61777 m .38196 .6598 L .46712 .67209 L p .732 .55 .646 r
F P
0 g
s
.4274 .44169 m .39649 .47226 L .43923 .49678 L p .754 .696 .797 r
F P
0 g
s
.43923 .49678 m .45926 .4609 L .4274 .44169 L p .754 .696 .797 r
F P
0 g
s
.465 .70967 m .46712 .67209 L .38196 .6598 L p .731 .521 .608 r
F P
0 g
s
.46712 .67209 m .465 .70967 L .54532 .70267 L p .66 .457 .598 r
F P
0 g
s
.54532 .70267 m .54477 .66861 L .46712 .67209 L p .66 .457 .598 r
F P
0 g
s
.54384 .63271 m .54477 .66861 L .61233 .65512 L p .619 .444 .624 r
F P
0 g
s
.61233 .65512 m .60844 .62131 L .54384 .63271 L p .619 .444 .624 r
F P
0 g
s
.48065 .42809 m .45926 .4609 L .49698 .47325 L p .715 .669 .803 r
F P
0 g
s
.49698 .47325 m .5061 .43652 L .48065 .42809 L p .715 .669 .803 r
F P
0 g
s
.5061 .43652 m .49698 .47325 L .53605 .47725 L p .692 .637 .79 r
F P
0 g
s
.53605 .47725 m .53309 .4392 L .5061 .43652 L p .692 .637 .79 r
F P
0 g
s
.53309 .4392 m .53605 .47725 L .57319 .47235 L p .667 .615 .787 r
F P
0 g
s
.58524 .51047 m .57319 .47235 L .53605 .47725 L p .66 .577 .751 r
F P
0 g
s
.57319 .47235 m .58524 .51047 L .62714 .49351 L p .632 .563 .758 r
F P
0 g
s
.58524 .51047 m .59509 .54859 L .6445 .52934 L p .621 .525 .725 r
F P
0 g
s
.6445 .52934 m .62714 .49351 L .58524 .51047 L p .621 .525 .725 r
F P
0 g
s
.59509 .54859 m .60277 .58574 L .65824 .56507 L p .609 .49 .692 r
F P
0 g
s
.65824 .56507 m .6445 .52934 L .59509 .54859 L p .609 .49 .692 r
F P
0 g
s
.31983 .5855 m .30332 .62797 L .38196 .6598 L p .806 .63 .664 r
F P
0 g
s
.37596 .70079 m .38196 .6598 L .30332 .62797 L p .815 .604 .617 r
F P
0 g
s
.38196 .6598 m .37596 .70079 L .465 .70967 L p .731 .521 .608 r
F P
0 g
s
.45959 .41502 m .4274 .44169 L .45926 .4609 L p .736 .708 .825 r
F P
0 g
s
.45926 .4609 m .48065 .42809 L .45959 .41502 L p .736 .708 .825 r
F P
0 g
s
.60277 .58574 m .60844 .62131 L .66854 .60002 L p .598 .456 .659 r
F P
0 g
s
.66854 .60002 m .65824 .56507 L .60277 .58574 L p .598 .456 .659 r
F P
0 g
s
.57319 .47235 m .55909 .43561 L .53309 .4392 L p .667 .615 .787 r
F P
0 g
s
.55909 .43561 m .57319 .47235 L .60618 .45859 L p .644 .603 .794 r
F P
0 g
s
.62714 .49351 m .60618 .45859 L .57319 .47235 L p .632 .563 .758 r
F P
0 g
s
.54477 .66861 m .54532 .70267 L .61465 .68726 L p .607 .412 .592 r
F P
0 g
s
.61465 .68726 m .61233 .65512 L .54477 .66861 L p .607 .412 .592 r
F P
0 g
s
.36801 .44172 m .33201 .46995 L .36758 .50671 L p .81 .759 .806 r
F P
0 g
s
.36758 .50671 m .39649 .47226 L .36801 .44172 L p .81 .759 .806 r
F P
0 g
s
.34164 .5447 m .36758 .50671 L .33201 .46995 L p .838 .758 .775 r
F P
0 g
s
.46433 .74486 m .465 .70967 L .37596 .70079 L p .727 .487 .564 r
F P
0 g
s
.465 .70967 m .46433 .74486 L .54551 .7348 L p .65 .423 .561 r
F P
0 g
s
.54551 .7348 m .54532 .70267 L .465 .70967 L p .65 .423 .561 r
F P
0 g
s
.40619 .41812 m .36801 .44172 L .39649 .47226 L p .781 .757 .831 r
F P
0 g
s
.39649 .47226 m .4274 .44169 L .40619 .41812 L p .781 .757 .831 r
F P
0 g
s
.50308 .39861 m .48065 .42809 L .5061 .43652 L p .705 .694 .838 r
F P
0 g
s
.5061 .43652 m .51594 .40271 L .50308 .39861 L p .705 .694 .838 r
F P
0 g
s
.51594 .40271 m .5061 .43652 L .53309 .4392 L p .69 .672 .828 r
F P
0 g
s
.33201 .46995 m .29948 .50272 L .34164 .5447 L p .838 .758 .775 r
F P
0 g
s
.31983 .5855 m .34164 .5447 L .29948 .50272 L p .866 .753 .736 r
F P
0 g
s
.53309 .4392 m .52982 .40386 L .51594 .40271 L p .69 .672 .828 r
F P
0 g
s
.52982 .40386 m .53309 .4392 L .55909 .43561 L p .672 .656 .826 r
F P
0 g
s
.60844 .62131 m .61233 .65512 L .67568 .63384 L p .586 .422 .626 r
F P
0 g
s
.67568 .63384 m .66854 .60002 L .60844 .62131 L p .586 .422 .626 r
F P
0 g
s
.60618 .45859 m .62714 .49351 L .66252 .4661 L p .607 .561 .777 r
F P
0 g
s
.62714 .49351 m .6445 .52934 L .68829 .49807 L p .592 .52 .743 r
F P
0 g
s
.68829 .49807 m .66252 .4661 L .62714 .49351 L p .592 .52 .743 r
F P
0 g
s
.55909 .43561 m .54329 .40183 L .52982 .40386 L p .672 .656 .826 r
F P
0 g
s
.54329 .40183 m .55909 .43561 L .58193 .42586 L p .655 .648 .832 r
F P
0 g
s
.60618 .45859 m .58193 .42586 L .55909 .43561 L p .644 .603 .794 r
F P
0 g
s
.49262 .39208 m .45959 .41502 L .48065 .42809 L p .715 .72 .853 r
F P
0 g
s
.48065 .42809 m .50308 .39861 L .49262 .39208 L p .715 .72 .853 r
F P
0 g
s
.30332 .62797 m .29316 .67063 L .37596 .70079 L p .815 .604 .617 r
F P
0 g
s
.37415 .73942 m .37596 .70079 L .29316 .67063 L p .821 .569 .559 r
F P
0 g
s
.37596 .70079 m .37415 .73942 L .46433 .74486 L p .727 .487 .564 r
F P
0 g
s
.44563 .39895 m .40619 .41812 L .4274 .44169 L p .751 .752 .853 r
F P
0 g
s
.4274 .44169 m .45959 .41502 L .44563 .39895 L p .751 .752 .853 r
F P
0 g
s
.58193 .42586 m .60618 .45859 L .63276 .43669 L p .623 .604 .81 r
F P
0 g
s
.66252 .4661 m .63276 .43669 L .60618 .45859 L p .607 .561 .777 r
F P
0 g
s
.6445 .52934 m .65824 .56507 L .70969 .53178 L p .576 .481 .71 r
F P
0 g
s
.70969 .53178 m .68829 .49807 L .6445 .52934 L p .576 .481 .71 r
F P
0 g
s
.29948 .50272 m .27195 .53955 L .31983 .5855 L p .866 .753 .736 r
F P
0 g
s
.30332 .62797 m .31983 .5855 L .27195 .53955 L p .893 .742 .687 r
F P
0 g
s
.54532 .70267 m .54551 .7348 L .6155 .71791 L p .594 .378 .558 r
F P
0 g
s
.6155 .71791 m .61465 .68726 L .54532 .70267 L p .594 .378 .558 r
F P
0 g
s
.65824 .56507 m .66854 .60002 L .72651 .56649 L p .561 .442 .675 r
F P
0 g
s
.72651 .56649 m .70969 .53178 L .65824 .56507 L p .561 .442 .675 r
F P
0 g
s
.61233 .65512 m .61465 .68726 L .67995 .66645 L p .573 .387 .592 r
F P
0 g
s
.67995 .66645 m .67568 .63384 L .61233 .65512 L p .573 .387 .592 r
F P
0 g
s
.58193 .42586 m .55501 .39676 L .54329 .40183 L p .655 .648 .832 r
F P
0 g
s
.55501 .39676 m .58193 .42586 L .59958 .41075 L p .64 .65 .844 r
F P
0 g
s
.63276 .43669 m .59958 .41075 L .58193 .42586 L p .623 .604 .81 r
F P
0 g
s
.48574 .3839 m .44563 .39895 L .45959 .41502 L p .721 .745 .871 r
F P
0 g
s
.45959 .41502 m .49262 .39208 L .48574 .3839 L p .721 .745 .871 r
F P
0 g
s
.46518 .77692 m .46433 .74486 L .37415 .73942 L p .719 .444 .509 r
F P
0 g
s
.46433 .74486 m .46518 .77692 L .54532 .76479 L p .638 .384 .518 r
F P
0 g
s
.54532 .76479 m .54551 .7348 L .46433 .74486 L p .638 .384 .518 r
F P
0 g
s
.52982 .40386 m .52632 .37269 L .51594 .40271 L closepath p .672 .704 .871 r
F P
0 g
s
.54329 .40183 m .52632 .37269 L .52982 .40386 L closepath p .669 .701 .871 r
F P
0 g
s
.51594 .40271 m .52632 .37269 L .50308 .39861 L closepath p .677 .71 .873 r
F P
0 g
s
.27195 .53955 m .251 .57951 L .30332 .62797 L p .893 .742 .687 r
F P
0 g
s
.29316 .67063 m .30332 .62797 L .251 .57951 L p .919 .722 .621 r
F P
0 g
s
.55501 .39676 m .52632 .37269 L .54329 .40183 L closepath p .667 .701 .872 r
F P
0 g
s
.50308 .39861 m .52632 .37269 L .49262 .39208 L closepath p .684 .722 .878 r
F P
0 g
s
.66854 .60002 m .67568 .63384 L .73861 .60159 L p .545 .402 .638 r
F P
0 g
s
.73861 .60159 m .72651 .56649 L .66854 .60002 L p .545 .402 .638 r
F P
0 g
s
.59958 .41075 m .63276 .43669 L .64981 .40858 L p .604 .614 .834 r
F P
0 g
s
.63276 .43669 m .66252 .4661 L .68716 .42988 L p .579 .568 .805 r
F P
0 g
s
.68716 .42988 m .64981 .40858 L .63276 .43669 L p .579 .568 .805 r
F P
0 g
s
.66252 .4661 m .68829 .49807 L .7212 .45551 L p .554 .522 .774 r
F P
0 g
s
.7212 .45551 m .68716 .42988 L .66252 .4661 L p .554 .522 .774 r
F P
0 g
s
.59958 .41075 m .56378 .38915 L .55501 .39676 L p .64 .65 .844 r
F P
0 g
s
.56378 .38915 m .59958 .41075 L .61003 .39186 L p .628 .66 .862 r
F P
0 g
s
.64981 .40858 m .61003 .39186 L .59958 .41075 L p .604 .614 .834 r
F P
0 g
s
.56378 .38915 m .52632 .37269 L .55501 .39676 L closepath p .666 .701 .873 r
F P
0 g
s
.54551 .7348 m .54532 .76479 L .61483 .74716 L p .579 .34 .518 r
F P
0 g
s
.61483 .74716 m .6155 .71791 L .54551 .7348 L p .579 .34 .518 r
F P
0 g
s
.29316 .67063 m .29015 .71178 L .37415 .73942 L p .821 .569 .559 r
F P
0 g
s
.37676 .77434 m .37415 .73942 L .29015 .71178 L p .82 .52 .482 r
F P
0 g
s
.37415 .73942 m .37676 .77434 L .46518 .77692 L p .719 .444 .509 r
F P
0 g
s
.61465 .68726 m .6155 .71791 L .68146 .69788 L p .558 .35 .555 r
F P
0 g
s
.68146 .69788 m .67995 .66645 L .61465 .68726 L p .558 .35 .555 r
F P
0 g
s
.49262 .39208 m .52632 .37269 L .48574 .3839 L closepath p .688 .736 .887 r
F P
0 g
s
.44064 .38176 m .399 .3933 L .40619 .41812 L p .759 .8 .886 r
F P
0 g
s
.40619 .41812 m .44563 .39895 L .44064 .38176 L p .759 .8 .886 r
F P
0 g
s
.36801 .44172 m .40619 .41812 L .399 .3933 L p .798 .829 .876 r
F P
0 g
s
.399 .3933 m .35908 .40976 L .36801 .44172 L p .798 .829 .876 r
F P
0 g
s
.33201 .46995 m .36801 .44172 L .35908 .40976 L p .84 .857 .857 r
F P
0 g
s
.68829 .49807 m .70969 .53178 L .75098 .48512 L p .527 .474 .741 r
F P
0 g
s
.75098 .48512 m .7212 .45551 L .68829 .49807 L p .527 .474 .741 r
F P
0 g
s
.48327 .37495 m .44064 .38176 L .44563 .39895 L p .723 .771 .891 r
F P
0 g
s
.44563 .39895 m .48574 .3839 L .48327 .37495 L p .723 .771 .891 r
F P
0 g
s
.56863 .37986 m .52632 .37269 L .56378 .38915 L closepath p .662 .702 .876 r
F P
0 g
s
.61003 .39186 m .56863 .37986 L .56378 .38915 L p .628 .66 .862 r
F P
0 g
s
.35908 .40976 m .32189 .43128 L .33201 .46995 L p .84 .857 .857 r
F P
0 g
s
.29948 .50272 m .33201 .46995 L .32189 .43128 L p .885 .882 .825 r
F P
0 g
s
.67568 .63384 m .67995 .66645 L .74592 .63653 L p .527 .359 .597 r
F P
0 g
s
.74592 .63653 m .73861 .60159 L .67568 .63384 L p .527 .359 .597 r
F P
0 g
s
.48574 .3839 m .52632 .37269 L .48327 .37495 L closepath p .688 .75 .899 r
F P
0 g
s
.251 .57951 m .23807 .62123 L .29316 .67063 L p .919 .722 .621 r
F P
0 g
s
.29015 .71178 m .29316 .67063 L .23807 .62123 L p .939 .685 .527 r
F P
0 g
s
.70969 .53178 m .72651 .56649 L .77548 .51818 L p .498 .423 .702 r
F P
0 g
s
.77548 .51818 m .75098 .48512 L .70969 .53178 L p .498 .423 .702 r
F P
0 g
s
.4676 .80507 m .46518 .77692 L .37676 .77434 L p .705 .387 .436 r
F P
0 g
s
.46518 .77692 m .4676 .80507 L .54472 .79225 L p .621 .335 .461 r
F P
0 g
s
.54472 .79225 m .54532 .76479 L .46518 .77692 L p .621 .335 .461 r
F P
0 g
s
.56892 .37001 m .52632 .37269 L .56863 .37986 L closepath p .656 .707 .884 r
F P
0 g
s
.56863 .37986 m .61003 .39186 L .61154 .37158 L p .619 .675 .881 r
F P
0 g
s
.61154 .37158 m .56892 .37001 L .56863 .37986 L p .619 .675 .881 r
F P
0 g
s
.61003 .39186 m .64981 .40858 L .6538 .37778 L p .584 .633 .866 r
F P
0 g
s
.6538 .37778 m .61154 .37158 L .61003 .39186 L p .584 .633 .866 r
F P
0 g
s
.32189 .43128 m .28866 .45785 L .29948 .50272 L p .885 .882 .825 r
F P
0 g
s
.27195 .53955 m .29948 .50272 L .28866 .45785 L p .931 .901 .774 r
F P
0 g
s
.55582 .35342 m .52632 .37269 L .56451 .36082 L closepath p .652 .732 .907 r
F P
0 g
s
.48327 .37495 m .52632 .37269 L .48549 .36613 L closepath p .683 .759 .909 r
F P
0 g
s
.56451 .36082 m .52632 .37269 L .56892 .37001 L closepath p .652 .717 .896 r
F P
0 g
s
.54382 .34862 m .52632 .37269 L .55582 .35342 L closepath p .657 .746 .916 r
F P
0 g
s
.5299 .34683 m .52632 .37269 L .54382 .34862 L closepath p .664 .757 .919 r
F P
0 g
s
.51563 .34807 m .52632 .37269 L .5299 .34683 L closepath p .67 .762 .919 r
F P
0 g
s
.50259 .35203 m .52632 .37269 L .51563 .34807 L closepath p .672 .763 .919 r
F P
0 g
s
.49217 .35825 m .52632 .37269 L .50259 .35203 L closepath p .673 .763 .918 r
F P
0 g
s
.48549 .36613 m .52632 .37269 L .49217 .35825 L closepath p .677 .763 .916 r
F P
0 g
s
.64981 .40858 m .68716 .42988 L .69501 .38911 L p .544 .586 .846 r
F P
0 g
s
.69501 .38911 m .6538 .37778 L .64981 .40858 L p .544 .586 .846 r
F P
0 g
s
.6155 .71791 m .61483 .74716 L .68015 .72811 L p .539 .307 .511 r
F P
0 g
s
.68015 .72811 m .68146 .69788 L .6155 .71791 L p .539 .307 .511 r
F P
0 g
s
.44064 .38176 m .48327 .37495 L .48549 .36613 L p .72 .796 .912 r
F P
0 g
s
.54532 .76479 m .54472 .79225 L .61246 .7748 L p .56 .292 .467 r
F P
0 g
s
.61246 .7748 m .61483 .74716 L .54532 .76479 L p .56 .292 .467 r
F P
0 g
s
.48549 .36613 m .44523 .3652 L .44064 .38176 L p .72 .796 .912 r
F P
0 g
s
.399 .3933 m .44064 .38176 L .44523 .3652 L p .753 .849 .922 r
F P
0 g
s
.56892 .37001 m .61154 .37158 L .60327 .35277 L p .611 .695 .903 r
F P
0 g
s
.60327 .35277 m .56451 .36082 L .56892 .37001 L p .611 .695 .903 r
F P
0 g
s
.72651 .56649 m .73861 .60159 L .79376 .55397 L p .465 .365 .657 r
F P
0 g
s
.79376 .55397 m .77548 .51818 L .72651 .56649 L p .465 .365 .657 r
F P
0 g
s
.67995 .66645 m .68146 .69788 L .74831 .67085 L p .504 .31 .55 r
F P
0 g
s
.74831 .67085 m .74592 .63653 L .67995 .66645 L p .504 .31 .55 r
F P
0 g
s
.68716 .42988 m .7212 .45551 L .73409 .40607 L p .499 .532 .822 r
F P
0 g
s
.73409 .40607 m .69501 .38911 L .68716 .42988 L p .499 .532 .822 r
F P
0 g
s
.29015 .71178 m .29469 .74965 L .37676 .77434 L p .82 .52 .482 r
F P
0 g
s
.38379 .80434 m .37676 .77434 L .29469 .74965 L p .808 .446 .372 r
F P
0 g
s
.37676 .77434 m .38379 .80434 L .4676 .80507 L p .705 .387 .436 r
F P
0 g
s
.44523 .3652 m .48549 .36613 L .49217 .35825 L p .709 .82 .934 r
F P
0 g
s
.28866 .45785 m .26081 .48916 L .27195 .53955 L p .931 .901 .774 r
F P
0 g
s
.251 .57951 m .27195 .53955 L .26081 .48916 L p .972 .906 .689 r
F P
0 g
s
.44523 .3652 m .40653 .37002 L .399 .3933 L p .753 .849 .922 r
F P
0 g
s
.35908 .40976 m .399 .3933 L .40653 .37002 L p .788 .905 .923 r
F P
0 g
s
.61154 .37158 m .6538 .37778 L .64239 .34912 L p .562 .662 .904 r
F P
0 g
s
.64239 .34912 m .60327 .35277 L .61154 .37158 L p .562 .662 .904 r
F P
0 g
s
.56451 .36082 m .60327 .35277 L .58586 .33812 L p .603 .72 .927 r
F P
0 g
s
.58586 .33812 m .55582 .35342 L .56451 .36082 L p .603 .72 .927 r
F P
0 g
s
.23807 .62123 m .23423 .66302 L .29015 .71178 L p .939 .685 .527 r
F P
0 g
s
.29469 .74965 m .29015 .71178 L .23423 .66302 L p .942 .616 .385 r
F P
0 g
s
.7212 .45551 m .75098 .48512 L .76959 .429 L p .444 .468 .79 r
F P
0 g
s
.76959 .429 m .73409 .40607 L .7212 .45551 L p .444 .468 .79 r
F P
0 g
s
.45866 .35057 m .49217 .35825 L .50259 .35203 L p .687 .835 .954 r
F P
0 g
s
.49217 .35825 m .45866 .35057 L .44523 .3652 L p .709 .82 .934 r
F P
0 g
s
.61483 .74716 m .61246 .7748 L .67569 .75688 L p .514 .251 .454 r
F P
0 g
s
.67569 .75688 m .68015 .72811 L .61483 .74716 L p .514 .251 .454 r
F P
0 g
s
.73861 .60159 m .74592 .63653 L .80495 .59158 L p .425 .298 .602 r
F P
0 g
s
.80495 .59158 m .79376 .55397 L .73861 .60159 L p .425 .298 .602 r
F P
0 g
s
.55582 .35342 m .58586 .33812 L .56152 .32942 L p .598 .75 .95 r
F P
0 g
s
.56152 .32942 m .54382 .34862 L .55582 .35342 L p .598 .75 .95 r
F P
0 g
s
.40653 .37002 m .37038 .3806 L .35908 .40976 L p .788 .905 .923 r
F P
0 g
s
.32189 .43128 m .35908 .40976 L .37038 .3806 L p .821 .96 .902 r
F P
0 g
s
.47162 .8285 m .4676 .80507 L .38379 .80434 L p .678 .305 .334 r
F P
0 g
s
.4676 .80507 m .47162 .8285 L .54367 .81646 L p .596 .267 .383 r
F P
0 g
s
.54367 .81646 m .54472 .79225 L .4676 .80507 L p .596 .267 .383 r
F P
0 g
s
.40653 .37002 m .44523 .3652 L .45866 .35057 L p .727 .89 .955 r
F P
0 g
s
.68146 .69788 m .68015 .72811 L .74559 .70403 L p .475 .25 .492 r
F P
0 g
s
.74559 .70403 m .74831 .67085 L .68146 .69788 L p .475 .25 .492 r
F P
0 g
s
.47932 .33877 m .50259 .35203 L .51563 .34807 L p .654 .835 .97 r
F P
0 g
s
.50259 .35203 m .47932 .33877 L .45866 .35057 L p .687 .835 .954 r
F P
0 g
s
.6538 .37778 m .69501 .38911 L .6813 .35074 L p .498 .618 .901 r
F P
0 g
s
.6813 .35074 m .64239 .34912 L .6538 .37778 L p .498 .618 .901 r
F P
0 g
s
.54382 .34862 m .56152 .32942 L .53347 .32713 L p .602 .784 .968 r
F P
0 g
s
.53347 .32713 m .5299 .34683 L .54382 .34862 L p .602 .784 .968 r
F P
0 g
s
.54472 .79225 m .54367 .81646 L .60805 .80019 L p .532 .226 .394 r
F P
0 g
s
.60805 .80019 m .61246 .7748 L .54472 .79225 L p .532 .226 .394 r
F P
0 g
s
.50508 .33061 m .51563 .34807 L .5299 .34683 L p .622 .816 .975 r
F P
0 g
s
.51563 .34807 m .50508 .33061 L .47932 .33877 L p .654 .835 .97 r
F P
0 g
s
.26081 .48916 m .23974 .52457 L .251 .57951 L p .972 .906 .689 r
F P
0 g
s
.23807 .62123 m .251 .57951 L .23974 .52457 L p .991 .876 .543 r
F P
0 g
s
.5299 .34683 m .53347 .32713 L .50508 .33061 L p .622 .816 .975 r
F P
0 g
s
.75098 .48512 m .77548 .51818 L .7998 .45789 L p .377 .389 .746 r
F P
0 g
s
.7998 .45789 m .76959 .429 L .75098 .48512 L p .377 .389 .746 r
F P
0 g
s
.60327 .35277 m .64239 .34912 L .61618 .32745 L p .536 .704 .947 r
F P
0 g
s
.61618 .32745 m .58586 .33812 L .60327 .35277 L p .536 .704 .947 r
F P
0 g
s
.37038 .3806 m .33772 .39677 L .32189 .43128 L p .821 .96 .902 r
F P
0 g
s
.28866 .45785 m .32189 .43128 L .33772 .39677 L p .834 .998 .834 r
F P
0 g
s
.29469 .74965 m .30671 .78264 L .38379 .80434 L p .808 .446 .372 r
F P
0 g
s
.39507 .8284 m .38379 .80434 L .30671 .78264 L p .769 .328 .205 r
F P
0 g
s
.38379 .80434 m .39507 .8284 L .47162 .8285 L p .678 .305 .334 r
F P
0 g
s
.74592 .63653 m .74831 .67085 L .80839 .62991 L p .376 .216 .533 r
F P
0 g
s
.80839 .62991 m .80495 .59158 L .74592 .63653 L p .376 .216 .533 r
F P
0 g
s
.69501 .38911 m .73409 .40607 L .71897 .35867 L p .412 .556 .89 r
F P
0 g
s
.71897 .35867 m .6813 .35074 L .69501 .38911 L p .412 .556 .89 r
F P
0 g
s
.45866 .35057 m .42703 .34992 L .40653 .37002 L p .727 .89 .955 r
F P
0 g
s
.37038 .3806 m .40653 .37002 L .42703 .34992 L p .723 .957 .947 r
F P
0 g
s
.42703 .34992 m .45866 .35057 L .47932 .33877 L p .67 .911 .977 r
F P
0 g
s
.61246 .7748 m .60805 .80019 L .66759 .78356 L p .475 .173 .373 r
F P
0 g
s
.66759 .78356 m .67569 .75688 L .61246 .7748 L p .475 .173 .373 r
F P
0 g
s
.23423 .66302 m .24002 .70304 L .29469 .74965 L p .942 .616 .385 r
F P
0 g
s
.30671 .78264 m .29469 .74965 L .24002 .70304 L p .9 .484 .16 r
F P
0 g
s
.68015 .72811 m .67569 .75688 L .73747 .73545 L p .434 .172 .415 r
F P
0 g
s
.73747 .73545 m .74559 .70403 L .68015 .72811 L p .434 .172 .415 r
F P
0 g
s
.58586 .33812 m .61618 .32745 L .5791 .31582 L p .51 .756 .985 r
F P
0 g
s
.5791 .31582 m .56152 .32942 L .58586 .33812 L p .51 .756 .985 r
F P
0 g
s
.77548 .51818 m .79376 .55397 L .82289 .4923 L p .291 .288 .684 r
F P
0 g
s
.82289 .4923 m .7998 .45789 L .77548 .51818 L p .291 .288 .684 r
F P
0 g
s
.23974 .52457 m .22676 .56308 L .23807 .62123 L p .991 .876 .543 r
F P
0 g
s
.23423 .66302 m .23807 .62123 L .22676 .56308 L p .94 .765 .297 r
F P
0 g
s
.64239 .34912 m .6813 .35074 L .64627 .32234 L p .433 .669 .961 r
F P
0 g
s
.64627 .32234 m .61618 .32745 L .64239 .34912 L p .433 .669 .961 r
F P
0 g
s
.33772 .39677 m .30946 .41828 L .28866 .45785 L p .834 .998 .834 r
F P
0 g
s
.26081 .48916 m .28866 .45785 L .30946 .41828 L p .788 .97 .672 r
F P
0 g
s
.45752 .33347 m .47932 .33877 L .50508 .33061 L p .588 .899 .986 r
F P
0 g
s
.47932 .33877 m .45752 .33347 L .42703 .34992 L p .67 .911 .977 r
F P
0 g
s
.47725 .84636 m .47162 .8285 L .39507 .8284 L p .622 .178 .176 r
F P
0 g
s
.47162 .8285 m .47725 .84636 L .5421 .8364 L p .551 .165 .263 r
F P
0 g
s
.5421 .8364 m .54367 .81646 L .47162 .8285 L p .551 .165 .263 r
F P
0 g
s
.54367 .81646 m .5421 .8364 L .60122 .82222 L p .484 .126 .282 r
F P
0 g
s
.60122 .82222 m .60805 .80019 L .54367 .81646 L p .484 .126 .282 r
F P
0 g
s
.73409 .40607 m .76959 .429 L .75384 .37383 L p .289 .464 .86 r
F P
0 g
s
.75384 .37383 m .71897 .35867 L .73409 .40607 L p .289 .464 .86 r
F P
0 g
s
.56152 .32942 m .5791 .31582 L .53693 .31441 L p .496 .811 1 r
F P
0 g
s
.53693 .31441 m .53347 .32713 L .56152 .32942 L p .496 .811 1 r
F P
0 g
s
.74831 .67085 m .74559 .70403 L .80367 .66776 L p .312 .111 .439 r
F P
0 g
s
.80367 .66776 m .80839 .62991 L .74831 .67085 L p .312 .111 .439 r
F P
0 g
s
.42703 .34992 m .39834 .35619 L .37038 .3806 L p .723 .957 .947 r
F P
0 g
s
.33772 .39677 m .37038 .3806 L .39834 .35619 L p .651 .97 .849 r
F P
0 g
s
.49511 .32113 m .50508 .33061 L .53347 .32713 L p .519 .86 .994 r
F P
0 g
s
.50508 .33061 m .49511 .32113 L .45752 .33347 L p .588 .899 .986 r
F P
0 g
s
.53347 .32713 m .53693 .31441 L .49511 .32113 L p .519 .86 .994 r
F P
0 g
s
.79376 .55397 m .80495 .59158 L .8372 .53124 L p .179 .153 .59 r
F P
0 g
s
.8372 .53124 m .82289 .4923 L .79376 .55397 L p .179 .153 .59 r
F P
0 g
s
.39834 .35619 m .42703 .34992 L .45752 .33347 L p .572 .937 .911 r
F P
0 g
s
.67569 .75688 m .66759 .78356 L .72368 .76435 L p .372 .062 .305 r
F P
0 g
s
.72368 .76435 m .73747 .73545 L .67569 .75688 L p .372 .062 .305 r
F P
0 g
s
.60805 .80019 m .60122 .82222 L .65528 .80711 L p .411 .054 .246 r
F P
0 g
s
.65528 .80711 m .66759 .78356 L .60805 .80019 L p .411 .054 .246 r
F P
0 g
s
.30671 .78264 m .32568 .80944 L .39507 .8284 L p .769 .328 .205 r
F P
0 g
s
.41026 .84578 m .39507 .8284 L .32568 .80944 L p .663 .129 0 r
F P
0 g
s
.39507 .8284 m .41026 .84578 L .47725 .84636 L p .622 .178 .176 r
F P
0 g
s
.30946 .41828 m .28643 .4447 L .26081 .48916 L p .788 .97 .672 r
F P
0 g
s
.23974 .52457 m .26081 .48916 L .28643 .4447 L p .626 .804 .375 r
F P
0 g
s
.61618 .32745 m .64627 .32234 L .59613 .30861 L p .343 .722 .985 r
F P
0 g
s
.59613 .30861 m .5791 .31582 L .61618 .32745 L p .343 .722 .985 r
F P
0 g
s
.6813 .35074 m .71897 .35867 L .6753 .32391 L p .262 .591 .948 r
F P
0 g
s
.6753 .32391 m .64627 .32234 L .6813 .35074 L p .262 .591 .948 r
F P
0 g
s
.22676 .56308 m .22284 .60339 L .23423 .66302 L p .94 .765 .297 r
F P
0 g
s
.23423 .66302 m .22284 .60339 L p .23907 .69751 L .747 .518 0 r
F P
0 g
s
.23967 .70066 m .23423 .66302 L p .23907 .69751 L .747 .518 0 r
F P
0 g
s
.24002 .70304 m .25531 .73949 L .30671 .78264 L p .9 .484 .16 r
F P
0 g
s
.22284 .60339 m .2285 .64394 L .24002 .70304 L p .747 .518 0 r
F P
0 g
s
.24368 .68311 m .25531 .73949 L p .22918 .64638 L 0 0 .427 r
F P
0 g
s
.2285 .64394 m .22892 .64504 L p .22918 .64638 L 0 0 .427 r
F P
0 g
s
.22892 .64504 m .24368 .68311 L p .22918 .64638 L 0 0 .427 r
F P
0 g
s
.24002 .70304 m .23967 .70066 L p .23907 .69751 L .747 .518 0 r
F P
0 g
s
.32568 .80944 m .30671 .78264 L .25531 .73949 L p .744 .241 0 r
F P
0 g
s
.76959 .429 m .7998 .45789 L .784 .39685 L p .108 .319 .792 r
F P
0 g
s
.784 .39685 m .75384 .37383 L .76959 .429 L p .108 .319 .792 r
F P
0 g
s
.74559 .70403 m .73747 .73545 L .79073 .7039 L p .222 0 .307 r
F P
0 g
s
.79073 .7039 m .80367 .66776 L .74559 .70403 L p .222 0 .307 r
F P
0 g
s
.39834 .35619 m .37342 .36893 L .33772 .39677 L p .651 .97 .849 r
F P
0 g
s
.30946 .41828 m .33772 .39677 L .37342 .36893 L p .447 .822 .576 r
F P
0 g
s
.43806 .33613 m .45752 .33347 L .49511 .32113 L p .377 .843 .836 r
F P
0 g
s
.45752 .33347 m .43806 .33613 L .39834 .35619 L p .572 .937 .911 r
F P
0 g
s
.80495 .59158 m .80839 .62991 L .84149 .57324 L p .026 0 .447 r
F P
0 g
s
.84149 .57324 m .8372 .53124 L .80495 .59158 L p .026 0 .447 r
F P
0 g
s
.53998 .85075 m .5421 .8364 L .47725 .84636 L p .46 0 .06 r
F P
0 g
s
.5421 .8364 m .53998 .85075 L .59164 .83935 L p .391 0 .09 r
F P
0 g
s
.59164 .83935 m .60122 .82222 L .5421 .8364 L p .391 0 .09 r
F P
0 g
s
.48447 .85781 m .47725 .84636 L .41026 .84578 L p .498 0 0 r
F P
0 g
s
.47725 .84636 m .48447 .85781 L .53998 .85075 L p .46 0 .06 r
F P
0 g
s
.5791 .31582 m .59613 .30861 L .54016 .3092 L p .255 .745 .918 r
F P
0 g
s
.53693 .31441 m .5791 .31582 L p .54871 .31065 L .255 .745 .918 r
F P
0 g
s
.53904 .31101 m .53693 .31441 L p .54871 .31065 L .255 .745 .918 r
F P
0 g
s
.59613 .30861 m .64627 .32234 L p .6171 .31059 L .032 .569 .85 r
F P
0 g
s
.61211 .30858 m .60883 .30859 L p .6171 .31059 L .032 .569 .85 r
F P
0 g
s
.60883 .30859 m .59613 .30861 L p .6171 .31059 L .032 .569 .85 r
F P
0 g
s
.70209 .33326 m .6753 .32391 L .71897 .35867 L p 0 .42 .849 r
F P
0 g
s
.64627 .32234 m .6753 .32391 L .61211 .30858 L p .032 .569 .85 r
F P
0 g
s
.70209 .33326 m .62647 .31643 L p .66653 .32257 L .368 0 0 r
F P
0 g
s
.6753 .32391 m .68261 .32646 L p .66653 .32257 L .368 0 0 r
F P
0 g
s
.68261 .32646 m .70209 .33326 L p .66653 .32257 L .368 0 0 r
F P
0 g
s
.61211 .30858 m .54306 .31173 L p .58395 .30933 L .131 0 0 r
F P
0 g
s
.59613 .30861 m .60339 .3086 L p .58395 .30933 L .131 0 0 r
F P
0 g
s
.60339 .3086 m .61211 .30858 L p .58395 .30933 L .131 0 0 r
F P
0 g
s
.54016 .3092 m .53904 .31101 L p .54871 .31065 L .255 .745 .918 r
F P
0 g
s
.66759 .78356 m .65528 .80711 L .70396 .78977 L p .271 0 .133 r
F P
0 g
s
.70396 .78977 m .72368 .76435 L .66759 .78356 L p .271 0 .133 r
F P
0 g
s
.28643 .4447 m .26938 .47549 L .23974 .52457 L p .626 .804 .375 r
F P
0 g
s
.22676 .56308 m .23974 .52457 L .26938 .47549 L p 0 0 0 r
F P
0 g
s
.37342 .36893 m .39834 .35619 L .43806 .33613 L p 0 0 0 r
F P
0 g
s
.48611 .31986 m .49511 .32113 L .53693 .31441 L p .252 .764 .828 r
F P
0 g
s
.49511 .32113 m .48611 .31986 L .43806 .33613 L p .377 .843 .836 r
F P
0 g
s
.53693 .31441 m .54016 .3092 L .48611 .31986 L p .252 .764 .828 r
F P
0 g
s
.60122 .82222 m .59164 .83935 L .63828 .82613 L p .292 0 .031 r
F P
0 g
s
.63828 .82613 m .65528 .80711 L .60122 .82222 L p .292 0 .031 r
F P
0 g
s
.71897 .35867 m .75384 .37383 L .70209 .33326 L p 0 .42 .849 r
F P
0 g
s
.7998 .45789 m .82289 .4923 L .80736 .42777 L p 0 .086 .642 r
F P
0 g
s
.80736 .42777 m .784 .39685 L .7998 .45789 L p 0 .086 .642 r
F P
0 g
s
.25531 .73949 m .24002 .70304 L .2285 .64394 L p 0 0 .427 r
F P
0 g
s
.73747 .73545 m .72368 .76435 L .76983 .7371 L p .092 0 .113 r
F P
0 g
s
.76983 .7371 m .79073 .7039 L .73747 .73545 L p .092 0 .113 r
F P
0 g
s
.37342 .36893 m .3528 .38743 L .30946 .41828 L p .447 .822 .576 r
F P
0 g
s
.28643 .4447 m .30946 .41828 L .3528 .38743 L p 0 0 0 r
F P
0 g
s
.32568 .80944 m .35064 .82927 L .41026 .84578 L p .663 .129 0 r
F P
0 g
s
.42885 .85609 m .41026 .84578 L .35064 .82927 L p .42 0 0 r
F P
0 g
s
.41026 .84578 m .42885 .85609 L .48447 .85781 L p .498 0 0 r
F P
0 g
s
.25531 .73949 m .27934 .77084 L .32568 .80944 L p .744 .241 0 r
F P
0 g
s
.35064 .82927 m .32568 .80944 L .27934 .77084 L p 0 .103 .573 r
F P
0 g
s
.80839 .62991 m .80367 .66776 L .83513 .61647 L p 0 0 .225 r
F P
0 g
s
.83513 .61647 m .84149 .57324 L .80839 .62991 L p 0 0 .225 r
F P
0 g
s
.26938 .47549 m .25895 .50996 L .22676 .56308 L p 0 0 0 r
F P
0 g
s
.22284 .60339 m .22676 .56308 L .25895 .50996 L p 0 0 .287 r
F P
0 g
s
.42155 .3462 m .43806 .33613 L .48611 .31986 L p 0 0 0 r
F P
0 g
s
.43806 .33613 m .42155 .3462 L .37342 .36893 L p 0 0 0 r
F P
0 g
s
.3528 .38743 m .37342 .36893 L .42155 .3462 L p .006 0 0 r
F P
0 g
s
.65528 .80711 m .63828 .82613 L .67825 .81059 L p .096 0 0 r
F P
0 g
s
.67825 .81059 m .70396 .78977 L .65528 .80711 L p .096 0 0 r
F P
0 g
s
.53729 .85809 m .53998 .85075 L .48447 .85781 L p .253 0 0 r
F P
0 g
s
.53998 .85075 m .53729 .85809 L .57911 .84983 L p .189 0 0 r
F P
0 g
s
.57911 .84983 m .59164 .83935 L .53998 .85075 L p .189 0 0 r
F P
0 g
s
.82289 .4923 m .8372 .53124 L .82195 .46592 L p 0 0 .353 r
F P
0 g
s
.82195 .46592 m .80736 .42777 L .82289 .4923 L p 0 0 .353 r
F P
0 g
s
.49317 .86208 m .48447 .85781 L .42885 .85609 L p .229 0 0 r
F P
0 g
s
.48447 .85781 m .49317 .86208 L .53729 .85809 L p .253 0 0 r
F P
0 g
s
.54306 .31173 m .54016 .3092 L .59613 .30861 L p .131 0 0 r
F P
0 g
s
.27934 .77084 m .25531 .73949 L .24368 .68311 L p 0 .132 .674 r
F P
0 g
s
.75384 .37383 m .784 .39685 L .72522 .35128 L p 0 .101 .56 r
F P
0 g
s
.72522 .35128 m .70209 .33326 L .75384 .37383 L p 0 .101 .56 r
F P
0 g
s
.72368 .76435 m .70396 .78977 L .74158 .76626 L p 0 0 0 r
F P
0 g
s
.74158 .76626 m .76983 .7371 L .72368 .76435 L p 0 0 0 r
F P
0 g
s
.3528 .38743 m .3367 .41089 L .28643 .4447 L p 0 0 0 r
F P
0 g
s
.26938 .47549 m .28643 .4447 L .3367 .41089 L p .079 0 .119 r
F P
0 g
s
.59164 .83935 m .57911 .84983 L .61639 .83898 L p .059 0 0 r
F P
0 g
s
.61639 .83898 m .63828 .82613 L .59164 .83935 L p .059 0 0 r
F P
0 g
s
.47837 .32649 m .48611 .31986 L .54016 .3092 L p .125 0 0 r
F P
0 g
s
.48611 .31986 m .47837 .32649 L .42155 .3462 L p 0 0 0 r
F P
0 g
s
.80367 .66776 m .79073 .7039 L .81828 .65891 L p 0 0 0 r
F P
0 g
s
.81828 .65891 m .83513 .61647 L .80367 .66776 L p 0 0 0 r
F P
0 g
s
.54016 .3092 m .54306 .31173 L .47837 .32649 L p .125 0 0 r
F P
0 g
s
.27934 .77084 m .3108 .79605 L .35064 .82927 L p 0 .103 .573 r
F P
0 g
s
.35064 .82927 m .38044 .84183 L .42885 .85609 L p .42 0 0 r
F P
0 g
s
.38044 .84183 m .35064 .82927 L .3108 .79605 L p 0 .407 .838 r
F P
0 g
s
.62647 .31643 m .61211 .30858 L .6753 .32391 L p .368 0 0 r
F P
0 g
s
.25895 .50996 m .25565 .54731 L .22284 .60339 L p 0 0 .287 r
F P
0 g
s
.2285 .64394 m .22284 .60339 L .25565 .54731 L p .088 .027 .486 r
F P
0 g
s
.42885 .85609 m .45029 .85918 L .49317 .86208 L p .229 0 0 r
F P
0 g
s
.45029 .85918 m .42885 .85609 L .38044 .84183 L p 0 .513 .801 r
F P
0 g
s
.42155 .3462 m .40829 .36269 L .3528 .38743 L p .006 0 0 r
F P
0 g
s
.3367 .41089 m .3528 .38743 L .40829 .36269 L p .224 0 .104 r
F P
0 g
s
.40829 .36269 m .42155 .3462 L .47837 .32649 L p .244 0 0 r
F P
0 g
s
.8372 .53124 m .84149 .57324 L .8263 .5098 L p .831 .595 .044 r
F P
0 g
s
.8263 .5098 m .82195 .46592 L .8372 .53124 L p .831 .595 .044 r
F P
0 g
s
.63828 .82613 m .61639 .83898 L .64677 .82564 L p 0 0 0 r
F P
0 g
s
.64677 .82564 m .67825 .81059 L .63828 .82613 L p 0 0 0 r
F P
0 g
s
.3367 .41089 m .32518 .43853 L .26938 .47549 L p .079 0 .119 r
F P
0 g
s
.25895 .50996 m .26938 .47549 L .32518 .43853 L p .232 0 .323 r
F P
0 g
s
.24368 .68311 m .26778 .71935 L .27934 .77084 L p 0 .132 .674 r
F P
0 g
s
.3108 .79605 m .27934 .77084 L .26778 .71935 L p .133 .343 .806 r
F P
0 g
s
.70396 .78977 m .67825 .81059 L .70684 .79047 L p 0 0 0 r
F P
0 g
s
.70684 .79047 m .74158 .76626 L .70396 .78977 L p 0 0 0 r
F P
0 g
s
.79073 .7039 m .76983 .7371 L .79186 .69867 L p .634 .833 .428 r
F P
0 g
s
.79186 .69867 m .81828 .65891 L .79073 .7039 L p .634 .833 .428 r
F P
0 g
s
.784 .39685 m .80736 .42777 L .7431 .37833 L p .764 .259 0 r
F P
0 g
s
.7431 .37833 m .72522 .35128 L .784 .39685 L p .764 .259 0 r
F P
0 g
s
.53405 .85706 m .53729 .85809 L .49317 .86208 L p .132 .68 .768 r
F P
0 g
s
.53729 .85809 m .53405 .85706 L .56371 .85194 L p .18 .712 .738 r
F P
0 g
s
.56371 .85194 m .57911 .84983 L .53729 .85809 L p .18 .712 .738 r
F P
0 g
s
.61211 .30858 m .62647 .31643 L .54555 .32193 L p .427 0 0 r
F P
0 g
s
.54555 .32193 m .54306 .31173 L .61211 .30858 L p .427 0 0 r
F P
0 g
s
.50321 .85851 m .49317 .86208 L .45029 .85918 L p .17 .693 .874 r
F P
0 g
s
.49317 .86208 m .50321 .85851 L .53405 .85706 L p .132 .68 .768 r
F P
0 g
s
.25565 .54731 m .25984 .58658 L .2285 .64394 L p .088 .027 .486 r
F P
0 g
s
.24368 .68311 m .2285 .64394 L .25984 .58658 L p .224 .196 .615 r
F P
0 g
s
.47205 .34027 m .47837 .32649 L .54306 .31173 L p .366 0 .002 r
F P
0 g
s
.47837 .32649 m .47205 .34027 L .40829 .36269 L p .244 0 0 r
F P
0 g
s
.57911 .84983 m .56371 .85194 L .58983 .84405 L p .292 .789 .788 r
F P
0 g
s
.58983 .84405 m .61639 .83898 L .57911 .84983 L p .292 .789 .788 r
F P
0 g
s
.3108 .79605 m .34806 .8146 L .38044 .84183 L p 0 .407 .838 r
F P
0 g
s
.41384 .84733 m .38044 .84183 L .34806 .8146 L p .228 .588 .946 r
F P
0 g
s
.38044 .84183 m .41384 .84733 L .45029 .85918 L p 0 .513 .801 r
F P
0 g
s
.54306 .31173 m .54555 .32193 L .47205 .34027 L p .366 0 .002 r
F P
0 g
s
.70209 .33326 m .72522 .35128 L .63857 .33266 L p .63 .096 0 r
F P
0 g
s
.63857 .33266 m .62647 .31643 L .70209 .33326 L p .63 .096 0 r
F P
0 g
s
.40829 .36269 m .39825 .38448 L .3367 .41089 L p .224 0 .104 r
F P
0 g
s
.32518 .43853 m .3367 .41089 L .39825 .38448 L p .347 .038 .291 r
F P
0 g
s
.47403 .85514 m .45029 .85918 L .41384 .84733 L p .283 .707 .97 r
F P
0 g
s
.45029 .85918 m .47403 .85514 L .50321 .85851 L p .17 .693 .874 r
F P
0 g
s
.84149 .57324 m .83513 .61647 L .81972 .55727 L p .974 .805 .387 r
F P
0 g
s
.81972 .55727 m .8263 .5098 L .84149 .57324 L p .974 .805 .387 r
F P
0 g
s
.32518 .43853 m .3182 .46975 L .25895 .50996 L p .232 0 .323 r
F P
0 g
s
.25565 .54731 m .25895 .50996 L .3182 .46975 L p .33 .133 .455 r
F P
0 g
s
.39825 .38448 m .40829 .36269 L .47205 .34027 L p .381 .015 .213 r
F P
0 g
s
.76983 .7371 m .74158 .76626 L .75741 .73418 L p .752 .97 .697 r
F P
0 g
s
.75741 .73418 m .79186 .69867 L .76983 .7371 L p .752 .97 .697 r
F P
0 g
s
.26778 .71935 m .2997 .75137 L .3108 .79605 L p .133 .343 .806 r
F P
0 g
s
.34806 .8146 m .3108 .79605 L .2997 .75137 L p .295 .482 .873 r
F P
0 g
s
.67825 .81059 m .64677 .82564 L .66671 .809 L p .525 .917 .812 r
F P
0 g
s
.66671 .809 m .70684 .79047 L .67825 .81059 L p .525 .917 .812 r
F P
0 g
s
.61639 .83898 m .58983 .84405 L .61017 .83382 L p .451 .883 .879 r
F P
0 g
s
.61017 .83382 m .64677 .82564 L .61639 .83898 L p .451 .883 .879 r
F P
0 g
s
.25984 .58658 m .27169 .62668 L .24368 .68311 L p .224 .196 .615 r
F P
0 g
s
.26778 .71935 m .24368 .68311 L .27169 .62668 L p .323 .32 .701 r
F P
0 g
s
.80736 .42777 m .82195 .46592 L .75428 .41406 L p .899 .493 .217 r
F P
0 g
s
.75428 .41406 m .7431 .37833 L .80736 .42777 L p .899 .493 .217 r
F P
0 g
s
.34806 .8146 m .38948 .8265 L .41384 .84733 L p .228 .588 .946 r
F P
0 g
s
.44978 .84624 m .41384 .84733 L .38948 .8265 L p .404 .683 .974 r
F P
0 g
s
.41384 .84733 m .44978 .84624 L .47403 .85514 L p .283 .707 .97 r
F P
0 g
s
.53035 .84664 m .53405 .85706 L .50321 .85851 L p .466 .839 .989 r
F P
0 g
s
.53405 .85706 m .53035 .84664 L .54586 .84433 L p .494 .863 .985 r
F P
0 g
s
.54586 .84433 m .56371 .85194 L .53405 .85706 L p .494 .863 .985 r
F P
0 g
s
.4672 .36021 m .47205 .34027 L .54555 .32193 L p .478 .092 .228 r
F P
0 g
s
.47205 .34027 m .4672 .36021 L .39825 .38448 L p .381 .015 .213 r
F P
0 g
s
.62647 .31643 m .63857 .33266 L .54755 .33949 L p .566 .124 .16 r
F P
0 g
s
.54755 .33949 m .54555 .32193 L .62647 .31643 L p .566 .124 .16 r
F P
0 g
s
.39825 .38448 m .39124 .41053 L .32518 .43853 L p .347 .038 .291 r
F P
0 g
s
.3182 .46975 m .32518 .43853 L .39124 .41053 L p .421 .159 .409 r
F P
0 g
s
.83513 .61647 m .81828 .65891 L .80248 .60575 L p .99 .889 .603 r
F P
0 g
s
.80248 .60575 m .81972 .55727 L .83513 .61647 L p .99 .889 .603 r
F P
0 g
s
.51436 .84666 m .50321 .85851 L .47403 .85514 L p .461 .809 .998 r
F P
0 g
s
.50321 .85851 m .51436 .84666 L .53035 .84664 L p .466 .839 .989 r
F P
0 g
s
.3182 .46975 m .31581 .5041 L .25565 .54731 L p .33 .133 .455 r
F P
0 g
s
.25984 .58658 m .25565 .54731 L .31581 .5041 L p .396 .237 .546 r
F P
0 g
s
.74158 .76626 m .70684 .79047 L .71679 .76435 L p .779 .997 .852 r
F P
0 g
s
.71679 .76435 m .75741 .73418 L .74158 .76626 L p .779 .997 .852 r
F P
0 g
s
.56371 .85194 m .54586 .84433 L .55937 .84007 L p .535 .881 .986 r
F P
0 g
s
.55937 .84007 m .58983 .84405 L .56371 .85194 L p .535 .881 .986 r
F P
0 g
s
.2997 .75137 m .33803 .77822 L .34806 .8146 L p .295 .482 .873 r
F P
0 g
s
.38948 .8265 m .34806 .8146 L .33803 .77822 L p .408 .577 .907 r
F P
0 g
s
.64677 .82564 m .61017 .83382 L .62239 .82135 L p .619 .941 .953 r
F P
0 g
s
.62239 .82135 m .66671 .809 L .64677 .82564 L p .619 .941 .953 r
F P
0 g
s
.39124 .41053 m .39825 .38448 L .4672 .36021 L p .453 .144 .35 r
F P
0 g
s
.54555 .32193 m .54755 .33949 L .4672 .36021 L p .478 .092 .228 r
F P
0 g
s
.72522 .35128 m .7431 .37833 L .64776 .35742 L p .737 .304 .222 r
F P
0 g
s
.64776 .35742 m .63857 .33266 L .72522 .35128 L p .737 .304 .222 r
F P
0 g
s
.27169 .62668 m .29113 .6664 L .26778 .71935 L p .323 .32 .701 r
F P
0 g
s
.2997 .75137 m .26778 .71935 L .29113 .6664 L p .398 .416 .762 r
F P
0 g
s
.49953 .84416 m .47403 .85514 L .44978 .84624 L p .483 .773 .995 r
F P
0 g
s
.47403 .85514 m .49953 .84416 L .51436 .84666 L p .461 .809 .998 r
F P
0 g
s
.58983 .84405 m .55937 .84007 L .56951 .83423 L p .585 .891 .989 r
F P
0 g
s
.56951 .83423 m .61017 .83382 L .58983 .84405 L p .585 .891 .989 r
F P
0 g
s
.82195 .46592 m .8263 .5098 L .75764 .45724 L p .926 .614 .431 r
F P
0 g
s
.75764 .45724 m .75428 .41406 L .82195 .46592 L p .926 .614 .431 r
F P
0 g
s
.70684 .79047 m .66671 .809 L .67189 .78865 L p .76 .968 .928 r
F P
0 g
s
.67189 .78865 m .71679 .76435 L .70684 .79047 L p .76 .968 .928 r
F P
0 g
s
.31581 .5041 m .31819 .54123 L .25984 .58658 L p .396 .237 .546 r
F P
0 g
s
.27169 .62668 m .25984 .58658 L .31819 .54123 L p .443 .318 .615 r
F P
0 g
s
.81828 .65891 m .79186 .69867 L .77579 .65269 L p .956 .911 .731 r
F P
0 g
s
.77579 .65269 m .80248 .60575 L .81828 .65891 L p .956 .911 .731 r
F P
0 g
s
.39124 .41053 m .38703 .44013 L .3182 .46975 L p .421 .159 .409 r
F P
0 g
s
.31581 .5041 m .3182 .46975 L .38703 .44013 L p .469 .244 .49 r
F P
0 g
s
.38948 .8265 m .43364 .83213 L .44978 .84624 L p .404 .683 .974 r
F P
0 g
s
.48744 .83913 m .44978 .84624 L .43364 .83213 L p .519 .735 .972 r
F P
0 g
s
.44978 .84624 m .48744 .83913 L .49953 .84416 L p .483 .773 .995 r
F P
0 g
s
.33803 .77822 m .38124 .79931 L .38948 .8265 L p .408 .577 .907 r
F P
0 g
s
.43364 .83213 m .38948 .8265 L .38124 .79931 L p .491 .647 .927 r
F P
0 g
s
.29113 .6664 m .31781 .70446 L .2997 .75137 L p .398 .416 .762 r
F P
0 g
s
.33803 .77822 m .2997 .75137 L .31781 .70446 L p .457 .494 .808 r
F P
0 g
s
.46377 .38533 m .4672 .36021 L .54755 .33949 L p .533 .207 .361 r
F P
0 g
s
.4672 .36021 m .46377 .38533 L .39124 .41053 L p .453 .144 .35 r
F P
0 g
s
.61017 .83382 m .56951 .83423 L .57516 .8272 L p .64 .888 .985 r
F P
0 g
s
.57516 .8272 m .62239 .82135 L .61017 .83382 L p .64 .888 .985 r
F P
0 g
s
.38703 .44013 m .39124 .41053 L .46377 .38533 L p .496 .228 .438 r
F P
0 g
s
.52632 .82641 m .53035 .84664 L .51436 .84666 L closepath p .608 .813 .979 r
F P
0 g
s
.52632 .82641 m .54586 .84433 L .53035 .84664 L closepath p .613 .816 .978 r
F P
0 g
s
.63857 .33266 m .64776 .35742 L .54902 .36394 L p .627 .261 .329 r
F P
0 g
s
.54902 .36394 m .54755 .33949 L .63857 .33266 L p .627 .261 .329 r
F P
0 g
s
.52632 .82641 m .51436 .84666 L .49953 .84416 L closepath p .6 .802 .977 r
F P
0 g
s
.52632 .82641 m .55937 .84007 L .54586 .84433 L closepath p .616 .817 .978 r
F P
0 g
s
.66671 .809 m .62239 .82135 L .62439 .80698 L p .725 .919 .959 r
F P
0 g
s
.62439 .80698 m .67189 .78865 L .66671 .809 L p .725 .919 .959 r
F P
0 g
s
.79186 .69867 m .75741 .73418 L .74156 .6959 L p .908 .906 .809 r
F P
0 g
s
.74156 .6959 m .77579 .65269 L .79186 .69867 L p .908 .906 .809 r
F P
0 g
s
.31819 .54123 m .3257 .58074 L .27169 .62668 L p .443 .318 .615 r
F P
0 g
s
.29113 .6664 m .27169 .62668 L .3257 .58074 L p .48 .386 .67 r
F P
0 g
s
.52632 .82641 m .49953 .84416 L .48744 .83913 L closepath p .595 .785 .971 r
F P
0 g
s
.54755 .33949 m .54902 .36394 L .46377 .38533 L p .533 .207 .361 r
F P
0 g
s
.7431 .37833 m .75428 .41406 L .65346 .39037 L p .775 .424 .391 r
F P
0 g
s
.65346 .39037 m .64776 .35742 L .7431 .37833 L p .775 .424 .391 r
F P
0 g
s
.31781 .70446 m .35107 .73952 L .33803 .77822 L p .457 .494 .808 r
F P
0 g
s
.38124 .79931 m .33803 .77822 L .35107 .73952 L p .506 .561 .846 r
F P
0 g
s
.38124 .79931 m .42786 .8144 L .43364 .83213 L p .491 .647 .927 r
F P
0 g
s
.47948 .83196 m .43364 .83213 L .42786 .8144 L p .555 .702 .938 r
F P
0 g
s
.43364 .83213 m .47948 .83196 L .48744 .83913 L p .519 .735 .972 r
F P
0 g
s
.52632 .82641 m .56951 .83423 L .55937 .84007 L closepath p .62 .818 .977 r
F P
0 g
s
.38703 .44013 m .38549 .47294 L .31581 .5041 L p .469 .244 .49 r
F P
0 g
s
.31819 .54123 m .31581 .5041 L .38549 .47294 L p .502 .31 .552 r
F P
0 g
s
.8263 .5098 m .81972 .55727 L .75265 .5059 L p .916 .677 .562 r
F P
0 g
s
.75265 .5059 m .75764 .45724 L .8263 .5098 L p .916 .677 .562 r
F P
0 g
s
.52632 .82641 m .48744 .83913 L .47948 .83196 L closepath p .598 .765 .959 r
F P
0 g
s
.62239 .82135 m .57516 .8272 L .57556 .8195 L p .685 .865 .967 r
F P
0 g
s
.57556 .8195 m .62439 .80698 L .62239 .82135 L p .685 .865 .967 r
F P
0 g
s
.52632 .82641 m .57516 .8272 L .56951 .83423 L closepath p .63 .817 .972 r
F P
0 g
s
.35107 .73952 m .38993 .7703 L .38124 .79931 L p .506 .561 .846 r
F P
0 g
s
.42786 .8144 m .38124 .79931 L .38993 .7703 L p .548 .622 .878 r
F P
0 g
s
.75741 .73418 m .71679 .76435 L .70201 .73387 L p .857 .892 .86 r
F P
0 g
s
.70201 .73387 m .74156 .6959 L .75741 .73418 L p .857 .892 .86 r
F P
0 g
s
.46377 .38533 m .4617 .41491 L .38703 .44013 L p .496 .228 .438 r
F P
0 g
s
.38549 .47294 m .38703 .44013 L .4617 .41491 L p .525 .29 .501 r
F P
0 g
s
.4617 .41491 m .46377 .38533 L .54902 .36394 L p .564 .283 .447 r
F P
0 g
s
.3257 .58074 m .33878 .62203 L .29113 .6664 L p .48 .386 .67 r
F P
0 g
s
.31781 .70446 m .29113 .6664 L .33878 .62203 L p .511 .445 .718 r
F P
0 g
s
.42786 .8144 m .47659 .82342 L .47948 .83196 L p .555 .702 .938 r
F P
0 g
s
.52632 .82641 m .47948 .83196 L .47659 .82342 L closepath p .608 .749 .945 r
F P
0 g
s
.52632 .82641 m .57556 .8195 L .57516 .8272 L closepath p .645 .81 .962 r
F P
0 g
s
.38993 .7703 m .43312 .79564 L .42786 .8144 L p .548 .622 .878 r
F P
0 g
s
.47659 .82342 m .42786 .8144 L .43312 .79564 L p .586 .681 .906 r
F P
0 g
s
.38549 .47294 m .3867 .50895 L .31819 .54123 L p .502 .31 .552 r
F P
0 g
s
.3257 .58074 m .31819 .54123 L .3867 .50895 L p .527 .364 .603 r
F P
0 g
s
.71679 .76435 m .67189 .78865 L .65926 .76584 L p .806 .872 .895 r
F P
0 g
s
.65926 .76584 m .70201 .73387 L .71679 .76435 L p .806 .872 .895 r
F P
0 g
s
.43312 .79564 m .47914 .81456 L .47659 .82342 L p .586 .681 .906 r
F P
0 g
s
.52632 .82641 m .47659 .82342 L .47914 .81456 L closepath p .621 .74 .932 r
F P
0 g
s
.33878 .62203 m .35779 .6641 L .31781 .70446 L p .511 .445 .718 r
F P
0 g
s
.35107 .73952 m .31781 .70446 L .35779 .6641 L p .538 .5 .762 r
F P
0 g
s
.81972 .55727 m .80248 .60575 L .73951 .55747 L p .894 .713 .65 r
F P
0 g
s
.73951 .55747 m .75265 .5059 L .81972 .55727 L p .894 .713 .65 r
F P
0 g
s
.64776 .35742 m .65346 .39037 L .54992 .39472 L p .658 .348 .437 r
F P
0 g
s
.54992 .39472 m .54902 .36394 L .64776 .35742 L p .658 .348 .437 r
F P
0 g
s
.52632 .82641 m .56046 .80489 L .5705 .81178 L closepath p .659 .776 .935 r
F P
0 g
s
.52632 .82641 m .54657 .7997 L .56046 .80489 L closepath p .654 .757 .926 r
F P
0 g
s
.52632 .82641 m .53046 .79699 L .54657 .7997 L closepath p .646 .745 .921 r
F P
0 g
s
.52632 .82641 m .51396 .79724 L .53046 .79699 L closepath p .639 .739 .921 r
F P
0 g
s
.52632 .82641 m .49888 .80056 L .51396 .79724 L closepath p .637 .738 .921 r
F P
0 g
s
.52632 .82641 m .48685 .80658 L .49888 .80056 L closepath p .635 .737 .922 r
F P
0 g
s
.52632 .82641 m .47914 .81456 L .48685 .80658 L closepath p .63 .737 .925 r
F P
0 g
s
.52632 .82641 m .5705 .81178 L .57556 .8195 L closepath p .656 .795 .949 r
F P
0 g
s
.54902 .36394 m .54992 .39472 L .4617 .41491 L p .564 .283 .447 r
F P
0 g
s
.67189 .78865 m .62439 .80698 L .61504 .79172 L p .757 .849 .92 r
F P
0 g
s
.61504 .79172 m .65926 .76584 L .67189 .78865 L p .757 .849 .92 r
F P
0 g
s
.75428 .41406 m .75764 .45724 L .65522 .43063 L p .787 .499 .5 r
F P
0 g
s
.65522 .43063 m .65346 .39037 L .75428 .41406 L p .787 .499 .5 r
F P
0 g
s
.62439 .80698 m .57556 .8195 L .5705 .81178 L p .707 .824 .937 r
F P
0 g
s
.5705 .81178 m .61504 .79172 L .62439 .80698 L p .707 .824 .937 r
F P
0 g
s
.4617 .41491 m .46096 .44852 L .38549 .47294 L p .525 .29 .501 r
F P
0 g
s
.3867 .50895 m .38549 .47294 L .46096 .44852 L p .548 .341 .552 r
F P
0 g
s
.35779 .6641 m .38278 .7055 L .35107 .73952 L p .538 .5 .762 r
F P
0 g
s
.38993 .7703 m .35107 .73952 L .38278 .7055 L p .562 .554 .803 r
F P
0 g
s
.44856 .77874 m .48685 .80658 L .47914 .81456 L p .609 .67 .884 r
F P
0 g
s
.47914 .81456 m .43312 .79564 L .44856 .77874 L p .609 .67 .884 r
F P
0 g
s
.3867 .50895 m .39102 .54821 L .3257 .58074 L p .527 .364 .603 r
F P
0 g
s
.33878 .62203 m .3257 .58074 L .39102 .54821 L p .548 .413 .649 r
F P
0 g
s
.46096 .44852 m .4617 .41491 L .54992 .39472 L p .586 .339 .509 r
F P
0 g
s
.38278 .7055 m .41337 .74439 L .38993 .7703 L p .562 .554 .803 r
F P
0 g
s
.43312 .79564 m .38993 .7703 L .41337 .74439 L p .586 .61 .843 r
F P
0 g
s
.41337 .74439 m .44856 .77874 L .43312 .79564 L p .586 .61 .843 r
F P
0 g
s
.61504 .79172 m .5705 .81178 L .56046 .80489 L p .707 .776 .906 r
F P
0 g
s
.47228 .76618 m .49888 .80056 L .48685 .80658 L p .625 .667 .87 r
F P
0 g
s
.48685 .80658 m .44856 .77874 L .47228 .76618 L p .625 .667 .87 r
F P
0 g
s
.80248 .60575 m .77579 .65269 L .71911 .60924 L p .868 .736 .714 r
F P
0 g
s
.71911 .60924 m .73951 .55747 L .80248 .60575 L p .868 .736 .714 r
F P
0 g
s
.56046 .80489 m .59502 .77734 L .61504 .79172 L p .707 .776 .906 r
F P
0 g
s
.59502 .77734 m .56046 .80489 L .54657 .7997 L p .693 .734 .882 r
F P
0 g
s
.39102 .54821 m .39895 .59056 L .33878 .62203 L p .548 .413 .649 r
F P
0 g
s
.35779 .6641 m .33878 .62203 L .39895 .59056 L p .565 .46 .693 r
F P
0 g
s
.46096 .44852 m .4616 .48601 L .3867 .50895 L p .548 .341 .552 r
F P
0 g
s
.39102 .54821 m .3867 .50895 L .4616 .48601 L p .567 .387 .597 r
F P
0 g
s
.50188 .75961 m .51396 .79724 L .49888 .80056 L p .64 .67 .863 r
F P
0 g
s
.49888 .80056 m .47228 .76618 L .50188 .75961 L p .64 .67 .863 r
F P
0 g
s
.65926 .76584 m .61504 .79172 L .59502 .77734 L p .746 .774 .875 r
F P
0 g
s
.54657 .7997 m .56692 .766 L .59502 .77734 L p .693 .734 .882 r
F P
0 g
s
.56692 .766 m .54657 .7997 L .53046 .79699 L p .674 .701 .867 r
F P
0 g
s
.55021 .43122 m .54992 .39472 L .65346 .39037 L p .675 .41 .512 r
F P
0 g
s
.54992 .39472 m .55021 .43122 L .46096 .44852 L p .586 .339 .509 r
F P
0 g
s
.53456 .75967 m .53046 .79699 L .51396 .79724 L p .655 .68 .862 r
F P
0 g
s
.51396 .79724 m .50188 .75961 L .53456 .75967 L p .655 .68 .862 r
F P
0 g
s
.44806 .72544 m .47228 .76618 L .44856 .77874 L p .612 .608 .822 r
F P
0 g
s
.44856 .77874 m .41337 .74439 L .44806 .72544 L p .612 .608 .822 r
F P
0 g
s
.65346 .39037 m .65522 .43063 L .55021 .43122 L p .675 .41 .512 r
F P
0 g
s
.77579 .65269 m .74156 .6959 L .69285 .65869 L p .841 .751 .764 r
F P
0 g
s
.69285 .65869 m .71911 .60924 L .77579 .65269 L p .841 .751 .764 r
F P
0 g
s
.53046 .79699 m .53456 .75967 L .56692 .766 L p .674 .701 .867 r
F P
0 g
s
.75764 .45724 m .75265 .5059 L .6528 .4768 L p .788 .55 .577 r
F P
0 g
s
.6528 .4768 m .65522 .43063 L .75764 .45724 L p .788 .55 .577 r
F P
0 g
s
.4616 .48601 m .46096 .44852 L .55021 .43122 L p .602 .385 .559 r
F P
0 g
s
.39895 .59056 m .41098 .63528 L .35779 .6641 L p .565 .46 .693 r
F P
0 g
s
.38278 .7055 m .35779 .6641 L .41098 .63528 L p .582 .506 .735 r
F P
0 g
s
.70201 .73387 m .65926 .76584 L .62932 .74364 L p .781 .769 .842 r
F P
0 g
s
.59502 .77734 m .62932 .74364 L .65926 .76584 L p .746 .774 .875 r
F P
0 g
s
.4274 .68095 m .44806 .72544 L .41337 .74439 L p .597 .555 .778 r
F P
0 g
s
.41337 .74439 m .38278 .7055 L .4274 .68095 L p .597 .555 .778 r
F P
0 g
s
.74156 .6959 m .70201 .73387 L .66238 .7039 L p .812 .761 .806 r
F P
0 g
s
.66238 .7039 m .69285 .65869 L .74156 .6959 L p .812 .761 .806 r
F P
0 g
s
.41098 .63528 m .4274 .68095 L .38278 .7055 L p .582 .506 .735 r
F P
0 g
s
.62932 .74364 m .66238 .7039 L .70201 .73387 L p .781 .769 .842 r
F P
0 g
s
.4616 .48601 m .46377 .5273 L .39102 .54821 L p .567 .387 .597 r
F P
0 g
s
.39895 .59056 m .39102 .54821 L .46377 .5273 L p .584 .43 .639 r
F P
0 g
s
.62932 .74364 m .59502 .77734 L .56692 .766 L p .72 .71 .841 r
F P
0 g
s
.49077 .7157 m .50188 .75961 L .47228 .76618 L p .634 .613 .812 r
F P
0 g
s
.47228 .76618 m .44806 .72544 L .49077 .7157 L p .634 .613 .812 r
F P
0 g
s
.55021 .43122 m .54987 .47275 L .4616 .48601 L p .602 .385 .559 r
F P
0 g
s
.46377 .5273 m .4616 .48601 L .54987 .47275 L p .617 .427 .602 r
F P
0 g
s
.46377 .5273 m .46765 .57208 L .39895 .59056 L p .584 .43 .639 r
F P
0 g
s
.41098 .63528 m .39895 .59056 L .46765 .57208 L p .599 .474 .681 r
F P
0 g
s
.54987 .47275 m .55021 .43122 L .65522 .43063 L p .685 .457 .57 r
F P
0 g
s
.75265 .5059 m .73951 .55747 L .64622 .52701 L p .783 .587 .635 r
F P
0 g
s
.64622 .52701 m .6528 .4768 L .75265 .5059 L p .783 .587 .635 r
F P
0 g
s
.53844 .716 m .53456 .75967 L .50188 .75961 L p .658 .63 .81 r
F P
0 g
s
.50188 .75961 m .49077 .7157 L .53844 .716 L p .658 .63 .81 r
F P
0 g
s
.56692 .766 m .58674 .72593 L .62932 .74364 L p .72 .71 .841 r
F P
0 g
s
.58674 .72593 m .56692 .766 L .53456 .75967 L p .688 .662 .819 r
F P
0 g
s
.48117 .66813 m .49077 .7157 L .44806 .72544 L p .624 .563 .766 r
F P
0 g
s
.44806 .72544 m .4274 .68095 L .48117 .66813 L p .624 .563 .766 r
F P
0 g
s
.65522 .43063 m .6528 .4768 L .54987 .47275 L p .685 .457 .57 r
F P
0 g
s
.53456 .75967 m .53844 .716 L .58674 .72593 L p .688 .662 .819 r
F P
0 g
s
.66238 .7039 m .62932 .74364 L .58674 .72593 L p .739 .688 .802 r
F P
0 g
s
.46765 .57208 m .47343 .61953 L .41098 .63528 L p .599 .474 .681 r
F P
0 g
s
.4274 .68095 m .41098 .63528 L .47343 .61953 L p .613 .518 .722 r
F P
0 g
s
.47343 .61953 m .48117 .66813 L .4274 .68095 L p .613 .518 .722 r
F P
0 g
s
.54987 .47275 m .54888 .51847 L .46377 .5273 L p .617 .427 .602 r
F P
0 g
s
.46765 .57208 m .46377 .5273 L .54888 .51847 L p .629 .467 .643 r
F P
0 g
s
.73951 .55747 m .71911 .60924 L .63575 .57912 L p .775 .617 .683 r
F P
0 g
s
.63575 .57912 m .64622 .52701 L .73951 .55747 L p .775 .617 .683 r
F P
0 g
s
.54192 .66796 m .53844 .716 L .49077 .7157 L p .656 .586 .765 r
F P
0 g
s
.49077 .7157 m .48117 .66813 L .54192 .66796 L p .656 .586 .765 r
F P
0 g
s
.69285 .65869 m .66238 .7039 L .60531 .68047 L p .754 .666 .764 r
F P
0 g
s
.58674 .72593 m .60531 .68047 L .66238 .7039 L p .739 .688 .802 r
F P
0 g
s
.54888 .51847 m .54987 .47275 L .6528 .4768 L p .692 .496 .618 r
F P
0 g
s
.60531 .68047 m .58674 .72593 L .53844 .716 L p .695 .628 .777 r
F P
0 g
s
.54888 .51847 m .54721 .56727 L .46765 .57208 L p .629 .467 .643 r
F P
0 g
s
.47343 .61953 m .46765 .57208 L .54721 .56727 L p .641 .506 .683 r
F P
0 g
s
.71911 .60924 m .69285 .65869 L .6219 .63095 L p .766 .643 .725 r
F P
0 g
s
.6219 .63095 m .63575 .57912 L .71911 .60924 L p .766 .643 .725 r
F P
0 g
s
.53844 .716 m .54192 .66796 L .60531 .68047 L p .695 .628 .777 r
F P
0 g
s
.60531 .68047 m .6219 .63095 L .69285 .65869 L p .754 .666 .764 r
F P
0 g
s
.6528 .4768 m .64622 .52701 L .54888 .51847 L p .692 .496 .618 r
F P
0 g
s
.54487 .6177 m .54192 .66796 L .48117 .66813 L p .649 .545 .723 r
F P
0 g
s
.48117 .66813 m .47343 .61953 L .54487 .6177 L p .649 .545 .723 r
F P
0 g
s
.54721 .56727 m .54487 .6177 L .47343 .61953 L p .641 .506 .683 r
F P
0 g
s
.54721 .56727 m .54888 .51847 L .64622 .52701 L p .696 .531 .66 r
F P
0 g
s
.6219 .63095 m .60531 .68047 L .54192 .66796 L p .698 .595 .737 r
F P
0 g
s
.54192 .66796 m .54487 .6177 L .6219 .63095 L p .698 .595 .737 r
F P
0 g
s
.64622 .52701 m .63575 .57912 L .54721 .56727 L p .696 .531 .66 r
F P
0 g
s
.54487 .6177 m .54721 .56727 L .63575 .57912 L p .698 .563 .699 r
F P
0 g
s
.63575 .57912 m .6219 .63095 L .54487 .6177 L p .698 .563 .699 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
M?oooolMo`0001Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0KOoo
ool6o`0000;o7`003Ol0000=ofd000Go00004Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02Wooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Ioooool5
o`0000?o7`001Ol00002oed00003o`000?m]003oK@00017oK@003Ol0000=ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1Rooooo`Co00000olO0005o`0000SoG@0000?o0000ofd00?m]00000om]000=o`00
00KoT1lX00?o0000oj4H0?nQ60002?l00009ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Nooooo`Co
000000?o7`00o`000?l000000ol0000;oed000So00005?n@7bP00ol0003oXAP0oj4H0003oj4H00So
00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo000Yooooo`;o0000
6_ooool00ol0003oooooooooo`1Jooooo`So00003?mM0004o`0000;oNQLj00?o0000oi0O:?n@7bP0
6?n@7bP00ol0003oXAP0oj4H0006oj4H00Wo000000?oooooo`000?ooool0=_ooool00ol0003ooooo
ooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Kooooo1ol0
00000oln003o0000oed00009oed000Co00001_mj5cX00ol0003oT1lXoi0O:00Ioi0O:003o`000?nQ
603oXAP000WoXAP01?l000000omN003o0000o`00000gooooo`03o`000?oooooooooo02Kooooo000Y
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0D_ooool7o`0000?o?P0000?o0000
oed00?mM00001_mM0003o`0000[oNQLj00?o0000oi0O:?n@7bP05On@7bP8o`0000coXAP01Ol0000f
ooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0C_ooool8o`0000Go?P0000?o0000oed00?mM00000_mM0004o`0000koNQLj00?o0000oi0O
:?n@7bP02on@7bP9o`0000GoX49D00?o0000oka=>?nlCCP01Ol00009oj4H0003o`000?nQ603o0000
00;o0000=Oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo04_ooooo1ol00008och000Go00004_mj5cX00ol0003oT1lXoi0O:002oi0O:0Wo
00003onP@U@00ol0003o_4dhoka=>004oka=>0Co00001OnQ60000ol0003oXAP0oj4H0002oj4H0003
o`000?oooooooooo03;ooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`19ooooo`Go00002Oln0003o`0001CoNQLj1ol0000Hoj12E003o`00
0?nlCCSo_4dh00So_4dh1_l00005oj4H00;o0000<oooool00ol0003oooooooooo`0Sooooo`00:?oo
ool2o`00027ooooo00?o0000ooooooooool0A_ooool5o`0000So?P000ol000000omQ0cKo0000ogXG
>P0?ogXG>PGo00000_n8=5`00ol0003oX49Doj12E00Joj12E003o`000?nlCCSo_4dh00go_4dh1?l0
0004oj4H0003o`000?oooooooooo033ooooo00?o0000ooooooooool08oooool002Sooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`13ooooo`Co00002?ln0003o`0000?oH@<f00?o0000
ogXG>_mj5cX02omj5cX4o`0000OoR3AL00?o0000oj12E?nP@U@06onP@U@00ol0003o_4dhoka=>00<
oka=>004o`000?nlCCSo_4dhoka=>0Ko0000<_ooool00ol0003oooooooooo`0Rooooo`00:?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo047ooooo0ol000000ol1003o0000och00004
och000?o00001_mQ0cH00ol0003oNQLjogXG>P07ogXG>PCo00002on8=5`00ol0003oX49Doj12E00K
oj12E003o`000?nlCCSo_4dh00co_4dh00?o0000oka=>?nlCCP01_nlCCP3o`00037ooooo00?o0000
ooooooooool08Oooool002Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0noooo
o`?o00000_l100001?l0003o?P00och00?ln0003o`0000WoH@<f00?o0000ogXG>_mj5cX00_mj5cX5
o`0000ooR3AL00?o0000oj12E?nP@U@06onP@U@00ol0003o_4dhoka=>00<oka=>003o`000?nlCCSo
_4dh00Oo_4dh00?o0000ol=20?l00000<?ooool00ol0003oooooooooo`0Qooooo`009oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03_ooooo0ol00003o`400003o`000?ln003o0000
00;o00002omQ0cH00ol0003oNQLjo`000003o`0001CoR3AL00?o0000oj12E?nP@U@05?nP@U@;o`00
00_o_4dh00?o0000oka=>?nlCCP02?nlCCP00ol0003o`d80o`00000`ooooo`03o`000?oooooooooo
023ooooo000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool2o`0000Go
0@000ol0000=of43=P?o00006?n8=5`00ol0003oX49Doj12E005oj12E0oo00002?nXFFl00ol0003o
aVaTolI/I004o`0000Oo_4dh00?o0000oka=>?nlCCP02OnlCCP01?l0003o`d80o`000?l0000^oooo
o`03o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=Oooool2o`0000Go0@000_l0000=of43=P?o000000?oLbAIo`000?n8=5`05_n8=5`:o`0001Oo
Z5U_00?o0000olI/I?o6K6@01?o6K6@5o`0000;o_4dh00?o0000oka=>?nlCCP02OnlCCP01Ol0003o
`d80ol=20?o3@P3o000002kooooo00?o0000ooooooooool07oooool002Oooooo0_l0000Yooooo`03
o`000?oooooooooo03;ooooo0_l00005o`4000;o000000?o>@0Jo`000?mQ0cH02OmQ0cH3o`0000Co
LbAI00?o0000ohPdG?n8=5`04On8=5`4o`0000;oT4Qb00?o0000ojQIKonXFFl07OnXFFl00ol0003o
aVaTolI/I008olI/I0Co00002onlCCP01Ol0003o`d80ol=20?o3@P3o000002kooooo00?o0000oooo
ooooool07_ooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0_ooooo`;o
00001Ol10002o`0000;o>@0J00?o0000of43=_mQ0cH01omQ0cH2o`0000OoLbAI00?o0000ohPdG?n8
=5`03On8=5`4o`0000KoT4Qb00?o0000ojQIKonXFFl07OnXFFl00ol0003oaVaTolI/I00:olI/I003
o`000?o6K6Co000000?o00002?nlCCP01?l0003o`d80ol=20?o3@P02o`0002cooooo00?o0000oooo
ooooool07_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0]ooooo`;o
00001?l10002o`0000Co>@0J00?o0000of43=_mQ0cH01?mQ0cH3o`0000WoLbAI00?o0000ohPdG?n8
=5`02On8=5`4o`0000[oT4Qb00?o0000ojQIKonXFFl07OnXFFl00ol0003oaVaTolI/I00:olI/I003
o`000?o6K6CoaVaT00?oaVaT1Ol00003oka=>003o`000?o3@P3o`d8000?o`d8000?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02_ooooo0_l00002o`4000?o00001Oli01X00ol0003oH@<fof43=P03of43=P;o0000
2omc95T00ol0003oR3ALohPdG007ohPdG0?o00003_n@B7800ol0003oZ5U_ojQIK`0MojQIK`03o`00
0?o6K6CoaVaT00[oaVaT00?o0000olI/I?o6K6@02?o6K6@5o`0000Go`d800_l0000Zooooo`03o`00
0?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:?oo
ool3o`000003o`400?l0003o000000So>@0J00?o0000of43=_mQ0cH00ol0000=og<TF@03o`000?n8
=5coR3AL00?oR3AL1?l0000Aoi18LP03o`000?nXFFooZ5U_01goZ5U_00?o0000olI/I?o6K6@02_o6
K6@00ol0003oaVaTolI/I00<olI/I0?o00001Oo3@P000ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01cooooo000Vooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool0
0ol0003oL]:Co`000002o`0000[o>@0J0ol0000@og<TF@03o`000?n8=5co000000?o00005On@B780
0ol0003oZ5U_ojQIK`0NojQIK`03o`000?o6K6CoaVaT00WoaVaT00?o0000olI/I?o6K6@03Oo6K6@0
0ol0003oiWhgo`000005ol=20003o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool0
02Kooooo0ol0000_ooooo`03o`000?oooooooooo02?ooooo0_l000000ombdY?o0000o`00000:ocT0
6P;o00004_mc95T3o`0001WoT4Qb00?o0000ojQIKonXFFl07_nXFFl00ol0003oaVaTolI/I00:olI/
I003o`000?o6K6CoaVaT00coaVaT00Co0000onIn=ooVOSOo00001Oo3@P02o`0002Sooooo00?o0000
ooooooooool06oooool002Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Qoooo
o`04o`000?mbdY?o0000o`0000Wo>@0J0ol000000omH2D[o0000og<TF@0>og<TF@?o000000?oOSY`
o`000?n@B7806On@B7800ol0003oZ5U_ojQIK`0FojQIK`_o00002_o6K6@00ol0003oaVaTolI/I00=
olI/I003o`000?oVOSOoiWhg00;o00001Oo3@P000ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07ooo
ool00ol0003oL]:Co`000002o`0000Oo>@0J0_l00004oeP9BP03o`000?mc95WoLbAI00[oLbAI0ol0
0004oghjL003o`000?n@B7;oT4Qb01SoT4Qb00?o0000ojQIKonXFFl01OnXFFlAo`0000So[6R300?o
0000olUoOoo9Ogl01?l00006olI/I003o`000?o6K6CoaVaT00goaVaT00?o0000onIn=ooVOSL00_oV
OSL00ol0003o`d80ol=20003ol=20003o`000?oooooooooo02Gooooo00?o0000ooooooooool06_oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool6o`0000Ko>@0J0_l0
0005oeP9BP03o`000?mc95WoLbAI00SoLbAI0ol00007oghjL003o`000?n@B7;oT4Qb01KoT4Qb2_l0
000IojaXP`03o`000?o9OgoobGmo00CobGmo1?l00002olI/I003o`000?o6K6CoaVaT00goaVaT00?o
0000onIn=ooVOSL00ooVOSL00ol0003o`d80ol=20003ol=20003o`000?oooooooooo02Gooooo00?o
0000ooooooooool06Oooool000?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06_oo
ool00ol0003oL]:Co`000003o`0000Co>@0J0ol00007oeP9BP03o`000?mc95WoLbAI00KoLbAI0_l0
000:oghjL003o`000?n@B7;oT4Qb017oT4Qb1Ol00002oiIFPP03o`000?n/J8?o[6R301ko[6R300?o
0000olUoOoo9Ogl02?o9Ogl4o`0000ooaVaT00?o0000onIn=ooVOSL00ooVOSL2o`0000?o`d8000?o
0000ooooooooool09_ooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Sooooo1_l00003ocT06P;o00002_mH2DX00ol0003oLbAIog<TF@03og<TF@?o00003?mn
>W000ol0003oT4Qboi18LP0=oi18LPCo00001onFEX800ol0003o[6R3ojaXP`0NojaXP`03o`000?o9
OgoobGmo00[obGmo00?o0000olUoOol000000_l0000<olI/I003o`000?oVOSOoiWhg00GoiWhg00Go
0000ol=20?o3@P3o`d80o`00000Wooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Eooooo`So000000?o>@0Jo`000?l000003?mH2DX00ol0003o
LbAIog<TF@03o`0000ooOSY`00?o0000oi18L_n@B7802?n@B785o`0000_oUUJ200?o0000ojaXPon/
J8<07_n/J8<00ol0003obGmoolUoO`0:olUoO`03o`000?o9OgoobGmo00;obGmo1?l00008olI/I003
o`000?oVOSOoiWhg00KoiWhg00Go0000ol=20?o3@P3o`d80o`00000Wooooo`03o`000?oooooooooo
01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06oooo
o`;o0000>?ooool00ol0003oooooooooo`0Cooooo`[o00003OmH2DX4o`0001;oOSY`00?o0000oi18
L_n@B7801?n@B784o`00013oUUJ200?o0000ojaXPon/J8<07_n/J8<00ol0003obGmoolUoO`0:olUo
O`03o`000?o9OgoobGmo00KobGmo1?l00004olI/I003o`000?oVOSOoiWhg00OoiWhg0_l000000oo3
@P3o0000ooooo`0Vooooo`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool04Oooool8o`0000ooF0U:0_l0000EoghjL003o`000?n@B7;o000000Co00005?nFEX800ol0
003o[6R3ojaXP`0NojaXP`03o`000?o9OgoobGmo00[obGmo00?o0000olUoOoo9Ogl02_o9Ogl4o`00
0003olI/I?l0003oiWhg00WoiWhg00?o0000ol=20?l000009oooool00ol0003oooooooooo`0Foooo
o`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool03oooool7o`000003oa@07_l0003oF0U:00_oF0U:0ol000000om[
:6So0000oghjL00CoghjL0?o00006OnFEX800ol0003o[6R3ojaXP`0NojaXP`03o`000?o9OgoobGmo
00[obGmo00?o0000olUoOoo9Ogl03_o9Ogl3o`0000[oiWhg00?o0000ol=20?l000009Oooool3o`00
01Oooooo000Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03_ooool7o`000003
oa@07_l0003oF0U:00[oF0U:0_l00004of/XJ003o`000?mn>W3oOSY`00ooOSY`0ol000000on6BX3o
0000oiIFPP0IoiIFPP03o`000?n/J8?o[6R301ko[6R300?o0000olUoOoo9Ogl02_o9Ogl00ol0003o
bGmoolUoO`0?olUoO`03o`000?o]WFko000000[oiWhg0ol0000Qooooo`?o00000_ooool00ol0003o
ooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00gooooo
1Ol00003oa@07P03o`000?mH2D[oF0U:00OoF0U:0_l00005of/XJ003o`000?mn>W3oOSY`00goOSY`
0ol00004ohI:P003o`000?nFEX;oUUJ201SoUUJ200?o0000ojaXPon/J8<07_n/J8<00ol0003obGmo
olUoO`0:olUoO`03o`000?o9OgoobGmo00oobGmo00Co0000onfMK_o]WFko00002ooVOSL00ol0003o
ooooooooo`0Looooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00_ooooo1?l00004oa@07P03o`000?mH2D[oF0U:00GoF0U:
0ol00007of/XJ003o`000?mn>W3oOSY`00[oOSY`0ol00007ohI:P003o`000?nFEX;oUUJ201SoUUJ2
00?o0000ojaXPon/J8<07_n/J8<00ol0003obGmoolUoO`0:olUoO`03o`000?o9OgoobGmo00oobGmo
00Co0000onfMK_o]WFkokIe^0_l0000:onIn=`03o`000?oooooooooo01Sooooo0ol00008ooooo`03
o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
2Oooool4o`0000Go500N00?o0000oeP9B_mH2DX00omH2DX2o`0000[oJbQX00?o0000oghjL?mn>W00
1omn>W03o`0000[oQTZ000?o0000oiIFP_nFEX806?nFEX800ol0003o[6R3ojaXP`0NojaXP`03o`00
0?o9OgoobGmo00[obGmo00?o0000olUoOoo9Ogl03oo9Ogl00ol0003okIe^onfMKP03onfMKP03o`00
0?oVOSOoiWhg00SoiWhg00?o0000ooooooooool05?ooool3o`0000_ooooo00?o0000ooooooooool0
5Oooool002Cooooo0_l0000oooooo`03o`000?oooooooooo00Oooooo0ol00007oa@07P04o`000?mH
2D[oF0U:oeP9BP;o00003?m[:6P00ol0003oOSY`oghjL004oghjL0?o00003On6BX000ol0003oUUJ2
oiIFPP0FoiIFPRKo00002_o9Ogl00ol0003obGmoolUoO`0?olUoO`03o`000?o]WFkokIe^00CokIe^
00?o0000onIn=ooVOSL01ooVOSL00ol0003oooooooooo`0Aooooo`?o00003oooool00ol0003ooooo
ooooo`0Dooooo`009?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo0ol0
0007oa@07P03o`000?mH2D[o000000;o00003_m[:6P01?l0003oOSY`oghjL?mn>W03o`0000ooQTZ0
00?o0000oiIFP_nFEX804_nFEX85o`0000;oVV:?00?o0000ojmdTOn_M9407_n_M9400ol0003obHbC
olV<T`04o`0000KobGmo00?o0000olUoOoo9Ogl03oo9Ogl00ol0003okIe^onfMKP05onfMKP;o0000
2?oVOSL00ol0003oooooooooo`0=ooooo`?o00004_ooool00ol0003oooooooooo`0Dooooo`008ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?ooooo0_l00009oa@07P;o00004?m[
:6P00ol0003oOSY`o`000002o`0001;oQTZ000?o0000oiIFP_nFEX803OnFEX85o`0000OoVV:?00?o
0000ojmdTOn_M9407_n_M9400ol0003obHbColV<T`04olV<T`Co00000_o9Ogl00ol0003obGmoolUo
O`0@olUoO`03o`000?o]WFkokIe^00KokIe^00?o0000onIn=ooVOSL01OoVOSL00ol0003ooooooooo
o`0:ooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`12
ooooo`05o`000?ooooooooooooooool000002OlD01h2o`00017oJbQX0ol0000EohI:P003o`000?nF
EX;oUUJ200WoUUJ21?l0000<oiYRS`03o`000?n_M97o[gBA01ko[gBA00?o0000olV<Too9S9<02?o9
S9<4o`00017obGmo00?o0000onfMK_o]WFh01oo]WFh00ol0003oiWhgonIn=`04onIn=`03o`000?oo
oooooooo00Oooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooool000002OlD01h00ol0003o>`1Bo`00000>of/XJ0?o000000?oN3im
o`000?n6BX005On6BX000ol0003oUUJ2oiIFPP04oiIFPPGo00004?nJHXl00ol0003o[gBAojmdT@0N
ojmdT@03o`000?o9S9?obHbC00_obHbC1Ol0000=olUoO`03o`000?o]WFkokIe^00SokIe^00?o0000
onIn=ooVOSL01?oVOSL00ol0003oooooooooo`03ooooo`?o00006oooool00ol0003oooooooooo`0D
ooooo`008oooool00ol0003oooooooooo`14ooooo`;o00001olD01h2o`0000;o>`1B00?o0000of/X
J?m[:6P02_m[:6P2o`0000CoN3im00?o0000ohI:P?n6BX005?n6BX000ol0003oUUJ2o`000004o`00
01GoVV:?00?o0000ojmdTOn_M9407_n_M9400ol0003obHbColV<T`0;olV<T`03o`000?o9S9?obHbC
00;obHbC1?l00009olUoO`03o`000?o]WFkokIe^00WokIe^0_l00004onIn=`03o`000?oooooooooo
00?o00007_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`14ooooo`03
o`000?lD01ko500N00Co500N0_l00003oc/0DP03o`000?m[:6SoJbQX00WoJbQX0_l00006ogPnO@03
o`000?n6BX3oQTZ001;oQTZ01?l0000JoiYRS`03o`000?n_M97o[gBA01ko[gBA00?o0000olV<Too9
S9<02oo9S9<00ol0003obHbColV<T`06olV<T`Co00001Oo9Ogl00ol0003okIe^onfMKP0;onfMKP04
o`000?oVOSOoiWhgonIn=`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2o`0004Co
oooo00?o0000oa@07_lD01h01?lD01h00ol0003o>`1Boc/0DP03oc/0DP03o`000?m[:6SoJbQX00Ko
JbQX0ol00008ogPnO@03o`000?n6BX3oQTZ000ooQTZ00ol00002ohaGS@03o`000?nJHXooVV:?01Wo
VV:?00?o0000ojmdTOn_M9407_n_M9400ol0003obHbColV<T`0;olV<T`03o`000?o9S9?obHbC00[o
bHbC1?l000000oo9Ogoo0000onfMKP0=onfMKP05o`000?oVOSOoiWhgonIn=ol000008oooool00ol0
003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`13ooooo`03o`000?lD01ko500N00;o
500N0_l00006oc/0DP03o`000?m[:6SoJbQX00CoJbQX0_l0000;ogPnO@03o`000?n6BX3oQTZ000co
QTZ00ol00005ohaGS@03o`000?nJHXooVV:?01WoVV:?00?o0000ojmdTOn_M9407On_M9400ol0003o
bHbColV<T`0<olV<T`03o`000?o9S9?obHbC00kobHbC0ol0000>onfMKP;o000000?oiWhgo`000?oo
ool08_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`13ooooo`04o`00
0?lD01ko500Noa@07P;o00002?lk05800ol0003oJbQXof/XJ002of/XJ0;o00003Omh?Wd00ol0003o
QTZ0ohI:P008ohI:P0Co00002?n<Ehd00ol0003oVV:?oiYRS`0IoiYRS`03o`000?n_M97o[gBA01go
[gBA00?o0000olV<Too9S9<03?o9S9<00ol0003obHbColV<T`0?olV<T`03o`000?oZ[Hoo000000oo
kIe^0_l0000Sooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04?ooooo
00Co0000oa@07_lD01ko00002_lk05800ol0003oJbQXo`000002o`0000ooN3im00?o0000ohI:P?n6
BX001On6BX03o`0000coS5N=00?o0000oiYRSonJHXl06OnJHXl00ol0003o[gBAojmdT@0MojmdT@03
o`000?o9S9?obHbC00cobHbC00?o0000olV<Too9S9<03oo9S9<01?l0003ojZf?onZ]Sol0000?onfM
KP;o00008_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`12ooooo`04
o`000?lD01ko0000o`0000[o>`1B0ol0000BogPnO@03o`000?n6BX3oQTZ000;oQTZ00ol0000?ohaG
S@03o`000?nJHXooVV:?01WoVV:?00?o0000ojmdTOn_M9407On_M9400ol0003obHbColV<T`0<olV<
T`03o`000?o9S9?obHbC00oobHbC00Co0000onZ]SooZ[HoojZf?0_l0000>onfMKP03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0@Oooool3o`00
00_o>`1B0_l0000DogPnO@03o`000?n6BX3o000000;o00004on<Ehd00ol0003oVV:?oiYRS`0HoiYR
S`03o`000?n_M97o[gBA01go[gBA00?o0000olV<Too9S9<03?o9S9<00ol0003obHbColV<T`0?olV<
T`03o`000?oZ[HoojZf?00?ojZf?00?o0000onfMK_o]WFh02oo]WFh00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo047ooooo00?o0000oc/0D_lk
05802_lk05800ol0003oE29do`00000CogPnO@?o00005_n<Ehd00ol0003oVV:?oiYRS`0EoiYRS`co
00005on_M9400ol0003obHbColV<T`0<olV<T`03o`000?o9S9?obHbC00oobHbC00?o0000onZ]SooZ
[Hl01?oZ[Hl00ol0003okIe^onfMKP0:onfMKP03o`000?oooooooooo023ooooo00?o0000oooooooo
ool04oooool0027ooooo0ol00011ooooo`03o`000?lk05;o>`1B00Wo>`1B0_l00002oe@RM003o`00
0?mh?WgoN3im00ooN3im0_l000000on0Chgo0000ohaGS@0FohaGS@03o`000?nJHXooVV:?00koVV:?
1ol00003oie]VP03o`000?naOYko/GjN00Ko/GjN4?l00007ojmdT@03o`000?o9S9?obHbC00cobHbC
00?o0000olV<Too9S9<03oo9S9<00ol0003ojZf?onZ]S`05onZ]S`03o`000?o]WFkokIe^00WokIe^
0_l0000Rooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo047ooooo00?o
0000oc/0D_lk05802?lk05800ol0003oE29doe@RM002oe@RM003o`000?mh?WgoN3im00coN3im0ol0
0003oh1?S@03o`000?n<EhgoS5N=01GoS5N=00?o0000oiYRSonJHXl01onJHXl7o`0000[oWFfJ00?o
0000ok5nW_naOYh05_naOYh:o`0000cobHbC00?o0000olV<Too9S9<03oo9S9<00ol0003ojZf?onZ]
S`06onZ]S`;o00002_o]WFh00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo000Q
ooooo`03o`000?oooooooooo043ooooo0_l00008oc/0DP;o00001OmD8W@00ol0003oN3imogPnO@0:
ogPnO@;o00001_n0Chd00ol0003oS5N=ohaGS@0EohaGS@03o`000?nJHXooVV:?00Oo00004OnMKIX0
0ol0003o/GjNok5nWP0Mok5nWP03o`000?o8UZ;ob9JR00?o00002Oo9S9<00ol0003obHbColV<T`0?
olV<T`03o`000?oZ[HoojZf?00SojZf?00?o0000onfMK_o]WFh01oo]WFh00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo03oooooo0_l00008oc/0
DP03o`000?mD8WCoE29d00GoE29d00?o0000ogPnOOmh?Wd02?mh?Wd2o`0000SoP4n=00?o0000ohaG
SOn<Ehd05?n<Ehd4o`0001SoWFfJ00?o0000ok5nW_naOYh07OnaOYh00ol0003ob9JRolRFXP03olRF
XPCo00001Oo9S9<00ol0003obHbColV<T`0>olV<T`03o`000?oZ[HoojZf?00[ojZf?00?o0000onfM
K_o]WFh01_o]WFh00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo000Qooooo`03
o`000?oooooooooo03oooooo0_l00006oc/0DP;o00001omD8W@00ol0003oN3imogPnO@07ogPnO@;o
00002_n0Chd00ol0003oS5N=ohaGS@0AohaGS@?o000000?oTF>Ho`000?nMKIX06OnMKIX00ol0003o
/GjNok5nWP0Mok5nWP03o`000?o8UZ;ob9JR00Oob9JR0ol00002olV<T`03o`000?o9S9?obHbC00ko
bHbC00?o0000onZ]SooZ[Hl02ooZ[Hl2o`0000KokIe^0_l0000Qooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo03kooooo0ol00005oc/0DP03o`000?mD8WCoE29d00OoE29d
00?o0000ogPnOOmh?Wd01Omh?Wd2o`0000coP4n=00?o0000ohaGSOn<Ehd03_n<Ehd3o`0000CoTF>H
00?o0000oie]V_nMKIX06?nMKIX00ol0003o/GjNok5nWP0Mok5nWP03o`000?o8UZ;ob9JR00[ob9JR
1?l0000?olV<T`03o`000?oZ[HoojZf?00gojZf?00?o0000onfMK_o]WFh00oo]WFh2o`00027ooooo
00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0?_ooool2o`0000Go>`1B00?o
0000oe@RM?mD8W@02?mD8W@00ol0003oN3imogPnO@02ogPnO@?o00003_n0Chd00ol0003oS5N=ohaG
S@0;ohaGS@?o00001onAHiP00ol0003oWFfJoie]VP0Hoie]VP03o`000?naOYko/GjN01co/GjN00?o
0000olRFX_o8UZ803Oo8UZ800ol0003ob9JRo`000003o`0000_obHbC00?o0000onZ]SooZ[Hl03_oZ
[Hl00ol0003okIe^onfMKP02onfMKP;o00008Oooool00ol0003oooooooooo`0Booooo`008?ooool3
o`0003kooooo0ol00003oc/0DP;o00002omD8W@00ol0003oN3imogPnO@02o`00017oP4n=00?o0000
ohaGSOn<Ehd02?n<Ehd3o`0000[oTF>H00?o0000oie]V_nMKIX06?nMKIX00ol0003o/GjNok5nWP0L
ok5nWP03o`000?o8UZ;ob9JR00gob9JR00?o0000olRFX_o8UZ800oo8UZ83o`0000SobHbC00?o0000
onZ]SooZ[Hl03ooZ[Hl01?l0003okIe^onfMK_o]WFh2o`0002;ooooo00?o0000ooooooooool04Ooo
ool0023ooooo00?o0000ooooooooool0?Oooool4o`0000;o>`1B00?o0000oe@RM?mD8W@02omD8W@3
o`0001?oP4n=00?o0000ohaGSOn<Ehd01On<Ehd3o`0000goTF>H00?o0000oie]V_nMKIX06?nMKIX0
0ol0003o/GjNok5nWP0Lok5nWP03o`000?o8UZ;ob9JR00kob9JR00?o0000olRFX_o8UZ801Oo8UZ84
o`0000CobHbC00?o0000onZ]SooZ[Hl04?oZ[Hl2o`0000;okIe^0_l0000Qooooo`03o`000?oooooo
oooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0m
ooooo`Ko00003OmD8W@2o`0001GoP4n=00?o0000ohaGSOn<Ehd00_n<Ehd3o`00013oTF>H00?o0000
oie]V_nMKIX06?nMKIX00ol0003o/GjNok5nWP0Lok5nWP03o`000?o8UZ;ob9JR00kob9JR00?o0000
olRFX_o8UZ802Oo8UZ83o`000003olV<Tol0003ojZf?01?ojZf?00Co0000onfMK_l0003o00008Ooo
ool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0??ooool5o`0000koE29d00?o0000ofDlRol000005On0Chd00ol0003oS5N=o`00
0002o`0001?oTF>H00?o0000oie]V_nMKIX06?nMKIX00ol0003o/GjNok5nWP0Lok5nWP03o`000?o8
UZ;ob9JR00kob9JR00?o0000olRFX_o8UZ803?o8UZ83o`0001CojZf?0ol0000Qooooo`03o`000?oo
oooooooo017ooooo000Eooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`0looooo`Co00003_mD8W@01?l0003oICb;ofDlRol0000Doh1?S@?o00005_nAHiP00ol0003oWFfJ
oie]VP0Hoie]VP03o`000?naOYko/GjN01co/GjN00?o0000olRFX_o8UZ803_o8UZ800ol0003ob9JR
olRFXP0=olRFXP03o`000?oT]ZKo000001CojZf?0_l0000Qooooo`03o`000?oooooooooo017ooooo
000Eooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0kooooo`Go0000
3?mD8W@2o`0000?oICb;00?o0000oh1?SOn0Chd04?n0Chd2o`000003ohIMV_l0003oTF>H01KoTF>H
00?o0000oie]V_nMKIX06?nMKIX00ol0003o/GjNok5nWP0Lok5nWP03o`000?o8UZ;ob9JR00kob9JR
00?o0000olRFX_o8UZ803Oo8UZ801?l0003oi;JVonBfY_l0000ConZ]S`;o00008Oooool00ol0003o
ooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0>oooool6o`0000_oE29d00?o0000ofDlRomU?8/00omU?8/00ol0003oP4n=oh1?S@0>oh1?S@;o
00000on6GIX00ol0003oTF>Hoi5SV00Eoi5SV003o`000?nMKI[oWFfJ01SoWFfJ00?o0000ok5nW_na
OYh06onaOYh00ol0003ob9JRolRFXP0?olRFXP03o`000?o8UZ;ob9JR00cob9JR00?o0000onBfY_oT
]ZH00_oT]ZH2o`00017ojZf?00?o0000omBH2ol000008?ooool00ol0003oooooooooo`0Aooooo`00
5Oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000looooo`Co000000?o0019o`000?mD
8W@02OmD8W@00ol0003oICb;ofDlR`04ofDlR`03o`000?n0ChgoP4n=00coP4n=0_l00005ohIMVP03
o`000?nAHiSoTF>H01GoTF>H00?o0000oie]V_nMKIX04OnMKIX@o`0001Go/GjN00?o0000olRFX_o8
UZ803oo8UZ800ol0003ob9JRolRFXP0<olRFXP03o`000?oT]ZKoi;JV00Coi;JV00?o0000onZ]SooZ
[Hl03_oZ[Hl3o`00023ooooo00?o0000ooooooooool04Oooool001Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo03[ooooo1Ol000000ol004Wo0000oe@RM007oe@RM0;o
00001omU?8/00ol0003oP4n=oh1?S@0:oh1?S@;o00002?n6GIX00ol0003oTF>Hoi5SV00Doi5SV003
o`000?nMKI[oWFfJ00CoWFfJ3Ol00007oj5gY003o`000?nbQjSo/XNX00Ko/XNX3ol00006ok5nWP03
o`000?o8UZ;ob9JR00oob9JR00?o0000olRFX_o8UZ803?o8UZ800ol0003oi;JVonBfYP05onBfYP03
o`000?oZ[HoojZf?00gojZf?0ol0000Qooooo`03o`000?oooooooooo013ooooo000Eooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0jooooo`Co00000_l004T00ol0003o
E29doe@RM005oe@RM003o`000?mU?8_oICb;00SoICb;00?o0000oh1?SOn0Chd01_n0Chd3o`0000[o
QUfJ00?o0000oi5SV?nAHiP04_nAHiP9o`0001CoXGNT00?o0000ok:7Z?nbQjP05OnbQjP9o`0000oo
b9JR00?o0000olRFX_o8UZ803?o8UZ800ol0003oi;JVonBfYP06onBfYP;o00003?oZ[Hl01?l0003o
nLiSo`000?l0000Qooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03[o
oooo1?l00002o`00B@03o`000?mD8WCoE29d00?oE29d0_l0000;ofDlR`03o`000?n0ChgoP4n=00Co
P4n=0_l0000=ohIMVP03o`000?nAHiSoTF>H00ooTF>H0ol00002oiE^X`03o`000?nQMjCoXGNT01So
XGNT00?o0000ok:7Z?nbQjP06onbQjP00ol0003oaYf^olJM[P03o`0000cob9JR00?o0000olRFX_o8
UZ802oo8UZ800ol0003oi;JVonBfYP09onBfYP03o`000?oZ[HoojZf?00WojZf?00Go0000ooW>Hol0
003oe9P;o`00000Pooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03Wo
oooo1?l00002o`00B@03o`000?mD8WCoE29d00?oE29d00?o0000ofDlRomU?8/02omU?8/00ol0003o
P4n=oh1?S@02oh1?S@;o00003on6GIX00ol0003oTF>Hoi5SV00<oi5SV0?o00001OnEKZ<00ol0003o
XGNToj5gY00Hoj5gY003o`000?nbQjSo/XNX01_o/XNX00?o0000olJM[_o6WJh00oo6WJh3o`0000Wo
b9JR00?o0000olRFX_o8UZ802oo8UZ800ol0003oi;JVonBfYP0:onBfYP03o`000?oZ[HoojZf?00So
jZf?00?o0000ooW>HooicV<00_l0000Pooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`00
0?oooooooooo03Wooooo1?l00002o`00B@03o`000?mD8WCoE29d00;oE29d00?o0000ofDlRomU?8/0
3?mU?8/00ol0003oP4n=oh1?S@02o`00017oQUfJ00?o0000oi5SV?nAHiP02OnAHiP3o`0000SoUFjS
00?o0000oj5gY?nQMj@06?nQMj@00ol0003o/XNXok:7Z00Kok:7Z003o`000?o6WJkoaYf^00KoaYf^
0ol00006olRFXP03o`000?o8UZ;ob9JR00_ob9JR00?o0000onBfY_oT]ZH02ooT]ZH00ol0003ojZf?
onZ]S`07onZ]S`03o`000?oicV?onLiS00;o00008?ooool00ol0003oooooooooo`0@ooooo`007_oo
ool00ol0003oooooooooo`0jooooo`?o00000ol004T00ol0003oE29doe@RM002o`0000ooICb;0ol0
000CohIMVP03o`000?nAHiSoTF>H00KoTF>H0ol0000<oiE^X`03o`000?nQMjCoXGNT01OoXGNT00?o
0000ok:7Z?nbQjP06_nbQjP00ol0003oaYf^olJM[P0:olJM[P?o00000oo8UZ800ol0003ob9JRolRF
XP0;olRFXP03o`000?oT]ZKoi;JV00coi;JV0_l00007onZ]S`03o`000?oicV?onLiS00;o00008?oo
ool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`0iooooo`?o00001?l004T0
0ol0003oE29do`00000@ofDlR`;o00005_n6GIX00ol0003oTF>Hoi5SV002oi5SV0?o00003onEKZ<0
0ol0003oXGNToj5gY00Goj5gY003o`000?nbQjSo/XNX01[o/XNX00?o0000olJM[_o6WJh03Oo6WJh4
o`0000cob9JR00?o0000onBfY_oT]ZH03ooT]ZH00ol0003ojZf?onZ]S`04onZ]S`03o`000?oicV?o
nLiS00;o00008?ooool00ol0003oooooooooo`0@ooooo`007_ooool2o`0003[ooooo0ol00004o`00
B@;o00004?mU?8/00ol0003oLE6Mo`00000FohIMVP03o`000?nAHiSo000000;o00004_nEKZ<00ol0
003oXGNToj5gY00Foj5gY003o`000?nbQjSo/XNX01_o/XNX00?o0000olJM[_o6WJh04?o6WJh3o`00
00[ob9JR00?o0000onBfY_oT]ZH04?oT]ZH00ol0003ojZf?onZ]S`03onZ]S`04o`000?oicV?onLiS
ooW>H`;o00008?ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0ioooo
o`;o00001Ol004T00ol0003oICb;ofDlR`0>ofDlR`04o`000?maDIgoLE6Mo`0001GoQUfJ0ol0000E
oiE^X`03o`000?nQMjCoXGNT01KoXGNT00?o0000ok:7Z?nbQjP06onbQjP00ol0003oaYf^olJM[P0@
olJM[P03o`000?o6WJkoaYf^00?o00001oo8UZ800ol0003oi;JVonBfYP0AonBfYP;o00000_oZ[Hl0
0ol0003onLiSooW>H`02ooW>H`;o00008?ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`0hooooo`?o00001Ol004T00ol0003oICb;ofDlR`0<ofDlR`;o00000omaDId00ol0
003oQUfJohIMVP0AohIMVP;o000000?oS6VVo`000?nEKZ<05OnEKZ<00ol0003oXGNToj5gY00Foj5g
Y003o`000?nbQjSo/XNX01_o/XNX00?o0000olJM[_o6WJh04?o6WJh00ol0003oaYf^olJM[P03olJM
[P?o00001?o8UZ800ol0003oi;JVonBfYP0ConBfYP03o`000?oZ[Hoo000000ConLiS0_l0000Poooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l00005o`00B@;o
00003OmU?8/00ol0003oLE6Mog5AW@04og5AW@03o`000?n6GI[oQUfJ00koQUfJ0_l00003ohaYYP03
o`000?nEKZ?oUFjS01CoUFjS00?o0000oj5gY?nQMj@05_nQMj@00ol0003o/XNXok:7Z00Jok:7Z003
o`000?o6WJkoaYf^017oaYf^00?o0000olJM[_o6WJh01_o6WJh4o`0001Ooi;JV0_l00004ooW>H`;o
00008?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0iooooo`03o`00
0?l004Wo001900Co00190_l0000<ofDlR`03o`000?maDIgoLE6M00GoLE6M00?o0000ohIMV_n6GIX0
3?n6GIX2o`0000GoS6VV00?o0000oiE^XonEKZ<05?nEKZ<00ol0003oXGNToj5gY00Foj5gY003o`00
0?nbQjSo/XNX01[o/XNX00?o0000olJM[_o6WJh04Oo6WJh00ol0003oaYf^olJM[P09olJM[P;o0000
5ooT]ZH00ol0003onLiSooW>H`03ooW>H`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
3oooool001gooooo00?o0000ooooooooool0>?ooool2o`0000Go001900?o0000oaH6O?l000002_mU
?8/2o`0000SoLE6M00?o0000ohIMV_n6GIX02_n6GIX2o`0000SoS6VV00?o0000oiE^XonEKZ<05?nE
KZ<00ol0003oXGNToj5gY00Eoj5gY003o`000?nbQjSo/XNX01[o/XNX00?o0000olJM[_o6WJh04_o6
WJh00ol0003oaYf^olJM[P08olJM[P03o`000?oN_;Ko000001Koi;JV00?o0000ooW>HooicV<00ooi
cV<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo03Sooooo00?o0000o`00BOl004T00ol004T01?l0003o5PIloaH6O?l00009ofDlR`03o`000?ma
DIgoLE6M00SoLE6M00?o0000ohIMV_n6GIX01on6GIX3o`0000[oS6VV00?o0000oiE^XonEKZ<05?nE
KZ<00ol0003oXGNToj5gY00Eoj5gY003o`000?nbQjSo/XNX01[o/XNX00?o0000olJM[_o6WJh04_o6
WJh00ol0003oaYf^olJM[P07olJM[P05o`000?oN_;Kog[bfomjl]_l000005?oT]ZH2o`0000GonLiS
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0003Wooooo00?o
0000o`00BOl004T00ol004T01?l0003o5PIloaH6O?l00007ofDlR`;o00002omaDId00ol0003oQUfJ
ohIMVP05ohIMVP;o00003On<JJH00ol0003oUFjSoiE^X`0DoiE^X`03o`000?nQMjCoXGNT00WoXGNT
4Ol0000Hok:7Z003o`000?o6WJkoaYf^01;oaYf^00?o0000olJM[_o6WJh01oo6WJh00ol0003og[bf
omjl]P02omjl]P03o`000?oT]ZKoi;JV017oi;JV00?o0000oogSV_l000001?oicV<2o`00023ooooo
00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0>?ooool00ol0003o0019o`00
B@02o`00B@03o`000?lF1Wco5PIl00;o5PIl00?o0000ofDlRomU?8/00omU?8/00ol0003oLE6Mog5A
W@0;og5AW@03o`000?n6GI[oQUfJ00?oQUfJ0_l0000?ohaYYP03o`000?nEKZ?oUFjS01;oUFjS3_l0
000<ojB1[P03o`000?nbT;;o/Y2b00;o/Y2b1ol0000Aok:7Z003o`000?o6WJkoaYf^01;oaYf^00?o
0000olJM[_o6WJh01_o6WJh00ol0003og[bfomjl]P04omjl]P;o00004OoT]ZH00ol0003ooN>Jo`00
0005ooW>H`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool0>?ooool00ol0003o0019o`00B@02o`00B@03o`000?lF1Wco5PIl00;o5PIl00?o0000
ofDlRomU?8/00_mU?8/00ol0003oLE6Mog5AW@0=og5AW@03o`000?n6GI[oQUfJ00;o00004On<JJH0
0ol0003oUFjSoiE^X`0>oiE^X`Co00000_nINJh00ol0003oY86^ojB1[P0EojB1[P03o`000?nbT;;o
/Y2b00Wo/Y2b1ol00009ok:7Z003o`000?o6WJkoaYf^01?oaYf^00?o0000olJM[_o6WJh01_o6WJh0
0ol0003og[bfomjl]P06omjl]P03o`000?oT]ZKoi;JV00goi;JV00Co0000oogSV_omhi[o00001Ooi
cV<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooo
oooo03Wooooo00Go0000o`00BOl004Wo0019o`000005oaH6O003o`000?mU?8_oICb;00;o00004?ma
DId3o`0001?oS6VV00?o0000oiE^XonEKZ<02onEKZ<3o`0000KoVGV^00?o0000ojB1[_nTPJh05OnT
PJh00ol0003o/Y2bok:@/P0@ok:@/POo00000_nbQjP00ol0003oaYf^olJM[P0ColJM[P03o`000?o6
WJkoaYf^00KoaYf^00?o0000omjl]_oN_;H01ooN_;H00ol0003oi;JVonBfYP0<onBfYP05o`000?om
hi[ooN>JoogSV_l000001?oicV<00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03Wooooo00Co0000o`00BOl004Wo00001_lF1W`00ol0003oICb;
o`00000Aog5AW@;o00005On<JJH00ol0003oUFjSoiE^X`07oiE^X`Co00002OnINJh00ol0003oY86^
ojB1[P0EojB1[P03o`000?nbT;;o/Y2b01Oo/Y2b1?l0000DolJM[P03o`000?o6WJkoaYf^00GoaYf^
00?o0000omjl]_oN_;H02OoN_;H2o`0000_oi;JV00?o0000oogSV_omhiX00_omhiX00ol0003onLiS
ooW>H`02ooW>H`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool001cooooo00?o
0000ooooooooool0>Oooool01?l0003o0019o`00BOl00006oaH6O0;o00004OmaDId00ol0003oNV:[
o`00000FohaYYP03o`000?nEKZ?oUFjS00;oUFjS1?l0000=oiUi[P03o`000?nTPJkoY86^01GoY86^
00?o0000ok:@/_nbT;806OnbT;800ol0003oa:Bio`000002o`00017oaYf^00?o0000olJM[_o6WJh0
1Oo6WJh00ol0003og[bfomjl]P0;omjl]P03o`000?oT]ZKoi;JV00Soi;JV00?o0000oogSV_omhiX0
0_omhiX00ol0003onLiSooW>H`02ooW>H`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0>?ooool01?l0003o0019o`00BOl00007oaH6O003o`00
0?maDIgoLE6M00ooLE6M00Co0000ogYRZomjHZ_o00005_n<JJH00ol0003oUFjSo`000002o`00017o
VGV^00?o0000ojB1[_nTPJh05OnTPJh00ol0003o/Y2bok:@/P0Iok:@/P03o`000?o4Y;Woa:Bi00;o
a:Bi0ol0000<olJM[P?o00001_o6WJh00ol0003og[bfomjl]P0=omjl]P03o`000?oT]ZKoi;JV00Oo
i;JV00?o0000oogSV_omhiX00_omhiX01Ol0003onLiSooW>HooicV?o0000027ooooo00?o0000oooo
ooooool03_ooool001cooooo00?o0000ooooooooool0>?ooool01?l0003o0019o`00BOl00007oaH6
O003o`000?maDIgoLE6M00koLE6M00?o0000ogYRZomjHZ/00_mjHZ/00ol0003oS6VVohaYYP0BohaY
YP?o00005?nINJh00ol0003oY86^ojB1[P0EojB1[P03o`000?nbT;;o/Y2b01So/Y2b00?o0000olBT
^Oo4Y;T01_o4Y;T3o`0000KoaYf^0ol00002olJM[P03o`000?o6WJkoaYf^00CoaYf^00?o0000omjl
]_oN_;H03_oN_;H00ol0003oi;JVonBfYP05onBfYP03o`000?omhi[ooN>J00CooN>J00Co0000ooW>
HooicV?o00008_ooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0003Wooooo00?o0000o`00
BOl000001olF1W`00ol0003o>C:Mo`00000>og5AW@03o`000?mjHZ_oNV:[00?oNV:[00?o0000ohaY
Y_n<JJH04?n<JJH2o`000003oi1e/Ol0003oVGV^01CoVGV^00?o0000ojB1[_nTPJh05OnTPJh00ol0
003o/Y2bok:@/P0Hok:@/P03o`000?o4Y;Woa:Bi00Woa:Bi1_l00006olJM[P03o`000?o6WJkoaYf^
00;oaYf^00?o0000omjl]_oN_;H04?oN_;H2o`0000Goi;JV00?o0000oogSV_omhiX01?omhiX01?l0
003onLiSooW>Hol0000Rooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
03Wooooo0_l00008oaH6O003o`000?li<Ygo000000coLE6M0_l00006ogYRZ`03o`000?n<JJKoS6VV
00koS6VV0_l00003oi1e/@03o`000?nINJkoVGV^01CoVGV^00?o0000ojB1[_nTPJh05?nTPJh00ol0
003o/Y2bok:@/P0Hok:@/P03o`000?o4Y;Woa:Bi00Woa:Bi1_l00007olJM[P05o`000?o6WJkoaYf^
olJM[_l000005?oN_;H01Ol0003oi;JVonBfY_oT]ZKo000000OooN>J00Co0000ooW>HooicV?o0000
8_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0iooooo`;o00001olF
1W`01?l0003o>C:MocTbWOl0000;og5AW@03o`000?mjHZ_oNV:[00OoNV:[00?o0000ohaYY_n<JJH0
2on<JJH2o`0000KoT7Fa00?o0000oiUi[_nINJh04onINJh00ol0003oY86^ojB1[P0DojB1[P03o`00
0?nbT;;o/Y2b01So/Y2b00?o0000olBT^Oo4Y;T01Oo4Y;T4o`0000Koa:Bi0ol00005olJM[P04o`00
0?o6WJkoaYf^o`0001Gog[bf00Co0000onBfY_oT]ZKo00001oomhiX01?l0003onLiSooW>Hol0000R
ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000oaH6
O?lF1W`01_lF1W`01Ol0003o>C:MocTbWOli<Ygo000000WoLE6M00?o0000ogYRZomjHZ/02?mjHZ/0
0ol0003oS6VVohaYYP09ohaYYP;o00002?n@MK400ol0003oVGV^oiUi[P0CoiUi[P03o`000?nTPJko
Y86^01CoY86^00?o0000ok:@/_nbT;805onbT;800ol0003oa:BiolBT^@03olBT^@?o00003Oo4Y;T3
o`0000?oaYf^0_l0000Gomjl]P03o`000?oT]ZKo000000SooN>J00?o0000ooW>Hol000008_ooool0
0ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0iooooo`03o`000?lF1Wco5PIl
00Go5PIl00?o0000ocTbWOli<Yd00_li<Yd00ol0003oLE6Mog5AW@06og5AW@03o`000?mjHZ_oNV:[
00WoNV:[00?o0000ohaYY_n<JJH02?n<JJH00ol0003oT7Faoi1e/@08oi1e/@03o`000?nINJkoVGV^
01?oVGV^00?o0000ojB1[_nTPJh05?nTPJh00ol0003o/Y2bok:@/P0Gok:@/P03o`000?o4Y;Woa:Bi
00?o00004oo4Y;T5o`0001Sog[bf00?o0000oogSV_omhiX01oomhiX00ol0003onLiSo`00000Roooo
o`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000oaH6O?lF
1W`01OlF1W`00ol0003o>C:MocTbW@02ocTbW@03o`000?maDIgoLE6M00CoLE6M0_l0000=ogYRZ`03
o`000?n<JJKoS6VV00GoS6VV0_l0000<oi1e/@03o`000?nINJkoVGV^01;oVGV^00?o0000ojB1[_nT
PJh05?nTPJh00ol0003o/Y2bok:@/P0Gok:@/P?o00006Oo4Y;T2o`0001Sog[bf00?o0000oogSV_om
hiX01oomhiX2o`0002?ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
>Oooool00ol0003o5PIloaH6O004oaH6O003o`000?li<Ygo>C:M00Co>C:M00?o0000og5AWOmaDId0
0_maDId00ol0003oNV:[ogYRZ`0=ogYRZ`03o`000?n<JJKoS6VV00?oS6VV0_l0000>oi1e/@03o`00
0?nINJkoVGV^01;oVGV^00?o0000ojB1[_nTPJh05?nTPJh00ol0003o/Y2bok:@/P0Cok:@/PGo0000
6oo4Y;T00ol0003oel33o`00000Fomjl]P;o00002_omhiX00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00gooooo000Kooooo`;o0000>oooool00ol0003o5PIloaH6O003oaH6O003o`000?li
<Ygo>C:M00Co>C:M00Go0000og5AWOmaDIgoLE6Mo`00000@ogYRZ`04o`000?n<JJKoS6VVohaYYP;o
00004?n@MK400ol0003oVGV^oiUi[P0BoiUi[P03o`000?nTPJkoY86^01CoY86^00?o0000ok:@/_nb
T;804?nbT;83o`0000?o/Y2b00?o0000olBT^Oo4Y;T06Oo4Y;T01Ol0003oel33omO0`ooG`<?o0000
01Gog[bf00?o0000ooCY^ol000002OomhiX00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00cooooo000Jooooo`03o`000?oooooooooo03_ooooo00?o0000oaH6O?lF1W`00_lF1W`00ol0003o
>C:MocTbW@05ocTbW@04o`000?maDIgoLE6Mo`0001;oNV:[0ol0000Boi1e/@03o`000?nINJkoVGV^
013oVGV^7Ol0000<ok:@/P?o00001_nbT;800ol0003oa:BiolBT^@0IolBT^@03o`000?oG`<?oel33
00;oel330_l0000Bomjl]P04o`000?odjK_om>Vko`0000WooN>J00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03_ooooo00?o0000oaH6O?lF1W`00_lF
1W`00ol0003o>C:MocTbW@06ocTbW@;o00004_mjHZ/2o`0001GoT7Fa00?o0000oiUi[_nINJh02onI
NJh4o`0000;oW8Bh00?o0000ojJ;^OnVRkT05?nVRkT01?l0003o/YRlok:H_?nbV;`6o`0000?o/Y2b
0ol00009ok:@/P03o`000?o4Y;Woa:Bi01Soa:Bi00?o0000omO0`ooG`<<01?oG`<<2o`00017og[bf
00Co0000ooCY^oodjK_o00002?omhiX00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00co
oooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo03_ooooo00Go0000oaH6O?lF1Wco5PIlo`000009ocTbW@03o`000?mjHZ_oNV:[
013oNV:[00?o0000oh9a]ol000005On@MK400ol0003oVGV^oiUi[P07oiUi[PCo00001_nLQ;P00ol0
003oYX^iojJ;^@0DojJ;^@03o`000?nbV;co/YRl00Ko/YRl1ol00009ok:@/P03o`000?o4Y;Woa:Bi
01Soa:Bi00?o0000omO0`ooG`<<01?oG`<<00ol0003oel33o`00000?omjl]P03o`000?odjK_om>Vk
00;om>Vk00?o0000oogSV_omhiX01OomhiX00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00cooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0kooooo`05o`000?lF1Wco5PIloaH6O?l000002Oli<Yd00ol0003oNV:[ogYRZ`0?ogYR
Z`05o`000?n2LKOoPW6goh9a]ol000005?n@MK400ol0003oVGV^oiUi[P04oiUi[P?o00002onLQ;P0
0ol0003oYX^iojJ;^@0CojJ;^@03o`000?nbV;co/YRl00?o/YRl0ol00007ok:H_0Ko00000_nbT;80
0ol0003oa:BiolBT^@0HolBT^@03o`000?oG`<?oel3300Koel3300?o0000omO0`ol000003_oN_;H0
0ol0003om>VkooCY^`02ooCY^`03o`000?omhi[ooN>J00CooN>J00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0>oooool01?l0003o5PIloaH6O?l00009ocTbW@03o`000?mBDK?o
000000ooNV:[00?o0000oh9a]on2LKL00_n2LKL00ol0003oT7Faoi1e/@0Coi1e/@03o`000?nINJko
000000?o00003_nLQ;P00ol0003oYX^iojJ;^@0CojJ;^@03o`000?nbV;co/YRl00?o00004?nbV;`4
o`0001Woa:Bi00?o0000omO0`ooG`<<01ooG`<<01?l0003oel33o`000?l0000;omjl]P03o`000?od
jK_om>Vk00?om>Vk00?o0000oogSV_omhiX01?omhiX00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00cooooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo03_ooooo00Co0000oaH6O?lF1Wco00002Oli<Yd00ol0003oDU6c
o`00000>ogYRZ`03o`000?n2LKOoPW6g00CoPW6g00?o0000oi1e/On@MK404On@MK43o`0001;oW8Bh
00?o0000ojJ;^OnVRkT04onVRkT3o`0001Go/YRl00?o0000ol6Z`ol000000_l0000EolBT^@03o`00
0?oG`<?oel3300Woel3300Co0000omO0`ooG`<?o00002OoN_;H00ol0003om>VkooCY^`05ooCY^`03
o`000?omhi[ooN>J00?ooN>J00?o0000ooooooooool09?ooool00ol0003oooooooooo`0<ooooo`00
0oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
?Oooool2o`0000Wo>C:M00Go0000oe9A/omBDK?oDU6co`00000<ogYRZ`03o`000?n2LKOoPW6g00Go
PW6g00?o0000oi1e/On@MK403on@MK42o`000003oiB1_?l0003oW8Bh01;oW8Bh00?o0000ojJ;^OnV
RkT03onVRkT5o`0001Ko/YRl00?o0000ol6Z`oo1Z/<00oo1Z/<3o`00017oa:Bi00?o0000omO0`ooG
`<<02ooG`<<01?l0003oel33omO0`ol00008omjl]P03o`000?odjK_om>Vk00Gom>Vk00?o0000oogS
V_omhiX00_omhiX00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00_ooooo00001?nHV9So
oooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo0_l0000nooooo`;o00002Oli<Yd01Ol0
003oDU6coe9A/omBDK?o000000_oNV:[00?o0000oh9a]on2LKL01on2LKL00ol0003oT7Faoi1e/@0<
oi1e/@;o00001?nDPK`00ol0003oW8Bhoib4^00@oib4^003o`000?nVRkWoYX^i00coYX^i0ol00004
ojJ;^@03o`000?nbV;co/YRl01Co/YRl00?o0000ol6Z`oo1Z/<01_o1Z/<3o`0000koa:Bi00?o0000
omO0`ooG`<<02ooG`<<01?l0003oel33omO0`ooG`<<2o`0000Gog[bf00?o0000ooCY^oodjK/01_od
jK/00ol0003ooN>JoogSVP02oogSVP03o`000?oooooooooo02Kooooo00?o0000ooooooooool02ooo
ool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo03gooooo00?o
0000ocTbWOli<Yd01oli<Yd00ol0003oDU6coe9A/`03oe9A/`03o`000?mjHZ_oNV:[00OoNV:[00?o
0000oh9a]on2LKL02?n2LKL00ol0003oT7Faoi1e/@0:oi1e/@;o00001_nDPK`00ol0003oW8Bhoib4
^00Aoib4^003o`000?nVRkWoYX^i00SoYX^i0ol00006ojJ;^@03o`000?nbV;co/YRl01Go/YRl00?o
0000ol6Z`oo1Z/<02Oo1Z/<2o`0000_oa:Bi00?o0000omO0`ooG`<<03OoG`<<00ol0003oel33omO0
``02omO0``03o`000?oN_;Kog[bf00;og[bf00?o0000ooCY^oodjK/01_odjK/01Ol0003ooN>JoogS
V_omhi[o000002Wooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0?Ooo
ool00ol0003o>C:MocTbW@07ocTbW@03o`000?mBDK?oDU6c00?oDU6c00?o0000ogYRZomjHZ/01_mj
HZ/00ol0003oPW6goh9a]`09oh9a]`03o`000?n@MK7oT7Fa00SoT7Fa0_l00008oiB1_003o`000?nL
Q;SoW8Bh017oW8Bh00?o0000ojJ;^OnVRkT01OnVRkT3o`0000WoYX^i00?o0000ok:H_?nbV;`05?nb
V;`00ol0003o`J[3ol6Z``0<ol6Z``?o00002?o4Y;T00ol0003oel33omO0``0>omO0``03o`000?oG
`<?oel3300;oel3300Co0000omjl]_oN_;Ko00002_odjK/01?l0003ooN>JoogSV_l0000Yooooo`03
o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03gooooo0_l00007ocTbW@03o`00
0?mBDK?oDU6c00CoDU6c00?o0000ogYRZomjHZ/01OmjHZ/00ol0003oPW6goh9a]`0;oh9a]`03o`00
0?n@MK7oT7Fa00KoT7Fa00?o0000oiB1_?nDPK`02OnDPK`00ol0003oW8Bhoib4^00@oib4^004o`00
0?nVRkWoYX^iojJ;^@Co00003?nVRkT00ol0003o/YRlok:H_00Dok:H_003o`000?o1Z/?o`J[300oo
`J[30ol00004olBT^@03o`000?oG`<?oel33013oel3300?o0000omO0`ooG`<<00_oG`<<00ol0003o
g[bfo`00000:ooCY^`03o`000?omhi[o000002[ooooo00?o0000ooooooooool02oooool001Wooooo
00?o0000ooooooooool0?Oooool2o`0000Oo>C:M00?o0000oe9A/omBDK<01OmBDK<00ol0003oNV:[
ogYRZ`03ogYRZ`03o`000?n2LKOoPW6g00coPW6g00?o0000oi1e/On@MK401?n@MK42o`0000coU86l
00?o0000oib4^?nLQ;P04?nLQ;P4o`00013oYX^i00?o0000ok:H_?nbV;`05?nbV;`00ol0003o`J[3
ol6Z``0Bol6Z``?o000000?oa:Bio`000?oG`<<04_oG`<<00ol0003oel33omO0``02omO0``03o`00
0?odjK_om>Vk00Wom>Vk00?o0000oogSV_l00000:_ooool00ol0003oooooooooo`0;ooooo`006?oo
ool00ol0003oooooooooo`0oooooo`03o`000?li<Ygo>C:M00Co>C:M00?o0000oe9A/omBDK<01_mB
DK<00ol0003oNV:[ogYRZ`02ogYRZ`03o`000?n2LKOoPW6g00koPW6g00Co0000oi1e/On@MK7oT7Fa
0_l0000>oiB1_003o`000?nLQ;SoW8Bh00koW8Bh0ol0000CojJ;^@03o`000?nbV;co/YRl01?o/YRl
00?o0000ol6Z`oo1Z/<05_o1Z/<2o`0001Coel3300Go0000omO0`ooG`<?oel33o`00000<ooCY^`;o
0000:_ooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`0oooooo`;o0000
1Oli<Yd00ol0003oDU6coe9A/`07oe9A/`04o`000?mjHZ_oNV:[o`00017oPW6g00Co0000oi1e/Ol0
003o00004OnDPK`00ol0003oW8Bhoib4^00:oib4^0?o00000onLQ;P00ol0003oYX^iojJ;^@0@ojJ;
^@03o`000?nbV;co/YRl01?o/YRl00?o0000ol6Z`oo1Z/<05_o1Z/<00ol0003ocl;>o`00000ComO0
``06o`000?oG`<?oel33o`000?oXiloo00002oodjK/00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00[ooooo000Hooooo`03o`000?oooooooooo03oooooo0_l00004ocTbW@03o`000?mBDK?o
DU6c00SoDU6c00?o0000ogYRZol000004on2LKL00ol0003oU86loiB1_00AoiB1_003o`000?nLQ;So
W8Bh00KoW8Bh1?l00006oib4^003o`000?nVRkWoYX^i013oYX^i00?o0000ok:H_?nbV;`04onbV;`0
0ol0003o`J[3ol6Z``0Eol6Z``05o`000?o?`/kocl;>olo2c_l000004ooG`<<2o`0000;oj>O?00?o
0000ooCY^oodjK/02OodjK/00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00[ooooo000H
ooooo`;o0000@?ooool2o`0000Co>C:M00?o0000oe9A/omBDK<02OmBDK<00ol0003oPW6goh9a]`0B
oh9a]`03o`000?nDPKcoU86l017oU86l00?o0000oib4^?nLQ;P00onLQ;P3o`0000SoW8Bh6Ol0000A
ok:H_003o`000?o1Z/?o`J[301Go`J[300?o0000olo2c_o?`/h00oo?`/h00ol0003oel33omO0``0@
omO0``;o00000_oXill00ol0003om>VkooCY^`08ooCY^`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02_ooool001Sooooo00?o0000ooooooooool0?oooool00ol0003o001]o`000002ocTb
W@03o`000?mBDK?oDU6c00[oDU6c00?o0000oh9a]on2LKL04On2LKL00ol0003oRGo3o`00000CoiB1
_003o`000?nLQ;So000000;o00001onLQ;P4o`0000;oWi3400?o0000ojNF`onWU/<04?nWU/<01?l0
003o/J36ok6Pa_naX<H5o`0000co/YRl00?o0000ol6Z`oo1Z/<05Oo1Z/<00ol0003ocl;>olo2cP04
olo2cP;o00003ooG`<<01?l0003oj>O?onSWcol00002onSWc`03o`000?odjK_om>Vk00Kom>Vk0_l0
000]ooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`000?oooooooooo03oooooo00?o0000
o`00KOl000000_li<Yd00ol0003oDU6coe9A/`09oe9A/`03o`000?mUJ/?o0000017oPW6g00Go0000
ohUo`on9Ol?oRGo3o`00000AoiB1_0?o00001OnLQ;P5o`0000KoWi3400?o0000ojNF`onWU/<04?nW
U/<00ol0003o/J36ok6PaP06ok6PaPGo00001onbV;`00ol0003o`J[3ol6Z``0Dol6Z``03o`000?o?
`/kocl;>00Oocl;>00?o0000omO0`ooG`<<02ooG`<<00ol0003oj>O?onSWc`02onSWc`03o`000?oX
iloo000000Som>Vk00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0:ooooo`005oooool0
0ol0003oooooooooo`11ooooo`;o000000?o>C:Mo`000?mBDK<02omBDK<01?l0003oIF[3ofEZ`ol0
000?oh9a]`03o`000?n9Ol?oRGo300;oRGo300?o0000oiB1_?nDPK`02onDPK`4o`000004oiB1_?l0
003oW8Bhoib4^0Co00003?nOT<@00ol0003oYiK3ojNF``0?ojNF``03o`000?naX<Ko/J3600_o/J36
1Ol000000onbV;co0000ol6Z``0Eol6Z``03o`000?o?`/kocl;>00Wocl;>00?o0000omO0`ooG`<<0
2OoG`<<00ol0003oj>O?onSWc`03onSWc`03o`000?oXiloo000000Oom>Vk00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`11ooooo`04o`000?l0
06go>C:Mo`0000_oDU6c00?o0000ofEZ`omUJ/<00_mUJ/<00ol0003oPW6goh9a]`0;oh9a]`03o`00
0?n9Ol?oRGo300CoRGo300?o0000oiB1_?nDPK`01onDPK`3o`0000GoU86l0ol0000@oin@a003o`00
0?nWU/?oYiK300ooYiK300?o0000ok6Pa_naX<H04?naX<H2o`0001Ko`J[300?o0000olo2c_o?`/h0
2_o?`/h00ol0003oel33omO0``08omO0``03o`000?oXilooj>O?00Coj>O?00?o0000onSWcol00000
1OodjK/2o`0002oooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0@Ooo
ool00ol0003o001]o`00000<oe9A/`03o`000?mUJ/?oIF[300;oIF[300?o0000oh9a]on2LKL02_n2
LKL00ol0003oRGo3ohUo``05ohUo``03o`000?nDPKcoU86l00CoU86l0ol00006oiB1_0;o000000?o
V8k7o`000?nOT<@04?nOT<@00ol0003oYiK3ojNF``0?ojNF``03o`000?naX<Ko/J36017o/J3600Co
0000okf`cOl0003o00004_o1Z/<00ol0003ocl;>olo2cP0<olo2cP;o00001ooG`<<00ol0003oj>O?
onSWc`06onSWc`;o00001OodjK/00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo
000Gooooo`03o`000?oooooooooo047ooooo00?o0000o`00KOl000003?mBDK<00ol0003oIF[3ofEZ
``03ofEZ``03o`000?n2LKOoPW6g00SoPW6g00?o0000ohUo`on9Ol<01on9Ol<00ol0003oU86loiB1
_003o`0000SoU86l00?o0000oiR>aonHS/L00_nHS/L00ol0003oWi34oin@a00>oin@a003o`000?nW
U/?oYiK300ooYiK300?o0000ok6Pa_naX<H04?naX<H00ol0003o_K3=okf`c@02okf`c@;o00003oo1
Z/<00ol0003ocl;>olo2cP0?olo2cP03o`000?oG`<?oel3300?oel3300?o0000onSWcooXill02?oX
ill00ol0003om>VkooCY^`02ooCY^`;o0000<Oooool00ol0003oooooooooo`09ooooo`005oooool0
0ol0003oooooooooo`11ooooo`04o`000?l006go0000o`0000[oDU6c00?o0000ofEZ`omUJ/<01OmU
J/<00ol0003oPW6goh9a]`06oh9a]`03o`000?n9Ol?oRGo300OoRGo31?l00009oiB1_0;o00001OnH
S/L00ol0003oWi34oin@a00>oin@a003o`000?nWU/?oYiK300ooYiK300?o0000ok6Pa_naX<H04?na
X<H00ol0003o_K3=okf`c@04okf`c@;o00003Oo1Z/<00ol0003ocl;>olo2cP0@olo2cP05o`000?oG
`<?oel33omO0`ol000003?oXill00ol0003om>VkooCY^`02o`0003;ooooo00?o0000ooooooooool0
2Oooool001Oooooo00?o0000ooooooooool0@Oooool01Ol0003o001]o`00KOl08Jco000000WoDU6c
00?o0000ofEZ`omUJ/<01_mUJ/<00ol0003oPW6goh9a]`04oh9a]`03o`000?n9Ol?oRGo300GoRGo3
0ol00002ohUo``03o`000?nDPKcoU86l00KoU86l0_l00008oiR>a`03o`000?nOT<CoWi3400koWi34
00?o0000ojNF`onWU/<03OnWU/<00ol0003o/J36ok6PaP0@ok6PaP03o`000?nm/<go_K3=00Oo_K3=
0ol00009ol6Z``03o`000?o?`/kocl;>01;ocl;>00?o0000omO0`ol000003OoXill00ol0003om>Vk
ooCY^`02o`0003;ooooo00?o0000ooooooooool02Oooool001Oooooo0_l00013ooooo`05o`000?l0
06go0000o`0Q[?l000001omBDK<00ol0003oIF[3ofEZ``07ofEZ``03o`000?n2LKOoPW6g00?oPW6g
00?o0000ohUo`on9Ol<00on9Ol<3o`0000KoRGo300?o0000oiB1_?nDPK`00onDPK`2o`0000[oV8k7
00?o0000oin@a?nOT<@03_nOT<@00ol0003oYiK3ojNF``0=ojNF``03o`000?naX<Ko/J36013o/J36
00?o0000okf`cOnm/<d02_nm/<d2o`0000Ko`J[300?o0000olo2c_o?`/h05?o?`/h00ol0003oj>O?
onSWc`0<onSWc`Co0000<oooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003ooooooooo
o`13ooooo`05o`000?l006go0000o`0Q[?l000001omBDK<00ol0003oIF[3ofEZ``08ofEZ``05o`00
0?n2LKOoPW6goh9a]ol000000on9Ol<3o`0000WoRGo300?o0000oiB1_?nDPK`00_nDPK`00ol0003o
V8k7oiR>a`0:oiR>a`03o`000?nOT<CoWi3400koWi3400?o0000ojNF`onWU/<03OnWU/<00ol0003o
/J36ok6PaP0@ok6PaP03o`000?nm/<go_K3=00co_K3=0_l00004ol6Z``03o`000?o?`/kocl;>01?o
cl;>0_l0000?onSWc`;o0000=?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?l006go000000;o026/00?o0000oe9A/omBDK<00omBDK<00ol0003oIF[3
ofEZ``0:ofEZ``03o`000?n2LKOo000000Co00003On9Ol<01?l0003oU86lo`000?l0000>oiR>a`03
o`000?nOT<CoWi3400goWi3400?o0000ojNF`onWU/<03OnWU/<00ol0003o/J36ok6PaP0?ok6PaP03
o`000?nm/<go_K3=00oo_K3=0_l000000oo1Z/?o0000olo2cP0Dolo2cP04o`000?oKi=cofnCLo`00
00goj>O?1?l0000cooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04?o
oooo00?o0000o`00KOl000000ol08J`00ol0003oDU6coe9A/`02oe9A/`03o`000?mUJ/?oIF[300[o
IF[30ol0000BohUo``03o`000?nHS/OoV8k700koV8k700?o0000oin@a?nOT<@03OnOT<@00ol0003o
YiK3ojNF``0=ojNF``03o`000?naX<Ko/J3600oo/J3600?o0000okf`cOnm/<d04Onm/<d2o`0001Co
cl;>00Go0000om_Tg?oKi=cofnCLo`00000<onSWc`?o00000_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04Cooooo00?o0000o`00KOl0
00000_l08J`00ol0003oDU6coe9A/`02oe9A/`03o`000?mUJ/?oIF[300OoIF[30ol000000omUJ/?o
0000ohUo``0BohUo``03o`000?nHS/OoV8k700ooV8k700?o0000oin@a?nOT<@03OnOT<@00ol0003o
YiK3ojNF``0<ojNF``03o`000?naX<Ko/J3600ko/J3600?o0000okf`cOnm/<d04_nm/<d00ol0003o
alCGo`00000Bolo2cP03o`000?oKi=cofnCL00;ofnCL00?o0000onSWcooXill02OoXill01?l0003o
`?Rbo`000?l00003ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool001Ko
oooo00?o0000ooooooooool0A?ooool00ol0003o001]o`000003o`0Q[004o`000?mBDK?oDU6co`00
00OoIF[30ol00003ofEZ``03o`000?mdO/ko0000017oRGo300?o0000ohn=cOl000004?nHS/L00ol0
003oWi34oin@a00=oin@a003o`000?nWU/?oYiK300coYiK300?o0000ok6Pa_naX<H03_naX<H00ol0
003o_K3=okf`c@0Aokf`c@04o`000?o7a=OoalCGolO4e`;o00003oo?`/h00ol0003ofnCLom_Tg004
om_Tg003o`000?oXilooj>O?00Ooj>O?00Co0000ol3h/_l0003o00001?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooooooo04Cooooo00?o0000
o`00KOl000001?l08J`00ol0003oDU6co`000003ofEZ``Co00001_mUJ/<01?l0003oM7k>ogAnc_l0
000?ohUo``05o`000?n?SLgoShg=ohn=cOl000004?nHS/L00ol0003oWi34oin@a00:oin@a1Go0000
3?naX<H00ol0003o_K3=okf`c@0Aokf`c@03o`000?o7a=OoalCG00CoalCG00?o0000olo2c_o?`/h0
2oo?`/h00ol0003ofnCLom_Tg005om_Tg003o`000?oXilooj>O?00Koj>O?00Co0000ol3h/_l0003o
00001_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`00
0?oooooooooo04Kooooo0_l00005o`0Q[003o`000?mUJ/?o000000;o00002OmUJ/<00ol0003oM7k>
ogAncP02ogAncP03o`000?n9Ol?oRGo300_oRGo300?o0000ohn=cOn?SLd00on?SLd00ol0003oV8k7
oiR>a`0=oiR>a`03o`000?nOT<CoWi3400GoWi341Ol00002oj:Lc`03o`000?nXXLooZ:7?00coZ:7?
00Co0000ok2YdOn`ZM7o/:WA1Ol00007ok6PaP03o`000?nm/<go_K3=013o_K3=00?o0000olO4eoo7
a=L01_o7a=L2o`0000[ocl;>00?o0000om_Tg?oKi=`01ooKi=`00ol0003oj>O?onSWc`04onSWc`03
o`000?o0n;;o`?Rb00;o00001oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00So
oooo000Eooooo`?o0000A_ooool00ol0003o001]o`000003o`0Q[0?o00003?mUJ/<00ol0003oM7k>
ogAncP03ogAncP03o`000?n9Ol?oRGo300WoRGo300?o0000ohn=cOn?SLd01On?SLd00ol0003oV8k7
oiR>a`0<oiR>a`03o`000?nOT<CoWi3400Go00001onRW<l00ol0003oZ:7?ojRQc`0<ojRQc`03o`00
0?n`ZM7o/:WA00Ko/:WA1Ol00002ok6PaP03o`000?nm/<go_K3=00oo_K3=00?o0000olO4eoo7a=L0
2Oo7a=L00ol0003ocl;>olo2cP06olo2cP03o`000?oKi=cofnCL00SofnCL00?o0000onSWcooXill0
0ooXill00ol0003o`?Rbol3h/P02o`0000Wooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`08ooooo`005Oooool00ol0003oooooooooo`17ooooo`Go000000Co026/o`000?lRElko0000
2omUJ/<00ol0003oM7k>ogAncP04ogAncP03o`000?n9Ol?oRGo300OoRGo300?o0000ohn=cOn?SLd0
1on?SLd00ol0003oV8k7oiR>a`0;oiR>a`?o00003OnRW<l00ol0003oZ:7?ojRQc`0;ojRQc`03o`00
0?n`ZM7o/:WA00_o/:WA0_l0000Aokf`c@03o`000?o7a=OoalCG00_oalCG00?o0000olo2c_o?`/h0
1?o?`/h00ol0003ofnCLom_Tg00:om_Tg005o`000?oXilooj>O?onSWcol000000oo0n;800ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool001Gooooo
00?o0000ooooooooool0AOooool4o`0000Go026/0_lRElh00ol0003oIF[3ofEZ``07ofEZ``03o`00
0?mdO/koM7k>00KoM7k>00?o0000ohUo`on9Ol<01On9Ol<00ol0003oShg=ohn=c@08ohn=c@03o`00
0?nHS/OoV8k700WoV8k70_l000000onLVm;o0000oj:Lc`0=oj:Lc`03o`000?nXXLooZ:7?00[oZ:7?
00?o0000ok2YdOn`ZM403On`ZM401?l0003o^;GGo`000?l0000>okf`c@03o`000?o7a=OoalCG00co
alCG0_l00003olo2cP03o`000?oKi=cofnCL00_ofnCL00Co0000onSWcooXiloo00000oo0n;800ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool001Go
oooo00?o0000ooooooooool0@_ooool3o`0000?ooooo00?o0000o`0Q[?l08J`00ol08J`01?l0003o
8UO>ob9Gc_l00008ofEZ``03o`000?mdO/koM7k>00OoM7k>00?o0000ohUo`on9Ol<00on9Ol<00ol0
003oShg=ohn=c@0:ohn=c@03o`000?nHS/OoV8k700OoV8k700?o0000oibKd_nLVm800_nLVm800ol0
003oXYc?oj:Lc`0;oj:Lc`03o`000?nXXLooZ:7?00[oZ:7?00?o0000ok2YdOn`ZM403?n`ZM400ol0
003o^;GGokRee`02okRee`;o00002onm/<d00ol0003oalCGolO4e`0?olO4e`03o`000?o?`/ko0000
00kofnCL00?o0000onSWcol000000oo0n;82o`0000gooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`07ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00001_ooool00ol0003o
026/o`0Q[003o`0Q[005o`000?lRElko8UO>ob9Gc_l000001_mUJ/<00ol0003oM7k>ogAncP09ogAn
cP05o`000?n9Ol?oRGo3ohUo`ol000003_n?SLd00ol0003oV8k7oiR>a`04oiR>a`;o00001_nLVm80
0ol0003oXYc?oj:Lc`0:oj:Lc`03o`000?nXXLooZ:7?00[oZ:7?00?o0000ok2YdOn`ZM403?n`ZM40
0ol0003o^;GGokRee`04okRee`?o00001onm/<d00ol0003oalCGolO4e`0AolO4e`03o`000?oKi=co
fnCL00kofnCL00?o0000ol3h/_o0n;800_o0n;800ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0?Oooool3o`00
00Wooooo0_l00004o`0Q[003o`000?lRElko8UO>00;o8UO>00?o0000ofEZ`omUJ/<00omUJ/<00ol0
003oM7k>ogAncP0:ogAncP03o`000?n9Ol?o0000013oShg=00Co0000oiR>aonHS/OoV8k70_l00008
oibKdP03o`000?nRW<ooXYc?00[oXYc?00?o0000ojRQconXXLl02_nXXLl00ol0003o/:WAok2Yd@0;
ok2Yd@03o`000?nh]MOo^;GG00So^;GG0_l00004okf`c@03o`000?o7a=OoalCG013oalCG00?o0000
olkOiOl000003_oKi=`00ol0003oaooJo`000003ol3h/P03o`000?oooooooooo00oooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0ioooo
o`Co00003Oooool00ol0003o026/o`0Q[003o`0Q[003o`000?lRElko8UO>00;o8UO>00Go0000ofEZ
`omUJ/?oIF[3o`00000>ogAncP;o00004On?SLd00ol0003oV8k7o`00000;oibKdP03o`000?nRW<oo
XYc?00[oXYc?00?o0000ojRQconXXLl02OnXXLl00ol0003o/:WAok2Yd@0;ok2Yd@03o`000?nh]MOo
^;GG00[o^;GG0_l000000onm/<go0000olO4e`0@olO4e`;o00000oo>gnD00ol0003ofnCLom_Tg00:
om_Tg003o`000?o7om[o000000?o`?Rb00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Kooooo0ol0000Aoooo
o`03o`000?l08Jco026/00?o026/00?o0000ob9Gc_lRElh00olRElh01?l0003oIF[3ofEZ`ol0000>
ogAncP;oPHoH00?o0000ohn=cOn?SLd03on?SLd00ol0003oW9_BoibKdP0:oibKdP03o`000?nRW<oo
XYc?00[oXYc?00?o0000ojRQconXXLl02OnXXLl00ol0003o/:WAok2Yd@0:ok2Yd@03o`000?nh]MOo
^;GG00go^;GG00?o0000olO4eoo7a=L03oo7a=L00ol0003oc]oUolkOi@03olkOi@03o`000?oKi=co
fnCL00SofnCL0_l00002olOofP04o`000?o0n;;o`?Rbo`0001Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Eooooo`03o`000?l08Jco
026/00;o026/00?o0000ob9Gc_lRElh01?lRElh00ol0003oIF[3o`00000=ogAncP05o`000?n1SmSo
PHoHoh6?f?l000003on?SLd00ol0003oUYcGo`00000<oibKdP03o`000?nRW<ooXYc?00WoXYc?00?o
0000ojRQconXXLl02OnXXLl00ol0003o/:WAok2Yd@0:ok2Yd@03o`000?nh]MOo^;GG00co^;GG00Co
0000okk6gonna]oo00003_o7a=L00ol0003oc]oUolkOi@04olkOi@03o`000?oKi=cofnCL00OofnCL
00Go0000olOof_o7om[oaooJo`000002ol3h/P03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o0000
6Oooool01Ol0003o026/o`0Q[?l08Jco000000Oo8UO>0_l0000=ogAncP03o`000?n1SmSoPHoH00;o
PHoH0_l0000<ohn=c@05o`000?nFW=OoUYcGoiJLeol000003?nLVm800ol0003oXYc?oj:Lc`08oj:L
c`03o`000?nXXLooZ:7?00SoZ:7?00?o0000ok2YdOn`ZM402on`ZM400ol0003o^;GGokRee`0;okRe
e`03o`000?nna]oo_/KO00;o_/KO00?o0000olO4eoo7a=L02Oo7a=L2o`0000Soc]oU00?o0000om_T
g?oKi=`01OoKi=`00ol0003oaooJolOofP02olOofP03o`000?o0n;;o000001Sooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0;?ooool4o`0001gooooo00Co0000o`0Q[?l08Jco00001olRElh2od]k
g`03o`000?mdO/koM7k>00[oM7k>00?o0000oh6?f?n1SmP01?n1SmP00ol0003oShg=ohn=c@08ohn=
c@03o`000?nFW=OoUYcG00?oUYcG00?o0000oibKd_nLVm802OnLVm800ol0003oXYc?oj:Lc`08oj:L
c`03o`000?nXXLooZ:7?00SoZ:7?00?o0000ok2YdOn`ZM402_n`ZM400ol0003o^;GGokRee`0;okRe
e`03o`000?nna]oo_/KO00Co_/KO0_l00008olO4e`03o`000?o>gnGoc]oU00Soc]oU00?o0000om_T
g?oKi=`01?oKi=`00ol0003oaooJolOofP02olOofP03o`000?o0n;;o000001[ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02[ooooo0ol0000Rooooo`04o`000?l08Jco026/o`0000Ko8UO>00Co0000od]k
gom;Nmoo00002_mdO/h00ol0003oPHoHoh6?f006oh6?f003o`000?n?SLgoShg=00KoShg=00?o0000
oiJLeonFW=L01OnFW=L00ol0003oW9_BoibKdP09oibKdP03o`000?nRW<ooXYc?00SoXYc?00?o0000
ojRQconXXLl01onXXLl00ol0003o/:WAok2Yd@0:ok2Yd@03o`000?nh]MOo^;GG00[o^;GG00?o0000
okk6gonna]l01onna]l00ol0003oalCGolO4e`03olO4e`;o00003?o>gnD01?l0003ofnCLom_Tg?oK
i=`2o`0000GoaooJ0_l0000Looooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_oo
ool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool0
1?l0003o026/o`0Q[?l00007ob9GcP03o`000?m;NmooBg_O00;o00002?mdO/h00ol0003oPHoHoh6?
f007oh6?f0;o00001On?SLd00ol0003oUYcGoiJLe`07oiJLe`03o`000?nLVm;oW9_B00SoW9_B00?o
0000oj:LconRW<l01_nRW<l@o`0000So/:WA00?o0000okReeonh]ML02_nh]ML00ol0003o_/KOokk6
g`09okk6g`05o`000?o7a=OoalCGolO4eol000003_o>gnD01?l0003ofnCLom_Tg?l00006olOofP;o
00007_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09?ooool3o`0002Wooooo00?o0000o`0Q[?l00000
1olRElh00ol0003oBg_Ood]kg`02od]kg`03o`000?mdO/koM7k>00GoM7k>00?o0000oh6?f?n1SmP0
2On1SmP01Ol0003oShg=ohn=cOn?SLgo000000_oUYcG00?o0000oibKd_nLVm802?nLVm800ol0003o
XYc?oj:Lc`05o`0000;oXj_L00?o0000ojN^g?nW[]`01onW[]`01?l0003o[;?MojbcgOn//md5o`00
00?o/:WA00?o0000okReeonh]ML02Onh]ML00ol0003o_/KOokk6g`0;okk6g`03o`000?o7a=Oo0000
00ooc]oU00?o0000om_Tg?l000001oo7omX00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Pooooo`Co0000;Oooool2o`0000Oo8UO>00?o0000od]kgom;Nml00om;Nml00ol0003o
M7k>ogAncP03ogAncP03o`000?n1SmSoPHoH00_oPHoH00?o0000ohn=cOl000003OnFW=L00ol0003o
W9_BoibKdP07oibKdP?o00002?nSZm`00ol0003oYjkLojN^g006ojN^g003o`000?n//mgo[;?M00Ko
[;?M1?l0000:okRee`03o`000?nna]oo_/KO00go_/KO00?o0000olkOiOo>gnD03oo>gnD00ol0003o
aooJolOofP05olOofP03o`000?oooooooooo01oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo
0ol0000booooo`03o`0Q[?l0003o8UO>00Go8UO>00?o0000od]kgom;Nml01?m;Nml2o`0000?oM7k>
00?o0000oh6?f?n1SmP03?n1SmP2o`0000koUYcG00?o0000oibKd_nLVm801?nLVm82o`000003oinZ
g_l0003oXj_L00SoXj_L00?o0000ojN^g?nW[]`01_nW[]`00ol0003o[;?Mojbcg@08ojbcg@04o`00
0?na^n7o0000o`0000Oo^;GG00?o0000okk6gonna]l03?nna]l00ol0003o`MW[o`00000>olkOi@;o
000000?o`_O]o`000?o7omX01?o7omX00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Jooooo`?o0000=_ooool2o`0000Go8UO>00?o0000od]kgom;Nml01_m;Nml01?l0003oM7k>
ogAnc_l0000>oh6?f0;oS9oP0_l0000=oiJLe`03o`000?nLVm;oW9_B00;oW9_B00?o0000oinZg_nO
Z]h00_nOZ]h00ol0003oXj_Loj>[g006oj>[g003o`000?nW[]coYjkL00KoYjkL00?o0000ojbcgOn/
/md01on//md00ol0003o/K_Qok6kh@02ok6kh@;o00001?nh]ML00ol0003o_/KOokk6g`0;okk6g`;o
00000oo1fN/00ol0003oc]oUolkOi@09olkOi@;o00000_o2mnd00ol0003oaooJolOofP03olOofP03
o`000?oooooooooo02Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`00
2_ooool00omEEEGoIVIVo`000006ooooo`;o00006?ooool3o`0003_ooooo00?o0000ob9Gc_lRElh0
0olRElh00ol0003oBg_Ood]kg`06od]kg`;o00003_n1SmP00ol0003oS9oPohbOh002ohbOh003o`00
0?nFW=OoUYcG00_oUYcG00Co0000oibKd_l0003o00001_nOZ]h00ol0003oXj_Loj>[g006oj>[g003
o`000?nW[]coYjkL00GoYjkL00?o0000ojbcgOn//md01_n//md00ol0003o/K_Qok6kh@05ok6kh@;o
000000?o^;GGo`000?nna]l02onna]l2o`0000Go`MW[00?o0000olkOiOo>gnD01oo>gnD2o`0000Co
`_O]00Co0000olOof_o7om[oaooJ0_l0000Xooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01_ooool001;ooooo00?o0000ooooooooool05?ooool4o`0003oooooo00?o0000ob9Gc_lR
Elh00_lRElh00ol0003oBg_Ood]kg`07od]kg`;o00003On1SmP00ol0003oS9oPohbOh003ohbOh0;o
00003?nFW=L2o`0000SoWj[N00?o0000oj>[g?nSZm`01OnSZm`00ol0003oYjkLojN^g005ojN^g003
o`000?n//mgo[;?M00Ko[;?M00?o0000ok6khOna^n401ona^n400ol0003o_/KOokk6g`0:okk6g`03
o`000?o1fN_o`MW[00Ko`MW[00?o0000olkOiOo>gnD01?o>gnD2o`0000Ko`_O]00Co0000olOof_o7
om[o0000:_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo000Booooo`03
o`000?oooooooooo017ooooo0ol00014ooooo`;o00000_lRElh00ol0003oBg_Ood]kg`07od]kg`04
o`000?mXTnSo0000o`0000_oPHoH00?o0000ohbOh?n<Wn001On<Wn02o`0000WoUYcG00Co0000oi^[
h_nKZn;o00001onOZ]h00ol0003oXj_Loj>[g005oj>[g003o`000?nW[]coYjkL00CoYjkL00?o0000
ojbcgOn//md01_n//md00ol0003o/K_Qok6kh@07ok6kh@?o]<KW0_l00007okk6g`;o00002_o1fN/0
1?l0003oc]oUolkOiOo>gnD2o`0000Oo`_O]00Co0000olOof_l0003o0000;?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0
0018ooooo`04o`0JT_l0003o8UO>o`0000WoBg_O00Co0000ofRCj?mXTnSoJ9?X0_l00008oh6?f003
o`000?n<Wn3oS9oP00SoS9oP0_l00006oiJLe`03o`000?nKZn;oVj_R00;oVj_R00?o0000oinZg_nO
Z]h01OnOZ]h00ol0003oXj_Loj>[g005oj>[g003o`000?nW[]coYjkL00?oYjkL00?o0000ojbcgOn/
/md01On//md00ol0003o/K_Qok6kh@06ok6kh@03o`000?nda^Oo]<KW00Co]<KW00?o0000okk6gonn
a]l00_nna]l2o`0000co`MW[00Co0000olkOiOl0003o00002Oo2mnd2o`0002oooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0;ooooo`?o
0000C?ooool3o`0000[oBg_O00?o0000ofRCj?mXTnP00_mXTnP3o`0000GoPHoH00?o0000ohbOh?n<
Wn002_n<Wn000ol0003oUYcGoiJLe`02oiJLe`03o`000?nKZn;oVj_R00CoVj_R0_l00006oinZgP03
o`000?nSZmcoXj_L00CoXj_L00?o0000ojN^g?nW[]`00onW[]`00ol0003o[;?Mojbcg@05ojbcg@03
o`000?na^n7o/K_Q00Go/K_Q00?o0000okC6ionda^L01_nda^L2o`000003okk6gol0003o`MW[00ko
`MW[00?o0000ol;gkOo2mnd02Oo2mnd00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01oooool4o`00053ooooo
00?o0000ob9Gc_l000002Om;Nml00ol0003oJ9?XofRCj005ofRCj0;o00000on1SmP00ol0003oS9oP
ohbOh00;ohbOh004o`000?nFW=OoUYcGo`0000WoVj_R00?o0000oinZg_nOZ]h00onOZ]h00ol0003o
Xj_Loj>[g004oj>[g003o`000?nW[]coYjkL00?oYjkL00?o0000ojbcgOn//md01?n//md00ol0003o
/K_Qok6kh@04ok6kh@;o00002onda^L00ol0003o`MW[ol7Ij`0:ol7Ij`?o000000?o^N_eo`000?o2
mnd02Oo2mnd00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool01Oooool001;ooooo00?o0000ooooooooool01?ooool3o`0005Kooooo0_l00008od]kg`03o`00
0?mXTnSoJ9?X00OoJ9?X00?o0000oh6?f?l000004?n<Wn02o`0000[oVj_R00?o0000oinZg_nOZ]h0
0onOZ]h00ol0003oXj_Loj>[g004oj>[g003o`000?nW[]coYjkL00;oYjkL00?o0000ojbcgOn//md0
1?n//md00ol0003o/K_Qok6kh@03ok6kh@03o`000?nda^Oo]<KW00Wo]<KW00?o0000okCBkol00000
2_o1fN/2o`0000Co^N_e00?o0000ol;gkOo2mnd01?o2mnd3o`0003Kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000F_oo
ool00ol06Y;o0000o`000007od]kg`03o`000?mXTnSoJ9?X00SoJ9?X0ol0000>ohbOh003o`000?nF
[^Oo000000;o00002?nKZn82o`0000CoWj[N00Co0000oj>[g?nSZmcoXj_L2ol00002ojbcg@03o`00
0?na^n7o/K_Q00?o/K_Q00?o0000okC6ionda^L01_nda^L2o`0000Go]=;_00?o0000ol7Ijoo1fN/0
1Oo1fN/2o`0000Ko^N_e00?o0000ol;gkOo2mnd00_o2mnd4o`0003Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0005kooooo00Co
01ZBo`1Xe_l0003o00001Om;Nml00ol0003oJ9?XofRCj008ofRCj003o`000?mmYNgoOJG]00?o0000
2_n<Wn000ol0003oUZkWoiJ^i`03oiJ^i`;o00002?nKZn801?l0003oWj[NoinZg_nOZ]h4o`0000;o
Xkc[00?o0000oj>mjonS_N/00_nS_N/01?l0003oYKk[ojFnjonU_^/5o`0000;o/K_Q00?o0000okC6
ionda^L01Onda^L2o`0000So]=;_00Co0000ol7Ijoo1fN_o`MW[0ol00007okW[m@04o`000?o2mngo
`_O]ol;gk@;o000000?oQ^[?o`000?ooool0>Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Cooooo000Aooooo`;o0000H_ooool2o`000003o`1Xe_l0003o000000?oBg_O00?o0000
ofRCj?mXTnP02OmXTnP00ol0003oOJG]ogfUk@02ogfUk@?o00001on<Wn000ol0003oUZkWoiJ^i`05
oiJ^i`;o00001onKZn800ol0003oWj[No`000003oj:lk005o`000?nS_>_oXkc[oj>ljol000000onS
_N/00ol0003oYKk[ojFnj`02ojFnj`04o`000?nW`NgoYl7]ojO1k@;o00001Onda^L3o`0000[o]=;_
00Co0000ol7Ijol0003o00002_nijoD4o`000003ohKZcol0003o000003cooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`004oooool00ol0003oooooooooo`1Pooooo`;o0000
0_l0J=H2o`000003od]kgol0003oJ9?X00[oJ9?X00?o0000ogfUkOmmYNd01OmmYNd3o`0000CoS9oP
00?o0000oiJ^ionF[^L01onF[^L3o`0000CoVj_R0ol00004oj:lk004o`000?nS_>_oXkc[o`0000?o
Xkg[00Go0000ojFnjonU_^_oYKk[o`000003ojO1k@06o`000?nXa^ooZ<K_ojS6kol0003o]<KW0_l0
000>okCBk`03o`000?nijoGo^N_e00[o^N_e00Go0000ohKZcon6j/ooQ^[?o`00000oooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01?ooool001Cooooo0_l0001Qooooo`?o00000_l0
J=H00ol0003oBg_Oo`00000:ofRCj003o`000?mmYNgoOJG]00SoOJG]0_l000000on<Wn3o0000oiJ^
i`0<oiJ^i`;o000000?oVj_Ro`000?nQ_>`00_nQ_>`2o`0000?oX[c/00Co0000oj>ljonS_>_o0000
0_nS_N/01?l0003oYKk[ojFnjol00002ojO1k@;o00001?nXa^l2o`0000[o]=;_1?l00002ojoMm`03
o`000?nijoGo^N_e00Go^N_e0ol000001?nNl??o0000ohKZcon6j/l2o`00047ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooo`00001Pooooo`03
o`0JT_l0003o06SF00;o06SF0ol00009ofRCj003o`000?mmYNgoOJG]00[oOJG]1?l0000<oiJ^i`?o
00001?nQ_>`2o`0000;oX[c/00Go0000oj>ljol0003oXkg[o`000002ojFnj`04o`000?nW`Ngo0000
o`0000?oZ<K_0ol000000onWbo;o0000okCBk`05okCBk`Co00001_n_gOL01?l0003o^N_eokW[mOni
joD4o`0000?oW_3c00Co0000ohKZcol0003o0000@oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo000Gooooo`;o0000HOooool2o`0000Co06SF00Co>YKbo`000?l0003o0000
1_mXTnP00ol0003oOJG]ogfUk@0:ogfUk@04o`000?n>/o3oS[?`ohjcl0Go00001onF[^L00ol0003o
W[g^oijmkP04o`0000;oXKc/0_l000001OnR_>co0000o`000?nS_N_o000000;oYKk[0_l00002ojS6
k`?o00001OnWbo800ol0003o]=;_o`000003o`0000Wo[mgg00?o0000okW[mOl000000_l00006oik`
l`?o0000A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o
0000HOooool2o`0000Co06SF00?o0000ocZFl_ljU_800ol00003ofRCj003o`000?mmYNgoOJG]00_o
OJG]00?o0000ohjcl?n>/o001On>/o05o`000003oiJ^iol0003oW[g^00KoW[g^0ol000000onQ_>co
0000o`000003o`000003ojFnjol0003o000000?o00001?nWbo86o`0000go[mgg0_l00008oik`l`;o
0000BOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`00
0?oooooooooo063ooooo00?o0000o`1Xe_l0J=H00_l0J=H00ol0003o>YKbocZFlP02ocZFlP?o0000
00?oJ9?Xo`000?mmYNd02ommYNd00ol0003oS[?`ohjcl00:ohjcl0[o00000_nN_Nh@o`0000CoYLof
00Co0000ojoMmon_gOOo[mgg1ol00003oj?So003o`000?nNl??oW_3c00OoW_3c0_l0001;ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool001_ooooo0_l000000ooooooo0000
ooooo`1Nooooo`03o`000?l0J=Ko06SF00;o06SF00?o0000ocZFl_ljU_801?ljU_86o`0000SoOJG]
00?o0000ohjcl?n>/o002on>/o000ol0003oVkoaoi^ol@06oi^olA[o00002OnSho`00ol0003oW_3c
oik`l`04oik`l`;o000000?oW_3co`000?ooool0COooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00?ooooo000Mooooo`;o0000H?ooool2o`0000?o06SF00?o0000ocZFl_ljU_801_lj
U_800ol0003oIjkiofN^n@07o`0000;oOJG]00?o0000ohjcl?n>/o002on>/o001?l0003oVkoaoi^o
lOnK_o4:o`000003oiW=n_l0003o000000Wo00000onQdOP00ol0003oXn?loj?So00:oj?So003o`00
0?nNl??o000000Oo0000D?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
000Nooooo`03o`000?oooooooooo063ooooo0_l00002o`1XeP03o`000?ljU_;o>YKb00Ko>YKb00?o
0000ofN^nOmW[_T01_mW[_TDo`0000CoVL?e1?l00002oiW=nP;o000000CoW=3jo`000?nMdO[oWM7j
0_l00004oikAnPgo00000_nSho`3o`0000?oLn;Q0_l0001Dooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00oooool001oooooo0_l0001Rooooo`;o000000?o06SFo`000?ljU_801olj
U_82o`0000[oIjki00?o0000ohBln?n4_?P02on4_?P00ol0003oVL?eoiW3m@03o`000003oiS8n?l0
003oVLgj00;oVLgj00?o0000oi_@n_l000000_nLd?X01?l0003oWM7joigAn_nMdOX3o`000003oikA
n_l0003oUNCm00[oUNCm0_l00004og?Rh@?o0000Eoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo06;ooooo0_l00009ocZFlP03o`000?mW
[_WoIjki00SoIjki00?o0000ohBln?n4_?P02on4_?P3o`000003oiS8n?l0003o000000CoVLgj00Co
0000oi_@n_nKd?[o00000_nLd?X00ol0003oWM7joigAnP02oigAnPOo00001OnEi?d2o`000003og?R
hOl0003o000000?o0000Foooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo
000Rooooo`?o0000Hoooool7o`0000?o>YKb00?o0000ofN^nOmW[_T02?mW[_T01?l0003oQ;chohBl
n?n4_?P6o`0000KoNlGn1?l00002oiW=nP05o`000?nKd?[oVm3joi_@n_l000000onLd?X01?l0003o
WM7jo`000?l00007ohSQo0[o0000Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo000Tooooo`03o`000?oooooooooo06Cooooo1?l0Pld>o`000004ofN^nOl0003o0000o`00
00WoNlGn0_l00005ogK?o`ko00001on8hO`6o`0006Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`009Oooool2o`0006Sooooo00?o0000o`23cOl0Pld00ol0Pld2o`0000Wo
B;Ch0ol00006og_5oP03o`000?mfcoooM/oo00KoM/oo00?o0000ogOFoOmge_d00_mge_d00ol0003o
O]clogkLo005ogkLo0;o00000_n8hO`5o`0006Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`02ooooo`009oooool00ol0003oooooooooo`1Wooooo`?o00001?l0Pld3o`0000SoB;Ch
0ol000000omkaOko0000o`000008ogK?o`03o`000?mge_goMmKm00?oMmKm00?o0000ogkLo?mng?`0
1_mng?`4o`0006gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00:?oo
ool00ol0003oooooo`00001Vooooo`03o`000?oooooooooo00;ooooo0_l00003o`23c@?o00001?m8
]?P2o`0000;oB;Ch00?o0000ogK?ool000000ol00004ogK?o`03o`000?mge_goMmKm00GoMmKm00?o
0000ogkLo?mng?`01Ol0001booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_oo
ool001kooooo1?l000000ol@413oooooooooo`04ooooo`;o0000I_ooool00ol0003oooooooooo`08
ooooo`03o`000?l0Plgo000000?o00002_l[/Ml?o`0007Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool04_ooool7o`0000Go8Jk4P_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo000Eooooo`Ko00001Oooool00ol0003oooooooooo`09ooooo`;o
0000Hoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool0023ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00001Pooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`008?oo
ool00ol0003oooooooooo`0<ooooo`;o0000H?ooool00ol0003oooooooooo`2Rooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03Oooool2
o`0005oooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo007ooooo000Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool001ko
oooo00?oEEEEofIVI_l000004_ooool2o`000003ooooool0003ooooo05Sooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000eooooo`;o0000
FOooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0Oooool003Kooooo0_l0001Hooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`00>?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o
0000ooooooooool0Z?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000i
ooooo`04o`000?ooooooooooo`0005?ooooo00?o0000ooooooooool0ZOooool00ol0003ooooooooo
o`09ooooo`7o00000Oooool1ooooo`00>_ooool3o`0005?ooooo00?o0000ooooooooool0Z_ooool0
0ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00??ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool003go
oooo0_l0001Aooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool01oooool1o`00007o
oooo0Oooool003oooooo00?o0000ooooool00000C_ooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0010ooooo`;o0000C_ooool00ol0003ooooooooo
o`2]ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0011ooooo`;o0000COooool0
0ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0013oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`05oooo
o`7o00000Oooool004Cooooo0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:oo
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0016ooooo`;o0000B?ooool00ol0003ooooo
ooooo`2`ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00<_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000Aoooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00<_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;oooooo`0004Kooooo00?o0000oooo
ooooool0/_ooool01Ol0003ooooooooooooooooo0000007ooooo000Zooooo`Ko00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ol00013ooooo`03o`000?oooooo
oooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00
000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`2cooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo007o0000000booooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`08ooooo`;o0000@?ooool00ol0003oooooooooo`2eooooo`7o
00000Oooool1o`000000<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool02_ooool2o`0003kooooo00?o0000ooooooooool0]_ooool2o`000000<_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o0000?Oooool00ol0003oooooooooo`2eooooo`?o
0000001Cooooo`05o`000?ooooooooooooooool00000>?ooool00ol0003oooooooooo`2`ooooo`Go
00000oooool005Cooooo00Co0000oooooooooooo0000>?ooool00ol0003oooooooooo`2/ooooo`Co
00002?ooool005Gooooo0ol0000hooooo`03o`000?oooooooooo0:Sooooo1?l0000<ooooo`00Eooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:Cooooo1Ol0000@ooooo`00F?ooool2
o`0003Gooooo00?o0000ooooooooool0X?ooool4o`0001Gooooo001Jooooo`03o`000?oooooo0000
03;ooooo00?o0000ooooooooool0W?ooool4o`0001Wooooo001Kooooo`;o0000<_ooool00ol0003o
ooooooooo`2Gooooo`Go00007Oooool005gooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2Cooooo`Co00008_ooool005kooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooo
ooooo`2>ooooo`Go00009_ooool005oooooo0ol0000]ooooo`03o`000?oooooooooo08[ooooo1?l0
000[ooooo`00HOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000_
ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0000[ooooo`03o`000?oooooo
oooo087ooooo1Ol0000cooooo`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooool00000:?ooool00ol0003oooooooooo`1mooooo`Co0000>?ooool005?ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`;o0000:?ooool00ol0003oooooooooo`1iooooo`Co0000??ooool0
05?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0M?ooool5o`00043ooooo001Cooooo`05o`000?ooooooooooooooool000004?ooool0
1?l0003oooooooooool0000Sooooo`03o`000?oooooooooo073ooooo1?l00015ooooo`00Doooool0
1Ol@413ooooooooooooooooo410@017ooooo0ol0000Sooooo`03o`000?oooooooooo06_ooooo1Ol0
0019ooooo`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo0_l0000Sooooo`03o`000?oo
oooooooo06Oooooo1?l0001>ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l0
00000ooooooo0000ooooo`0Nooooo`03o`000?oooooooooo06?ooooo1?l0001Booooo`00K_ooool2
o`0001oooooo00?o0000ooooooooool0G_ooool5o`0005Kooooo001_ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0F_ooool4o`0005_ooooo001`ooooo`;o00007Oooool00ol0003o
ooooooooo`1Fooooo`Co0000Goooool007;ooooo00?o0000ooooool000006_ooool00ol0003ooooo
ooooo`1Aooooo`Go0000Hoooool007?ooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0
001Xooooo`00MOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001/
ooooo`00M_ooool2o`000003ooooool0003ooooo01Cooooo00?o0000ooooooooool0A?ooool5o`00
073ooooo001hooooo`;o00005Oooool00ol0003oooooooooo`10ooooo`Co0000MOooool007Wooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`Go0000NOooool007[ooooo0_l0
00000ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0001nooooo`00Hoooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
0oooool2o`00017ooooo00?o0000ooooooooool0<oooool4o`0008;ooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool2o`0000oooooo
00?o0000ooooooooool0;oooool5o`0008Kooooo001Sooooo`05oa0@4?ooooooooooooooool@4100
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
:oooool4o`0008_ooooo001Sooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`06ooooo`?o00002oooool00ol0003oooooooooo`0Wooooo`Co0000Soooool006?ooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1Ol0002Cooooo`00Hoooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo01kooooo1?l0002Hooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool03Oooool3o`0000Oooooo00?o0000ooooooooool06Oooool5o`00
09cooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000XOooool008Oooooo0_l00005ooooo`03
o`000?oooooooooo017ooooo1?l0002Uooooo`00ROooool2o`0000?ooooo00?o0000ooooooooool0
3?ooool5o`000:Wooooo002:ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:kooooo
002;ooooo`;o000000?oooooo`000?ooool01Oooool4o`000;;ooooo002=ooooo`;o000000?ooooo
o`000?l000000ol0002fooooo`00S_ooool2o`000;_ooooo003oooooodcooooo003oooooodcooooo
0024ooooo`Co000000?o410@ooooooooool0`?ooool008Kooooo00?o0000ooooooooool0`_ooool0
08Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo
00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000
ooooooooool0`_ooool008Cooooo00?oEEEEofIVI_l00000a?ooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.4418 .49933 m .42537 .53731 L .48342 .55337 L p .733 .614 .725 r
F P
0 g
s
.48342 .55337 m .48985 .51411 L .4418 .49933 L p .733 .614 .725 r
F P
0 g
s
.47824 .59207 m .48342 .55337 L .42537 .53731 L p .734 .59 .694 r
F P
0 g
s
.48985 .51411 m .48342 .55337 L .54044 .55689 L p .702 .579 .714 r
F P
0 g
s
.48342 .55337 m .47824 .59207 L .54201 .59478 L p .699 .551 .683 r
F P
0 g
s
.54201 .59478 m .54044 .55689 L .48342 .55337 L p .699 .551 .683 r
F P
0 g
s
.54044 .55689 m .53843 .51773 L .48985 .51411 L p .702 .579 .714 r
F P
0 g
s
.53843 .51773 m .54044 .55689 L .59559 .54834 L p .674 .559 .717 r
F P
0 g
s
.54044 .55689 m .54201 .59478 L .60351 .58576 L p .67 .53 .685 r
F P
0 g
s
.60351 .58576 m .59559 .54834 L .54044 .55689 L p .67 .53 .685 r
F P
0 g
s
.46047 .46311 m .4418 .49933 L .48985 .51411 L p .729 .639 .758 r
F P
0 g
s
.48985 .51411 m .4975 .47517 L .46047 .46311 L p .729 .639 .758 r
F P
0 g
s
.4975 .47517 m .48985 .51411 L .53843 .51773 L p .703 .608 .748 r
F P
0 g
s
.42537 .53731 m .41147 .5763 L .47824 .59207 L p .734 .59 .694 r
F P
0 g
s
.47428 .62957 m .47824 .59207 L .41147 .5763 L p .734 .565 .663 r
F P
0 g
s
.47824 .59207 m .47428 .62957 L .54318 .63084 L p .694 .524 .653 r
F P
0 g
s
.54318 .63084 m .54201 .59478 L .47824 .59207 L p .694 .524 .653 r
F P
0 g
s
.53843 .51773 m .53596 .47826 L .4975 .47517 L p .703 .608 .748 r
F P
0 g
s
.53596 .47826 m .53843 .51773 L .58553 .51011 L p .678 .59 .75 r
F P
0 g
s
.59559 .54834 m .58553 .51011 L .53843 .51773 L p .674 .559 .717 r
F P
0 g
s
.39885 .47427 m .37162 .50866 L .42537 .53731 L p .768 .665 .749 r
F P
0 g
s
.42537 .53731 m .4418 .49933 L .39885 .47427 L p .768 .665 .749 r
F P
0 g
s
.41147 .5763 m .42537 .53731 L .37162 .50866 L p .777 .647 .718 r
F P
0 g
s
.54201 .59478 m .54318 .63084 L .60942 .62177 L p .666 .503 .655 r
F P
0 g
s
.60942 .62177 m .60351 .58576 L .54201 .59478 L p .666 .503 .655 r
F P
0 g
s
.37162 .50866 m .34762 .54594 L .41147 .5763 L p .777 .647 .718 r
F P
0 g
s
.40034 .61556 m .41147 .5763 L .34762 .54594 L p .786 .628 .685 r
F P
0 g
s
.41147 .5763 m .40034 .61556 L .47428 .62957 L p .734 .565 .663 r
F P
0 g
s
.42851 .44327 m .39885 .47427 L .4418 .49933 L p .755 .681 .78 r
F P
0 g
s
.4418 .49933 m .46047 .46311 L .42851 .44327 L p .755 .681 .78 r
F P
0 g
s
.47149 .66551 m .47428 .62957 L .40034 .61556 L p .732 .54 .632 r
F P
0 g
s
.47428 .62957 m .47149 .66551 L .54397 .66493 L p .689 .498 .623 r
F P
0 g
s
.54397 .66493 m .54318 .63084 L .47428 .62957 L p .689 .498 .623 r
F P
0 g
s
.58553 .51011 m .59559 .54834 L .64871 .52743 L p .647 .55 .731 r
F P
0 g
s
.59559 .54834 m .60351 .58576 L .66448 .56422 L p .641 .519 .699 r
F P
0 g
s
.66448 .56422 m .64871 .52743 L .59559 .54834 L p .641 .519 .699 r
F P
0 g
s
.58553 .51011 m .57333 .47203 L .53596 .47826 L p .678 .59 .75 r
F P
0 g
s
.57333 .47203 m .58553 .51011 L .62959 .49134 L p .653 .582 .763 r
F P
0 g
s
.64871 .52743 m .62959 .49134 L .58553 .51011 L p .647 .55 .731 r
F P
0 g
s
.50627 .43772 m .4975 .47517 L .53596 .47826 L p .701 .638 .783 r
F P
0 g
s
.53596 .47826 m .53306 .43983 L .50627 .43772 L p .701 .638 .783 r
F P
0 g
s
.53306 .43983 m .53596 .47826 L .57333 .47203 L p .679 .623 .785 r
F P
0 g
s
.48104 .42941 m .46047 .46311 L .4975 .47517 L p .722 .664 .792 r
F P
0 g
s
.4975 .47517 m .50627 .43772 L .48104 .42941 L p .722 .664 .792 r
F P
0 g
s
.54318 .63084 m .54397 .66493 L .61352 .65611 L p .66 .476 .624 r
F P
0 g
s
.61352 .65611 m .60942 .62177 L .54318 .63084 L p .66 .476 .624 r
F P
0 g
s
.60351 .58576 m .60942 .62177 L .67679 .601 L p .635 .489 .667 r
F P
0 g
s
.67679 .601 m .66448 .56422 L .60351 .58576 L p .635 .489 .667 r
F P
0 g
s
.34762 .54594 m .32773 .5854 L .40034 .61556 L p .786 .628 .685 r
F P
0 g
s
.39223 .65434 m .40034 .61556 L .32773 .5854 L p .792 .606 .649 r
F P
0 g
s
.40034 .61556 m .39223 .65434 L .47149 .66551 L p .732 .54 .632 r
F P
0 g
s
.57333 .47203 m .55914 .43541 L .53306 .43983 L p .679 .623 .785 r
F P
0 g
s
.55914 .43541 m .57333 .47203 L .60732 .45681 L p .658 .618 .797 r
F P
0 g
s
.62959 .49134 m .60732 .45681 L .57333 .47203 L p .653 .582 .763 r
F P
0 g
s
.45994 .41591 m .42851 .44327 L .46047 .46311 L p .74 .698 .811 r
F P
0 g
s
.46047 .46311 m .48104 .42941 L .45994 .41591 L p .74 .698 .811 r
F P
0 g
s
.46982 .6997 m .47149 .66551 L .39223 .65434 L p .729 .513 .599 r
F P
0 g
s
.47149 .66551 m .46982 .6997 L .54445 .69716 L p .683 .471 .593 r
F P
0 g
s
.54445 .69716 m .54397 .66493 L .47149 .66551 L p .683 .471 .593 r
F P
0 g
s
.60942 .62177 m .61352 .65611 L .68561 .63722 L p .628 .459 .634 r
F P
0 g
s
.68561 .63722 m .67679 .601 L .60942 .62177 L p .628 .459 .634 r
F P
0 g
s
.60732 .45681 m .62959 .49134 L .66698 .46227 L p .625 .582 .785 r
F P
0 g
s
.62959 .49134 m .64871 .52743 L .69599 .49403 L p .613 .545 .754 r
F P
0 g
s
.69599 .49403 m .66698 .46227 L .62959 .49134 L p .613 .545 .754 r
F P
0 g
s
.64871 .52743 m .66448 .56422 L .72114 .52858 L p .599 .508 .722 r
F P
0 g
s
.72114 .52858 m .69599 .49403 L .64871 .52743 L p .599 .508 .722 r
F P
0 g
s
.51596 .40309 m .50627 .43772 L .53306 .43983 L p .696 .672 .823 r
F P
0 g
s
.53306 .43983 m .52981 .40406 L .51596 .40309 L p .696 .672 .823 r
F P
0 g
s
.52981 .40406 m .53306 .43983 L .55914 .43541 L p .679 .661 .825 r
F P
0 g
s
.50313 .39902 m .48104 .42941 L .50627 .43772 L p .71 .691 .83 r
F P
0 g
s
.50627 .43772 m .51596 .40309 L .50313 .39902 L p .71 .691 .83 r
F P
0 g
s
.36793 .44165 m .33187 .46987 L .37162 .50866 L p .803 .732 .786 r
F P
0 g
s
.37162 .50866 m .39885 .47427 L .36793 .44165 L p .803 .732 .786 r
F P
0 g
s
.34762 .54594 m .37162 .50866 L .33187 .46987 L p .825 .726 .755 r
F P
0 g
s
.54397 .66493 m .54445 .69716 L .61595 .6888 L p .654 .449 .594 r
F P
0 g
s
.61595 .6888 m .61352 .65611 L .54397 .66493 L p .654 .449 .594 r
F P
0 g
s
.40616 .41807 m .36793 .44165 L .39885 .47427 L p .779 .736 .814 r
F P
0 g
s
.39885 .47427 m .42851 .44327 L .40616 .41807 L p .779 .736 .814 r
F P
0 g
s
.32773 .5854 m .31283 .62605 L .39223 .65434 L p .792 .606 .649 r
F P
0 g
s
.38731 .6919 m .39223 .65434 L .31283 .62605 L p .797 .58 .608 r
F P
0 g
s
.39223 .65434 m .38731 .6919 L .46982 .6997 L p .729 .513 .599 r
F P
0 g
s
.60732 .45681 m .5823 .42483 L .55914 .43541 L p .658 .618 .797 r
F P
0 g
s
.5823 .42483 m .60732 .45681 L .63483 .43384 L p .637 .62 .817 r
F P
0 g
s
.66698 .46227 m .63483 .43384 L .60732 .45681 L p .625 .582 .785 r
F P
0 g
s
.55914 .43541 m .54329 .40177 L .52981 .40406 L p .679 .661 .825 r
F P
0 g
s
.54329 .40177 m .55914 .43541 L .5823 .42483 L p .663 .657 .834 r
F P
0 g
s
.33187 .46987 m .29928 .50264 L .34762 .54594 L p .825 .726 .755 r
F P
0 g
s
.32773 .5854 m .34762 .54594 L .29928 .50264 L p .847 .716 .718 r
F P
0 g
s
.66448 .56422 m .67679 .601 L .74169 .56524 L p .585 .469 .688 r
F P
0 g
s
.74169 .56524 m .72114 .52858 L .66448 .56422 L p .585 .469 .688 r
F P
0 g
s
.49267 .39235 m .45994 .41591 L .48104 .42941 L p .72 .714 .844 r
F P
0 g
s
.48104 .42941 m .50313 .39902 L .49267 .39235 L p .72 .714 .844 r
F P
0 g
s
.44561 .39892 m .40616 .41807 L .42851 .44327 L p .753 .738 .839 r
F P
0 g
s
.42851 .44327 m .45994 .41591 L .44561 .39892 L p .753 .738 .839 r
F P
0 g
s
.61352 .65611 m .61595 .6888 L .69093 .67241 L p .619 .426 .599 r
F P
0 g
s
.69093 .67241 m .68561 .63722 L .61352 .65611 L p .619 .426 .599 r
F P
0 g
s
.46926 .73199 m .46982 .6997 L .38731 .6919 L p .725 .484 .562 r
F P
0 g
s
.46982 .6997 m .46926 .73199 L .54462 .72774 L p .676 .443 .561 r
F P
0 g
s
.54462 .72774 m .54445 .69716 L .46982 .6997 L p .676 .443 .561 r
F P
0 g
s
.5823 .42483 m .55506 .39644 L .54329 .40177 L p .663 .657 .834 r
F P
0 g
s
.55506 .39644 m .5823 .42483 L .60024 .40919 L p .649 .661 .849 r
F P
0 g
s
.63483 .43384 m .60024 .40919 L .5823 .42483 L p .637 .62 .817 r
F P
0 g
s
.29928 .50264 m .27168 .5395 L .32773 .5854 L p .847 .716 .718 r
F P
0 g
s
.31283 .62605 m .32773 .5854 L .27168 .5395 L p .868 .702 .674 r
F P
0 g
s
.67679 .601 m .68561 .63722 L .75692 .60318 L p .569 .428 .65 r
F P
0 g
s
.75692 .60318 m .74169 .56524 L .67679 .601 L p .569 .428 .65 r
F P
0 g
s
.48574 .38389 m .44561 .39892 L .45994 .41591 L p .724 .739 .863 r
F P
0 g
s
.45994 .41591 m .49267 .39235 L .48574 .38389 L p .724 .739 .863 r
F P
0 g
s
.54445 .69716 m .54462 .72774 L .61683 .71992 L p .647 .42 .56 r
F P
0 g
s
.61683 .71992 m .61595 .6888 L .54445 .69716 L p .647 .42 .56 r
F P
0 g
s
.31283 .62605 m .30371 .66667 L .38731 .6919 L p .797 .58 .608 r
F P
0 g
s
.38577 .72748 m .38731 .6919 L .30371 .66667 L p .799 .549 .559 r
F P
0 g
s
.38731 .6919 m .38577 .72748 L .46926 .73199 L p .725 .484 .562 r
F P
0 g
s
.52981 .40406 m .52632 .37269 L .51596 .40309 L closepath p .678 .706 .869 r
F P
0 g
s
.54329 .40177 m .52632 .37269 L .52981 .40406 L closepath p .677 .706 .869 r
F P
0 g
s
.63483 .43384 m .66698 .46227 L .69155 .4257 L p .59 .588 .818 r
F P
0 g
s
.66698 .46227 m .69599 .49403 L .72882 .45052 L p .563 .543 .79 r
F P
0 g
s
.72882 .45052 m .69155 .4257 L .66698 .46227 L p .563 .543 .79 r
F P
0 g
s
.51596 .40309 m .52632 .37269 L .50313 .39902 L closepath p .68 .709 .87 r
F P
0 g
s
.60024 .40919 m .63483 .43384 L .65184 .40572 L p .613 .63 .843 r
F P
0 g
s
.69155 .4257 m .65184 .40572 L .63483 .43384 L p .59 .588 .818 r
F P
0 g
s
.55506 .39644 m .52632 .37269 L .54329 .40177 L closepath p .675 .705 .87 r
F P
0 g
s
.69599 .49403 m .72114 .52858 L .76236 .48016 L p .534 .494 .758 r
F P
0 g
s
.76236 .48016 m .72882 .45052 L .69599 .49403 L p .534 .494 .758 r
F P
0 g
s
.50313 .39902 m .52632 .37269 L .49267 .39235 L closepath p .685 .717 .873 r
F P
0 g
s
.60024 .40919 m .56386 .3887 L .55506 .39644 L p .649 .661 .849 r
F P
0 g
s
.56386 .3887 m .60024 .40919 L .61068 .39039 L p .635 .671 .867 r
F P
0 g
s
.65184 .40572 m .61068 .39039 L .60024 .40919 L p .613 .63 .843 r
F P
0 g
s
.61595 .6888 m .61683 .71992 L .69267 .70618 L p .608 .39 .559 r
F P
0 g
s
.69267 .70618 m .69093 .67241 L .61595 .6888 L p .608 .39 .559 r
F P
0 g
s
.56386 .3887 m .52632 .37269 L .55506 .39644 L closepath p .671 .704 .873 r
F P
0 g
s
.68561 .63722 m .69093 .67241 L .76621 .64147 L p .55 .382 .606 r
F P
0 g
s
.76621 .64147 m .75692 .60318 L .68561 .63722 L p .55 .382 .606 r
F P
0 g
s
.27168 .5395 m .25067 .5795 L .31283 .62605 L p .868 .702 .674 r
F P
0 g
s
.30371 .66667 m .31283 .62605 L .25067 .5795 L p .886 .679 .617 r
F P
0 g
s
.49267 .39235 m .52632 .37269 L .48574 .38389 L closepath p .688 .729 .881 r
F P
0 g
s
.44016 .38062 m .39745 .391 L .40616 .41807 L p .756 .783 .875 r
F P
0 g
s
.40616 .41807 m .44561 .39892 L .44016 .38062 L p .756 .783 .875 r
F P
0 g
s
.36793 .44165 m .40616 .41807 L .39745 .391 L p .792 .802 .86 r
F P
0 g
s
.39745 .391 m .35572 .40628 L .36793 .44165 L p .792 .802 .86 r
F P
0 g
s
.33187 .46987 m .36793 .44165 L .35572 .40628 L p .83 .82 .839 r
F P
0 g
s
.46983 .76217 m .46926 .73199 L .38577 .72748 L p .718 .449 .518 r
F P
0 g
s
.46926 .73199 m .46983 .76217 L .54448 .75675 L p .667 .412 .524 r
F P
0 g
s
.54448 .75675 m .54462 .72774 L .46926 .73199 L p .667 .412 .524 r
F P
0 g
s
.72114 .52858 m .74169 .56524 L .79065 .51424 L p .5 .439 .72 r
F P
0 g
s
.79065 .51424 m .76236 .48016 L .72114 .52858 L p .5 .439 .72 r
F P
0 g
s
.4832 .37464 m .44016 .38062 L .44561 .39892 L p .722 .763 .885 r
F P
0 g
s
.44561 .39892 m .48574 .38389 L .4832 .37464 L p .722 .763 .885 r
F P
0 g
s
.56871 .37946 m .52632 .37269 L .56386 .3887 L closepath p .663 .706 .879 r
F P
0 g
s
.61068 .39039 m .56871 .37946 L .56386 .3887 L p .635 .671 .867 r
F P
0 g
s
.54462 .72774 m .54448 .75675 L .61608 .74948 L p .636 .386 .522 r
F P
0 g
s
.61608 .74948 m .61683 .71992 L .54462 .72774 L p .636 .386 .522 r
F P
0 g
s
.35572 .40628 m .31604 .42694 L .33187 .46987 L p .83 .82 .839 r
F P
0 g
s
.29928 .50264 m .33187 .46987 L .31604 .42694 L p .87 .836 .809 r
F P
0 g
s
.48574 .38389 m .52632 .37269 L .4832 .37464 L closepath p .688 .742 .892 r
F P
0 g
s
.30371 .66667 m .30096 .70588 L .38577 .72748 L p .799 .549 .559 r
F P
0 g
s
.38775 .76028 m .38577 .72748 L .30096 .70588 L p .797 .507 .498 r
F P
0 g
s
.38577 .72748 m .38775 .76028 L .46983 .76217 L p .718 .449 .518 r
F P
0 g
s
.56871 .37946 m .61068 .39039 L .61181 .37093 L p .621 .684 .888 r
F P
0 g
s
.61068 .39039 m .65184 .40572 L .65464 .37643 L p .584 .646 .878 r
F P
0 g
s
.65464 .37643 m .61181 .37093 L .61068 .39039 L p .584 .646 .878 r
F P
0 g
s
.56896 .36984 m .52632 .37269 L .56871 .37946 L closepath p .656 .713 .89 r
F P
0 g
s
.61181 .37093 m .56896 .36984 L .56871 .37946 L p .621 .684 .888 r
F P
0 g
s
.74169 .56524 m .75692 .60318 L .81213 .55198 L p .46 .375 .673 r
F P
0 g
s
.81213 .55198 m .79065 .51424 L .74169 .56524 L p .46 .375 .673 r
F P
0 g
s
.69093 .67241 m .69267 .70618 L .76907 .67906 L p .526 .327 .554 r
F P
0 g
s
.76907 .67906 m .76621 .64147 L .69093 .67241 L p .526 .327 .554 r
F P
0 g
s
.65184 .40572 m .69155 .4257 L .69684 .387 L p .541 .602 .864 r
F P
0 g
s
.69684 .387 m .65464 .37643 L .65184 .40572 L p .541 .602 .864 r
F P
0 g
s
.31604 .42694 m .27989 .45323 L .29928 .50264 L p .87 .836 .809 r
F P
0 g
s
.27168 .5395 m .29928 .50264 L .27989 .45323 L p .912 .847 .766 r
F P
0 g
s
.61683 .71992 m .61608 .74948 L .69071 .73807 L p .593 .346 .511 r
F P
0 g
s
.69071 .73807 m .69267 .70618 L .61683 .71992 L p .593 .346 .511 r
F P
0 g
s
.55576 .35387 m .52632 .37269 L .56449 .36098 L closepath p .651 .738 .914 r
F P
0 g
s
.4832 .37464 m .52632 .37269 L .48539 .36563 L closepath p .682 .753 .905 r
F P
0 g
s
.56449 .36098 m .52632 .37269 L .56896 .36984 L closepath p .651 .725 .903 r
F P
0 g
s
.54378 .34917 m .52632 .37269 L .55576 .35387 L closepath p .654 .75 .92 r
F P
0 g
s
.52989 .34725 m .52632 .37269 L .54378 .34917 L closepath p .658 .756 .922 r
F P
0 g
s
.51564 .34817 m .52632 .37269 L .52989 .34725 L closepath p .66 .758 .922 r
F P
0 g
s
.50256 .35178 m .52632 .37269 L .51564 .34817 L closepath p .662 .758 .922 r
F P
0 g
s
.4921 .35777 m .52632 .37269 L .50256 .35178 L closepath p .665 .759 .92 r
F P
0 g
s
.48539 .36563 m .52632 .37269 L .4921 .35777 L closepath p .673 .758 .915 r
F P
0 g
s
.25067 .5795 m .2377 .62128 L .30371 .66667 L p .886 .679 .617 r
F P
0 g
s
.30096 .70588 m .30371 .66667 L .2377 .62128 L p .901 .645 .542 r
F P
0 g
s
.44016 .38062 m .4832 .37464 L .48539 .36563 L p .714 .785 .907 r
F P
0 g
s
.69155 .4257 m .72882 .45052 L .73729 .40334 L p .488 .549 .844 r
F P
0 g
s
.73729 .40334 m .69684 .387 L .69155 .4257 L p .488 .549 .844 r
F P
0 g
s
.48539 .36563 m .4445 .36324 L .44016 .38062 L p .714 .785 .907 r
F P
0 g
s
.39745 .391 m .44016 .38062 L .4445 .36324 L p .746 .828 .915 r
F P
0 g
s
.56896 .36984 m .61181 .37093 L .60305 .35342 L p .605 .701 .911 r
F P
0 g
s
.60305 .35342 m .56449 .36098 L .56896 .36984 L p .605 .701 .911 r
F P
0 g
s
.47163 .78981 m .46983 .76217 L .38775 .76028 L p .709 .406 .462 r
F P
0 g
s
.46983 .76217 m .47163 .78981 L .544 .78398 L p .657 .373 .477 r
F P
0 g
s
.544 .78398 m .54448 .75675 L .46983 .76217 L p .657 .373 .477 r
F P
0 g
s
.54448 .75675 m .544 .78398 L .61354 .77721 L p .622 .342 .473 r
F P
0 g
s
.61354 .77721 m .61608 .74948 L .54448 .75675 L p .622 .342 .473 r
F P
0 g
s
.4445 .36324 m .48539 .36563 L .4921 .35777 L p .7 .805 .93 r
F P
0 g
s
.4445 .36324 m .4042 .36586 L .39745 .391 L p .746 .828 .915 r
F P
0 g
s
.35572 .40628 m .39745 .391 L .4042 .36586 L p .782 .874 .915 r
F P
0 g
s
.27989 .45323 m .24908 .48501 L .27168 .5395 L p .912 .847 .766 r
F P
0 g
s
.25067 .5795 m .27168 .5395 L .24908 .48501 L p .954 .85 .7 r
F P
0 g
s
.75692 .60318 m .76621 .64147 L .82539 .5922 L p .411 .297 .612 r
F P
0 g
s
.82539 .5922 m .81213 .55198 L .75692 .60318 L p .411 .297 .612 r
F P
0 g
s
.72882 .45052 m .76236 .48016 L .77442 .42594 L p .422 .481 .815 r
F P
0 g
s
.77442 .42594 m .73729 .40334 L .72882 .45052 L p .422 .481 .815 r
F P
0 g
s
.61181 .37093 m .65464 .37643 L .64169 .35053 L p .547 .672 .92 r
F P
0 g
s
.64169 .35053 m .60305 .35342 L .61181 .37093 L p .547 .672 .92 r
F P
0 g
s
.56449 .36098 m .60305 .35342 L .5854 .34 L p .589 .723 .937 r
F P
0 g
s
.5854 .34 m .55576 .35387 L .56449 .36098 L p .589 .723 .937 r
F P
0 g
s
.69267 .70618 m .69071 .73807 L .76517 .71484 L p .495 .26 .487 r
F P
0 g
s
.76517 .71484 m .76907 .67906 L .69267 .70618 L p .495 .26 .487 r
F P
0 g
s
.30096 .70588 m .30494 .74228 L .38775 .76028 L p .797 .507 .498 r
F P
0 g
s
.39335 .7895 m .38775 .76028 L .30494 .74228 L p .788 .449 .415 r
F P
0 g
s
.38775 .76028 m .39335 .7895 L .47163 .78981 L p .709 .406 .462 r
F P
0 g
s
.45808 .34858 m .4921 .35777 L .50256 .35178 L p .677 .82 .952 r
F P
0 g
s
.4921 .35777 m .45808 .34858 L .4445 .36324 L p .7 .805 .93 r
F P
0 g
s
.61608 .74948 m .61354 .77721 L .68483 .76751 L p .57 .289 .45 r
F P
0 g
s
.68483 .76751 m .69071 .73807 L .61608 .74948 L p .57 .289 .45 r
F P
0 g
s
.4042 .36586 m .36525 .37393 L .35572 .40628 L p .782 .874 .915 r
F P
0 g
s
.31604 .42694 m .35572 .40628 L .36525 .37393 L p .821 .924 .903 r
F P
0 g
s
.55576 .35387 m .5854 .34 L .5612 .33179 L p .577 .752 .96 r
F P
0 g
s
.5612 .33179 m .54378 .34917 L .55576 .35387 L p .577 .752 .96 r
F P
0 g
s
.2377 .62128 m .23385 .66313 L .30096 .70588 L p .901 .645 .542 r
F P
0 g
s
.30494 .74228 m .30096 .70588 L .23385 .66313 L p .906 .589 .435 r
F P
0 g
s
.4042 .36586 m .4445 .36324 L .45808 .34858 L p .714 .866 .954 r
F P
0 g
s
.65464 .37643 m .69684 .387 L .67976 .35305 L p .469 .629 .923 r
F P
0 g
s
.67976 .35305 m .64169 .35053 L .65464 .37643 L p .469 .629 .923 r
F P
0 g
s
.47911 .33769 m .50256 .35178 L .51564 .34817 L p .643 .824 .97 r
F P
0 g
s
.50256 .35178 m .47911 .33769 L .45808 .34858 L p .677 .82 .952 r
F P
0 g
s
.76236 .48016 m .79065 .51424 L .80628 .45493 L p .337 .391 .77 r
F P
0 g
s
.80628 .45493 m .77442 .42594 L .76236 .48016 L p .337 .391 .77 r
F P
0 g
s
.54378 .34917 m .5612 .33179 L .53342 .32894 L p .581 .784 .976 r
F P
0 g
s
.53342 .32894 m .52989 .34725 L .54378 .34917 L p .581 .784 .976 r
F P
0 g
s
.24908 .48501 m .22549 .52166 L .25067 .5795 L p .954 .85 .7 r
F P
0 g
s
.2377 .62128 m .25067 .5795 L .22549 .52166 L p .989 .833 .596 r
F P
0 g
s
.50512 .33105 m .51564 .34817 L .52989 .34725 L p .606 .811 .979 r
F P
0 g
s
.51564 .34817 m .50512 .33105 L .47911 .33769 L p .643 .824 .97 r
F P
0 g
s
.52989 .34725 m .53342 .32894 L .50512 .33105 L p .606 .811 .979 r
F P
0 g
s
.76621 .64147 m .76907 .67906 L .82935 .63339 L p .348 .197 .53 r
F P
0 g
s
.82935 .63339 m .82539 .5922 L .76621 .64147 L p .348 .197 .53 r
F P
0 g
s
.60305 .35342 m .64169 .35053 L .6147 .33166 L p .5 .708 .964 r
F P
0 g
s
.6147 .33166 m .5854 .34 L .60305 .35342 L p .5 .708 .964 r
F P
0 g
s
.47481 .8142 m .47163 .78981 L .39335 .7895 L p .692 .345 .383 r
F P
0 g
s
.47163 .78981 m .47481 .8142 L .54309 .80875 L p .64 .318 .411 r
F P
0 g
s
.54309 .80875 m .544 .78398 L .47163 .78981 L p .64 .318 .411 r
F P
0 g
s
.544 .78398 m .54309 .80875 L .6089 .80245 L p .599 .282 .403 r
F P
0 g
s
.6089 .80245 m .61354 .77721 L .544 .78398 L p .599 .282 .403 r
F P
0 g
s
.36525 .37393 m .32869 .38785 L .31604 .42694 L p .821 .924 .903 r
F P
0 g
s
.27989 .45323 m .31604 .42694 L .32869 .38785 L p .859 .97 .865 r
F P
0 g
s
.69684 .387 m .73729 .40334 L .71625 .36184 L p .357 .562 .914 r
F P
0 g
s
.71625 .36184 m .67976 .35305 L .69684 .387 L p .357 .562 .914 r
F P
0 g
s
.69071 .73807 m .68483 .76751 L .75443 .74769 L p .451 .172 .398 r
F P
0 g
s
.75443 .74769 m .76517 .71484 L .69071 .73807 L p .451 .172 .398 r
F P
0 g
s
.45808 .34858 m .42515 .34551 L .4042 .36586 L p .714 .866 .954 r
F P
0 g
s
.36525 .37393 m .4042 .36586 L .42515 .34551 L p .716 .931 .961 r
F P
0 g
s
.42515 .34551 m .45808 .34858 L .47911 .33769 L p .652 .888 .983 r
F P
0 g
s
.79065 .51424 m .81213 .55198 L .83078 .48988 L p .221 .268 .699 r
F P
0 g
s
.83078 .48988 m .80628 .45493 L .79065 .51424 L p .221 .268 .699 r
F P
0 g
s
.61354 .77721 m .6089 .80245 L .67477 .79375 L p .535 .21 .364 r
F P
0 g
s
.67477 .79375 m .68483 .76751 L .61354 .77721 L p .535 .21 .364 r
F P
0 g
s
.30494 .74228 m .31563 .77453 L .39335 .7895 L p .788 .449 .415 r
F P
0 g
s
.40263 .81427 m .39335 .7895 L .31563 .77453 L p .764 .364 .295 r
F P
0 g
s
.39335 .7895 m .40263 .81427 L .47481 .8142 L p .692 .345 .383 r
F P
0 g
s
.5854 .34 m .6147 .33166 L .57802 .32127 L p .45 .749 .993 r
F P
0 g
s
.57802 .32127 m .5612 .33179 L .5854 .34 L p .45 .749 .993 r
F P
0 g
s
.23385 .66313 m .23966 .70319 L .30494 .74228 L p .906 .589 .435 r
F P
0 g
s
.31563 .77453 m .30494 .74228 L .23966 .70319 L p .887 .494 .276 r
F P
0 g
s
.32869 .38785 m .29581 .40791 L .27989 .45323 L p .859 .97 .865 r
F P
0 g
s
.24908 .48501 m .27989 .45323 L .29581 .40791 L p .877 .993 .77 r
F P
0 g
s
.22549 .52166 m .21088 .56203 L .2377 .62128 L p .989 .833 .596 r
F P
0 g
s
.23385 .66313 m .2377 .62128 L .21088 .56203 L p .996 .774 .425 r
F P
0 g
s
.64169 .35053 m .67976 .35305 L .64298 .32948 L p .354 .661 .972 r
F P
0 g
s
.64298 .32948 m .6147 .33166 L .64169 .35053 L p .354 .661 .972 r
F P
0 g
s
.76907 .67906 m .76517 .71484 L .82348 .67381 L p .263 .065 .413 r
F P
0 g
s
.82348 .67381 m .82935 .63339 L .76907 .67906 L p .263 .065 .413 r
F P
0 g
s
.45684 .33103 m .47911 .33769 L .50512 .33105 L p .558 .877 .993 r
F P
0 g
s
.47911 .33769 m .45684 .33103 L .42515 .34551 L p .652 .888 .983 r
F P
0 g
s
.73729 .40334 m .77442 .42594 L .74971 .37763 L p .19 .449 .875 r
F P
0 g
s
.74971 .37763 m .71625 .36184 L .73729 .40334 L p .19 .449 .875 r
F P
0 g
s
.5612 .33179 m .57802 .32127 L .53677 .31861 L p .425 .791 .995 r
F P
0 g
s
.53677 .31861 m .53342 .32894 L .5612 .33179 L p .425 .791 .995 r
F P
0 g
s
.42515 .34551 m .39419 .34884 L .36525 .37393 L p .716 .931 .961 r
F P
0 g
s
.32869 .38785 m .36525 .37393 L .39419 .34884 L p .679 .972 .912 r
F P
0 g
s
.5417 .82994 m .54309 .80875 L .47481 .8142 L p .608 .235 .309 r
F P
0 g
s
.54309 .80875 m .5417 .82994 L .60182 .82412 L p .559 .19 .297 r
F P
0 g
s
.60182 .82412 m .6089 .80245 L .54309 .80875 L p .559 .19 .297 r
F P
0 g
s
.4795 .83433 m .47481 .8142 L .40263 .81427 L p .657 .251 .263 r
F P
0 g
s
.47481 .8142 m .4795 .83433 L .5417 .82994 L p .608 .235 .309 r
F P
0 g
s
.81213 .55198 m .82539 .5922 L .84602 .52977 L p .06 .092 .58 r
F P
0 g
s
.84602 .52977 m .83078 .48988 L .81213 .55198 L p .06 .092 .58 r
F P
0 g
s
.49523 .32214 m .50512 .33105 L .53342 .32894 L p .465 .837 .991 r
F P
0 g
s
.50512 .33105 m .49523 .32214 L .45684 .33103 L p .558 .877 .993 r
F P
0 g
s
.53342 .32894 m .53677 .31861 L .49523 .32214 L p .465 .837 .991 r
F P
0 g
s
.68483 .76751 m .67477 .79375 L .737 .77659 L p .385 .049 .268 r
F P
0 g
s
.737 .77659 m .75443 .74769 L .68483 .76751 L p .385 .049 .268 r
F P
0 g
s
.39419 .34884 m .42515 .34551 L .45684 .33103 L p .556 .92 .949 r
F P
0 g
s
.6089 .80245 m .60182 .82412 L .66031 .81585 L p .475 .092 .233 r
F P
0 g
s
.66031 .81585 m .67477 .79375 L .6089 .80245 L p .475 .092 .233 r
F P
0 g
s
.29581 .40791 m .26808 .43412 L .24908 .48501 L p .877 .993 .77 r
F P
0 g
s
.22549 .52166 m .24908 .48501 L .26808 .43412 L p .826 .936 .566 r
F P
0 g
s
.21088 .56203 m .20653 .60449 L .23385 .66313 L p .996 .774 .425 r
F P
0 g
s
.23966 .70319 m .23385 .66313 L .20653 .60449 L p .923 .622 .145 r
F P
0 g
s
.67976 .35305 m .71625 .36184 L .66945 .33407 L p .104 .54 .913 r
F P
0 g
s
.66945 .33407 m .64298 .32948 L .67976 .35305 L p .104 .54 .913 r
F P
0 g
s
.31563 .77453 m .33272 .8015 L .40263 .81427 L p .764 .364 .295 r
F P
0 g
s
.41557 .83374 m .40263 .81427 L .33272 .8015 L p .704 .226 .111 r
F P
0 g
s
.40263 .81427 m .41557 .83374 L .4795 .83433 L p .657 .251 .263 r
F P
0 g
s
.6147 .33166 m .64298 .32948 L .59373 .31804 L p .193 .663 .937 r
F P
0 g
s
.59373 .31804 m .57802 .32127 L .6147 .33166 L p .193 .663 .937 r
F P
0 g
s
.77442 .42594 m .80628 .45493 L .77842 .40088 L p 0 .257 .768 r
F P
0 g
s
.77842 .40088 m .74971 .37763 L .77442 .42594 L p 0 .257 .768 r
F P
0 g
s
.76517 .71484 m .75443 .74769 L .80787 .71173 L p .142 0 .24 r
F P
0 g
s
.80787 .71173 m .82348 .67381 L .76517 .71484 L p .142 0 .24 r
F P
0 g
s
.23966 .70319 m .255 .73967 L .31563 .77453 L p .887 .494 .276 r
F P
0 g
s
.33272 .8015 m .31563 .77453 L .255 .73967 L p .812 .328 .032 r
F P
0 g
s
.39419 .34884 m .36607 .35864 L .32869 .38785 L p .679 .972 .912 r
F P
0 g
s
.29581 .40791 m .32869 .38785 L .36607 .35864 L p .539 .907 .723 r
F P
0 g
s
.82539 .5922 m .82935 .63339 L .85056 .57296 L p 0 0 .379 r
F P
0 g
s
.85056 .57296 m .84602 .52977 L .82539 .5922 L p 0 0 .379 r
F P
0 g
s
.43656 .33194 m .45684 .33103 L .49523 .32214 L p .32 .808 .854 r
F P
0 g
s
.45684 .33103 m .43656 .33194 L .39419 .34884 L p .556 .92 .949 r
F P
0 g
s
.53974 .84599 m .5417 .82994 L .4795 .83433 L p .54 .092 .136 r
F P
0 g
s
.5417 .82994 m .53974 .84599 L .592 .84076 L p .479 .036 .117 r
F P
0 g
s
.592 .84076 m .60182 .82412 L .5417 .82994 L p .479 .036 .117 r
F P
0 g
s
.57802 .32127 m .59373 .31804 L .53979 .31654 L p .082 .635 .815 r
F P
0 g
s
.53677 .31861 m .57802 .32127 L p .54725 .31746 L .082 .635 .815 r
F P
0 g
s
.60783 .32229 m .5424 .32247 L p .58376 .3189 L .325 0 0 r
F P
0 g
s
.59373 .31804 m .59852 .31949 L p .58376 .3189 L .325 0 0 r
F P
0 g
s
.59852 .31949 m .60783 .32229 L p .58376 .3189 L .325 0 0 r
F P
0 g
s
.53979 .31654 m .53893 .31713 L p .54725 .31746 L .082 .635 .815 r
F P
0 g
s
.53893 .31713 m .53677 .31861 L p .54725 .31746 L .082 .635 .815 r
F P
0 g
s
.48582 .84892 m .4795 .83433 L .41557 .83374 L p .578 .09 .06 r
F P
0 g
s
.4795 .83433 m .48582 .84892 L .53974 .84599 L p .54 .092 .136 r
F P
0 g
s
.67477 .79375 m .66031 .81585 L .71327 .8006 L p .275 0 .069 r
F P
0 g
s
.71327 .8006 m .737 .77659 L .67477 .79375 L p .275 0 .069 r
F P
0 g
s
.26808 .43412 m .24701 .46612 L .22549 .52166 L p .826 .936 .566 r
F P
0 g
s
.21088 .56203 m .22549 .52166 L .24701 .46612 L p 0 0 0 r
F P
0 g
s
.36607 .35864 m .39419 .34884 L .43656 .33194 L p .308 .789 .716 r
F P
0 g
s
.48638 .32161 m .49523 .32214 L .53677 .31861 L p .128 .677 .771 r
F P
0 g
s
.49523 .32214 m .48638 .32161 L .43656 .33194 L p .32 .808 .854 r
F P
0 g
s
.53677 .31861 m .53979 .31654 L .48638 .32161 L p .128 .677 .771 r
F P
0 g
s
.60182 .82412 m .592 .84076 L .6413 .83269 L p .361 0 .013 r
F P
0 g
s
.6413 .83269 m .66031 .81585 L .60182 .82412 L p .361 0 .013 r
F P
0 g
s
.80628 .45493 m .83078 .48988 L .80052 .43155 L p 0 0 .524 r
F P
0 g
s
.80052 .43155 m .77842 .40088 L .80628 .45493 L p 0 0 .524 r
F P
0 g
s
.71625 .36184 m .74971 .37763 L .69316 .34595 L p 0 .279 .685 r
F P
0 g
s
.69316 .34595 m .66945 .33407 L .71625 .36184 L p 0 .279 .685 r
F P
0 g
s
.20653 .60449 m .21308 .64709 L .23966 .70319 L p .923 .622 .145 r
F P
0 g
s
.23966 .70319 m .21308 .64709 L p .25484 .73931 L .695 .335 0 r
F P
0 g
s
.25494 .73952 m .23966 .70319 L p .25484 .73931 L .695 .335 0 r
F P
0 g
s
.255 .73967 m .2791 .77103 L .33272 .8015 L p .812 .328 .032 r
F P
0 g
s
.21308 .64709 m .23035 .68782 L .255 .73967 L p .695 .335 0 r
F P
0 g
s
.25736 .72484 m .2791 .77103 L p .23047 .68803 L 0 .016 .584 r
F P
0 g
s
.23035 .68782 m .23042 .68791 L p .23047 .68803 L 0 .016 .584 r
F P
0 g
s
.23042 .68791 m .25736 .72484 L p .23047 .68803 L 0 .016 .584 r
F P
0 g
s
.255 .73967 m .25494 .73952 L p .25484 .73931 L .695 .335 0 r
F P
0 g
s
.75443 .74769 m .737 .77659 L .78326 .74559 L p 0 0 0 r
F P
0 g
s
.78326 .74559 m .80787 .71173 L .75443 .74769 L p 0 0 0 r
F P
0 g
s
.36607 .35864 m .34164 .37486 L .29581 .40791 L p .539 .907 .723 r
F P
0 g
s
.26808 .43412 m .29581 .40791 L .34164 .37486 L p 0 0 0 r
F P
0 g
s
.60783 .32229 m .59373 .31804 L .64298 .32948 L p .211 0 0 r
F P
0 g
s
.64298 .32948 m .66945 .33407 L .60783 .32229 L p .211 0 0 r
F P
0 g
s
.35559 .82234 m .33272 .8015 L .2791 .77103 L p .617 .058 0 r
F P
0 g
s
.33272 .8015 m .35559 .82234 L .41557 .83374 L p .704 .226 .111 r
F P
0 g
s
.43206 .84709 m .41557 .83374 L .35559 .82234 L p .56 0 0 r
F P
0 g
s
.41557 .83374 m .43206 .84709 L .48582 .84892 L p .578 .09 .06 r
F P
0 g
s
.82935 .63339 m .82348 .67381 L .84369 .61739 L p 0 0 .063 r
F P
0 g
s
.84369 .61739 m .85056 .57296 L .82935 .63339 L p 0 0 .063 r
F P
0 g
s
.24701 .46612 m .23398 .50314 L .21088 .56203 L p 0 0 0 r
F P
0 g
s
.20653 .60449 m .21088 .56203 L .23398 .50314 L p 0 0 .165 r
F P
0 g
s
.41889 .34017 m .43656 .33194 L .48638 .32161 L p .062 0 0 r
F P
0 g
s
.43656 .33194 m .41889 .34017 L .36607 .35864 L p .308 .789 .716 r
F P
0 g
s
.34164 .37486 m .36607 .35864 L .41889 .34017 L p .029 0 0 r
F P
0 g
s
.66031 .81585 m .6413 .83269 L .68382 .81893 L p .086 0 0 r
F P
0 g
s
.68382 .81893 m .71327 .8006 L .66031 .81585 L p .086 0 0 r
F P
0 g
s
.53717 .85514 m .53974 .84599 L .48582 .84892 L p .374 0 0 r
F P
0 g
s
.53974 .84599 m .53717 .85514 L .57928 .85071 L p .297 0 0 r
F P
0 g
s
.57928 .85071 m .592 .84076 L .53974 .84599 L p .297 0 0 r
F P
0 g
s
.83078 .48988 m .84602 .52977 L .81428 .46896 L p .776 .41 0 r
F P
0 g
s
.81428 .46896 m .80052 .43155 L .83078 .48988 L p .776 .41 0 r
F P
0 g
s
.49383 .85656 m .48582 .84892 L .43206 .84709 L p .381 0 0 r
F P
0 g
s
.48582 .84892 m .49383 .85656 L .53717 .85514 L p .374 0 0 r
F P
0 g
s
.5424 .32247 m .53979 .31654 L .59373 .31804 L p .325 0 0 r
F P
0 g
s
.2791 .77103 m .255 .73967 L .23035 .68782 L p 0 .016 .584 r
F P
0 g
s
.74971 .37763 m .77842 .40088 L .7131 .36541 L p .63 .071 0 r
F P
0 g
s
.7131 .36541 m .69316 .34595 L .74971 .37763 L p .63 .071 0 r
F P
0 g
s
.737 .77659 m .71327 .8006 L .75091 .7742 L p 0 0 0 r
F P
0 g
s
.75091 .7742 m .78326 .74559 L .737 .77659 L p 0 0 0 r
F P
0 g
s
.34164 .37486 m .32166 .39723 L .26808 .43412 L p 0 0 0 r
F P
0 g
s
.24701 .46612 m .26808 .43412 L .32166 .39723 L p .005 0 .021 r
F P
0 g
s
.592 .84076 m .57928 .85071 L .61784 .84311 L p .132 0 0 r
F P
0 g
s
.61784 .84311 m .6413 .83269 L .592 .84076 L p .132 0 0 r
F P
0 g
s
.47885 .32905 m .48638 .32161 L .53979 .31654 L p .265 0 0 r
F P
0 g
s
.48638 .32161 m .47885 .32905 L .41889 .34017 L p .062 0 0 r
F P
0 g
s
.82348 .67381 m .80787 .71173 L .82567 .66083 L p .713 .795 .318 r
F P
0 g
s
.82567 .66083 m .84369 .61739 L .82348 .67381 L p .713 .795 .318 r
F P
0 g
s
.53979 .31654 m .5424 .32247 L .47885 .32905 L p .265 0 0 r
F P
0 g
s
.2791 .77103 m .31063 .79622 L .35559 .82234 L p .617 .058 0 r
F P
0 g
s
.35559 .82234 m .38341 .83656 L .43206 .84709 L p .56 0 0 r
F P
0 g
s
.38341 .83656 m .35559 .82234 L .31063 .79622 L p 0 .275 .676 r
F P
0 g
s
.66945 .33407 m .69316 .34595 L .61991 .33389 L p .538 0 0 r
F P
0 g
s
.61991 .33389 m .60783 .32229 L .66945 .33407 L p .538 0 0 r
F P
0 g
s
.45184 .85355 m .43206 .84709 L .38341 .83656 L p .255 0 0 r
F P
0 g
s
.43206 .84709 m .45184 .85355 L .49383 .85656 L p .381 0 0 r
F P
0 g
s
.23398 .50314 m .23004 .54393 L .20653 .60449 L p 0 0 .165 r
F P
0 g
s
.21308 .64709 m .20653 .60449 L .23004 .54393 L p 0 0 .448 r
F P
0 g
s
.41889 .34017 m .40423 .35511 L .34164 .37486 L p .029 0 0 r
F P
0 g
s
.32166 .39723 m .34164 .37486 L .40423 .35511 L p .269 0 .058 r
F P
0 g
s
.40423 .35511 m .41889 .34017 L .47885 .32905 L p .336 0 0 r
F P
0 g
s
.84602 .52977 m .85056 .57296 L .8184 .51173 L p .96 .664 .238 r
F P
0 g
s
.8184 .51173 m .81428 .46896 L .84602 .52977 L p .96 .664 .238 r
F P
0 g
s
.6413 .83269 m .61784 .84311 L .64944 .83101 L p 0 0 0 r
F P
0 g
s
.64944 .83101 m .68382 .81893 L .6413 .83269 L p 0 0 0 r
F P
0 g
s
.31063 .79622 m .2791 .77103 L .25736 .72484 L p 0 .296 .793 r
F P
0 g
s
.32166 .39723 m .30682 .42535 L .24701 .46612 L p .005 0 .021 r
F P
0 g
s
.23398 .50314 m .24701 .46612 L .30682 .42535 L p .196 0 .282 r
F P
0 g
s
.71327 .8006 m .68382 .81893 L .71239 .79684 L p .472 .87 .697 r
F P
0 g
s
.71239 .79684 m .75091 .7742 L .71327 .8006 L p .472 .87 .697 r
F P
0 g
s
.77842 .40088 m .80052 .43155 L .72821 .3924 L p .814 .339 .078 r
F P
0 g
s
.72821 .3924 m .7131 .36541 L .77842 .40088 L p .814 .339 .078 r
F P
0 g
s
.80787 .71173 m .78326 .74559 L .79762 .70118 L p .843 .96 .624 r
F P
0 g
s
.79762 .70118 m .82567 .66083 L .80787 .71173 L p .843 .96 .624 r
F P
0 g
s
.53401 .85568 m .53717 .85514 L .49383 .85656 L p 0 0 0 r
F P
0 g
s
.53717 .85514 m .53401 .85568 L .56377 .85235 L p 0 0 0 r
F P
0 g
s
.56377 .85235 m .57928 .85071 L .53717 .85514 L p 0 0 0 r
F P
0 g
s
.60783 .32229 m .61991 .33389 L .54453 .3357 L p .54 .045 .03 r
F P
0 g
s
.54453 .3357 m .5424 .32247 L .60783 .32229 L p .54 .045 .03 r
F P
0 g
s
.50343 .85593 m .49383 .85656 L .45184 .85355 L p .019 .59 .766 r
F P
0 g
s
.49383 .85656 m .50343 .85593 L .53401 .85568 L p 0 0 0 r
F P
0 g
s
.47278 .34353 m .47885 .32905 L .5424 .32247 L p .472 .008 .07 r
F P
0 g
s
.47885 .32905 m .47278 .34353 L .40423 .35511 L p .336 0 0 r
F P
0 g
s
.57928 .85071 m .56377 .85235 L .59031 .84601 L p .227 .748 .797 r
F P
0 g
s
.59031 .84601 m .61784 .84311 L .57928 .85071 L p .227 .748 .797 r
F P
0 g
s
.23004 .54393 m .23571 .5869 L .21308 .64709 L p 0 0 .448 r
F P
0 g
s
.23035 .68782 m .21308 .64709 L .23571 .5869 L p .135 .159 .62 r
F P
0 g
s
.31063 .79622 m .34796 .81473 L .38341 .83656 L p 0 .275 .676 r
F P
0 g
s
.41527 .84397 m .38341 .83656 L .34796 .81473 L p .071 .537 .899 r
F P
0 g
s
.38341 .83656 m .41527 .84397 L .45184 .85355 L p .255 0 0 r
F P
0 g
s
.5424 .32247 m .54453 .3357 L .47278 .34353 L p .472 .008 .07 r
F P
0 g
s
.69316 .34595 m .7131 .36541 L .62966 .35253 L p .684 .208 .116 r
F P
0 g
s
.62966 .35253 m .61991 .33389 L .69316 .34595 L p .684 .208 .116 r
F P
0 g
s
.47454 .85249 m .45184 .85355 L .41527 .84397 L p .147 .649 .907 r
F P
0 g
s
.45184 .85355 m .47454 .85249 L .50343 .85593 L p .019 .59 .766 r
F P
0 g
s
.85056 .57296 m .84369 .61739 L .81227 .55792 L p .997 .785 .487 r
F P
0 g
s
.81227 .55792 m .8184 .51173 L .85056 .57296 L p .997 .785 .487 r
F P
0 g
s
.40423 .35511 m .39277 .37598 L .32166 .39723 L p .269 0 .058 r
F P
0 g
s
.30682 .42535 m .32166 .39723 L .39277 .37598 L p .401 .064 .275 r
F P
0 g
s
.25736 .72484 m .29249 .75672 L .31063 .79622 L p 0 .296 .793 r
F P
0 g
s
.34796 .81473 m .31063 .79622 L .29249 .75672 L p .202 .476 .891 r
F P
0 g
s
.39277 .37598 m .40423 .35511 L .47278 .34353 L p .471 .079 .215 r
F P
0 g
s
.30682 .42535 m .29773 .45861 L .23398 .50314 L p .196 0 .282 r
F P
0 g
s
.23004 .54393 m .23398 .50314 L .29773 .45861 L p .316 .119 .447 r
F P
0 g
s
.78326 .74559 m .75091 .7742 L .76138 .73677 L p .86 .997 .8 r
F P
0 g
s
.76138 .73677 m .79762 .70118 L .78326 .74559 L p .86 .997 .8 r
F P
0 g
s
.68382 .81893 m .64944 .83101 L .66934 .81322 L p .595 .948 .898 r
F P
0 g
s
.66934 .81322 m .71239 .79684 L .68382 .81893 L p .595 .948 .898 r
F P
0 g
s
.61784 .84311 m .59031 .84601 L .61104 .83641 L p .443 .873 .916 r
F P
0 g
s
.61104 .83641 m .64944 .83101 L .61784 .84311 L p .443 .873 .916 r
F P
0 g
s
.80052 .43155 m .81428 .46896 L .73756 .42645 L p .875 .493 .316 r
F P
0 g
s
.73756 .42645 m .72821 .3924 L .80052 .43155 L p .875 .493 .316 r
F P
0 g
s
.23571 .5869 m .25092 .63024 L .23035 .68782 L p .135 .159 .62 r
F P
0 g
s
.25736 .72484 m .23035 .68782 L .25092 .63024 L p .273 .316 .725 r
F P
0 g
s
.61991 .33389 m .62966 .35253 L .54617 .35525 L p .624 .216 .248 r
F P
0 g
s
.54617 .35525 m .54453 .3357 L .61991 .33389 L p .624 .216 .248 r
F P
0 g
s
.34796 .81473 m .38944 .82659 L .41527 .84397 L p .071 .537 .899 r
F P
0 g
s
.45024 .84464 m .41527 .84397 L .38944 .82659 L p .325 .679 .978 r
F P
0 g
s
.41527 .84397 m .45024 .84464 L .47454 .85249 L p .147 .649 .907 r
F P
0 g
s
.53034 .8463 m .53401 .85568 L .50343 .85593 L p .409 .813 .981 r
F P
0 g
s
.53401 .85568 m .53034 .8463 L .54587 .84443 L p .441 .834 .982 r
F P
0 g
s
.54587 .84443 m .56377 .85235 L .53401 .85568 L p .441 .834 .982 r
F P
0 g
s
.46819 .36392 m .47278 .34353 L .54453 .3357 L p .561 .176 .269 r
F P
0 g
s
.47278 .34353 m .46819 .36392 L .39277 .37598 L p .471 .079 .215 r
F P
0 g
s
.51439 .84601 m .50343 .85593 L .47454 .85249 L p .405 .793 .989 r
F P
0 g
s
.50343 .85593 m .51439 .84601 L .53034 .8463 L p .409 .813 .981 r
F P
0 g
s
.84369 .61739 m .82567 .66083 L .79607 .60522 L p .975 .831 .636 r
F P
0 g
s
.79607 .60522 m .81227 .55792 L .84369 .61739 L p .975 .831 .636 r
F P
0 g
s
.56377 .85235 m .54587 .84443 L .55944 .84057 L p .495 .856 .99 r
F P
0 g
s
.55944 .84057 m .59031 .84601 L .56377 .85235 L p .495 .856 .99 r
F P
0 g
s
.7131 .36541 m .72821 .3924 L .63683 .37773 L p .739 .346 .306 r
F P
0 g
s
.63683 .37773 m .62966 .35253 L .7131 .36541 L p .739 .346 .306 r
F P
0 g
s
.54453 .3357 m .54617 .35525 L .46819 .36392 L p .561 .176 .269 r
F P
0 g
s
.75091 .7742 m .71239 .79684 L .71912 .76657 L p .828 .974 .888 r
F P
0 g
s
.71912 .76657 m .76138 .73677 L .75091 .7742 L p .828 .974 .888 r
F P
0 g
s
.29249 .75672 m .33376 .78264 L .34796 .81473 L p .202 .476 .891 r
F P
0 g
s
.38944 .82659 m .34796 .81473 L .33376 .78264 L p .355 .589 .933 r
F P
0 g
s
.39277 .37598 m .38456 .40199 L .30682 .42535 L p .401 .064 .275 r
F P
0 g
s
.29773 .45861 m .30682 .42535 L .38456 .40199 L p .476 .196 .409 r
F P
0 g
s
.29773 .45861 m .29484 .49623 L .23004 .54393 L p .316 .119 .447 r
F P
0 g
s
.23571 .5869 m .23004 .54393 L .29484 .49623 L p .396 .244 .555 r
F P
0 g
s
.4996 .84349 m .47454 .85249 L .45024 .84464 L p .435 .772 .997 r
F P
0 g
s
.47454 .85249 m .4996 .84349 L .51439 .84601 L p .405 .793 .989 r
F P
0 g
s
.64944 .83101 m .61104 .83641 L .62324 .82345 L p .638 .927 .973 r
F P
0 g
s
.62324 .82345 m .66934 .81322 L .64944 .83101 L p .638 .927 .973 r
F P
0 g
s
.38456 .40199 m .39277 .37598 L .46819 .36392 L p .539 .209 .356 r
F P
0 g
s
.25092 .63024 m .27499 .67212 L .25736 .72484 L p .273 .316 .725 r
F P
0 g
s
.29249 .75672 m .25736 .72484 L .27499 .67212 L p .371 .429 .792 r
F P
0 g
s
.59031 .84601 m .55944 .84057 L .56963 .8349 L p .568 .873 .994 r
F P
0 g
s
.56963 .8349 m .61104 .83641 L .59031 .84601 L p .568 .873 .994 r
F P
0 g
s
.81428 .46896 m .8184 .51173 L .74045 .46659 L p .885 .58 .465 r
F P
0 g
s
.74045 .46659 m .73756 .42645 L .81428 .46896 L p .885 .58 .465 r
F P
0 g
s
.38944 .82659 m .43362 .83217 L .45024 .84464 L p .325 .679 .978 r
F P
0 g
s
.4875 .83872 m .45024 .84464 L .43362 .83217 L p .487 .745 .986 r
F P
0 g
s
.45024 .84464 m .4875 .83872 L .4996 .84349 L p .435 .772 .997 r
F P
0 g
s
.71239 .79684 m .66934 .81322 L .67299 .79019 L p .783 .933 .93 r
F P
0 g
s
.67299 .79019 m .71912 .76657 L .71239 .79684 L p .783 .933 .93 r
F P
0 g
s
.82567 .66083 m .79762 .70118 L .77083 .6513 L p .935 .845 .729 r
F P
0 g
s
.77083 .6513 m .79607 .60522 L .82567 .66083 L p .935 .845 .729 r
F P
0 g
s
.33376 .78264 m .37923 .80231 L .38944 .82659 L p .355 .589 .933 r
F P
0 g
s
.43362 .83217 m .38944 .82659 L .37923 .80231 L p .462 .664 .95 r
F P
0 g
s
.62966 .35253 m .63683 .37773 L .54734 .38016 L p .661 .314 .375 r
F P
0 g
s
.54734 .38016 m .54617 .35525 L .62966 .35253 L p .661 .314 .375 r
F P
0 g
s
.46498 .38914 m .46819 .36392 L .54617 .35525 L p .603 .274 .385 r
F P
0 g
s
.46819 .36392 m .46498 .38914 L .38456 .40199 L p .539 .209 .356 r
F P
0 g
s
.29484 .49623 m .29848 .53727 L .23571 .5869 L p .396 .244 .555 r
F P
0 g
s
.25092 .63024 m .23571 .5869 L .29848 .53727 L p .452 .337 .632 r
F P
0 g
s
.27499 .67212 m .30671 .71092 L .29249 .75672 L p .371 .429 .792 r
F P
0 g
s
.33376 .78264 m .29249 .75672 L .30671 .71092 L p .444 .515 .837 r
F P
0 g
s
.61104 .83641 m .56963 .8349 L .57527 .82776 L p .642 .871 .984 r
F P
0 g
s
.57527 .82776 m .62324 .82345 L .61104 .83641 L p .642 .871 .984 r
F P
0 g
s
.38456 .40199 m .37958 .43248 L .29773 .45861 L p .476 .196 .409 r
F P
0 g
s
.29484 .49623 m .29773 .45861 L .37958 .43248 L p .522 .286 .499 r
F P
0 g
s
.54617 .35525 m .54734 .38016 L .46498 .38914 L p .603 .274 .385 r
F P
0 g
s
.72821 .3924 m .73756 .42645 L .64121 .40893 L p .761 .43 .425 r
F P
0 g
s
.64121 .40893 m .63683 .37773 L .72821 .3924 L p .761 .43 .425 r
F P
0 g
s
.52632 .82641 m .53034 .8463 L .51439 .84601 L closepath p .594 .807 .981 r
F P
0 g
s
.52632 .82641 m .54587 .84443 L .53034 .8463 L closepath p .596 .809 .981 r
F P
0 g
s
.52632 .82641 m .51439 .84601 L .4996 .84349 L closepath p .59 .802 .981 r
F P
0 g
s
.37958 .43248 m .38456 .40199 L .46498 .38914 L p .578 .293 .447 r
F P
0 g
s
.52632 .82641 m .55944 .84057 L .54587 .84443 L closepath p .6 .81 .98 r
F P
0 g
s
.66934 .81322 m .62324 .82345 L .62474 .80777 L p .736 .888 .949 r
F P
0 g
s
.62474 .80777 m .67299 .79019 L .66934 .81322 L p .736 .888 .949 r
F P
0 g
s
.52632 .82641 m .4996 .84349 L .4875 .83872 L closepath p .587 .791 .977 r
F P
0 g
s
.79762 .70118 m .76138 .73677 L .73817 .69412 L p .892 .845 .792 r
F P
0 g
s
.73817 .69412 m .77083 .6513 L .79762 .70118 L p .892 .845 .792 r
F P
0 g
s
.37923 .80231 m .42722 .81591 L .43362 .83217 L p .462 .664 .95 r
F P
0 g
s
.47948 .83198 m .43362 .83217 L .42722 .81591 L p .541 .718 .955 r
F P
0 g
s
.43362 .83217 m .47948 .83198 L .4875 .83872 L p .487 .745 .986 r
F P
0 g
s
.8184 .51173 m .81227 .55792 L .73647 .51141 L p .877 .633 .565 r
F P
0 g
s
.73647 .51141 m .74045 .46659 L .8184 .51173 L p .877 .633 .565 r
F P
0 g
s
.52632 .82641 m .56963 .8349 L .55944 .84057 L closepath p .611 .812 .977 r
F P
0 g
s
.30671 .71092 m .34456 .74534 L .33376 .78264 L p .444 .515 .837 r
F P
0 g
s
.37923 .80231 m .33376 .78264 L .34456 .74534 L p .501 .585 .871 r
F P
0 g
s
.52632 .82641 m .4875 .83872 L .47948 .83198 L closepath p .591 .775 .967 r
F P
0 g
s
.29848 .53727 m .30879 .58055 L .25092 .63024 L p .452 .337 .632 r
F P
0 g
s
.27499 .67212 m .25092 .63024 L .30879 .58055 L p .494 .411 .691 r
F P
0 g
s
.52632 .82641 m .57527 .82776 L .56963 .8349 L closepath p .63 .81 .969 r
F P
0 g
s
.62324 .82345 m .57527 .82776 L .5756 .81971 L p .692 .844 .956 r
F P
0 g
s
.5756 .81971 m .62474 .80777 L .62324 .82345 L p .692 .844 .956 r
F P
0 g
s
.46304 .4184 m .46498 .38914 L .54734 .38016 L p .626 .338 .46 r
F P
0 g
s
.46498 .38914 m .46304 .4184 L .37958 .43248 L p .578 .293 .447 r
F P
0 g
s
.37958 .43248 m .37787 .46698 L .29484 .49623 L p .522 .286 .499 r
F P
0 g
s
.29848 .53727 m .29484 .49623 L .37787 .46698 L p .553 .354 .565 r
F P
0 g
s
.34456 .74534 m .38689 .77448 L .37923 .80231 L p .501 .585 .871 r
F P
0 g
s
.42722 .81591 m .37923 .80231 L .38689 .77448 L p .547 .644 .897 r
F P
0 g
s
.76138 .73677 m .71912 .76657 L .70003 .73217 L p .848 .839 .836 r
F P
0 g
s
.70003 .73217 m .73817 .69412 L .76138 .73677 L p .848 .839 .836 r
F P
0 g
s
.63683 .37773 m .64121 .40893 L .54804 .4097 L p .678 .377 .456 r
F P
0 g
s
.54804 .4097 m .54734 .38016 L .63683 .37773 L p .678 .377 .456 r
F P
0 g
s
.42722 .81591 m .47651 .82382 L .47948 .83198 L p .541 .718 .955 r
F P
0 g
s
.52632 .82641 m .47948 .83198 L .47651 .82382 L closepath p .603 .759 .953 r
F P
0 g
s
.54734 .38016 m .54804 .4097 L .46304 .4184 L p .626 .338 .46 r
F P
0 g
s
.37787 .46698 m .37958 .43248 L .46304 .4184 L p .603 .353 .511 r
F P
0 g
s
.52632 .82641 m .5756 .81971 L .57527 .82776 L closepath p .649 .801 .956 r
F P
0 g
s
.73756 .42645 m .74045 .46659 L .64265 .4455 L p .769 .486 .507 r
F P
0 g
s
.64265 .4455 m .64121 .40893 L .73756 .42645 L p .769 .486 .507 r
F P
0 g
s
.38689 .77448 m .43216 .79784 L .42722 .81591 L p .547 .644 .897 r
F P
0 g
s
.47651 .82382 m .42722 .81591 L .43216 .79784 L p .585 .697 .919 r
F P
0 g
s
.30879 .58055 m .32568 .62476 L .27499 .67212 L p .494 .411 .691 r
F P
0 g
s
.30671 .71092 m .27499 .67212 L .32568 .62476 L p .528 .473 .739 r
F P
0 g
s
.81227 .55792 m .79607 .60522 L .72565 .55914 L p .862 .667 .637 r
F P
0 g
s
.72565 .55914 m .73647 .51141 L .81227 .55792 L p .862 .667 .637 r
F P
0 g
s
.71912 .76657 m .67299 .79019 L .65835 .76458 L p .804 .829 .87 r
F P
0 g
s
.65835 .76458 m .70003 .73217 L .71912 .76657 L p .804 .829 .87 r
F P
0 g
s
.43216 .79784 m .47901 .81517 L .47651 .82382 L p .585 .697 .919 r
F P
0 g
s
.52632 .82641 m .47651 .82382 L .47901 .81517 L closepath p .619 .747 .938 r
F P
0 g
s
.52632 .82641 m .56038 .80439 L .57046 .81159 L closepath p .662 .767 .928 r
F P
0 g
s
.52632 .82641 m .54652 .79911 L .56038 .80439 L closepath p .658 .753 .921 r
F P
0 g
s
.52632 .82641 m .53045 .79655 L .54652 .79911 L closepath p .653 .747 .918 r
F P
0 g
s
.52632 .82641 m .51396 .79713 L .53045 .79655 L closepath p .651 .744 .918 r
F P
0 g
s
.52632 .82641 m .49885 .80083 L .51396 .79713 L closepath p .649 .743 .918 r
F P
0 g
s
.52632 .82641 m .48675 .80714 L .49885 .80083 L closepath p .645 .742 .92 r
F P
0 g
s
.52632 .82641 m .47901 .81517 L .48675 .80714 L closepath p .634 .742 .926 r
F P
0 g
s
.52632 .82641 m .57046 .81159 L .5756 .81971 L closepath p .66 .784 .94 r
F P
0 g
s
.67299 .79019 m .62474 .80777 L .61475 .79104 L p .759 .816 .898 r
F P
0 g
s
.61475 .79104 m .65835 .76458 L .67299 .79019 L p .759 .816 .898 r
F P
0 g
s
.62474 .80777 m .5756 .81971 L .57046 .81159 L p .712 .802 .921 r
F P
0 g
s
.57046 .81159 m .61475 .79104 L .62474 .80777 L p .712 .802 .921 r
F P
0 g
s
.37787 .46698 m .37955 .50515 L .29848 .53727 L p .553 .354 .565 r
F P
0 g
s
.30879 .58055 m .29848 .53727 L .37955 .50515 L p .575 .408 .618 r
F P
0 g
s
.32568 .62476 m .34881 .66842 L .30671 .71092 L p .528 .473 .739 r
F P
0 g
s
.34456 .74534 m .30671 .71092 L .34881 .66842 L p .556 .529 .78 r
F P
0 g
s
.46233 .45134 m .46304 .4184 L .54804 .4097 L p .641 .384 .514 r
F P
0 g
s
.46304 .4184 m .46233 .45134 L .37787 .46698 L p .603 .353 .511 r
F P
0 g
s
.4478 .78066 m .48675 .80714 L .47901 .81517 L p .619 .685 .89 r
F P
0 g
s
.47901 .81517 m .43216 .79784 L .4478 .78066 L p .619 .685 .89 r
F P
0 g
s
.34881 .66842 m .37754 .70997 L .34456 .74534 L p .556 .529 .78 r
F P
0 g
s
.38689 .77448 m .34456 .74534 L .37754 .70997 L p .58 .581 .818 r
F P
0 g
s
.37955 .50515 m .37787 .46698 L .46233 .45134 L p .62 .4 .562 r
F P
0 g
s
.61475 .79104 m .57046 .81159 L .56038 .80439 L p .712 .759 .89 r
F P
0 g
s
.79607 .60522 m .77083 .6513 L .70842 .60778 L p .844 .691 .693 r
F P
0 g
s
.70842 .60778 m .72565 .55914 L .79607 .60522 L p .844 .691 .693 r
F P
0 g
s
.41093 .74787 m .4478 .78066 L .43216 .79784 L p .601 .632 .854 r
F P
0 g
s
.43216 .79784 m .38689 .77448 L .41093 .74787 L p .601 .632 .854 r
F P
0 g
s
.64121 .40893 m .64265 .4455 L .54829 .44344 L p .689 .423 .515 r
F P
0 g
s
.54829 .44344 m .54804 .4097 L .64121 .40893 L p .689 .423 .515 r
F P
0 g
s
.54804 .4097 m .54829 .44344 L .46233 .45134 L p .641 .384 .514 r
F P
0 g
s
.37754 .70997 m .41093 .74787 L .38689 .77448 L p .58 .581 .818 r
F P
0 g
s
.47201 .76711 m .49885 .80083 L .48675 .80714 L p .643 .681 .871 r
F P
0 g
s
.48675 .80714 m .4478 .78066 L .47201 .76711 L p .643 .681 .871 r
F P
0 g
s
.74045 .46659 m .73647 .51141 L .64099 .48673 L p .771 .529 .568 r
F P
0 g
s
.64099 .48673 m .64265 .4455 L .74045 .46659 L p .771 .529 .568 r
F P
0 g
s
.37955 .50515 m .38489 .54664 L .30879 .58055 L p .575 .408 .618 r
F P
0 g
s
.32568 .62476 m .30879 .58055 L .38489 .54664 L p .592 .455 .664 r
F P
0 g
s
.56038 .80439 m .59441 .77562 L .61475 .79104 L p .712 .759 .89 r
F P
0 g
s
.59441 .77562 m .56038 .80439 L .54652 .79911 L p .7 .725 .869 r
F P
0 g
s
.50193 .75926 m .51396 .79713 L .49885 .80083 L p .66 .683 .861 r
F P
0 g
s
.49885 .80083 m .47201 .76711 L .50193 .75926 L p .66 .683 .861 r
F P
0 g
s
.65835 .76458 m .61475 .79104 L .59441 .77562 L p .748 .749 .853 r
F P
0 g
s
.77083 .6513 m .73817 .69412 L .68558 .65539 L p .824 .71 .739 r
F P
0 g
s
.68558 .65539 m .70842 .60778 L .77083 .6513 L p .824 .71 .739 r
F P
0 g
s
.54652 .79911 m .56649 .76403 L .59441 .77562 L p .7 .725 .869 r
F P
0 g
s
.56649 .76403 m .54652 .79911 L .53045 .79655 L p .686 .702 .859 r
F P
0 g
s
.46289 .48794 m .46233 .45134 L .54829 .44344 L p .653 .423 .559 r
F P
0 g
s
.46233 .45134 m .46289 .48794 L .37955 .50515 L p .62 .4 .562 r
F P
0 g
s
.5345 .75823 m .53045 .79655 L .51396 .79713 L p .673 .689 .857 r
F P
0 g
s
.51396 .79713 m .50193 .75926 L .5345 .75823 L p .673 .689 .857 r
F P
0 g
s
.53045 .79655 m .5345 .75823 L .56649 .76403 L p .686 .702 .859 r
F P
0 g
s
.44718 .72703 m .47201 .76711 L .4478 .78066 L p .637 .629 .826 r
F P
0 g
s
.4478 .78066 m .41093 .74787 L .44718 .72703 L p .637 .629 .826 r
F P
0 g
s
.38489 .54664 m .37955 .50515 L .46289 .48794 L p .632 .44 .606 r
F P
0 g
s
.70003 .73217 m .65835 .76458 L .62739 .74062 L p .777 .738 .816 r
F P
0 g
s
.59441 .77562 m .62739 .74062 L .65835 .76458 L p .748 .749 .853 r
F P
0 g
s
.73817 .69412 m .70003 .73217 L .65817 .70016 L p .802 .725 .779 r
F P
0 g
s
.65817 .70016 m .68558 .65539 L .73817 .69412 L p .802 .725 .779 r
F P
0 g
s
.38489 .54664 m .39421 .59084 L .32568 .62476 L p .592 .455 .664 r
F P
0 g
s
.34881 .66842 m .32568 .62476 L .39421 .59084 L p .606 .498 .705 r
F P
0 g
s
.62739 .74062 m .65817 .70016 L .70003 .73217 L p .777 .738 .816 r
F P
0 g
s
.54807 .48121 m .54829 .44344 L .64265 .4455 L p .697 .461 .562 r
F P
0 g
s
.54829 .44344 m .54807 .48121 L .46289 .48794 L p .653 .423 .559 r
F P
0 g
s
.64265 .4455 m .64099 .48673 L .54807 .48121 L p .697 .461 .562 r
F P
0 g
s
.73647 .51141 m .72565 .55914 L .63612 .53173 L p .77 .563 .619 r
F P
0 g
s
.63612 .53173 m .64099 .48673 L .73647 .51141 L p .77 .563 .619 r
F P
0 g
s
.42551 .68282 m .44718 .72703 L .41093 .74787 L p .628 .583 .785 r
F P
0 g
s
.41093 .74787 m .37754 .70997 L .42551 .68282 L p .628 .583 .785 r
F P
0 g
s
.62739 .74062 m .59441 .77562 L .56649 .76403 L p .726 .697 .823 r
F P
0 g
s
.39421 .59084 m .40774 .63675 L .34881 .66842 L p .606 .498 .705 r
F P
0 g
s
.37754 .70997 m .34881 .66842 L .40774 .63675 L p .617 .54 .745 r
F P
0 g
s
.40774 .63675 m .42551 .68282 L .37754 .70997 L p .617 .54 .745 r
F P
0 g
s
.49093 .71512 m .50193 .75926 L .47201 .76711 L p .661 .632 .81 r
F P
0 g
s
.47201 .76711 m .44718 .72703 L .49093 .71512 L p .661 .632 .81 r
F P
0 g
s
.46487 .52828 m .46289 .48794 L .54807 .48121 L p .662 .459 .599 r
F P
0 g
s
.46289 .48794 m .46487 .52828 L .38489 .54664 L p .632 .44 .606 r
F P
0 g
s
.39421 .59084 m .38489 .54664 L .46487 .52828 L p .641 .477 .646 r
F P
0 g
s
.56649 .76403 m .58533 .72261 L .62739 .74062 L p .726 .697 .823 r
F P
0 g
s
.58533 .72261 m .56649 .76403 L .5345 .75823 L p .702 .662 .807 r
F P
0 g
s
.53822 .71363 m .5345 .75823 L .50193 .75926 L p .681 .642 .804 r
F P
0 g
s
.50193 .75926 m .49093 .71512 L .53822 .71363 L p .681 .642 .804 r
F P
0 g
s
.72565 .55914 m .70842 .60778 L .62797 .5794 L p .766 .592 .662 r
F P
0 g
s
.62797 .5794 m .63612 .53173 L .72565 .55914 L p .766 .592 .662 r
F P
0 g
s
.5345 .75823 m .53822 .71363 L .58533 .72261 L p .702 .662 .807 r
F P
0 g
s
.65817 .70016 m .62739 .74062 L .58533 .72261 L p .742 .671 .781 r
F P
0 g
s
.54733 .52289 m .54807 .48121 L .64099 .48673 L p .703 .495 .604 r
F P
0 g
s
.54807 .48121 m .54733 .52289 L .46487 .52828 L p .662 .459 .599 r
F P
0 g
s
.64099 .48673 m .63612 .53173 L .54733 .52289 L p .703 .495 .604 r
F P
0 g
s
.48151 .6675 m .49093 .71512 L .44718 .72703 L p .658 .589 .766 r
F P
0 g
s
.44718 .72703 m .42551 .68282 L .48151 .6675 L p .658 .589 .766 r
F P
0 g
s
.46487 .52828 m .4685 .57224 L .39421 .59084 L p .641 .477 .646 r
F P
0 g
s
.40774 .63675 m .39421 .59084 L .4685 .57224 L p .648 .513 .685 r
F P
0 g
s
.4685 .57224 m .46487 .52828 L .54733 .52289 L p .67 .493 .638 r
F P
0 g
s
.68558 .65539 m .65817 .70016 L .60225 .6767 L p .753 .645 .741 r
F P
0 g
s
.58533 .72261 m .60225 .6767 L .65817 .70016 L p .742 .671 .781 r
F P
0 g
s
.70842 .60778 m .68558 .65539 L .61661 .6283 L p .761 .619 .702 r
F P
0 g
s
.61661 .6283 m .62797 .5794 L .70842 .60778 L p .761 .619 .702 r
F P
0 g
s
.4685 .57224 m .47401 .61913 L .40774 .63675 L p .648 .513 .685 r
F P
0 g
s
.42551 .68282 m .40774 .63675 L .47401 .61913 L p .654 .55 .724 r
F P
0 g
s
.47401 .61913 m .48151 .6675 L .42551 .68282 L p .654 .55 .724 r
F P
0 g
s
.60225 .6767 m .61661 .6283 L .68558 .65539 L p .753 .645 .741 r
F P
0 g
s
.60225 .6767 m .58533 .72261 L .53822 .71363 L p .709 .626 .762 r
F P
0 g
s
.54145 .66541 m .53822 .71363 L .49093 .71512 L p .682 .6 .758 r
F P
0 g
s
.49093 .71512 m .48151 .6675 L .54145 .66541 L p .682 .6 .758 r
F P
0 g
s
.54602 .56817 m .54733 .52289 L .63612 .53173 L p .708 .528 .643 r
F P
0 g
s
.54733 .52289 m .54602 .56817 L .4685 .57224 L p .67 .493 .638 r
F P
0 g
s
.63612 .53173 m .62797 .5794 L .54602 .56817 L p .708 .528 .643 r
F P
0 g
s
.47401 .61913 m .4685 .57224 L .54602 .56817 L p .676 .528 .676 r
F P
0 g
s
.53822 .71363 m .54145 .66541 L .60225 .6767 L p .709 .626 .762 r
F P
0 g
s
.54406 .61618 m .54145 .66541 L .48151 .6675 L p .68 .563 .716 r
F P
0 g
s
.48151 .6675 m .47401 .61913 L .54406 .61618 L p .68 .563 .716 r
F P
0 g
s
.54602 .56817 m .54406 .61618 L .47401 .61913 L p .676 .528 .676 r
F P
0 g
s
.61661 .6283 m .60225 .6767 L .54145 .66541 L p .712 .592 .721 r
F P
0 g
s
.62797 .5794 m .61661 .6283 L .54406 .61618 L p .711 .56 .682 r
F P
0 g
s
.54406 .61618 m .54602 .56817 L .62797 .5794 L p .711 .56 .682 r
F P
0 g
s
.54145 .66541 m .54406 .61618 L .61661 .6283 L p .712 .592 .721 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Y_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo000Qooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Uooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:Oooool002[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1aooooo`ko00009Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ioooool9o`00
00Co@`0000?o0000oe<00?mC00001omC000;o`0001[ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo063o
oooo1_l00009od<001ko00005Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oo
oooo000Yooooo`;o00006_ooool00ol0003oooooooooo`1Jooooo`Go000000?o3`00o`000?m30000
0_m3000:o`0000GoN08A00?o0000ohX;1on:2`L04_n:2`L00ol0003oR@00ohT00006o`00017ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo05Cooooo1Ol00003o`l000Oo00003omh0Q400ol0003oRP/7ohX;
1`0CohX;1`03o`000?n9003oR@0000CoR@001Ol0000=ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1?
ooooo`Co00000ol?0005o`0000;oEP0000?o0000ogP24Omh0Q404_mh0Q400ol0003oRP/7ohX;1`0C
ohX;1`03o`000?n9003oR@0000SoR@001Ol00008ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool09Oooool002Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1;oooo
o`?o00000_l?0005o`0000KoEP0000?o0000ogP24Omh0Q403omh0Q4Oo`0000_oR@000ol00005oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`17ooooo`So00002omF00000ol0003oN08AogP24@07ogP24@So
00001?n?;D@00ol0003oWcLooilg?`0Doilg?`04o`000?n_=Ago[cDMojle7@Ko00002?n90002o`00
00?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo04Cooooo1Ol0000@oeH00003o`000?mh0Q7oN08A00Oo
00003?n?;D@00ol0003oWcLooilg?`0Eoilg?`03o`000?n_=Ago[cDM00Ko[cDM1Ol00005ohT00004
o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03
o`000?oooooooooo043ooooo1_l0000>oeH000Oo00004on?;D@00ol0003oWcLooilg?`0Eoilg?`03
o`000?n_=Ago[cDM00_o[cDM2Ol0000jooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0?Oooool4o`0000;o1`0000?o0000oeH00?mF0000
1_mF0007o`0000?oN1@g00?o0000ohl]A?n?;D@05?n?;D@00ol0003oWcLooilg?`0Foilg?`03o`00
0?n_=Ago[cDM013o[cDM1?l0000jooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0>_ooool3o`0000Co1`0000?o0000oeH00?mF00001ol0
000:ogPD=`03o`000?n?;DCoSbe401CoSbe400?o0000oilg?onO=cl05_nO=cl00ol0003o[cDMojle
7@0Bojle7@Co0000>Oooool00ol0003oooooooooo`0Qooooo`00:?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03Kooooo1?l00004o`L000Go00004Omh53L00ol0003oSbe4ohl]A00@
ohl]A2;o00004?n_=Ad01?l0003o[cDMo`000?nQ4P02o`0003Oooooo00?o0000ooooooooool08Ooo
ool002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0cooooo`?o00001?l70003
o`000003od@03_l0003oN1@g01;oN1@g00?o0000ohl]A?n?;D@02On?;D@8o`0000CoVTIR00?o0000
ojU@GonYD5l05onYD5l01?l0003o_EQ>okeHC_nmF4h7o`0000Wo[cDM00Co0000ojle7On_=Ago0000
0_nQ4P02o`0003Kooooo00?o0000ooooooooool08?ooool002Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0`ooooo`;o00001?l70003o`0000?oA00>00?o0000ogPD=omh53L04_mh
53L01?l0003oSbe4ohl]A?n?;D@8o`0000coVTIR00?o0000ojU@GonYD5l05onYD5l00ol0003o_EQ>
okeHCP08okeHCPKo00000on_=Ad01Ol0003o[cDMojle7On_=Ago000000?oXA800_l0000dooooo`03
o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
;_ooool01?l0003o1`00o`L00?l70003o`0000KoA00>00?o0000ogPD=omh53L03omh53L7o`0001Co
VTIR00?o0000ojU@GonYD5l06?nYD5l00ol0003o_EQ>okeHCP0=okeHCPOo000000?o[cDMo`000?nQ
4P000onQ4P02o`0003?ooooo00?o0000ooooooooool07oooool002Oooooo0_l0000Yooooo`03o`00
0?oooooooooo02_ooooo0_l000001?l7003o0000o`000?l00008od@03P03o`000?mh53OoN1@g00[o
N1@g1_l00003ohTeF`03o`000?nJAV;oVTIR01GoVTIR00?o0000ojU@GonYD5l06?nYD5l00ol0003o
_EQ>okeHCP0@okeHCP04o`000?nmF4ko_EQ>okeHCPCo00001?nQ4P02o`0003;ooooo00?o0000oooo
ooooool07_ooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`Go
00002_m400h00ol0003oN1@gogPD=`05ogPD=`Ko00002On9=E/00ol0003oVTIRoiY6HP0EoiY6HP03
o`000?nYD5ooZE1O01SoZE1O00?o0000okeHC_nmF4h04?nmF4h00ol0003o_EQ>okeHCP03okeHCP04
o`000?o@EQ?o0000o`0000CoXA800_l0000`ooooo`03o`000?oooooooooo01kooooo000Wooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool09_ooool3o`0000goA00>00?o0000ogPD=ol0
00001Ol0000?ohTeF`03o`000?nJAV;oVTIR01GoVTIR00?o0000ojU@GonYD5l06OnYD5l00ol0003o
_EQ>okeHCP0?okeHCP03o`000?nmF4ko_EQ>00Co_EQ>00?o0000om1F4oo@EQ<00_l00004oj4B00;o
0000;oooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo02?ooooo0_l0000=od@03PGo00005On9=E/00ol0003oVTIRoiY6HP0EoiY6HP03o`00
0?nYD5ooZE1O00_oZE1O4_l0000>okeHCP03o`000?nmF4ko_EQ>00Go_EQ>00Co0000om1F4oo@EQ?o
d5HC0_l00004oj4B00;o0000;Oooool00ol0003oooooooooo`0Mooooo`009_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo027ooooo0ol0000:od@03P?o00000_mV44H00ol0003oRCEK
ohTeF`0DohTeF`03o`000?nJAV;oVTIR01;oVTIR4_l0000>ojePM004o`000?o2KVco`Vi/ol9^K0Ko
00002?nmF4h00ol0003o_EQ>okeHCP05okeHCP03o`000?o@EQ?od5HC00?od5HC0_l00004oj4B0003
o`000?oooooooooo02_ooooo00?o0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Nooooo`Co00002?m400h3o`0000GoIQ1600?o0000ohTeFon9=E/0
5?n9=E/00ol0003oVTIRoiY6HP09oiY6HPWo00001?nPEWD00ol0003o[F1dojePM00IojePM003o`00
0?o2KVco`Vi/00Oo`Vi/1_l00002okeHCP03o`000?nmF4ko_EQ>00Ko_EQ>00?o0000om1F4oo@EQ<0
1?o@EQ<2o`0000?oXA8000?o0000ooooooooool0:oooool00ol0003oooooooooo`0Kooooo`009_oo
ool3o`0002oooooo00?o0000ooooooooool07?ooool4o`0000KoA00>0ol00007ofH@AP03o`000?n9
=E_oRCEK01GoRCEK00Co0000oiY6H_nJAV;oVTIR2?l0000=oj1FM@03o`000?n]H7Co[F1d01[o[F1d
00?o0000ol9^K?o2KV`03?o2KV`5o`0000Ko_EQ>00?o0000om1F4oo@EQ<01_o@EQ<01Ol0003oXA80
oj4B0?nQ4P3o000002cooooo00?o0000ooooooooool06oooool002Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Jooooo`Co00001?m400h3o`0000[oIQ1600?o0000ohTeFon9=E/0
4_n9=E/7o`0001GoX5Ie00?o0000ojePM?n]H7@06_n]H7@00ol0003o`Vi/ol9^K00?ol9^K003o`00
0?o2KVco000000Go000000?o_EQ>o`000?o@EQ<01oo@EQ<2o`0000;oXA8000?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Oooooo1Ol00002od@03P?o00003OmV44H00ol0003oRCEKohTeF`0<ohTeF`Ko
00000onCBg800ol0003oX5Ieoj1FM@0Foj1FM@03o`000?n]H7Co[F1d01[o[F1d00?o0000ol9^K?o2
KV`03oo2KV`00ol0003o`Vi/ol9^K005ol9^K0Co00002?o@EQ<2o`000003oj4B0?l0003ooooo02[o
oooo00?o0000ooooooooool06_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05Oooool8o`00013oIQ1600?o0000ohTeFon9=E/01On9=E/7o`0000WoTd]b00?o0000oj1FMOnP
EWD05_nPEWD00ol0003o[F1dojePM00JojePM003o`000?o2KVco`Vi/00oo`Vi/00?o0000ol9^K?o2
KV`01oo2KV`01?l0003oggi@o`000?l00008om1F4`?o0000:oooool00ol0003oooooooooo`0Ioooo
o`000oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Booooo`Oo00004_mV44H00ol0
003oRCEKohTeF`06o`00013oTd]b00?o0000oj1FMOnPEWD05onPEWD00ol0003o[F1dojePM00IojeP
M003o`000?o2KVco`Vi/00oo`Vi/00?o0000ol9^K?o2KV`01oo2KV`01?l0003oggi@ommnD?oOOU02
o`0000Sod5HC0_l0000[ooooo`03o`000?oooooooooo01Sooooo000;ooooo`05o`000?oooooooooo
ooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool04?ooool5o`000003o`401Ol0003oIQ16013oIQ161Ol0000Foi=;LP03o`000?nPEWGo
X5Ie01OoX5Ie00?o0000ojePM?n]H7@06_n]H7@00ol0003o`Vi/ol9^K00>ol9^K003o`000?o2KVco
`Vi/00So`Vi/00?o0000ommnD?oOOU000_oOOU02o`0000Sod5HC00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool03_oo
ool5o`000003o`401Ol0003oIQ1600koIQ160ol00002ogTbJ003o`000?nCBg;oTd]b01GoTd]b00?o
0000oj1FMOnPEWD06?nPEWD00ol0003o[F1dojePM00JojePM003o`000?o2KVco`Vi/00ko`Vi/00?o
0000ol9^K?o2KV`02?o2KV`00ol0003oggi@ommnD004ommnD0;o00001_o@EQ<00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`;o0000>?ooool00ol0003oooooooooo`0;ooooo`Go00000_l1
00D00ol0003oIQ16ofH@AP0:ofH@APCo00001Omi<VP00ol0003oTd]boi=;LP0Eoi=;LP03o`000?nP
EWGoX5Ie01SoX5Ie00?o0000ojePM?n]H7@03?n]H7@Bo`0000go`Vi/00?o0000ol9^K?o2KV`02?o2
KV`00ol0003oggi@ommnD006ommnD0;o00001Oo@EQ<00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02Oooool5o`0000?o0@0500?o
0000ofH@A_mV44H01_mV44H4o`0000SoNC9X00?o0000oi=;L_nCBg805_nCBg800ol0003oX5Ieoj1F
M@0Aoj1FMAKo00003_n`K8<01?l0003oa7b1olAlPOo4O845o`0000So`Vi/00?o0000ol9^K?o2KV`0
2Oo2KV`00ol0003oggi@ommnD007ommnD003o`000?o@EQ?od5HC00?od5HC00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0Fooooo`002oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01oooool4o`0000Co0@05
00?o0000ofH@A_mV44H01?mV44H3o`0000coNC9X00?o0000oi=;L_nCBg805_nCBg800ol0003oX5Ie
oj1FM@04oj1FM@go00001onTHX<00ol0003o/6b3ok1/P`0Jok1/P`03o`000?o4O87oa7b100Koa7b1
1Ol00003ol9^K003o`000?o2KVco`Vi/00Wo`Vi/00?o0000ommnD?oOOU002?oOOU02o`0000Cod5HC
00?o0000ooooooooool09_ooool3o`0001Oooooo000Tooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool01_ooool3o`0000Ko0@0500?o0000ofH@A_mV44H01?l0000?ogTbJ003o`000?nC
Bg;oTd]b01?oTd]b2_l0000DojARP`03o`000?n`K8?o/6b301[o/6b300?o0000olAlPOo4O8402oo4
O845o`0000[o`Vi/00?o0000ommnD?oOOU002_oOOU02o`0000?od5HC00?o0000ooooooooool08_oo
ool3o`0000;ooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`04ooooo`?o00001_l100D4o`0001?oNC9X00?o0000oi=;L_nCBg803_nCBg85
o`0000?oVUZ200?o0000ojARPonTHX<06?nTHX<00ol0003o/6b3ok1/P`0Jok1/P`03o`000?o4O87o
a7b100koa7b100?o0000olAlPOl000001?l00005ol9^K003o`000?oOOU3oggi@00coggi@0_l00000
0oo@EQ?o0000ooooo`0Pooooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo0_l00006o`401@?o00005_mi<VP00ol0
003oTd]boi=;LP09oi=;LPGo00002?nJFX800ol0003oY6:3ojARP`0HojARP`03o`000?n`K8?o/6b3
01[o/6b300?o0000olAlPOo4O8403_o4O8400ol0003oa7b1olAlP@04olAlP@Go000000?o`Vi/o`00
0?oOOU003_oOOU03o`0001gooooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00_l00006o`401@03o`000?lb04So000001Ko
NC9X00?o0000oi=;L_nCBg801OnCBg85o`0000goVUZ200?o0000ojARPonTHX<06?nTHX<00ol0003o
/6b3ok1/P`0Jok1/P`03o`000?o4O87oa7b100koa7b100?o0000olAlPOo4O8402Oo4O843o`00013o
ggi@0_l0000Iooooo`?o00002oooool00ol0003oooooooooo`0Eooooo`009?ooool2o`0003oooooo
0_l00006o`401@;o00000_lb04P00ol0003oNC9XogTbJ00DogTbJ003o`000?nCBg;oTd]b00Go0000
4_nJFX800ol0003oY6:3ojARP`0HojARP`03o`000?n`K8?o/6b301[o/6b300?o0000olAlPOo4O840
3_o4O8400ol0003oa7b1olAlP@0:olAlP@04o`000?oRU7Oo0000o`00013oggi@00?o0000oooooooo
ool04oooool3o`0000oooooo00?o0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0
?_ooool00ol0003o0@05o`401@04o`401@05o`000?lb04So<P18oc80B?l000005Omi<VP5o`0001Oo
VUZ200?o0000ojARPonTHX<06?nTHX<00ol0003o/6b3ok1/P`0Jok1/P`03o`000?o4O87oa7b100ko
a7b100?o0000olAlPOo4O8402_o4O8401?l0003ohYAgon:DMooRU7L2o`0000koggi@00?o0000oooo
ooooool04?ooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0?oooool00ol0003o0@05o`401@02o`401@;o00001?lb04P00ol0003oNC9XogTbJ00@ogTbJ0?o
00000_n5BGl00ol0003oVUZ2oiYJPP0GoiYJPP03o`000?nTHX?oY6:301SoY6:300?o0000ok1/Pon`
K8<06_n`K8<00ol0003oa7b1olAlP@0>olAlP@03o`000?o4O87oa7b100[oa7b100?o0000on:DMooR
U7L00ooRU7L00ol0003oggi@ommnD00<ommnD003o`000?oooooooooo00cooooo0ol0000Eooooo`03
o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03kooooo00?o0000o`401Ol100D0
0_l100D00ol0003o<P18oc80B004oc80B003o`000?mi<VSoNC9X00goNC9X0ol00005ohE9O`03o`00
0?nJFX;oVUZ201OoVUZ200?o0000ojARPonTHX<06?nTHX<00ol0003o/6b3ok1/P`0Jok1/P`03o`00
0?o4O87oa7b100koa7b100?o0000olAlPOo4O8402_o4O8400ol0003ohYAgon:DM`04on:DM`;o0000
3?oOOU000ol0003oooooooooo`09ooooo`?o00006?ooool00ol0003oooooooooo`0Dooooo`008ooo
ool00ol0003oooooooooo`0mooooo`04o`000?l100Go0@05o`401@;o00001_lb04P00ol0003oNC9X
ogTbJ00;ogTbJ0?o00002?n5BGl00ol0003oVUZ2oiYJPP0GoiYJPP03o`000?nTHX?oY6:301CoY6:3
5?l0000=ok1/P`03o`000?o4O87oa7b100ooa7b100?o0000olAlPOo4O8402Oo4O8400ol0003ohYAg
on:DM`06on:DM`;o00002_oOOU02o`0000Oooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo
000Sooooo`03o`000?oooooooooo03gooooo00Co0000o`401Ol100Go00002?lb04P00ol0003oNC9X
ogTbJ007ogTbJ0Co00002on5BGl00ol0003oVUZ2oiYJPP0GoiYJPP03o`000?nTHX?oY6:300_oY6:3
2Ol00004ojM/S`03o`000?nbMXoo/WJ?00go/WJ?4Ol0000>olAlP@03o`000?o4O87oa7b100Woa7b1
00?o0000on:DMooRU7L02?oRU7L2o`0000Woggi@00?o0000ooooooooool00_ooool3o`0001kooooo
00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0??ooool01?l0003o0@05o`40
1Ol00009oc80B003o`000?mi<VSoNC9X00CoNC9X0ol0000?ohE9O`03o`000?nJFX;oVUZ201OoVUZ2
00?o0000ojARPonTHX<00_nTHX<9o`0000goYfb?00?o0000ok9fSonbMXl06_nbMXl01?l0003oaHNA
olF7TOo5Qi45o`0000Woa7b100?o0000olAlPOo4O8402_o4O8400ol0003ohYAgon:DM`09on:DM`;o
00001ooOOU05o`00027ooooo00?o0000ooooooooool05?ooool002?ooooo0_l0000looooo`04o`00
0?l100Go0000o`0000[o<P1800Co0000ogTbJ?mi<VSoNC9X0ol0000AohE9O`03o`000?nJFX;oVUZ2
01GoVUZ22?l0000FojM/S`03o`000?nbMXoo/WJ?01[o/WJ?00?o0000olF7TOo5Qi401_o5Qi45o`00
00Coa7b100?o0000olAlPOo4O8402_o4O8400ol0003ohYAgon:DM`0;on:DM`;o00001OoOOU02o`00
02Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0>_ooool00ol0003o
0@05o`00000;oc80B003o`000?mi<VSo000000;o00005?n5BGl00ol0003oVUZ2oiYJPP0>oiYJPPOo
00000onNIXl00ol0003oYfb?ojM/S`0HojM/S`03o`000?nbMXoo/WJ?01[o/WJ?00?o0000olF7TOo5
Qi402oo5Qi45o`0000coa7b100?o0000on:DMooRU7L03OoRU7L2o`0000Coggi@0_l0000Tooooo`03
o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo03_ooooo0_l0000;oc80B0?o0000
5on5BGl00ol0003oVUZ2oiYJPP07oiYJPPOo00002_nNIXl00ol0003oYfb?ojM/S`0HojM/S`03o`00
0?nbMXoo/WJ?01[o/WJ?00?o0000olF7TOo5Qi403oo5Qi46o`0000Ooa7b100?o0000on:DMooRU7L0
3ooRU7L01?l0003oggi@ommnD?oOOU02o`0002Cooooo00?o0000ooooooooool04oooool002;ooooo
00?o0000ooooooooool0>_ooool00ol0003o<P18oc80B00:oc80B003o`000?m@7W;o000001SoQDUo
00?o0000oiYJP_nJFX801ol0000AoiiVS`03o`000?nWK8ooYfb?01SoYfb?00?o0000ok9fSonbMXl0
6_nbMXl00ol0003oaHNAolF7T@0?olF7T@03o`000?o5Qi7oaHNA00?oaHNA1Ol00002olAlP@03o`00
0?oRU7OohYAg013ohYAg0_l000001?oOOU3o0000olIX0?l0000Sooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo03Wooooo00?o0000oc80B?lb04P02Olb04P2o`0000;oD1ib
00?o0000ohE9Oon5BGl05On5BGl4o`0001SoWVJ?00?o0000ojM/SonWK8l06?nWK8l00ol0003o/WJ?
ok9fS`0Jok9fS`03o`000?o5Qi7oaHNA00ooaHNA00?o0000olF7TOo5Qi402?o5Qi44o`0001?ohYAg
1?l0000Sooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo03Wooooo00?o
0000oc80B?lb04P02?lb04P00ol0003oD1iboe0NLP02oe0NLP03o`000?n5BGooQDUo01;oQDUo0ol0
00000on=FY3o0000oiiVS`0IoiiVS`03o`000?nWK8ooYfb?01SoYfb?00?o0000ok9fSonbMXl06_nb
MXl00ol0003oaHNAolF7T@0?olF7T@03o`000?o5Qi7oaHNA00[oaHNA00Co0000on2RT?l0003o0000
4ooRU7L2o`0002?ooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0>?oo
ool00ol0003o<P18oc80B008oc80B003o`000?m@7W;oD1ib00?oD1ib00?o0000ohE9Oon5BGl03on5
BGl3o`0000CoSEZ@00?o0000oiiVSonNIXl06?nNIXl00ol0003oYfb?ojM/S`0HojM/S`03o`000?nb
MXoo/WJ?01[o/WJ?00?o0000olF7TOo5Qi403oo5Qi400ol0003oaHNAolF7T@0:olF7T@05o`000?oP
XY3oh::@on2RT?l000004_oRU7L00ol0003oaVP0o`00000Rooooo`03o`000?oooooooooo01?ooooo
000Qooooo`?o0000>Oooool00ol0003o<P18oc80B006oc80B0;o00001_m@7W800ol0003oQDUoohE9
O`0=ohE9O`;o00001on=FY000ol0003oWVJ?oiiVS`0HoiiVS`03o`000?nWK8ooYfb?01SoYfb?00?o
0000ok9fSonbMXl06_nbMXl00ol0003oaHNAolF7T@0?olF7T@03o`000?o5Qi7oaHNA00[oaHNA00?o
0000on2RT?oPXY000_oPXY02o`00013ohYAg0ol0000Sooooo`03o`000?oooooooooo01;ooooo000Q
ooooo`03o`000?oooooooooo03Wooooo00?o0000oc80B?lb04P01Olb04P00ol0003oD1iboe0NLP06
oe0NLP03o`000?n5BGooQDUo00[oQDUo0ol00009oheJT003o`000?nNIXooWVJ?01SoWVJ?00?o0000
ojM/SonWK8l06?nWK8l00ol0003o/WJ?ok9fS`0Jok9fS`03o`000?o5Qi7oaHNA00ooaHNA00?o0000
olF7TOo5Qi402_o5Qi400ol0003oh::@on2RT004on2RT0;o00003_oRU7L2o`000003olIX0?l0003o
oooo027ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0>?ooool00ol0
003o<P18oc80B004oc80B0;o00002?m@7W800ol0003oQDUoohE9O`09ohE9O`;o00003?n=FY000ol0
003oWVJ?oiiVS`0HoiiVS`03o`000?nWK8ooYfb?017oYfb?3ol0000Eok9fS`03o`000?o5Qi7oaHNA
00ooaHNA00?o0000olF7TOo5Qi402_o5Qi400ol0003oh::@on2RT006on2RT003o`000?oRU7OohYAg
00_ohYAg00Co0000ooFY??l0003o00008_ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0
003oooooooooo`0hooooo`03o`000?lb04So<P1800?o<P1800?o0000oe0NL_m@7W802?m@7W800ol0
003oQDUoohE9O`06ohE9O`?o00003_n=FY000ol0003oWVJ?oiiVS`0HoiiVS`03o`000?nWK8ooYfb?
00CoYfb?3Ol00007ojUeV@03o`000?ncOY[o/gjJ00Go/gjJ3ol00006ok9fS`03o`000?o5Qi7oaHNA
00ooaHNA00?o0000olF7TOo5Qi402_o5Qi400ol0003oh::@on2RT007on2RT0;o00002ooRU7L01Ol0
003omJTlo`000?o6J03o0000027ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooo
ooooool0>?ooool01?l0003o<P18oc80B?lb04P2o`0000_oD1ib00?o0000ohE9Oon5BGl00on5BGl3
o`0001;oSEZ@00?o0000oiiVSonNIXl05?nNIXl:o`0001CoZGFI00?o0000ok=nV_ncOYX05?ncOYX9
o`0000ooaHNA00?o0000olF7TOo5Qi402_o5Qi400ol0003oh::@on2RT009on2RT0;o00002OoRU7L0
0ol0003omJTlooFY?002o`00027ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000oooo
ooooool0=oooool01Ol0003o<P18oc80B?lb04So000000goD1ib00Co0000ohE9Oon5BGooQDUo0_l0
000EoheJT003o`000?nNIXooWVJ?00ooWVJ?1Ol00003oj5`V`03o`000?nYMIWoZGFI01SoZGFI00?o
0000ok=nV_ncOYX06_ncOYX00ol0003oaI2NolF@WP04o`0000_oaHNA00?o0000olF7TOo5Qi402Oo5
Qi400ol0003oh::@on2RT00<on2RT0;o00002?oRU7L01Ol0003omJTlo`000?o6J03o0000023ooooo
00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0=oooool01?l0003o<P18oc80
B?l0000>oe0NLPCo00005on=FY000ol0003oWVJ?oiiVS`0:oiiVS`Go00002?nQL9/00ol0003oZGFI
ojUeV@0HojUeV@03o`000?ncOY[o/gjJ01[o/gjJ00?o0000olF@W_o5T9h01?o5T9h5o`0000KoaHNA
00?o0000olF7TOo5Qi402Oo5Qi400ol0003oh::@on2RT00>on2RT003o`000?oRU7OohYAg00GohYAg
00?o0000ooFY??oeZC`00_l0000Pooooo`03o`000?oooooooooo01;ooooo000Pooooo`?o0000>?oo
ool3o`0000koD1ib0_l0000JoheJT003o`000?nNIXooWVJ?00GoWVJ?1Ol0000=oj5`V`03o`000?nY
MIWoZGFI01SoZGFI00?o0000ok=nV_ncOYX06_ncOYX00ol0003oaI2NolF@WP09olF@WPCo00000_o5
Qi400ol0003oaHNAolF7T@09olF7T@03o`000?oPXY3oh::@00ooh::@0_l00005on:DM`06o`000?oe
ZCcomJTlo`000?o6J03o00008?ooool00ol0003oooooooooo`0Aooooo`008?ooool00ol0003ooooo
ooooo`0gooooo`;o00003om@7W800ol0003oICj>o`00000JoheJT003o`000?nNIXooWVJ?00Go0000
4_nQL9/00ol0003oZGFIojUeV@0HojUeV@03o`000?ncOY[o/gjJ01Wo/gjJ00?o0000olF@W_o5T9h0
3_o5T9h4o`0000[oaHNA00?o0000on2RT?oPXY004OoPXY02o`0000?ohYAg00Co0000ooFY??oeZCco
mJTl0_l0000Pooooo`03o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0gooooo`03o`000?m@7W;oD1ib00goD1ib00Co0000ofDnS_mU
?Xko00006On=FY04o`0001OoXG2K00?o0000ojUeVOnYMIT05onYMIT00ol0003o/gjJok=nVP0Jok=n
VP03o`000?o5T9koaI2N017oaI2N1_l00005olF7T@03o`000?oPXY3oh::@01?oh::@00Co0000on:D
MooRU7Oo00001?oeZC`00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo000Eoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0gooooo`03o`000?m@7W;o
D1ib00_oD1ib0_l00003ofDnSP03o`000?n=FY3oSEZ@01CoSEZ@0ol000000onCJ9ko0000oj5`V`0H
oj5`V`03o`000?nYMIWoZGFI01OoZGFI00?o0000ok=nV_ncOYX06_ncOYX00ol0003oaI2NolF@WP0A
olF@WP03o`000?o5T9koaI2N00?oaI2N1?l000000oo5Qi7o0000on2RT00Eon2RT0?o00001?oeZC`2
o`0001oooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo03Kooooo0_l0000<oe0NLP03o`000?mU?XkoICj>00CoICj>00?o0000
oheJT?n=FY004On=FY02o`0000CoTfRN00?o0000oj5`VonQL9/06?nQL9/00ol0003oZGFIojUeV@0F
ojUeV@03o`000?ncOY[o/gjJ01[o/gjJ00?o0000olF@W_o5T9h04Oo5T9h00ol0003oaI2NolF@WP07
olF@WP?o00005ooPXY000ol0003omJTlooFY?003ooFY?003o`000?oooooooooo01gooooo00?o0000
ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo03Kooooo0_l0000;oe0NLP03o`000?mU?XkoICj>00GoICj>00?o0000oheJT?n=FY003_n=FY03
o`0000KoTfRN00?o0000oj5`VonQL9/06?nQL9/00ol0003oZGFIojUeV@0FojUeV@03o`000?ncOY[o
/gjJ01[o/gjJ00?o0000olF@W_o5T9h04Oo5T9h00ol0003oaI2NolF@WP08olF@WP03o`000?oLZZ?o
000001Koh::@00?o0000ooFY??oeZC`00ooeZC`2o`0001kooooo00?o0000ooooooooool04Oooool0
01Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03Oooooo00?o000Z
o`000?m@7W802?m@7W82o`0000SoICj>00?o0000oheJT?n=FY003?n=FY02o`0000[oTfRN00?o0000
oj5`VonQL9/05onQL9/00ol0003oZGFIojUeV@0FojUeV@03o`000?ncOY[o/gjJ01[o/gjJ00?o0000
olF@W_o5T9h04Oo5T9h00ol0003oaI2NolF@WP08olF@WP03o`000?oLZZ?og:ZS00;o00005?oPXY02
o`0000GomJTl00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol@
413ooooooooooooooooo410@00Gooooo0_l0000gooooo`03o`000?l002[o000000SoD1ib00?o0000
ofDnS_mU?Xh02?mU?Xh00ol0003oSEZ@oheJT009oheJT0?o00003?nCJ9h00ol0003oXG2Koj5`V`0G
oj5`V`03o`000?nYMIWoZGFI01KoZGFI00?o0000ok=nV_ncOYX06_ncOYX00ol0003oaI2NolF@WP0A
olF@WP03o`000?o5T9koaI2N00OoaI2N00?o0000ombZXooLZZ<00ooLZZ<00ol0003oh::@on2RT00A
on2RT0;o00001OoeZC`2o`0001gooooo00?o0000ooooooooool04Oooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03Kooooo00?o0000o`00:_l000001om@7W80
0ol0003oICj>ofDnSP09ofDnSP03o`000?n=FY3oSEZ@00OoSEZ@0_l0000?oi=XWP03o`000?nQL9_o
XG2K01OoXG2K00?o0000ojUeVOnYMIT04?nYMIT<o`0001Ko/gjJ00?o0000olF@W_o5T9h04_o5T9h0
0ol0003oaI2NolF@WP07olF@WP03o`000?oLZZ?og:ZS00Cog:ZS0_l0000Aon2RT003o`000?oob7co
000000GomJTl00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`005Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0=Oooool00ol0003o000Zo`000006
oe0NLP;o00003?mU?Xh00ol0003oSEZ@oheJT004oheJT0?o00004OnCJ9h00ol0003oXG2Koj5`V`0G
oj5`V`03o`000?nYMIWoZGFI00?oZGFI3Ol00006oj]nX`03o`000?neQjCo]HNT00?o]HNT2Ol0000=
ok=nVP03o`000?o5T9koaI2N01;oaI2N00?o0000olF@W_o5T9h01oo5T9h00ol0003og:ZSombZX`06
ombZX`03o`000?oPXY3oh::@00goh::@00Co0000ooo8O?oob7co00001OoeZC`00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03Gooooo00?o0000
o`00:_l000001Om@7W800ol0003oICj>ofDnSP0=ofDnSP04o`000?n=FY3oSEZ@oheJT0;o00005?nC
J9h00ol0003oXG2Koj5`V`0Eoj5`V`So00004on[OZ<00ol0003o]HNTokF7Y00<okF7Y0Wo00001?nc
OYX00ol0003oaI2NolF@WP0BolF@WP03o`000?o5T9koaI2N00OoaI2N00?o0000ombZXooLZZ<01ooL
ZZ<2o`0000goh::@00Go0000ooo8O?oob7coolQlo`000005ooFY?003o`000?oooooooooo01_ooooo
00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0=Oooool00ol0003o000Zo`00
0004oe0NLP03o`000?mU?XkoICj>00koICj>1?l0000Foi=XWP03o`000?nQL9_oXG2K013oXG2K1Ol0
0002ojAjY@03o`000?n[OZ?oZgjS01KoZgjS00?o0000okF7Y?neQj@05OneQj@7o`0001;oaI2N00?o
0000olF@W_o5T9h01_o5T9h00ol0003og:ZSombZX`0:ombZX`;o00002ooPXY001Ol0003oolQlooo8
O?oob7co000000GomJTl00?o0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`007ooo
ool00ol0003oooooooooo`0dooooo`04o`000?l002[o000Zo`0000;oD1ib0_l0000@ofDnSP;o0000
6OnCJ9h00ol0003oXG2Koj5`V`0;oj5`V`Go00001onTNZD00ol0003oZgjSoj]nX`0Foj]nX`03o`00
0?neQjCo]HNT01Wo]HNT00?o0000olBGZOo4UjT00ol0000?olF@WP03o`000?o5T9koaI2N00KoaI2N
00?o0000ombZXooLZZ<03?oLZZ<00ol0003oh::@on2RT008on2RT003o`000?oob7coolQl00;oolQl
00?o0000ooFY??oeZC`00_oeZC`00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo
000Nooooo`03o`000?oooooooooo03Gooooo00Ko0000o`00:_l002[o0000oe0NL_l0000AofDnSP03
o`000?mcEZ7o000001[oTfRN00?o0000oj5`VonQL9/01OnQL9/5o`0000coY7ZU00?o0000oj]nXon[
OZ<05_n[OZ<00ol0003o]HNTokF7Y00IokF7Y003o`000?o4UjWoa9NY00?oa9NY1?l0000;olF@WP03
o`000?o5T9koaI2N00KoaI2N00?o0000ombZXooLZZ<03OoLZZ<2o`0000Soh::@00?o0000ooo8O?oo
b7`00_oob7`00ol0003omJTlooFY?002ooFY?003o`000?oooooooooo01_ooooo00?o0000oooooooo
ool04?ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003o000Zo`00:P02o`00017oICj>
00Co0000og=FXOmcEZ7o00006_nCJ9h00ol0003oXG2Koj5`V`05o`00017oY7ZU00?o0000oj]nXon[
OZ<05_n[OZ<00ol0003o]HNTokF7Y00IokF7Y003o`000?o4UjWoa9NY00Ooa9NY0ol00008olF@WP03
o`000?o5T9koaI2N00GoaI2N00?o0000ombZXooLZZ<04?oLZZ<00ol0003oh::@on2RT005on2RT003
o`000?oob7coolQl00?oolQl00Go0000ooFY??oeZCcomJTlo`00000Mooooo`03o`000?oooooooooo
013ooooo000Nooooo`;o0000=Oooool01Ol0003o000Zo`00:_l002[o0000017oICj>00?o0000og=F
XOmcEZ400_mcEZ400ol0003oTfRNoi=XWP0Foi=XWPCo00005_nTNZD00ol0003oZgjSoj]nX`0Foj]n
X`03o`000?neQjCo]HNT01Wo]HNT00?o0000olBGZOo4UjT02_o4UjT4o`0000CoaI2N00?o0000olF@
W_o5T9h01Oo5T9h00ol0003og:ZSombZX`0AombZX`;o00001OoPXY000ol0003oolQlooo8O003ooo8
O005o`000?oeZCcomJTlooFY??l000007_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0
003oooooooooo`0dooooo`05o`000?l002[o000Zo`00:_l000003omU?Xh2o`0000GoLeJQ00?o0000
oi=XW_nCJ9h05?nCJ9h2o`000003oiMdZOl0003oY7ZU01OoY7ZU00?o0000oj]nXon[OZ<05_n[OZ<0
0ol0003o]HNTokF7Y00HokF7Y003o`000?o4UjWoa9NY00ooa9NY0ol000000oo5T9ko0000olF@WP06
olF@WP03o`000?oLZZ?og:ZS01?og:ZS00Go0000on2RT?oPXY3oh::@o`000007ooo8O004o`000?oe
ZCcomJTlo`0001kooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0<ooo
ool01?l0003o000Zo`00:_l002X2o`0000koICj>00?o0000og=FXOmcEZ401OmcEZ400ol0003oTfRN
oi=XWP0Boi=XWP;o00000onGM:T00ol0003oY7ZUojAjY@0GojAjY@03o`000?n[OZ?oZgjS01GoZgjS
00?o0000okF7Y?neQj@06?neQj@00ol0003oa9NYolBGZ@0BolBGZ@Co00001Oo5T9h00ol0003og:ZS
ombZX`0DombZX`;o000000?oh::@o`000?oob7`01_oob7`01?l0003omJTlooFY??l0000Nooooo`03
o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03?ooooo00Co0000o`00:_l002[o
000Z0_l0000=ofDnSP03o`000?mcEZ7oLeJQ00KoLeJQ00?o0000oi=XW_nCJ9h03onCJ9h3o`0000Ko
UgBY00?o0000ojAjYOnTNZD05_nTNZD00ol0003oZgjSoj]nX`0Eoj]nX`03o`000?neQjCo]HNT01So
]HNT00?o0000olBGZOo4UjT04oo4UjT00ol0003oa9NYolBGZ@03o`000003olF@W_l0003og:ZS01So
g:ZS0_l00008ooo8O004o`000?oeZCcomJTlo`0001gooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool0=?ooool01ol0003o000Zo`00:_l002[o0000o`00L_l000002omU?Xh0
0ol0003oLeJQog=FX@07og=FX@03o`000?nCJ9koTfRN00goTfRN0_l00009oiMdZ@03o`000?nTNZGo
Y7ZU01KoY7ZU00?o0000oj]nXon[OZ<05On[OZ<00ol0003o]HNTokF7Y00HokF7Y003o`000?o4UjWo
a9NY01?oa9NY00?o0000olBGZOo4UjT00oo4UjT3o`0001Wog:ZS00?o0000ooo8O?oob7`01_oob7`0
1?l0003omJTlooFY??l0000Mooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooo
oooo03?ooooo00Go0000o`00:_l002[o000Zo`000002o`00LP03o`000?mU?XkoICj>00OoICj>0_l0
000;og=FX@03o`000?nCJ9koTfRN00[oTfRN0_l0000;oiMdZ@03o`000?nTNZGoY7ZU01KoY7ZU00?o
0000oj]nXon[OZ<05On[OZ<00ol0003o]HNTokF7Y00HokF7Y003o`000?o4UjWoa9NY01Coa9NY00?o
0000olBGZOo4UjT00oo4UjT00ol0003of;2ao`00000HombZX`03o`000?oob7coolQl00OoolQl00?o
0000ooFY??l000007Oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0c
ooooo`05o`000?l002[o000Zo`00:_l000000_l007800ol0003oICj>ofDnSP06ofDnSP03o`000?mc
EZ7oLeJQ00_oLeJQ00?o0000oi=XW_nCJ9h02?nCJ9h2o`0000goUgBY00?o0000ojAjYOnTNZD05_nT
NZD00ol0003oZgjSoj]nX`0Eoj]nX`03o`000?neQjCo]HNT01So]HNT00?o0000olBGZOo4UjT05?o4
UjT00ol0003oa9NYolBGZ@02olBGZ@04o`000?oH/;7of;2aomR`/@;o00005OoLZZ<00ol0003onMBR
o`000008ooo8O003o`000?oeZCco000001gooooo00?o0000ooooooooool03oooool001gooooo0_l0
000dooooo`04o`000?l002[o000Zo`0000?o001b00?o0000ofDnS_mU?Xh01OmU?Xh00ol0003oLeJQ
og=FX@0<og=FX@03o`000?nCJ9koTfRN00KoTfRN0_l0000?oiMdZ@03o`000?nTNZGoY7ZU01KoY7ZU
00?o0000oj]nXon[OZ<02On[OZ<@o`0001Oo]HNT00?o0000olBGZOo4UjT05?o4UjT00ol0003oa9NY
olBGZ@02olBGZ@03o`000?oH/;7of;2a00?of;2a00?o0000ombZXooLZZ<04_oLZZ<00ol0003onMBR
o`000009ooo8O0;o00007_ooool00ol0003oooooooooo`0>ooooo`007Oooool00ol0003ooooooooo
o`0cooooo`04o`000?l002[o000Zo`0000?o001b00?o0000ofDnS_mU?Xh01?mU?Xh00ol0003oLeJQ
og=FX@0=og=FX@03o`000?nCJ9koTfRN00?oTfRN0ol0000BoiMdZ@03o`000?nTNZGoY7ZU01?oY7ZU
3_l0000<ojf7[@04o`000?nfSjko]Xn^okJ?[POo00003oneQj@00ol0003oa9NYolBGZ@0EolBGZ@03
o`000?o4UjWoa9NY00;oa9NY00?o0000omR`/OoH/;401?oH/;42o`0001;og:ZS00Co0000ooWDX_oi
e:;o00002?oob7`2o`0001kooooo00?o0000ooooooooool03_ooool001gooooo00?o0000oooooooo
ool0<oooool01?l0003o000Zo`00:_l00003o`00LP03o`000?mU?XkoICj>00;oICj>0_l0000@og=F
X@04o`000?nCJ9koTfRNoi=XWP;o00005OnGM:T00ol0003oY7ZUojAjY@0?ojAjY@Co00000_nUPjl0
0ol0003o[HN]ojf7[@0Eojf7[@03o`000?nfSjko]Xn^00So]Xn^1_l00009okF7Y003o`000?o4UjWo
a9NY01Goa9NY00Go0000olBGZOo4UjWoa9NYo`000009omR`/@03o`000?oLZZ?og:ZS00kog:ZS00Go
0000ooWDX_oie:;onMBRo`000009ooo8O003o`000?oooooooooo01cooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0=?ooool00ol0003o000Zo`000004o`00LP05o`000?mU
?XkoICj>ofDnS_l000004omcEZ43o`0001OoUgBY00?o0000ojAjYOnTNZD02onTNZD4o`0000KoYH>_
00?o0000ojf7[On]Qjd05On]Qjd00ol0003o]Xn^okJ?[P0>okJ?[POo00000_neQj@00ol0003oa9NY
olBGZ@0EolBGZ@05o`000?o4UjWoa9NYolBGZOl000002_oH/;42o`0000kog:ZS00?o0000ooWDX_oi
e:800_oie:800ol0003oolQlooo8O006ooo8O003o`000?oooooooooo01cooooo00?o0000oooooooo
ool03_ooool001cooooo00?o0000ooooooooool0=?ooool00ol0003o000Zo`000005o`00LP03o`00
0?mU?Xko000001?oLeJQ0_l0000IoiMdZ@03o`000?nTNZGoY7ZU00SoY7ZU0ol0000:ojF3[`03o`00
0?n]Qjgo[HN]01Go[HN]00?o0000okJ?[_nfSjh05OnfSjh5o`0001Goa9NY00Go0000olBGZOo4UjWo
a9NYo`00000<omR`/@03o`000?oLZZ?og:ZS00_og:ZS00?o0000ooWDX_oie:800_oie:800ol0003o
olQlooo8O006ooo8O003o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool001cooooo
00?o0000ooooooooool0<oooool01?l0003o000Zo`00:_l00005o`00LP;o00004omcEZ400ol0003o
OVV`o`00000IoiMdZ@03o`000?nTNZGoY7ZU00CoY7ZU1?l0000=ojF3[`03o`000?n]Qjgo[HN]01Go
[HN]00?o0000okJ?[_nfSjh05onfSjh00ol0003o`Yjcol:N/`03o`0001;oa9NY00Co0000olBGZOo4
UjWo00003_oH/;400ol0003og:ZSombZX`09ombZX`03o`000?oie:;onMBR00ConMBR00?o0000ooo8
O?oob7`01Ooob7`00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo03?ooooo00?o0000o`00:_l000001_l007800ol0003oLeJQog=FX@0Aog=FX@05
o`000?mnJK3oOVV`ogiY/?l000006OnGM:T00ol0003oY7ZUo`000003o`0001;oYH>_00?o0000ojf7
[On]Qjd05?n]Qjd00ol0003o]Xn^okJ?[P0GokJ?[P03o`000?o2W[?o`Yjc00?o`Yjc0ol0000=olBG
Z@?o00000_o4UjT00ol0003of;2aomR`/@0=omR`/@;o00002OoLZZ<00ol0003onMBRooWDXP04ooWD
XP03o`000?oob7coolQl00CoolQl00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>oooo
o`007?ooool00ol0003oooooooooo`0cooooo`03o`000?l002[o000000Ko001b00?o0000og=FXOmc
EZ404?mcEZ400ol0003oOVV`ogiY/002ogiY/003o`000?nGM:WoUgBY01KoUgBY0ol0000FojF3[`03
o`000?n]Qjgo[HN]01Co[HN]00?o0000okJ?[_nfSjh05_nfSjh00ol0003o`Yjcol:N/`07ol:N/`?o
00001oo4UjT3o`0000;oa9NY00Co0000olBGZOo4UjWo00004OoH/;400ol0003og:ZSombZX`06ombZ
X`03o`000?oie:;onMBR00GonMBR00?o0000ooo8O?oob7`00ooob7`00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo000Looooo`;o0000=?ooool2o`0000Ko001b00?o0000ob8XW_l0
00004?mcEZ400ol0003oOVV`ogiY/003ogiY/003o`000?nGM:WoUgBY01CoUgBY0_l000000onKOkCo
0000ojF3[`0FojF3[`03o`000?n]Qjgo[HN]01?o[HN]00?o0000okJ?[_nfSjh05onfSjh00ol0003o
`Yjcol:N/`0:ol:N/`?o000000Coa9NYo`000?l0003o00001_o4UjT2o`0001?of;2a0_l00005ombZ
X`03o`000?oie:;onMBR00OonMBR00?o0000ooo8O?oob7`00_oob7`00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03Cooooo0_l00006o`00LP03
o`000?lR:9ko000000ooLeJQ00?o0000ogiY/?mnJK001OmnJK000ol0003oUgBYoiMdZ@0AoiMdZ@;o
00000onKOk@00ol0003oYH>_ojF3[`0EojF3[`03o`000?n]Qjgo[HN]01?o[HN]00?o0000okJ?[_nf
Sjh05onfSjh00ol0003o`Yjcol:N/`0;ol:N/`Go00002?o4UjT00ol0003of;2aomR`/@0ComR`/@03
o`000?oLZZ?og:ZS00;og:ZS00?o0000ooWDX_oie:801ooie:800ol0003oolQlooo8O002ooo8O003
o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0
=?ooool2o`0000Ko001b00?o0000ob8XW_l000003_mcEZ400ol0003oOVV`ogiY/006ogiY/003o`00
0?nGM:WoUgBY00ooUgBY0_l00006oi]o]003o`000?nUPjooYH>_01CoYH>_00?o0000ojf7[On]Qjd0
4on]Qjd00ol0003o]Xn^okJ?[P0GokJ?[P03o`000?o2W[?o`Yjc00Oo`Yjc1?l00005ol:N/`?o0000
1Oo4UjT2o`0001Gof;2a0_l00002ombZX`03o`000?oie:;onMBR00SonMBR00Go0000ooo8O?oob7co
olQlo`00000Pooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03Cooooo
00?o0000o`00L_l007801?l007801Ol0003o8RRNob8XW_lR:9ko000000coLeJQ00?o0000ogiY/?mn
JK001omnJK000ol0003oUgBYoiMdZ@0=oiMdZ@;o00002?nKOk@00ol0003oYH>_ojF3[`0DojF3[`03
o`000?n]Qjgo[HN]01?o[HN]00?o0000okJ?[_nfSjh05_nfSjh00ol0003o`Yjcol:N/`05ol:N/`?o
00003?o2W[<3o`000005olBGZOl0003of;2aomR`/Ol000005_oH/;42o`0000_onMBR00Go0000ooo8
O?oob7coolQlo`00000Pooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
03Cooooo00?o0000o`00L_l007801?l007801Ol0003o8RRNob8XW_lR:9ko000000[oLeJQ0_l0000;
ogiY/003o`000?nGM:WoUgBY00[oUgBY0_l0000:oi]o]003o`000?nUPjooYH>_01CoYH>_00?o0000
ojf7[On]Qjd04on]Qjd00ol0003o]Xn^okJ?[P0FokJ?[P03o`000?o2W[?o`Yjc00;o`Yjc0ol0000B
ol:N/`?o000000?of;2ao`000?oH/;405_oH/;400ol0003onMBRooWDXP0:ooWDXP04o`000?oob7co
olQlo`00023ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0=?ooool0
0ol0003o001bo`00LP04o`00LP05o`000?lR:9ko8RRNob8XW_l000002OmcEZ400ol0003oOVV`ogiY
/00;ogiY/003o`000?nGM:WoUgBY00SoUgBY0_l0000<oi]o]003o`000?nUPjooYH>_01GoYH>_00?o
0000ojf7[On]Qjd04_n]Qjd00ol0003o]Xn^okJ?[P0FokJ?[P03o`000?o2W[?o000000;o00005_o2
W[<01Ol0003od[Fmo`000?oH/;7o000001Kof;2a00?o0000ooWDX_oie:802_oie:800ol0003oolQl
o`00000Qooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03Cooooo00?o
0000o`00L_l007800ol007800ol0003o8RRNob8XWP03ob8XWP03o`000?mcEZ7oLeJQ00GoLeJQ00?o
0000ogiY/?mnJK003?mnJK000ol0003oUgBYoiMdZ@06oiMdZ@;o00003onKOk@00ol0003oYH>_ojF3
[`0DojF3[`03o`000?n]Qjgo[HN]01;o[HN]00?o0000okJ?[_nfSjh05?nfSjh4o`0001So`Yjc00Oo
0000om:e_OoB]Kgod[Fmo`000?oH/;7o000001Cof;2a00?o0000onoH^_l000003?oie:82o`00027o
oooo00?o0000ooooooooool03Oooool001_ooooo0_l0000fooooo`03o`000?l007;o001b00;o001b
00?o0000ob8XW_lR:9h00olR:9h00ol0003oLeJQog=FX@04og=FX@03o`000?mnJK3oOVV`00koOVV`
00?o0000oiMdZOnGM:T00onGM:T2o`00017oVgnd00?o0000ojF3[onUPjl05?nUPjl00ol0003o[HN]
ojf7[@08ojf7[@ko00004?nfSjh3o`000003okJ?[_l0003o`Yjc01Wo`Yjc00?o0000om:e_OoB]Kd0
0_oB]Kd3o`0001?of;2a00?o0000onoH^_l000003?oie:82o`0002;ooooo00?o0000ooooooooool0
3?ooool001[ooooo00?o0000ooooooooool0=_ooool01Ol0003o001bo`00L_l007;o000000Ko8RRN
00?o0000og=FXOmcEZ400omcEZ400ol0003oOVV`ogiY/00?ogiY/004o`000?nGM:WoUgBYoiMdZ@;o
00004onKOk@00ol0003oYH>_ojF3[`0BojF3[`go00002_n^T;L01?l0003o]YNhokJG^?nfUkP6o`00
00Oo]Xn^0ol00004okJ?[P03o`000?o2W[?o`Yjc01Oo`Yjc00?o0000om:e_OoB]Kd01OoB]Kd2o`00
017of;2a00Go0000onoH^_o_f;[okmRjo`00000<ooWDXP03o`000?oooooooooo023ooooo00?o0000
ooooooooool03?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0fooooo`05o`000?l007;o001bo`00L_l00000
1olR:9h01Ol0003oLeJQog=FXOmcEZ7o000001;oOVV`00Co0000oiMdZOl0003o00005_nKOk@00ol0
003oYH>_ojF3[`0>ojF3[`?o00000_nWS;T00ol0003o[Y2gojj@]`0Bojj@]`03o`000?nfUkSo]YNh
00Oo]YNh1ol00007okJ?[P03o`000?o2W[?o`Yjc01Oo`Yjc00?o0000om:e_OoB]Kd01_oB]Kd2o`00
00oof;2a00?o0000onoH^_o_f;X00oo_f;X00ol0003onMBRooWDXP09ooWDXP03o`000?oooooooooo
023ooooo00?o0000ooooooooool03?ooool00004oiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=_ooool01Ol0003o001bo`00L_l007;o
000000Oo8RRN00Co0000og=FXOmcEZ7o00004omnJK02o`0001SoVgnd00?o0000ojF3[onUPjl02_nU
Pjl4o`0000GoYhbi00?o0000ojj@]on^T;L04_n^T;L00ol0003o]YNhokJG^007okJG^0Co000000?o
]YNho`000?l000001?l00002okJ?[P03o`000?o2W[?o`Yjc01Oo`Yjc00?o0000om:e_OoB]Kd02?oB
]Kd2o`0000kof;2a00?o0000onoH^_o_f;X00oo_f;X00ol0003onMBRooWDXP08ooWDXP03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Kooooo00Co0000o`00L_l007;o00002?lR
:9h00ol0003oLeJQo`00000CogiY/003o`000?n7NKgo000001SoVgnd00?o0000ojF3[onUPjl01onU
Pjl3o`0000WoYhbi00?o0000ojj@]on^T;L04_n^T;L00ol0003o]YNhokJG^004okJG^0?o00002onf
UkP4o`0001So`Yjc00?o0000om:e_OoB]Kd02OoB]Kd2o`0000cof;2a00?o0000onoH^_o_f;X01Oo_
f;X00ol0003onMBRooWDXP07ooWDXP03o`000?oooooooooo027ooooo00?o0000ooooooooool03?oo
ool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo03Kooooo00Co0000o`00L_l007;o00002OlR:9h00ol0003oOVV`ogiY/00AogiY/005o`000?n7
NKgoQgVmohMi_Ol000005onKOk@00ol0003oYH>_ojF3[`03ojF3[`Co00003?nWS;T00ol0003o[Y2g
ojj@]`0Bojj@]`04o`000?nfUkSo]YNhokJG^0?o00004?nfUkP00ol0003o`:Fmo`000002o`0001Co
`Yjc00?o0000om:e_OoB]Kd02ooB]Kd3o`0000[of;2a00?o0000onoH^_o_f;X01Oo_f;X00ol0003o
nMBRooWDXP07ooWDXP03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool000?ooooo
00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0=_ooool01?l0003o001bo`00L_l00009ob8XWP03o`000?mnJK3oOVV`013oOVV`00?o0000ohMi
_On7NKd00_n7NKd00ol0003oVgndoi]o]00Foi]o]003o`000?nUPjoo000000;o00004OnWS;T00ol0
003o[Y2gojj@]`0Aojj@]`Co00004onfUkP00ol0003o`:Fmol2U_@02ol2U_@?o00004Oo2W[<00ol0
003od[Fmom:e_@0<om:e_@03o`000?oB]Kgo000000Sof;2a00?o0000onoH^_o_f;X01oo_f;X00ol0
003onMBRooWDXP05ooWDXP03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool000?o
oooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03So
oooo0_l00009ob8XWP03o`000?m5D;Wo0000013oOVV`00?o0000ohMi_On7NKd01?n7NKd00ol0003o
Vgndoi]o]00Doi]o]0?o00005?nWS;T00ol0003o[Y2gojj@]`0>ojj@]`Co00005OnfUkP00ol0003o
`:Fmol2U_@06ol2U_@?o00003_o2W[<00ol0003od[Fmom:e_@0=om:e_@03o`000?oB]Kgo000000Oo
f;2a00?o0000onoH^_o_f;X02?o_f;X00ol0003onMBRooWDXP04ooWDXP03o`000?oooooooooo02?o
oooo00?o0000ooooooooool02oooool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000oooooooo
ool01_ooool2o`0003Wooooo0_l00009ob8XWP03o`000?m5D;Wo000000ooOVV`00?o0000ohMi_On7
NKd01On7NKd00ol0003oVgndoi]o]00Boi]o]0;o000000?oWHZno`000?nWS;T05?nWS;T00ol0003o
[Y2gojj@]`0;ojj@]`?o00000on^T;L00ol0003o]YNhokJG^00CokJG^003o`000?o0YKgo`:Fm00Wo
`:Fm0_l0000;ol:N/`03o`000?oB]Kgod[Fm00kod[Fm00?o0000om:e_OoB]Kd00_l00004omR`/@03
o`000?o_f;[okmRj00WokmRj00?o0000ooWDX_oie:800ooie:82o`0002Gooooo00?o0000oooooooo
ool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo03So
oooo00?o001bo`000?lR:9h02?lR:9h01?l0003oAE2iodE@^Ol0000=ogiY/003o`000?n7NKgoQgVm
00OoQgVm00?o0000oi]o]?nKOk@03onKOk@2o`0000CoWHZn00?o0000ojN<^OnWS;T04_nWS;T00ol0
003o[Y2gojj@]`08ojj@]`?o00001_n^T;L00ol0003o]YNhokJG^00CokJG^003o`000?o0YKgo`:Fm
00_o`:Fm0ol00008ol:N/`03o`000?oB]Kgod[Fm00ood[Fm00Go0000om:e_OoB]Kgod[Fmo`000002
omR`/@03o`000?o_f;[okmRj00_okmRj00?o0000ooWDX_oie:800_oie:800ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03Sooooo00?o0000ob8X
W_lR:9h01olR:9h01Ol0003oAE2iodE@^Om5D;Wo000000coOVV`00?o0000ohMi_On7NKd02On7NKd0
0ol0003oVgndoi]o]00<oi]o]0;o00001_nMR[h00ol0003oYhbiojN<^@0BojN<^@03o`000?n^T;Oo
[Y2g00Go[Y2g0ol00009ojj@]`03o`000?nfUkSo]YNh01?o]YNh00?o0000ol2U_Oo0YKd03_o0YKd3
o`0000Co`Yjc00?o0000om:e_OoB]Kd04OoB]Kd01ol0003od[Fmom:e_OoB]Kgo0000omR`/Ol00000
3Oo_f;X00ol0003onMBRooWDXP02ooWDXP03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
2oooool001Wooooo00?o0000ooooooooool0>?ooool00ol0003o8RRNob8XWP07ob8XWP03o`000?m5
D;WoAE2i00;oAE2i00?o0000ogiY/?mnJK002?mnJK000ol0003oQgVmohMi_@0:ohMi_@03o`000?nK
OkCoVgnd00WoVgnd0ol00008oif:_P03o`000?nWS;WoYhbi01;oYhbi00Co0000ojj@]on^T;Oo[Y2g
1?l0000<ojj@]`03o`000?nfUkSo]YNh01;o]YNh00?o0000ol2U_Oo0YKd04_o0YKd3o`000003ol:N
/ol0003od[Fm01?od[Fm00Go0000om:e_OoB]Kgod[Fmo`00000?onoH^P03o`000?oie:;onMBR00;o
00009_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0iooooo`03o`00
0?lR:9ko8RRN00Go8RRN00?o0000odE@^Om5D;T01?m5D;T00ol0003oOVV`ogiY/006ogiY/003o`00
0?n7NKgoQgVm00coQgVm00?o0000oi]o]?nKOk@01_nKOk@2o`0000coWHZn00?o0000ojN<^OnWS;T0
4OnWS;T4o`00013o[Y2g00?o0000okJG^?nfUkP04_nfUkP00ol0003o`:Fmol2U_@0Eol2U_@;o0000
5OoB]Kd01?l0003od[Fmom:e_Ol0000@onoH^P03o`000?oie:;o000002Oooooo00?o0000oooooooo
ool02oooool001Sooooo00?o0000ooooooooool0>_ooool00ol0003o8RRNob8XWP05ob8XWP03o`00
0?m5D;WoAE2i00CoAE2i00?o0000ogiY/?mnJK001OmnJK000ol0003oQgVmohMi_@0=ohMi_@03o`00
0?nKOkCoVgnd00CoVgnd0_l0000>oif:_P03o`000?nWS;WoYhbi00ooYhbi1?l0000Bojj@]`03o`00
0?nfUkSo]YNh01;o]YNh00?o0000ol2U_Oo0YKd05Oo0YKd00ol0003ocKW7o`00000Eom:e_@;o0000
00?oi=S:o`000?o_f;X03_o_f;X00ol0003onMBRo`00000Wooooo`03o`000?oooooooooo00_ooooo
000Hooooo`03o`000?oooooooooo03[ooooo00?o0000ob8XW_lR:9h01OlR:9h00ol0003oAE2iodE@
^@05odE@^@03o`000?mnJK3oOVV`00?oOVV`00?o0000ohMi_On7NKd03on7NKd01?l0003oVgndoi]o
]?nKOk@2o`00013oWHZn00?o0000ojN<^OnWS;T03?nWS;T3o`0000?oYhbi00?o0000ojj@]on^T;L0
4?n^T;L00ol0003o]YNhokJG^00AokJG^003o`000?o0YKgo`:Fm01Go`:Fm00Go0000olfiaoo=^LOo
cKW7o`00000Dom:e_@04o`000?oTf<[oi=S:o`00013okmRj0_l0000Xooooo`03o`000?oooooooooo
00[ooooo000Hooooo`03o`000?oooooooooo03_ooooo00?o0000ob8XW_lR:9h00olR:9h00ol0003o
AE2iodE@^@06odE@^@03o`000?mnJK3oOVV`00;oOVV`00?o0000ohMi_On7NKd04?n7NKd01?l0003o
Vgndo`000?l0000Coif:_P03o`000?nWS;WoYhbi00OoYhbi1?l00006ojN<^@03o`000?n^T;Oo[Y2g
013o[Y2g00?o0000okJG^?nfUkP04OnfUkP00ol0003o`:Fmol2U_@0Dol2U_@03o`000?o=^LOocKW7
00?ocKW700?o0000om:e_OoB]Kd04?oB]Kd00ol0003oi=S:o`000002onCHbP03o`000?o_f;[okmRj
00gokmRj00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`006?ooool2o`0003co
oooo00?o0000ob8XW_lR:9h00olR:9h00ol0003oAE2iodE@^@07odE@^@04o`000?mnJK3oOVV`o`00
01CoQgVm00?o0000oif:__nMR[h04onMR[h00ol0003oYhbiojN<^@04ojN<^@?o00002?nWS;TIo`00
013o]YNh00?o0000ol2U_Oo0YKd05?o0YKd00ol0003ocKW7olfia`04olfia`;o00004?oB]Kd01?l0
003oi=S:onCHb_l00002onCHbP03o`000?o_f;[okmRj00_okmRj0_l0000Yooooo`03o`000?oooooo
oooo00[ooooo000Hooooo`03o`000?oooooooooo03cooooo00?o0000ob8XW_lR:9h00_lR:9h00ol0
003oAE2iodE@^@07odE@^@03o`000?mnJK3o000001GoQgVm00?o0000oif:__nMR[h04onMR[h01?l0
003oYhbiojN<^OnWS;T3o`0000SoYhbi0ol00002ojRFa003o`000?n^VL;o[YW2013o[YW200Co0000
okFP`oneX<?o]J331ol00009okJG^003o`000?o0YKgo`:Fm01?o`:Fm00?o0000olfiaoo=^LL01oo=
^LL00ol0003od[Fmom:e_@0<om:e_@03o`000?oTf<[oi=S:00;oi=S:00?o0000onCHb_l000003?o_
f;X3o`0002Wooooo00?o0000ooooooooool02_ooool001Sooooo00?o0000ooooooooool0??ooool0
1Ol0003o8RRNob8XW_lR:9ko000000_oAE2i00?o0000ohMi_On7NKd04on7NKd00ol0003oSXO7o`00
000Eoif:_P?o00001onWS;T4o`0000GoZ9K400?o0000ojjI`_n^VL804?n^VL800ol0003o]J33okFP
``08okFP``Ko00000_nfUkP00ol0003o`:Fmol2U_@0Col2U_@03o`000?o=^LOocKW700WocKW700?o
0000om:e_OoB]Kd02_oB]Kd00ol0003oi=S:onCHbP04onCHbP03o`000?oTf<[o000000_okmRj0_l0
000Zooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooooooo03gooooo00Go0000
ob8XW_lR:9ko8RRNo`00000;odE@^@03o`000?n7NKgoQgVm01;oQgVm00Go0000ohj7aon>QlOoSXO7
o`00000@oif:_PGo00001OnWS;T4o`0000[oZ9K400?o0000ojjI`_n^VL803on^VL800ol0003o]J33
okFP``0>okFP``?o00005Oo0YKd00ol0003ocKW7olfia`0:olfia`03o`000?oB]Kgod[Fm00Wod[Fm
00?o0000onCHb_oTf<X01?oTf<X00ol0003oi=S:o`00000:onoH^P?o0000:_ooool00ol0003ooooo
ooooo`0:ooooo`005oooool00ol0003oooooooooo`0nooooo`03o`000?lR:9ko000000coAE2i00?o
GVg:o`000?n7NKd04On7NKd00ol0003oSXO7ohj7a`02ohj7a`03o`000?nMR[koWHZn00_oWHZn0ol0
0004oif:_P03o`000?nWS;WoYhbi00?o00003_nXU/@00ol0003o[YW2ojjI`P0?ojjI`P03o`000?ne
X<?o]J33013o]J3300?o0000okf[aol000000_l0000@ol2U_@03o`000?o=^LOocKW700cocKW700?o
0000om:e_OoB]Kd01ooB]Kd00ol0003oi=S:onCHbP06onCHbP03o`000?oTf<[o000000SokmRj00?o
0000omOeWol00000:oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`0n
ooooo`03o`000?lR:9ko000000_oAE2i00Co0000oei]b_mNKL[o00004?n7NKd00ol0003oSXO7ohj7
a`04ohj7a`03o`000?nMR[koWHZn00OoWHZn0ol00007oif:_P?o00004OnXU/@00ol0003o[YW2ojjI
`P0?ojjI`P03o`000?neX<?o]J3300oo]J3300?o0000okf[aonmZlL00onmZlL2o`0000ko`:Fm00?o
0000olfiaoo=^LL03Oo=^LL2o`0000Kod[Fm00?o0000onCHb_oTf<X02?oTf<X2o`0000OokmRj00Co
0000omOeWooGmIoo0000;?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003ooooooooo
o`0nooooo`03o`000?lR:9ko000000_oAE2i00Go0000oei]b_mNKL[oGVg:o`00000>ohMi_@03o`00
0?n>QlOoSXO700KoSXO700?o0000oif:__nMR[h00onMR[h3o`0000SoWHZn0_l000000onPULSo0000
ojRFa00AojRFa003o`000?n^VL;o[YW200oo[YW200?o0000okFP`oneX<<03oneX<<00ol0003o_J_7
okf[a`05okf[a`?o00002_o0YKd00ol0003ocKW7olfia`0@olfia`03o`000?oB]Kgod[Fm00;od[Fm
00?o0000onCHb_oTf<X02_oTf<X2o`0000KokmRj00Co0000omOeWol0003o0000;?ooool00ol0003o
ooooooooo`09ooooo`005oooool00ol0003oooooooooo`0oooooo`03o`000?m5D;WoAE2i00[oAE2i
00?o0000oei]b_mNKLX00_mNKLX00ol0003oQgVmohMi_@0:ohMi_@03o`000?n>QlOoSXO700SoSXO7
1Ol00009oif:_P;o00001?nPULP00ol0003oZ9K4ojRFa00?ojRFa003o`000?n^VL;o[YW200oo[YW2
00?o0000okFP`oneX<<03_neX<<00ol0003o_J_7okf[a`09okf[a`;o00001oo0YKd00ol0003ocKW7
olfia`0Bolfia`05o`000?oB]Kgod[Fmom:e_Ol000003OoTf<X00ol0003okmRjonoH^P03onoH^P04
o`000?oGmIooeoFOo`0002gooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000oooooooo
ool0?oooool00ol0003oAE2iodE@^@09odE@^@03o`000?mNKL[oGVg:00CoGVg:00?o0000ohMi_On7
NKd02?n7NKd00ol0003oSXO7ohj7a`07ohj7a`?o00002onMR[h2o`0000KoX9G800?o0000ojRFa?nX
U/@04?nXU/@00ol0003o[YW2ojjI`P0=ojjI`P03o`000?neX<?o]J3300oo]J3300?o0000okf[aonm
ZlL02onmZlL2o`0000Go`:Fm00?o0000olfiaoo=^LL04oo=^LL00ol0003od[Fmo`00000>onCHbP;o
00000oo_f;X00ol0003oeoFOomOeW`02o`0002gooooo00?o0000ooooooooool02Oooool001Oooooo
0_l00011ooooo`03o`000?m5D;WoAE2i00SoAE2i00?o0000oei]b_mNKLX01?mNKLX00ol0003oQgVm
ohMi_@07ohMi_@03o`000?n>QlOoSXO700GoSXO70ol00003ohj7a`03o`000?nMR[koWHZn00OoWHZn
00?o0000oj2Eb?nPULP01onPULP00ol0003oZ9K4ojRFa00?ojRFa003o`000?n^VL;o[YW200go[YW2
00?o0000okFP`oneX<<03oneX<<00ol0003o_J_7okf[a`0=okf[a`?o000000?o`:Fmo`000?o=^LL0
5_o=^LL00ol0003oi=S:onCHbP0>onCHbP;o00000_o_f;X01?l0003oeoFOomOeWol0000^ooooo`03
o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo047ooooo0_l00009odE@^@03o`00
0?mNKL[oGVg:00GoGVg:00?o0000ohMi_On7NKd01On7NKd00ol0003oSXO7ohj7a`03ohj7a`?o0000
1on>QlL00ol0003oWHZnoif:_P04oif:_P;o00002_nPULP00ol0003oZ9K4ojRFa00?ojRFa003o`00
0?n^VL;o[YW200go[YW200?o0000okFP`oneX<<03_neX<<00ol0003o_J_7okf[a`0Aokf[a`;o0000
5Oo=^LL00ol0003ofMKFo`00000AonCHbP03o`000?o_f;[o000000?oeoFO00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`12ooooo`;o00001om5
D;T00ol0003oGVg:oei]bP07oei]bP03o`000?n7NKgoQgVm00?oQgVm00?o0000ohj7aon>QlL01?l0
000:ohj7a`03o`000?nMR[koWHZn00;oWHZn0_l0000=oj2Eb003o`000?nXU/CoZ9K400koZ9K400?o
0000ojjI`_n^VL803On^VL800ol0003o]J33okFP``0>okFP``03o`000?nmZlOo_J_7017o_J_700?o
0000olJld?l000004oo=^LL01Ol0003ofMKFomWFe_oIe]Ko0000017oi=S:00Go0000omOeWooGmIoo
eoFOo`00000_ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04;ooooo
00?o0000o`04UOl000001_m5D;T00ol0003oGVg:oei]bP08oei]bP04o`000?n7NKgoQgVmohMi_@Co
00003on>QlL01?l0003oWHZno`000?l0000?oj2Eb003o`000?nXU/CoZ9K400koZ9K400?o0000ojjI
`_n^VL803On^VL800ol0003o]J33okFP``0=okFP``03o`000?nmZlOo_J_7017o_J_700Go0000olJl
d?o6_=3oa[c@o`00000Aolfia`03o`000?oIe]KofMKF00;ofMKF00?o0000onCHb_oTf<X03OoTf<X0
1?l0003og?o<o`000?l00002omOeW`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Ooo
ool001Kooooo00?o0000ooooooooool0@oooool00ol0003o00BEo`000005odE@^@03o`000?mNKL[o
GVg:00WoGVg:1?l0000Cohj7a`03o`000?nPULSoX9G8013oX9G800?o0000ojRFa?nXU/@03_nXU/@0
0ol0003o[YW2ojjI`P0<ojjI`P03o`000?neX<?o]J3300go]J3300?o0000okf[aonmZlL04?nmZlL0
0ol0003oa[c@olJld003olJld0;o00003_o=^LL00ol0003ofMKFomWFeP04omWFeP03o`000?oTf<[o
i=S:00_oi=S:00?o0000omcoc?l000000_oGmIl00ol0003oeoFOo`00000`ooooo`03o`000?oooooo
oooo00Sooooo000Fooooo`03o`000?oooooooooo04?ooooo00?o0000o`04UOl000001?m5D;T00ol0
003oGVg:oei]bP08oei]bPGo00005?n>QlL00ol0003oX9G8oj2Eb00@oj2Eb003o`000?nXU/CoZ9K4
00koZ9K400?o0000ojjI`_n^VL803?n^VL800ol0003o]J33okFP``0<okFP``03o`000?nmZlOo_J_7
017o_J_700?o0000olJld?o6_=001Oo6_=000ol0003ocKW7olfia`0:olfia`03o`000?oIe]KofMKF
00GofMKF00?o0000onCHb_oTf<X02_oTf<X01?l0003og?o<omcoc?l00002omOeW`;o0000<Oooool0
0ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`14ooooo`03o`000?l019Go0000
00?oAE2i00?o0000oei]b_mNKLX01?mNKLX4o`0000?oGVg:0_maPmH00ol0003oSXO7ohj7a`0@ohj7
a`03o`000?nDU=7o000001;oX9G800?o0000ojRFa?nXU/@02onXU/@Fo`0000[o]J3300?o0000okf[
aonmZlL04?nmZlL00ol0003oa[c@olJld007olJld003o`000?o=^LOocKW700SocKW700?o0000omWF
e_oIe]H01ooIe]H00ol0003oi=S:onCHbP08onCHbP05o`000?oLolcog?o<omcoc?l000000ooGmIl0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
04Gooooo00Co0000o`04UOl019Go00000_m5D;T01?l0003oGVg:oei]b_mNKLX3o`0000OoGVg:00Co
0000og63e_maPmKo00004?n>QlL01Ol0003oU9CAoiBDdOnDU=7o0000017oX9G800?o0000ojRFa?nX
U/@02?nXU/@3o`0000;oZJ7?00?o0000ojjTcOn^Y<d03?n^Y<d00ol0003o/jW>ok>YcP02ok>YcPOo
00000oneX<<00ol0003o_J_7okf[a`0?okf[a`03o`000?o6_=3oa[c@00Woa[c@00?o0000olfiaoo=
^LL01_o=^LL00ol0003ofMKFomWFeP09omWFeP03o`000?oTf<[oi=S:00Koi=S:00Go0000omcoc?oL
olcog?o<o`000003omOeW`03o`000?oooooo0000033ooooo00?o0000ooooooooool02?ooool001Go
oooo0ol00016ooooo`03o`000?l019Go00BE00;o000000CoGVg:o`000?l0003o00002OmNKLX00ol0
003oLH?Fog63eP02og63eP03o`000?n>QlOoSXO700coSXO700?o0000oiBDdOnDU=400onDU=400ol0
003oX9G8oj2Eb00?oj2Eb003o`000?nXU/CoZ9K400?oZ9K41?l00005ojVQc`03o`000?n^Y<go[ZC=
00co[ZC=00?o0000ok>Yc_ncZLh02OncZLh3o`00017o_J_700?o0000olJld?o6_=002oo6_=02o`00
00GocKW700?o0000omWFe_oIe]H02_oIe]H00ol0003oi=S:onCHbP05onCHbP03o`000?oLolcog?o<
00;og?o<00Co0000omOeWooGmIoo00000oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo00Sooooo000Eooooo`03o`000?oooooooooo04Kooooo00?o0000o`04UOl019D00ol0000<oei]
bP03o`000?maPmKoLH?F00?oLH?F00?o0000ohj7aon>QlL02_n>QlL00ol0003oU9CAoiBDd@05oiBD
d@03o`000?nPULSoX9G800koX9G800?o0000ojRFa?nXU/@00ol0000:ojVQc`03o`000?n^Y<go[ZC=
00_o[ZC=00?o0000ok>Yc_ncZLh02oncZLh00ol0003o^K;Bo`000002o`0000go_J_700?o0000olJl
d?o6_=003Oo6_=001Ol0003ocKW7olfiaoo=^LOo000000kofMKF00?o0000onCHb_oTf<X00ooTf<X0
0ol0003og?o<omcoc003omcoc003o`000?oGmIoo000000Gooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`15ooooo`Co000000Co00BEo`1;
bol0Bl_o00002omNKLX00ol0003oLH?Fog63eP04og63eP03o`000?n>QlOoSXO700SoSXO700?o0000
oiBDdOnDU=401onDU=400ol0003oX9G8oj2Eb00=oj2Eb0?o00003OnYXLl00ol0003o[ZC=ojjTc@0:
ojjTc@03o`000?ncZLko/jW>00_o/jW>00?o0000okVbd_ni/]800oni/]82o`0000[o_J_700?o0000
olJld?o6_=003oo6_=000ol0003ocKW7o`00000?omWFeP03o`000?oTf<[oi=S:00;oi=S:00?o0000
omcoc?oLol`00ooLol`01?l0003oeoFOomOeWol00005ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0@_ooool3o`0000;ooooo00Co0000
o`04UOl019Go00BE0_l0Bl/00ol0003oGVg:oei]bP07oei]bP03o`000?maPmKoLH?F00KoLH?F00?o
0000ohj7aon>QlL01on>QlL00ol0003oU9CAoiBDd@08oiBDd@03o`000?nPULSoX9G800[oX9G80_l0
00000onSXM?o0000ojVQc`0=ojVQc`03o`000?n^Y<go[ZC=00[o[ZC=00?o0000ok>Yc_ncZLh02onc
ZLh00ol0003o^K;BokVbdP05okVbdP;o00001onmZlL00ol0003oa[c@olJld00AolJld003o`000?oI
e]KofMKF00oofMKF00Co0000onCHb_oTf<[o00001_oLol`00ol0003oeoFOo`000007ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01oooool001Gooooo00?o0000ooooooooool0?ooo
ool3o`0000Kooooo00Co0000o`04UOl019Go00000_l0Bl/00ol0003oGVg:oei]bP06oei]bP03o`00
0?maPmKoLH?F00OoLH?F00?o0000ohj7aon>QlL01On>QlL00ol0003oU9CAoiBDd@0:oiBDd@03o`00
0?nPULSoX9G800OoX9G80_l00004oj>Qd`03o`000?nYXLooZJ7?00_oZJ7?00?o0000ojjTcOn^Y<d0
2_n^Y<d00ol0003o/jW>ok>YcP0:ok>YcP03o`000?ni/];o^K;B00So^K;B0ol00004okf[a`03o`00
0?o6_=3oa[c@00ooa[c@00?o0000olgDg_l000004OoIe]H00ol0003oi=S:o`000007omcoc0;o0000
2Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oo
oooooooo03gooooo0ol00009ooooo`05o`000?l019Go00BEo`04UOl000000_l0Bl/00ol0003oGVg:
oei]bP05oei]bP03o`000?maPmKoLH?F00SoLH?F00?o0000ohj7aon>QlL00on>QlL00ol0003oU9CA
oiBDd@0<oiBDd@03o`000?nPULSoX9G800GoX9G800?o0000oj>QdonSXM<01OnSXM<00ol0003oZJ7?
ojVQc`0:ojVQc`03o`000?n^Y<go[ZC=00[o[ZC=00?o0000ok>Yc_ncZLh02_ncZLh00ol0003o^K;B
okVbdP0;okVbdP;o000000?o_J_7o`000?o6_=004?o6_=001Ol0003ocMCNolgDg_o=e=ko0000017o
fMKF00?o0000omcoc?oLol`01OoLol`00ol0003oeoFOo`00000:ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0>Oooool4o`0000gooooo
00Co0000o`04UOl019Go00000ol0Bl/00ol0003oGVg:oei]bP04oei]bP03o`000?maPmKoLH?F00Wo
LH?F00Go0000ohj7aon>QlOoSXO7o`00000@oiBDd@03o`000?nPULSoX9G800;oX9G80_l00008oj>Q
d`03o`000?nYXLooZJ7?00_oZJ7?00?o0000ojjTcOn^Y<d02On^Y<d00ol0003o/jW>ok>YcP09ok>Y
cP03o`000?ni/];o^K;B00ko^K;B00?o0000olJld?o6_=003oo6_=000ol0003ocMCNolgDgP02olgD
gP03o`000?oIe]KofMKF00gofMKF00?o0000om?ihol000001ooLol`2o`0000cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0fooooo`?o
00004Oooool01Ol0003o00BEo`04UOl019Go000000?o04_;00?o0000oei]b_mNKLX00_mNKLX00ol0
003oLH?Fog63eP0;og63eP03o`000?n>QlOo000001;oU9CA00Co0000oj2Eb?l0003o00002onSXM<0
0ol0003oZJ7?ojVQc`0:ojVQc`03o`000?n^Y<go[ZC=00Wo[ZC=00?o0000ok>Yc_ncZLh02OncZLh0
0ol0003o^K;BokVbdP0=okVbdP04o`000?no_m[o_koJo`0000koa[c@00?o0000olgDg_o=e=h01?o=
e=h00ol0003ofMKFomWFeP0:omWFeP;o00000_oCnN<00ol0003og?o<omcoc005omcoc003o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`005?ooool3
o`0003?ooooo0ol0000Eooooo`04o`000?l019Go00BEo`0000Co04_;00Go0000oei]b_mNKL[oGVg:
o`00000>og63eP;o00004onDU=400ol0003oXj7Coj>Qd`0<oj>Qd`03o`000?nYXLooZJ7?00WoZJ7?
00?o0000ojjTcOn^Y<d02On^Y<d00ol0003o/jW>ok>YcP09ok>YcP03o`000?ni/];o^K;B00co^K;B
00?o0000oknof_no_mX00_no_mX00ol0003oa[c@olJld009olJld0;o00001oo=e=h00ol0003ofMKF
omWFeP09omWFeP05o`000?oCnN?odoWSom?ihol000001_oLol`2o`0000oooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o0000
6Oooool01?l0003o00BEo`04UOl00004o`1;b`04o`000?mNKL[oGVg:o`0000koLH?F0_n0UMh00ol0
003oU9CAoiBDd@0@oiBDd@;o00003OnSXM<00ol0003oZJ7?ojVQc`09ojVQc`03o`000?n^Y<go[ZC=
00So[ZC=00?o0000ok>Yc_ncZLh02OncZLh00ol0003o^K;BokVbdP0<okVbdP03o`000?no_m[o_koJ
00Co_koJ00?o0000olJld?o6_=001oo6_=000ol0003ocMCNolgDgP08olgDgP03o`000?oIe]KofMKF
00KofMKF0_l00004om?ih`03o`000?oLolcog?o<00?og?o<00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo000:ooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0/ooooo`Co00007Oooool00ol0003o00BEo`000005o`1;b`;o
00003omaPmH00ol0003oP9GNoh2EgP02o`0000ooU9CA00Co0000oiVQf_nIXM[o00003OnSXM<00ol0
003oZJ7?ojVQc`08ojVQc`03o`000?n^Y<go[ZC=00So[ZC=00?o0000ok>Yc_ncZLh02OncZLh00ol0
003o^K;BokVbdP0;okVbdP03o`000?no_m[o_koJ00Ko_koJ00?o0000olJld?o6_=001Oo6_=000ol0
003ocMCNolgDgP0:olgDgP03o`000?oIe]KofMKF00CofMKF00?o0000om?ihooCnN<01?oCnN<00ol0
003og?o<omcoc002omcoc003o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[o
oooo0ol0000Rooooo`;o00001_l0Bl/2o`0000goLH?F00?o0000oh2Eg_n0UMh00on0UMh00ol0003o
U9CAoiBDd@0;oiBDd@03o`000?nIXM[oVJ7J00;oVJ7J00?o0000oj>QdonSXM<02onSXM<00ol0003o
ZJ7?ojVQc`08ojVQc`03o`000?n^Y<go[ZC=00Oo[ZC=00?o0000ok>Yc_ncZLh02?ncZLh00ol0003o
^K;BokVbdP0;okVbdP03o`000?no_m[o_koJ00So_koJ00?o0000olJld?o6_=000oo6_=000ol0003o
cMCNolgDgP0;olgDgP03o`000?oIe]KofMKF00?ofMKF00?o0000om?ihooCnN<01OoCnN<01Ol0003o
g?o<omcoc?oLolco000001Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06oooo
o`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo0ol0000Uooooo`03
o`000?l019Go000000Go04_;0_lcNN@00ol0003oLH?Fog63eP0:og63eP03o`000?n0UMkoP9GN00Co
P9GN0_l0000:oiBDd@03o`000?nIXM[oVJ7J00CoVJ7J00?o0000oj>QdonSXM<02_nSXM<00ol0003o
ZJ7?ojVQc`06ojVQca;o00001OncZLh00ol0003o^K;BokVbdP0:okVbdP03o`000?no_m[o_koJ00[o
_koJ00Go0000olJld?o6_=3oa[c@o`00000?olgDgP03o`000?oIe]KofMKF00;o00001ooCnN<01Ol0
003og?o<omcoc?oLolco000001Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo0ol0000Yoooo
o`;o00001_l0Bl/2oc=ii0;o00002_maPmH00ol0003oP9GNoh2EgP06oh2EgP03o`000?nDU=7oU9CA
00KoU9CA00?o0000oiVQf_nIXMX01_nIXMX00ol0003oXj7Coj>Qd`0:oj>Qd`03o`000?nYXLooZJ7?
00Go00000_nX[]`00ol0003o[;3Kojb`f`07ojb`f`03o`000?n_/m_o[k?K00?o[k?K1_l0000;okVb
dP03o`000?no_m[o_koJ00co_koJ00?o0000olJld?l000004?o=e=h00ol0003ofMKFo`000009om?i
h`04o`000?oLolcog?o<o`0001Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06
ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo1?l0000]oooo
o`;o00001Ol0Bl/01?l0003o<gWToc=ii?lcNN@2o`0000OoLH?F00?o0000oh2Eg_n0UMh02?n0UMh0
0ol0003oU9CAoiBDd@04oiBDd@03o`000?nIXM[oVJ7J00SoVJ7J00?o0000oj>QdonSXM<02OnSXM<3
o`0000SoZ:kL00?o0000ojb`fon//=/01_n//=/00ol0003o[k?Kojncf`07ojncf`04o`000?nc^Mko
0000o`0000So^K;B00?o0000oknof_no_mX03_no_mX00ol0003ocMCNolgDgP0@olgDgP03o`000?oC
nN?odoWS00SodoWS00?o0000omcoc?l000006oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool3
o`0003;ooooo00?o0000o`1;bol0Bl/00ol0Bl/00ol0003o<gWToc=ii003oc=ii003o`000?maPmKo
LH?F00CoLH?F00?o0000oh2Eg_n0UMh02On0UMh2o`0000?oU9CA00?o0000oiVQf_nIXMX02_nIXMX0
0ol0003oXj7Coj>Qd`07oj>Qd`03o`000?nT[]ko000000WoZ:kL00?o0000ojb`fon//=/01_n//=/0
0ol0003o[k?Kojncf`06ojncf`03o`000?nc^Mko/kWN00;o/kWN0ol00004okVbdP03o`000?no_m[o
_koJ00go_koJ00?o0000ol;@iOl000003oo=e=h2o`000003olS^k_l0003odoWS00WodoWS0_l0000M
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool000cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Jooooo`?o0000=_ooool2o`0000Co04_;00?o0000oc=i
i?lcNN@00olcNN@2o`0000CoLH?F00?o0000oh2Eg_n0UMh02on0UMh00ol0003oU9CAo`00000>oiVQ
fP03o`000?nSXM?oXj7C00CoXj7C0_l00003ojB^gP03o`000?nX[]coZ:kL00KoZ:kL00?o0000ojb`
fon//=/01_n//=/00ol0003o[k?Kojncf`06ojncf`03o`000?nc^Mko/kWN00Go/kWN0_l000000oni
/];o0000oknofP0=oknofP;o00000oo2d>D00ol0003ocMCNolgDgP0;olgDgP05o`000?o8k^kob>k^
olS^k_l000002OoCnN<2o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06
ooooo`002_ooool00omEEEGoIVIVo`000006ooooo`;o00006?ooool3o`0003_ooooo00Go0000o`1;
bol0Bl_o04_;o`000007oc=ii0;o00000_maPmH00ol0003oP9GNoh2EgP0<oh2EgP;o00003onIXMX0
1?l0003oXj7Coj>QdonSXM<2o`0000KoY:kN00?o0000ojR^g?nX[]`01_nX[]`00ol0003o[;3Kojb`
f`05ojb`f`03o`000?n_/m_o[k?K00Go[k?K00?o0000ok>ig_nc^Mh02?nc^Mh00ol0003o_koJokno
fP0;oknofP;o00001_o2d>D00ol0003ocMCNolgDgP08olgDgP;o00000oo8k^h00ol0003odoWSom?i
h`08om?ih`03o`000?oooooooooo01oooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`06ooooo`004_ooool00ol0003oooooooooo`0Dooooo`Co0000?oooool01Ol0003o04_;o`1;bol0
Bl_o000000So<gWT00?oLH?Fo`000?n0UMh03_n0UMh01?l0003oS:CUo`000?l0000>oiVQfP03o`00
0?nSXM?o000000WoY:kN00?o0000ojR^g?nX[]`01OnX[]`00ol0003o[;3Kojb`f`05ojb`f`03o`00
0?n_/m_o[k?K00Go[k?K00?o0000ok>ig_nc^Mh01onc^Mh3okK2h`03o`000?no_m[o_koJ00So_koJ
00?o0000ol;@iOo2d>D01_o2d>D00ol0003ocMCNolgDgP06olgDgP;o00001Oo8k^h00ol0003odoWS
om?ih`05om?ih`;o00008oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo
000Booooo`03o`000?oooooooooo017ooooo0ol00014ooooo`;o000000?o04_;o`000?lcNN@02?lc
NN@2o`0000koP9GN00Co0000ohbTiOn<Y>GoS:CU0_l0000=oiVQfP;o00002OnT[]h00ol0003oZ:kL
ojR^g005ojR^g003o`000?n//=_o[;3K00Co[;3K00?o0000ojncfon_/m/01On_/m/00ol0003o/kWN
ok>igP06ok>igP03o`000?nf`^?o]/;S00?o]/;S0_l00006oknofP;o00002_o2d>D00ol0003ocMCN
olgDgP03olgDgP;o00001oo8k^h00ol0003odoWSom?ih`04om?ih`;o00009Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0
0019ooooo`;o04_;00?o0000oc=ii?lcNN@01_lcNN@00ol0003oFYK^o`000002o`0000[oP9GN00?o
0000ohbTiOn<Y>D01?n<Y>D2o`0000[oVJ7J00Co0000oij_honN[n?o00002OnT[]h00ol0003oZ:kL
ojR^g005ojR^g003o`000?n//=_o[;3K00?o[;3K00?o0000ojncfon_/m/01?n_/m/00ol0003o/kWN
ok>igP06ok>igP03o`000?nf`^?o]/;S00Ko]/;S00Co0000oknof_no_m[o_koJ0_l0000<ol;@i@03
o`000?o=e=kocMCN00;ocMCN00?o0000olS^k_o8k^h01oo8k^h00ol0003odoWSom?ih`02om?ih`;o
0000:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`00
0?oooooooooo00_ooooo0ol0001=ooooo`03o`1;bol0003o<gWT00So<gWT00Co0000oeZFk_mJU^ko
FYK^0_l00008oh2EgP03o`000?n<Y>GoS:CU00KoS:CU0_l00007oiVQfP03o`000?nN[n?oWZoS00;o
WZoS0_l00008ojB^gP03o`000?nX[]coZ:kL00CoZ:kL00?o0000ojb`fon//=/00on//=/00ol0003o
[k?Kojncf`04ojncf`03o`000?nc^Mko/kWN00Go/kWN00?o0000okK2honf`^<02?nf`^<00ol0003o
_koJo`00000?ol;@i@04o`000?o=e=ko0000o`0000[ob>k^00?o0000om?ihooCnN<00ol0000Zoooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooooooo
ool01oooool4o`00057ooooo00?o0000oc=ii?lcNN@01olcNN@00ol0003oFYK^oeZFkP03oeZFkP;o
00001_n0UMh00ol0003oS:CUohbTi@08ohbTi@;o00001?nIXMX00ol0003oWZoSoij_h`05oij_h`03
o`000?nT[]koY:kN00GoY:kN00?o0000ojR^g?nX[]`01?nX[]`00ol0003o[;3Kojb`f`03ojb`f`03
o`000?n_/m_o[k?K00?o[k?K00?o0000ok>ig_nc^Mh01Onc^Mh00ol0003o]/;SokK2h`0:okK2h`03
o`000?o2d>Go`]3U00oo`]3U00?o0000olS^k_o8k^h02Oo8k^h00ol0003odoWSom?ih`02o`0002go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`04ooooo`?o0000E_ooool2o`0000Oo<gWT00?o0000oeZFk_mJU^h01OmJU^h3o`0000?oP9GN
00?o0000ohbTiOn<Y>D02_n<Y>D2o`000003oiVQf_l0003oWZoS00SoWZoS0_l00006ojB^gP03o`00
0?nX[]coZ:kL00CoZ:kL00?o0000ojb`fon//=/00_n//=/00ol0003o[k?Kojncf`03ojncf`03o`00
0?nc^Mko/kWN00Co/kWN00?o0000okK2honf`^<02Onf`^<00ol0003o]/g[o`00000=ol;@i@?o0000
00?o_>?bo`000?o8k^h02_o8k^h4o`0002oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000Foooool2o`0000Ko<gWT00?o
0000oeZFk_mJU^h01omJU^h00ol0003oP9GNo`00000?ohbTi@?o00002_nN[n<00ol0003oY:kNojB^
gP04ojB^gP04o`000?nX[]coZ:kLojR^g0ko00001Onc^Mh00ol0003o]/;SokK2h`06okK2h`;o0000
1OnfcN/00ol0003o`]3Uol;@i@07ol;@i@?o00001?nlho800ol0003ob>k^olS^kP09olS^kP;o0000
<Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oo
oooo000000;o0000Goooool3o`0000Co<gWT00?o0000oeZFk_mJU^h02OmJU^h3o`0000goS:CU00?o
0000oiFbjonE/^/00ol00008oij_h`;o00001?nT[]h4o`0000;oY[k[00?o0000ojJnjonV_^/00_nV
_^/00ol0003oYko[ojNoj`02ojNoj`03o`000?nX`>_o000000;o000000?o/kWNo`000?nf`^<01_nf
`^<2o`0000So]/g[00?o0000ol;@iOo2d>D00oo2d>D3o`0000Oo_>?b00?o0000olS^k_o8k^h01Oo8
k^h5o`0003?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`004Oooool2
o`0006Cooooo00?o04J]o`000?l000000olcNN@00ol0003oFYK^oeZFkP08oeZFkP03o`000?mfZO?o
MZWc00?o00002_n<Y>D00ol0003oUK;[oiFbj`03oiFbj`?o00001onN[n<01?l0003oY:kNo`000?l0
0003ojFmj`05o`000?nV_^_oY[k[ojJnjol000000onV_^/01Ol0003oYko[ojNojonW_n_o000000Co
Z<3[0_l00005okK2h`?o00002_nfcN/00ol0003o`]3Uol;@i@03o`0000Wo_>?b00?o0000olS^k_o8
k^h00oo8k^h3o`000003oiSbiOl0003o000003Kooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`04ooooo`004oooool00ol0003oooooooooo`1Rooooo`06o`000?l0AZgo0000o`000?lc
NNCo00002omJU^h00ol0003oMZWcogJYl`02ogJYl`?o00001on<Y>D00ol0003oUK;[oiFbj`06oiFb
j`?o00001OnN[n<2o`0000GoYKg[00Co0000ojJnjonV_^_o00000onV_^/01?l0003oYko[ojNojol0
0004ojS0j`06o`000?nYa>goZLC]ojW4kOl0003o]/;S0_l0000>okK=j`;o00003?nlho801?l0003o
b>k^olS^k_o8k^h2o`0000;oV?;U0ol0000hooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool01?ooool001Cooooo0_l0001Tooooo`04o`000?l0AZgo0000o`0000_oFYK^00?o0000ogJY
lomfZO<01OmfZO<3o`0000?oS:CU00?o0000oiFbjonE/^/02_nE/^/3o`000004oij_hol0003oX[g]
oj:mk@;o00001?nU_N/01?l0003oY[k[ojJnjol00002ojJnj`04o`000?nW_n_oYko[o`0000;oZ<3[
0_l00004ojW4k@;o00002_nfcN/4o`0000;o/MSd00?o0000okcSl_nlho802onlho84o`0000?oV?;U
0_l0000kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Kooooo00?o
0000ooooool00000Hoooool00ol0003o04J]o`000002o`0000SoFYK^00?o0000ogJYlomfZO<02?mf
ZO<2o`000003ohbTiOl0003oUK;[00koUK;[0ol00003oj:mk@;o00000onU_N/01Ol0003oY[k[o`00
0?nV_^_o000000;oYko[00Co0000ojS0jol0003o00000onYa>d3o`000003ojS8l?l0003o]/g[00Go
]/g[1?l00006ok7Hm003o`000?nlho;o_>?b00_o_>?b00?o0000oiSbiOnHl^D00onHl^D2o`0003co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005oooool2o`0006Cooooo
0_l000000ol0AZgo4XWVo`000002o`0000KoFYK^00?o0000ogJYlomfZO<02_mfZO<5o`0000_oUK;[
00?o0000oijol?nN_o001?l000001OnR_Ngo0000o`000?l0003oYKg[00;o000000KoY[k[o`000?nW
_n_o0000ojS0jol00002ojW4k@?o00001OnXb?000ol0003o]/g[o`000003o`0000Wo/MSd00?o0000
okcSl_nlho801Onlho86o`0000KoV?;U00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o0000IOooool01Ol0003o04J]o`000?l0003o
4XWV00?o00000omJU^h00ol0003oMZWcogJYl`0:ogJYl`03o`000?n:]oCoR[Od00;oR[Od1ol00003
oiFbj`03o`000?nN_o3oW[o`00GoW[o`0ol000000onR_Ngo0000o`000003o`000003ojNojol0003o
000000?o00001?nXb?06o`0000go/MSd00?o0000okcSl_nlho801Ol00003oj?]n@;o00001?nHl^D3
o`00047ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_ooool00ol0
003oooooooooo`1Sooooo`;o000000?o04J]o`000?l000000_lBRNH4o`0000goMZWc00?o0000ohZg
m?n:]o@02?n:]o@<o`0000;oW[o`4?l00004ojK=m003o`000?naf?Co/MSd00Go/MSd00?o0000ok7H
m?naf?@01?naf?@3o`0000OoXngi00?o0000oiSbiOnHl^D01?l00015ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00oooool001_ooooo0_l000000ooooooo0000ooooo`1Rooooo`;o
000000?o04J]o`000?lBRNH00olBRNH6o`0000SoMZWc00?o0000ohZgm?n:]o@02on:]o@00ol0003o
V/;coi[2l`06oi[2lako00001_nTg_/00ol0003oXngioj?]n@07oj?]n@Go0000BOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo000Mooooo`;o0000IOooool4o`0000Go4XWV
00?o0000oe>]n_mC[OX01ol000000omfZO?o0000ohZgm00=ohZgm004o`000?nJ`_?oV/;coi[2l`[o
000000?oUlgko`000?l000001_l00007oj7?n003o`000?nTg__oY=kk00[oY=kk00?o0000oj?]nOnS
kOT01?nSkOT2o`000004oj?]nOl0003o0000o`0004cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`03ooooo`007_ooool00ol0003oooooooooo`1Vooooo`03o`16[Ol0003o4XWV00Co
4XWV0_l00007oe>]nPoo000000?oR[Odo`000?l000000_l00004oiO6m`Go000000GoUlgko`000?l0
003oV<oko`000002oiW?nP;o000000?oW<ojo`000?l000000_l00002oj7?n003o`000?nTg__oY=kk
00[oY=kk00?o0000oj?]nOl000002?l0001@ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool00oooool001oooooo0_l0001Xooooo`Co00000olBRNH2o`0000WoDjgj00?o0000ogbno?ml
__`02oml__`00ol0003oUlKgoiO6m`03o`000003oiK:n_l0003o000000;oUlgk00?o0000oiS>nol0
00000_nHco/01?l0003oVLojoiW?n_nIcoX3o`0000;oW<oj3Ol000001?nTg__o0000o`000?l00003
og7OjP?o0000E?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Qoooo
o`03o`000?oooooooooo06Sooooo00?o@@00o`000?l000000_l000000olBRNKo0000oe>]nP08oe>]
nP03o`000?ml__coO;kl00_oO;kl0ol00002oiK:nP03o`000?nGcO_oUlgk00;oUlgk00Co0000oiS>
nonHc__o00000_nHco/00ol0003oVLojoiW?nP02oiW?nPGo00002OnAgoh2o`0000GoLMoZ0_l0001H
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001/oooo
o`03od400?l0003o000000Ko00000omC[OX01?l0003oO;klogbno?ml__`6o`0000KoKlGo1?l00002
oiO=n`05o`000?nHc__oV<kkoiS>nol000000onHco/01?l0003oVLojo`000?l00005ogkKo@Co0000
0onAgoh2o`0000;oLMoZ1Ol0001Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool002Cooooo00?o0000ooooooooool0J_ooool01_l0003ooooooooooooooooo@@00o`0000?o
9JKX0ol000001?mC[O[o0000o`000?l00009ofo5o`?o00001?mWbod>o`0000WoO]_m2Ol0001Ooooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Gooooo0_l0001Zooooo`03
o`000?oooooooooo00Gooooo00?o@@00o`000?l000000_l00003obFVj0Co00000_m_aOl3o`0000Oo
Il_m00?o0000ofS@nomXd?/00omXd?/00ol0003oL=Gkog3En`05og3En`;o00000omnfod8o`0006Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009oooool00ol0003ooooo
ooooo`1Wooooo`03o`000?oooooooooo00[ooooo1_l000000olUY^So0000o`000002ofO;o@?o0000
1?mWbod00ol0003oJ=3kofS@n`05ofS@n`03o`000?m`eO_oL=Gk00;oL=Gk2ol0001Yooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_ooool002Sooooo00?o0000ooooool00000I_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?l4UlCo19O400;o19O45?l0001booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04
ooooo`;o0000I_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`005Oooool6o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?ooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool03?oo
ool2o`00063ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo007ooooo000Pooooo`03o`000?oooooooooo00gooooo0_l0001Oooooo`03o`000?oooooo
oooo0:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`008?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0YOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Nooooo`03oeEEEOmVIVKo000001;o
oooo0_l000000ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo0:Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wooooo00?o0000ooooooooool0
Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000fooooo`;o0000F?oo
ool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Ooo
ool003Sooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`000?oooooooooo0:Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00>Oooool01?l0003oooooooooool0
001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Ooo
ool003[ooooo0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool02?ooool1
o`00007ooooo0Oooool003cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`2Zoooo
o`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o0000DOooool00ol0003o
ooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo000oooooo`03o`00
0?oooooo000004kooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`06ooooo`7o0000
0Oooool1ooooo`00@?ooool2o`0004kooooo00?o0000ooooooooool0[Oooool00ol0003ooooooooo
o`05ooooo`7o00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o0000ooooooooool0[_ooool0
0ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00007ooooo0014ooooo`;o
000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00Co
oooo0Ol00001ooooo`00A_ooool2o`0004Sooooo00?o0000ooooooooool0/?ooool00ol0003ooooo
ooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01?m4A4Co0000o`000?lb<S82o`0004Oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`02ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q2?ooool01?mgMgOo<S8booooool00016ooooo`03o`000?oooooooooo0;;ooooo00Go0000oooo
ooooooooooooo`000001ooooo`00:_ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?o0000@oooool00ol0003oooooooooo`2cooooo`04o`000?oooooo
ooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8boooo
o`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0/oooool01?l0003ooooooooo
ool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0]?ooool00ol0003o
ooooooooo`01o`000000<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool02?ooool2o`00043ooooo00?o0000ooooooooool0]Oooool1o`00007ooooo0Ol0000003;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[ooooo0_l0000nooooo`03
o`000?oooooooooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00002_ooool2o`0003gooooo00?o0000ooooooooool0]Oooool3o`000000Doooool01Ol0003ooooo
oooooooooooo000003Sooooo00?o0000ooooooooool0/?ooool5o`0000?ooooo001Dooooo`04o`00
0?ooooooooooo`0003Sooooo00?o0000ooooooooool0[?ooool4o`0000Sooooo001Eooooo`?o0000
>?ooool00ol0003oooooooooo`2Xooooo`Co00003?ooool005Oooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0000eooooo`03o`000?oooooo
oooo0:3ooooo1?l0000Eooooo`00F_ooool00ol0003oooooo`00000booooo`03o`000?oooooooooo
09cooooo1?l0000Iooooo`00Foooool2o`0003;ooooo00?o0000ooooooooool0Uoooool5o`0001go
oooo001Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Toooool4o`0002;ooooo
001Nooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0S_ooool5o`0002Kooooo
001Oooooo`?o0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000:oooool0067ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000;oooool005?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0:ooooo`;o0000:oooool00ol0003oooooooooo`21ooooo`Go0000<oooool0
05?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo000002Sooooo00?o0000
ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?ooooooooooooooool@41003Oooool2
o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo001Cooooo`05o`000?oooooooooo
ooooool000003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo1Ol00010
ooooo`00Doooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000oooooooooooo00008ooo
ool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go410@oooooooooooooooooa0@
400Aooooo`?o00008oooool00ol0003oooooooooo`1[ooooo`Go0000BOooool005?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0Booooo`;o00008oooool00ol0003oooooooooo`1Wooooo`Co0000C_oo
ool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?oooooo`000?ooool07_oo
ool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0000Oooooo`03o`000?oooooo
oooo05kooooo1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
05[ooooo1?l0001Kooooo`00L?ooool2o`0001gooooo00?o0000ooooooooool0E_ooool4o`0005oo
oooo001booooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0DOooool5o`0006?ooooo
001cooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000J?ooool007Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000K?ooool007Kooooo0_l000000ooo
oooo0000ooooo`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`ooooo`00N?ooool2o`0001Go
oooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0>oooool5o`0007Wooooo001jooooo`;o000000?oooooo`000?ooool04?oo
ool00ol0003oooooooooo`0gooooo`Co0000O_ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo0_l0000Aooooo`03o`00
0?oooooooooo03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo
1Ol00026ooooo`00Hoooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo1?l0002;ooooo`00Hooo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01_ooool3o`0000_ooooo
00?o0000ooooooooool09oooool4o`0008oooooo001Sooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Rooooo`Go0000Toooool006?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00cooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Noooo
o`Co0000V?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00gooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1Ol0002Looooo`00Hoooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co
0000YOooool008Wooooo0_l00003ooooo`03o`000?oooooooooo00cooooo1Ol0002Yooooo`00R_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l0002^ooooo`00Roooool2o`000003ooooool0
003ooooo00Gooooo1?l0002booooo`00SOooool2o`000003ooooool0003o000000?o0000]_ooool0
08kooooo0_l0002kooooo`00oooooom<ooooo`00oooooom<ooooo`00Q?ooool4o`000003oa0@4?oo
oooooooo0<3ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo
0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo
0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0024oooo
o`03oeEEEOmVIVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.49047 .51528 m .48448 .5541 L .54052 .55674 L p .722 .597 .715 r
F P
0 g
s
.54052 .55674 m .53847 .51748 L .49047 .51528 L p .722 .597 .715 r
F P
0 g
s
.54213 .59486 m .54052 .55674 L .48448 .5541 L p .724 .573 .684 r
F P
0 g
s
.53847 .51748 m .54052 .55674 L .59795 .54716 L p .696 .583 .725 r
F P
0 g
s
.54052 .55674 m .54213 .59486 L .60701 .58589 L p .696 .558 .694 r
F P
0 g
s
.60701 .58589 m .59795 .54716 L .54052 .55674 L p .696 .558 .694 r
F P
0 g
s
.49779 .47626 m .49047 .51528 L .53847 .51748 L p .719 .622 .748 r
F P
0 g
s
.53847 .51748 m .53598 .47802 L .49779 .47626 L p .719 .622 .748 r
F P
0 g
s
.53598 .47802 m .53847 .51748 L .58691 .50841 L p .694 .609 .757 r
F P
0 g
s
.59795 .54716 m .58691 .50841 L .53847 .51748 L p .696 .583 .725 r
F P
0 g
s
.58691 .50841 m .59795 .54716 L .65443 .52483 L p .663 .572 .743 r
F P
0 g
s
.59795 .54716 m .60701 .58589 L .67293 .56307 L p .658 .542 .711 r
F P
0 g
s
.67293 .56307 m .65443 .52483 L .59795 .54716 L p .658 .542 .711 r
F P
0 g
s
.48448 .5541 m .47981 .59177 L .54213 .59486 L p .724 .573 .684 r
F P
0 g
s
.54333 .63128 m .54213 .59486 L .47981 .59177 L p .725 .55 .654 r
F P
0 g
s
.54213 .59486 m .54333 .63128 L .61404 .62392 L p .696 .534 .664 r
F P
0 g
s
.61404 .62392 m .60701 .58589 L .54213 .59486 L p .696 .534 .664 r
F P
0 g
s
.44431 .50181 m .42967 .53926 L .48448 .5541 L p .748 .62 .717 r
F P
0 g
s
.48448 .5541 m .49047 .51528 L .44431 .50181 L p .748 .62 .717 r
F P
0 g
s
.47981 .59177 m .48448 .5541 L .42967 .53926 L p .752 .597 .685 r
F P
0 g
s
.58691 .50841 m .57397 .4705 L .53598 .47802 L p .694 .609 .757 r
F P
0 g
s
.57397 .4705 m .58691 .50841 L .63291 .48838 L p .666 .602 .774 r
F P
0 g
s
.65443 .52483 m .63291 .48838 L .58691 .50841 L p .663 .572 .743 r
F P
0 g
s
.60701 .58589 m .61404 .62392 L .68796 .60233 L p .652 .512 .679 r
F P
0 g
s
.68796 .60233 m .67293 .56307 L .60701 .58589 L p .652 .512 .679 r
F P
0 g
s
.46164 .46525 m .44431 .50181 L .49047 .51528 L p .742 .644 .751 r
F P
0 g
s
.49047 .51528 m .49779 .47626 L .46164 .46525 L p .742 .644 .751 r
F P
0 g
s
.42967 .53926 m .41783 .57668 L .47981 .59177 L p .752 .597 .685 r
F P
0 g
s
.47636 .62772 m .47981 .59177 L .41783 .57668 L p .752 .574 .654 r
F P
0 g
s
.47981 .59177 m .47636 .62772 L .54333 .63128 L p .725 .55 .654 r
F P
0 g
s
.50636 .4384 m .49779 .47626 L .53598 .47802 L p .712 .648 .784 r
F P
0 g
s
.53598 .47802 m .53307 .43968 L .50636 .4384 L p .712 .648 .784 r
F P
0 g
s
.53307 .43968 m .53598 .47802 L .57397 .4705 L p .691 .638 .791 r
F P
0 g
s
.48142 .43069 m .46164 .46525 L .49779 .47626 L p .732 .668 .787 r
F P
0 g
s
.49779 .47626 m .50636 .4384 L .48142 .43069 L p .732 .668 .787 r
F P
0 g
s
.54416 .6658 m .54333 .63128 L .47636 .62772 L p .725 .528 .624 r
F P
0 g
s
.54333 .63128 m .54416 .6658 L .61906 .66076 L p .695 .509 .632 r
F P
0 g
s
.61906 .66076 m .61404 .62392 L .54333 .63128 L p .695 .509 .632 r
F P
0 g
s
.61404 .62392 m .61906 .66076 L .69904 .64178 L p .645 .48 .645 r
F P
0 g
s
.69904 .64178 m .68796 .60233 L .61404 .62392 L p .645 .48 .645 r
F P
0 g
s
.57397 .4705 m .55934 .43447 L .53307 .43968 L p .691 .638 .791 r
F P
0 g
s
.55934 .43447 m .57397 .4705 L .60888 .45438 L p .669 .634 .806 r
F P
0 g
s
.63291 .48838 m .60888 .45438 L .57397 .4705 L p .666 .602 .774 r
F P
0 g
s
.40262 .47749 m .3781 .51177 L .42967 .53926 L p .777 .659 .733 r
F P
0 g
s
.42967 .53926 m .44431 .50181 L .40262 .47749 L p .777 .659 .733 r
F P
0 g
s
.41783 .57668 m .42967 .53926 L .3781 .51177 L p .785 .64 .701 r
F P
0 g
s
.43027 .44579 m .40262 .47749 L .44431 .50181 L p .765 .678 .766 r
F P
0 g
s
.44431 .50181 m .46164 .46525 L .43027 .44579 L p .765 .678 .766 r
F P
0 g
s
.63291 .48838 m .65443 .52483 L .70263 .49055 L p .617 .561 .769 r
F P
0 g
s
.65443 .52483 m .67293 .56307 L .73099 .52583 L p .602 .523 .738 r
F P
0 g
s
.73099 .52583 m .70263 .49055 L .65443 .52483 L p .602 .523 .738 r
F P
0 g
s
.60888 .45438 m .63291 .48838 L .67083 .45896 L p .631 .598 .799 r
F P
0 g
s
.70263 .49055 m .67083 .45896 L .63291 .48838 L p .617 .561 .769 r
F P
0 g
s
.41783 .57668 m .40874 .61339 L .47636 .62772 L p .752 .574 .654 r
F P
0 g
s
.47398 .66177 m .47636 .62772 L .40874 .61339 L p .752 .55 .624 r
F P
0 g
s
.47636 .62772 m .47398 .66177 L .54416 .6658 L p .725 .528 .624 r
F P
0 g
s
.67293 .56307 m .68796 .60233 L .75473 .56416 L p .584 .481 .703 r
F P
0 g
s
.75473 .56416 m .73099 .52583 L .67293 .56307 L p .584 .481 .703 r
F P
0 g
s
.3781 .51177 m .35722 .54793 L .41783 .57668 L p .785 .64 .701 r
F P
0 g
s
.40874 .61339 m .41783 .57668 L .35722 .54793 L p .79 .619 .668 r
F P
0 g
s
.46051 .41734 m .43027 .44579 L .46164 .46525 L p .75 .696 .8 r
F P
0 g
s
.46164 .46525 m .48142 .43069 L .46051 .41734 L p .75 .696 .8 r
F P
0 g
s
.51598 .40331 m .50636 .4384 L .53307 .43968 L p .702 .678 .824 r
F P
0 g
s
.53307 .43968 m .52981 .40401 L .51598 .40331 L p .702 .678 .824 r
F P
0 g
s
.52981 .40401 m .53307 .43968 L .55934 .43447 L p .686 .67 .829 r
F P
0 g
s
.60888 .45438 m .5828 .42341 L .55934 .43447 L p .669 .634 .806 r
F P
0 g
s
.5828 .42341 m .60888 .45438 L .63663 .43137 L p .642 .635 .827 r
F P
0 g
s
.67083 .45896 m .63663 .43137 L .60888 .45438 L p .631 .598 .799 r
F P
0 g
s
.54465 .69846 m .54416 .6658 L .47398 .66177 L p .723 .504 .594 r
F P
0 g
s
.54416 .6658 m .54465 .69846 L .62208 .69603 L p .693 .483 .599 r
F P
0 g
s
.62208 .69603 m .61906 .66076 L .54416 .6658 L p .693 .483 .599 r
F P
0 g
s
.61906 .66076 m .62208 .69603 L .70578 .68047 L p .636 .445 .606 r
F P
0 g
s
.70578 .68047 m .69904 .64178 L .61906 .66076 L p .636 .445 .606 r
F P
0 g
s
.50318 .39942 m .48142 .43069 L .50636 .4384 L p .717 .693 .826 r
F P
0 g
s
.50636 .4384 m .51598 .40331 L .50318 .39942 L p .717 .693 .826 r
F P
0 g
s
.68796 .60233 m .69904 .64178 L .77265 .60456 L p .564 .435 .663 r
F P
0 g
s
.77265 .60456 m .75473 .56416 L .68796 .60233 L p .564 .435 .663 r
F P
0 g
s
.55934 .43447 m .54332 .40147 L .52981 .40401 L p .686 .67 .829 r
F P
0 g
s
.54332 .40147 m .55934 .43447 L .5828 .42341 L p .669 .669 .84 r
F P
0 g
s
.35722 .54793 m .34042 .58525 L .40874 .61339 L p .79 .619 .668 r
F P
0 g
s
.40231 .64898 m .40874 .61339 L .34042 .58525 L p .794 .596 .635 r
F P
0 g
s
.40874 .61339 m .40231 .64898 L .47398 .66177 L p .752 .55 .624 r
F P
0 g
s
.47257 .69402 m .47398 .66177 L .40231 .64898 L p .75 .527 .593 r
F P
0 g
s
.47398 .66177 m .47257 .69402 L .54465 .69846 L p .723 .504 .594 r
F P
0 g
s
.49274 .39277 m .46051 .41734 L .48142 .43069 L p .728 .713 .837 r
F P
0 g
s
.48142 .43069 m .50318 .39942 L .49274 .39277 L p .728 .713 .837 r
F P
0 g
s
.40746 .41985 m .37072 .44414 L .40262 .47749 L p .785 .724 .796 r
F P
0 g
s
.40262 .47749 m .43027 .44579 L .40746 .41985 L p .785 .724 .796 r
F P
0 g
s
.3781 .51177 m .40262 .47749 L .37072 .44414 L p .806 .716 .765 r
F P
0 g
s
.37072 .44414 m .3367 .47268 L .3781 .51177 L p .806 .716 .765 r
F P
0 g
s
.35722 .54793 m .3781 .51177 L .3367 .47268 L p .824 .705 .733 r
F P
0 g
s
.44603 .39987 m .40746 .41985 L .43027 .44579 L p .761 .731 .825 r
F P
0 g
s
.43027 .44579 m .46051 .41734 L .44603 .39987 L p .761 .731 .825 r
F P
0 g
s
.5828 .42341 m .55512 .39601 L .54332 .40147 L p .669 .669 .84 r
F P
0 g
s
.55512 .39601 m .5828 .42341 L .60082 .40785 L p .653 .672 .856 r
F P
0 g
s
.63663 .43137 m .60082 .40785 L .5828 .42341 L p .642 .635 .827 r
F P
0 g
s
.69904 .64178 m .70578 .68047 L .78366 .64573 L p .54 .381 .615 r
F P
0 g
s
.78366 .64573 m .77265 .60456 L .69904 .64178 L p .54 .381 .615 r
F P
0 g
s
.3367 .47268 m .30646 .50519 L .35722 .54793 L p .824 .705 .733 r
F P
0 g
s
.34042 .58525 m .35722 .54793 L .30646 .50519 L p .84 .691 .697 r
F P
0 g
s
.54483 .7294 m .54465 .69846 L .47257 .69402 L p .72 .479 .561 r
F P
0 g
s
.54465 .69846 m .54483 .7294 L .62307 .72937 L p .688 .453 .562 r
F P
0 g
s
.62307 .72937 m .62208 .69603 L .54465 .69846 L p .688 .453 .562 r
F P
0 g
s
.63663 .43137 m .67083 .45896 L .69347 .42387 L p .583 .599 .834 r
F P
0 g
s
.67083 .45896 m .70263 .49055 L .73215 .44835 L p .552 .553 .809 r
F P
0 g
s
.73215 .44835 m .69347 .42387 L .67083 .45896 L p .552 .553 .809 r
F P
0 g
s
.62208 .69603 m .62307 .72937 L .70786 .71742 L p .625 .403 .561 r
F P
0 g
s
.70786 .71742 m .70578 .68047 L .62208 .69603 L p .625 .403 .561 r
F P
0 g
s
.34042 .58525 m .3281 .62297 L .40231 .64898 L p .794 .596 .635 r
F P
0 g
s
.39846 .68317 m .40231 .64898 L .3281 .62297 L p .796 .572 .598 r
F P
0 g
s
.40231 .64898 m .39846 .68317 L .47257 .69402 L p .75 .527 .593 r
F P
0 g
s
.70263 .49055 m .73099 .52583 L .76733 .47799 L p .515 .501 .778 r
F P
0 g
s
.76733 .47799 m .73215 .44835 L .70263 .49055 L p .515 .501 .778 r
F P
0 g
s
.60082 .40785 m .63663 .43137 L .65273 .40446 L p .61 .64 .855 r
F P
0 g
s
.69347 .42387 m .65273 .40446 L .63663 .43137 L p .583 .599 .834 r
F P
0 g
s
.4858 .38416 m .44603 .39987 L .46051 .41734 L p .732 .736 .855 r
F P
0 g
s
.46051 .41734 m .49274 .39277 L .4858 .38416 L p .732 .736 .855 r
F P
0 g
s
.52981 .40401 m .52632 .37269 L .51598 .40331 L closepath p .685 .712 .869 r
F P
0 g
s
.54332 .40147 m .52632 .37269 L .52981 .40401 L closepath p .684 .711 .869 r
F P
0 g
s
.51598 .40331 m .52632 .37269 L .50318 .39942 L closepath p .686 .713 .869 r
F P
0 g
s
.47206 .72467 m .47257 .69402 L .39846 .68317 L p .747 .502 .56 r
F P
0 g
s
.47257 .69402 m .47206 .72467 L .54483 .7294 L p .72 .479 .561 r
F P
0 g
s
.55512 .39601 m .52632 .37269 L .54332 .40147 L closepath p .679 .709 .871 r
F P
0 g
s
.73099 .52583 m .75473 .56416 L .79728 .51251 L p .473 .439 .739 r
F P
0 g
s
.79728 .51251 m .76733 .47799 L .73099 .52583 L p .473 .439 .739 r
F P
0 g
s
.50318 .39942 m .52632 .37269 L .49274 .39277 L closepath p .688 .717 .871 r
F P
0 g
s
.60082 .40785 m .56394 .38831 L .55512 .39601 L p .653 .672 .856 r
F P
0 g
s
.56394 .38831 m .60082 .40785 L .61096 .38975 L p .635 .678 .874 r
F P
0 g
s
.65273 .40446 m .61096 .38975 L .60082 .40785 L p .61 .64 .855 r
F P
0 g
s
.30646 .50519 m .28122 .54113 L .34042 .58525 L p .84 .691 .697 r
F P
0 g
s
.3281 .62297 m .34042 .58525 L .28122 .54113 L p .855 .674 .656 r
F P
0 g
s
.56394 .38831 m .52632 .37269 L .55512 .39601 L closepath p .671 .708 .876 r
F P
0 g
s
.49274 .39277 m .52632 .37269 L .4858 .38416 L closepath p .691 .725 .876 r
F P
0 g
s
.44012 .38053 m .39733 .39081 L .40746 .41985 L p .763 .771 .86 r
F P
0 g
s
.40746 .41985 m .44603 .39987 L .44012 .38053 L p .763 .771 .86 r
F P
0 g
s
.37072 .44414 m .40746 .41985 L .39733 .39081 L p .797 .782 .839 r
F P
0 g
s
.70578 .68047 m .70786 .71742 L .78695 .68613 L p .51 .317 .554 r
F P
0 g
s
.78695 .68613 m .78366 .64573 L .70578 .68047 L p .51 .317 .554 r
F P
0 g
s
.3281 .62297 m .32063 .66031 L .39846 .68317 L p .796 .572 .598 r
F P
0 g
s
.39716 .71577 m .39846 .68317 L .32063 .66031 L p .796 .545 .558 r
F P
0 g
s
.39846 .68317 m .39716 .71577 L .47206 .72467 L p .747 .502 .56 r
F P
0 g
s
.54468 .75865 m .54483 .7294 L .47206 .72467 L p .715 .45 .523 r
F P
0 g
s
.54483 .7294 m .54468 .75865 L .62197 .76039 L p .68 .417 .517 r
F P
0 g
s
.62197 .76039 m .62307 .72937 L .54483 .7294 L p .68 .417 .517 r
F P
0 g
s
.4832 .37462 m .44012 .38053 L .44603 .39987 L p .728 .758 .877 r
F P
0 g
s
.44603 .39987 m .4858 .38416 L .4832 .37462 L p .728 .758 .877 r
F P
0 g
s
.39733 .39081 m .35546 .40601 L .37072 .44414 L p .797 .782 .839 r
F P
0 g
s
.3367 .47268 m .37072 .44414 L .35546 .40601 L p .83 .791 .815 r
F P
0 g
s
.56875 .37928 m .52632 .37269 L .56394 .38831 L closepath p .661 .711 .885 r
F P
0 g
s
.61096 .38975 m .56875 .37928 L .56394 .38831 L p .635 .678 .874 r
F P
0 g
s
.75473 .56416 m .77265 .60456 L .82016 .5511 L p .42 .363 .688 r
F P
0 g
s
.82016 .5511 m .79728 .51251 L .75473 .56416 L p .42 .363 .688 r
F P
0 g
s
.62307 .72937 m .62197 .76039 L .70504 .75159 L p .608 .353 .505 r
F P
0 g
s
.70504 .75159 m .70786 .71742 L .62307 .72937 L p .608 .353 .505 r
F P
0 g
s
.4858 .38416 m .52632 .37269 L .4832 .37462 L closepath p .691 .736 .885 r
F P
0 g
s
.47247 .75379 m .47206 .72467 L .39716 .71577 L p .743 .474 .522 r
F P
0 g
s
.47206 .72467 m .47247 .75379 L .54468 .75865 L p .715 .45 .523 r
F P
0 g
s
.28122 .54113 m .26221 .57965 L .3281 .62297 L p .855 .674 .656 r
F P
0 g
s
.32063 .66031 m .3281 .62297 L .26221 .57965 L p .867 .651 .608 r
F P
0 g
s
.35546 .40601 m .31558 .4266 L .3367 .47268 L p .83 .791 .815 r
F P
0 g
s
.30646 .50519 m .3367 .47268 L .31558 .4266 L p .864 .798 .784 r
F P
0 g
s
.56875 .37928 m .61096 .38975 L .61159 .37146 L p .614 .687 .895 r
F P
0 g
s
.61096 .38975 m .65273 .40446 L .65396 .37753 L p .568 .651 .892 r
F P
0 g
s
.65396 .37753 m .61159 .37146 L .61096 .38975 L p .568 .651 .892 r
F P
0 g
s
.56893 .36998 m .52632 .37269 L .56875 .37928 L closepath p .652 .719 .898 r
F P
0 g
s
.61159 .37146 m .56893 .36998 L .56875 .37928 L p .614 .687 .895 r
F P
0 g
s
.65273 .40446 m .69347 .42387 L .69535 .38872 L p .514 .607 .883 r
F P
0 g
s
.69535 .38872 m .65396 .37753 L .65273 .40446 L p .514 .607 .883 r
F P
0 g
s
.55569 .35441 m .52632 .37269 L .56441 .36141 L closepath p .646 .74 .918 r
F P
0 g
s
.4832 .37462 m .52632 .37269 L .48533 .3653 L closepath p .685 .746 .898 r
F P
0 g
s
.56441 .36141 m .52632 .37269 L .56893 .36998 L closepath p .647 .73 .91 r
F P
0 g
s
.54375 .3496 m .52632 .37269 L .55569 .35441 L closepath p .648 .747 .921 r
F P
0 g
s
.52989 .34737 m .52632 .37269 L .54375 .3496 L closepath p .65 .749 .922 r
F P
0 g
s
.51562 .34793 m .52632 .37269 L .52989 .34737 L closepath p .651 .75 .922 r
F P
0 g
s
.50251 .35129 m .52632 .37269 L .51562 .34793 L closepath p .654 .752 .922 r
F P
0 g
s
.49202 .35725 m .52632 .37269 L .50251 .35129 L closepath p .663 .754 .918 r
F P
0 g
s
.48533 .3653 m .52632 .37269 L .49202 .35725 L closepath p .675 .753 .91 r
F P
0 g
s
.44012 .38053 m .4832 .37462 L .48533 .3653 L p .717 .777 .9 r
F P
0 g
s
.69347 .42387 m .73215 .44835 L .73468 .40557 L p .446 .548 .867 r
F P
0 g
s
.73468 .40557 m .69535 .38872 L .69347 .42387 L p .446 .548 .867 r
F P
0 g
s
.31558 .4266 m .2792 .45286 L .30646 .50519 L p .864 .798 .784 r
F P
0 g
s
.28122 .54113 m .30646 .50519 L .2792 .45286 L p .899 .801 .743 r
F P
0 g
s
.77265 .60456 m .78366 .64573 L .83433 .59248 L p .353 .267 .618 r
F P
0 g
s
.83433 .59248 m .82016 .5511 L .77265 .60456 L p .353 .267 .618 r
F P
0 g
s
.48533 .3653 m .44401 .36193 L .44012 .38053 L p .717 .777 .9 r
F P
0 g
s
.39733 .39081 m .44012 .38053 L .44401 .36193 L p .75 .811 .9 r
F P
0 g
s
.32063 .66031 m .31829 .69644 L .39716 .71577 L p .796 .545 .558 r
F P
0 g
s
.39849 .74654 m .39716 .71577 L .31829 .69644 L p .795 .511 .509 r
F P
0 g
s
.39716 .71577 m .39849 .74654 L .47247 .75379 L p .743 .474 .522 r
F P
0 g
s
.56893 .36998 m .61159 .37146 L .60248 .35512 L p .59 .7 .919 r
F P
0 g
s
.60248 .35512 m .56441 .36141 L .56893 .36998 L p .59 .7 .919 r
F P
0 g
s
.70786 .71742 m .70504 .75159 L .78209 .72417 L p .47 .235 .474 r
F P
0 g
s
.78209 .72417 m .78695 .68613 L .70786 .71742 L p .47 .235 .474 r
F P
0 g
s
.54417 .78593 m .54468 .75865 L .47247 .75379 L p .707 .412 .475 r
F P
0 g
s
.54468 .75865 m .54417 .78593 L .61864 .78856 L p .667 .37 .461 r
F P
0 g
s
.61864 .78856 m .62197 .76039 L .54468 .75865 L p .667 .37 .461 r
F P
0 g
s
.44401 .36193 m .48533 .3653 L .49202 .35725 L p .699 .793 .923 r
F P
0 g
s
.26221 .57965 m .25053 .61958 L .32063 .66031 L p .867 .651 .608 r
F P
0 g
s
.31829 .69644 m .32063 .66031 L .25053 .61958 L p .876 .619 .546 r
F P
0 g
s
.73215 .44835 m .76733 .47799 L .77049 .42843 L p .357 .469 .837 r
F P
0 g
s
.77049 .42843 m .73468 .40557 L .73215 .44835 L p .357 .469 .837 r
F P
0 g
s
.44401 .36193 m .40263 .36308 L .39733 .39081 L p .75 .811 .9 r
F P
0 g
s
.35546 .40601 m .39733 .39081 L .40263 .36308 L p .788 .847 .896 r
F P
0 g
s
.62197 .76039 m .61864 .78856 L .69726 .78198 L p .584 .288 .432 r
F P
0 g
s
.69726 .78198 m .70504 .75159 L .62197 .76039 L p .584 .288 .432 r
F P
0 g
s
.47392 .78116 m .47247 .75379 L .39849 .74654 L p .738 .438 .474 r
F P
0 g
s
.47247 .75379 m .47392 .78116 L .54417 .78593 L p .707 .412 .475 r
F P
0 g
s
.61159 .37146 m .65396 .37753 L .63986 .35422 L p .513 .67 .934 r
F P
0 g
s
.63986 .35422 m .60248 .35512 L .61159 .37146 L p .513 .67 .934 r
F P
0 g
s
.56441 .36141 m .60248 .35512 L .58485 .34226 L p .567 .72 .945 r
F P
0 g
s
.58485 .34226 m .55569 .35441 L .56441 .36141 L p .567 .72 .945 r
F P
0 g
s
.2792 .45286 m .24815 .48468 L .28122 .54113 L p .899 .801 .743 r
F P
0 g
s
.26221 .57965 m .28122 .54113 L .24815 .48468 L p .933 .797 .687 r
F P
0 g
s
.45746 .34643 m .49202 .35725 L .50251 .35129 L p .673 .804 .945 r
F P
0 g
s
.49202 .35725 m .45746 .34643 L .44401 .36193 L p .699 .793 .923 r
F P
0 g
s
.40263 .36308 m .36181 .36947 L .35546 .40601 L p .788 .847 .896 r
F P
0 g
s
.31558 .4266 m .35546 .40601 L .36181 .36947 L p .83 .885 .883 r
F P
0 g
s
.55569 .35441 m .58485 .34226 L .56094 .33362 L p .555 .747 .966 r
F P
0 g
s
.56094 .33362 m .54375 .3496 L .55569 .35441 L p .555 .747 .966 r
F P
0 g
s
.40263 .36308 m .44401 .36193 L .45746 .34643 L p .716 .844 .943 r
F P
0 g
s
.76733 .47799 m .79728 .51251 L .801 .45735 L p .238 .358 .784 r
F P
0 g
s
.801 .45735 m .77049 .42843 L .76733 .47799 L p .238 .358 .784 r
F P
0 g
s
.78366 .64573 m .78695 .68613 L .83853 .63492 L p .262 .137 .515 r
F P
0 g
s
.83853 .63492 m .83433 .59248 L .78366 .64573 L p .262 .137 .515 r
F P
0 g
s
.47871 .33561 m .50251 .35129 L .51562 .34793 L p .639 .808 .964 r
F P
0 g
s
.50251 .35129 m .47871 .33561 L .45746 .34643 L p .673 .804 .945 r
F P
0 g
s
.65396 .37753 m .69535 .38872 L .67573 .3591 L p .404 .618 .938 r
F P
0 g
s
.67573 .3591 m .63986 .35422 L .65396 .37753 L p .404 .618 .938 r
F P
0 g
s
.31829 .69644 m .32132 .7305 L .39849 .74654 L p .795 .511 .509 r
F P
0 g
s
.40267 .77503 m .39849 .74654 L .32132 .7305 L p .789 .468 .445 r
F P
0 g
s
.39849 .74654 m .40267 .77503 L .47392 .78116 L p .738 .438 .474 r
F P
0 g
s
.54375 .3496 m .56094 .33362 L .53341 .32946 L p .566 .776 .977 r
F P
0 g
s
.53341 .32946 m .52989 .34737 L .54375 .3496 L p .566 .776 .977 r
F P
0 g
s
.50503 .33001 m .51562 .34793 L .52989 .34737 L p .599 .799 .976 r
F P
0 g
s
.51562 .34793 m .50503 .33001 L .47871 .33561 L p .639 .808 .964 r
F P
0 g
s
.52989 .34737 m .53341 .32946 L .50503 .33001 L p .599 .799 .976 r
F P
0 g
s
.25053 .61958 m .24701 .65952 L .31829 .69644 L p .876 .619 .546 r
F P
0 g
s
.32132 .7305 m .31829 .69644 L .24701 .65952 L p .88 .574 .466 r
F P
0 g
s
.54323 .81057 m .54417 .78593 L .47392 .78116 L p .692 .359 .408 r
F P
0 g
s
.54417 .78593 m .54323 .81057 L .61291 .81312 L p .644 .305 .383 r
F P
0 g
s
.61291 .81312 m .61864 .78856 L .54417 .78593 L p .644 .305 .383 r
F P
0 g
s
.70504 .75159 m .69726 .78198 L .76912 .75829 L p .413 .123 .361 r
F P
0 g
s
.76912 .75829 m .78209 .72417 L .70504 .75159 L p .413 .123 .361 r
F P
0 g
s
.60248 .35512 m .63986 .35422 L .61291 .33674 L p .445 .694 .972 r
F P
0 g
s
.61291 .33674 m .58485 .34226 L .60248 .35512 L p .445 .694 .972 r
F P
0 g
s
.24815 .48468 m .22437 .52143 L .26221 .57965 L p .933 .797 .687 r
F P
0 g
s
.25053 .61958 m .26221 .57965 L .22437 .52143 L p .964 .78 .607 r
F P
0 g
s
.36181 .36947 m .32265 .38188 L .31558 .4266 L p .83 .885 .883 r
F P
0 g
s
.2792 .45286 m .31558 .4266 L .32265 .38188 L p .876 .925 .854 r
F P
0 g
s
.47661 .80613 m .47392 .78116 L .40267 .77503 L p .727 .387 .405 r
F P
0 g
s
.47392 .78116 m .47661 .80613 L .54323 .81057 L p .692 .359 .408 r
F P
0 g
s
.61864 .78856 m .61291 .81312 L .68457 .80766 L p .546 .197 .328 r
F P
0 g
s
.68457 .80766 m .69726 .78198 L .61864 .78856 L p .546 .197 .328 r
F P
0 g
s
.45746 .34643 m .42313 .34077 L .40263 .36308 L p .716 .844 .943 r
F P
0 g
s
.36181 .36947 m .40263 .36308 L .42313 .34077 L p .732 .903 .955 r
F P
0 g
s
.79728 .51251 m .82016 .5511 L .82435 .49185 L p .068 .195 .689 r
F P
0 g
s
.82435 .49185 m .801 .45735 L .79728 .51251 L p .068 .195 .689 r
F P
0 g
s
.69535 .38872 m .73468 .40557 L .70912 .37014 L p .241 .526 .917 r
F P
0 g
s
.70912 .37014 m .67573 .3591 L .69535 .38872 L p .241 .526 .917 r
F P
0 g
s
.42313 .34077 m .45746 .34643 L .47871 .33561 L p .653 .862 .979 r
F P
0 g
s
.78695 .68613 m .78209 .72417 L .83217 .67647 L p .133 0 .358 r
F P
0 g
s
.83217 .67647 m .83853 .63492 L .78695 .68613 L p .133 0 .358 r
F P
0 g
s
.58485 .34226 m .61291 .33674 L .57719 .32546 L p .385 .723 .989 r
F P
0 g
s
.57719 .32546 m .56094 .33362 L .58485 .34226 L p .385 .723 .989 r
F P
0 g
s
.32265 .38188 m .28667 .40097 L .2792 .45286 L p .876 .925 .854 r
F P
0 g
s
.24815 .48468 m .2792 .45286 L .28667 .40097 L p .92 .957 .794 r
F P
0 g
s
.32132 .7305 m .32985 .7616 L .40267 .77503 L p .789 .468 .445 r
F P
0 g
s
.40998 .80054 m .40267 .77503 L .32985 .7616 L p .776 .405 .354 r
F P
0 g
s
.40267 .77503 m .40998 .80054 L .47661 .80613 L p .727 .387 .405 r
F P
0 g
s
.63986 .35422 m .67573 .3591 L .63902 .3381 L p .229 .611 .953 r
F P
0 g
s
.63902 .3381 m .61291 .33674 L .63986 .35422 L p .229 .611 .953 r
F P
0 g
s
.45554 .32629 m .47871 .33561 L .50503 .33001 L p .56 .853 .997 r
F P
0 g
s
.47871 .33561 m .45554 .32629 L .42313 .34077 L p .653 .862 .979 r
F P
0 g
s
.22437 .52143 m .20962 .56194 L .25053 .61958 L p .964 .78 .607 r
F P
0 g
s
.24701 .65952 m .25053 .61958 L .20962 .56194 L p .983 .738 .485 r
F P
0 g
s
.24701 .65952 m .25212 .69797 L .32132 .7305 L p .88 .574 .466 r
F P
0 g
s
.32985 .7616 m .32132 .7305 L .25212 .69797 L p .871 .506 .353 r
F P
0 g
s
.73468 .40557 m .77049 .42843 L .73889 .38758 L p 0 .363 .833 r
F P
0 g
s
.73889 .38758 m .70912 .37014 L .73468 .40557 L p 0 .363 .833 r
F P
0 g
s
.42313 .34077 m .38972 .34092 L .36181 .36947 L p .732 .903 .955 r
F P
0 g
s
.32265 .38188 m .36181 .36947 L .38972 .34092 L p .735 .961 .941 r
F P
0 g
s
.54179 .83146 m .54323 .81057 L .47661 .80613 L p .663 .277 .304 r
F P
0 g
s
.54323 .81057 m .54179 .83146 L .60464 .83312 L p .603 .207 .265 r
F P
0 g
s
.60464 .83312 m .61291 .81312 L .54323 .81057 L p .603 .207 .265 r
F P
0 g
s
.56094 .33362 m .57719 .32546 L .53672 .31981 L p .38 .762 .99 r
F P
0 g
s
.53672 .31981 m .53341 .32946 L .56094 .33362 L p .38 .762 .99 r
F P
0 g
s
.69726 .78198 m .68457 .80766 L .74857 .78721 L p .322 0 .191 r
F P
0 g
s
.74857 .78721 m .76912 .75829 L .69726 .78198 L p .322 0 .191 r
F P
0 g
s
.82016 .5511 m .83433 .59248 L .83883 .53096 L p 0 0 .515 r
F P
0 g
s
.83883 .53096 m .82435 .49185 L .82016 .5511 L p 0 0 .515 r
F P
0 g
s
.49494 .31973 m .50503 .33001 L .53341 .32946 L p .453 .813 .996 r
F P
0 g
s
.50503 .33001 m .49494 .31973 L .45554 .32629 L p .56 .853 .997 r
F P
0 g
s
.48076 .82756 m .47661 .80613 L .40998 .80054 L p .702 .308 .298 r
F P
0 g
s
.47661 .80613 m .48076 .82756 L .54179 .83146 L p .663 .277 .304 r
F P
0 g
s
.53341 .32946 m .53672 .31981 L .49494 .31973 L p .453 .813 .996 r
F P
0 g
s
.38972 .34092 m .42313 .34077 L .45554 .32629 L p .59 .909 .98 r
F P
0 g
s
.61291 .81312 m .60464 .83312 L .66718 .82779 L p .477 .06 .169 r
F P
0 g
s
.66718 .82779 m .68457 .80766 L .61291 .81312 L p .477 .06 .169 r
F P
0 g
s
.28667 .40097 m .25578 .42702 L .24815 .48468 L p .92 .957 .794 r
F P
0 g
s
.22437 .52143 m .24815 .48468 L .25578 .42702 L p .943 .958 .67 r
F P
0 g
s
.78209 .72417 m .76912 .75829 L .8154 .71518 L p 0 0 .112 r
F P
0 g
s
.8154 .71518 m .83217 .67647 L .78209 .72417 L p 0 0 .112 r
F P
0 g
s
.61291 .33674 m .63902 .3381 L .59188 .32531 L p .042 .567 .866 r
F P
0 g
s
.57719 .32546 m .61291 .33674 L p .59607 .32758 L .042 .567 .866 r
F P
0 g
s
.6624 .34634 m .63902 .3381 L .67573 .3591 L p 0 .401 .792 r
F P
0 g
s
.6624 .34634 m .60453 .33283 L p .63222 .33706 L .393 0 0 r
F P
0 g
s
.63902 .3381 m .64726 .341 L p .63222 .33706 L .393 0 0 r
F P
0 g
s
.64726 .341 m .6624 .34634 L p .63222 .33706 L .393 0 0 r
F P
0 g
s
.59188 .32531 m .58755 .32535 L p .59607 .32758 L .042 .567 .866 r
F P
0 g
s
.58755 .32535 m .57719 .32546 L p .59607 .32758 L .042 .567 .866 r
F P
0 g
s
.67573 .3591 m .70912 .37014 L .6624 .34634 L p 0 .401 .792 r
F P
0 g
s
.20962 .56194 m .20524 .60457 L .24701 .65952 L p .983 .738 .485 r
F P
0 g
s
.25212 .69797 m .24701 .65952 L .20524 .60457 L p .968 .647 .297 r
F P
0 g
s
.77049 .42843 m .801 .45735 L .76381 .41144 L p 0 .093 .623 r
F P
0 g
s
.76381 .41144 m .73889 .38758 L .77049 .42843 L p 0 .093 .623 r
F P
0 g
s
.32985 .7616 m .34393 .78884 L .40998 .80054 L p .776 .405 .354 r
F P
0 g
s
.42073 .82207 m .40998 .80054 L .34393 .78884 L p .741 .304 .213 r
F P
0 g
s
.40998 .80054 m .42073 .82207 L .48076 .82756 L p .702 .308 .298 r
F P
0 g
s
.38972 .34092 m .35815 .34755 L .32265 .38188 L p .735 .961 .941 r
F P
0 g
s
.28667 .40097 m .32265 .38188 L .35815 .34755 L p .691 .981 .849 r
F P
0 g
s
.25212 .69797 m .26581 .73343 L .32985 .7616 L p .871 .506 .353 r
F P
0 g
s
.34393 .78884 m .32985 .7616 L .26581 .73343 L p .835 .397 .188 r
F P
0 g
s
.83433 .59248 m .83853 .63492 L .84316 .57319 L p 0 0 .219 r
F P
0 g
s
.84316 .57319 m .83883 .53096 L .83433 .59248 L p 0 0 .219 r
F P
0 g
s
.43366 .32381 m .45554 .32629 L .49494 .31973 L p .357 .818 .925 r
F P
0 g
s
.45554 .32629 m .43366 .32381 L .38972 .34092 L p .59 .909 .98 r
F P
0 g
s
.53979 .84711 m .54179 .83146 L .48076 .82756 L p .599 .137 .129 r
F P
0 g
s
.54179 .83146 m .53979 .84711 L .5937 .84743 L p .518 .043 .067 r
F P
0 g
s
.5937 .84743 m .60464 .83312 L .54179 .83146 L p .518 .043 .067 r
F P
0 g
s
.68457 .80766 m .66718 .82779 L .72135 .81001 L p .171 0 0 r
F P
0 g
s
.72135 .81001 m .74857 .78721 L .68457 .80766 L p .171 0 0 r
F P
0 g
s
.35815 .34755 m .38972 .34092 L .43366 .32381 L p .418 .866 .855 r
F P
0 g
s
.25578 .42702 m .23199 .45984 L .22437 .52143 L p .943 .958 .67 r
F P
0 g
s
.20962 .56194 m .22437 .52143 L .23199 .45984 L p .89 .871 .431 r
F P
0 g
s
.57719 .32546 m .59188 .32531 L .53969 .31864 L p 0 .562 .78 r
F P
0 g
s
.53672 .31981 m .57719 .32546 L p .54235 .31912 L 0 .562 .78 r
F P
0 g
s
.60453 .33283 m .54221 .32554 L p .58839 .32532 L .418 0 0 r
F P
0 g
s
.59188 .32531 m .59294 .32593 L p .58839 .32532 L .418 0 0 r
F P
0 g
s
.59294 .32593 m .60453 .33283 L p .58839 .32532 L .418 0 0 r
F P
0 g
s
.53969 .31864 m .53945 .31873 L p .54235 .31912 L 0 .562 .78 r
F P
0 g
s
.53945 .31873 m .53672 .31981 L p .54235 .31912 L 0 .562 .78 r
F P
0 g
s
.48658 .84392 m .48076 .82756 L .42073 .82207 L p .641 .168 .115 r
F P
0 g
s
.48076 .82756 m .48658 .84392 L .53979 .84711 L p .599 .137 .129 r
F P
0 g
s
.48574 .31743 m .49494 .31973 L .53672 .31981 L p .119 .665 .819 r
F P
0 g
s
.49494 .31973 m .48574 .31743 L .43366 .32381 L p .357 .818 .925 r
F P
0 g
s
.60464 .83312 m .5937 .84743 L .64544 .84168 L p .343 0 0 r
F P
0 g
s
.64544 .84168 m .66718 .82779 L .60464 .83312 L p .343 0 0 r
F P
0 g
s
.53672 .31981 m .53969 .31864 L .48574 .31743 L p .119 .665 .819 r
F P
0 g
s
.801 .45735 m .82435 .49185 L .78265 .44143 L p .699 .243 0 r
F P
0 g
s
.78265 .44143 m .76381 .41144 L .801 .45735 L p .699 .243 0 r
F P
0 g
s
.76912 .75829 m .74857 .78721 L .78916 .74933 L p 0 0 0 r
F P
0 g
s
.78916 .74933 m .8154 .71518 L .76912 .75829 L p 0 0 0 r
F P
0 g
s
.70912 .37014 m .73889 .38758 L .68242 .36122 L p .514 0 0 r
F P
0 g
s
.68242 .36122 m .6624 .34634 L .70912 .37014 L p .514 0 0 r
F P
0 g
s
.20524 .60457 m .21186 .64734 L .25212 .69797 L p .968 .647 .297 r
F P
0 g
s
.26581 .73343 m .25212 .69797 L .21186 .64734 L p .872 .468 .014 r
F P
0 g
s
.35815 .34755 m .32959 .36127 L .28667 .40097 L p .691 .981 .849 r
F P
0 g
s
.25578 .42702 m .28667 .40097 L .32959 .36127 L p .526 .861 .59 r
F P
0 g
s
.60453 .33283 m .59188 .32531 L .63902 .3381 L p .393 0 0 r
F P
0 g
s
.83853 .63492 m .83217 .67647 L .83671 .61664 L p .78 .708 .17 r
F P
0 g
s
.83671 .61664 m .84316 .57319 L .83853 .63492 L p .78 .708 .17 r
F P
0 g
s
.34393 .78884 m .36345 .81132 L .42073 .82207 L p .741 .304 .213 r
F P
0 g
s
.43517 .83838 m .42073 .82207 L .36345 .81132 L p .651 .127 0 r
F P
0 g
s
.42073 .82207 m .43517 .83838 L .48658 .84392 L p .641 .168 .115 r
F P
0 g
s
.26581 .73343 m .2876 .76457 L .34393 .78884 L p .835 .397 .188 r
F P
0 g
s
.36345 .81132 m .34393 .78884 L .2876 .76457 L p .737 .215 0 r
F P
0 g
s
.23199 .45984 m .21718 .49855 L .20962 .56194 L p .89 .871 .431 r
F P
0 g
s
.20524 .60457 m .20962 .56194 L .21718 .49855 L p 0 0 0 r
F P
0 g
s
.43366 .32381 m .41371 .32847 L .35815 .34755 L p .418 .866 .855 r
F P
0 g
s
.41371 .32847 m .43366 .32381 L .48574 .31743 L p .012 0 0 r
F P
0 g
s
.32959 .36127 m .35815 .34755 L .41371 .32847 L p 0 0 0 r
F P
0 g
s
.66718 .82779 m .64544 .84168 L .68866 .82618 L p 0 0 0 r
F P
0 g
s
.68866 .82618 m .72135 .81001 L .66718 .82779 L p 0 0 0 r
F P
0 g
s
.5372 .85584 m .53979 .84711 L .48658 .84392 L p .436 0 0 r
F P
0 g
s
.53979 .84711 m .5372 .85584 L .5801 .85486 L p .323 0 0 r
F P
0 g
s
.5801 .85486 m .5937 .84743 L .53979 .84711 L p .323 0 0 r
F P
0 g
s
.82435 .49185 m .83883 .53096 L .79427 .47688 L p .905 .511 .094 r
F P
0 g
s
.79427 .47688 m .78265 .44143 L .82435 .49185 L p .905 .511 .094 r
F P
0 g
s
.49419 .85346 m .48658 .84392 L .43517 .83838 L p .474 0 0 r
F P
0 g
s
.48658 .84392 m .49419 .85346 L .5372 .85584 L p .436 0 0 r
F P
0 g
s
.54221 .32554 m .53969 .31864 L .59188 .32531 L p .418 0 0 r
F P
0 g
s
.21186 .64734 m .22929 .6882 L .26581 .73343 L p .872 .468 .014 r
F P
0 g
s
.2876 .76457 m .26581 .73343 L .22929 .6882 L p .64 .181 0 r
F P
0 g
s
.73889 .38758 m .76381 .41144 L .69855 .38236 L p .745 .227 0 r
F P
0 g
s
.69855 .38236 m .68242 .36122 L .73889 .38758 L p .745 .227 0 r
F P
0 g
s
.74857 .78721 m .72135 .81001 L .75501 .7777 L p .535 .871 .607 r
F P
0 g
s
.75501 .7777 m .78916 .74933 L .74857 .78721 L p .535 .871 .607 r
F P
0 g
s
.32959 .36127 m .30537 .38244 L .25578 .42702 L p .526 .861 .59 r
F P
0 g
s
.23199 .45984 m .25578 .42702 L .30537 .38244 L p 0 0 0 r
F P
0 g
s
.5937 .84743 m .5801 .85486 L .61984 .84877 L p .083 0 0 r
F P
0 g
s
.61984 .84877 m .64544 .84168 L .5937 .84743 L p .083 0 0 r
F P
0 g
s
.4777 .32294 m .48574 .31743 L .53969 .31864 L p .294 0 0 r
F P
0 g
s
.48574 .31743 m .4777 .32294 L .41371 .32847 L p .012 0 0 r
F P
0 g
s
.83217 .67647 m .8154 .71518 L .81964 .65927 L p .926 .902 .502 r
F P
0 g
s
.81964 .65927 m .83671 .61664 L .83217 .67647 L p .926 .902 .502 r
F P
0 g
s
.53969 .31864 m .54221 .32554 L .4777 .32294 L p .294 0 0 r
F P
0 g
s
.6624 .34634 m .68242 .36122 L .61488 .34728 L p .642 .112 0 r
F P
0 g
s
.61488 .34728 m .60453 .33283 L .6624 .34634 L p .642 .112 0 r
F P
0 g
s
.2876 .76457 m .31656 .79036 L .36345 .81132 L p .737 .215 0 r
F P
0 g
s
.38813 .82818 m .36345 .81132 L .31656 .79036 L p .513 0 0 r
F P
0 g
s
.36345 .81132 m .38813 .82818 L .43517 .83838 L p .651 .127 0 r
F P
0 g
s
.45334 .8481 m .43517 .83838 L .38813 .82818 L p .418 0 0 r
F P
0 g
s
.43517 .83838 m .45334 .8481 L .49419 .85346 L p .474 0 0 r
F P
0 g
s
.21718 .49855 m .21276 .54165 L .20524 .60457 L p 0 0 0 r
F P
0 g
s
.21186 .64734 m .20524 .60457 L .21276 .54165 L p 0 0 .322 r
F P
0 g
s
.83883 .53096 m .84316 .57319 L .79784 .51675 L p .972 .661 .355 r
F P
0 g
s
.79784 .51675 m .79427 .47688 L .83883 .53096 L p .972 .661 .355 r
F P
0 g
s
.39633 .34038 m .41371 .32847 L .4777 .32294 L p .332 0 0 r
F P
0 g
s
.41371 .32847 m .39633 .34038 L .32959 .36127 L p 0 0 0 r
F P
0 g
s
.30537 .38244 m .32959 .36127 L .39633 .34038 L p .194 0 0 r
F P
0 g
s
.64544 .84168 m .61984 .84877 L .65175 .83567 L p .331 .813 .793 r
F P
0 g
s
.65175 .83567 m .68866 .82618 L .64544 .84168 L p .331 .813 .793 r
F P
0 g
s
.22929 .6882 m .25653 .72527 L .2876 .76457 L p .64 .181 0 r
F P
0 g
s
.31656 .79036 m .2876 .76457 L .25653 .72527 L p 0 .142 .66 r
F P
0 g
s
.76381 .41144 m .78265 .44143 L .71039 .40922 L p .833 .402 .213 r
F P
0 g
s
.71039 .40922 m .69855 .38236 L .76381 .41144 L p .833 .402 .213 r
F P
0 g
s
.30537 .38244 m .28689 .41102 L .23199 .45984 L p 0 0 0 r
F P
0 g
s
.21718 .49855 m .23199 .45984 L .28689 .41102 L p .034 0 .18 r
F P
0 g
s
.72135 .81001 m .68866 .82618 L .71482 .79964 L p .658 .972 .844 r
F P
0 g
s
.71482 .79964 m .75501 .7777 L .72135 .81001 L p .658 .972 .844 r
F P
0 g
s
.8154 .71518 m .78916 .74933 L .79292 .69914 L p .944 .962 .705 r
F P
0 g
s
.79292 .69914 m .81964 .65927 L .8154 .71518 L p .944 .962 .705 r
F P
0 g
s
.53402 .85601 m .5372 .85584 L .49419 .85346 L p .057 0 0 r
F P
0 g
s
.5372 .85584 m .53402 .85601 L .56404 .8543 L p .059 .624 .751 r
F P
0 g
s
.56404 .8543 m .5801 .85486 L .5372 .85584 L p .059 .624 .751 r
F P
0 g
s
.60453 .33283 m .61488 .34728 L .54424 .33962 L p .612 .12 .062 r
F P
0 g
s
.54424 .33962 m .54221 .32554 L .60453 .33283 L p .612 .12 .062 r
F P
0 g
s
.49419 .85346 m .50355 .85447 L .53402 .85601 L p .057 0 0 r
F P
0 g
s
.50355 .85447 m .49419 .85346 L .45334 .8481 L p 0 .507 .711 r
F P
0 g
s
.31656 .79036 m .3515 .81014 L .38813 .82818 L p .513 0 0 r
F P
0 g
s
.38813 .82818 m .41753 .83865 L .45334 .8481 L p .418 0 0 r
F P
0 g
s
.41753 .83865 m .38813 .82818 L .3515 .81014 L p 0 .4 .761 r
F P
0 g
s
.21276 .54165 m .21941 .58712 L .21186 .64734 L p 0 0 .322 r
F P
0 g
s
.22929 .6882 m .21186 .64734 L .21941 .58712 L p 0 .044 .581 r
F P
0 g
s
.47104 .33574 m .4777 .32294 L .54221 .32554 L p .523 .028 .022 r
F P
0 g
s
.4777 .32294 m .47104 .33574 L .39633 .34038 L p .332 0 0 r
F P
0 g
s
.5801 .85486 m .56404 .8543 L .59096 .8487 L p .263 .768 .867 r
F P
0 g
s
.59096 .8487 m .61984 .84877 L .5801 .85486 L p .263 .768 .867 r
F P
0 g
s
.68242 .36122 m .69855 .38236 L .62286 .36771 L p .733 .293 .205 r
F P
0 g
s
.62286 .36771 m .61488 .34728 L .68242 .36122 L p .733 .293 .205 r
F P
0 g
s
.54221 .32554 m .54424 .33962 L .47104 .33574 L p .523 .028 .022 r
F P
0 g
s
.47503 .84992 m .45334 .8481 L .41753 .83865 L p .007 .557 .827 r
F P
0 g
s
.45334 .8481 m .47503 .84992 L .50355 .85447 L p 0 .507 .711 r
F P
0 g
s
.84316 .57319 m .83671 .61664 L .79289 .55962 L p .972 .736 .522 r
F P
0 g
s
.79289 .55962 m .79784 .51675 L .84316 .57319 L p .972 .736 .522 r
F P
0 g
s
.25653 .72527 m .29191 .75715 L .31656 .79036 L p 0 .142 .66 r
F P
0 g
s
.3515 .81014 m .31656 .79036 L .29191 .75715 L p .003 .396 .849 r
F P
0 g
s
.39633 .34038 m .38209 .35942 L .30537 .38244 L p .194 0 0 r
F P
0 g
s
.28689 .41102 m .30537 .38244 L .38209 .35942 L p .368 .005 .211 r
F P
0 g
s
.78916 .74933 m .75501 .7777 L .75814 .73466 L p .908 .956 .814 r
F P
0 g
s
.75814 .73466 m .79292 .69914 L .78916 .74933 L p .908 .956 .814 r
F P
0 g
s
.78265 .44143 m .79427 .47688 L .71763 .44122 L p .859 .502 .374 r
F P
0 g
s
.71763 .44122 m .71039 .40922 L .78265 .44143 L p .859 .502 .374 r
F P
0 g
s
.38209 .35942 m .39633 .34038 L .47104 .33574 L p .497 .067 .154 r
F P
0 g
s
.61984 .84877 m .59096 .8487 L .61179 .83866 L p .507 .889 .963 r
F P
0 g
s
.61179 .83866 m .65175 .83567 L .61984 .84877 L p .507 .889 .963 r
F P
0 g
s
.68866 .82618 m .65175 .83567 L .67049 .81508 L p .69 .96 .944 r
F P
0 g
s
.67049 .81508 m .71482 .79964 L .68866 .82618 L p .69 .96 .944 r
F P
0 g
s
.28689 .41102 m .27542 .44646 L .21718 .49855 L p .034 0 .18 r
F P
0 g
s
.21276 .54165 m .21718 .49855 L .27542 .44646 L p .215 .036 .41 r
F P
0 g
s
.21941 .58712 m .23689 .63264 L .22929 .6882 L p 0 .044 .581 r
F P
0 g
s
.25653 .72527 m .22929 .6882 L .23689 .63264 L p .135 .26 .729 r
F P
0 g
s
.61488 .34728 m .62286 .36771 L .54578 .35972 L p .684 .276 .266 r
F P
0 g
s
.54578 .35972 m .54424 .33962 L .61488 .34728 L p .684 .276 .266 r
F P
0 g
s
.3515 .81014 m .39112 .82359 L .41753 .83865 L p 0 .4 .761 r
F P
0 g
s
.45098 .84209 m .41753 .83865 L .39112 .82359 L p .2 .632 .948 r
F P
0 g
s
.41753 .83865 m .45098 .84209 L .47503 .84992 L p .007 .557 .827 r
F P
0 g
s
.69855 .38236 m .71039 .40922 L .62851 .39319 L p .764 .392 .351 r
F P
0 g
s
.62851 .39319 m .62286 .36771 L .69855 .38236 L p .764 .392 .351 r
F P
0 g
s
.53034 .84638 m .53402 .85601 L .50355 .85447 L p .373 .783 .981 r
F P
0 g
s
.53402 .85601 m .53034 .84638 L .5459 .84492 L p .419 .81 .988 r
F P
0 g
s
.5459 .84492 m .56404 .8543 L .53402 .85601 L p .419 .81 .988 r
F P
0 g
s
.51441 .84565 m .50355 .85447 L .47503 .84992 L p .359 .764 .983 r
F P
0 g
s
.50355 .85447 m .51441 .84565 L .53034 .84638 L p .373 .783 .981 r
F P
0 g
s
.46583 .35504 m .47104 .33574 L .54424 .33962 L p .62 .209 .242 r
F P
0 g
s
.47104 .33574 m .46583 .35504 L .38209 .35942 L p .497 .067 .154 r
F P
0 g
s
.83671 .61664 m .81964 .65927 L .77942 .60385 L p .948 .772 .63 r
F P
0 g
s
.77942 .60385 m .79289 .55962 L .83671 .61664 L p .948 .772 .63 r
F P
0 g
s
.54424 .33962 m .54578 .35972 L .46583 .35504 L p .62 .209 .242 r
F P
0 g
s
.29191 .75715 m .33343 .78299 L .3515 .81014 L p .003 .396 .849 r
F P
0 g
s
.39112 .82359 m .3515 .81014 L .33343 .78299 L p .232 .559 .935 r
F P
0 g
s
.56404 .8543 m .5459 .84492 L .55952 .84125 L p .494 .84 .996 r
F P
0 g
s
.55952 .84125 m .59096 .8487 L .56404 .8543 L p .494 .84 .996 r
F P
0 g
s
.75501 .7777 m .71482 .79964 L .71722 .76476 L p .857 .928 .873 r
F P
0 g
s
.71722 .76476 m .75814 .73466 L .75501 .7777 L p .857 .928 .873 r
F P
0 g
s
.49967 .84284 m .47503 .84992 L .45098 .84209 L p .381 .752 .991 r
F P
0 g
s
.47503 .84992 m .49967 .84284 L .51441 .84565 L p .359 .764 .983 r
F P
0 g
s
.65175 .83567 m .61179 .83866 L .62361 .82437 L p .682 .911 .974 r
F P
0 g
s
.62361 .82437 m .67049 .81508 L .65175 .83567 L p .682 .911 .974 r
F P
0 g
s
.79427 .47688 m .79784 .51675 L .71999 .47771 L p .863 .565 .481 r
F P
0 g
s
.71999 .47771 m .71763 .44122 L .79427 .47688 L p .863 .565 .481 r
F P
0 g
s
.27542 .44646 m .27193 .48765 L .21276 .54165 L p .215 .036 .41 r
F P
0 g
s
.21941 .58712 m .21276 .54165 L .27193 .48765 L p .33 .203 .552 r
F P
0 g
s
.23689 .63264 m .26409 .67599 L .25653 .72527 L p .135 .26 .729 r
F P
0 g
s
.29191 .75715 m .25653 .72527 L .26409 .67599 L p .279 .408 .814 r
F P
0 g
s
.38209 .35942 m .3715 .38531 L .28689 .41102 L p .368 .005 .211 r
F P
0 g
s
.27542 .44646 m .28689 .41102 L .3715 .38531 L p .462 .171 .384 r
F P
0 g
s
.59096 .8487 m .55952 .84125 L .56973 .83548 L p .585 .861 .995 r
F P
0 g
s
.56973 .83548 m .61179 .83866 L .59096 .8487 L p .585 .861 .995 r
F P
0 g
s
.3715 .38531 m .38209 .35942 L .46583 .35504 L p .576 .22 .328 r
F P
0 g
s
.62286 .36771 m .62851 .39319 L .54686 .38476 L p .713 .364 .383 r
F P
0 g
s
.54686 .38476 m .54578 .35972 L .62286 .36771 L p .713 .364 .383 r
F P
0 g
s
.81964 .65927 m .79292 .69914 L .75792 .6477 L p .916 .789 .705 r
F P
0 g
s
.75792 .6477 m .77942 .60385 L .81964 .65927 L p .916 .789 .705 r
F P
0 g
s
.39112 .82359 m .43417 .8307 L .45098 .84209 L p .2 .632 .948 r
F P
0 g
s
.4876 .83807 m .45098 .84209 L .43417 .8307 L p .438 .739 .991 r
F P
0 g
s
.45098 .84209 m .4876 .83807 L .49967 .84284 L p .381 .752 .991 r
F P
0 g
s
.33343 .78299 m .37907 .80254 L .39112 .82359 L p .232 .559 .935 r
F P
0 g
s
.43417 .8307 m .39112 .82359 L .37907 .80254 L p .393 .66 .966 r
F P
0 g
s
.71482 .79964 m .67049 .81508 L .6721 .78893 L p .806 .894 .906 r
F P
0 g
s
.6721 .78893 m .71722 .76476 L .71482 .79964 L p .806 .894 .906 r
F P
0 g
s
.71039 .40922 m .71763 .44122 L .63192 .42301 L p .776 .454 .443 r
F P
0 g
s
.63192 .42301 m .62851 .39319 L .71039 .40922 L p .776 .454 .443 r
F P
0 g
s
.26409 .67599 m .29923 .71528 L .29191 .75715 L p .279 .408 .814 r
F P
0 g
s
.33343 .78299 m .29191 .75715 L .29923 .71528 L p .382 .513 .866 r
F P
0 g
s
.4621 .38004 m .46583 .35504 L .54578 .35972 L p .665 .316 .371 r
F P
0 g
s
.46583 .35504 m .4621 .38004 L .3715 .38531 L p .576 .22 .328 r
F P
0 g
s
.54578 .35972 m .54686 .38476 L .4621 .38004 L p .665 .316 .371 r
F P
0 g
s
.61179 .83866 m .56973 .83548 L .57532 .828 L p .662 .856 .974 r
F P
0 g
s
.57532 .828 m .62361 .82437 L .61179 .83866 L p .662 .856 .974 r
F P
0 g
s
.52632 .82641 m .53034 .84638 L .51441 .84565 L closepath p .58 .796 .981 r
F P
0 g
s
.52632 .82641 m .5459 .84492 L .53034 .84638 L closepath p .583 .798 .981 r
F P
0 g
s
.27193 .48765 m .27692 .53293 L .21941 .58712 L p .33 .203 .552 r
F P
0 g
s
.23689 .63264 m .21941 .58712 L .27692 .53293 L p .408 .322 .646 r
F P
0 g
s
.79784 .51675 m .79289 .55962 L .71723 .51797 L p .858 .607 .558 r
F P
0 g
s
.71723 .51797 m .71999 .47771 L .79784 .51675 L p .858 .607 .558 r
F P
0 g
s
.52632 .82641 m .51441 .84565 L .49967 .84284 L closepath p .579 .795 .981 r
F P
0 g
s
.52632 .82641 m .55952 .84125 L .5459 .84492 L closepath p .594 .803 .98 r
F P
0 g
s
.52632 .82641 m .49967 .84284 L .4876 .83807 L closepath p .578 .789 .979 r
F P
0 g
s
.67049 .81508 m .62361 .82437 L .62445 .80713 L p .756 .86 .926 r
F P
0 g
s
.62445 .80713 m .6721 .78893 L .67049 .81508 L p .756 .86 .926 r
F P
0 g
s
.79292 .69914 m .75814 .73466 L .72933 .68949 L p .882 .797 .76 r
F P
0 g
s
.72933 .68949 m .75792 .6477 L .79292 .69914 L p .882 .797 .76 r
F P
0 g
s
.3715 .38531 m .36499 .41751 L .27542 .44646 L p .462 .171 .384 r
F P
0 g
s
.27193 .48765 m .27542 .44646 L .36499 .41751 L p .518 .281 .495 r
F P
0 g
s
.37907 .80254 m .42717 .81603 L .43417 .8307 L p .393 .66 .966 r
F P
0 g
s
.47955 .83159 m .43417 .8307 L .42717 .81603 L p .507 .723 .97 r
F P
0 g
s
.43417 .8307 m .47955 .83159 L .4876 .83807 L p .438 .739 .991 r
F P
0 g
s
.52632 .82641 m .56973 .83548 L .55952 .84125 L closepath p .614 .806 .974 r
F P
0 g
s
.29923 .71528 m .34017 .74925 L .33343 .78299 L p .382 .513 .866 r
F P
0 g
s
.37907 .80254 m .33343 .78299 L .34017 .74925 L p .458 .592 .898 r
F P
0 g
s
.36499 .41751 m .3715 .38531 L .4621 .38004 L p .618 .317 .437 r
F P
0 g
s
.52632 .82641 m .4876 .83807 L .47955 .83159 L closepath p .581 .778 .973 r
F P
0 g
s
.62851 .39319 m .63192 .42301 L .54751 .41394 L p .727 .42 .459 r
F P
0 g
s
.54751 .41394 m .54686 .38476 L .62851 .39319 L p .727 .42 .459 r
F P
0 g
s
.71763 .44122 m .71999 .47771 L .63313 .45675 L p .78 .497 .508 r
F P
0 g
s
.63313 .45675 m .63192 .42301 L .71763 .44122 L p .78 .497 .508 r
F P
0 g
s
.52632 .82641 m .57532 .828 L .56973 .83548 L closepath p .639 .803 .962 r
F P
0 g
s
.62361 .82437 m .57532 .828 L .57556 .81954 L p .707 .827 .939 r
F P
0 g
s
.57556 .81954 m .62445 .80713 L .62361 .82437 L p .707 .827 .939 r
F P
0 g
s
.75814 .73466 m .71722 .76476 L .69488 .72775 L p .847 .799 .804 r
F P
0 g
s
.69488 .72775 m .72933 .68949 L .75814 .73466 L p .847 .799 .804 r
F P
0 g
s
.27692 .53293 m .29029 .58034 L .23689 .63264 L p .408 .322 .646 r
F P
0 g
s
.26409 .67599 m .23689 .63264 L .29029 .58034 L p .465 .411 .713 r
F P
0 g
s
.34017 .74925 m .38484 .77729 L .37907 .80254 L p .458 .592 .898 r
F P
0 g
s
.42717 .81603 m .37907 .80254 L .38484 .77729 L p .519 .655 .92 r
F P
0 g
s
.79289 .55962 m .77942 .60385 L .70916 .56111 L p .849 .639 .618 r
F P
0 g
s
.70916 .56111 m .71723 .51797 L .79289 .55962 L p .849 .639 .618 r
F P
0 g
s
.42717 .81603 m .4765 .82385 L .47955 .83159 L p .507 .723 .97 r
F P
0 g
s
.52632 .82641 m .47955 .83159 L .4765 .82385 L closepath p .592 .765 .962 r
F P
0 g
s
.54686 .38476 m .54751 .41394 L .45984 .41005 L p .688 .384 .455 r
F P
0 g
s
.45984 .41005 m .4621 .38004 L .54686 .38476 L p .688 .384 .455 r
F P
0 g
s
.4621 .38004 m .45984 .41005 L .36499 .41751 L p .618 .317 .437 r
F P
0 g
s
.52632 .82641 m .57556 .81954 L .57532 .828 L closepath p .658 .792 .947 r
F P
0 g
s
.38484 .77729 m .43151 .79931 L .42717 .81603 L p .519 .655 .92 r
F P
0 g
s
.4765 .82385 m .42717 .81603 L .43151 .79931 L p .568 .707 .936 r
F P
0 g
s
.71722 .76476 m .6721 .78893 L .65595 .76129 L p .81 .798 .841 r
F P
0 g
s
.65595 .76129 m .69488 .72775 L .71722 .76476 L p .81 .798 .841 r
F P
0 g
s
.36499 .41751 m .36291 .45529 L .27193 .48765 L p .518 .281 .495 r
F P
0 g
s
.27692 .53293 m .27193 .48765 L .36291 .45529 L p .555 .361 .573 r
F P
0 g
s
.43151 .79931 m .47893 .81559 L .4765 .82385 L p .568 .707 .936 r
F P
0 g
s
.52632 .82641 m .4765 .82385 L .47893 .81559 L closepath p .611 .754 .946 r
F P
0 g
s
.52632 .82641 m .56029 .80378 L .57036 .81109 L closepath p .667 .764 .923 r
F P
0 g
s
.52632 .82641 m .54648 .79865 L .56029 .80378 L closepath p .664 .757 .919 r
F P
0 g
s
.52632 .82641 m .53045 .79642 L .54648 .79865 L closepath p .663 .754 .918 r
F P
0 g
s
.52632 .82641 m .51395 .79739 L .53045 .79642 L closepath p .661 .753 .918 r
F P
0 g
s
.52632 .82641 m .49878 .80137 L .51395 .79739 L closepath p .657 .751 .919 r
F P
0 g
s
.52632 .82641 m .48664 .80774 L .49878 .80137 L closepath p .647 .748 .923 r
F P
0 g
s
.52632 .82641 m .47893 .81559 L .48664 .80774 L closepath p .631 .748 .932 r
F P
0 g
s
.52632 .82641 m .57036 .81109 L .57556 .81954 L closepath p .666 .777 .932 r
F P
0 g
s
.29029 .58034 m .31138 .62773 L .26409 .67599 L p .465 .411 .713 r
F P
0 g
s
.29923 .71528 m .26409 .67599 L .31138 .62773 L p .509 .483 .764 r
F P
0 g
s
.6721 .78893 m .62445 .80713 L .61399 .78926 L p .769 .794 .873 r
F P
0 g
s
.61399 .78926 m .65595 .76129 L .6721 .78893 L p .769 .794 .873 r
F P
0 g
s
.63192 .42301 m .63313 .45675 L .54775 .44689 L p .734 .46 .514 r
F P
0 g
s
.54775 .44689 m .54751 .41394 L .63192 .42301 L p .734 .46 .514 r
F P
0 g
s
.62445 .80713 m .57556 .81954 L .57036 .81109 L p .723 .788 .904 r
F P
0 g
s
.71999 .47771 m .71723 .51797 L .63205 .49423 L p .781 .531 .559 r
F P
0 g
s
.63205 .49423 m .63313 .45675 L .71999 .47771 L p .781 .531 .559 r
F P
0 g
s
.57036 .81109 m .61399 .78926 L .62445 .80713 L p .723 .788 .904 r
F P
0 g
s
.36291 .45529 m .36499 .41751 L .45984 .41005 L p .642 .384 .513 r
F P
0 g
s
.77942 .60385 m .75792 .6477 L .69569 .60605 L p .837 .664 .668 r
F P
0 g
s
.69569 .60605 m .70916 .56111 L .77942 .60385 L p .837 .664 .668 r
F P
0 g
s
.44697 .78275 m .48664 .80774 L .47893 .81559 L p .615 .698 .903 r
F P
0 g
s
.47893 .81559 m .43151 .79931 L .44697 .78275 L p .615 .698 .903 r
F P
0 g
s
.31138 .62773 m .33904 .67312 L .29923 .71528 L p .509 .483 .764 r
F P
0 g
s
.34017 .74925 m .29923 .71528 L .33904 .67312 L p .543 .544 .805 r
F P
0 g
s
.54751 .41394 m .54775 .44689 L .45905 .44458 L p .702 .434 .515 r
F P
0 g
s
.45905 .44458 m .45984 .41005 L .54751 .41394 L p .702 .434 .515 r
F P
0 g
s
.61399 .78926 m .57036 .81109 L .56029 .80378 L p .722 .754 .878 r
F P
0 g
s
.45984 .41005 m .45905 .44458 L .36291 .45529 L p .642 .384 .513 r
F P
0 g
s
.4083 .75163 m .44697 .78275 L .43151 .79931 L p .596 .649 .873 r
F P
0 g
s
.43151 .79931 m .38484 .77729 L .4083 .75163 L p .596 .649 .873 r
F P
0 g
s
.33904 .67312 m .37185 .71483 L .34017 .74925 L p .543 .544 .805 r
F P
0 g
s
.38484 .77729 m .34017 .74925 L .37185 .71483 L p .572 .598 .841 r
F P
0 g
s
.37185 .71483 m .4083 .75163 L .38484 .77729 L p .572 .598 .841 r
F P
0 g
s
.47148 .76891 m .49878 .80137 L .48664 .80774 L p .65 .696 .879 r
F P
0 g
s
.48664 .80774 m .44697 .78275 L .47148 .76891 L p .65 .696 .879 r
F P
0 g
s
.75792 .6477 m .72933 .68949 L .6769 .65145 L p .823 .686 .712 r
F P
0 g
s
.6769 .65145 m .69569 .60605 L .75792 .6477 L p .823 .686 .712 r
F P
0 g
s
.36291 .45529 m .3655 .4977 L .27692 .53293 L p .555 .361 .573 r
F P
0 g
s
.29029 .58034 m .27692 .53293 L .3655 .4977 L p .581 .423 .633 r
F P
0 g
s
.56029 .80378 m .59368 .77356 L .61399 .78926 L p .722 .754 .878 r
F P
0 g
s
.59368 .77356 m .56029 .80378 L .54648 .79865 L p .713 .728 .863 r
F P
0 g
s
.71723 .51797 m .70916 .56111 L .62847 .53531 L p .781 .562 .603 r
F P
0 g
s
.62847 .53531 m .63205 .49423 L .71723 .51797 L p .781 .562 .603 r
F P
0 g
s
.63313 .45675 m .63205 .49423 L .54756 .48359 L p .739 .494 .559 r
F P
0 g
s
.54756 .48359 m .54775 .44689 L .63313 .45675 L p .739 .494 .559 r
F P
0 g
s
.65595 .76129 m .61399 .78926 L .59368 .77356 L p .759 .739 .835 r
F P
0 g
s
.50181 .7601 m .51395 .79739 L .49878 .80137 L p .674 .699 .865 r
F P
0 g
s
.49878 .80137 m .47148 .76891 L .50181 .7601 L p .674 .699 .865 r
F P
0 g
s
.72933 .68949 m .69488 .72775 L .65313 .69568 L p .806 .705 .754 r
F P
0 g
s
.65313 .69568 m .6769 .65145 L .72933 .68949 L p .806 .705 .754 r
F P
0 g
s
.54648 .79865 m .56615 .76252 L .59368 .77356 L p .713 .728 .863 r
F P
0 g
s
.56615 .76252 m .54648 .79865 L .53045 .79642 L p .702 .713 .857 r
F P
0 g
s
.3655 .4977 m .36291 .45529 L .45905 .44458 L p .657 .435 .571 r
F P
0 g
s
.53448 .75782 m .53045 .79642 L .51395 .79739 L p .69 .704 .858 r
F P
0 g
s
.51395 .79739 m .50181 .7601 L .53448 .75782 L p .69 .704 .858 r
F P
0 g
s
.69488 .72775 m .65595 .76129 L .62506 .73699 L p .786 .723 .794 r
F P
0 g
s
.59368 .77356 m .62506 .73699 L .65595 .76129 L p .759 .739 .835 r
F P
0 g
s
.53045 .79642 m .53448 .75782 L .56615 .76252 L p .702 .713 .857 r
F P
0 g
s
.62506 .73699 m .65313 .69568 L .69488 .72775 L p .786 .723 .794 r
F P
0 g
s
.54775 .44689 m .54756 .48359 L .45981 .48332 L p .71 .472 .564 r
F P
0 g
s
.45981 .48332 m .45905 .44458 L .54775 .44689 L p .71 .472 .564 r
F P
0 g
s
.44549 .73012 m .47148 .76891 L .44697 .78275 L p .646 .649 .839 r
F P
0 g
s
.44697 .78275 m .4083 .75163 L .44549 .73012 L p .646 .649 .839 r
F P
0 g
s
.3655 .4977 m .37286 .54354 L .29029 .58034 L p .581 .423 .633 r
F P
0 g
s
.31138 .62773 m .29029 .58034 L .37286 .54354 L p .6 .475 .681 r
F P
0 g
s
.45905 .44458 m .45981 .48332 L .3655 .4977 L p .657 .435 .571 r
F P
0 g
s
.70916 .56111 m .69569 .60605 L .62207 .57961 L p .779 .591 .645 r
F P
0 g
s
.62207 .57961 m .62847 .53531 L .70916 .56111 L p .779 .591 .645 r
F P
0 g
s
.62506 .73699 m .59368 .77356 L .56615 .76252 L p .741 .7 .813 r
F P
0 g
s
.63205 .49423 m .62847 .53531 L .5469 .52414 L p .742 .524 .599 r
F P
0 g
s
.5469 .52414 m .54756 .48359 L .63205 .49423 L p .742 .524 .599 r
F P
0 g
s
.42183 .68646 m .44549 .73012 L .4083 .75163 L p .639 .606 .801 r
F P
0 g
s
.4083 .75163 m .37185 .71483 L .42183 .68646 L p .639 .606 .801 r
F P
0 g
s
.37286 .54354 m .38492 .59139 L .31138 .62773 L p .6 .475 .681 r
F P
0 g
s
.33904 .67312 m .31138 .62773 L .38492 .59139 L p .616 .521 .724 r
F P
0 g
s
.49056 .71651 m .50181 .7601 L .47148 .76891 L p .68 .655 .818 r
F P
0 g
s
.47148 .76891 m .44549 .73012 L .49056 .71651 L p .68 .655 .818 r
F P
0 g
s
.37286 .54354 m .3655 .4977 L .45981 .48332 L p .667 .477 .618 r
F P
0 g
s
.56615 .76252 m .58426 .72006 L .62506 .73699 L p .741 .7 .813 r
F P
0 g
s
.58426 .72006 m .56615 .76252 L .53448 .75782 L p .722 .676 .804 r
F P
0 g
s
.69569 .60605 m .6769 .65145 L .61258 .62629 L p .775 .618 .685 r
F P
0 g
s
.61258 .62629 m .62207 .57961 L .69569 .60605 L p .775 .618 .685 r
F P
0 g
s
.4014 .63962 m .42183 .68646 L .37185 .71483 L p .629 .564 .763 r
F P
0 g
s
.37185 .71483 m .33904 .67312 L .4014 .63962 L p .629 .564 .763 r
F P
0 g
s
.65313 .69568 m .62506 .73699 L .58426 .72006 L p .758 .672 .767 r
F P
0 g
s
.54756 .48359 m .5469 .52414 L .46223 .52593 L p .714 .505 .606 r
F P
0 g
s
.46223 .52593 m .45981 .48332 L .54756 .48359 L p .714 .505 .606 r
F P
0 g
s
.38492 .59139 m .4014 .63962 L .33904 .67312 L p .616 .521 .724 r
F P
0 g
s
.53816 .71296 m .53448 .75782 L .50181 .7601 L p .704 .663 .807 r
F P
0 g
s
.50181 .7601 m .49056 .71651 L .53816 .71296 L p .704 .663 .807 r
F P
0 g
s
.53448 .75782 m .53816 .71296 L .58426 .72006 L p .722 .676 .804 r
F P
0 g
s
.45981 .48332 m .46223 .52593 L .37286 .54354 L p .667 .477 .618 r
F P
0 g
s
.6769 .65145 m .65313 .69568 L .59992 .67381 L p .769 .645 .726 r
F P
0 g
s
.59992 .67381 m .61258 .62629 L .6769 .65145 L p .769 .645 .726 r
F P
0 g
s
.58426 .72006 m .59992 .67381 L .65313 .69568 L p .758 .672 .767 r
F P
0 g
s
.62847 .53531 m .62207 .57961 L .54568 .56842 L p .743 .553 .638 r
F P
0 g
s
.54568 .56842 m .5469 .52414 L .62847 .53531 L p .743 .553 .638 r
F P
0 g
s
.4807 .66902 m .49056 .71651 L .44549 .73012 L p .682 .616 .776 r
F P
0 g
s
.44549 .73012 m .42183 .68646 L .4807 .66902 L p .682 .616 .776 r
F P
0 g
s
.38492 .59139 m .37286 .54354 L .46223 .52593 L p .674 .513 .66 r
F P
0 g
s
.59992 .67381 m .58426 .72006 L .53816 .71296 L p .734 .643 .758 r
F P
0 g
s
.5469 .52414 m .54568 .56842 L .46646 .57186 L p .716 .536 .645 r
F P
0 g
s
.46646 .57186 m .46223 .52593 L .5469 .52414 L p .716 .536 .645 r
F P
0 g
s
.62207 .57961 m .61258 .62629 L .54383 .61575 L p .742 .582 .676 r
F P
0 g
s
.54383 .61575 m .54568 .56842 L .62207 .57961 L p .742 .582 .676 r
F P
0 g
s
.46223 .52593 m .46646 .57186 L .38492 .59139 L p .674 .513 .66 r
F P
0 g
s
.54132 .66468 m .53816 .71296 L .49056 .71651 L p .711 .627 .762 r
F P
0 g
s
.49056 .71651 m .4807 .66902 L .54132 .66468 L p .711 .627 .762 r
F P
0 g
s
.53816 .71296 m .54132 .66468 L .59992 .67381 L p .734 .643 .758 r
F P
0 g
s
.47262 .62009 m .4807 .66902 L .42183 .68646 L p .681 .581 .736 r
F P
0 g
s
.42183 .68646 m .4014 .63962 L .47262 .62009 L p .681 .581 .736 r
F P
0 g
s
.4014 .63962 m .38492 .59139 L .46646 .57186 L p .679 .547 .698 r
F P
0 g
s
.61258 .62629 m .59992 .67381 L .54132 .66468 L p .74 .612 .716 r
F P
0 g
s
.54132 .66468 m .54383 .61575 L .61258 .62629 L p .74 .612 .716 r
F P
0 g
s
.46646 .57186 m .47262 .62009 L .4014 .63962 L p .679 .547 .698 r
F P
0 g
s
.54568 .56842 m .54383 .61575 L .47262 .62009 L p .716 .565 .683 r
F P
0 g
s
.47262 .62009 m .46646 .57186 L .54568 .56842 L p .716 .565 .683 r
F P
0 g
s
.54383 .61575 m .54132 .66468 L .4807 .66902 L p .715 .595 .721 r
F P
0 g
s
.4807 .66902 m .47262 .62009 L .54383 .61575 L p .715 .595 .721 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Y_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo000Qooooo`03oeEEEOmV
IVKo000000Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Uooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:Oooool002[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`2Tooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0
02Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Ooooooa[o0000:_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0E_oooolEo`0000SoB`0000?o0000of/00?m[00000_m[0008o`0002;o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`0001[ooooo
00?o0000ooooooooool0C_ooool<o`0000GoE00000?o0000ohD71On51`D02?n51`D?o`0000KoJ`00
1_l0000Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`19ooooo`Ko00003_mD00000ol0003oQ@L5ohD7
1@0BohD71@03o`000?nL7PooW1h?00?oW1h?2Ol00002of/000Go00006Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0AOooool3o`0001CoE00000?o0000ohD71On51`D04_n51`D00ol0003oW1h?oi`N3`0<
oi`N3`[o00005_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Gooooo000Yoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool5o`0000koE0003Ol0000?ohD7
1@03o`000?nL7PooW1h?013oW1h?00?o0000oj@L0?nT70001ol0000Booooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0mooooo`Ko00001?mD000<o`0000KoOa4W00?o0000oihe?OnN=Cd01?nN=Cd;o`0000Co
Q@L500?o0000oi`N3onL7Pl04OnL7Pl00ol0003oY1`0oj@L0002oj@L00So00003_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02Cooooo000Xooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0>Oooool=o`00017oOa4W00?o0000oihe?OnN=Cd04?nN=Cd;o`0000koW1h?
00?o0000oj@L0?nT70001OnT7006o`0000cooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Sooooo`00:?ooool2o`00027ooooo00?o0000ooooooooool0=Oooool8o`0000;o<@0000?o
0000oglA9omo4BL05?mo4BL00ol0003oWSDmoihe?@0Doihe?@03o`000?n_ATCo[dI400Co[dI42ol0
0004oi`N3`03o`000?nT703oY1`000SoY1`01?l0000:ooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0a
ooooo`So00001?la00000ol0003oOa4WoglA9`0EoglA9`03o`000?nN=CgoWSDm01CoWSDm00?o0000
ojm6A?n_AT@03on_AT@9o`0000WoY1`00ol00008ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool08_ooool002Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0^oooo
o`Ko00001ola00000ol0003oOa4WoglA9`0EoglA9`03o`000?nN=CgoWSDm01GoWSDm00?o0000ojm6
A?n_AT@05?n_AT@01?l0003o^d/dok];=?nkBc@5o`0000OoY1`00_l00006ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08Oooool002Sooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Zooooo`Ko00002_la00000ol0003oOa4WoglA9`0?oglA9`go00004_nN=Cd00ol0
003o[dI4ojm6A00Dojm6A003o`000?nkBcCo^d/d00Go^d/d1Ol00004oj@L00;o00001?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo000Wooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09oooool4o`0000go<@0000?o0000oglA9omo4BL00omo4BL=o`0000Ko
TcQC00?o0000ojY@G_nZD5h01?nZD5h=o`0000GoWSDm00?o0000ojm6A?n_AT@05?n_AT@00ol0003o
^d/dok];=00:ok];=0Wo000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0Pooooo`00
9oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo0_l0000=oc4000Wo0000
4onC>5<00ol0003oZU1NojY@GP0AojY@GPco00004?n_AT@00ol0003o^d/dok];=00?ok];=0Ko0000
?Oooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo02?ooooo00?o0000oc400?la00002_la0003o`0000;oGP4f00?o0000oi<hDonC>5<05onC
>5<00ol0003oZU1NojY@GP0FojY@GP03o`000?nfGF;o]UeR00Co]UeR3?l00005ojm6A003o`000?nk
BcCo^d/d013o^d/d00?o0000okhj0?l000000ol0000looooo`03o`000?oooooooooo01oooooo000W
ooooo`;o0000:Oooool00ol0003oooooooooo`0Qooooo`03o`000?la003o<@0000Oo<@001?l00004
oeh1=P03o`000?nC>5?oTcQC01SoTcQC00?o0000ojY@G_nZD5h05_nZD5h00ol0003o]UeRokIMHP0@
okIMHPSo00004OnkBc@00ol0003o_SX0o`000004o`0003_ooooo00?o0000ooooooooool07_ooool0
02Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Oooooo`03o`000?la003o<@00
00Go<@000ol00008oeh1=P03o`000?nC>5?oTcQC01OoTcQC00?o0000ojY@G_nZD5h05onZD5h00ol0
003o]UeRokIMHP0EokIMHP03o`000?o3I5Wo`fAI00Go00003OnkBc@2o`0000;o_SX01?l0000ioooo
o`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool07Oooool00ol0003o<@00oc400003oc4000?o00002_mN0CH00ol0003oTcQCoi<hD`0Hoi<hD`03
o`000?nZD5koZU1N01OoZU1N00?o0000okIMH_nfGF805OnfGF800ol0003o`fAIol=TF@05ol=TF@Go
00002OnkBc@00ol0003o_SX0okhj0002okhj00?o0000>Oooool00ol0003oooooooooo`0Mooooo`00
9oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01_ooooo00?o0000oc400?la0000
1?l0000=oeh1=P03o`000?nC>5?oTcQC01SoTcQC00?o0000ojY@G_nZD5h05onZD5h00ol0003o]UeR
okIMHP0FokIMHP03o`000?o3I5Wo`fAI00Wo`fAI1Ol00004ok];=003o`000?nn>P3o_SX000Co_SX0
0ol0000gooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool06Oooool4o`00013oGP4f00?o0000oi<hDonC>5<04_nC>5<?o`0001;oZU1N00?o
0000okIMH_nfGF805_nfGF800ol0003o`fAIol=TF@0>ol=TF@Ko00001_nn>P03o`0003Oooooo00?o
0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0F
ooooo`?o00004omN0CH00ol0003oTcQCoi<hD`03oi<hD`oo00001onNDFl00ol0003o/69dok1RM005
ok1RM0go00001OnZD5h00ol0003o]UeRokIMHP0FokIMHP03o`000?o3I5Wo`fAI01;o`fAI1?l00006
okhj00?o0000=_ooool00ol0003oooooooooo`0Kooooo`009_ooool3o`0002oooooo00?o0000oooo
ooooool05?ooool3o`00017oGP4f2Ol0000FoiiAK`03o`000?n`HWCo/69d01;o/69d3Ol0000AokIM
HP03o`000?o3I5Wo`fAI01?o`fAI0_l000000ooEISKo0000o`000006okhj00;o0000=Oooool00ol0
003oooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01;o
oooo0ol0000?oeh1=P?o00000_mf:f800ol0003oWU5_oiiAK`0JoiiAK`03o`000?n`HWCo/69d01Oo
/69d00?o0000okY[MOnjJgD01OnjJgD=o`0000Go]UeR00?o0000ol=TFOo3I5T04_o3I5T00ol0003o
`fAIo`000002omEV=P?o00001Onn>P02o`0003Cooooo00?o0000ooooooooool06_ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`?o00003OmN0CH3o`00
00GoMR]R00?o0000oiiAKonNDFl06_nNDFl00ol0003o/69dok1RM00Gok1RM003o`000?njJgGo^V]e
01;o^V]e2Ol0000Aol=TF@03o`000?o3I5Wo000000GoeFHf0_l00005okhj0003o`000?oooooooooo
037ooooo00?o0000ooooooooool06_ooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool03_ooool4o`0000[oGP4f0ol00007ogH[HP03o`000?nNDFooWU5_01_oWU5_00?o0000ok1R
M?n`HW@05on`HW@00ol0003o^V]eokY[M@0GokY[M@04o`000?o6M77oaWAaolIdL@Go00003?o3I5T0
0ol0003o`fAIo`000007omEV=P;o00001?nn>P000ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01Wooooo0003ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00cooooo1?l00007
oeh1=PCo00002_mf:f800ol0003oWU5_oiiAK`0JoiiAK`03o`000?n`HWCo/69d01So/69d00?o0000
okY[MOnjJgD05onjJgD00ol0003oaWAaolIdL@06olIdL@Go00001oo3I5T01?l0003o`fAIol=TFOl0
0008omEV=P;o00000onn>P000ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Sooooo000;
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02_ooool4o`0000GoGP4f0ol0000>ogH[HP03o`000?nN
DFooWU5_01[oWU5_00?o0000ok1RM?n`HW@06On`HW@00ol0003o^V]eokY[M@0FokY[M@03o`000?o6
M77oaWAa00_oaWAa1Ol00002ol=TF@04o`000?o3I5Wo`fAIo`0000[oeFHf0_l00002okhj0003o`00
0?oooooooooo033ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Oooooo1_l00002oeh1=P?o00004Omf:f800ol0003oWU5_oiiAK`0JoiiAK`03
o`000?n`HWCo/69d01Wo/69d00?o0000okY[MOnjJgD05_njJgD00ol0003oaWAaolIdL@0@olIdL@Ko
00003?oEISH4o`0003;ooooo00?o0000ooooooooool05oooool000_ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000hooooo`03o`000?oooooooooo00Go
oooo2Ol0000DogH[HP03o`000?nNDFooWU5_01[oWU5_00?o0000ok1RM?n`HW@06On`HW@00ol0003o
^V]eokY[M@0FokY[M@03o`000?o6M77oaWAa01;oaWAa00?o0000olIdLOo6M7400ol0000=omEV=P;o
0000<Oooool00ol0003oooooooooo`0Gooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?o
oooo1ol0000FogH[HP03o`000?nNDFooWU5_01CoWU5_5_l0000=ok1RM003o`000?njJgGo^V]e01Oo
^V]e00?o0000olIdLOo6M7404Oo6M7401_l0003oaWAaolIdLOo6M77o0000om^0G`;o00003OoEISH0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo000;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool0>Oooool01?l0003ooooooooooooo
ool5o`000003o`P0;_l0003oMR]R01KoMR]R00?o0000oiiAKonNDFl01OnNDFl?o`0000OoY6:300?o
0000ok=_PoncKh<03?ncKh<Bo`0001Go^V]e00?o0000olIdLOo6M7404Oo6M7401Ol0003oaWAaolId
LOo6M77o000000?ofh1O0ol0000:omEV=P03o`000?oooooooooo02kooooo0ol0000Gooooo`009?oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Go000000?o200^o`000?mf:f805Omf
:f8:o`0001KoY6:300?o0000ok=_PoncKh<06OncKh<00ol0003o^gF3ok]eP`02ok]eP`Wo00003?nj
JgD00ol0003oaWAaolIdL@0AolIdL@03o`000?o6M77oaWAa00;oaWAa00?o0000om^0GooKP5l00ooK
P5l2o`0000WoeFHf00?o0000ooooooooool0:_ooool3o`0000;ooooo00?o0000ooooooooool05Ooo
ool002Cooooo00?o0000ooooooooool0>oooool6o`0000;o200^00?o0000ogH[H_mf:f804Omf:f83
o`0000;oQ4Mn00?o0000ojARPonTHX<06onTHX<00ol0003o/fn3ok=_P`0Iok=_P`03o`000?nkMH?o
^gF300_o^gF32Ol00003okY[M@03o`000?o6M77oaWAa017oaWAa00?o0000olIdLOo6M7400_o6M740
0ol0003ofh1Oom^0G`05om^0G`;o00002?oEISH00ol0003oooooooooo`0Vooooo`?o00001Oooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`Go00000ol802h00ol0
003oMR]RogH[HP0>ogH[HP?o00001On4Agh00ol0003oY6:3ojARP`0KojARP`03o`000?ncKh?o/fn3
01Wo/fn300?o0000ok]ePonkMH<05?nkMH<7o`00013oaWAa00?o0000olIdLOo6M7400_o6M7400ol0
003ofh1Oom^0G`07om^0G`?o00001OoEISH2o`0002Cooooo0ol00008ooooo`03o`000?oooooooooo
01Gooooo000Tooooo`03o`000?oooooooooo03[ooooo1Ol00003o`P0;P03o`000?mf:f;oMR]R00co
MR]R0ol00008ohA7OP03o`000?nTHX?oY6:301_oY6:300?o0000ok=_PoncKh<06OncKh<00ol0003o
^gF3ok]eP`0Gok]eP`04o`000?o7Oh;oagn2olMoPPGo00002oo6M7400ol0003oaWAaolIdL@03olId
L@03o`000?oKP5oofh1O00Wofh1O0_l00004omEV=P;o00008?ooool3o`0000_ooooo00?o0000oooo
ooooool05Oooool002Cooooo0_l0000kooooo`Co00001?l802h00ol0003oMR]RogH[HP09ogH[HP?o
00002on4Agh00ol0003oY6:3ojARP`0KojARP`03o`000?ncKh?o/fn301Wo/fn300?o0000ok]ePonk
MH<05onkMH<00ol0003oagn2olMoPP06olMoPPKo00001Oo6M7400ol0003oaWAaolIdL@03olIdL@03
o`000?oKP5oofh1O00_ofh1O0_l00003omEV=P;o00007?ooool3o`0000oooooo00?o0000oooooooo
ool05?ooool002Cooooo00?o0000ooooooooool0>Oooool4o`0000Go200^00?o0000ogH[H_mf:f80
1_mf:f83o`0000koQ4Mn00?o0000ojARPonTHX<06onTHX<00ol0003o/fn3ok=_P`0Iok=_P`03o`00
0?nkMH?o^gF301Oo^gF300?o0000olMoP_o7Oh803?o7Oh86o`0000GoaWAa00?o0000om^0GooKP5l0
3OoKP5l4o`000003ok8n0?l0003ooooo01Oooooo0ol0000Booooo`03o`000?oooooooooo01Cooooo
000Sooooo`03o`000?oooooooooo03Wooooo0ol00006o`P0;P03o`000?mf:f;oMR]R00CoMR]R0ol0
000AohA7OP03o`000?nTHX?oY6:301_oY6:300?o0000ok=_PoncKh<06OncKh<00ol0003o^gF3ok]e
P`0Gok]eP`03o`000?o7Oh;oagn2017oagn21Ol00002olIdL@03o`000?oKP5oofh1O00oofh1O0ol0
000Eooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0i
ooooo`;o00001ol802h01?l0003oMR]RogH[H_mf:f83o`0001CoQ4Mn00?o0000ojARPonTHX<06onT
HX<00ol0003o/fn3ok=_P`0Iok=_P`03o`000?nkMH?o^gF301Oo^gF300?o0000olMoP_o7Oh804Oo7
Oh800ol0003oagn2olMoPP02olMoPPCo00004_oKP5l2o`00017ooooo0ol0000Hooooo`03o`000?oo
oooooooo01Cooooo000Sooooo`03o`000?oooooooooo03Sooooo0_l00008o`P0;PCo00005on4Agh0
0ol0003oY6:3ojARP`0GojARPa?o00003OncKh<00ol0003o^gF3ok]eP`0Gok]eP`03o`000?o7Oh;o
agn201;oagn200?o0000olMoP_o7Oh800oo7Oh801?l0003og91ko`000?l0000@om^0G`03o`000?nb
?P3o000000gooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooo
oooo03Oooooo0_l00007o`P0;P?o00006_n4Agh00ol0003oY6:3ojARP`0@ojARP`Oo00001?nXKi80
0ol0003o]GR@okEhT00<okEhT1;o00005OnkMH<00ol0003oagn2olMoPP0BolMoPP03o`000?o7Oh;o
agn200?oagn200Co0000omb@NooLT7_og91k0_l0000?om^0G`03o`000?nb?P3o000000Wooooo0ol0
000Nooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03Kooooo0_l00007
o`P0;P03o`000?lg2FSo000001_oQ4Mn00?o0000ojARPonTHX<02?nTHX<8o`0000_oZ6nB00?o0000
okEhT?neN9006OneN9000ol0003o_Gj?okenS`02okenS`Wo00003?nkMH<00ol0003oagn2olMoPP0B
olMoPP03o`000?o7Oh;oagn200?oagn200?o0000omb@NooLT7/00ooLT7/2o`0000gofh1O0_l00000
0onb?P3o0000ooooo`04ooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2o`00
03Oooooo00?o0000o`P0;_l802h01Ol802h01?l0003o=`UXocL9J?l0000KohA7OP04o`000?nTHX?o
Y6:3ojARP`Oo00004onXKi800ol0003o]GR@okEhT00IokEhT003o`000?nmOXoo_Gj?00_o_Gj?2Ol0
0003ok]eP`03o`000?o7Oh;oagn201;oagn200?o0000olMoP_o7Oh800oo7Oh800ol0003og91komb@
N`05omb@N`;o00002ooKP5l01_l0003oih8Ho`000?nb?P3o0000ooooo`?o00009Oooool00ol0003o
ooooooooo`0Cooooo`008oooool00ol0003oooooooooo`0eooooo`03o`000?l802ko200^00Go200^
00Go0000ocL9J?lg2FSo=`UXo`00000JohA7OPGo00006_nXKi800ol0003o]GR@okEhT00IokEhT003
o`000?nmOXoo_Gj?01Co_Gj?1_l0000BolMoPP03o`000?o7Oh;oagn200?oagn200?o0000omb@NooL
T7/01ooLT7/2o`0000[ofh1O00Go0000onN26?l0003o/Sh0o`00000Xooooo`03o`000?oooooooooo
01?ooooo000Rooooo`03o`000?oooooooooo03Gooooo00?o0000o`P0;_l802h01Ol802h00ol0003o
=`UXocL9J002ocL9J003o`000?n4AgkoQ4Mn01GoQ4Mn0ol000000on>G9;o0000ojQ_TP0LojQ_TP03
o`000?neN93o]GR@01Wo]GR@00?o0000okenSonmOXl05onmOXl00ol0003oahN?olN7S`04o`0000ko
agn200?o0000olMoP_o7Oh800oo7Oh800ol0003og91komb@N`09omb@N`;o00002?oKP5l01Ol0003o
ih8Ho`000?nb?P3o000002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o0000oooooooo
ool0=Oooool00ol0003o200^o`P0;P04o`P0;P03o`000?lg2FSo=`UX00?o=`UX00?o0000ohA7O_n4
Agh04_n4Agh3o`0000CoSUbB00?o0000ojQ_T_nXKi806onXKi800ol0003o]GR@okEhT00IokEhT003
o`000?nmOXoo_Gj?01Oo_Gj?00?o0000olN7Soo7Qhl01?o7Qhl4o`0000[oagn200?o0000olMoP_o7
Oh800oo7Oh800ol0003og91komb@N`0;omb@N`;o00001_oKP5l01_l0003oih8HonN26?l0003o/Sh0
o`0002Oooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0=?ooool00ol0
003o200^o`P0;P04o`P0;P03o`000?lg2FSo=`UX00Co=`UX00?o0000ohA7O_n4Agh03on4Agh3o`00
00OoSUbB00?o0000ojQ_T_nXKi806onXKi800ol0003o]GR@okEhT00IokEhT003o`000?nmOXoo_Gj?
01Oo_Gj?00?o0000olN7Soo7Qhl02?o7Qhl4o`0000Koagn200?o0000olMoP_o7Oh800oo7Oh800ol0
003og91komb@N`0=omb@N`;o00001OoKP5l01_l0003oih8HonN26?l0003o/Sh0o`0002Kooooo00?o
0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0=?ooool00ol0003o200^o`P0;P03
o`P0;P03o`000?lg2FSo=`UX00Co=`UX00?o0000ohA7O_n4Agh03On4Agh3o`0000[oSUbB00?o0000
ojQ_T_nXKi806onXKi800ol0003o]GR@okEhT00IokEhT003o`000?nmOXoo_Gj?01Oo_Gj?00?o0000
olN7Soo7Qhl03?o7Qhl3o`0000?oagn200?o0000olMoP_o7Oh800oo7Oh800ol0003og91komb@N`0?
omb@N`;o00000ooKP5l01?l0003oih8HonN26?oWPQP2o`0002Kooooo00?o0000ooooooooool04ooo
ool002;ooooo00?o0000ooooooooool0=?ooool01?l0003o200^o`P0;_l802h2o`0000Oo=`UX00?o
0000ohA7O_n4Agh02_n4Agh3o`0000goSUbB00?o0000ojQ_T_nXKi806onXKi800ol0003o]GR@okEh
T00IokEhT003o`000?nmOXoo_Gj?01Oo_Gj?00?o0000olN7Soo7Qhl03oo7Qhl4o`0000Goagn200?o
0000omb@NooLT7/04OoLT7/2o`000003om^0Gol0003oih8H00?oih8H0_l0000Uooooo`03o`000?oo
oooooooo01?ooooo000Qooooo`?o0000=?ooool01Ol0003o200^o`P0;_l802ko000000Wo=`UX00?o
0000ohA7O_n4Agh01on4Agh3o`00013oSUbB00?o0000ojQ_T_nXKi806onXKi800ol0003o]GR@okEh
T00IokEhT003o`000?nmOXoo_Gj?01Oo_Gj?00?o0000olN7Soo7Qhl04_o7Qhl5o`000003olMoP_l0
003og91k01Cog91k0ol00004onN260;o00009Oooool00ol0003oooooooooo`0Booooo`008Oooool0
0ol0003oooooooooo`0dooooo`04o`000?l802ko200^o`0000[o=`UX00?o0000ohA7O_n4Agh01?n4
Agh3o`0001CoSUbB00?o0000ojQ_T_nXKi806_nXKi800ol0003o]GR@okEhT00IokEhT003o`000?nm
OXoo_Gj?01Oo_Gj?00?o0000olN7Soo7Qhl04_o7Qhl00ol0003oahN?olN7S`02olN7S`?o00005_oL
T7/00ol0003oih8HonN26002onN260;o00009Oooool00ol0003oooooooooo`0Booooo`008Oooool0
0ol0003oooooooooo`0cooooo`04o`000?l802ko200^o`0000_o=`UX00Co0000ohA7O_n4AgkoQ4Mn
0ol0000GohiLTP03o`000?nXKi;oZ6nB01[oZ6nB00?o0000okEhT?neN9006OneN9000ol0003o_Gj?
okenS`0GokenS`03o`000?o7QhooahN?01;oahN?00?o0000olN7Soo7Qhl00oo7Qhl01?l0003ofi^>
o`000?l0000Domb@N`03o`000?oWPQSoih8H00?oih8H0_l0000Tooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo03?ooooo00?o0000o`P0;_l000003?lg2FP4o`0001[oSUbB
00?o0000ojQ_T_nXKi805_nXKi8Uo`0001Go_Gj?00?o0000olN7Soo7Qhl04_o7Qhl00ol0003oahN?
olN7S`03olN7S`04o`000?oKVhkofi^>om^KSP;o00004_oLT7/2o`0000Goih8H00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0booooo`03o`00
0?l802ko000000co=`UX0_l0000MohiLTP03o`000?nXKi;oZ6nB00ooZ6nB1ol00004ojYjWP03o`00
0?nfPI_o]X6K01Wo]X6K00?o0000okf6VOnmQYT00_nmQYT9o`0000co_Gj?00?o0000olN7Soo7Qhl0
4_o7Qhl00ol0003oahN?olN7S`03olN7S`03o`000?oKVhkofi^>00?ofi^>0_l0000@omb@N`03o`00
0?ohZE[o000000Goih8H00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Booooo`008Ooo
ool00ol0003oooooooooo`0booooo`;o00003?lg2FP00ol0003oE3>=o`00000MohiLTP03o`000?nX
Ki;oZ6nB00SoZ6nB1ol0000;ojYjWP03o`000?nfPI_o]X6K01Wo]X6K00?o0000okf6VOnmQYT02onm
QYT9o`0000?o_Gj?00?o0000olN7Soo7Qhl04_o7Qhl00ol0003oahN?olN7S`03olN7S`03o`000?oK
Vhkofi^>00Gofi^>0_l0000>omb@N`04o`000?ohZE[on:UJo`0000Goih8H00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?lg
2FSo=`UX00[o=`UX00Co0000oe@cSOmD<hgo00007On>G9801?l0003oZ6nBojQ_T_nXKi87o`0001;o
ZWZN00?o0000okJ1VonfPI/06OnfPI/00ol0003o_HJIokf6V@0Dokf6V@Ko00004_o7Qhl00ol0003o
ahN?olN7S`03olN7S`03o`000?oKVhkofi^>00Oofi^>0_l0000<omb@N`05o`000?ohZE[on:UJooRY
F_l000001?oWPQP00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo000Pooooo`?o
0000<_ooool00ol0003o=`UXocL9J00:ocL9J005o`000?mD<hgoE3>=oe@cSOl000007?n>G985o`00
01WoZWZN00?o0000okJ1VonfPI/06OnfPI/00ol0003o_HJIokf6V@0Gokf6V@03o`000?o7Si[oahnJ
00Co00003_o7Qhl00ol0003oahN?olN7S`03olN7S`03o`000?oKVhkofi^>00Wofi^>0ol00009omb@
N`03o`000?ohZE[on:UJ00;on:UJ00?o0000onN26?oWPQP00_oWPQP00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo017ooooo000Pooooo`03o`000?oooooooooo03;ooooo00?o0000ocL9J?lg
2FP02Olg2FP00ol0003oE3>=oe@cS@03oe@cS@03o`000?n>G9;oSUbB01KoSUbB0ol000000onDK:;o
0000ojYjWP0KojYjWP03o`000?nfPI_o]X6K01Wo]X6K00?o0000okf6VOnmQYT05onmQYT00ol0003o
ahnJolN?VP04olN?VPCo00002oo7Qhl00ol0003oahN?olN7S`02olN7S`03o`000?oKVhkofi^>00co
fi^>0_l00008omb@N`03o`000?ohZE[on:UJ00;on:UJ00Go0000onN26?oWPQSoih8Ho`00000Roooo
o`03o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`0booooo`03o`000?lg2FSo=`UX00So=`UX00?o0000oe@cSOmD<hd01?mD<hd00ol0
003oSUbBohiLTP0DohiLTP;o00001?nDK:800ol0003oZWZNojYjWP0JojYjWP03o`000?nfPI_o]X6K
01Wo]X6K00?o0000okf6VOnmQYT05onmQYT00ol0003oahnJolN?VP08olN?VPCo00001oo7Qhl00ol0
003oahN?olN7S`02olN7S`03o`000?oKVhkofi^>00kofi^>0_l00006omb@N`03o`000?ohZE[on:UJ
00?on:UJ00Co0000onN26?oWPQSo00008_ooool00ol0003oooooooooo`0Aooooo`005Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0<_ooool00ol0003o=`UXocL9J007
ocL9J003o`000?mD<hgoE3>=00GoE3>=00?o0000ohiLT_n>G9804On>G983o`0000KoU6bR00?o0000
ojYjW_nZNYh06onZNYh00ol0003o]X6KokJ1V`0GokJ1V`03o`000?nmQYWo_HJI01So_HJI00?o0000
olN?V_o7SiX03?o7SiX3o`0000CoahN?00?o0000olN7Soo7Qhl00_o7Qhl00ol0003ofi^>om^KSP0@
om^KSP;o00001?oLT7/00ol0003on:UJooRYFP03ooRYFP05o`000?oWPQSoih8HonN26?l000008Ooo
ool00ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0<_ooool00ol0003o=`UXocL9J006ocL9J003o`000?mD<hgoE3>=00KoE3>=00?o
0000ohiLT_n>G9803on>G982o`0000[oU6bR00?o0000ojYjW_nZNYh06_nZNYh00ol0003o]X6KokJ1
V`0GokJ1V`03o`000?nmQYWo_HJI01So_HJI00?o0000olN?V_o7SiX03oo7SiX5o`0000CoahN?00?o
0000om^KS_oKVhh04_oKVhh2o`0000;og91k00?o0000ooRYF_ohZEX01?ohZEX01?l0003oih8HonN2
6?l0000Qooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0booooo`03o`000?lg2FSo=`UX00Go=`UX00?o0000oe@cSOmD<hd0
1omD<hd00ol0003oSUbBohiLTP0<ohiLTP?o00003?nDK:800ol0003oZWZNojYjWP0JojYjWP03o`00
0?nfPI_o]X6K01Oo]X6K00?o0000okf6VOnmQYT06?nmQYT00ol0003oahnJolN?VP0ColN?VPCo0000
00?oahN?o`000?oKVhh05OoKVhh3o`0000Oon:UJ00Co0000onN26?oWPQSo00008?ooool00ol0003o
ooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0<_ooool2o`0000Ko=`UX00?o0000oe@cSOmD<hd02?mD<hd00ol0003oSUbBohiLTP09ohiLTP?o
00003onDK:800ol0003oZWZNojYjWP0JojYjWP03o`000?nfPI_o]X6K01Oo]X6K00?o0000okf6VOnm
QYT05onmQYT00ol0003oahnJolN?VP0DolN?VP04o`000?o7Si[oahnJolN?VP?o00005ooKVhh00ol0
003on:UJooRYFP06ooRYFP03o`000?oWPQSo0000023ooooo00?o0000ooooooooool04Oooool001Go
oooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000<oooool2o`0000Go=`UX00?o0000oe@c
SOmD<hd02OmD<hd00ol0003oSUbBohiLTP07ohiLTP;o00004_nDK:800ol0003oZWZNojYjWP0JojYj
WP03o`000?nfPI_o]X6K01Oo]X6K00?o0000okf6VOnmQYT05onmQYT00ol0003oahnJolN?VP0DolN?
VP03o`000?o7Si[oahnJ00;oahnJ00Co0000omVSW_l0003o00005OoKVhh00ol0003on:UJooRYFP07
ooRYFP03o`000?oWPQSo000001oooooo00?o0000ooooooooool04Oooool001Gooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo03;ooooo00?o0000ocL9J?lg2FP00olg2FP0
0ol0003oE3>=oe@cS@0;oe@cS@03o`000?n>G9;oSUbB00?oSUbB0ol0000DoiA/XP03o`000?nZNYko
ZWZN01[oZWZN00?o0000okJ1VonfPI/02_nfPI/Ao`0001Ko_HJI00?o0000olN?V_o7SiX05?o7SiX0
0ol0003oahnJolN?VP02olN?VP05o`000?oIXikofJ>NomVSW_l000005?oKVhh2o`0000Won:UJ0_l0
000Pooooo`03o`000?oooooooooo013ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0booooo`03o`000?lg2FSo=`UX00;o=`UX00?o0000oe@cSOmD<hd03?mD
<hd01?l0003oSUbBohiLT_n>G982o`0001OoU6bR00?o0000ojYjW_nZNYh05onZNYh@o`0000go]hVU
00Co0000okj=XonnSJ?o_XfS1ol0000?okf6V@03o`000?o7Si[oahnJ01CoahnJ00Go0000olN?V_o7
Si[oahnJo`000005omVSWP;o00004_oKVhh00ol0003on;b5o`000009ooRYFP03o`000?oooooooooo
01kooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0<_ooool01Ol0003o
=`UXocL9J?lg2FSo000000ooE3>=1?l0000IoiA/XP03o`000?nZNYkoZWZN01;oZWZN1Ol00003ojb3
Z003o`000?ngRJGo]hVU01Oo]hVU00?o0000okj=XonnSJ<02?nnSJ<6o`0000Wo_HJI00?o0000olN?
V_o7SiX05?o7SiX01Ol0003oahnJolN?V_o7Si[o000000OofJ>N0_l0000?om^KSP05o`000?oh_8Go
n;b5ooRlQOl000002OohZEX00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo000O
ooooo`03o`000?oooooooooo03;ooooo00Co0000ocL9J?lg2FSo00003omD<hd2o`0001goU6bR00?o
0000ojYjW_nZNYh02onZNYh6o`0000So[8>X00?o0000okN9YOngRJD05ongRJD00ol0003o_XfSokj=
X`0>okj=X`Oo00000_nmQYT00ol0003oahnJolN?VP0DolN?VP05o`000?o7Si[oahnJolN?V_l00000
2OoIXih2o`0000gofi^>00?o0000ooRlQOoh_8D00_oh_8D00ol0003on:UJooRYFP06ooRYFP03o`00
0?oooooooooo01gooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0<_oo
ool00ol0003o=`UXo`00000?oe@cS@03o`000?mXDZGo000001goU6bR00?o0000ojYjW_nZNYh01OnZ
NYh6o`0000ko[8>X00?o0000okN9YOngRJD05ongRJD00ol0003o_XfSokj=X`0Eokj=X`Go00005?o7
SiX01Ol0003oahnJolN?V_o7Si[o000000_ofJ>N0_l0000;om^KSP03o`000?oh_8Gon;b500;on;b5
00?o0000ooRYF_ohZEX01_ohZEX00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo
000Nooooo`03o`000?oooooooooo03?ooooo0_l0000?oe@cS@04o`000?mXDZGoJ5:Uo`0001goU6bR
00?o0000ojYjW_nZNYh01Ol0000Dojb3Z003o`000?ngRJGo]hVU01Oo]hVU00?o0000okj=XonnSJ<0
5onnSJ<00ol0003oaiNUolNGY@03o`00017oahnJ00Go0000olN?V_o7Si[oahnJo`00000=omVSWP03
o`000?oKVhkofi^>00Sofi^>00?o0000ooRlQOoh_8D00ooh_8D00ol0003on:UJooRYFP05ooRYFP03
o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool001kooooo00?o0000ooooooooool0
<_ooool2o`0000ooE3>=00?o0000ofQBYOmXDZD00_mXDZD00ol0003oU6bRoiA/XP0IoiA/XPCo0000
6On/PjP00ol0003o]hVUokN9Y@0GokN9Y@03o`000?nnSJ?o_XfS01Oo_XfS00?o0000olNGYOo7UjD0
0oo7UjD3o`0000koahnJ00Co0000olN?V_o7Si[o00003ooIXih2o`0000Sofi^>00?o0000ooRlQOoh
_8D01?oh_8D00ol0003on:UJooRYFP04ooRYFP03o`000?oooooooooo01gooooo00?o0000oooooooo
ool04?ooool001kooooo0_l0000cooooo`;o00003_mD<hd00ol0003oJ5:UofQBY@03ofQBY@03o`00
0?nDK:;oU6bR01OoU6bR0_l000000onINJko0000ojb3Z00Jojb3Z003o`000?ngRJGo]hVU01Oo]hVU
00?o0000okj=XonnSJ<05onnSJ<00ol0003oaiNUolNGY@06olNGY@?o00002oo7SiX01?l0003oahnJ
olN?V_l0000AomVSWP;o00001_oKVhh00ol0003on;b5ooRlQ@05ooRlQ@03o`000?ohZE[on:UJ00?o
n:UJ00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003ooooo
ooooo`0booooo`;o00003OmD<hd00ol0003oJ5:UofQBY@04ofQBY@03o`000?nDK:;oU6bR01GoU6bR
0_l00003oiUi[P03o`000?n/PjSo[8>X01Wo[8>X00?o0000okN9YOngRJD05ongRJD00ol0003o_XfS
okj=X`0Fokj=X`03o`000?o7UjGoaiNU00[oaiNU0ol00008olN?VP04o`000?o7Si[oahnJo`0001?o
fJ>N0_l00004om^KSP03o`000?oh_8Gon;b500Gon;b500?o0000ooRYF_ohZEX00oohZEX00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03;ooooo
0_l0000<oe@cS@03o`000?mXDZGoJ5:U00GoJ5:U00?o0000oiA/X_nDK:804_nDK:83o`0000KoVGV^
00?o0000ojb3Z?n/PjP06On/PjP00ol0003o]hVUokN9Y@0FokN9Y@03o`000?nnSJ?o_XfS01Ko_XfS
00?o0000olNGYOo7UjD03Oo7UjD3o`0000GoahnJ00Co0000olN?V_o7Si[o00005OoIXih01?l0003o
fi^>om^KS_l00009ooRlQ@03o`000?ohZE[on:UJ00;on:UJ00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0booooo`03o`000?l005;o000000[o
E3>=00?o0000ofQBYOmXDZD01omXDZD00ol0003oU6bRoiA/XP0?oiA/XP;o00002OnINJh00ol0003o
[8>Xojb3Z00Iojb3Z003o`000?ngRJGo]hVU01Ko]hVU00?o0000okj=XonnSJ<05_nnSJ<00ol0003o
aiNUolNGY@0@olNGY@?o00000_o7SiX01?l0003oahnJolN?V_l0000FomVSWP?o00002_oh_8D00ol0
003on:UJooRYFP02ooRYFP03o`000?oooooooooo01gooooo00?o0000ooooooooool03oooool001go
oooo00?o0000ooooooooool0<oooool00ol0003o001Bo`000009oe@cS@03o`000?mXDZGoJ5:U00So
J5:U00?o0000oiA/X_nDK:803OnDK:82o`0000_oVGV^00?o0000ojb3Z?n/PjP06On/PjP00ol0003o
]hVUokN9Y@0FokN9Y@03o`000?nnSJ?o_XfS01Ko_XfS00?o0000olNGYOo7UjD04oo7UjD3o`000003
olN?V_l0003ofJ>N01SofJ>N00?o0000ooRlQOoh_8D02Ooh_8D01Ol0003on:UJooRYF_ohZE[o0000
01oooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0<oooool00ol0003o
001Bo`000008oe@cS@03o`000?mXDZGoJ5:U00WoJ5:U00?o0000oiA/X_nDK:802onDK:82o`0000go
VGV^00?o0000ojb3Z?n/PjP06On/PjP00ol0003o]hVUokN9Y@0FokN9Y@03o`000?nnSJ?o_XfS01Ko
_XfS00?o0000olNGYOo7UjD05_o7UjD3o`0001SofJ>N00?o0000ooRlQOoh_8D02_oh_8D01?l0003o
n:UJooRYF_l0000Oooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo03?o
oooo00?o0000o`00D_l000001omD<hd00ol0003oJ5:UofQBY@0;ofQBY@03o`000?nDK:;oU6bR00So
U6bR0_l0000@oiUi[P03o`000?n/PjSo[8>X01So[8>X00?o0000okN9YOngRJD05_ngRJD00ol0003o
_XfSokj=X`0Fokj=X`03o`000?o7UjGoaiNU01KoaiNU0_l000000ooFZJ_o0000o`00000FomVSWP;o
00002ooh_8D01?l0003on:UJooRYF_l0000Oooooo`03o`000?oooooooooo00oooooo000Mooooo`;o
0000=?ooool00ol0003o001Bo`000006oe@cS@03o`000?mXDZGoJ5:U00coJ5:U00?o0000oiA/X_nD
K:801_nDK:82o`0001;oVGV^00?o0000ojb3Z?n/PjP06?n/PjP00ol0003o]hVUokN9Y@0:okN9YA3o
00005OnnSJ<00ol0003oaiNUolNGY@0FolNGY@;o00000ooFZJ/00ol0003ofJ>NomVSWP0BomVSWP04
o`000?obaJ7ol/FQo`0000_on;b500?o0000ooRYF_l000008?ooool00ol0003oooooooooo`0>oooo
o`007Oooool00ol0003oooooooooo`0booooo`;o000000?o001Bo`000?mD<hd01?mD<hd00ol0003o
J5:UofQBY@0=ofQBY@03o`000?nDK:;oU6bR00?oU6bR0ol0000DoiUi[P03o`000?n/PjSo[8>X01Ko
[8>X3ol0000<okN@[P04o`000?nmU:go_IB]okfD[@Ko00003_nnSJ<00ol0003oaiNUolNGY@0GolNG
Y@03o`000?oFZJ_oeZV[00?oeZV[0_l0000BomVSWP05o`000?obaJ7ol/FQoo;5XOl000002ooh_8D2
o`00023ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0<_ooool01?l0
003o001Bo`00D_l00004oe@cS@03o`000?mXDZGoJ5:U00koJ5:U00Co0000oiA/X_nDK:;oU6bR0_l0
000HoiUi[P03o`000?n/PjSo[8>X017o[8>X1?l00002ojf</P03o`000?ngT:ko]i2^01Ko]i2^00?o
0000okfD[OnmU:d01onmU:d6o`0000So_XfS00?o0000olNGYOo7UjD05oo7UjD00ol0003oeZV[omJY
Z`05omJYZ`;o00004?oIXih00ol0003ol/FQoo;5X@02oo;5X@03o`000?oh_8Gon;b500Won;b500?o
0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0c
ooooo`05o`000?l005;o001Bo`00D_l000000_mD<hd00ol0003oJ5:UofQBY@0@ofQBY@?o00006_nI
NJh00ol0003o[8>Xojb3Z00=ojb3Z0Co00001_n]S;800ol0003o]i2^okN@[P0FokN@[P03o`000?nm
U:go_IB]00go_IB]1_l00002okj=X`03o`000?o7UjGoaiNU01OoaiNU00?o0000omJYZooFZJ/01ooF
ZJ/00ol0003ofJ>NomVSWP0<omVSWP03o`000?obaJ7ol/FQ00?ol/FQ00?o0000ooRlQOoh_8D02Ooh
_8D00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooo
oooo03?ooooo00Oo0000o`00D_l005;o001Bo`000?mD<hgo000001;oJ5:U0_l0000LoiUi[P03o`00
0?n/PjSo[8>X00So[8>X1Ol0000:ojf</P03o`000?ngT:ko]i2^01Ko]i2^00?o0000okfD[OnmU:d0
4onmU:d4o`0001OoaiNU0_l0000:omJYZ`;o00003?oIXih00ol0003ol/FQoo;5X@04oo;5X@03o`00
0?oh_8Gon;b500Son;b500?o0000ooooooooool07_ooool00ol0003oooooooooo`0>ooooo`007?oo
ool00ol0003oooooooooo`0cooooo`04o`000?l005;o001Bo`00DP;o00004_mXDZD00ol0003oMfVf
o`00000LoiUi[P03o`000?n/PjSo[8>X00Co[8>X1?l0000?ojf</P03o`000?ngT:ko]i2^01Ko]i2^
00?o0000okfD[OnmU:d05OnmU:d00ol0003oaYj_o`000002o`0001CoaiNU0_l0000<omJYZ`;o0000
2_oIXih00ol0003ol/FQoo;5X@05oo;5X@03o`000?oh_8Gon;b500Oon;b500?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0cooooo`05o`000?l0
05;o001Bo`00D_l000004_mXDZD01Ol0003oMfVfogMY]_mgJKKo000001coVGV^00?o0000ojb3Z?l0
00000ol0000Dojf</P03o`000?ngT:ko]i2^01Go]i2^00?o0000okfD[OnmU:d05OnmU:d00ol0003o
aYj_olJN[`02olJN[`?o00004?o7UjD3o`0000koeZV[00?o0000omVSW_oIXih01ooIXih00ol0003o
l/FQoo;5X@06oo;5X@03o`000?oh_8Gon;b500Gon;b50_l0000Pooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo03?ooooo00Go0000o`00D_l005;o001Bo`00000AofQBY@03
o`000?mgJKKoMfVf00;oMfVf00?o0000oiUi[_nINJh06OnINJh3o`0001So[Hbb00?o0000okN@[_ng
T:h05OngT:h00ol0003o_IB]okfD[@0DokfD[@03o`000?o6WZooaYj_00KoaYj_0ol0000:olNGY@?o
000000?oaiNUo`000?l000003ooFZJ/2o`0000KofJ>N00?o0000oo;5XOobaJ401oobaJ400ol0003o
n;b5ooRlQ@05ooRlQ@;o00008Oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0003Cooooo
00Ko0000o`00D_l005;o001Bo`0;U?l0000?ofQBY@03o`000?mgJKKoMfVf00CoMfVf00?o0000oiUi
[_nINJh05_nINJh2o`000003oif5^Ol0003o[Hbb01So[Hbb00?o0000okN@[_ngT:h05?ngT:h00ol0
003o_IB]okfD[@0EokfD[@03o`000?o6WZooaYj_00WoaYj_0ol00004olNGY@?o00000oo7UjD01?l0
003oeZV[omJYZol0000@omJYZ`;o00001?oIXih00ol0003ol/FQoo;5X@08oo;5X@03o`000?oh_8Go
n;b500Con;b50_l0000Qooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
03?ooooo00?o0000o`00D_l005800_l005800ol02iCo0000ofQBY@0=ofQBY@03o`000?mgJKKoMfVf
00GoMfVf00?o0000oiUi[_nINJh05?nINJh2o`0000CoWHFi00?o0000ojf</_n]S;805_n]S;800ol0
003o]i2^okN@[P0DokN@[P03o`000?nmU:go_IB]01Go_IB]00?o0000olJN[oo6WZl03?o6WZl4o`00
00KoaiNU00Go0000omJYZooFZJ_oeZV[o`00000AomJYZ`05o`000?oIXikofJ>NomVSW_l000002oob
aJ400ol0003on;b5ooRlQ@03ooRlQ@;o00008Oooool00ol0003oooooooooo`0=ooooo`006oooool0
0ol0003oooooooooo`0cooooo`07o`000?l005;o001Bo`00D_l0003o00^Do`00000=ofQBY@03o`00
0?mgJKKoMfVf00OoMfVf00?o0000oiUi[_nINJh04OnINJh2o`0000KoWHFi00?o0000ojf</_n]S;80
5_n]S;800ol0003o]i2^okN@[P0DokN@[P03o`000?nmU:go_IB]01Go_IB]00?o0000olJN[oo6WZl0
2Oo6WZl4o`0000;oaYj_0ol00004olNGY@03o`000?oFZJ_oeZV[00;oeZV[00?o0000omJYZooFZJ/0
3ooFZJ/3o`0000gol/FQ00?o0000ooRlQOoh_8D00_oh_8D2o`00027ooooo00?o0000ooooooooool0
3Oooool001_ooooo00?o0000ooooooooool0<oooool01Ol0003o001Bo`00D_l005;o000000;o00^D
00?o0000ofQBYOmXDZD02OmXDZD00ol0003oMfVfogMY]P08ogMY]P03o`000?nINJkoVGV^00ooVGV^
0_l00008oif5^@03o`000?n]S;;o[Hbb01Ko[Hbb00?o0000okN@[_ngT:h05?ngT:h00ol0003o_IB]
okfD[@0EokfD[@03o`000?o6WZooaYj_00KoaYj_0ol00009olJN[`Co00001_oFZJ/00ol0003oeZV[
omJYZ`0@omJYZ`03o`000?obaJ7ol/FQ00col/FQ00Co0000ooRlQOoh_8Gon;b50_l0000Qooooo`03
o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo03?ooooo00Go0000o`00D_l005;o
001Bo`000002o`0;U003o`000?mXDZGoJ5:U00SoJ5:U00?o0000ogMY]_mgJKH02_mgJKH00ol0003o
VGV^oiUi[P0<oiUi[P;o00002onMQKT00ol0003o[Hbbojf</P0Eojf</P03o`000?ngT:ko]i2^01Co
]i2^00?o0000okfD[OnmU:d05?nmU:d00ol0003oaYj_olJN[`04olJN[`?o00003oo6WZl2o`0000Go
eZV[00?o0000omJYZooFZJ/04?oFZJ/00ol0003ol/FQoo;5X@0<oo;5X@05o`000?oh_8Gon;b5ooRl
QOl000008_ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0cooooo`05
o`000?l005;o001Bo`00D_l000000_l02i@00ol0003oJ5:UofQBY@07ofQBY@03o`000?mgJKKoMfVf
00_oMfVf00?o0000oiUi[_nINJh02onINJh00ol0003oWHFioif5^@0;oif5^@03o`000?n]S;;o[Hbb
01Ko[Hbb00?o0000okN@[_ngT:h04ongT:h00ol0003o_IB]okfD[@0DokfD[@04o`000?o6WZooaYj_
olJN[`?o00004_o6WZl00ol0003odZnfo`000005omJYZ`03o`000?oFZJ_oeZV[00koeZV[00?o0000
on[9]?l000003_obaJ401?l0003on;b5o`000?l0000Rooooo`03o`000?oooooooooo00gooooo000K
ooooo`03o`000?oooooooooo03?ooooo00Go0000o`00D_l005;o001Bo`000003o`0;U003o`000?mX
DZGoJ5:U00GoJ5:U00?o0000ogMY]_mgJKH03?mgJKH00ol0003oVGV^oiUi[P09oiUi[P;o00003_nM
QKT00ol0003o[Hbbojf</P0Fojf</P03o`000?ngT:ko]i2^01?o]i2^00?o0000okfD[OnmU:d05?nm
U:d4o`0001CoaYj_00Co0000om:_]_oB[kKodZnf0_l00004omJYZ`03o`000?oFZJ_oeZV[00goeZV[
00Co0000on[9]?oZbKCo00003_obaJ43o`0002;ooooo00?o0000ooooooooool03Oooool001_ooooo
0_l0000eooooo`04o`000?l005;o001Bo`0000?o00^D00?o0000ofQBYOmXDZD01?mXDZD00ol0003o
MfVfogMY]P0>ogMY]P03o`000?nINJkoVGV^00KoVGV^0_l0000Aoif5^@03o`000?n]S;;o[Hbb01Go
[Hbb00?o0000okN@[_ngT:h02?ngT:h@o`0000oo_IB]1?l0000GolJN[`03o`000?oB[kKodZnf00?o
dZnf00?o0000omJYZooFZJ/00_oFZJ/00ol0003oeZV[omJYZ`0;omJYZ`03o`000?oZbKCoj/Vd00;o
j/Vd00?o0000oo;5XOobaJ403?obaJ42o`0002?ooooo00?o0000ooooooooool03?ooool001[ooooo
00?o0000ooooooooool0=Oooool00ol0003o001Bo`000004o`0;U003o`000?mXDZGoJ5:U00?oJ5:U
00?o0000ogMY]_mgJKH03omgJKH00ol0003oVGV^oiUi[P04oiUi[P;o00004onMQKT00ol0003o[Hbb
ojf</P0Cojf</Pgo00002ongV;P00ol0003o_IbgokfL]`02okfL]`Oo00001OnmU:d3o`0000?o_IB]
00?o0000olJN[oo6WZl05?o6WZl00ol0003odZnfom:_]P05om:_]P;o00000ooFZJ/00ol0003oeZV[
omJYZ`0:omJYZ`03o`000?oZbKCoj/Vd00;oj/Vd00?o0000oo;5XOobaJ403?obaJ42o`0002?ooooo
00?o0000ooooooooool03?ooool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0eooooo`03o`000?l005;o000000Go
00^D00Go0000ofQBYOmXDZGoJ5:Uo`00000CogMY]P04o`000?nINJkoVGV^oiUi[P;o00005OnMQKT0
0ol0003o[Hbbojf</P0?ojf</PCo00000_n^U;`00ol0003o]iRhokNH^00CokNH^003o`000?nmW;Oo
_Ibg00Wo_Ibg1ol00003okfD[@03o`000?o6WZooaYj_01GoaYj_00?o0000om:_]_oB[kH01ooB[kH0
1Ol0003oeZV[omJYZooFZJ_o000000[oeZV[00?o0000on[9]?oZbK@01?oZbK@00ol0003ol/FQoo;5
X@0:oo;5X@?o00008oooool00ol0003oooooooooo`0<ooooo`0000CoV9RHoooooonHV9SoMgMg1Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0eooooo`03o`000?l0
05;o000000Go00^D00Co0000ofQBYOmXDZGo00005?mgJKH01?l0003oVGV^o`000?l0000Hoif5^@03
o`000?n]S;;o[Hbb00_o[Hbb0ol00006ojjD_003o`000?ngV;So]iRh01?o]iRh00?o0000okfL]onm
W;L01onmW;L4o`0000Go_Ibg1Ol0000FolJN[`03o`000?oB[kKodZnf00SodZnf0_l000000ooFZJ_o
0000omJYZ`09omJYZ`03o`000?oZbKCoj/Vd00Goj/Vd00?o0000oo;5XOobaJ402OobaJ43o`0002?o
oooo00?o0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo03Gooooo00?o0000o`00D_l000001Ol02i@00ol0003oJ5:U
o`00000FogMY]P03o`000?nMQKWoWHFi01SoWHFi00?o0000ojf</_n]S;801on]S;84o`0000Wo[YBl
00?o0000okNH^?ngV;P04ongV;P00ol0003o_IbgokfL]`04okfL]`?o00003?nmW;L00ol0003oa:Fi
o`000002o`0001;oaYj_00?o0000om:_]_oB[kH02ooB[kH00ol0003oeZV[o`000008omJYZ`03o`00
0?oZbKCoj/Vd00Koj/Vd00?o0000oo;5XOobaJ402OobaJ43o`0002?ooooo00?o0000ooooooooool0
3?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo03Gooooo00?o0000o`00D_l000001_l02i@00ol0003oMfVfogMY]P0DogMY]P;o00006_nM
QKT00ol0003o[Hbbojf</P03ojf</PCo00003_n^U;`00ol0003o]iRhokNH^00BokNH^004o`000?nm
W;Oo_IbgokfL]`?o00003onmW;L00ol0003oa:FiolBU^@02olBU^@;o00004?o6WZl00ol0003odZnf
om:_]P0<om:_]P03o`000?oFZJ_o000000OoeZV[00?o0000on[9]?oZbK@01ooZbK@00ol0003ol/FQ
oo;5X@07oo;5X@04o`000?o]iX3o0000o`0002?ooooo00?o0000ooooooooool03?ooool000?ooooo
00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool0=Oooool00ol0003o001Bo`000006o`0;U003o`000?mgJKKoMfVf01?oMfVf00Co0000oh9k`on2
Nl?o00006_nMQKT00ol0003o[Hbbo`000002o`0001;o[YBl00?o0000okNH^?ngV;P04_ngV;P4o`00
017o_Ibg00?o0000olBU^Oo4YKT01Oo4YKT3o`0000coaYj_00?o0000om:_]_oB[kH03_oB[kH3o`00
00GoeZV[00?o0000on[9]?oZbK@02OoZbK@00ol0003ol/FQoo;5X@06oo;5X@04o`000?o]iX3o0000
o`0002?ooooo00?o0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool02_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Oooooo00?o001Bo`000?l02i@01Ol02i@00olR
@[[o0000ogMY]P0BogMY]P05o`000?n2Nl?oPW_3oh9k`ol000006OnMQKT3o`0001Go[YBl00?o0000
okNH^?ngV;P03ongV;P4o`0001Co_Ibg00?o0000olBU^Oo4YKT02?o4YKT2o`0000[oaYj_00?o0000
om:_]_oB[kH04?oB[kH2o`0000CoeZV[00?o0000on[9]?oZbK@02_oZbK@00ol0003ol/FQoo;5X@05
oo;5X@04o`000?o]iX3o0000o`0002Cooooo00?o0000ooooooooool02oooool00004oiRHV?oooooo
V9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o0000o`0;U?l02i@01Ol0
2i@00ol0003o8T:jo`00000AogMY]P03o`000?n2Nl?oPW_300?oPW_300?o0000oif5^OnMQKT05?nM
QKT2o`000003oj6@`ol0003o[YBl01Go[YBl00?o0000okNH^?ngV;P03?ngV;P3o`0000?o]iRh00?o
0000okfL]onmW;L04_nmW;L00ol0003oa:FiolBU^@0:olBU^@?o00001_o6WZl00ol0003odZnfom:_
]P0Bom:_]P;o00000_oFZJ/00ol0003oj/Vdon[9]00;on[9]003o`000?obaJ7ol/FQ00Col/FQ00?o
0000ongVP?o]iX000_l0000Tooooo`03o`000?oooooooooo00_ooooo00001?lb<S;o0000oc8b<_o^
k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0gooooo`03o`000?l02iCo00^D00Go00^D00?o
0000ob92^_l000004?mgJKH00ol0003oPW_3oh9k``05oh9k``03o`000?nMQKWoWHFi017oWHFi0_l0
0004oj6@``03o`000?n^U;co[YBl01?o[YBl00?o0000okNH^?ngV;P02OngV;P3o`0000Ko]iRh00?o
0000okfL]onmW;L04_nmW;L00ol0003oa:FiolBU^@0=olBU^@;o00001?o6WZl00ol0003odZnfom:_
]P0Com:_]P;o000000?oeZV[o`000?oZbK@03OoZbK@00ol0003ol/FQoo;5X@03oo;5X@03o`000?o]
iX3okNJ000;o00009?ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0g
ooooo`03o`000?l02iCo00^D00Co00^D00Go0000ob92^_lR@[[o8T:jo`00000>ogMY]P03o`000?n2
Nl?oPW_300KoPW_300?o0000oif5^OnMQKT04?nMQKT00ol0003oXI33oj6@``04oj6@``03o`000?n^
U;co[YBl01Co[YBl00?o0000okNH^?ngV;P01OngV;P3o`0000Wo]iRh00?o0000okfL]onmW;L04Onm
W;L00ol0003oa:FiolBU^@0@olBU^@?o000000?oaYj_o`000?oB[kH05OoB[kH2o`00013oj/Vd00?o
0000oo;5XOobaJ400_obaJ401?l0003okNJ0o`000?l0000Uooooo`03o`000?oooooooooo00_ooooo
000Iooooo`03o`000?oooooooooo03Oooooo00?o0000o`0;U?l02i@01?l02i@00ol0003o8T:job92
^P02ob92^P03o`000?mgJKKoMfVf00[oMfVf00?o0000oh9k`on2Nl<02?n2Nl<00ol0003oWHFioif5
^@0=oif5^@;o00001onQT<<00ol0003o[YBlojjD_00DojjD_004o`000?ngV;So]iRhokNH^0Co0000
3?ngV;P00ol0003o_IbgokfL]`0AokfL]`03o`000?o4YKWoa:Fi01?oa:Fi0_l0000Gom:_]P03o`00
0?oZbKCoj/Vd00koj/Vd00Go0000oo;5XOobaJ7ol/FQo`000002ongVP0;o00009Oooool00ol0003o
ooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`0hooooo`03o`000?l02iCo00^D00?o00^D
00?o0000ob92^_lR@[X00_lR@[X00ol0003oMfVfogMY]P09ogMY]P03o`000?n2Nl?oPW_300WoPW_3
00?o0000oif5^OnMQKT02onMQKT2o`0000[oXI3300?o0000ojjD_?n^U;`04on^U;`4o`00013o]iRh
00?o0000okfL]onmW;L04OnmW;L00ol0003oa:FiolBU^@0ColBU^@03o`000?o>]<7o000001GodZnf
00?o0000on7<`_l000004?oZbK@01?l0003ol/FQoo;5XOl00002ongVP0;o00009Oooool00ol0003o
ooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`0iooooo`03o`000?l02iCo00^D00?o00^D
00?o0000ob92^_lR@[X00olR@[X00ol0003oMfVfogMY]P07ogMY]P03o`000?n2Nl?oPW_300_oPW_3
00?o0000oif5^OnMQKT02?nMQKT2o`0000coXI3300?o0000ojjD_?n^U;`04On^U;`3o`0001?o]iRh
00?o0000okfL]onmW;L04?nmW;L00ol0003oa:FiolBU^@0ColBU^@05o`000?o>]<7oc[C1oljd`Ol0
00004ooB[kH01Ol0003ohLc2on7<`_oQc<;o0000013oj/Vd00?o0000oo;5XOl000000_o]iX02o`00
02Gooooo00?o0000ooooooooool02oooool001Sooooo00?o0000ooooooooool0>_ooool00ol0003o
00^Do`0;U002o`0;U003o`000?lR@[[o8T:j00?o8T:j00?o0000ogMY]_mgJKH01_mgJKH00ol0003o
PW_3oh9k``0<oh9k``03o`000?nMQKWoWHFi00KoWHFi0_l0000?oj6@``03o`000?n^U;co[YBl00go
[YBl0ol00002ojjD_003o`000?ngV;So]iRh017o]iRh00?o0000okfL]onmW;L04?nmW;L00ol0003o
a:FiolBU^@0ColBU^@03o`000?o>]<7oc[C100;oc[C10_l0000Aom:_]P05o`000?oQc<;ohLc2on7<
`_l000004OoZbK@01?l0003okNJ0ongVP?o]iX02o`0002Kooooo00?o0000ooooooooool02_ooool0
01Sooooo00?o0000ooooooooool0>_ooool00ol0003o00^Do`0;U002o`0;U003o`000?lR@[[o8T:j
00Co8T:j00?o0000ogMY]_mgJKH01?mgJKH00ol0003oPW_3oh9k``0>oh9k``03o`000?nMQKWoWHFi
00CoWHFi00?o0000oj6@`onQT<<03onQT<<00ol0003o[YBlojjD_009ojjD_0Co00001_n^U;`00ol0
003o]iRhokNH^00;okNH^0Wo00003onmW;L00ol0003oa:FiolBU^@0BolBU^@03o`000?o>]<7oc[C1
00Goc[C100?o0000om:_]_oB[kH03OoB[kH00ol0003ohLc2on7<`P03on7<`P03o`000?oZbKCoj/Vd
00koj/Vd00Co0000ongVP?o]iX3okNJ00_l0000Vooooo`03o`000?oooooooooo00[ooooo000Hoooo
o`;o0000??ooool01Ol0003o00^Do`0;U?l02iCo000000Oo8T:j00?o0000ogMY]_mgJKH00_mgJKH0
0ol0003oPW_3oh9k``0@oh9k``04o`000?nMQKWoWHFioif5^@;o00004_nQT<<00ol0003o[YBlojjD
_006ojjD_0?o00002_n^U;`00ol0003o]iRhokNH^002okNH^0Wo00001OnfX<<01?l0003o^jC2ok^T
`_nkY<86o`0000Wo_Ibg00?o0000olBU^Oo4YKT04_o4YKT00ol0003oc[C1oljd`@06oljd`@03o`00
0?oB[kKodZnf00_odZnf00?o0000on7<`_oQc<801OoQc<800ol0003oj/Vdon[9]00<on[9]0;o0000
0oo]iX02o`0002Kooooo00?o0000ooooooooool02_ooool001Sooooo00?o0000ooooooooool0>ooo
ool01Ol0003o00^Do`0;U?l02iCo000000Oo8T:j00Go0000ogMY]_mgJKKoMfVfo`00000Coh9k``04
o`000?nMQKWo0000o`0001GoXI3300?o0000ojjD_?n^U;`00_n^U;`3o`0000_o[YBl1ol0000>okJP
``03o`000?nkY<;o^jC200Oo^jC21_l00002okfL]`03o`000?o4YKWoa:Fi01;oa:Fi00?o0000oljd
`Oo>]<402?o>]<42o`0000[odZnf00?o0000on7<`_oQc<801_oQc<82o`0000coj/Vd00?o0000oo7f
]?l000000oo]iX000ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo000Hooooo`03
o`000?oooooooooo03_ooooo00Go0000o`0;U?l02iCo00^Do`000008ob92^P03o`000?mgJKKo0000
01GoPW_300?o0000oj6@`onQT<<05OnQT<<00ol0003o[YBlo`000002o`0000[o[YBl1?l00002ojjM
aP03o`000?nfX<?o]Z33013o]Z3300?o0000ok^T`_nkY<803OnkY<84o`0001?oa:Fi00?o0000oljd
`Oo>]<402_o>]<400ol0003odZnfom:_]P07om:_]P03o`000?oQc<;ohLc200OohLc20_l0000:on[9
]004o`000?oam[ColOJdo`0000?okNJ000?o0000ooooooooool09Oooool00ol0003oooooooooo`0:
ooooo`005oooool00ol0003oooooooooo`0mooooo`03o`000?l02iCo000000[o8T:j00?o0000oh9k
`on2Nl<05?n2Nl<00ol0003oXI33oj6@``0Coj6@``Co00002On^U;`4o`0000Ko[Yg600?o0000okJP
`onfX<<04?nfX<<00ol0003o^jC2ok^T`P0?ok^T`P03o`000?o2[<Co000000;o00003oo4YKT00ol0
003oc[C1oljd`@0<oljd`@03o`000?oB[kKodZnf00GodZnf00?o0000on7<`_oQc<802OoQc<800ol0
003oj/Vdon[9]008on[9]003o`000?oam[Co000000CokNJ000?o0000ooooooooool09Oooool00ol0
003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`0mooooo`03o`000?l02iCo000000[o
8T:j00?o0000oh9k`on2Nl<04on2Nl<00ol0003oRh_>o`00000Aoj6@``?o00000onQT<<00ol0003o
[YBlojjD_004ojjD_0?o00002on^WLH00ol0003o]Z33okJP``0?okJP``03o`000?nkY<;o^jC200ko
^jC200?o0000ol:/a?o2[<@00oo2[<@2o`0000goa:Fi00?o0000oljd`Oo>]<403Oo>]<42o`0000Co
dZnf00?o0000on7<`_oQc<802ooQc<800ol0003oj/Vdon[9]006on[9]004o`000?oam[ColOJdo`00
00CokNJ000?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003o
ooooooooo`0nooooo`;o00002_lR@[X2o`0001?oPW_300Go0000oh^;c_n;RlkoRh_>o`00000=oj6@
``?o00001_nQT<<00ol0003o[YBlojjD_004o`0000ko[Yg600?o0000okJP`onfX<<03onfX<<00ol0
003o^jC2ok^T`P0>ok^T`P03o`000?o2[<Co`Zc400Go`Zc40ol00009olBU^@03o`000?o>]<7oc[C1
013oc[C100Go0000om:_]_oB[kKodZnfo`00000=on7<`P;o00001_oZbK@01Ol0003olOJdoo7f]?oa
m[Co000000?okNJ000?o0000ooooooooool09oooool00ol0003oooooooooo`09ooooo`005oooool0
0ol0003oooooooooo`0nooooo`;o00002OlR@[X01?l0003oAfS@odMXd?l0000Aoh9k``03o`000?n;
RlkoRh_>00?oRh_>00?o0000oj6@`onQT<<01onQT<<3o`0000WoXI330ol0000BojjMaP03o`000?nf
X<?o]Z3300oo]Z3300?o0000ok^T`_nkY<803_nkY<800ol0003o`Zc4ol:/a008ol:/a0;o00001oo4
YKT00ol0003oc[C1oljd`@0Aoljd`@03o`000?oB[kKo000000oohLc20_l00004on[9]003o`000?oa
m[ColOJd00;olOJd00Go0000ongVP?o]iX3okNJ0o`00000Yooooo`03o`000?oooooooooo00Wooooo
000Gooooo`03o`000?oooooooooo03oooooo00?o0000ob92^_lR@[X01olR@[X01Ol0003oAfS@odMX
d?m7J=3o000000ooPW_300?o0000oh^;c_n;Rlh01On;Rlh00ol0003oXI33oj6@``02oj6@``Co0000
2_nQT<<2o`000003oj>KcOl0003o[Yg601;o[Yg600?o0000okJP`onfX<<03_nfX<<00ol0003o^jC2
ok^T`P0>ok^T`P03o`000?o2[<Co`Zc400_o`Zc40_l00004olBU^@03o`000?o>]<7oc[C101?oc[C1
00?o0000on7<`_oQc<803ooQc<82o`0000?oj/Vd00?o0000oo7f]?oam[@00_oam[@01?l0003okNJ0
ongVP?l0000Zooooo`03o`000?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo03oooooo
00?o0000ob92^_lR@[X01olR@[X00ol0003oAfS@odMXd002odMXd003o`000?n2Nl?oPW_300_oPW_3
00?o0000oh^;c_n;Rlh01on;Rlh4o`0000goXI3300?o0000oj>KcOnSVld00_nSVld00ol0003o[Yg6
ojjMaP0@ojjMaP03o`000?nfX<?o]Z3300ko]Z3300?o0000ok^T`_nkY<803_nkY<800ol0003o`Zc4
ol:/a00=ol:/a0?o000000?oa:Fio`000?o>]<405?o>]<400ol0003ohLc2on7<`P0?on7<`P;o0000
0_oZbK@00ol0003olOJdoo7f]003oo7f]004o`000?o]iX3okNJ0o`0002[ooooo00?o0000oooooooo
ool02Oooool001Oooooo0_l00011ooooo`03o`000?lR@[[o8T:j00Ko8T:j00?o0000odMXd?m7J=00
0om7J=000ol0003oPW_3oh9k``09oh9k``03o`000?n;RlkoRh_>00KoRh_>1?l0000=oj6@``;o0000
1OnSVld00ol0003o[Yg6ojjMaP0AojjMaP03o`000?nfX<?o]Z3300go]Z3300?o0000ok^T`_nkY<80
3_nkY<800ol0003o`Zc4ol:/a00@ol:/a0;o00005?o>]<400ol0003of<c=o`00000Aon7<`P?o0000
1_oam[@00ol0003okNJ0o`00000[ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oo
oooooooo04;ooooo00?o0000ob92^_lR@[X01OlR@[X00ol0003oAfS@odMXd004odMXd003o`000?n2
Nl?oPW_300OoPW_300?o0000oh^;c_n;Rlh01?n;Rlh3o`0000?oRh_>00?o0000oj6@`onQT<<02OnQ
T<<2o`0000SoXi_=00?o0000ojjMa_n^WLH04?n^WLH00ol0003o]Z33okJP``0=okJP``03o`000?nk
Y<;o^jC200go^jC200?o0000ol:/a?o2[<@04Oo2[<@00ol0003obKW;o`00000Boljd`@05o`000?oH
c<gof<c=omS<cOl000004OoQc<82o`0000KolOJd00?o0000ongVP?l00000:oooool00ol0003ooooo
ooooo`09ooooo`005_ooool00ol0003oooooooooo`13ooooo`03o`000?lR@[[o8T:j00?o8T:j00?o
0000odMXd?m7J=001_m7J=000ol0003oPW_3oh9k``05oh9k``04o`000?n;RlkoRh_>oh^;cPCo0000
1on;Rlh00ol0003oXI33oj6@``07oj6@``03o`000?nSVlgoXi_=00WoXi_=00?o0000ojjMa_n^WLH0
3on^WLH00ol0003o]Z33okJP``0=okJP``03o`000?nkY<;o^jC200go^jC200?o0000ol:/a?o2[<@0
4?o2[<@01Ol0003obKW;olViboo9^L_o0000013oc[C100?o0000omS<cOoHc<d00_oHc<d00ol0003o
hLc2on7<`P0>on7<`P;o000000?olOJdo`000?oam[@01?oam[@2o`0002cooooo00?o0000oooooooo
ool02Oooool001Kooooo00?o0000ooooooooool0@oooool00ol0003o8T:job92^P03ob92^P03o`00
0?m7J=3oAfS@00OoAfS@00?o0000oh9k`on2Nl<00on2Nl<00ol0003oRh_>o`000002o`0000coRh_>
00?o0000oj6@`onQT<<01?nQT<<2o`0000coXi_=00?o0000ojjMa_n^WLH03on^WLH00ol0003o]Z33
okJP``0=okJP``03o`000?nkY<;o^jC200go^jC200?o0000ol:/a?o2[<@03oo2[<@00ol0003obKW;
olVib`03olVib`;o00003Oo>]<400ol0003of<c=omS<c@04omS<c@03o`000?oQc<;ohLc200cohLc2
00?o0000onSdd?l000000_oam[@01ol0003olOJdoo7f]?oam[Co0000ongVP?l00000;?ooool00ol0
003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`14ooooo`03o`000?lR@[[o8T:j00;o
8T:j00?o0000odMXd?m7J=002?m7J=001?l0003oPW_3oh9k`on2Nl<3o`00013oRh_>00Co0000oj6@
`onQT<?oXI330_l0000?oj>Kc@03o`000?n^WLKo[Yg600ko[Yg600?o0000okJP`onfX<<03OnfX<<0
0ol0003o^jC2ok^T`P0<ok^T`P03o`000?o2[<Co`Zc4013o`Zc400?o0000olViboo9^L/01Oo9^L/0
0ol0003oc[C1oljd`@09oljd`@03o`000?oHc<gof<c=00Kof<c=00?o0000on7<`_oQc<802_oQc<80
1?l0003oj?C@onSdd?l00003oo7f]003o`000?oam[ColOJd00;o0000;_ooool00ol0003ooooooooo
o`08ooooo`005_ooool00ol0003oooooooooo`15ooooo`05o`000?lR@[[o8T:job92^_l000002om7
J=03o`0001CoRh_>00?o0000oj6@`ol000004OnSVld00ol0003o[Yg6ojjMaP0?ojjMaP03o`000?nf
X<?o]Z3300So]Z331ol0000<ok^T`P03o`000?o2[<Co`Zc400oo`Zc400?o0000olViboo9^L/01oo9
^L/00ol0003oc[C1oljd`@08oljd`@03o`000?oHc<gof<c=00Kof<c=00?o0000on7<`_oQc<802OoQ
c<801Ol0003oj?C@onSdd?oXm=3o000000?olOJd00?o0000oo7f]?oam[@00_l0000^ooooo`03o`00
0?oooooooooo00Sooooo000Fooooo`03o`000?oooooooooo04Gooooo00Go0000ob92^_lR@[[o8T:j
o`000007odMXd0Co000000?oAfS@o`000?l000005On;Rlh00ol0003oXi_=oj>Kc@0Aoj>Kc@03o`00
0?n^WLKo[Yg600ko[Yg600Co0000okJP`onfX<?o]Z331ol00004okBYcP03o`000?nh[Lgo^:g=00Go
00001onkY<800ol0003o`Zc4ol:/a00>ol:/a003o`000?o9^L_obKW;00WobKW;00?o0000oljd`Oo>
]<401_o>]<400ol0003of<c=omS<c@08omS<c@03o`000?oQc<;ohLc200OohLc200?o0000onSdd?oX
m=000_oXm=000ol0003olOJdoo7f]002oo7f]003o`000?oam[Co000002oooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool0Aoooool00ol0003o8T:jo`000005odMXd0?o0000
1Om7J=02of63g@03o`000?n;RlkoRh_>01;oRh_>00?o0000oj>KcOnSVld04OnSVld00ol0003o[Yg6
ojjMaP0<ojjMaPKo00002ondZLh00ol0003o^:g=okR]c@05okR]c@Go000000?o^jC2o`000?o2[<@0
3oo2[<@00ol0003obKW;olVib`0;olVib`;o00001Oo>]<400ol0003of<c=omS<c@09omS<c@03o`00
0?oQc<;ohLc200KohLc200?o0000onSdd?oXm=000ooXm=000ol0003olOJdoo7f]003oo7f]0;o0000
;oooool00ol0003oooooooooo`08ooooo`005Oooool3o`0004Sooooo0_l00002odMXd0?o00002?m7
J=001?l0003oHH?Mof63gOl0000Boh^;cP03o`000?nBVMOo000001?oXi_=00?o0000ojjMa_n^WLH0
2?n^WLH3o`0000;o[ZOA00?o0000okBYc_ndZLh03?ndZLh00ol0003o^:g=okR]c@0:okR]c@?o0000
3oo2[<@00ol0003obKW;olVib`0=olVib`05o`000?o>]<7oc[C1oljd`Ol000003OoHc<d00ol0003o
hLc2on7<`P04on7<`P03o`000?oXm=3oj?C@00Coj?C@00?o0000oo7f]?oam[@00ooam[@2o`0002oo
oooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000_oAfS@
00Go0000of63gOmQPmgoHH?Mo`00000@oh^;cP05o`000?nBVMOoTYWGoi:Ieol000004onSVld00ol0
003o[Yg6ojjMaP03ojjMaPCo00001On^Ym400ol0003o]:W>okBYcP0;okBYcP03o`000?nh[Lgo^:g=
00co^:g=00?o0000okfcd?l000000_l0000;ol:/a003o`000?o9^L_obKW;00oobKW;00?o0000oljd
`Ol000003ooHc<d00ol0003ohLc2on7<`P02on7<`P03o`000?oXm=3oj?C@00Goj?C@00?o0000oo7f
]?oam[@00_oam[@01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo00Sooooo000Eoooo
o`03o`000?oooooooooo04Gooooo1?l00002o`0TZ003o`000?m7J=3oAfS@00SoAfS@00?o0000of63
gOmQPmd00omQPmd00ol0003oRh_>oh^;cP0<oh^;cP03o`000?nBVMOoTYWG00?oTYWG00?o0000oj>K
cOnSVld04?nSVld00ol0003o[Yg6ojjMaP03o`0000[o[ZOA00?o0000okBYc_ndZLh02_ndZLh00ol0
003o^:g=okR]c@0;okR]c@03o`000?nm/m3o_K?@00?o_K?@0ol00007ol:/a003o`000?o9^L_obKW;
017obKW;00?o0000omS<cOoHc<d03_oHc<d01Ol0003ohLc2on7<`_oQc<;o000000Ooj?C@00?o0000
oo7f]?oam[@00_oam[@01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool02?oo
ool001Gooooo00?o0000ooooooooool0@_ooool3o`0000Gooooo0_l09:P00ol0003oAfS@odMXd007
odMXd003o`000?mQPmgoHH?M00CoHH?M0_l0000;oh^;cP03o`000?nBVMOoTYWG00GoTYWG00?o0000
oj>KcOnSVld03onSVld3o`0000go[ZOA00?o0000okBYc_ndZLh02_ndZLh00ol0003o^:g=okR]c@0;
okR]c@03o`000?nm/m3o_K?@00Ko_K?@0_l00005ol:/a003o`000?o9^L_obKW;00oobKW;00?o0000
olo<eol000004OoHc<d00ol0003ohLc2o`000008onSdd003o`000?oam[ColOJd00;olOJd00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo000Eoooo
o`03o`000?oooooooooo03oooooo0ol00009ooooo`;o02BX00?o0000odMXd?m7J=001_m7J=000ol0
003oHH?Mof63g@06of63g@03o`000?n;RlkoRh_>00OoRh_>00?o0000oi:IeonBVML01onBVML00ol0
003oXi_=oj>Kc@0<oj>Kc@;o000000?oYJKFo`000?n^Ym403On^Ym400ol0003o]:W>okBYcP0:okBY
cP03o`000?nh[Lgo^:g=00[o^:g=00?o0000okfcd?nm/m002Onm/m03o`000003ol:/a?l0003obKW;
013obKW;00Go0000olo<eoo?c=OoclcGo`00000AomS<c@03o`000?oXm=3oj?C@00Ooj?C@00Go0000
oo7f]?oam[ColOJdo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01ooo
ool001Cooooo00?o0000ooooooooool0?Oooool3o`0000gooooo0_l09:P00ol0003oAfS@odMXd005
odMXd003o`000?mQPmgoHH?M00OoHH?M00?o0000oh^;c_n;Rlh01On;Rlh00ol0003oTYWGoi:Ie`09
oi:Ie`03o`000?nSVlgoXi_=00[oXi_=00?o0000ojFVe_nUY]H00_nUY]H00ol0003o[ZOAojjWd@0;
ojjWd@03o`000?ndZLko]:W>00[o]:W>00?o0000okR]cOnh[Ld02_nh[Ld00ol0003o_K?@okfcd00<
okfcd003o`000?o9^L_obKW;00oobKW;00?o0000olo<eoo?c=L00_o?c=L00ol0003of<c=omS<c@0=
omS<c@03o`000?oKkMoo000000Woj?C@00Co0000oo7f]?oam[Co00002?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Wooooo1?l0000@
ooooo`03o`000?l09:So02BX00;o00001Om7J=000ol0003oHH?Mof63g@08of63g@03o`000?n;Rlko
Rh_>00?oRh_>00?o0000oi:IeonBVML02onBVML00ol0003oXi_=oj>Kc@07oj>Kc@;o00001_nUY]H0
0ol0003o[ZOAojjWd@0;ojjWd@03o`000?ndZLko]:W>00Wo]:W>00?o0000okR]cOnh[Ld02Onh[Ld0
0ol0003o_K?@okfcd00=okfcd003o`000?o2_MGo000000kobKW;00?o0000olo<eoo?c=L01?o?c=L0
0ol0003of<c=omS<c@0;omS<c@04o`000?oKkMoofngOo`0000Woj?C@00Co0000oo7f]?oam[Co0000
2Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oo
oooooooo03Kooooo0ol0000Eooooo`05o`000?l09:So02BXo`0TZ?l000001?m7J=000ol0003oHH?M
of63g@09of63g@05o`000?n;RlkoRh_>oh^;c_l000003onBVML00ol0003oXi_=oj>Kc@04oj>Kc@;o
00002?nUY]H00ol0003o[ZOAojjWd@0;ojjWd@03o`000?ndZLko]:W>00Wo]:W>00?o0000okR]cOnh
[Ld02Onh[Ld00ol0003o_K?@okfcd00<okfcd005o`000?o2_MGo`[gEol:meOl000002oo9^L/2o`00
00SoclcG00?o0000omS<cOoHc<d02OoHc<d01Ol0003ofngOom_]gooKkMoo000000Woj?C@00?o0000
oo7f]?l000002_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Doooo
o`?o0000<oooool3o`0001Wooooo00Go0000o`0TZ?l09:So02BXo`000003odMXd003o`000?mQPmgo
HH?M00[oHH?M00?o0000oh^;c_l000004OnBVML00ol0003oXi_=oj>Kc@02oj>Kc@03o`000?nUY]Ko
YJKF00WoYJKF00?o0000ojjWdOn^Ym402_n^Ym400ol0003o]:W>okBYcP08okBYcP03o`000?nh[Lgo
^:g=00[o^:g=00?o0000okfcd?nm/m002onm/m000ol0003o`[gEol:me@03ol:me@03o`000?o9^L_o
bKW;00OobKW;00?o0000olo<eoo?c=L02?o?c=L00ol0003of<c=omS<c@08omS<c@03o`000?oKkMoo
fngO00;ofngO00?o0000onSdd?oXm=001ooXm=02o`0000cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00007Oooool01ol0
003o02BXo`0TZ?l09:So0000odMXd?l000003_mQPmd2o`0001;oTYWG00Co0000oj>KcOl0003o0000
3OnUY]H00ol0003o[ZOAojjWd@09ojjWd@03o`000?ndZLko]:W>00So]:W>00?o0000okR]cOnh[Ld0
2Onh[Ld00ol0003o_K?@okfcd00;okfcd003o`000?o2_MGo`[gE00Go`[gE00?o0000olViboo9^L/0
1Oo9^L/00ol0003oclcGolo<e`0:olo<e`03o`000?oHc<gof<c=00Gof<c=0_l00005om_]g`03o`00
0?oXm=3oj?C@00Koj?C@0_l0000>ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02cooooo1?l0
000Qooooo`06o`000?l09:So02BXo`0TZ?m7J=3o00003_mQPmd2ogFGi@03o`000?nBVMOoTYWG013o
TYWG0_l0000>ojFVeP03o`000?n^Ym7o[ZOA00Wo[ZOA00?o0000okBYc_ndZLh02?ndZLh00ol0003o
^:g=okR]c@09okR]c@03o`000?nm/m3o_K?@00[o_K?@00?o0000ol:meOo2_MD01oo2_MD00ol0003o
bKW;olVib`03olVib`03o`000?o?c=OoclcG00_oclcG00?o0000omS<cOoHc<d01?oHc<d00ol0003o
fngOom_]g`05om_]g`03o`000?oXm=3oj?C@00Goj?C@00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0:_ooool3o`0002Gooooo00?o0000o`0TZ?l09:P00_l09:P2o`0000goHH?M
00?o0000ogFGiOmeUnD00_l0000@oi:Ie`03o`000?nHY]oo000000koYJKF00?o0000ojjWdOn^Ym40
2On^Ym400ol0003o]:W>okBYcP02okBYcPWo00001onh[Ld00ol0003o_K?@okfcd00:okfcd003o`00
0?o2_MGo`[gE00Wo`[gE00Go0000olViboo9^L_obKW;o`00000?olo<e`03o`000?oHc<gof<c=00;o
f<c=00?o0000om_]gooKkMl01_oKkMl00ol0003oj?C@onSdd004onSdd003o`000?oooooooooo017o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo0ol0000Yooooo`07o`000?l09:So02BXo`0TZ?l0
003o06GIo`00000;of63g@03o`000?meUnGoMIOU00?oMIOU00?o0000oi:IeonBVML03?nBVML01Ol0
003oV:KOoiRVgonHY]oo000000koYJKF00?o0000ojjWdOn^Ym401on^Ym46o`0000Go/;CK00Co0000
ok>ffonc]]_o/kKK1Ol00002okR]c@03o`000?nm/m3o_K?@00Wo_K?@00?o0000ol:meOo2_MD02oo2
_MD00ol0003obKW;o`00000Aolo<e`04o`000?oHc<gof<c=o`0000SofngO00?o0000onSdd?oXm=00
1?oXm=000ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`?o0000;Ooo
ool01_l0003o02BXo`0TZ?l09:So0000o`1Uf@;o00002OmQPmd00ol0003oMIOUogFGi@04ogFGi@;o
00002onBVML00ol0003oV:KOoiRVg`03oiRVg`;o00003?nUY]H00ol0003o[ZOAojjWd@04ojjWd@?o
000000?o[;;Mo`000?n`]=/02?n`]=/00ol0003o/kKKok>ff`06ok>ff`Co00002Onm/m000ol0003o
`[gEol:me@0=ol:me@03o`000?o?c=OoclcG013oclcG00?o0000omS<cOl000002OoKkMl00ol0003o
j?C@onSdd002onSdd0;o00005_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool4o`00037ooooo
00Go0000o`0TZ?l09:So02BXo`000002o`1Uf@;o00001omQPmd00ol0003oMIOUogFGi@06ogFGi@;o
00002?nBVML00ol0003oV:KOoiRVg`06oiRVg`03o`000?nUY]KoYJKF00[oYJKF00?o0000ojjWdOn^
Ym400ol00005ojbbg@03o`000?n`]=_o/;CK00Ko/;CK00?o0000ok>ffonc]]/01onc]]/00ol0003o
][[LokJjg003o`0000Go_K?@00?o0000ol:meOo2_MD03?o2_MD00ol0003oa<_Oo`00000Colo<e`03
o`000?oKkMoofngO00SofngO00Co0000onSdd?oXm=3oj?C@0_l0000Hooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Mooooo`?o0000=oooool2o`0TZ003o`000?l0IMWo06GI00;o06GI00?o0000of63gOmQ
Pmd01?mQPmd00ol0003oMIOUogFGi@08ogFGi@03o`000?nBVMOoTYWG00CoTYWG00?o0000oiRVgonH
Y]l02?nHY]l00ol0003oYJKFojFVeP09ojFVeP?o00002?n//]d00ol0003o/;CKok2df`06ok2df`03
o`000?nc]]_o/kKK00Ko/kKK00?o0000okJjg?nf^]`01?nf^]`3o`000003okfcd?l0003o`[gE00co
`[gE0_l00003olC;g`03o`000?o?c=OoclcG00goclcG0_l000000oo>i>Oo0000om_]g`09om_]g`03
o`000?oXm=3oj?C@00;o00006_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Ko
oooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_ooool3o`0003_ooooo
0_l09:P00ol0003o06GIo`1Uf@02o`1Uf@;o00001?mQPmd00ol0003oMIOUogFGi@09ogFGi@;o0000
0onBVML00ol0003oV:KOoiRVg`0:oiRVg`;o00001onUY]H2o`000003ojJbhOl0003o[;;M00So[;;M
00?o0000ok2dfon`]=/01_n`]=/00ol0003o/kKKok>ff`06ok>ff`03o`000?nf^]co][[L00Oo][[L
00?o0000ol:meOo2_MD02_o2_MD2o`0000Koa<_O00?o0000olo<eoo?c=L02_o?c=L2o`0000?oc^CW
00?o0000om_]gooKkMl02?oKkMl01?l0003oj?C@o`000?l0000Looooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01_ooool000[ooooo00?oEEEEofIVI_l000001_ooool2o`0001Sooooo
0ol0000oooooo`;o02BX00?o0000o`1UfOl0IMT00ol0IMT2o`000003of63gOl0003oMIOU00goMIOU
00?o0000oi:Ieol000003onHY]l00ol0003oYJKFojFVeP02ojFVeP;o00001?nV/^400ol0003o[;;M
ojbbg@07ojbbg@03o`000?n`]=_o/;CK00Go/;CK00?o0000ok>ffonc]]/01Onc]]/00ol0003o][[L
okJjg007okJjg004o`000?nh`N3o^<7Po`0000Wo`[gE00?o0000olC;goo4bml01oo4bml00ol0003o
clcGolo<e`07olo<e`;o00001Oo>i>L00ol0003ofngOom_]g`08om_]g`?o00007_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Booooo`03o`000?oooooooooo01Cooooo
1?l00013ooooo`03o`0TZ?l0003o06GI00Ko06GI00?oHH?Mo`000?meUnD03_meUnD2o`00013oV:KO
00Co0000ojFVe_l0003o00001onV/^400ol0003o[;;Mojbbg@06ojbbg@03o`000?n`]=_o/;CK00Co
/;CK00?o0000ok>ffonc]]/01_nc]]/00ol0003o][[LokJjg006okJjg003o`000?nh`N3o^<7P00;o
^<7P00?o0000ol:meOo2_MD01?o2_MD2o`0000[oa<_O00?o0000olo<eoo?c=L01Oo?c=L2o`0000Oo
c^CW00?o0000om_]gooKkMl01ooKkMl3o`0001oooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0Aooooo`?o0000B?ooool00ol09:So0000
o`1Uf@06o`1Uf@;o00003_meUnD00ol0003oQ:O[o`000002o`0000koV:KO0_l00009ojJbh@03o`00
0?n//]go[;;M00Go[;;M00?o0000ok2dfon`]=/01?n`]=/00ol0003o/kKKok>ff`05ok>ff`03o`00
0?nf^]co][[L00Ko][[L00?o0000okS1h?nh`N001?nh`N001?l0003o`[gEol:meOo2_MD2o`0000go
a<_O00?o0000olo<eoo?c=L00_o?c=L2o`0000Woc^CW00?o0000om_]gooKkMl01OoKkMl4o`00027o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`0>ooooo`?o0000C?ooool00ol0003o06GIo`1Uf@05o`1Uf@03o`000?lkSnoo000000;o0000
2omeUnD00ol0003oQ:O[ohBWj`02ohBWj`;o00002onHY]l01?l0003oWK;Woifbiol00009ojJbh@03
o`000?n//]go[;;M00Go[;;M00?o0000ok2dfon`]=/00on`]=/00ol0003o/kKKok>ff`04ok>ff`03
o`000?nf^]co][[L00Ko][[L00?o0000okS1h?nh`N001_nh`N000ol0003o`[gEo`00000@olC;g`04
o`000?o?c=Oo0000o`0000[oc^CW00?o0000om_]gooKkMl01OoKkMl01?l0003oZ?SHo`000?l0000S
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooo
ooooool02oooool3o`00053ooooo00?o0000o`1UfOl0IMT01Ol0IMT01?l0003o>ho_oc^?kolkSnl2
o`0000SoMIOU00?o0000ohBWjon4Yn/01On4Yn/2o`0000SoV:KO00?o0000oifbionM/^L00_nM/^L2
o`0000OoY[;Q00?o0000ojbbgOn//]d01On//]d00ol0003o/;CKok2df`03ok2df`03o`000?nc]]_o
/kKK00Co/kKK00?o0000okJjg?nf^]`01Onf^]`00ol0003o^<7PokS1h008okS1h003o`000?o4bmoo
a<_O013oa<_O00?o0000olkTioo>i>L02_o>i>L00ol0003ofngOom_]g`03om_]g`;o000000?oZ?SH
o`000?l000009Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Boooo
o`03o`000?oooooooooo00Oooooo1?l0001Dooooo`;o00001Ol0IMT00ol0003o>ho_oc^?k`03oc^?
k`;o00001_meUnD00ol0003oQ:O[ohBWj`07ohBWj`?o00001?nHY]l00ol0003oWK;Woifbi`05oifb
i`03o`000?nV/^7oY[;Q00GoY[;Q00?o0000ojbbgOn//]d01?n//]d00ol0003o/;CKok2df`03ok2d
f`03o`000?nc]]_o/kKK00?o/kKK00?o0000okJjg?nf^]`01Onf^]`00ol0003o^<7PokS1h007okS1
h003o`000?nibNOo000000koa<_O0ol000000oo1g>go0000olkTi`0;olkTi`04o`000?oKkMoofngO
om_]g`;o00000_nXn=P00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3o`0005[ooooo0_l00004o`1U
f@03o`000?lkSnoo>ho_00Co>ho_0ol00003ogFGi@03o`000?n4Yn_oQ:O[00[oQ:O[0_l000000onH
Y]oo0000oifbi`08oifbi`;o00001_nV/^400ol0003o[;;Mojbbg@04ojbbg@03o`000?n`]=_o/;CK
00;o/;CK00?o0000ok>ffonc]]/00onc]]/00ol0003o][[LokJjg004okJjg003o`000?nh`N3o^<7P
00Go^<7P0_l00004okW9i`03o`000?o4bmooa<_O00Woa<_O0_l00004ol7Lk@03o`000?o>i>Ooc^CW
00[oc^CW00Co0000om_]gooKkMoo00000onXn=P00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01Oooool0017ooooo00?o0000ooooooooool00_ooool3o`00
05oooooo0_l00003o`1Uf@03o`000?lkSnoo>ho_00Ko>ho_00?o0000ogFGiOl000003on4Yn/2o`00
00_oWK;W00?o0000ojJbhOnV/^401?nV/^401?l0003o[;;MojbbgOn//]d>o`0000Go][[L00?o0000
okS1h?nh`N001?nh`N02o`0000Oo^LWW00?o0000olC;goo4bml01Oo4bml3o`0000Ko`Mc]00?o0000
olkTioo>i>L02_o>i>L3o`0000?oZ?SH00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooo000000;o0000I?ooool01?l0
003o06GIo`1UfOl0000:oc^?k`?o00003On4Yn/00ol0003oTKC_o`000002o`0000WoWK;W0_l00004
ojJbh@Co00000_nX`>/00ol0003oZL3[ojW0j`02ojW0j`03o`000?nY`N_oZL7[00;oZL7[00?o0000
ojW1jol000000_l000000onf^]co0000okS1h005okS1h003o`000?nibNOo^LWW00Oo^LWW00?o0000
olC;goo4bml00oo4bml2o`0000Wo`Mc]00?o0000olkTioo>i>L02?o>i>L00ol0003oc^CWo`000004
ojShf003o`000?oooooooooo02_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04
ooooo`004Oooool2o`0006Sooooo0_l000000ol0IMWo0000oc^?k`08oc^?k`03o`000?mTZ?OoI:Sg
00?o00002_n4Yn/00ol0003oTKC_oi6dk`02oi6dk`;o00002OnM/^L01?l0003oY[;Qo`000?l00003
ojFok005o`000?nX`>_oZ<3[ojS0jol000000onY`>/01Ol0003oZL7[ojW1jonY`N_o000000CoZL7[
0_l00005okS1h0;o00002onibNL00ol0003oa<_Oo`000002o`0000[o`Mc]00?o0000olkTioo>i>L0
1_o>i>L3o`000003ok3elOl0003oZ?SH00?oZ?SH00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06Oooooo0_l0
000:oc^?k`03o`000?mTZ?OoI:Sg00;oI:Sg0ol00007ohBWj`03o`000?nA]>ooTKC_00CoTKC_0ol0
0007oifbi`;o00001OnU_n`01?l0003oZ<3[ojS0jol00003ojW0j`04o`000?nY`N_oZL7[o`0000Co
ZL7[00Ko0000oj[3k?nZ`ncoZ/?/o`000?nh`N02o`0000ko^LWW00?o0000ol7LkOo1g>d02oo1g>d0
0ol0003oc^CWolkTi`02olkTi`Co00000on`mO400ol0003oZ?SHojShf002ojShf003o`000?oooooo
oooo02oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`005?ooool2o`00
06Wooooo0ol00007oc^?k`03o`000?mTZ?OoI:Sg00GoI:Sg0ol00003ohBWj`03o`000?nA]>ooTKC_
00SoTKC_0_l00005oifbi`04o`000?nQ_nko0000o`0000CoYKo/00Co0000ojS0jonX`>_o00000_nY
`>/01?l0003oZL7[ojW1jol00002ojW1j`;o00001?nZ`n`2o`0000[o^LWW1?l00002okCCl003o`00
0?o1g>go`Mc]00_o`Mc]00?o0000olkTiol000000_l00006ok3el@04o`000?nXn=SoZ?SHojShf0;o
0000<oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`00
0?oooooo000006Sooooo00Co06K2o`000?l0003o00001OlkSnl00ol0003oI:SgofBXm`07ofBXm`;o
000000?oQ:O[o`000?nA]>l02onA]>l3o`000003oifbiol0003oXKo^00?oXKo^0_l00003ojFok005
o`000?nX`>_o0000ojW0jol000000_nY`N/01?l0003oZL7[o`000?l00003oj[3k0?o000000?oZ/K^
o`000?nibNL01OnibNL4o`0000Ko]=?`00?o0000ol7LkOo1g>d02oo1g>d2o`0000So/?Ga00?o0000
ojShf?nXn=P00_l0000eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool0
01Oooooo0_l0001[ooooo`04o`1V`_l0003o0000o`0000?o>ho_00?o0000ofBXmomTZ?L02OmTZ?L5
o`0000_oTKC_1?l00004oj6okP?o000000WoYKo/o`000?l0003oZL3[o`000?nY`N_o0000ojW1jol0
00000_nZ`n`3o`0000GoZ/K^00?o0000okW9iol000000ol00009okCCl003o`000?o1g>go`Mc]00Go
`Mc]1Ol00002ojkYn@03o`000?n`mO7o/?Ga00Ko/?Ga00Co0000ojShf?l0003o0000>?ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o0000K?ooool2o`1V`PCo
00002omTZ?L00ol0003oPKWhoh6in002oh6in0Oo00001?nA]>l01?l0003oW<7boic1l_nL`O85o`00
00;oXKo^1Ol000000onY`N_o0000o`000003o`0000CoZ/K^1_l0000=okCCl003o`000?o1g>go`Mc]
00Go00001_n^jOT00ol0003o/?Gaok3el@06ok3el@?o0000>oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo06_ooooo0ol0I/85o`0000So
I:Sg00?o0000oh6in?n1^OP02?n1^OP<o`000003oic1l_l0003o000000oo00001?nXb_800ol0003o
]=?`okCCl005okCCl003o`000?nddo3o]=?`00Co]=?`0ol0000:ojkYn@03o`000?n`mO7o/?Ga00Ko
/?Ga0_l0000nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool001_ooooo
0_l000000ooooooo0000ooooo`1[ooooo`?o06K200?o0000oc>Ql_l000001_l000000omTZ?Oo0000
oh6in00<oh6in003o`000?nG`oKoUl?f00KoUl?f7_l00007ojWKn@03o`000?n^jOWo[^Wi00Wo[^Wi
00?o0000ok3elOn`mO401?n`mO43o`00047ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`03ooooo`007Oooool2o`0006kooooo0_l0I/82o`0000Ko<j7b2_l00006oh6in004o`000?nG
`oKoUl?foiO3mP[o000000?oU<_ko`000?l000001_l00007oj?=mP03o`000?nYfoWoZM_i00_oZM_i
00?o0000ojkYnOn^jOT02On^jOT01?l0003o/?Gaok3elOn`mO45o`0004?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`03ooooo`007_ooool00ol0003oooooooooo`1^ooooo`;o06K2
0_l00008oc>QlP03o`000?m`_OgoL;gm00?oL;gm1Ol000000on1^OSo0000o`000002o`0000CoU<Oi
1Ol000001_nDbo_o0000o`000?nEc?_o0000oiS=nP;o00000_nMc_T4o`0000;oXlgf00?o0000ojWK
nOnYfoT02onYfoT00ol0003o[^WiojkYn@09ojkYn@Oo0000Aoooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003o06K2o`000008oc>QlP03
o`000?m`_OgoL;gm00[oL;gm00?o0000oiC7nOnDaoT00ol000000onCbO[o0000o`000002oiC;n`03
o`000?nDbo_o000000;oULck00?o0000oiS=n_nHcOX00_l00004oig>n@Wo00001onYfoT00ol0003o
[^WiojkYn@02ojkYn@_o0000Boooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo000Qooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01_l00003oc>QlP03o`00
0?m`_OgoL;gm00CoL;gm1?l00002og2mo@?o00000_nCbOX00ol0003oU<_koiC;n`02oiC;n`04o`00
0?nDbo_oU<_ko`0000;oULck00Co0000oiS=n_nHcO[oV<gj0_l000000onMc_Wo0000oiGLoP08oiGL
oPco00000_n1hoH6o`0004oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03oooo
o`008_ooool3o`0006cooooo00?o0000ooooooooool00oooool00ol0003o0HkCo`6>d`0:o`0000Wo
HL3m1?l00002oiC;n`05o`000?nDbo_oU<_koiC;nol000000onEc?/00ol0003oV<gjoiS=nP06o`00
00WoUMcn0ol00007oh7SmPGo0000Doooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo000Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool01oooool3o`0000?o
0HkC1?l00003of70o@Co00001OmK`o/=o`0000KoO]On1?l00003oiGLoP;o00001on1hoH5o`0005Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009Oooool2o`0006[ooooo
00?o0000ooooooooool02_ooool6o`000004o`6>dol0003o0000o`0000WoFl?k00?o0000oeo8nomO
b?/00omOb?/00ol0003oJlolof_?o004of_?o0;o00002?mneoh=o`0005_ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`009oooool00ol0003oooooooooo`1Wooooo`03o`00
0?oooooooooo013ooooo1Ol0PKH5o`0000;oFl?k00?o0000oeo8nomOb?/01OmOb?/00ol0003oJlol
of_?o005of_?o004o`000?mneokoO]OnogkGoPCo00000_m3a=d6o`00067ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`00:?ooool00ol0003oooooo`00001Vooooo`03o`00
0?oooooooooo01Sooooo0_l0PKHLo`0006Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001Vooooo`03o`000?oo
oooooooo09oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`008?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Eooooo`Ko00001Oooool00ol0
003oooooooooo`09ooooo`;o0000Hoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00001Pooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`008?ooool00ol0003oooooooooo`0<ooooo`;o0000H?ooool00ol0003ooooo
ooooo`2Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00Oooool0023ooooo00?o
0000ooooooooool03Oooool2o`0005oooooo00?o0000ooooooooool0Xoooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00Oooool001kooooo00?oEEEEofIVI_l000004_ooool2o`000003ooooool0003ooooo
05Sooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
007ooooo000eooooo`;o0000FOooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00Oooool003Kooooo0_l0001Hooooo`03o`000?oooooooooo0:Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00>?ooool01Ol0003ooooooooo
oooooooo000005?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo007ooooo000iooooo`04o`000?ooooooooooo`0005?ooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00>_ooool3o`0005?ooooo00?o
0000ooooooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00??ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool02?ooool1
o`00007ooooo0Oooool003gooooo0_l0001Aooooo`03o`000?oooooooooo0:_ooooo00?o0000oooo
ooooool01oooool1o`00007ooooo0Oooool003oooooo00?o0000ooooool00000C_ooool00ol0003o
ooooooooo`2/ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0010ooooo`;o0000
C_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0011ooooo`;o0000COooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0[_ooool0
0ol0003oooooooooo`05ooooo`7o00000Oooool004Cooooo0_l000000ooooooo0000ooooo`17oooo
o`03o`000?oooooooooo0:oooooo00?o0000ooooooooool01?ooool1o`00007ooooo0016ooooo`;o
0000B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`04odA4A?l0003o0000oc8b
<P;o0000Aoooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00;ooooo0Ol00001oooo
o`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`04ogMgMolb<S;ooooo
o`0004Kooooo00?o0000ooooooooool0/_ooool01Ol0003ooooooooooooooooo0000007ooooo000Z
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ol0
0013ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`2cooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo007o0000000booooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`;o0000@?ooool00ol0
003oooooooooo`2eooooo`7o00000Oooool1o`000000<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool02_ooool2o`0003kooooo00?o0000ooooooooool0]_ooool2o`00
0000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000:ooooo`;o0000?Oooool00ol0
003oooooooooo`2eooooo`?o0000001Cooooo`05o`000?ooooooooooooooool00000>?ooool00ol0
003oooooooooo`2`ooooo`Go00000oooool005Cooooo00Co0000oooooooooooo0000>?ooool00ol0
003oooooooooo`2/ooooo`Co00002?ooool005Gooooo0ol0000hooooo`03o`000?oooooooooo0:So
oooo1?l0000<ooooo`00Eoooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:Cooooo
1Ol0000@ooooo`00F?ooool2o`0003Gooooo00?o0000ooooooooool0X?ooool4o`0001Gooooo001J
ooooo`03o`000?oooooo000003;ooooo00?o0000ooooooooool0W?ooool4o`0001Wooooo001Koooo
o`;o0000<_ooool00ol0003oooooooooo`2Gooooo`Go00007Oooool005gooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`2Cooooo`Co00008_ooool005kooooo00Co0000oooooooooooo
0000;Oooool00ol0003oooooooooo`2>ooooo`Go00009_ooool005oooooo0ol0000]ooooo`03o`00
0?oooooooooo08[ooooo1?l0000[ooooo`00HOooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo08Kooooo1?l0000_ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo0_l0
000[ooooo`03o`000?oooooooooo087ooooo1Ol0000cooooo`00Doooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`1mooooo`Co0000>?oo
ool005?ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000:?ooool00ol0003ooooooooo
o`1iooooo`Co0000??ooool005?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0M?ooool5o`00043ooooo001Cooooo`05o`000?oooooo
ooooooooool000004?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo073ooooo
1?l00015ooooo`00Doooool01Ol@413ooooooooooooooooo410@017ooooo0ol0000Sooooo`03o`00
0?oooooooooo06_ooooo1Ol00019ooooo`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg01;ooooo
0_l0000Sooooo`03o`000?oooooooooo06Oooooo1?l0001>ooooo`00Doooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Cooooo0_l000000ooooooo0000ooooo`0Nooooo`03o`000?oooooooooo06?ooooo
1?l0001Booooo`00K_ooool2o`0001oooooo00?o0000ooooooooool0G_ooool5o`0005Kooooo001_
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0F_ooool4o`0005_ooooo001`oooo
o`;o00007Oooool00ol0003oooooooooo`1Fooooo`Co0000Goooool007;ooooo00?o0000ooooool0
00006_ooool00ol0003oooooooooo`1Aooooo`Go0000Hoooool007?ooooo0_l0000Jooooo`03o`00
0?oooooooooo04gooooo1?l0001Xooooo`00MOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo04Wooooo1?l0001/ooooo`00M_ooool2o`000003ooooool0003ooooo01Cooooo00?o0000
ooooooooool0A?ooool5o`00073ooooo001hooooo`;o00005Oooool00ol0003oooooooooo`10oooo
o`Co0000MOooool007Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0kooooo`Go
0000NOooool007[ooooo0_l000000ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo03Oooooo
1?l0001nooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd00oooool2o`00017ooooo00?o0000ooooooooool0<oooool4o`0008;o
oooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool00oooool2o`0000oooooo00?o0000ooooooooool0;oooool5o`0008Kooooo001Sooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0:oooool4o`0008_ooooo001Sooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`06ooooo`?o00002oooool00ol0003oooooooooo`0Wooooo`Co
0000Soooool006?ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1Ol0002Coooo
o`00Hoooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool03?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo01kooooo1?l0002Hooooo`00Hoooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool03Oooool3o`0000Oooooo00?o0000
ooooooooool06Oooool5o`0009cooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eooooo`Co0000XOooool0
08Oooooo0_l00005ooooo`03o`000?oooooooooo017ooooo1?l0002Uooooo`00ROooool2o`0000?o
oooo00?o0000ooooooooool03?ooool5o`000:Wooooo002:ooooo`05o`000?ooooooooooooooool0
00002_ooool4o`000:kooooo002;ooooo`;o000000?oooooo`000?ooool01Oooool4o`000;;ooooo
002=ooooo`;o000000?oooooo`000?l000000ol0002fooooo`00S_ooool2o`000;_ooooo003ooooo
odcooooo003oooooodcooooo0024ooooo`Co000000?o410@ooooooooool0`?ooool008Kooooo00?o
0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000oooo
ooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0
`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Cooooo00?oEEEEofIVI_l00000a?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.54099 .55588 m .54282 .59538 L .61187 .58606 L p .709 .58 .708 r
F P
0 g
s
.61187 .58606 m .60125 .54551 L .54099 .55588 L p .709 .58 .708 r
F P
0 g
s
.62045 .62691 m .61187 .58606 L .54282 .59538 L p .71 .555 .677 r
F P
0 g
s
.60125 .54551 m .61187 .58606 L .68035 .56206 L p .658 .554 .726 r
F P
0 g
s
.61187 .58606 m .62045 .62691 L .69774 .6035 L p .65 .521 .693 r
F P
0 g
s
.69774 .6035 m .68035 .56206 L .61187 .58606 L p .65 .521 .693 r
F P
0 g
s
.53875 .51601 m .54099 .55588 L .60125 .54551 L p .707 .604 .738 r
F P
0 g
s
.60125 .54551 m .58883 .50604 L .53875 .51601 L p .707 .604 .738 r
F P
0 g
s
.58883 .50604 m .60125 .54551 L .65945 .52255 L p .664 .585 .757 r
F P
0 g
s
.68035 .56206 m .65945 .52255 L .60125 .54551 L p .658 .554 .726 r
F P
0 g
s
.49037 .51509 m .48431 .55399 L .54099 .55588 L p .741 .621 .726 r
F P
0 g
s
.54099 .55588 m .53875 .51601 L .49037 .51509 L p .741 .621 .726 r
F P
0 g
s
.54282 .59538 m .54099 .55588 L .48431 .55399 L p .747 .601 .695 r
F P
0 g
s
.48431 .55399 m .47956 .59182 L .54282 .59538 L p .747 .601 .695 r
F P
0 g
s
.54424 .63386 m .54282 .59538 L .47956 .59182 L p .752 .582 .664 r
F P
0 g
s
.54282 .59538 m .54424 .63386 L .62045 .62691 L p .71 .555 .677 r
F P
0 g
s
.49774 .47608 m .49037 .51509 L .53875 .51601 L p .733 .642 .758 r
F P
0 g
s
.53875 .51601 m .53611 .47663 L .49774 .47608 L p .733 .642 .758 r
F P
0 g
s
.53611 .47663 m .53875 .51601 L .58883 .50604 L p .704 .628 .769 r
F P
0 g
s
.62675 .66721 m .62045 .62691 L .54424 .63386 L p .709 .529 .643 r
F P
0 g
s
.62045 .62691 m .62675 .66721 L .7108 .64578 L p .64 .485 .656 r
F P
0 g
s
.7108 .64578 m .69774 .6035 L .62045 .62691 L p .64 .485 .656 r
F P
0 g
s
.58883 .50604 m .57488 .46837 L .53611 .47663 L p .704 .628 .769 r
F P
0 g
s
.57488 .46837 m .58883 .50604 L .63585 .48578 L p .668 .616 .787 r
F P
0 g
s
.65945 .52255 m .63585 .48578 L .58883 .50604 L p .664 .585 .757 r
F P
0 g
s
.47956 .59182 m .47603 .62801 L .54424 .63386 L p .752 .582 .664 r
F P
0 g
s
.54525 .67086 m .54424 .63386 L .47603 .62801 L p .756 .561 .632 r
F P
0 g
s
.54424 .63386 m .54525 .67086 L .62675 .66721 L p .709 .529 .643 r
F P
0 g
s
.44578 .50327 m .43221 .54041 L .48431 .55399 L p .768 .641 .72 r
F P
0 g
s
.48431 .55399 m .49037 .51509 L .44578 .50327 L p .768 .641 .72 r
F P
0 g
s
.47956 .59182 m .48431 .55399 L .43221 .54041 L p .776 .621 .688 r
F P
0 g
s
.46233 .4665 m .44578 .50327 L .49037 .51509 L p .757 .66 .754 r
F P
0 g
s
.49037 .51509 m .49774 .47608 L .46233 .4665 L p .757 .66 .754 r
F P
0 g
s
.50635 .43829 m .49774 .47608 L .53611 .47663 L p .722 .663 .792 r
F P
0 g
s
.53611 .47663 m .53311 .4388 L .50635 .43829 L p .722 .663 .792 r
F P
0 g
s
.53311 .4388 m .53611 .47663 L .57488 .46837 L p .698 .653 .802 r
F P
0 g
s
.63585 .48578 m .65945 .52255 L .7057 .48894 L p .605 .567 .785 r
F P
0 g
s
.65945 .52255 m .68035 .56206 L .73554 .52456 L p .585 .525 .754 r
F P
0 g
s
.73554 .52456 m .7057 .48894 L .65945 .52255 L p .585 .525 .754 r
F P
0 g
s
.43221 .54041 m .42158 .5769 L .47956 .59182 L p .776 .621 .688 r
F P
0 g
s
.47603 .62801 m .47956 .59182 L .42158 .5769 L p .782 .602 .656 r
F P
0 g
s
.68035 .56206 m .69774 .6035 L .76076 .56366 L p .563 .479 .717 r
F P
0 g
s
.76076 .56366 m .73554 .52456 L .68035 .56206 L p .563 .479 .717 r
F P
0 g
s
.63058 .70605 m .62675 .66721 L .54525 .67086 L p .707 .5 .606 r
F P
0 g
s
.62675 .66721 m .63058 .70605 L .7188 .68754 L p .629 .444 .614 r
F P
0 g
s
.7188 .68754 m .7108 .64578 L .62675 .66721 L p .629 .444 .614 r
F P
0 g
s
.57488 .46837 m .55964 .43316 L .53311 .4388 L p .698 .653 .802 r
F P
0 g
s
.55964 .43316 m .57488 .46837 L .61026 .45224 L p .67 .646 .817 r
F P
0 g
s
.63585 .48578 m .61026 .45224 L .57488 .46837 L p .668 .616 .787 r
F P
0 g
s
.61026 .45224 m .63585 .48578 L .67262 .45743 L p .622 .605 .813 r
F P
0 g
s
.7057 .48894 m .67262 .45743 L .63585 .48578 L p .605 .567 .785 r
F P
0 g
s
.48164 .43145 m .46233 .4665 L .49774 .47608 L p .743 .679 .789 r
F P
0 g
s
.49774 .47608 m .50635 .43829 L .48164 .43145 L p .743 .679 .789 r
F P
0 g
s
.47603 .62801 m .47359 .66237 L .54525 .67086 L p .756 .561 .632 r
F P
0 g
s
.54586 .70605 m .54525 .67086 L .47359 .66237 L p .759 .539 .598 r
F P
0 g
s
.54525 .67086 m .54586 .70605 L .63058 .70605 L p .707 .5 .606 r
F P
0 g
s
.69774 .6035 m .7108 .64578 L .77992 .60519 L p .537 .426 .674 r
F P
0 g
s
.77992 .60519 m .76076 .56366 L .69774 .6035 L p .537 .426 .674 r
F P
0 g
s
.42158 .5769 m .41371 .61211 L .47603 .62801 L p .782 .602 .656 r
F P
0 g
s
.47359 .66237 m .47603 .62801 L .41371 .61211 L p .786 .582 .625 r
F P
0 g
s
.43202 .44829 m .40637 .48069 L .44578 .50327 L p .78 .687 .761 r
F P
0 g
s
.44578 .50327 m .46233 .4665 L .43202 .44829 L p .78 .687 .761 r
F P
0 g
s
.43221 .54041 m .44578 .50327 L .40637 .48069 L p .794 .669 .727 r
F P
0 g
s
.40637 .48069 m .38457 .51488 L .43221 .54041 L p .794 .669 .727 r
F P
0 g
s
.42158 .5769 m .43221 .54041 L .38457 .51488 L p .803 .65 .693 r
F P
0 g
s
.61026 .45224 m .58324 .42216 L .55964 .43316 L p .67 .646 .817 r
F P
0 g
s
.58324 .42216 m .61026 .45224 L .63746 .43023 L p .637 .642 .838 r
F P
0 g
s
.67262 .45743 m .63746 .43023 L .61026 .45224 L p .622 .605 .813 r
F P
0 g
s
.46107 .41874 m .43202 .44829 L .46233 .4665 L p .761 .703 .797 r
F P
0 g
s
.46233 .4665 m .48164 .43145 L .46107 .41874 L p .761 .703 .797 r
F P
0 g
s
.51597 .40328 m .50635 .43829 L .53311 .4388 L p .706 .687 .829 r
F P
0 g
s
.53311 .4388 m .52982 .40373 L .51597 .40328 L p .706 .687 .829 r
F P
0 g
s
.52982 .40373 m .53311 .4388 L .55964 .43316 L p .689 .681 .837 r
F P
0 g
s
.63176 .7425 m .63058 .70605 L .54586 .70605 L p .703 .466 .563 r
F P
0 g
s
.63058 .70605 m .63176 .7425 L .72118 .72728 L p .614 .396 .563 r
F P
0 g
s
.72118 .72728 m .7188 .68754 L .63058 .70605 L p .614 .396 .563 r
F P
0 g
s
.50321 .39965 m .48164 .43145 L .50635 .43829 L p .723 .699 .828 r
F P
0 g
s
.50635 .43829 m .51597 .40328 L .50321 .39965 L p .723 .699 .828 r
F P
0 g
s
.55964 .43316 m .54336 .40106 L .52982 .40373 L p .689 .681 .837 r
F P
0 g
s
.54336 .40106 m .55964 .43316 L .58324 .42216 L p .671 .678 .848 r
F P
0 g
s
.38457 .51488 m .36681 .54992 L .42158 .5769 L p .803 .65 .693 r
F P
0 g
s
.41371 .61211 m .42158 .5769 L .36681 .54992 L p .81 .63 .659 r
F P
0 g
s
.7108 .64578 m .7188 .68754 L .79174 .64769 L p .505 .362 .621 r
F P
0 g
s
.79174 .64769 m .77992 .60519 L .7108 .64578 L p .505 .362 .621 r
F P
0 g
s
.47359 .66237 m .47213 .69493 L .54586 .70605 L p .759 .539 .598 r
F P
0 g
s
.54606 .73913 m .54586 .70605 L .47213 .69493 L p .759 .512 .56 r
F P
0 g
s
.54586 .70605 m .54606 .73913 L .63176 .7425 L p .703 .466 .563 r
F P
0 g
s
.41371 .61211 m .40829 .6458 L .47359 .66237 L p .786 .582 .625 r
F P
0 g
s
.47213 .69493 m .47359 .66237 L .40829 .6458 L p .789 .562 .592 r
F P
0 g
s
.49281 .39319 m .46107 .41874 L .48164 .43145 L p .735 .717 .834 r
F P
0 g
s
.48164 .43145 m .50321 .39965 L .49281 .39319 L p .735 .717 .834 r
F P
0 g
s
.58324 .42216 m .55518 .39563 L .54336 .40106 L p .671 .678 .848 r
F P
0 g
s
.55518 .39563 m .58324 .42216 L .60108 .40722 L p .65 .677 .862 r
F P
0 g
s
.63746 .43023 m .60108 .40722 L .58324 .42216 L p .637 .642 .838 r
F P
0 g
s
.36681 .54992 m .35312 .5851 L .41371 .61211 L p .81 .63 .659 r
F P
0 g
s
.40829 .6458 m .41371 .61211 L .35312 .5851 L p .814 .609 .625 r
F P
0 g
s
.4096 .42279 m .37534 .44827 L .40637 .48069 L p .799 .725 .783 r
F P
0 g
s
.40637 .48069 m .43202 .44829 L .4096 .42279 L p .799 .725 .783 r
F P
0 g
s
.38457 .51488 m .40637 .48069 L .37534 .44827 L p .819 .714 .749 r
F P
0 g
s
.63746 .43023 m .67262 .45743 L .6922 .42508 L p .559 .598 .849 r
F P
0 g
s
.67262 .45743 m .7057 .48894 L .72995 .44979 L p .518 .548 .826 r
F P
0 g
s
.72995 .44979 m .6922 .42508 L .67262 .45743 L p .518 .548 .826 r
F P
0 g
s
.44671 .40142 m .4096 .42279 L .43202 .44829 L p .773 .734 .816 r
F P
0 g
s
.43202 .44829 m .46107 .41874 L .44671 .40142 L p .773 .734 .816 r
F P
0 g
s
.7057 .48894 m .73554 .52456 L .76404 .47942 L p .471 .489 .795 r
F P
0 g
s
.76404 .47942 m .72995 .44979 L .7057 .48894 L p .471 .489 .795 r
F P
0 g
s
.37534 .44827 m .3447 .47733 L .38457 .51488 L p .819 .714 .749 r
F P
0 g
s
.36681 .54992 m .38457 .51488 L .3447 .47733 L p .835 .7 .715 r
F P
0 g
s
.60108 .40722 m .63746 .43023 L .65214 .40529 L p .594 .641 .866 r
F P
0 g
s
.6922 .42508 m .65214 .40529 L .63746 .43023 L p .559 .598 .849 r
F P
0 g
s
.40829 .6458 m .40506 .678 L .47213 .69493 L p .789 .562 .592 r
F P
0 g
s
.47161 .72584 m .47213 .69493 L .40506 .678 L p .79 .539 .557 r
F P
0 g
s
.47213 .69493 m .47161 .72584 L .54606 .73913 L p .759 .512 .56 r
F P
0 g
s
.52982 .40373 m .52632 .37269 L .51597 .40328 L closepath p .691 .719 .871 r
F P
0 g
s
.54336 .40106 m .52632 .37269 L .52982 .40373 L closepath p .687 .716 .871 r
F P
0 g
s
.48589 .38459 m .44671 .40142 L .46107 .41874 L p .741 .739 .849 r
F P
0 g
s
.46107 .41874 m .49281 .39319 L .48589 .38459 L p .741 .739 .849 r
F P
0 g
s
.73554 .52456 m .76076 .56366 L .79289 .51365 L p .414 .417 .753 r
F P
0 g
s
.79289 .51365 m .76404 .47942 L .73554 .52456 L p .414 .417 .753 r
F P
0 g
s
.7188 .68754 m .72118 .72728 L .79523 .68941 L p .463 .283 .551 r
F P
0 g
s
.79523 .68941 m .79174 .64769 L .7188 .68754 L p .463 .283 .551 r
F P
0 g
s
.51597 .40328 m .52632 .37269 L .50321 .39965 L closepath p .693 .721 .871 r
F P
0 g
s
.55518 .39563 m .52632 .37269 L .54336 .40106 L closepath p .679 .713 .874 r
F P
0 g
s
.63017 .7756 m .63176 .7425 L .54606 .73913 L p .695 .424 .51 r
F P
0 g
s
.63176 .7425 m .63017 .7756 L .71766 .76349 L p .593 .336 .497 r
F P
0 g
s
.71766 .76349 m .72118 .72728 L .63176 .7425 L p .593 .336 .497 r
F P
0 g
s
.54584 .76973 m .54606 .73913 L .47161 .72584 L p .756 .48 .514 r
F P
0 g
s
.54606 .73913 m .54584 .76973 L .63017 .7756 L p .695 .424 .51 r
F P
0 g
s
.60108 .40722 m .56398 .38813 L .55518 .39563 L p .65 .677 .862 r
F P
0 g
s
.56398 .38813 m .60108 .40722 L .61077 .39018 L p .627 .678 .879 r
F P
0 g
s
.65214 .40529 m .61077 .39018 L .60108 .40722 L p .594 .641 .866 r
F P
0 g
s
.3447 .47733 m .31837 .50941 L .36681 .54992 L p .835 .7 .715 r
F P
0 g
s
.35312 .5851 m .36681 .54992 L .31837 .50941 L p .848 .684 .678 r
F P
0 g
s
.50321 .39965 m .52632 .37269 L .49281 .39319 L closepath p .693 .722 .872 r
F P
0 g
s
.35312 .5851 m .3434 .61989 L .40829 .6458 L p .814 .609 .625 r
F P
0 g
s
.40506 .678 m .40829 .6458 L .3434 .61989 L p .817 .587 .591 r
F P
0 g
s
.56398 .38813 m .52632 .37269 L .55518 .39563 L closepath p .667 .712 .881 r
F P
0 g
s
.49281 .39319 m .52632 .37269 L .48589 .38459 L closepath p .695 .726 .874 r
F P
0 g
s
.76076 .56366 m .77992 .60519 L .81485 .55168 L p .341 .324 .695 r
F P
0 g
s
.81485 .55168 m .79289 .51365 L .76076 .56366 L p .341 .324 .695 r
F P
0 g
s
.56872 .3794 m .52632 .37269 L .56398 .38813 L closepath p .655 .715 .892 r
F P
0 g
s
.61077 .39018 m .56872 .3794 L .56398 .38813 L p .627 .678 .879 r
F P
0 g
s
.44054 .38153 m .39868 .39282 L .4096 .42279 L p .776 .769 .847 r
F P
0 g
s
.4096 .42279 m .44671 .40142 L .44054 .38153 L p .776 .769 .847 r
F P
0 g
s
.37534 .44827 m .4096 .42279 L .39868 .39282 L p .809 .775 .821 r
F P
0 g
s
.48325 .37489 m .44054 .38153 L .44671 .40142 L p .738 .759 .87 r
F P
0 g
s
.44671 .40142 m .48589 .38459 L .48325 .37489 L p .738 .759 .87 r
F P
0 g
s
.31837 .50941 m .29705 .54384 L .35312 .5851 L p .848 .684 .678 r
F P
0 g
s
.3434 .61989 m .35312 .5851 L .29705 .54384 L p .858 .664 .639 r
F P
0 g
s
.40506 .678 m .40389 .70886 L .47161 .72584 L p .79 .539 .557 r
F P
0 g
s
.47205 .75513 m .47161 .72584 L .40389 .70886 L p .789 .511 .516 r
F P
0 g
s
.47161 .72584 m .47205 .75513 L .54584 .76973 L p .756 .48 .514 r
F P
0 g
s
.39868 .39282 m .35838 .40904 L .37534 .44827 L p .809 .775 .821 r
F P
0 g
s
.3447 .47733 m .37534 .44827 L .35838 .40904 L p .84 .778 .792 r
F P
0 g
s
.48589 .38459 m .52632 .37269 L .48325 .37489 L closepath p .695 .733 .88 r
F P
0 g
s
.3434 .61989 m .33755 .65395 L .40506 .678 L p .817 .587 .591 r
F P
0 g
s
.40389 .70886 m .40506 .678 L .33755 .65395 L p .818 .564 .554 r
F P
0 g
s
.56872 .3794 m .61077 .39018 L .61098 .37297 L p .599 .683 .9 r
F P
0 g
s
.61077 .39018 m .65214 .40529 L .65201 .38066 L p .539 .643 .901 r
F P
0 g
s
.65201 .38066 m .61098 .37297 L .61077 .39018 L p .539 .643 .901 r
F P
0 g
s
.56885 .37037 m .52632 .37269 L .56872 .3794 L closepath p .646 .722 .904 r
F P
0 g
s
.61098 .37297 m .56885 .37037 L .56872 .3794 L p .599 .683 .9 r
F P
0 g
s
.72118 .72728 m .71766 .76349 L .78994 .7285 L p .406 .178 .453 r
F P
0 g
s
.78994 .7285 m .79523 .68941 L .72118 .72728 L p .406 .178 .453 r
F P
0 g
s
.65214 .40529 m .6922 .42508 L .6911 .39361 L p .465 .592 .895 r
F P
0 g
s
.6911 .39361 m .65201 .38066 L .65214 .40529 L p .465 .592 .895 r
F P
0 g
s
.35838 .40904 m .32067 .43039 L .3447 .47733 L p .84 .778 .792 r
F P
0 g
s
.31837 .50941 m .3447 .47733 L .32067 .43039 L p .869 .777 .758 r
F P
0 g
s
.55564 .35484 m .52632 .37269 L .56432 .36193 L closepath p .641 .736 .918 r
F P
0 g
s
.48325 .37489 m .52632 .37269 L .48532 .36526 L closepath p .691 .742 .891 r
F P
0 g
s
.56432 .36193 m .52632 .37269 L .56885 .37037 L closepath p .641 .73 .913 r
F P
0 g
s
.54374 .34974 m .52632 .37269 L .55564 .35484 L closepath p .642 .739 .919 r
F P
0 g
s
.52989 .34715 m .52632 .37269 L .54374 .34974 L closepath p .642 .74 .92 r
F P
0 g
s
.5156 .34743 m .52632 .37269 L .52989 .34715 L closepath p .645 .743 .92 r
F P
0 g
s
.50246 .35075 m .52632 .37269 L .5156 .34743 L closepath p .653 .747 .919 r
F P
0 g
s
.49196 .35689 m .52632 .37269 L .50246 .35075 L closepath p .667 .75 .913 r
F P
0 g
s
.48532 .36526 m .52632 .37269 L .49196 .35689 L closepath p .681 .749 .903 r
F P
0 g
s
.54517 .79733 m .54584 .76973 L .47205 .75513 L p .749 .437 .455 r
F P
0 g
s
.54584 .76973 m .54517 .79733 L .62576 .80442 L p .681 .369 .44 r
F P
0 g
s
.62576 .80442 m .63017 .7756 L .54584 .76973 L p .681 .369 .44 r
F P
0 g
s
.77992 .60519 m .79174 .64769 L .82842 .59229 L p .244 .201 .609 r
F P
0 g
s
.82842 .59229 m .81485 .55168 L .77992 .60519 L p .244 .201 .609 r
F P
0 g
s
.44054 .38153 m .48325 .37489 L .48532 .36526 L p .725 .776 .893 r
F P
0 g
s
.63017 .7756 m .62576 .80442 L .70824 .79476 L p .561 .255 .407 r
F P
0 g
s
.70824 .79476 m .71766 .76349 L .63017 .7756 L p .561 .255 .407 r
F P
0 g
s
.6922 .42508 m .72995 .44979 L .72724 .41191 L p .369 .52 .877 r
F P
0 g
s
.72724 .41191 m .6911 .39361 L .6922 .42508 L p .369 .52 .877 r
F P
0 g
s
.29705 .54384 m .28133 .57989 L .3434 .61989 L p .858 .664 .639 r
F P
0 g
s
.33755 .65395 m .3434 .61989 L .28133 .57989 L p .866 .642 .596 r
F P
0 g
s
.48532 .36526 m .44395 .36176 L .44054 .38153 L p .725 .776 .893 r
F P
0 g
s
.39868 .39282 m .44054 .38153 L .44395 .36176 L p .763 .803 .886 r
F P
0 g
s
.56885 .37037 m .61098 .37297 L .60178 .35722 L p .57 .693 .924 r
F P
0 g
s
.60178 .35722 m .56432 .36193 L .56885 .37037 L p .57 .693 .924 r
F P
0 g
s
.32067 .43039 m .28685 .45689 L .31837 .50941 L p .869 .777 .758 r
F P
0 g
s
.29705 .54384 m .31837 .50941 L .28685 .45689 L p .897 .773 .717 r
F P
0 g
s
.44395 .36176 m .48532 .36526 L .49196 .35689 L p .704 .787 .916 r
F P
0 g
s
.33755 .65395 m .33559 .68701 L .40389 .70886 L p .818 .564 .554 r
F P
0 g
s
.40483 .73843 m .40389 .70886 L .33559 .68701 L p .819 .536 .51 r
F P
0 g
s
.40389 .70886 m .40483 .73843 L .47205 .75513 L p .789 .511 .516 r
F P
0 g
s
.47356 .78254 m .47205 .75513 L .40483 .73843 L p .785 .475 .463 r
F P
0 g
s
.47205 .75513 m .47356 .78254 L .54517 .79733 L p .749 .437 .455 r
F P
0 g
s
.72995 .44979 m .76404 .47942 L .75927 .43553 L p .242 .419 .837 r
F P
0 g
s
.75927 .43553 m .72724 .41191 L .72995 .44979 L p .242 .419 .837 r
F P
0 g
s
.44395 .36176 m .40243 .36273 L .39868 .39282 L p .763 .803 .886 r
F P
0 g
s
.35838 .40904 m .39868 .39282 L .40243 .36273 L p .802 .831 .874 r
F P
0 g
s
.56432 .36193 m .60178 .35722 L .58442 .34405 L p .547 .711 .947 r
F P
0 g
s
.58442 .34405 m .55564 .35484 L .56432 .36193 L p .547 .711 .947 r
F P
0 g
s
.61098 .37297 m .65201 .38066 L .63759 .35878 L p .469 .651 .939 r
F P
0 g
s
.63759 .35878 m .60178 .35722 L .61098 .37297 L p .469 .651 .939 r
F P
0 g
s
.45703 .34495 m .49196 .35689 L .50246 .35075 L p .677 .793 .936 r
F P
0 g
s
.49196 .35689 m .45703 .34495 L .44395 .36176 L p .704 .787 .916 r
F P
0 g
s
.79174 .64769 m .79523 .68941 L .83246 .63391 L p .107 .028 .476 r
F P
0 g
s
.83246 .63391 m .82842 .59229 L .79174 .64769 L p .107 .028 .476 r
F P
0 g
s
.28133 .57989 m .27176 .61676 L .33755 .65395 L p .866 .642 .596 r
F P
0 g
s
.33559 .68701 m .33755 .65395 L .27176 .61676 L p .872 .614 .545 r
F P
0 g
s
.55564 .35484 m .58442 .34405 L .56086 .3342 L p .544 .736 .965 r
F P
0 g
s
.56086 .3342 m .54374 .34974 L .55564 .35484 L p .544 .736 .965 r
F P
0 g
s
.40243 .36273 m .36138 .36891 L .35838 .40904 L p .802 .831 .874 r
F P
0 g
s
.32067 .43039 m .35838 .40904 L .36138 .36891 L p .843 .859 .855 r
F P
0 g
s
.40243 .36273 m .44395 .36176 L .45703 .34495 L p .729 .831 .928 r
F P
0 g
s
.28685 .45689 m .25838 .4883 L .29705 .54384 L p .897 .773 .717 r
F P
0 g
s
.28133 .57989 m .29705 .54384 L .25838 .4883 L p .922 .762 .665 r
F P
0 g
s
.71766 .76349 m .70824 .79476 L .77594 .76322 L p .319 .029 .306 r
F P
0 g
s
.77594 .76322 m .78994 .7285 L .71766 .76349 L p .319 .029 .306 r
F P
0 g
s
.76404 .47942 m .79289 .51365 L .78596 .46423 L p .066 .269 .76 r
F P
0 g
s
.78596 .46423 m .75927 .43553 L .76404 .47942 L p .066 .269 .76 r
F P
0 g
s
.47827 .33332 m .50246 .35075 L .5156 .34743 L p .643 .793 .954 r
F P
0 g
s
.50246 .35075 m .47827 .33332 L .45703 .34495 L p .677 .793 .936 r
F P
0 g
s
.54402 .82121 m .54517 .79733 L .47356 .78254 L p .733 .375 .373 r
F P
0 g
s
.54517 .79733 m .54402 .82121 L .61854 .82806 L p .655 .292 .343 r
F P
0 g
s
.61854 .82806 m .62576 .80442 L .54517 .79733 L p .655 .292 .343 r
F P
0 g
s
.65201 .38066 m .6911 .39361 L .67073 .36659 L p .317 .577 .934 r
F P
0 g
s
.67073 .36659 m .63759 .35878 L .65201 .38066 L p .317 .577 .934 r
F P
0 g
s
.54374 .34974 m .56086 .3342 L .53344 .32849 L p .565 .764 .972 r
F P
0 g
s
.53344 .32849 m .52989 .34715 L .54374 .34974 L p .565 .764 .972 r
F P
0 g
s
.50485 .32789 m .5156 .34743 L .52989 .34715 L p .603 .784 .967 r
F P
0 g
s
.5156 .34743 m .50485 .32789 L .47827 .33332 L p .643 .793 .954 r
F P
0 g
s
.52989 .34715 m .53344 .32849 L .50485 .32789 L p .603 .784 .967 r
F P
0 g
s
.62576 .80442 m .61854 .82806 L .69325 .81998 L p .509 .139 .274 r
F P
0 g
s
.69325 .81998 m .70824 .79476 L .62576 .80442 L p .509 .139 .274 r
F P
0 g
s
.33559 .68701 m .33763 .71876 L .40483 .73843 L p .819 .536 .51 r
F P
0 g
s
.40815 .76651 m .40483 .73843 L .33763 .71876 L p .817 .499 .453 r
F P
0 g
s
.40483 .73843 m .40815 .76651 L .47356 .78254 L p .785 .475 .463 r
F P
0 g
s
.60178 .35722 m .63759 .35878 L .6115 .34075 L p .395 .666 .968 r
F P
0 g
s
.6115 .34075 m .58442 .34405 L .60178 .35722 L p .395 .666 .968 r
F P
0 g
s
.47632 .80741 m .47356 .78254 L .40815 .76651 L p .775 .422 .387 r
F P
0 g
s
.47356 .78254 m .47632 .80741 L .54402 .82121 L p .733 .375 .373 r
F P
0 g
s
.36138 .36891 m .32188 .38113 L .32067 .43039 L p .843 .859 .855 r
F P
0 g
s
.28685 .45689 m .32067 .43039 L .32188 .38113 L p .888 .886 .824 r
F P
0 g
s
.45703 .34495 m .42174 .3375 L .40243 .36273 L p .729 .831 .928 r
F P
0 g
s
.36138 .36891 m .40243 .36273 L .42174 .3375 L p .757 .883 .935 r
F P
0 g
s
.27176 .61676 m .26877 .65357 L .33559 .68701 L p .872 .614 .545 r
F P
0 g
s
.33763 .71876 m .33559 .68701 L .26877 .65357 L p .875 .578 .482 r
F P
0 g
s
.42174 .3375 m .45703 .34495 L .47827 .33332 L p .67 .844 .967 r
F P
0 g
s
.25838 .4883 m .23679 .52396 L .28133 .57989 L p .922 .762 .665 r
F P
0 g
s
.27176 .61676 m .28133 .57989 L .23679 .52396 L p .945 .742 .598 r
F P
0 g
s
.79289 .51365 m .81485 .55168 L .80604 .49745 L p 0 .049 .611 r
F P
0 g
s
.80604 .49745 m .78596 .46423 L .79289 .51365 L p 0 .049 .611 r
F P
0 g
s
.6911 .39361 m .72724 .41191 L .70029 .38042 L p .083 .439 .877 r
F P
0 g
s
.70029 .38042 m .67073 .36659 L .6911 .39361 L p .083 .439 .877 r
F P
0 g
s
.79523 .68941 m .78994 .7285 L .82642 .67471 L p 0 0 .26 r
F P
0 g
s
.82642 .67471 m .83246 .63391 L .79523 .68941 L p 0 0 .26 r
F P
0 g
s
.58442 .34405 m .6115 .34075 L .57693 .3268 L p .356 .695 .982 r
F P
0 g
s
.57693 .3268 m .56086 .3342 L .58442 .34405 L p .356 .695 .982 r
F P
0 g
s
.32188 .38113 m .28552 .40009 L .28685 .45689 L p .888 .886 .824 r
F P
0 g
s
.25838 .4883 m .28685 .45689 L .28552 .40009 L p .933 .909 .773 r
F P
0 g
s
.4541 .32107 m .47827 .33332 L .50485 .32789 L p .584 .833 .992 r
F P
0 g
s
.47827 .33332 m .4541 .32107 L .42174 .3375 L p .67 .844 .967 r
F P
0 g
s
.33763 .71876 m .34398 .74876 L .40815 .76651 L p .817 .499 .453 r
F P
0 g
s
.41429 .79248 m .40815 .76651 L .34398 .74876 L p .808 .446 .37 r
F P
0 g
s
.40815 .76651 m .41429 .79248 L .47632 .80741 L p .775 .422 .387 r
F P
0 g
s
.70824 .79476 m .69325 .81998 L .75395 .79216 L p .179 0 .074 r
F P
0 g
s
.75395 .79216 m .77594 .76322 L .70824 .79476 L p .179 0 .074 r
F P
0 g
s
.63759 .35878 m .67073 .36659 L .63588 .34491 L p .122 .54 .918 r
F P
0 g
s
.63588 .34491 m .6115 .34075 L .63759 .35878 L p .122 .54 .918 r
F P
0 g
s
.54235 .84038 m .54402 .82121 L .47632 .80741 L p .699 .281 .25 r
F P
0 g
s
.54402 .82121 m .54235 .84038 L .60859 .84575 L p .604 .172 .194 r
F P
0 g
s
.60859 .84575 m .61854 .82806 L .54402 .82121 L p .604 .172 .194 r
F P
0 g
s
.42174 .3375 m .38664 .33545 L .36138 .36891 L p .757 .883 .935 r
F P
0 g
s
.32188 .38113 m .36138 .36891 L .38664 .33545 L p .784 .94 .929 r
F P
0 g
s
.56086 .3342 m .57693 .3268 L .53681 .31755 L p .39 .743 .992 r
F P
0 g
s
.53681 .31755 m .53344 .32849 L .56086 .3342 L p .39 .743 .992 r
F P
0 g
s
.23679 .52396 m .22347 .56287 L .27176 .61676 L p .945 .742 .598 r
F P
0 g
s
.26877 .65357 m .27176 .61676 L .22347 .56287 L p .961 .707 .507 r
F P
0 g
s
.72724 .41191 m .75927 .43553 L .72552 .39988 L p 0 .201 .705 r
F P
0 g
s
.72552 .39988 m .70029 .38042 L .72724 .41191 L p 0 .201 .705 r
F P
0 g
s
.26877 .65357 m .27267 .68936 L .33763 .71876 L p .875 .578 .482 r
F P
0 g
s
.34398 .74876 m .33763 .71876 L .27267 .68936 L p .872 .528 .396 r
F P
0 g
s
.81485 .55168 m .82842 .59229 L .8184 .53437 L p 0 0 .353 r
F P
0 g
s
.8184 .53437 m .80604 .49745 L .81485 .55168 L p 0 0 .353 r
F P
0 g
s
.49436 .31484 m .50485 .32789 L .53344 .32849 L p .481 .797 .999 r
F P
0 g
s
.50485 .32789 m .49436 .31484 L .4541 .32107 L p .584 .833 .992 r
F P
0 g
s
.61854 .82806 m .60859 .84575 L .67328 .83839 L p .413 0 .064 r
F P
0 g
s
.67328 .83839 m .69325 .81998 L .61854 .82806 L p .413 0 .064 r
F P
0 g
s
.48056 .82864 m .47632 .80741 L .41429 .79248 L p .749 .338 .271 r
F P
0 g
s
.47632 .80741 m .48056 .82864 L .54235 .84038 L p .699 .281 .25 r
F P
0 g
s
.53344 .32849 m .53681 .31755 L .49436 .31484 L p .481 .797 .999 r
F P
0 g
s
.38664 .33545 m .42174 .3375 L .4541 .32107 L p .643 .899 .984 r
F P
0 g
s
.78994 .7285 m .77594 .76322 L .81042 .7129 L p 0 0 0 r
F P
0 g
s
.81042 .7129 m .82642 .67471 L .78994 .7285 L p 0 0 0 r
F P
0 g
s
.28552 .40009 m .25422 .42612 L .25838 .4883 L p .933 .909 .773 r
F P
0 g
s
.23679 .52396 m .25838 .4883 L .25422 .42612 L p .973 .916 .684 r
F P
0 g
s
.6115 .34075 m .63588 .34491 L .59129 .32763 L p 0 .515 .853 r
F P
0 g
s
.57693 .3268 m .6115 .34075 L p .59291 .32868 L 0 .515 .853 r
F P
0 g
s
.65683 .35602 m .63588 .34491 L .67073 .36659 L p 0 .26 .675 r
F P
0 g
s
.65683 .35602 m .60348 .33619 L p .63333 .34422 L .444 0 0 r
F P
0 g
s
.63588 .34491 m .63791 .34598 L p .63333 .34422 L .444 0 0 r
F P
0 g
s
.63791 .34598 m .65683 .35602 L p .63333 .34422 L .444 0 0 r
F P
0 g
s
.59129 .32763 m .58997 .32755 L p .59291 .32868 L 0 .515 .853 r
F P
0 g
s
.58997 .32755 m .57693 .3268 L p .59291 .32868 L 0 .515 .853 r
F P
0 g
s
.67073 .36659 m .70029 .38042 L .65683 .35602 L p 0 .26 .675 r
F P
0 g
s
.38664 .33545 m .35268 .33989 L .32188 .38113 L p .784 .94 .929 r
F P
0 g
s
.28552 .40009 m .32188 .38113 L .35268 .33989 L p .798 .99 .884 r
F P
0 g
s
.75927 .43553 m .78596 .46423 L .7458 .42445 L p .602 .113 0 r
F P
0 g
s
.7458 .42445 m .72552 .39988 L .75927 .43553 L p .602 .113 0 r
F P
0 g
s
.34398 .74876 m .35504 .77631 L .41429 .79248 L p .808 .446 .37 r
F P
0 g
s
.42375 .81523 m .41429 .79248 L .35504 .77631 L p .782 .357 .239 r
F P
0 g
s
.41429 .79248 m .42375 .81523 L .48056 .82864 L p .749 .338 .271 r
F P
0 g
s
.22347 .56287 m .21947 .60362 L .26877 .65357 L p .961 .707 .507 r
F P
0 g
s
.27267 .68936 m .26877 .65357 L .21947 .60362 L p .961 .645 .377 r
F P
0 g
s
.82842 .59229 m .83246 .63391 L .82218 .57384 L p .782 .568 0 r
F P
0 g
s
.82218 .57384 m .8184 .53437 L .82842 .59229 L p .782 .568 0 r
F P
0 g
s
.43045 .31485 m .4541 .32107 L .49436 .31484 L p .446 .839 .981 r
F P
0 g
s
.4541 .32107 m .43045 .31485 L .38664 .33545 L p .643 .899 .984 r
F P
0 g
s
.27267 .68936 m .28362 .72315 L .34398 .74876 L p .872 .528 .396 r
F P
0 g
s
.35504 .77631 m .34398 .74876 L .28362 .72315 L p .854 .451 .272 r
F P
0 g
s
.69325 .81998 m .67328 .83839 L .72512 .81439 L p 0 0 0 r
F P
0 g
s
.72512 .81439 m .75395 .79216 L .69325 .81998 L p 0 0 0 r
F P
0 g
s
.54013 .85369 m .54235 .84038 L .48056 .82864 L p .62 .12 .043 r
F P
0 g
s
.54235 .84038 m .54013 .85369 L .59609 .85681 L p .494 0 0 r
F P
0 g
s
.59609 .85681 m .60859 .84575 L .54235 .84038 L p .494 0 0 r
F P
0 g
s
.35268 .33989 m .38664 .33545 L .43045 .31485 L p .558 .924 .941 r
F P
0 g
s
.57693 .3268 m .59129 .32763 L .53989 .31469 L p .037 .576 .849 r
F P
0 g
s
.53989 .31469 m .53681 .31755 L .57693 .3268 L p .037 .576 .849 r
F P
0 g
s
.48646 .84472 m .48056 .82864 L .42375 .81523 L p .682 .19 .073 r
F P
0 g
s
.48056 .82864 m .48646 .84472 L .54013 .85369 L p .62 .12 .043 r
F P
0 g
s
.25422 .42612 m .23009 .45904 L .23679 .52396 L p .973 .916 .684 r
F P
0 g
s
.22347 .56287 m .23679 .52396 L .23009 .45904 L p .983 .881 .526 r
F P
0 g
s
.48443 .30889 m .49436 .31484 L .53681 .31755 L p .213 .709 .917 r
F P
0 g
s
.49436 .31484 m .48443 .30889 L .43045 .31485 L p .446 .839 .981 r
F P
0 g
s
.60859 .84575 m .59609 .85681 L .64912 .84966 L p .225 0 0 r
F P
0 g
s
.64912 .84966 m .67328 .83839 L .60859 .84575 L p .225 0 0 r
F P
0 g
s
.53681 .31755 m .53989 .31469 L .48443 .30889 L p .213 .709 .917 r
F P
0 g
s
.77594 .76322 m .75395 .79216 L .78526 .74686 L p .619 .842 .459 r
F P
0 g
s
.78526 .74686 m .81042 .7129 L .77594 .76322 L p .619 .842 .459 r
F P
0 g
s
.78596 .46423 m .80604 .49745 L .76066 .45357 L p .835 .385 0 r
F P
0 g
s
.76066 .45357 m .7458 .42445 L .78596 .46423 L p .835 .385 0 r
F P
0 g
s
.35268 .33989 m .32125 .35188 L .28552 .40009 L p .798 .99 .884 r
F P
0 g
s
.25422 .42612 m .28552 .40009 L .32125 .35188 L p .752 .981 .739 r
F P
0 g
s
.70029 .38042 m .72552 .39988 L .67395 .37325 L p .642 .087 0 r
F P
0 g
s
.67395 .37325 m .65683 .35602 L .70029 .38042 L p .642 .087 0 r
F P
0 g
s
.21947 .60362 m .22531 .64459 L .27267 .68936 L p .961 .645 .377 r
F P
0 g
s
.28362 .72315 m .27267 .68936 L .22531 .64459 L p .925 .535 .187 r
F P
0 g
s
.60348 .33619 m .59129 .32763 L .63588 .34491 L p .444 0 0 r
F P
0 g
s
.83246 .63391 m .82642 .67471 L .8169 .61449 L p .948 .787 .331 r
F P
0 g
s
.8169 .61449 m .82218 .57384 L .83246 .63391 L p .948 .787 .331 r
F P
0 g
s
.35504 .77631 m .37122 .80043 L .42375 .81523 L p .782 .357 .239 r
F P
0 g
s
.43698 .83329 m .42375 .81523 L .37122 .80043 L p .706 .195 .015 r
F P
0 g
s
.42375 .81523 m .43698 .83329 L .48646 .84472 L p .682 .19 .073 r
F P
0 g
s
.28362 .72315 m .30157 .75394 L .35504 .77631 L p .854 .451 .272 r
F P
0 g
s
.37122 .80043 m .35504 .77631 L .30157 .75394 L p .798 .319 .077 r
F P
0 g
s
.23009 .45904 m .21505 .49797 L .22347 .56287 L p .983 .881 .526 r
F P
0 g
s
.21947 .60362 m .22347 .56287 L .21505 .49797 L p .911 .753 .261 r
F P
0 g
s
.408 .31556 m .43045 .31485 L .48443 .30889 L p .151 .694 .781 r
F P
0 g
s
.43045 .31485 m .408 .31556 L .35268 .33989 L p .558 .924 .941 r
F P
0 g
s
.32125 .35188 m .35268 .33989 L .408 .31556 L p .338 .806 .715 r
F P
0 g
s
.67328 .83839 m .64912 .84966 L .69092 .82956 L p .314 .782 .666 r
F P
0 g
s
.69092 .82956 m .72512 .81439 L .67328 .83839 L p .314 .782 .666 r
F P
0 g
s
.53736 .85991 m .54013 .85369 L .48646 .84472 L p .421 0 0 r
F P
0 g
s
.54013 .85369 m .53736 .85991 L .58126 .8607 L p .249 0 0 r
F P
0 g
s
.59609 .85681 m .54013 .85369 L p .57309 .85931 L .249 0 0 r
F P
0 g
s
.53408 .85791 m .56442 .85704 L p .54258 .85936 L .138 .674 .849 r
F P
0 g
s
.53736 .85991 m .53647 .85937 L p .54258 .85936 L .138 .674 .849 r
F P
0 g
s
.53647 .85937 m .53408 .85791 L p .54258 .85936 L .138 .674 .849 r
F P
0 g
s
.58126 .8607 m .58666 .85928 L p .57309 .85931 L .249 0 0 r
F P
0 g
s
.58666 .85928 m .59609 .85681 L p .57309 .85931 L .249 0 0 r
F P
0 g
s
.80604 .49745 m .8184 .53437 L .76972 .48661 L p .933 .554 .223 r
F P
0 g
s
.76972 .48661 m .76066 .45357 L .80604 .49745 L p .933 .554 .223 r
F P
0 g
s
.49414 .85395 m .48646 .84472 L .43698 .83329 L p .497 0 0 r
F P
0 g
s
.48646 .84472 m .49414 .85395 L .53736 .85991 L p .421 0 0 r
F P
0 g
s
.59129 .32763 m .60348 .33619 L .54257 .31977 L p .394 0 0 r
F P
0 g
s
.54257 .31977 m .53989 .31469 L .59129 .32763 L p .394 0 0 r
F P
0 g
s
.22531 .64459 m .24092 .68408 L .28362 .72315 L p .925 .535 .187 r
F P
0 g
s
.30157 .75394 m .28362 .72315 L .24092 .68408 L p .813 .349 0 r
F P
0 g
s
.72552 .39988 m .7458 .42445 L .68712 .39567 L p .805 .324 .062 r
F P
0 g
s
.68712 .39567 m .67395 .37325 L .72552 .39988 L p .805 .324 .062 r
F P
0 g
s
.75395 .79216 m .72512 .81439 L .75229 .77539 L p .758 .984 .744 r
F P
0 g
s
.75229 .77539 m .78526 .74686 L .75395 .79216 L p .758 .984 .744 r
F P
0 g
s
.32125 .35188 m .29408 .37219 L .25422 .42612 L p .752 .981 .739 r
F P
0 g
s
.23009 .45904 m .25422 .42612 L .29408 .37219 L p 0 0 0 r
F P
0 g
s
.59609 .85681 m .58126 .8607 L .62161 .8538 L p 0 0 0 r
F P
0 g
s
.62161 .8538 m .64912 .84966 L .59609 .85681 L p 0 0 0 r
F P
0 g
s
.47538 .31048 m .48443 .30889 L .53989 .31469 L p .199 0 0 r
F P
0 g
s
.48443 .30889 m .47538 .31048 L .408 .31556 L p .151 .694 .781 r
F P
0 g
s
.82642 .67471 m .81042 .7129 L .80255 .65483 L p .989 .886 .561 r
F P
0 g
s
.80255 .65483 m .8169 .61449 L .82642 .67471 L p .989 .886 .561 r
F P
0 g
s
.53989 .31469 m .54257 .31977 L .47538 .31048 L p .199 0 0 r
F P
0 g
s
.30157 .75394 m .3263 .78073 L .37122 .80043 L p .798 .319 .077 r
F P
0 g
s
.3928 .81991 m .37122 .80043 L .3263 .78073 L p .647 .088 0 r
F P
0 g
s
.37122 .80043 m .3928 .81991 L .43698 .83329 L p .706 .195 .015 r
F P
0 g
s
.65683 .35602 m .67395 .37325 L .61328 .35154 L p .693 .164 0 r
F P
0 g
s
.61328 .35154 m .60348 .33619 L .65683 .35602 L p .693 .164 0 r
F P
0 g
s
.45422 .84491 m .43698 .83329 L .3928 .81991 L p .489 0 0 r
F P
0 g
s
.43698 .83329 m .45422 .84491 L .49414 .85395 L p .497 0 0 r
F P
0 g
s
.21505 .49797 m .21057 .54136 L .21947 .60362 L p .911 .753 .261 r
F P
0 g
s
.22531 .64459 m .21947 .60362 L .21057 .54136 L p .7 .49 0 r
F P
0 g
s
.8184 .53437 m .82218 .57384 L .77266 .5229 L p .958 .649 .402 r
F P
0 g
s
.77266 .5229 m .76972 .48661 L .8184 .53437 L p .958 .649 .402 r
F P
0 g
s
.408 .31556 m .3876 .32407 L .32125 .35188 L p .338 .806 .715 r
F P
0 g
s
.3876 .32407 m .408 .31556 L .47538 .31048 L p .219 0 0 r
F P
0 g
s
.29408 .37219 m .32125 .35188 L .3876 .32407 L p 0 0 0 r
F P
0 g
s
.24092 .68408 m .26562 .72048 L .30157 .75394 L p .813 .349 0 r
F P
0 g
s
.3263 .78073 m .30157 .75394 L .26562 .72048 L p .582 .075 0 r
F P
0 g
s
.64912 .84966 m .62161 .8538 L .65283 .83784 L p .507 .908 .907 r
F P
0 g
s
.65283 .83784 m .69092 .82956 L .64912 .84966 L p .507 .908 .907 r
F P
0 g
s
.7458 .42445 m .76066 .45357 L .69645 .42239 L p .858 .453 .267 r
F P
0 g
s
.69645 .42239 m .68712 .39567 L .7458 .42445 L p .858 .453 .267 r
F P
0 g
s
.29408 .37219 m .27303 .40107 L .23009 .45904 L p 0 0 0 r
F P
0 g
s
.21505 .49797 m .23009 .45904 L .27303 .40107 L p 0 0 .008 r
F P
0 g
s
.72512 .81439 m .69092 .82956 L .71321 .79779 L p .784 .991 .884 r
F P
0 g
s
.71321 .79779 m .75229 .77539 L .72512 .81439 L p .784 .991 .884 r
F P
0 g
s
.81042 .7129 m .78526 .74686 L .77961 .69334 L p .968 .912 .7 r
F P
0 g
s
.77961 .69334 m .80255 .65483 L .81042 .7129 L p .968 .912 .7 r
F P
0 g
s
.60348 .33619 m .61328 .35154 L .54479 .33223 L p .636 .109 0 r
F P
0 g
s
.54479 .33223 m .54257 .31977 L .60348 .33619 L p .636 .109 0 r
F P
0 g
s
.53408 .85791 m .53736 .85991 L .49414 .85395 L p 0 .554 .774 r
F P
0 g
s
.56442 .85704 m .58126 .8607 L .53736 .85991 L p .138 .674 .849 r
F P
0 g
s
.50353 .8547 m .49414 .85395 L .45422 .84491 L p 0 .493 .752 r
F P
0 g
s
.49414 .85395 m .50353 .8547 L .53408 .85791 L p 0 .554 .774 r
F P
0 g
s
.3263 .78073 m .35731 .80259 L .3928 .81991 L p .647 .088 0 r
F P
0 g
s
.41977 .83339 m .3928 .81991 L .35731 .80259 L p .323 0 0 r
F P
0 g
s
.3928 .81991 m .41977 .83339 L .45422 .84491 L p .489 0 0 r
F P
0 g
s
.21057 .54136 m .21734 .58714 L .22531 .64459 L p .7 .49 0 r
F P
0 g
s
.24092 .68408 m .22531 .64459 L .21734 .58714 L p 0 0 .44 r
F P
0 g
s
.67395 .37325 m .68712 .39567 L .62069 .37254 L p .782 .34 .199 r
F P
0 g
s
.62069 .37254 m .61328 .35154 L .67395 .37325 L p .782 .34 .199 r
F P
0 g
s
.58126 .8607 m .56442 .85704 L .59154 .85108 L p .367 .817 .942 r
F P
0 g
s
.59154 .85108 m .62161 .8538 L .58126 .8607 L p .367 .817 .942 r
F P
0 g
s
.46748 .31981 m .47538 .31048 L .54257 .31977 L p .503 0 0 r
F P
0 g
s
.47538 .31048 m .46748 .31981 L .3876 .32407 L p .219 0 0 r
F P
0 g
s
.54257 .31977 m .54479 .33223 L .46748 .31981 L p .503 0 0 r
F P
0 g
s
.82218 .57384 m .8169 .61449 L .76919 .5617 L p .953 .703 .522 r
F P
0 g
s
.76919 .5617 m .77266 .5229 L .82218 .57384 L p .953 .703 .522 r
F P
0 g
s
.47532 .84841 m .45422 .84491 L .41977 .83339 L p 0 .499 .804 r
F P
0 g
s
.45422 .84491 m .47532 .84841 L .50353 .8547 L p 0 .493 .752 r
F P
0 g
s
.26562 .72048 m .29821 .75248 L .3263 .78073 L p .582 .075 0 r
F P
0 g
s
.35731 .80259 m .3263 .78073 L .29821 .75248 L p 0 .229 .707 r
F P
0 g
s
.76066 .45357 m .76972 .48661 L .70208 .45275 L p .872 .526 .394 r
F P
0 g
s
.70208 .45275 m .69645 .42239 L .76066 .45357 L p .872 .526 .394 r
F P
0 g
s
.78526 .74686 m .75229 .77539 L .74896 .72865 L p .926 .908 .785 r
F P
0 g
s
.74896 .72865 m .77961 .69334 L .78526 .74686 L p .926 .908 .785 r
F P
0 g
s
.3876 .32407 m .37023 .34104 L .29408 .37219 L p 0 0 0 r
F P
0 g
s
.27303 .40107 m .29408 .37219 L .37023 .34104 L p .246 0 .101 r
F P
0 g
s
.27303 .40107 m .25987 .438 L .21505 .49797 L p 0 0 .008 r
F P
0 g
s
.21057 .54136 m .21505 .49797 L .25987 .438 L p .013 0 .33 r
F P
0 g
s
.62161 .8538 m .59154 .85108 L .61214 .83971 L p .592 .903 .984 r
F P
0 g
s
.61214 .83971 m .65283 .83784 L .62161 .8538 L p .592 .903 .984 r
F P
0 g
s
.69092 .82956 m .65283 .83784 L .66973 .81385 L p .762 .949 .938 r
F P
0 g
s
.66973 .81385 m .71321 .79779 L .69092 .82956 L p .762 .949 .938 r
F P
0 g
s
.37023 .34104 m .3876 .32407 L .46748 .31981 L p .451 0 .041 r
F P
0 g
s
.21734 .58714 m .23511 .63295 L .24092 .68408 L p 0 0 .44 r
F P
0 g
s
.26562 .72048 m .24092 .68408 L .23511 .63295 L p 0 .125 .669 r
F P
0 g
s
.61328 .35154 m .62069 .37254 L .54652 .35128 L p .73 .291 .207 r
F P
0 g
s
.54652 .35128 m .54479 .33223 L .61328 .35154 L p .73 .291 .207 r
F P
0 g
s
.68712 .39567 m .69645 .42239 L .62586 .3981 L p .811 .435 .344 r
F P
0 g
s
.62586 .3981 m .62069 .37254 L .68712 .39567 L p .811 .435 .344 r
F P
0 g
s
.35731 .80259 m .39388 .81867 L .41977 .83339 L p .323 0 0 r
F P
0 g
s
.45171 .83957 m .41977 .83339 L .39388 .81867 L p .09 .563 .906 r
F P
0 g
s
.41977 .83339 m .45171 .83957 L .47532 .84841 L p 0 .499 .804 r
F P
0 g
s
.8169 .61449 m .80255 .65483 L .75905 .60218 L p .936 .736 .609 r
F P
0 g
s
.75905 .60218 m .76919 .5617 L .8169 .61449 L p .936 .736 .609 r
F P
0 g
s
.53035 .84685 m .53408 .85791 L .50353 .8547 L p .376 .764 .989 r
F P
0 g
s
.53408 .85791 m .53035 .84685 L .54596 .84561 L p .437 .799 .996 r
F P
0 g
s
.54596 .84561 m .56442 .85704 L .53408 .85791 L p .437 .799 .996 r
F P
0 g
s
.51441 .84571 m .50353 .8547 L .47532 .84841 L p .347 .74 .985 r
F P
0 g
s
.50353 .8547 m .51441 .84571 L .53035 .84685 L p .376 .764 .989 r
F P
0 g
s
.29821 .75248 m .33715 .77913 L .35731 .80259 L p 0 .229 .707 r
F P
0 g
s
.39388 .81867 m .35731 .80259 L .33715 .77913 L p .058 .471 .886 r
F P
0 g
s
.76972 .48661 m .77266 .5229 L .70407 .48637 L p .872 .574 .48 r
F P
0 g
s
.70407 .48637 m .70208 .45275 L .76972 .48661 L p .872 .574 .48 r
F P
0 g
s
.56442 .85704 m .54596 .84561 L .5596 .84186 L p .527 .836 .999 r
F P
0 g
s
.5596 .84186 m .59154 .85108 L .56442 .85704 L p .527 .836 .999 r
F P
0 g
s
.54479 .33223 m .54652 .35128 L .461 .33684 L p .639 .186 .16 r
F P
0 g
s
.461 .33684 m .46748 .31981 L .54479 .33223 L p .639 .186 .16 r
F P
0 g
s
.75229 .77539 m .71321 .79779 L .71181 .75961 L p .878 .891 .839 r
F P
0 g
s
.71181 .75961 m .74896 .72865 L .75229 .77539 L p .878 .891 .839 r
F P
0 g
s
.46748 .31981 m .461 .33684 L .37023 .34104 L p .451 0 .041 r
F P
0 g
s
.4997 .84246 m .47532 .84841 L .45171 .83957 L p .352 .726 .987 r
F P
0 g
s
.47532 .84841 m .4997 .84246 L .51441 .84571 L p .347 .74 .985 r
F P
0 g
s
.23511 .63295 m .26271 .67648 L .26562 .72048 L p 0 .125 .669 r
F P
0 g
s
.29821 .75248 m .26562 .72048 L .26271 .67648 L p .105 .328 .8 r
F P
0 g
s
.65283 .83784 m .61214 .83971 L .62337 .82376 L p .727 .897 .956 r
F P
0 g
s
.62337 .82376 m .66973 .81385 L .65283 .83784 L p .727 .897 .956 r
F P
0 g
s
.25987 .438 m .25594 .48165 L .21057 .54136 L p .013 0 .33 r
F P
0 g
s
.21734 .58714 m .21057 .54136 L .25594 .48165 L p .194 .111 .528 r
F P
0 g
s
.59154 .85108 m .5596 .84186 L .56978 .83576 L p .62 .855 .988 r
F P
0 g
s
.56978 .83576 m .61214 .83971 L .59154 .85108 L p .62 .855 .988 r
F P
0 g
s
.80255 .65483 m .77961 .69334 L .74214 .64329 L p .913 .758 .675 r
F P
0 g
s
.74214 .64329 m .75905 .60218 L .80255 .65483 L p .913 .758 .675 r
F P
0 g
s
.37023 .34104 m .35694 .36671 L .27303 .40107 L p .246 0 .101 r
F P
0 g
s
.25987 .438 m .27303 .40107 L .35694 .36671 L p .388 .093 .338 r
F P
0 g
s
.69645 .42239 m .70208 .45275 L .62897 .42747 L p .82 .493 .435 r
F P
0 g
s
.62897 .42747 m .62586 .3981 L .69645 .42239 L p .82 .493 .435 r
F P
0 g
s
.62069 .37254 m .62586 .3981 L .54776 .37609 L p .768 .395 .349 r
F P
0 g
s
.54776 .37609 m .54652 .35128 L .62069 .37254 L p .768 .395 .349 r
F P
0 g
s
.39388 .81867 m .43507 .8283 L .45171 .83957 L p .09 .563 .906 r
F P
0 g
s
.4877 .83742 m .45171 .83957 L .43507 .8283 L p .394 .719 .988 r
F P
0 g
s
.45171 .83957 m .4877 .83742 L .4997 .84246 L p .352 .726 .987 r
F P
0 g
s
.33715 .77913 m .38082 .79993 L .39388 .81867 L p .058 .471 .886 r
F P
0 g
s
.43507 .8283 m .39388 .81867 L .38082 .79993 L p .296 .624 .96 r
F P
0 g
s
.35694 .36671 m .37023 .34104 L .461 .33684 L p .56 .178 .275 r
F P
0 g
s
.71321 .79779 m .66973 .81385 L .66956 .78536 L p .828 .869 .875 r
F P
0 g
s
.66956 .78536 m .71181 .75961 L .71321 .79779 L p .828 .869 .875 r
F P
0 g
s
.77266 .5229 m .76919 .5617 L .70227 .52307 L p .868 .609 .545 r
F P
0 g
s
.70227 .52307 m .70407 .48637 L .77266 .5229 L p .868 .609 .545 r
F P
0 g
s
.26271 .67648 m .29828 .71584 L .29821 .75248 L p .105 .328 .8 r
F P
0 g
s
.33715 .77913 m .29821 .75248 L .29828 .71584 L p .259 .469 .873 r
F P
0 g
s
.61214 .83971 m .56978 .83576 L .57529 .82784 L p .689 .846 .958 r
F P
0 g
s
.57529 .82784 m .62337 .82376 L .61214 .83971 L p .689 .846 .958 r
F P
0 g
s
.52632 .82641 m .53035 .84685 L .51441 .84571 L closepath p .572 .784 .979 r
F P
0 g
s
.52632 .82641 m .54596 .84561 L .53035 .84685 L closepath p .58 .79 .979 r
F P
0 g
s
.77961 .69334 m .74896 .72865 L .71851 .68381 L p .887 .772 .729 r
F P
0 g
s
.71851 .68381 m .74214 .64329 L .77961 .69334 L p .887 .772 .729 r
F P
0 g
s
.54652 .35128 m .54776 .37609 L .45618 .36135 L p .697 .32 .329 r
F P
0 g
s
.45618 .36135 m .461 .33684 L .54652 .35128 L p .697 .32 .329 r
F P
0 g
s
.52632 .82641 m .51441 .84571 L .4997 .84246 L closepath p .57 .782 .979 r
F P
0 g
s
.25594 .48165 m .26185 .52991 L .21734 .58714 L p .194 .111 .528 r
F P
0 g
s
.23511 .63295 m .21734 .58714 L .26185 .52991 L p .312 .269 .649 r
F P
0 g
s
.52632 .82641 m .5596 .84186 L .54596 .84561 L closepath p .599 .798 .976 r
F P
0 g
s
.461 .33684 m .45618 .36135 L .35694 .36671 L p .56 .178 .275 r
F P
0 g
s
.66973 .81385 m .62337 .82376 L .62364 .80528 L p .778 .845 .902 r
F P
0 g
s
.62364 .80528 m .66956 .78536 L .66973 .81385 L p .778 .845 .902 r
F P
0 g
s
.52632 .82641 m .4997 .84246 L .4877 .83742 L closepath p .57 .78 .978 r
F P
0 g
s
.38082 .79993 m .42773 .81471 L .43507 .8283 L p .296 .624 .96 r
F P
0 g
s
.47967 .83096 m .43507 .8283 L .42773 .81471 L p .463 .714 .977 r
F P
0 g
s
.43507 .8283 m .47967 .83096 L .4877 .83742 L p .394 .719 .988 r
F P
0 g
s
.70208 .45275 m .70407 .48637 L .63012 .46031 L p .823 .533 .499 r
F P
0 g
s
.63012 .46031 m .62897 .42747 L .70208 .45275 L p .823 .533 .499 r
F P
0 g
s
.29828 .71584 m .33961 .74975 L .33715 .77913 L p .259 .469 .873 r
F P
0 g
s
.38082 .79993 m .33715 .77913 L .33961 .74975 L p .374 .571 .915 r
F P
0 g
s
.52632 .82641 m .56978 .83576 L .5596 .84186 L closepath p .626 .802 .967 r
F P
0 g
s
.62586 .3981 m .62897 .42747 L .54851 .40594 L p .784 .46 .441 r
F P
0 g
s
.54851 .40594 m .54776 .37609 L .62586 .3981 L p .784 .46 .441 r
F P
0 g
s
.76919 .5617 m .75905 .60218 L .69634 .56265 L p .861 .639 .599 r
F P
0 g
s
.69634 .56265 m .70227 .52307 L .76919 .5617 L p .861 .639 .599 r
F P
0 g
s
.52632 .82641 m .4877 .83742 L .47967 .83096 L closepath p .571 .775 .975 r
F P
0 g
s
.35694 .36671 m .34867 .40076 L .25987 .438 L p .388 .093 .338 r
F P
0 g
s
.25594 .48165 m .25987 .438 L .34867 .40076 L p .469 .239 .482 r
F P
0 g
s
.74896 .72865 m .71181 .75961 L .68855 .72231 L p .858 .782 .776 r
F P
0 g
s
.68855 .72231 m .71851 .68381 L .74896 .72865 L p .858 .782 .776 r
F P
0 g
s
.52632 .82641 m .57529 .82784 L .56978 .83576 L closepath p .651 .799 .953 r
F P
0 g
s
.62337 .82376 m .57529 .82784 L .57546 .81903 L p .725 .818 .923 r
F P
0 g
s
.57546 .81903 m .62364 .80528 L .62337 .82376 L p .725 .818 .923 r
F P
0 g
s
.33961 .74975 m .38458 .77764 L .38082 .79993 L p .374 .571 .915 r
F P
0 g
s
.42773 .81471 m .38082 .79993 L .38458 .77764 L p .463 .647 .938 r
F P
0 g
s
.26185 .52991 m .27736 .58019 L .23511 .63295 L p .312 .269 .649 r
F P
0 g
s
.26271 .67648 m .23511 .63295 L .27736 .58019 L p .393 .383 .729 r
F P
0 g
s
.42773 .81471 m .47657 .8235 L .47967 .83096 L p .463 .714 .977 r
F P
0 g
s
.52632 .82641 m .47967 .83096 L .47657 .8235 L closepath p .58 .766 .967 r
F P
0 g
s
.34867 .40076 m .35694 .36671 L .45618 .36135 L p .613 .301 .417 r
F P
0 g
s
.71181 .75961 m .66956 .78536 L .65301 .75724 L p .824 .787 .817 r
F P
0 g
s
.65301 .75724 m .68855 .72231 L .71181 .75961 L p .824 .787 .817 r
F P
0 g
s
.70407 .48637 m .70227 .52307 L .62923 .4966 L p .822 .565 .551 r
F P
0 g
s
.62923 .4966 m .63012 .46031 L .70407 .48637 L p .822 .565 .551 r
F P
0 g
s
.52632 .82641 m .57546 .81903 L .57529 .82784 L closepath p .667 .788 .939 r
F P
0 g
s
.38458 .77764 m .43143 .7995 L .42773 .81471 L p .463 .647 .938 r
F P
0 g
s
.47657 .8235 m .42773 .81471 L .43143 .7995 L p .535 .708 .95 r
F P
0 g
s
.75905 .60218 m .74214 .64329 L .68577 .60471 L p .852 .665 .648 r
F P
0 g
s
.68577 .60471 m .69634 .56265 L .75905 .60218 L p .852 .665 .648 r
F P
0 g
s
.54776 .37609 m .54851 .40594 L .45322 .39284 L p .724 .404 .437 r
F P
0 g
s
.45322 .39284 m .45618 .36135 L .54776 .37609 L p .724 .404 .437 r
F P
0 g
s
.43143 .7995 m .47892 .81564 L .47657 .8235 L p .535 .708 .95 r
F P
0 g
s
.52632 .82641 m .47657 .8235 L .47892 .81564 L closepath p .597 .757 .955 r
F P
0 g
s
.62897 .42747 m .63012 .46031 L .54877 .44038 L p .79 .506 .507 r
F P
0 g
s
.54877 .44038 m .54851 .40594 L .62897 .42747 L p .79 .506 .507 r
F P
0 g
s
.66956 .78536 m .62364 .80528 L .61306 .78707 L p .785 .789 .856 r
F P
0 g
s
.61306 .78707 m .65301 .75724 L .66956 .78536 L p .785 .789 .856 r
F P
0 g
s
.52632 .82641 m .56022 .80331 L .57024 .81047 L closepath p .673 .769 .922 r
F P
0 g
s
.52632 .82641 m .54646 .79851 L .56022 .80331 L closepath p .672 .766 .921 r
F P
0 g
s
.52632 .82641 m .53045 .79666 L .54646 .79851 L closepath p .671 .764 .92 r
F P
0 g
s
.52632 .82641 m .51392 .79791 L .53045 .79666 L closepath p .668 .761 .92 r
F P
0 g
s
.52632 .82641 m .49871 .80196 L .51392 .79791 L closepath p .659 .756 .922 r
F P
0 g
s
.52632 .82641 m .48657 .80816 L .49871 .80196 L closepath p .642 .752 .929 r
F P
0 g
s
.52632 .82641 m .47892 .81564 L .48657 .80816 L closepath p .62 .752 .94 r
F P
0 g
s
.52632 .82641 m .57024 .81047 L .57546 .81903 L closepath p .673 .776 .928 r
F P
0 g
s
.45618 .36135 m .45322 .39284 L .34867 .40076 L p .613 .301 .417 r
F P
0 g
s
.27736 .58019 m .30139 .62981 L .26271 .67648 L p .393 .383 .729 r
F P
0 g
s
.29828 .71584 m .26271 .67648 L .30139 .62981 L p .453 .47 .786 r
F P
0 g
s
.62364 .80528 m .57546 .81903 L .57024 .81047 L p .736 .786 .893 r
F P
0 g
s
.57024 .81047 m .61306 .78707 L .62364 .80528 L p .736 .786 .893 r
F P
0 g
s
.34867 .40076 m .34614 .44218 L .25594 .48165 L p .469 .239 .482 r
F P
0 g
s
.26185 .52991 m .25594 .48165 L .34614 .44218 L p .519 .339 .577 r
F P
0 g
s
.74214 .64329 m .71851 .68381 L .67011 .64836 L p .84 .688 .694 r
F P
0 g
s
.67011 .64836 m .68577 .60471 L .74214 .64329 L p .84 .688 .694 r
F P
0 g
s
.4464 .78419 m .48657 .80816 L .47892 .81564 L p .596 .704 .919 r
F P
0 g
s
.47892 .81564 m .43143 .7995 L .4464 .78419 L p .596 .704 .919 r
F P
0 g
s
.70227 .52307 m .69634 .56265 L .62605 .53644 L p .819 .593 .596 r
F P
0 g
s
.62605 .53644 m .62923 .4966 L .70227 .52307 L p .819 .593 .596 r
F P
0 g
s
.30139 .62981 m .33223 .6764 L .29828 .71584 L p .453 .47 .786 r
F P
0 g
s
.33961 .74975 m .29828 .71584 L .33223 .6764 L p .5 .54 .83 r
F P
0 g
s
.61306 .78707 m .57024 .81047 L .56022 .80331 L p .735 .76 .873 r
F P
0 g
s
.40647 .75424 m .4464 .78419 L .43143 .7995 L p .569 .655 .894 r
F P
0 g
s
.43143 .7995 m .38458 .77764 L .40647 .75424 L p .569 .655 .894 r
F P
0 g
s
.33223 .6764 m .3679 .7182 L .33961 .74975 L p .5 .54 .83 r
F P
0 g
s
.38458 .77764 m .33961 .74975 L .3679 .7182 L p .538 .601 .865 r
F P
0 g
s
.3679 .7182 m .40647 .75424 L .38458 .77764 L p .538 .601 .865 r
F P
0 g
s
.71851 .68381 m .68855 .72231 L .64918 .69217 L p .825 .71 .738 r
F P
0 g
s
.64918 .69217 m .67011 .64836 L .71851 .68381 L p .825 .71 .738 r
F P
0 g
s
.34614 .44218 m .34867 .40076 L .45322 .39284 L p .643 .383 .51 r
F P
0 g
s
.47089 .7709 m .49871 .80196 L .48657 .80816 L p .643 .706 .893 r
F P
0 g
s
.48657 .80816 m .4464 .78419 L .47089 .7709 L p .643 .706 .893 r
F P
0 g
s
.63012 .46031 m .62923 .4966 L .54852 .47909 L p .792 .542 .559 r
F P
0 g
s
.54852 .47909 m .54877 .44038 L .63012 .46031 L p .792 .542 .559 r
F P
0 g
s
.54851 .40594 m .54877 .44038 L .45227 .43063 L p .737 .462 .512 r
F P
0 g
s
.45227 .43063 m .45322 .39284 L .54851 .40594 L p .737 .462 .512 r
F P
0 g
s
.56022 .80331 m .59311 .77194 L .61306 .78707 L p .735 .76 .873 r
F P
0 g
s
.59311 .77194 m .56022 .80331 L .54646 .79851 L p .727 .743 .864 r
F P
0 g
s
.65301 .75724 m .61306 .78707 L .59311 .77194 L p .775 .746 .827 r
F P
0 g
s
.68855 .72231 m .65301 .75724 L .62323 .73413 L p .804 .729 .782 r
F P
0 g
s
.62323 .73413 m .64918 .69217 L .68855 .72231 L p .804 .729 .782 r
F P
0 g
s
.59311 .77194 m .62323 .73413 L .65301 .75724 L p .775 .746 .827 r
F P
0 g
s
.50158 .76181 m .51392 .79791 L .49871 .80196 L p .677 .713 .875 r
F P
0 g
s
.49871 .80196 m .47089 .7709 L .50158 .76181 L p .677 .713 .875 r
F P
0 g
s
.69634 .56265 m .68577 .60471 L .6202 .57968 L p .814 .619 .639 r
F P
0 g
s
.6202 .57968 m .62605 .53644 L .69634 .56265 L p .814 .619 .639 r
F P
0 g
s
.54646 .79851 m .56604 .76203 L .59311 .77194 L p .727 .743 .864 r
F P
0 g
s
.56604 .76203 m .54646 .79851 L .53045 .79666 L p .717 .731 .862 r
F P
0 g
s
.34614 .44218 m .34973 .48933 L .26185 .52991 L p .519 .339 .577 r
F P
0 g
s
.27736 .58019 m .26185 .52991 L .34973 .48933 L p .554 .414 .645 r
F P
0 g
s
.45322 .39284 m .45227 .43063 L .34614 .44218 L p .643 .383 .51 r
F P
0 g
s
.53451 .75859 m .53045 .79666 L .51392 .79791 L p .701 .722 .866 r
F P
0 g
s
.51392 .79791 m .50158 .76181 L .53451 .75859 L p .701 .722 .866 r
F P
0 g
s
.53045 .79666 m .53451 .75859 L .56604 .76203 L p .717 .731 .862 r
F P
0 g
s
.44361 .73354 m .47089 .7709 L .4464 .78419 L p .638 .662 .857 r
F P
0 g
s
.4464 .78419 m .40647 .75424 L .44361 .73354 L p .638 .662 .857 r
F P
0 g
s
.62923 .4966 m .62605 .53644 L .54772 .52178 L p .79 .571 .604 r
F P
0 g
s
.54772 .52178 m .54852 .47909 L .62923 .4966 L p .79 .571 .604 r
F P
0 g
s
.62323 .73413 m .59311 .77194 L .56604 .76203 L p .76 .719 .814 r
F P
0 g
s
.68577 .60471 m .67011 .64836 L .61131 .62564 L p .807 .645 .681 r
F P
0 g
s
.61131 .62564 m .6202 .57968 L .68577 .60471 L p .807 .645 .681 r
F P
0 g
s
.54877 .44038 m .54852 .47909 L .45345 .47377 L p .744 .505 .57 r
F P
0 g
s
.45345 .47377 m .45227 .43063 L .54877 .44038 L p .744 .505 .57 r
F P
0 g
s
.34973 .48933 m .35936 .54007 L .27736 .58019 L p .554 .414 .645 r
F P
0 g
s
.30139 .62981 m .27736 .58019 L .35936 .54007 L p .58 .475 .699 r
F P
0 g
s
.34973 .48933 m .34614 .44218 L .45227 .43063 L p .66 .443 .578 r
F P
0 g
s
.41774 .69051 m .44361 .73354 L .40647 .75424 L p .629 .619 .821 r
F P
0 g
s
.40647 .75424 m .3679 .7182 L .41774 .69051 L p .629 .619 .821 r
F P
0 g
s
.64918 .69217 m .62323 .73413 L .58391 .71925 L p .782 .694 .767 r
F P
0 g
s
.56604 .76203 m .58391 .71925 L .62323 .73413 L p .76 .719 .814 r
F P
0 g
s
.67011 .64836 m .64918 .69217 L .59917 .6729 L p .797 .67 .724 r
F P
0 g
s
.59917 .6729 m .61131 .62564 L .67011 .64836 L p .797 .67 .724 r
F P
0 g
s
.4898 .71934 m .50158 .76181 L .47089 .7709 L p .686 .674 .832 r
F P
0 g
s
.47089 .7709 m .44361 .73354 L .4898 .71934 L p .686 .674 .832 r
F P
0 g
s
.58391 .71925 m .56604 .76203 L .53451 .75859 L p .743 .701 .812 r
F P
0 g
s
.58391 .71925 m .59917 .6729 L .64918 .69217 L p .782 .694 .767 r
F P
0 g
s
.62605 .53644 m .6202 .57968 L .54632 .56794 L p .786 .597 .645 r
F P
0 g
s
.54632 .56794 m .54772 .52178 L .62605 .53644 L p .786 .597 .645 r
F P
0 g
s
.45227 .43063 m .45345 .47377 L .34973 .48933 L p .66 .443 .578 r
F P
0 g
s
.35936 .54007 m .37452 .592 L .30139 .62981 L p .58 .475 .699 r
F P
0 g
s
.33223 .6764 m .30139 .62981 L .37452 .592 L p .6 .527 .744 r
F P
0 g
s
.39433 .64282 m .41774 .69051 L .3679 .7182 L p .617 .575 .784 r
F P
0 g
s
.3679 .7182 m .33223 .6764 L .39433 .64282 L p .617 .575 .784 r
F P
0 g
s
.53451 .75859 m .53828 .71423 L .58391 .71925 L p .743 .701 .812 r
F P
0 g
s
.53828 .71423 m .53451 .75859 L .50158 .76181 L p .719 .687 .818 r
F P
0 g
s
.50158 .76181 m .4898 .71934 L .53828 .71423 L p .719 .687 .818 r
F P
0 g
s
.37452 .592 m .39433 .64282 L .33223 .6764 L p .6 .527 .744 r
F P
0 g
s
.54852 .47909 m .54772 .52178 L .45679 .52108 L p .746 .541 .617 r
F P
0 g
s
.45679 .52108 m .45345 .47377 L .54852 .47909 L p .746 .541 .617 r
F P
0 g
s
.59917 .6729 m .58391 .71925 L .53828 .71423 L p .759 .673 .767 r
F P
0 g
s
.6202 .57968 m .61131 .62564 L .54427 .61656 L p .78 .622 .685 r
F P
0 g
s
.54427 .61656 m .54632 .56794 L .6202 .57968 L p .78 .622 .685 r
F P
0 g
s
.35936 .54007 m .34973 .48933 L .45345 .47377 L p .672 .49 .631 r
F P
0 g
s
.47905 .67214 m .4898 .71934 L .44361 .73354 L p .689 .637 .793 r
F P
0 g
s
.44361 .73354 m .41774 .69051 L .47905 .67214 L p .689 .637 .793 r
F P
0 g
s
.61131 .62564 m .59917 .6729 L .54157 .66605 L p .771 .647 .725 r
F P
0 g
s
.54157 .66605 m .54427 .61656 L .61131 .62564 L p .771 .647 .725 r
F P
0 g
s
.53828 .71423 m .54157 .66605 L .59917 .6729 L p .759 .673 .767 r
F P
0 g
s
.54157 .66605 m .53828 .71423 L .4898 .71934 L p .73 .656 .775 r
F P
0 g
s
.45345 .47377 m .45679 .52108 L .35936 .54007 L p .672 .49 .631 r
F P
0 g
s
.54772 .52178 m .54632 .56794 L .46227 .57108 L p .745 .571 .659 r
F P
0 g
s
.46227 .57108 m .45679 .52108 L .54772 .52178 L p .745 .571 .659 r
F P
0 g
s
.4898 .71934 m .47905 .67214 L .54157 .66605 L p .73 .656 .775 r
F P
0 g
s
.46976 .62206 m .47905 .67214 L .41774 .69051 L p .688 .602 .755 r
F P
0 g
s
.41774 .69051 m .39433 .64282 L .46976 .62206 L p .688 .602 .755 r
F P
0 g
s
.37452 .592 m .35936 .54007 L .45679 .52108 L p .68 .531 .676 r
F P
0 g
s
.54632 .56794 m .54427 .61656 L .46976 .62206 L p .742 .599 .698 r
F P
0 g
s
.46976 .62206 m .46227 .57108 L .54632 .56794 L p .742 .599 .698 r
F P
0 g
s
.54427 .61656 m .54157 .66605 L .47905 .67214 L p .738 .627 .736 r
F P
0 g
s
.46227 .57108 m .46976 .62206 L .39433 .64282 L p .685 .568 .716 r
F P
0 g
s
.39433 .64282 m .37452 .592 L .46227 .57108 L p .685 .568 .716 r
F P
0 g
s
.45679 .52108 m .46227 .57108 L .37452 .592 L p .68 .531 .676 r
F P
0 g
s
.47905 .67214 m .46976 .62206 L .54427 .61656 L p .738 .627 .736 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool002?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`;o00004_ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0:Oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`00
8oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
G_ooool=o`0003_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0D_oo
ool;o`0000Co>00000?o0000oh000?n000000on0000<o`0003;ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Yooooo`00:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04_ooooo1_l0000>ocP00003o`000?n0003oP00000_oP0002ol0000/ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`17ooooo`?o00003Olh000:o`0001;oP0002?l0000Xooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`14ooooo`;o00000olh000=o`0000KoL`0:00Co0000oj<_:?nS;bSoXblX1_l0000>oh00
0003o`000?nR6`3oXQ/000Oo00009?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
02Oooooo000Yooooo`;o00006_ooool00ol0003oooooooooo`11ooooo`Oo00004_mc00X00ol0003o
XblXoj<_:008oj<_:0Oo00001on000000ol0003oXQ/0oj8K0004oj8K00Oo00008Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0?Oooool4o`0001SoL`0:00?o0000oj<_:?nS;bP03onS;bP6o`0000;oP000
00?o0000oj8K0?nR6`001onR6`06o`0001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03[ooooo1Ol0
000Iog<02P03o`000?nS;bSoXblX01GoXblX1Ol0000:oj8K00Ko00006oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0=_ooool7o`0001WoL`0:00?o0000oj<_:?nS;bP06?nS;bP00ol0003o^TXdokY:=003
o`0000_oXQ/01Ol0000Hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool0
02Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0cooooo`So00003?mc00XBo`00
01OoXblX00?o0000okY:=?njBS@00onjBS@4o`0000SoXQ/000?o0000ok4Y0?l000001?l0000Eoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0_oooooaOo00003_n?;DH01?l0003o/U5Dok9AE?nbDE@7o`00
013oXblX00?o0000okY:=?njBS@01onjBS@3o`0000KoXQ/000Co0000ok4Y0?na:@3o/BT01Ol0000B
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo0_l0000Qoooo
o`03o`000?oooooooooo02cooooo2_l000000oln01Wo0000ohl]AP0Johl]AP03o`000?nbDECo/U5D
00So/U5D1ol00009oj<_:003o`000?njBSCo^TXd00[o^TXd1?l00003oj8K0003o`000?na:@3o/BT0
00;o/BT01Ol0000@ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool002So
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Xooooo`[o00000oln01T00ol0003o
Sbe6ohl]AP0Johl]AP03o`000?nbDECo/U5D00oo/U5D1ol00002oj<_:003o`000?njBSCo^TXd00ko
^TXd1?l00007ok4Y00Co00003_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02;o
oooo000Xooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09Oooool:o`0000Go?P0I
00?o0000ohl]A_n?;DH06On?;DH00ol0003o/U5Dok9AE00Gok9AE0Go00004OnjBS@3o`0000Oo/BT0
0ol0000=ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08Oooool002Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`Wo00001_ln01T00ol0003oSbe6ohl]
AP0Johl]AP03o`000?nbDECo/U5D01Wo/U5D00?o0000olAUFOo4IET00ol0000?okY:=003o`000?o8
Ec;o000000;o00001_na:@03o`0000_ooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0Qooooo`009oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo027ooooo1ol00009
och06@03o`000?n?;DKoSbe601[oSbe600?o0000ok9AE?nbDE@06OnbDE@00ol0003oa6EIolAUF@03
olAUF@?o00003?njBS@00ol0003ob5LbolQG<P02olQG<P?o00001_na:@02o`0000Wooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo01kooooo1ol0000:och06@03o`000?n?;DKoSbe601?oSbe63?l0000Hok9A
E003o`000?o4IEWoa6EI00Koa6EI1?l00009okY:=003o`000?o8Ec;ob5Lb00Cob5Lb0ol00004ok4Y
00?o00001oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo023ooooo000Wooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool07?ooool5o`0000go?P0I00?o0000ohl]A_n?
;DH01?n?;DH?o`0000SoW4eZ00Co0000okUWKoniIfoo^FM_1_l0000Bok9AE003o`000?o4IEWoa6EI
00[oa6EI0ol00006okY:=003o`000?o8Ec;ob5Lb00Oob5Lb0_l00003ok4Y0004o`000?nT5P3o0000
o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`009oooool2o`00
02Wooooo00?o0000ooooooooool06_ooool4o`0000go?P0I2Ol0000Goia=JP03o`000?niIfoo^FM_
00Oo^FM_1_l0000=ok9AE003o`000?o4IEWoa6EI00coa6EI0ol00003okY:=003o`000?o8Ec;ob5Lb
00Wob5Lb0ol000001?na:@3o0000oj@F0?nT5P02o`0000?ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Nooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
01Sooooo0ol0000<och06@?o000000?oHaMFo`000?nLCFX07OnLCFX00ol0003o^FM_okUWK`0=okUW
K`Go00002?nbDE@00ol0003oa6EIolAUF@0?olAUF@?o000000?o^TXdo`000?o8Ec803?o8Ec83o`00
00?oY1H000Co0000oooooooooooo0000?oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000och06Oln01T02oln01T2o`00
00CoHaMF00?o0000oia=J_nLCFX07?nLCFX00ol0003o^FM_okUWK`0BokUWK`Ko00000_nbDE@00ol0
003oa6EIolAUF@0BolAUF@Co00003_o8Ec82o`0000;oY1H00ol00010ooooo`03o`000?oooooooooo
01gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05Oooool00ol0003o
?P0Ioch06@09och06@;o00001OmS5eH00ol0003oW4eZoia=JP0Moia=JP03o`000?niIfoo^FM_01So
^FM_1Ol0000ColAUF@03o`000?o?KeSocfmH00?o00002oo8Ec801?l0003ocU8?o`000?l00002oj@F
00;o0000?oooool00ol0003oooooooooo`0Mooooo`009_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01?ooooo00?o0000och06Oln01T01oln01T3o`0000OoHaMF00?o0000oia=J_nL
CFX07?nLCFX00ol0003o^FM_okUWK`0KokUWK`03o`000?o8MG3ob7E`00?o00004?o4IET00ol0003o
cfmHolm_F003olm_F0?o00002Oo8Ec800ol0003ocU8?oliB3`03o`000003oj@F0?l0003o000003ko
oooo00?o0000ooooooooool07?ooool002Kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?ln01Wo?P0I00Ko?P0I0_l0000:of<GEP03o`000?nLCF[oW4eZ01coW4eZ
00?o0000okUWKoniIfl06oniIfl00ol0003ob7E`olQeL003olQeL0Co00003Oo4IET00ol0003ocfmH
olm_F005olm_F0?o00001_o8Ec800ol0003ocU8?oliB3`02oliB3`;o00000_nT5P000ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo01_ooooo000Vooooo`?o0000;oooool00ol0003ooooooooo
o`0@ooooo`03o`000?ln01Wo?P0I00Co?P0I0_l0000;of<GEP03o`000?nLCF[oW4eZ01goW4eZ00?o
0000okUWKoniIfl06oniIfl00ol0003ob7E`olQeL007olQeL0?o00002_o4IET00ol0003ocfmHolm_
F008olm_F0?o00001?o8Ec800ol0003ocU8?oliB3`02oliB3`?o000000?oY1H0o`000?ooool0??oo
ool00ol0003oooooooooo`0Kooooo`009_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00kooooo00?o0000och06Oln01T00_ln01T3o`0000goHaMF00?o0000oia=J_nLCFX07OnLCFX0
0ol0003o^FM_okUWK`0KokUWK`03o`000?o8MG3ob7E`00[ob7E`0ol00007olAUF@03o`000?o?KeSo
cfmH00_ocfmH0ol00002olQG<P05o`000?o>DPoocU8?oliB3ol000000_o>DPl4o`0003cooooo00?o
0000ooooooooool06_ooool000_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0<ooooo`04o`000?ln01Wo?P0Ioch06@;o00004?mS5eH00ol0003oW4eZoia=JP0Hoia=JP[o
00006OniIfl00ol0003ob7E`olQeL00=olQeL0Co00000oo4IET00ol0003ocfmHolm_F00>olm_F0?o
00000oo>DPl00ol0003ocU8?oliB3`02oliB3`?o0000>oooool00ol0003oooooooooo`0Jooooo`00
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`;o000000?o?P0Io`000?l0
00004_mS5eH00ol0003oW4eZoia=JP0=oia=JP_o00001OnTHX800ol0003o_7J3okafP`02okafP`Oo
00004_niIfl00ol0003ob7E`olQeL00AolQeL0?o000000?oa6EIo`000?o?KeP04Oo?KeP2o`000003
oliB3ol0003ocU8?00GocU8?0_l0000kooooo`03o`000?oooooooooo01Wooooo0003ooooo`Ko0000
0_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00Wooooo0ol0000Cof<GEP03o`000?nLCF[oW4eZ00?o
W4eZ2ol0000@ojARPP03o`000?nlMX?o_7J300Wo_7J32?l0000:okUWK`03o`000?o8MG3ob7E`01Co
b7E`1?l0000@olm_F004o`000?oKLdCo0000o`0000SocU8?00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo00?o0000of<G
E_mS5eH04omS5eH7o`0001_oY6:200?o0000okafPonlMX<04OnlMX<7o`0000?o^FM_00?o0000olQe
L?o8MG005Oo8MG000ol0003odGi_om5nK`03o`0000kocfmH00?o0000om]cA?l000000_l00006oliB
3`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Gooooo0_l0000Bof<GEP?o000000?oN3eko`000?nTHX807onTHX80
0ol0003o_7J3okafP`0HokafP`Ko00005Oo8MG000ol0003odGi_om5nK`03om5nK`?o00002oo?KeP0
0ol0003ofg=4o`000002om]cA0;o00001Oo>DPl00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06
ooooo`;o0000>?ooool00ol0003oooooooooo`04ooooo`03o`000?mS5eKoHaMF00ooHaMF0_l00004
ogPmN`03o`000?nTHX;oY6:201koY6:200?o0000okafPonlMX<06onlMX<00ol0003obX61olZ1P@03
o`0001;ob7E`00?o0000om5nKooAOVl01_oAOVl3o`0000SocfmH00?o0000om]cA?l000001?oKLd@3
o`0000?ocU8?00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Gooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo00;ooooo0_l0000>of<GEP?o00001_mh?G/00ol0003oY6:2ojARPP0N
ojARPP03o`000?nlMX?o_7J301_o_7J300?o0000olZ1POo:PH400oo:PH44o`0000kob7E`00?o0000
om5nKooAOVl02OoAOVl3o`0000KocfmH0_l00007om]cA0;o00000_o>DPl00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02o`0000goHaMF0_l00009
ogPmN`03o`000?nTHX;oY6:201koY6:200?o0000okafPonlMX<06onlMX<00ol0003obX61olZ1P@07
olZ1P@Co00002oo8MG000ol0003odGi_om5nK`0;om5nK`?o00000oo?KeP2o`0000Wofg=40_l00000
0oo>DPoo0000ooooo`0gooooo`?o00005oooool002Cooooo00?o0000ooooooooool0>_ooool01Ol0
003oooooo`000?l000;o000000[oHaMF0ol0000;ogPmN`03o`000?nTHX;oY6:201koY6:200?o0000
okafPonlMX<06onlMX<00ol0003obX61olZ1P@0;olZ1P@?o00002?o8MG000ol0003odGi_om5nK`0>
om5nK`Go00002ooKLd@3o`0003Cooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`03o`000?oooooooooo03_ooooo0ol00008of<GEP?o00003_mh?G/00ol0003oY6:2ojARPP0NojAR
PP03o`000?nlMX?o_7J301_o_7J300?o0000olZ1POo:PH403_o:PH44o`0000Cob7E`00?o0000om5n
KooAOVl04OoAOVl3o`0000cofg=40_l0000`ooooo`?o00001Oooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`0kooooo`03o`000?l000;o000000KoHaMF0_l0000@ogPmN`03
o`000?nTHX;oY6:201ooY6:200?o0000okafPonlMX<06onlMX<00ol0003obX61olZ1P@0BolZ1P@?o
000000?ob7E`o`000?oAOVl04ooAOVl01?l0003oghITo`000?l0000<om]cA003o`000?oooooooooo
02[ooooo0ol00008ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03[o
oooo00Co0000o`000_l000;o00000omS5eH3o`0001;oN3ek00?o0000ojARP_nTHX807onTHX800ol0
003o_7J3okafP`0KokafP`03o`000?o:PH7obX6101GobX610ol0000Com5nK`04o`000?oOQVCoghIT
omn6I0;o00002_oKLd@2o`0002Sooooo0ol0000;ooooo`03o`000?oooooooooo01Gooooo000Toooo
o`;o0000>_ooool01?l0003o0002o`000_l00002of<GEP;o00005Omh?G/00ol0003oY6:2ojARPP0K
ojARPP[o00006?nlMX<00ol0003obX61olZ1P@0FolZ1P@03o`000?oBR7oo000000;o00004?oAOVl2
o`0000CoghIT0_l00009om]cA0;o00009?ooool3o`0000oooooo00?o0000ooooooooool05?ooool0
02Cooooo00?o0000ooooooooool0>Oooool00ol0003o0002o`000P03o`0001OoN3ek00?o0000ojAR
P_nTHX804_nTHX89o`0000CoZ76C00?o0000okj1TOnnPI400onnPI4:o`0000ko_7J300?o0000olZ1
POo:PH405_o:PH400ol0003odXQoom:8O`02om:8O`?o00003OoAOVl2o`0000KoghIT0_l00007om]c
A0?o00008?ooool3o`0001;ooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000oooooooo
ool0>Oooool01?l0003o0002o`000_l0000JogPmN`03o`000?nTHX;oY6:200[oY6:22?l0000=ojQa
T`03o`000?nnPI7o_X6A00go_X6A2_l00004okafP`03o`000?o:PH7obX6101KobX6100?o0000om:8
OooBR7l01OoBR7l3o`0000[odGi_0_l00008omn6I0;o00001_oKLd@3o`0001cooooo0ol0000Eoooo
o`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03Sooooo00Go0000o`000_l0
00;o0002o`00000JogPmN`04o`000?nTHX;oY6:2ojARPPWo00005OnXLI<00ol0003o_X6Aokj1T@0G
okj1T@Oo00005_o:PH400ol0003odXQoom:8O`08om:8O`?o00001ooAOVl2o`0000[oghIT0_l00004
om]cA003o`000?oEHP3o000001Wooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Soooo
o`03o`000?oooooooooo03Oooooo00Co0000o`000_l000;o00020_l0000IogPmN`Go00007_nXLI<0
0ol0003o_X6Aokj1T@0Kokj1T@03o`000?o:RXoobXZ?00Co00004_o:PH400ol0003odXQoom:8O`0;
om:8O`?o00001OoAOVl00ol0003oghITomn6I00:omn6I0;o00000_oKLd@01?l0003oeF80omER0?l0
000Eooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0f
ooooo`07o`000?l000;o0002o`000_l0003o0`1Do`00000FogPmN`?o000000?oQ5JCo`000?nXLI<0
8?nXLI<00ol0003o_X6Aokj1T@0Kokj1T@03o`000?o:RXoobXZ?00CobXZ?1?l0000>olZ1P@03o`00
0?oBR7oodXQo00kodXQo0ol00002om5nK`;o00003OoOQV@2o`000005om]cA?l0003oeF80omER0?l0
00004Oooool3o`0001kooooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0
=_ooool01?l0003o0002o`000_l00002o`<0E003o`000?mh?G_oN3ek01;oN3ek0_l00004ohAFT`03
o`000?nXLI?oZ76C01ooZ76C00?o0000okj1TOnnPI406onnPI400ol0003obXZ?olZ:S`08olZ:S`Go
00002Oo:PH400ol0003odXQoom:8O`0Aom:8O`Co00003ooOQV@2o`0000?oeF8000?o0000oooooooo
ool02oooool3o`00027ooooo00?o0000ooooooooool05?ooool002?ooooo0_l0000fooooo`05o`00
0?l000;o0002o`000_l000000_l305@00ol0003oN3ekogPmN`0@ogPmN`;o00001_n4EY<00ol0003o
Z76CojQaT`0OojQaT`03o`000?nnPI7o_X6A01_o_X6A00?o0000olZ:Soo:RXl03Oo:RXl4o`0000Go
bX6100?o0000om:8OooBR7l04ooBR7l3o`00013oghIT00Go0000omER0?oEHP3oeF80o`000009oooo
o`?o00009Oooool00ol0003oooooooooo`0Cooooo`008oooool00ol0003oooooooooo`0dooooo`05
o`000?l000;o0002o`000_l000000ol305@00ol0003oN3ekogPmN`0=ogPmN`?o00002On4EY<00ol0
003oZ76CojQaT`0NojQaT`03o`000?nnPI7o_X6A01_o_X6A00?o0000olZ:Soo:RXl04Oo:RXl4o`00
0003olZ1POl0003odXQo01CodXQo0_l000000ooOTW[o0000o`00000>omn6I0;o00000ooEHP000ol0
003oooooooooo`03ooooo`?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003o
ooooooooo`0dooooo`05o`000?l000;o0002o`000_l000001?l305@00ol0003oN3ekogPmN`0;ogPm
N`;o00003?n4EY<00ol0003oZ76CojQaT`0NojQaT`03o`000?nnPI7o_X6A01_o_X6A00?o0000olZ:
Soo:RXl05Oo:RXl3o`0001CodXQo0_l00003omnBNP;o00003?oOQV@00ol0003okXdio`000003omER
0003o`000?oooooo000000;o0000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003o
ooooooooo`0dooooo`04o`000?l000;o0002o`0000Co0`1D00?o0000ogPmNomh?G/02_mh?G/2o`00
00koQ5JC00?o0000ojQaTonXLI<07_nXLI<00ol0003o_X6Aokj1T@0Kokj1T@03o`000?o:RXoobXZ?
01KobXZ?00?o0000om:@SOl000000_l0000Aom:8O`;o00001OoOTWX2o`0000_oghIT00?o0000onj=
>Ol000000ooEHP000ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03
o`000?oooooooooo03?ooooo00Go0000o`000_l000;o0002o`000004o`<0E003o`000?mh?G_oN3ek
00OoN3ek0ol0000@ohAFT`03o`000?nXLI?oZ76C01koZ76C00?o0000okj1TOnnPI406onnPI400ol0
003obXZ?olZ:S`0FolZ:S`03o`000?oBT8godY2=00;odY2=0ol0000>om:8O`;o00001ooOTWX2o`00
00WoghIT00Co0000onj=>Oo^SCWo00000ooEHP000ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo01?ooooo000Rooooo`03o`000?oooooooooo03?ooooo00Co0000o`000_l000;o00001Ol305@0
0ol0003oN3ekogPmN`05ogPmN`;o00004on4EY<00ol0003oZ76CojQaT`0NojQaT`03o`000?nnPI7o
_X6A01_o_X6A00?o0000olZ:Soo:RXl05_o:RXl00ol0003odY2=om:@S@05om:@S@;o00003?oBR7l2
o`0000Wogi9j0_l00007omn6I005o`000?o^SCWokXdionj=>Ol000000_oEHP000ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo03?ooooo00?o0000
o`000_l000001_l305@00ol0003oN3ekogPmN`03ogPmN`;o00005On4EY<00ol0003oZ76CojQaT`0N
ojQaT`03o`000?nnPI7o_X6A01_o_X6A00?o0000olZ:Soo:RXl05_o:RXl00ol0003odY2=om:@S@07
om:@S@?o00002OoBR7l00ol0003odXQoo`00000:omnBNP03o`000?oOQVCoghIT00GoghIT00Go0000
onj=>Oo^SCWokXdio`000002omER0003o`000?oooooooooo02[ooooo00?o0000ooooooooool04ooo
ool0027ooooo0ol0000cooooo`04o`000?l000;o0002o`0000Ko0`1D00?o0000ogPmNomh?G/00ol0
000GohAFT`03o`000?nXLI?oZ76C01[oZ76C5?l0000>okj1T@03o`000?o:RXoobXZ?01KobXZ?00?o
0000om:@SOoBT8d02_oBT8d3o`0000KodXQo00?o0000om:8Ool000002ooOTWX2o`0000GoghIT00?o
0000onj=>Oo^SCT00_o^SCT01?l0003oeF80omER0?l0000/ooooo`03o`000?oooooooooo01;ooooo
000Qooooo`03o`000?oooooooooo03?ooooo00?o0000o`000_l000001ol305@3o`0001_oQ5JC00?o
0000ojQaTonXLI<04OnXLI<8o`0000Co[7fQ00?o0000okj:WOnnRYd03OnnRYdAo`0001KobXZ?00?o
0000om:@SOoBT8d03OoBT8d2o`0000CodXQo00?o0000om:8Ool000003OoOTWX2o`0000?oghIT00?o
0000onj=>Oo^SCT00oo^SCT00ol0003oeF80o`00000/ooooo`03o`000?oooooooooo01;ooooo000Q
ooooo`03o`000?oooooooooo03;ooooo00?o0000o`000_l000002?l305@00ol0003oQ5JCohAFT`0K
ohAFT`03o`000?nXLI?oZ76C00WoZ76C2?l0000<ojamX@03o`000?nnRYgo_XZM01_o_XZM00?o0000
olZBV_o:TYX01?l0000BolZ:S`03o`000?oBT8godY2=00oodY2=0ol000001?oBR7oo0000om:8Ool0
000?omnBNP;o000000?oghITo`000?o^SCT01Oo^SCT00ol0003oeF80o`00000[ooooo`03o`000?oo
oooooooo01;ooooo000Qooooo`03o`000?oooooooooo03;ooooo0_l00009o`<0E003o`000?n4EY?o
Q5JC01_oQ5JC00Co0000ojQaTonXLI?oZ76C2?l0000DojamX@03o`000?nnRYgo_XZM01_o_XZM00?o
0000olZBV_o:TYX01?o:TYX4o`0000kobXZ?00?o0000om:@SOoBT8d04_oBT8d4o`00017ogi9j0ol0
0006onj=>@;o0000:oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0a
ooooo`03o`000?l000;o000000So0`1D0_l0000LohAFT`Go00007?n/OJ400ol0003o_XZMokj:W@0K
okj:W@03o`000?o:TY[obY:J00SobY:J1Ol00009olZ:S`03o`000?oBT8godY2=01?odY2=00Co0000
om:@SOl0003o00004_oOTWX00ol0003okXdionj=>@05onj=>@;o0000:_ooool00ol0003ooooooooo
o`0Booooo`008Oooool00ol0003oooooooooo`0aooooo`;o00002?l305@00ol0003o<Ab7o`00000J
ohAFT`;o000000?oSFVUo`000?n/OJ407_n/OJ400ol0003o_XZMokj:W@0Kokj:W@03o`000?o:TY[o
bY:J00gobY:J1?l00005olZ:S`03o`000?oBT8godY2=01?odY2=00Co0000om:@SOl0003ogY^;0_l0
000@omnBNP;o00001oo^SCT2o`0002Wooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000
ooooooooool0<Oooool00ol0003o0`1Do`<0E006o`<0E004o`000?la78Oo<Ab7o`0001SoQ5JC0_l0
0003oheYY@03o`000?n/OJ7o[7fQ01go[7fQ00?o0000okj:WOnnRYd06onnRYd00ol0003obY:JolZB
VP0AolZBVPCo000000?obXZ?o`000?oBT8d05?oBT8d00ol0003odY2=o`000003omjKR`;o00003_oO
TWX00ol0003omJIVo`000007onj=>@03o`000?oooooooooo02Oooooo00?o0000ooooooooool04_oo
ool0023ooooo0ol0000aooooo`03o`000?l305Co0`1D00Oo0`1D00Go0000oc4LQola78Oo<Ab7o`00
000DohAFT`?o00001On=JJD00ol0003o[7fQojamX@0MojamX@03o`000?nnRYgo_XZM01_o_XZM00?o
0000olZBV_o:TYX05Oo:TYX3o`0001CodY2=00?o0000om:@SOl000001OoNVh/2o`0000cogi9j00Co
0000ooFVI_oeYVKo00001oo^SCT00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo
000Pooooo`03o`000?oooooooooo037ooooo00?o0000o`<0E?l305@01_l305@00ol0003o<Ab7oc4L
Q`02oc4LQ`03o`000?n4EY?oQ5JC013oQ5JC0_l00009oheYY@03o`000?n/OJ7o[7fQ01go[7fQ00?o
0000okj:WOnnRYd06_nnRYd00ol0003obY:JolZBVP0FolZBVP03o`000?oAUiSo000000;o00004_oB
T8d2o`0000OogY^;0_l0000:omnBNP05o`000?oeYVKomJIVooFVI_l000001_o^SCT00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`0aooooo`03o`000?l305Co0`1D00Go0`1D00?o0000oc4LQola78L0
0ola78L00ol0003oQ5JCohAFT`0>ohAFT`;o00002on=JJD00ol0003o[7fQojamX@0MojamX@03o`00
0?nnRYgo_XZM01[o_XZM00?o0000olZBV_o:TYX05_o:TYX00ol0003odINHom6GV002om6GV0?o0000
3ooBT8d2o`0000WogY^;0_l00008omnBNP03o`000?oeYVKomJIV00;omJIV00?o0000onj=>Oo^SCT0
1?o^SCT00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0aooooo`03o`000?l305Co0`1D00Co0`1D
00?o0000oc4LQola78L01?la78L00ol0003oQ5JCohAFT`0<ohAFT`;o00003On=JJD00ol0003o[7fQ
ojamX@0MojamX@03o`000?nnRYgo_XZM01[o_XZM00?o0000olZBV_o:TYX05_o:TYX00ol0003odINH
om6GV005om6GV0?o00003?oBT8d00ol0003ogY^;omjKR`0:omjKR`03o`000?oOTW[ogi9j00Kogi9j
00?o0000ooFVI_oeYVH00_oeYVH00ol0003okXdionj=>@03onj=>@03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo037ooooo00?o0000o`<0E?l305@01?l305@00ol0003o<Ab7oc4LQ`04oc4LQ`03o`00
0?n4EY?oQ5JC00[oQ5JC0_l0000?oheYY@03o`000?n/OJ7o[7fQ01go[7fQ00?o0000okj:WOnnRYd0
6_nnRYd00ol0003obY:JolZBVP0FolZBVP03o`000?oAUiSodINH00SodINH0ol00009om:@S@03o`00
0?oNVh_ogY^;00_ogY^;0_l00006omnBNP03o`000?oeYVKomJIV00?omJIV00?o0000onj=>Oo^SCT0
0_o^SCT00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0aooooo`03o`000?l305Co0`1D00?o0`1D
00?o0000oc4LQola78L01Ola78L00ol0003oQ5JCohAFT`08ohAFT`;o00004On=JJD00ol0003o[7fQ
ojamX@0MojamX@03o`000?nnRYgo_XZM01[o_XZM00?o0000olZBV_o:TYX05_o:TYX00ol0003odINH
om6GV00;om6GV0?o00001_oBT8d00ol0003ogY^;omjKR`0=omjKR`;o00001?oOTWX00ol0003omJIV
ooFVIP04ooFVIP03o`000?o^SCWokXdi00;okXdi00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
<_ooool00ol0003o0`1Do`<0E002o`<0E003o`000?la78Oo<Ab700Ko<Ab700?o0000ohAFTon4EY<0
1_n4EY<2o`0001CoSFVU00?o0000ojamXOn/OJ407?n/OJ400ol0003o_XZMokj:W@0Jokj:W@03o`00
0?o:TY[obY:J01KobY:J00?o0000om6GV?oAUiP03_oAUiP3o`0000?odY2=00?o0000omjKRooNVh/0
3ooNVh/2o`0000;ogi9j00?o0000ooFVI_oeYVH01OoeYVH01Ol0003okXdionj=>Oo^SCWo000002Oo
oooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4005ooooo`;o
0000<oooool00ol0003o0`1Do`<0E002o`<0E003o`000?la78Oo<Ab700Oo<Ab700?o0000ohAFTon4
EY<00_n4EY<3o`0001KoSFVU00?o0000ojamXOn/OJ406_n/OJ4Bo`0000go_XZM00?o0000olZBV_o:
TYX05Oo:TYX00ol0003odINHom6GV00Bom6GV0Co00004ooNVh/3o`0000SomJIV00Co0000onj=>Oo^
SCWo00009oooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo00?o0000ooooooooool0<Oooool00ol0003o0`1Do`<0E002o`<0E003o`000?la78Oo<Ab7
00So<Ab700?o0000ohAFTon4EY<00_l0000IoheYY@03o`000?n/OJ7o[7fQ01Go[7fQ1Ol00002ojj7
[@03o`000?nnTZSo_Y:X00go_Y:X4Ol0000DolZBVP03o`000?oAUiSodINH01GodINH0_l0000DomjK
R`03o`000?oeYVKomJIV00OomJIV00Co0000onj=>Oo^SCWo00009oooool00ol0003oooooooooo`0@
ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0<Oooool0
1Ol0003o0`1Do`<0E?l305Co000000_o<Ab70ol0000KoheYY@03o`000?n/OJ7o[7fQ013o[7fQ1Ol0
0007ojj7[@03o`000?nnTZSo_Y:X01[o_Y:X00Co0000olVHYOo9V:GobIRU1_l0000>olZBVP03o`00
0?oAUiSodINH01GodINH00Co0000ombSVOl0003o00004_oNVh/00ol0003omJIVooFVIP08ooFVIP03
o`000?o^SCWo000002Oooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
<Oooool01?l0003o0`1Do`<0E?l0000<oc4LQ`03o`000?n=JJGoSFVU01_oSFVU00?o0000ojamXOn/
OJ402on/OJ45o`0000co[XN]00?o0000okjBZ?nnTZP06_nnTZP00ol0003obIRUolVHY@07olVHY@Ko
00002?o:TYX00ol0003odINHom6GV00Eom6GV005o`000?oLXiWog:>IombSVOl000004OoNVh/2o`00
00[omJIV0_l0000Wooooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo037o
oooo00Co0000o`<0E?l305Co00003?la78L00ol0003oSFVUoheYY@0LoheYY@03o`000?n/OJ7o[7fQ
00Go[7fQ1Ol0000Aojj7[@03o`000?nnTZSo_Y:X01[o_Y:X00?o0000olVHYOo9V:D03Oo9V:D6o`00
00;obY:J00?o0000om6GV?oAUiP05OoAUiP00ol0003og:>IombSV@02ombSV@;o00003ooNVh/00ol0
003olk>5o`00000:ooFVIP;o00009_ooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003o
ooooooooo`0aooooo`03o`000?l305Co000000co<Ab70_l0000NoheYY@03o`000?n/OJ7o[7fQ00Go
00005on^Qjd00ol0003o_Y:XokjBZ00IokjBZ003o`000?o9V:GobIRU01?obIRU1?l0000Eom6GV0;o
00001_oLXiT2o`0000gogY^;00Co0000oo>cQOoc/hGo00002_oeYVH00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo03;ooooo0_l0000<oc4LQ`04
o`000?m?A:KoCdBVo`0001coSFVU1?l0000Lojj7[@03o`000?nnTZSo_Y:X01Wo_Y:X00?o0000olVH
YOo9V:D05Oo9V:D00ol0003od9jSo`000002o`0001;odINH0_l00008ombSV@;o00002ooNVh/01Ol0
003olk>5oo>cQOoc/hGo000000WomJIV00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@
ooooo`007_ooool00ol0003oooooooooo`0booooo`03o`000?la78Oo<Ab700[o<Ab700Go0000odm4
Y_m?A:KoCdBVo`00000JoheYY@;o000000?oU7Vbo`000?n^Qjd07On^Qjd00ol0003o_Y:XokjBZ00I
okjBZ003o`000?o9V:GobIRU01GobIRU00?o0000om2NXoo@WZ<00_o@WZ<3o`0000oodINH0_l0000:
ombSV@03o`000?oNVh_ogY^;00SogY^;00?o0000oo>cQOoc/hD00_oc/hD00ol0003omJIVooFVIP06
ooFVIP03o`000?oooooooooo02Cooooo00?o0000ooooooooool04?ooool001kooooo0_l0000coooo
o`03o`000?la78Oo<Ab700Wo<Ab700?o0000odm4Y_m?A:H00_m?A:H00ol0003oSFVUoheYY@0FoheY
Y@;o00000onDNK800ol0003o[XN]ojj7[@0Lojj7[@03o`000?nnTZSo_Y:X01Wo_Y:X00?o0000olVH
YOo9V:D05Oo9V:D00ol0003od9jSom2NX`05om2NX`?o00003?oAUiP2o`0000_og:>I0_l00007omjK
R`03o`000?oc/hGolk>500Colk>500?o0000ooFVI_oeYVH01OoeYVH00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03;ooooo00?o0000oc4LQola
78L02Ola78L00ol0003oCdBVodm4YP03odm4YP03o`000?n=JJGoSFVU01?oSFVU0_l00006oiAi/P03
o`000?n^Qjgo[XN]01_o[XN]00?o0000okjBZ?nnTZP06?nnTZP00ol0003obIRUolVHY@0EolVHY@03
o`000?o@WZ?od9jS00Wod9jS0_l0000:om6GV0;o00003OoLXiT2o`0000GogY^;00?o0000oo>cQOoc
/hD01Ooc/hD00ol0003omJIVooFVIP04ooFVIP;o00009_ooool00ol0003oooooooooo`0?ooooo`00
7_ooool00ol0003oooooooooo`0booooo`03o`000?la78Oo<Ab700So<Ab700?o0000odm4Y_m?A:H0
1?m?A:H00ol0003oSFVUoheYY@0AoheYY@;o00002?nDNK800ol0003o[XN]ojj7[@0Kojj7[@03o`00
0?nnTZSo_Y:X01So_Y:X00?o0000olVHYOo9V:D05Oo9V:D00ol0003od9jSom2NX`0;om2NX`?o0000
1ooAUiP2o`0000oog:>I0_l00003omjKR`03o`000?oc/hGolk>500Kolk>500?o0000ooFVI_oeYVH0
0ooeYVH2o`0002Kooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0<ooo
ool00ol0003o<Ab7oc4LQ`06oc4LQ`03o`000?m?A:KoCdBV00GoCdBV00?o0000oheYYOn=JJD03on=
JJD2o`0000[oU7Vb00?o0000ojj7[On^Qjd06on^Qjd00ol0003o_Y:XokjBZ00HokjBZ003o`000?o9
V:GobIRU01GobIRU00?o0000om2NXoo@WZ<03_o@WZ<3o`0000?odINH00?o0000ombSVOl000004OoL
XiT01?l0003ogY^;omjKRol00009oo>cQ@03o`000?oeYVKomJIV00;omJIV0_l0000Vooooo`03o`00
0?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo03Cooooo00?o0000oc4LQola78L01Ola
78L00ol0003oCdBVodm4YP07odm4YP03o`000?n=JJGoSFVU00coSFVU0_l0000<oiAi/P03o`000?n^
Qjgo[XN]01_o[XN]00?o0000okjBZ?nnTZP06?nnTZP00ol0003obIRUolVHY@0EolVHY@03o`000?o@
WZ?od9jS017od9jS1?l000000ooLXiWo0000ombSV@0AombSV@?o00002_oc/hD00ol0003omJIVooFV
IP02ooFVIP03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool001gooooo00?o0000
ooooooooool0=?ooool00ol0003o<Ab7oc4LQ`05oc4LQ`03o`000?m?A:KoCdBV00OoCdBV00?o0000
oheYYOn=JJD02_n=JJD2o`0000ooU7Vb00?o0000ojj7[On^Qjd06on^Qjd00ol0003o_Y:XokjBZ00G
okjBZ003o`000?o9V:GobIRU01GobIRU00?o0000om2NXoo@WZ<05?o@WZ<2o`000003ombSVOl0003o
g:>I01;og:>I00?o0000oo>cQOoc/hD02Ooc/hD01Ol0003omJIVooFVI_oeYVKo000002Kooooo00?o
0000ooooooooool03oooool001gooooo00?o0000ooooooooool0=?ooool00ol0003o<Ab7oc4LQ`04
oc4LQ`03o`000?m?A:KoCdBV00SoCdBV00?o0000oheYYOn=JJD02?n=JJD2o`00017oU7Vb00?o0000
ojj7[On^Qjd06on^Qjd00ol0003o_Y:XokjBZ00GokjBZ003o`000?o9V:GobIRU01GobIRU00?o0000
om2NXoo@WZ<05?o@WZ<01?l0003ofZZUo`000?l0000CombSV@03o`000?oc/hGolk>500[olk>500Co
0000ooFVI_oeYVKo00009_ooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0003Gooooo00?o
0000oc4LQola78L00ola78L00ol0003oCdBVodm4YP0:odm4YP03o`000?n=JJGoSFVU00GoSFVU0_l0
000CoiAi/P03o`000?n^Qjgo[XN]01_o[XN]00?o0000okjBZ?nnTZP02_nnTZPAo`0001CobIRU00?o
0000om2NXoo@WZ<05?o@WZ<00ol0003ofZZUomZZY@02o`0001;og:>I0_l0000<oo>cQ@04o`000?oe
YVKo0000o`0002Kooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0=?oo
ool00ol0003o<Ab7oc4LQ`02oc4LQ`03o`000?m?A:KoCdBV00_oCdBV00?o0000oheYYOn=JJD00on=
JJD2o`0001GoU7Vb00?o0000ojj7[On^Qjd06On^Qjd?o`0000go_IVb00Co0000olNO[oo7Wjooain_
1_l0000=olVHY@03o`000?o@WZ?od9jS01Cod9jS00Oo0000omZZYOoJZZGofZZUo`000?oJZZGo0000
013og:>I00Co0000onnlVoo__9_o00003?oc/hD3o`0002Kooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool0=?ooool01Ol0003o<Ab7oc4LQola78Oo000000koCdBV00Co0000
oheYYOn=JJGoSFVU0_l0000GoiAi/P03o`000?n^Qjgo[XN]01Go[XN]1?l00002ojnA]`03o`000?nm
VK;o_IVb01Oo_IVb00?o0000olNO[oo7Wjl01oo7Wjl5o`0000SobIRU00?o0000om2NXoo@WZ<05?o@
WZ<01Ol0003ofZZUomZZYOoJZZGo000000;ofZZU0_l0000>ombSV@05o`000?o__9_okkbKonnlVol0
00003?oc/hD2o`0002Kooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0
=_ooool01?l0003o<Ab7oc4LQol0000?odm4YP?o00006_nDNK800ol0003o[XN]ojj7[@0@ojj7[@Co
00001_n_TKL00ol0003o_IVbokfI/P0GokfI/P03o`000?o7Wjooain_00coain_1_l00002olVHY@03
o`000?o@WZ?od9jS01Cod9jS00Go0000omZZYOoJZZGofZZUo`000004omZZY@03o`000?oLXiWog:>I
00_og:>I00?o0000onnlVoo__9/00_o__9/00ol0003olk>5oo>cQ@09oo>cQ@;o00009_ooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0fooooo`03o`000?la78Oo0000013o
CdBV00?o0000oiAi/_nDNK806_nDNK800ol0003o[XN]ojj7[@0<ojj7[@Co00002_n_TKL00ol0003o
_IVbokfI/P0GokfI/P03o`000?o7Wjooain_01;oain_1?l0000Eom2NX`05o`000?oJZZGofZZUomZZ
YOl000001OoJZZD2o`0000_og:>I00?o0000onnlVoo__9/00oo__9/00ol0003olk>5oo>cQ@08oo>c
Q@;o00009_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0fooooo`;o
00004Om?A:H00ol0003oU7VboiAi/P0JoiAi/P03o`000?n^Qjgo[XN]00So[XN]1?l0000>ojnA]`03
o`000?nmVK;o_IVb01Oo_IVb00?o0000olNO[oo7Wjl05?o7Wjl00ol0003ocZF^o`000002o`0001;o
d9jS00Go0000omZZYOoJZZGofZZUo`000007omZZY@;o00002?oLXiT00ol0003okkbKonnlV`05onnl
V`03o`000?oc/hGolk>500Oolk>50_l0000Vooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo03Kooooo00?o0000odm4Y_m?A:H03om?A:H00ol0003oI6:jo`00000KoiAi/P03
o`000?n^Qjgo[XN]00Co[XN]1?l0000CojnA]`03o`000?nmVK;o_IVb01Ko_IVb00?o0000olNO[oo7
Wjl05?o7Wjl00ol0003ocZF^oljU[P02oljU[P?o00003_o@WZ<00ol0003ofZZUomZZY@03o`0000Wo
fZZU00?o0000ombSVOoLXiT01OoLXiT00ol0003okkbKonnlV`06onnlV`03o`000?oc/hGolk>500Ko
lk>50ol0000Uooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo03Kooooo
00?o0000odm4Y_m?A:H03_m?A:H01?l0003oI6:jofAR^_l0000LoiAi/P03o`000?n^Qjgo000000?o
00005on_TKL00ol0003o_IVbokfI/P0FokfI/P03o`000?o7Wjooain_01?oain_00?o0000oljU[_o>
YJh01_o>YJh2o`0000cod9jS0ol00002omZZY@03o`000?oJZZGofZZU00SofZZU0_l00005ombSV@03
o`000?o__9_okkbK00OokkbK00?o0000oo>cQOoc/hD01Ooc/hD3o`0002Kooooo00?o0000oooooooo
ool03Oooool001cooooo0_l0000gooooo`03o`00L?l0003oCdBV00goCdBV00?o0000ofAR^_mTH[X0
0_mTH[X00ol0003oU7VboiAi/P0HoiAi/P?o00006on_TKL00ol0003o_IVbokfI/P0EokfI/P03o`00
0?o7Wjooain_01Coain_00?o0000oljU[_o>YJh02?o>YJh3o`0000Kod9jS1?l00005omZZY@03o`00
0?oJZZGofZZU00WofZZU00?o0000ombSVOoLXiT00_oLXiT00ol0003okkbKonnlV`07onnlV`03o`00
0?oc/hGolk>500Golk>50ol0000Vooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oo
oooooooo03Oooooo0_l0000=odm4YP03o`000?mTH[[oI6:j00?oI6:j00?o0000oiAi/_nDNK805_nD
NK82o`000003oiV6__l0003o[i6g01_o[i6g00?o0000okfI/_nmVK805OnmVK800ol0003oain_olNO
[`0DolNO[`03o`000?o>YJkocZF^00_ocZF^0_l000001?o@WZ?o0000o`000?l00003om2NX`03o`00
0?oJZZGofZZU00CofZZU00?o0000omZZYOoJZZD02OoJZZD2o`0000;og:>I00?o0000onnlVoo__9/0
2?o__9/00ol0003olk>5oo>cQ@03oo>cQ@04o`000?obbECo0000o`0002Kooooo00?o0000oooooooo
ool03Oooool001_ooooo00?o0000ooooooooool0>?ooool00ol0073o0000odm4YP0;odm4YP03o`00
0?mTH[[oI6:j00CoI6:j00?o0000oiAi/_nDNK804onDNK82o`0000CoVHJn00?o0000ojnA]on_TKL0
6On_TKL00ol0003o_IVbokfI/P0EokfI/P03o`000?o7Wjooain_01Coain_00?o0000oljU[_o>YJh0
2_o>YJh6o`0000Cod9jS00?o0000omZZYOoJZZD01OoJZZD00ol0003ofZZUomZZY@0:omZZY@;o0000
3?o__9/00ol0003olk>5oo>cQ@02oo>cQ@04o`000?obbECol/UDo`0002Kooooo00?o0000oooooooo
ool03Oooool001_ooooo00?o0000ooooooooool0>?ooool00ol0073o0000odm4YP0:odm4YP03o`00
0?mTH[[oI6:j00GoI6:j00?o0000oiAi/_nDNK804OnDNK82o`0000KoVHJn00?o0000ojnA]on_TKL0
6On_TKL00ol0003o_IVbokfI/P0EokfI/P03o`000?o7Wjooain_01Coain_00?o0000oljU[_o>YJh0
1oo>YJh3o`0000KocZF^1?l00009omZZY@03o`000?oJZZGofZZU00[ofZZU00?o0000onnlVoo__9/0
2oo__9/01Ol0003olk>5oo>cQOoc/hGo000000;ol/UD00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0=ooooo`006oooool00ol0003oooooooooo`0hooooo`03o`00L?l0003oCdBV00WoCdBV
00?o0000ofAR^_mTH[X01omTH[X00ol0003oU7VboiAi/P0>oiAi/P;o00002OnIQ[h00ol0003o[i6g
ojnA]`0HojnA]`03o`000?nmVK;o_IVb01Go_IVb00?o0000olNO[oo7Wjl04oo7Wjl00ol0003ocZF^
oljU[P05oljU[P?o00003?o>YJh2o`0000SofZZU00?o0000omZZYOoJZZD02_oJZZD00ol0003okkbK
onnlV`0<onnlV`04o`000?oc/hGolk>5o`0000;ol/UD0_l0000Uooooo`03o`000?oooooooooo00go
oooo000Kooooo`03o`000?oooooooooo03Sooooo00?o0000o`00L?l000002?m?A:H00ol0003oI6:j
ofAR^P08ofAR^P03o`000?nDNK;oU7Vb00_oU7Vb0ol0000;oiV6_P03o`000?n_TKOo[i6g01So[i6g
00?o0000okfI/_nmVK805OnmVK800ol0003oain_olNO[`0ColNO[`03o`000?o>YJkocZF^00;ocZF^
0ol0000?oljU[P03o`000?oG/;7o000000SofZZU00?o0000omZZYOoJZZD02?oJZZD00ol0003ojL:/
o`00000>onnlV`03o`000?oc/hGo000000;ol/UD0_l0000Uooooo`03o`000?oooooooooo00gooooo
000Kooooo`03o`000?oooooooooo03Sooooo00?o0000o`00L?l000001om?A:H00ol0003oI6:jofAR
^P09ofAR^P03o`000?nDNK;oU7Vb00WoU7Vb0_l0000?oiV6_P03o`000?n_TKOo[i6g01So[i6g00?o
0000okfI/_nmVK805?nmVK800ol0003oain_olNO[`0ColNO[`Go00004Oo>YJh01?l0003oek2aomN`
/OoG/;42o`0000OofZZU00?o0000omZZYOoJZZD01ooJZZD01?l0003ojL:/onW2[?l0000>onnlV`;o
00000_obbE@2o`0002Gooooo00?o0000ooooooooool03Oooool001_ooooo0_l0000iooooo`04o`00
0?l0073o001`o`0000GoCdBV00?o0000ofAR^_mTH[X02omTH[X00ol0003oU7VboiAi/P06oiAi/P;o
00004OnIQ[h00ol0003o[i6gojnA]`0HojnA]`03o`000?nmVK;o_IVb00ko_IVb2ol0000?olNO[`?o
00005Oo>YJh00ol0003oek2aomN`/@03omN`/@03o`000?oJZZGofZZU00GofZZU00?o0000omZZYOoJ
ZZD01OoJZZD00ol0003ojL:/onW2[002onW2[003o`000?o__9_okkbK00cokkbK00Go0000oo;9E?ob
bECol/UDo`00000Vooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo03[o
oooo00?o0000o`00L?l000001Om?A:H00ol0003oI6:jofAR^P0;ofAR^P03o`000?nDNK;oU7Vb00Co
U7Vb0_l0000DoiV6_P03o`000?n_TKOo[i6g01Oo[i6g00?o0000okfI/_nmVK800onmVK8;o`0000Ko
_:2l00?o0000olFU^Oo5YKT00_o5YKT7o`0000Goain_0ol00002olNO[`03o`000?o>YJkocZF^01?o
cZF^00?o0000omN`/OoG/;401?oG/;400ol0003ofZZUomZZY@05omZZY@03o`000?oJZZGofZZU00Co
fZZU00?o0000onW2[?oY`Z`00ooY`Z`00ol0003okkbKonnlV`0;onnlV`05o`000?obbECol/UDoo;9
E?l000009_ooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03[ooooo00Co0000
o`00L?l0073o00000om?A:H00ol0003oI6:jofAR^P0=ofAR^P04o`000?nDNK;oU7VboiAi/P;o0000
5_nIQ[h00ol0003o[i6gojnA]`0EojnA]`So00004OnlX;`00ol0003oaJFiolFU^@09olFU^@Oo0000
0_o7Wjl00ol0003ocZF^oljU[P0ColjU[P03o`000?oG/;7oek2a00Koek2a0_l00006omZZY@03o`00
0?oJZZGofZZU00;ofZZU00?o0000onW2[?oY`Z`01?oY`Z`00ol0003okkbKonnlV`0:onnlV`;o0000
0oobbE@00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00cooooo00001?nHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03[ooooo
00Co0000o`00L?l0073o00000_m?A:H00ol0003oI6:jofAR^P0>ofAR^P04o`000?nDNK;o0000o`00
01SoVHJn00?o0000ojnA]on_TKL04On_TKL4o`0000;o/9[100?o0000okbP_?nlX;`05?nlX;`00ol0
003oaJFiolFU^@07olFU^@Co00001Oo5YKT4o`0001CocZF^00?o0000omN`/OoG/;402?oG/;400ol0
003ofZZUomZZY@03omZZY@03o`000?oJZZGofZZU00;ofZZU00?o0000onW2[?oY`Z`01OoY`Z`00ol0
003okkbKonnlV`09onnlV`;o00000oobbE@00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00cooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0jooooo`06o`000?l0073o001`o`000?m?A:Ko00004_mTH[X00ol0003oVHJnoiV6_P0I
oiV6_P03o`000?n_TKOo[i6g00co[i6g1?l00006ok2J`@03o`000?nlX;co_:2l01Co_:2l00?o0000
olFU^Oo5YKT01?o5YKT3o`0000_oaJFi00?o0000olb[^Ol000000_l0000@oljU[P03o`000?oG/;7o
ek2a00[oek2a0_l00004omZZY@05o`000?oJZZGofZZUomZZYOl000002?oY`Z`00ol0003okkbKonnl
V`08onnlV`03o`000?omhXoo000000;ol/UD0_l0000Uooooo`03o`000?oooooooooo00cooooo0003
ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0j
ooooo`05o`000?l0073o001`o`00L?l000004omTH[X00ol0003oVHJnoiV6_P0IoiV6_P03o`000?n_
TKOo[i6g00Wo[i6g0ol0000:ok2J`@03o`000?nlX;co_:2l01Co_:2l00Co0000olFU^Oo5YKWoaJFi
0ol0000>olFU^@03o`000?o<ZkWoc:^i00;oc:^i0ol0000=oljU[P03o`000?oG/;7oek2a00coek2a
00?o0000omZZYOoJZZD00_oJZZD00ol0003ofZZUo`00000:onW2[003o`000?o__9_okkbK00KokkbK
00Co0000oogRSoomhXoo00000oobbE@00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00co
oooo0003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03
o`000?oooooooooo03[ooooo00Go0000o`00L?l0073o001`o`00000BofAR^P03o`000?mcN<Wo0000
01_oVHJn00?o0000ojnA]on_TKL01?n_TKL4o`0000ko/9[100?o0000okbP_?nlX;`04onlX;`4o`00
013oaJFi00?o0000olb[^Oo<ZkT01_o<ZkT3o`0000[ocZF^00?o0000omN`/OoG/;403OoG/;400ol0
003ofZZUomZZY@02omZZY@;o00002ooY`Z`00ol0003okkbKonnlV`05onnlV`04o`000?omhXoooN:?
o`0000?ol/UD00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`000oooool00ol@
413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool01Ol0
003o001`o`00L?l07j_o0000013oI6:j00Go0000og=hbOmcN<WoLgS9o`00000JoiV6_P03o`000?n_
TKOo[i6g00Co00004_n`V/400ol0003o_:2lokbP_00@okbP_0Co00004oo5YKT00ol0003oc:^iolb[
^@09olb[^@;o00001oo>YJh00ol0003oek2aomN`/@0?omN`/@;o00000_oJZZD2o`0000cojL:/00?o
0000onnlVoo__9/00oo__9/01Ol0003ooN:?oogRSoomhXoo000000?ol/UD00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003ooooo
ooooo`06ooooo`;o0000?Oooool00ol0003o001`o`00L002o`0000ooI6:j00?o0000og=hbOmcN<T0
0_mcN<T00ol0003oVHJnoiV6_P0HoiV6_P?o00005_n`V/400ol0003o_:2lokbP_00=okbP_0?o0000
0onlX;`00ol0003oaJFiolFU^@0AolFU^@03o`000?o<ZkWoc:^i00_oc:^i0ol00004oljU[P03o`00
0?oG/;7oek2a017oek2a00Co0000omZZYOl0003o00003?oY`Z`00ol0003okkbKonnlV`03onnlV`05
o`000?omhXoooN:?oogRSol000000oobbE@00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00_ooooo00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`0loooo
o`06o`000?l0073o001`o`000?l07j_o00003OmTH[X00ol0003oLgS9og=hb@04og=hb@03o`000?nI
Q[koVHJn01GoVHJn0_l000000onMTlSo0000ok2J`@0Fok2J`@03o`000?nlX;co_:2l00[o_:2l0ol0
0006okbP_003o`000?o5YKWoaJFi017oaJFi00?o0000olb[^Oo<ZkT03_o<ZkT3o`000003oljU[_l0
003oek2a01?oek2a00Co0000onW2[?oY`Zco00003?oY`Z`01Ol0003okkbKonnlVoo__9_o000000Co
oN:?00Go0000oo;9E?obbECol/UDo`00000Vooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo03cooooo00Co0000o`00L?l0073o001`0_l07j/00ol0003oI6:jofAR^P0:ofAR
^P03o`000?mcN<WoLgS900GoLgS900?o0000oiV6__nIQ[h04_nIQ[h2o`0000CoWI?800?o0000ok2J
`On`V/405?n`V/400ol0003o_:2lokbP_007okbP_0?o00002OnlX;`00ol0003oaJFiolFU^@0AolFU
^@03o`000?o<ZkWoc:^i017oc:^i0_l0000DomN`/@05o`000?oY`ZcojL:/onW2[?l000003?oY`Z`0
1?l0003okkbKonnlVol00005oogRS`03o`000?obbECo000002Oooooo00?o0000ooooooooool02ooo
ool001Wooooo00?o0000ooooooooool0?Oooool01_l0003o001`o`00L?l0003o01n[o`0000_oI6:j
00?o0000og=hbOmcN<T01_mcN<T00ol0003oVHJnoiV6_P0AoiV6_P03o`000?nMTlSoWI?800CoWI?8
00?o0000ok2J`On`V/405On`V/400ol0003o_:2lokbP_002okbP_0Co00003?nlX;`00ol0003oaJFi
olFU^@0@olFU^@03o`000?o<ZkWoc:^i01;oc:^i00?o0000om>e_?l000004_oG/;400ol0003ohlFj
o`000003onW2[003o`000?oY`ZcojL:/00[ojL:/00?o0000onnlVol000001OomhXl00ol0003ol/UD
o`00000Wooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo03gooooo00Co
0000o`00L?l0073o00000_l07j/00ol0003oI6:jofAR^P07ofAR^P03o`000?mcN<WoLgS900SoLgS9
00?o0000oiV6__nIQ[h03_nIQ[h2o`0000SoWI?800?o0000ok2J`On`V/405?n`V/400ol0003o_:2l
o`000002o`00013o_:2l00?o0000olFU^Oo5YKT04?o5YKT00ol0003oc:^iolb[^@0Aolb[^@05o`00
0?oC]KcodkFlom>e_?l000004OoG/;401?l0003ohlFjon?5^_l00003onW2[003o`000?oY`ZcojL:/
00[ojL:/00?o0000oogRSoomhXl01?omhXl00ol0003ol/UDo`00000Wooooo`03o`000?oooooooooo
00_ooooo000Hooooo`03o`000?oooooooooo03kooooo00Co0000o`00L?l0073o00000_l07j/00ol0
003oI6:jofAR^P06ofAR^P03o`000?mcN<WoLgS900[oLgS900?o0000oiV6__nIQ[h02onIQ[h2o`00
00[oWI?800?o0000ok2J`On`V/404on`V/43o`0001?o_:2l00?o0000olFU^Oo5YKT04?o5YKT00ol0
003oc:^iolb[^@0Aolb[^@03o`000?oC]KcodkFl00;odkFl0_l0000>omN`/@03o`000?oSaK[ohlFj
00;ohlFj00Go0000onW2[?oY`ZcojL:/o`00000;onW2[003o`000?omhXoooN:?00CooN:?00?o0000
oo;9E?l000009oooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`0ooooo
o`03o`000?l0073o000000?o01n[00?o0000ofAR^_mTH[X01?mTH[X00ol0003oLgS9og=hb@0;og=h
b@03o`000?nIQ[koVHJn00WoVHJn0_l0000=oifCb003o`000?n`V/7o/9[100oo/9[10ol000000on`
V/7o0000okbP_00CokbP_003o`000?o5YKWoaJFi013oaJFi00?o0000olb[^Oo<ZkT04?o<ZkT00ol0
003odkFlom>e_005om>e_003o`000?oG/;7oek2a00[oek2a00?o0000on?5^_oSaKX01?oSaKX01?l0
003ojL:/onW2[?l0000:onW2[0;o00001_omhXl00ol0003ol/UDo`00000Xooooo`03o`000?oooooo
oooo00[ooooo000Hooooo`03o`000?oooooooooo03oooooo00?o0000o`00L?l000000ol07j/00ol0
003oI6:jofAR^P04ofAR^P03o`000?mcN<WoLgS900coLgS900?o0000oiV6__nIQ[h01_nIQ[h2o`00
00ooWI?800?o0000ok2J`On`V/402on`V/44o`0000Co/9[100?o0000okbP_?nlX;`04_nlX;`00ol0
003oaJFiolFU^@0@olFU^@03o`000?o<ZkWoc:^i013oc:^i00?o0000om>e_?oC]K`01_oC]K`2o`00
00[oek2a00?o0000on?5^_oSaKX01?oSaKX01Ol0003ojL:/onW2[?oY`Zco000000WojL:/0_l00006
oogRS`03o`000?obbECo000002Sooooo00?o0000ooooooooool02_ooool001Sooooo0_l00011oooo
o`;o00001?l07j/00ol0003oI6:jofAR^P02ofAR^P03o`000?mcN<WoLgS900koLgS900?o0000oiV6
__nIQ[h01?nIQ[h00ol0003oWI?8oifCb00@oifCb003o`000?n`V/7o/9[100Oo/9[10ol00009ok2J
`@03o`000?nlX;co_:2l00co_:2l2ol0000<olFU^@03o`000?o<ZkWoc:^i013oc:^i00?o0000om>e
_?oC]K`02OoC]K`00ol0003oek2aomN`/@06omN`/@03o`000?oSaK[ohlFj00KohlFj00Go0000onW2
[?oY`ZcojL:/o`000007onW2[004o`000?ogjK?omnVco`0000KooN:?00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`10ooooo`;o00001Ol07j/0
1?l0003oI6:jofAR^_l0000Aog=hb@03o`000?nIQ[koVHJn00;oVHJn0_l0000CoifCb003o`000?n`
V/7o/9[100Co/9[10ol0000<ok2J`@03o`000?nlX;co_:2l00;o_:2l2_l00005okZWaP03o`000?o2
[<Co`Zc400?o`Zc42Ol00003olFU^@03o`000?o<ZkWoc:^i013oc:^i00?o0000om>e_?oC]K`02_oC
]K`00ol0003oek2aomN`/@05omN`/@03o`000?oSaK[ohlFj00OohlFj00Go0000onW2[?oY`ZcojL:/
o`000005onW2[005o`000?ogjK?omnVcooOY/ol000001_omhXl00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00[ooooo000Hooooo`03o`000?oooooooooo047ooooo00?o001`o`000?l07j/0
0ol07j/00ol0003oI6:jo`00000Cog=hb@04o`000?nIQ[ko0000o`0001GoWI?800Co0000ok2J`On`
V/7o/9[10ol0000=ok2J`@Oo00003onjYlH00ol0003o`Zc4ol:/a00<ol:/a0Go00004?o<ZkT00ol0
003odkFlom>e_00<om>e_0;o00001?oG/;400ol0003ohlFjon?5^P09on?5^P05o`000?oY`ZcojL:/
onW2[?l000001?oY`Z`01Ol0003omnVcooOY/oogjK?o000000KooN:?00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`12ooooo`03o`00L?l0003o
01n[00Co01n[00?o0000og=hbOmcN<T04omcN<T00ol0003oWI?8oifCb00EoifCb0Co00003?n`V/44
o`0000;o/:?;00?o0000okZWa_njYlH04OnjYlH00ol0003o`Zc4ol:/a00?ol:/a003o`000?o8/LCo
000000;o00003Oo<ZkT00ol0003odkFlom>e_00>om>e_004o`000?oG/;7oek2ao`0000gohlFj00Co
0000onW2[?oY`Zco00000ooY`Z`00ol0003omnVcooOY/`02ooOY/`03o`000?omhXoooN:?00CooN:?
00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003ooooooooo
o`12ooooo`;o00001Ol07j/00olJDlco0000og=hb@0Cog=hb@03o`000?nMTlSoWI?801;oWI?80ol0
00000onMTlSo0000ok2J`@09ok2J`@Co00001_n`Xl/00ol0003o^ZO6okZWaP0AokZWaP03o`000?o2
[<Co`Zc400ko`Zc400?o0000olRaa?o8/L@00oo8/L@2o`0000[oc:^i00?o0000om>e_?oC]K`04?oC
]K`00ol0003oek2ao`00000=on?5^P05o`000?oY`ZcojL:/onW2[?l000000_oY`Z`00ol0003omnVc
ooOY/`02ooOY/`03o`000?omhXoooN:?00?ooN:?00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0:ooooo`005oooool00ol0003oooooooooo`13ooooo`03o`000?l07j_o01n[00?o01n[00?o
0000oaYCc?l000004_mcN<T00ol0003oOh[Do`00000@oifCb0?o00001OnMTlP00ol0003o/9[1ok2J
`@04ok2J`@?o00002on`Xl/00ol0003o^ZO6okZWaP0@okZWaP03o`000?o2[<Co`Zc400ko`Zc400?o
0000olRaa?o8/L@01Oo8/L@3o`0000Ooc:^i00?o0000om>e_?oC]K`04OoC]K`00ol0003ohlFjon?5
^P0=on?5^P04o`000?oY`ZcojL:/onW2[0;o00001OogjK<00ol0003ooN:?oogRS`03oogRS`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0@ooo
ool00ol0003o01n[o`0OZ`03o`0OZ`04o`000?lJDlco6U?<o`00013oLgS900Go0000ogn:e?moR]Co
Oh[Do`00000<oifCb0?o00002?nMTlP00ol0003o/9[1ok2J`@04o`0000ko/:?;00?o0000okZWa_nj
YlH04?njYlH00ol0003o`Zc4ol:/a00>ol:/a003o`000?o8/LCob;7400Sob;740_l00004olb[^@03
o`000?oC]KcodkFl01;odkFl00?o0000on?5^_oSaKX03_oSaKX00ol0003ojL:/onW2[002o`0000Ko
mnVc00?o0000oogRSoomhXl00_omhXl00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Wo
oooo000Gooooo`03o`000?oooooooooo04Cooooo00?o0000o`0OZol07j/00_l07j/01Ol0003o6U?<
oaYCc?lJDlco000000koLgS900?o0000ogn:e?moR]@00omoR]@00ol0003oWI?8oifCb005oifCb0Co
00002onMTlP3o`0001;o/:?;00?o0000okZWa_njYlH04?njYlH00ol0003o`Zc4ol:/a00=ol:/a003
o`000?o8/LCob;7400_ob;740ol000000oo<ZkWo0000om>e_00Bom>e_003o`000?oKb<Ko0000013o
hlFj00Go0000onW2[?l0003omnVco`000005ooOY/`05o`000?omhXoooN:?oogRSol00000;?ooool0
0ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`14ooooo`03o`000?l07j_o01n[
00;o01n[00?o0000oaYCc?lJDl`00_lJDl`00ol0003oLgS9og=hb@0:og=hb@03o`000?moR]CoOh[D
00GoOh[D00Co0000oifCb?nMTlSoWI?80ol0000=oifCb0;o000000?oXIkBo`000?n`Xl/04_n`Xl/0
0ol0003o^ZO6okZWaP0?okZWaP03o`000?o2[<Co`Zc400ko`Zc400?o0000olRaa?o8/L@03_o8/L@2
o`0001;odkFl00Go0000om_8a_oKb<KoflS6o`00000@on?5^P04o`000?ogjK?omnVco`0000GomnVc
00Go0000oogRSoomhXoooN:?o`00000/ooooo`03o`000?oooooooooo00Wooooo000Gooooo`;o0000
A_ooool01Ol0003o01n[o`0OZol07j_o000000Go6U?<00?o0000og=hbOmcN<T02?mcN<T00ol0003o
Oh[Dogn:e007ogn:e0?o00003onMTlP00ol0003oXIkBoj6NdP02oj6NdP03o`000?n`Xl_o/:?;013o
/:?;00?o0000okZWa_njYlH03onjYlH00ol0003o`Zc4ol:/a00>ol:/a003o`000?o8/LCob;7400ko
b;7400?o0000olfjb?l000004?oC]K`00ol0003oflS6om_8aP03om_8aP03o`000?oSaK[ohlFj00go
hlFj00Go0000ooOY/oogjK?omnVco`000004ooOY/`04o`000?omhXoooN:?o`0002gooooo00?o0000
ooooooooool02Oooool001Kooooo00?o0000ooooooooool0Aoooool01?l0003o01n[o`0OZol00006
oaYCc003o`000?mcN<WoLgS900OoLgS900?o0000ogn:e?moR]@01?moR]@3o`000003ogn:e?l0003o
WI?800goWI?80_l00005oj6NdP03o`000?n`Xl_o/:?;017o/:?;00?o0000okZWa_njYlH03_njYlH0
0ol0003o`Zc4ol:/a00=ol:/a003o`000?o8/LCob;7400kob;7400Co0000olfjb?o=^/SocK[80_l0
000>om>e_003o`000?oKb<KoflS600?oflS600?o0000on?5^_oSaKX03?oSaKX2o`0000ComnVc00Go
0000ooOY/oogjK?omnVco`000002oogRS`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
2Oooool001Kooooo00?o0000ooooooooool0Aoooool01Ol0003o01n[o`0OZol07j_o000000Ko6U?<
00?o0000og=hbOmcN<T01OmcN<T01?l0003oOh[Dogn:e?moR]@4o`0000CoOh[D00?o0000oifCb?nM
TlP02_nMTlP2o`0000SoXIkB00?o0000ok2Sbon`Xl/04?n`Xl/00ol0003o^ZO6okZWaP0>okZWaP03
o`000?o2[<Co`Zc400go`Zc400?o0000olRaa?o8/L@03Oo8/L@00ol0003ocK[8olfjb004olfjb003
o`000?oC]KcodkFl00[odkFl00?o0000om_8a_oKb<H01OoKb<H00ol0003ohlFjon?5^P0:on?5^P03
o`000?o]j<So000000GomnVc00Ko0000ooOY/oogjK?o0000oogRSol0000^ooooo`03o`000?oooooo
oooo00Wooooo000Fooooo`03o`000?oooooooooo04Sooooo00Co0000o`0OZol07j_o00001olJDl`0
0ol0003oLgS9og=hb@03og=hb@03o`000?moR]Co000000;o00002OmoR]@00ol0003oWI?8oifCb007
oifCb0;o00002onQW]800ol0003o/:?;ok2Sb`0?ok2Sb`03o`000?njYlKo^ZO600ko^ZO600?o0000
ol:/a?o2[<@03Oo2[<@00ol0003ob;74olRaa00=olRaa003o`000?o=^/SocK[800GocK[80_l00009
om>e_003o`000?oKb<KoflS600OoflS600?o0000on?5^_oSaKX02?oSaKX01?l0003okNS8ongXb?l0
0006ooOY/`03o`000?ogjK?omnVc00;o0000;_ooool00ol0003oooooooooo`09ooooo`005_ooool0
0ol0003oooooooooo`18ooooo`04o`000?l07j_o01n[o`0000So6U?<00Co0000og=hbOmcN<WoLgS9
0ol0000=ogn:e003o`000?nMTlSoWI?800CoWI?80_l0000=oj6NdP03o`000?n`Xl_o/:?;00oo/:?;
00?o0000okZWa_njYlH03_njYlH00ol0003o`Zc4ol:/a00<ol:/a003o`000?o8/LCob;7400gob;74
00?o0000olfjb?o=^/P02?o=^/P00ol0003odkFlom>e_005om>e_003o`000?oKb<KoflS600SoflS6
00?o0000on?5^_oSaKX01ooSaKX00ol0003okNS8ongXb002ongXb003o`000?ogjK?omnVc00ComnVc
00Co0000ooOY/ol0003o0000;oooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?l07j_o000000Wo6U?<0ol0000Aogn:e003o`000?nMTlSoWI?800;oWI?8
00?o0000oj6Nd_nQW]803_nQW]800ol0003o/:?;ok2Sb`0>ok2Sb`03o`000?njYlKo^ZO600ko^ZO6
00?o0000ol:/a?o2[<@03?o2[<@00ol0003ob;74olRaa00=olRaa003o`000?o=^/SocK[800WocK[8
00?o0000om>e_?oC]K`01?oC]K`00ol0003oflS6om_8aP09om_8aP03o`000?oSaK[ohlFj00GohlFj
00?o0000ongXb?o]j<P00oo]j<P00ol0003omnVcooOY/`04ooOY/`03o`000?ogjK?o0000033ooooo
00?o0000ooooooooool02?ooool001Kooooo00?o0000ooooooooool0B_ooool00ol07j_o0000oaYC
c004oaYCc0Co000000?o6U?<o`000?l000004_moR]@01?l0003oWI?8o`000?l0000Aoj6NdP03o`00
0?n`Xl_o/:?;00oo/:?;00?o0000okZWa_njYlH01OnjYlH@o`0000Oo`Zc400?o0000olRaa?o8/L@0
3?o8/L@00ol0003ocK[8olfjb00;olfjb0;o00000ooC]K`00ol0003oflS6om_8aP0;om_8aP03o`00
0?oSaK[ohlFj00CohlFj00?o0000ongXb?o]j<P00oo]j<P00ol0003omnVcooOY/`05ooOY/`;o0000
<?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`1;ooooo`;o00000_lJ
Dl`3o`0000Go6U?<0_m2N=l00ol0003oOh[Dogn:e00@ogn:e0;o00004onQW]800ol0003o/:?;ok2S
b`0=ok2Sb`Wo00002?nh[m400ol0003o_[??okjcc`05okjcc`So00003Oo8/L@00ol0003ocK[8olfj
b00>olfjb003o`000?oC]Kco000000ooflS600?o0000on?5^_oSaKX00_oSaKX00ol0003okNS8ongX
b004ongXb003o`000?ogjK?omnVc00GomnVc0_l0000`ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`?o0000C?ooool3o`0000So6U?<00Co0000od9hgom2N=oo00004OmoR]@2ohVIg@03o`000?nQ
W];oXIkB013oXIkB00?o0000ok2Sbon`Xl/02_n`Xl/3o`000003ojn/e?l0003o^:oA00ko^:oA00?o
0000okjcconn/ll02onn/ll00ol0003o`[S@o`000002o`0000[ob;7400?o0000olfjb?o=^/P03oo=
^/P00ol0003oflS6om_8aP0>om_8aP05o`000?oSaK[ohlFjon?5^_l000001oo]j<P00ol0003omnVc
ooOY/`04ooOY/`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool02?ooool001Gooooo
00?o0000ooooooooool0BOooool3o`000003ooooool0003o6U?<00So6U?<00Go0000od9hgom2N=oo
@WSOo`00000?ogn:e005o`000?n9VMgoRIWMohVIgOl000004_nQW]800ol0003o/:?;ok2Sb`06ok2S
b`?o00001?n_[=@00ol0003o^:oAokR_d@0=okR_d@03o`000?nn/loo_[??00[o_[??00?o0000ol:h
d?o2^=000oo2^=02o`0000Oob;7400?o0000olfjb?o=^/P03oo=^/P2o`00017oflS600?o0000on?5
^_l000002?o]j<P00ol0003omnVcooOY/`03ooOY/`;o00000oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Gooooo1?l00005ooooo`03
o`000?lJDlco6U?<00Ko6U?<00?o0000od9hgom2N=l00_m2N=l00ol0003oOh[Dogn:e00;ogn:e003
o`000?n9VMgoRIWM00?oRIWM00?o0000oj6Nd_nQW]804?nQW]800ol0003o/:?;ok2Sb`02ok2Sb`?o
00002?n_[=@00ol0003o^:oAokR_d@0;okR_d@03o`000?nn/loo_[??00_o_[??00?o0000ol:hd?o2
^=001Oo2^=02o`0000Gob;7400?o0000olfjb?o=^/P03_o=^/P01?l0003od/WAom;9dOl0000Aom_8
aP03o`000?o]j<SokNS800OokNS800?o0000ooOY/oogjK<00oogjK<00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool0@_ooool3o`0000[ooooo00?o0000oaYCc?lJDl`01OlJDl`00ol0003o@WSOod9hg`03od9hg`03
o`000?moR]CoOh[D00WoOh[D00?o0000ohVIgOn9VMd01On9VMd00ol0003oXIkBoj6NdP0?oj6NdP03
o`000?n`Xl_o000000;o00002on_[=@00ol0003o^:oAokR_d@0;okR_d@03o`000?nn/loo_[??00[o
_[??00?o0000ol:hd?o2^=002?o2^=03o`000003olRaa?l0003ocK[800oocK[800Go0000om;9dOoB
bM7od/WAo`00000?om_8aP03o`000?oPi=Ko000000WokNS800?o0000ooOY/oogjK<00_ogjK<00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01oooool001Go
oooo00?o0000ooooooooool0?oooool3o`0000kooooo00?o0000oaYCc?lJDl`01?lJDl`00ol0003o
@WSOod9hg`04od9hg`03o`000?moR]CoOh[D00OoOh[D00?o0000ohVIgOn9VMd01on9VMd00ol0003o
XIkBoj6NdP0>oj6NdP;o00003_n_[=@00ol0003o^:oAokR_d@0;okR_d@03o`000?nn/loo_[??00[o
_[??00?o0000ol:hd?o2^=002oo2^=02o`0000oocK[800?o0000om;9dOoBbM400ooBbM400ol0003o
flS6om_8aP0;om_8aP04o`000?oPi=Koh>CFo`0000WokNS800Co0000ooOY/oogjK?omnVc0_l00007
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooo
ooooool0?Oooool3o`0001;ooooo00?o0000oaYCc?lJDl`00_lJDl`00ol0003o@WSOod9hg`06od9h
g`03o`000?moR]CoOh[D00GoOh[D00?o0000ohVIgOn9VMd02On9VMd00ol0003oXIkBoj6NdP0;oj6N
dP;o000000?oXjWKo`000?n_[=@03_n_[=@00ol0003o^:oAokR_d@0:okR_d@03o`000?nn/loo_[??
00[o_[??00?o0000ol:hd?o2^=002oo2^=000ol0003oa[kCo`00000=olfjb003o`000?oBbM7od/WA
00God/WA00?o0000om_8a_oKb<H02OoKb<H01Ol0003oh>CFon3Te_oPi=Ko000000[okNS800Co0000
ooOY/oogjK?o00002Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo000D
ooooo`03o`000?oooooooooo03Wooooo1?l0000Fooooo`05o`000?lJDlco6U?<oaYCc?l000002Om2
N=l00ol0003oOh[Dogn:e003ogn:e003o`000?n9VMgoRIWM00_oRIWM00?o0000oj6Nd_nQW]802?nQ
W]82o`0000CoXjWK00?o0000ojn/e?n_[=@03?n_[=@00ol0003o^:oAokR_d@0:okR_d@03o`000?nn
/loo_[??00Wo_[??00?o0000ol:hd?o2^=002oo2^=001?l0003oa[kColJndoo6_]<2o`0000[ocK[8
00?o0000om;9dOoBbM401_oBbM400ol0003oflS6om_8aP08om_8aP03o`000?oPi=Koh>CF00;oh>CF
00?o0000ongXb?o]j<P02?o]j<P00ol0003omnVco`00000;ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0=_ooool3o`0001_ooooo00Co
0000oaYCc?lJDlco00002_m2N=l01Ol0003oOh[Dogn:e?moR]Co000000ooRIWM00?o0000oj6Nd_nQ
W]801OnQW]82o`0000OoXjWK00?o0000ojn/e?n_[=@02on_[=@00ol0003o^:oAokR_d@0:okR_d@03
o`000?nn/loo_[??00Wo_[??00?o0000ol:hd?o2^=002_o2^=000ol0003oa[kColJnd`04olJnd`03
o`000?o=^/SocK[800KocK[800?o0000om;9dOoBbM402?oBbM400ol0003oflS6om_8aP05om_8aP;o
00001OoPi=H00ol0003okNS8ongXb008ongXb0;o00003?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo00Oooooo000Dooooo`?o0000<oooool3o`0001oooooo00?o0000oaYCc?l00000
2om2N=l00ol0003oOh[Do`00000AohVIg@03o`000?nQW];oXIkB00;oXIkB0_l0000:oj>Yf`03o`00
0?n_[=Co[jcD00[o[jcD00?o0000okR_dOnh[m402_nh[m400ol0003o_[??okjcc`08okjcc`03o`00
0?o2^=3o`[S@00[o`[S@00?o0000olJndoo6_]<01_o6_]<00ol0003ocK[8olfjb004olfjb003o`00
0?oBbM7od/WA00Wod/WA00?o0000om_8a_oKb<H01?oKb<H00ol0003oh>CFon3TeP05on3TeP03o`00
0?o]j<SokNS800OokNS80ol0000=ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool0<?ooool3o`0002?ooooo00?o6U?<o`000?m2N=l02om2
N=l2o`0001;oRIWM00Co0000oj6Nd_l0003o00003?nSZM/00ol0003o[jcDojn/e00;ojn/e003o`00
0?nh[m7o^:oA00So^:oA00?o0000okjcconn/ll02Onn/ll00ol0003o`[S@ol:hd00:ol:hd003o`00
0?o6_]?oa[kC00Ooa[kC0_l00003olfjb003o`000?oBbM7od/WA00_od/WA00?o0000om_8a_oKb<H0
0_oKb<H00ol0003oh>CFon3TeP06on3TeP03o`000?o]j<SokNS800KokNS800?o0000ol;k__l00000
3oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo000:ooooo`Co000000?o
410@ooooooooool00oooool00ol0003oooooooooo`0/ooooo`Co00009oooool2o`0000_o@WSO0_mO
T^X2o`00017oRIWM0_l0000>oj>Yf`03o`000?n_[=Co[jcD00[o[jcD00?o0000okR_dOnh[m402?nh
[m400ol0003o_[??okjcc`08okjcc`03o`000?o2^=3o`[S@00[o`[S@00?o0000olJndoo6_]<02_o6
_]<00ol0003ocK[8o`00000?om;9d@04o`000?oKb<KoflS6o`0000[oh>CF00?o0000ongXb?o]j<P0
1?o]j<P00ol0003o`_^no`00000Aooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`?o0000;?oo
ool2o`0000[o@WSO00Go0000oenBj_mOT^[oGi;Zo`00000@ohVIg@03o`000?nAYnCo000000koXjWK
00?o0000ojn/e?n_[=@02On_[=@00ol0003o^:oAokR_d@08okR_d@03o`000?nn/loo_[??00So_[??
00?o0000ol:hd?o2^=002Oo2^=000ol0003oa[kColJnd`0<olJnd`03o`000?oBbM7od/WA00kod/WA
00?o0000om_8a_l000002ooPi=H00ol0003okNS8ongXb003ongXb004o`000?o2nkko0000o`0001;o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02Oooooo0ol0000`ooooo`?o00002?m2N=l00ol0003oGi;Z
oenBjP02oenBjP;o00003On9VMd01Ol0003oTJOToi6Wi?nAYnCo000000koXjWK00?o0000ojn/e?n_
[=@02On_[=@00ol0003o^:oAokR_d@02okR_d@_o00001Onn/ll00ol0003o`[S@ol:hd008ol:hd003
o`000?o6_]?oa[kC00_oa[kC00?o0000olS9fol000004OoBbM400ol0003oh>CFon3TeP0:on3TeP03
o`000?o]j<SokNS800;okNS800Co0000ol;k__l0003o00005?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09?ooool3o`0003Cooooo00Co0000o`0j]?l0003o00001_m2N=l00ol0003oGi;ZoenBjP04oenB
jP;o00002_n9VMd00ol0003oTJOToi6Wi003oi6Wi0;o00003?nSZM/00ol0003o[jcDojn/e008ojn/
e0Ko00001Onc^=d00ol0003o]k_LokNkg003okNkg0Oo00002Oo2^=000ol0003oa[kColJnd`0:olJn
d`05o`000?o8bM_ob<WKolS9fol000003_oBbM400ol0003odmkOo`00000<on3TeP05o`000?o]j<So
kNS8ongXb?l000000_o2nkh00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`Co0000>?ooool01?l0003o03Zdo`0j]?l00005od9hg`03o`000?mOT^[oGi;Z00KoGi;Z00?o
0000ohVIgOn9VMd01_n9VMd00ol0003oTJOToi6Wi006oi6Wi003o`000?nSZM_oXjWK00[oXjWK00?o
0000ojn/e?n_[=@01?n_[=@3o`000003ojffgol0003o/kSM00So/kSM00?o0000okNkg?ng^m`01ong
^m`00ol0003o^[kMokZng@03o`0000Go`[S@00?o0000olJndoo6_]<02Oo6_]<2o`0000Cob<WK00?o
0000om;9dOoBbM402_oBbM42o`0000;odmkO00?o0000on3Te_oPi=H02_oPi=H01?l0003okNS8ongX
b?l00002ol;k_P;o00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool3o`0003gooooo00?o
0000o`0j]?l0>[@00_l00003od9hg`03o`000?mOT^[oGi;Z00OoGi;Z0_l00006ohVIg@03o`000?nA
YnCoTJOT00OoTJOT00?o0000oj>YfonSZM/02_nSZM/00ol0003o[jcDojn/e003o`0000Go[KKO00?o
0000ok>hgOnc^=d01_nc^=d00ol0003o]k_LokNkg006okNkg003o`000?nj_]go^[kM00Co^[kM0ol0
00000oo2^=3o0000olJnd`0:olJnd`03o`000?o8bM_ob<WK00Gob<WK00?o0000om;9dOoBbM401ooB
bM42o`0000CodmkO00?o0000on3Te_oPi=H02_oPi=H00ol0003okNS8o`000002ol;k_P;o00006?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool3o`00047ooooo00Co0000o`0j]?l0>[Co03Zd0_l0
00000om2N=oo0000oenBjP0:oenBjP;o00000on9VMd00ol0003oTJOToi6Wi009oi6Wi003o`000?nS
ZM_oXjWK00WoXjWK0ol00008ojffg`03o`000?nc^=go/kSM00Ko/kSM00?o0000okNkg?ng^m`01_ng
^m`00ol0003o^[kMokZng@07okZng@03o`000?o6_]?oa[kC00Woa[kC00?o0000olS9foo8bM/01oo8
bM/00ol0003od/WAom;9d@05om;9d@03o`000?oCg]oodmkO00CodmkO00?o0000on3Te_oPi=H02_oP
i=H2o`0000?o`_^n00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hooooo`?o0000AOooool0
0ol0003o03Zdo`0j]002o`0j]003od9hgol0003oGi;Z00coGi;Z00?o0000ohVIgOl000003OnAYn@2
o`0000OoXjWK0_l000000onT]>Co0000ojffg`08ojffg`03o`000?nc^=go/kSM00Ko/kSM00?o0000
okNkg?ng^m`01Ong^m`00ol0003o^[kMokZng@07okZng@?o_<;O00?o0000olJndoo6_]<01_o6_]<0
0ol0003ob<WKolS9f`08olS9f`03o`000?oBbM7od/WA00?od/WA0_l00007om?Ng`03o`000?oPi=Ko
h>CF00Woh>CF0_l00003ol;k_P03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0Dooooo`Co0000BOooool00ol0
003o03Zdo`0j]002o`0j]0;o00003OmOT^X2o`0000ooTJOT00?o0000oj>YfonSZM/00_nSZM/2o`00
00CoY;CT00?o0000ojffgon]]]l01on]]]l00ol0003o/kSMok>hg@05ok>hg@03o`000?ng^mco]k_L
00Go]k_L00?o0000okZngOnj_]d01Onj_]d00ol0003o_<;Ookc2g`03okc2g`03o`000?o6_]?oa[kC
00?oa[kC0_l0000<olS9f`03o`000?oBbM7od/WA00;o00002OoCg]l00ol0003oh>CFon3TeP07on3T
eP;o000000Gob?gRo`000?o2nkko`_^no`00000Mooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`0004kooooo0_l00002o`0j
]004o`000?l>N>;o0000o`0000_oGi;Z00Co0000ogJUl?l0003o00003_nAYn@01?l0003oXjWKo`00
0?l00007ojBdi003o`000?n]]]oo[KKO00Ko[KKO00?o0000ok>hgOnc^=d01?nc^=d00ol0003o]k_L
okNkg005okNkg003o`000?nj_]go^[kM00Go^[kM00?o0000okc2gonl`]l01Onl`]l01Ol0003oa[kC
olJndoo6_]?o000000kob<WK00?o0000om;9dOl000002ooCg]l00ol0003oh>CFon3TeP05on3TeP;o
00000_o8oN800ol0003o`_^nol;k_P02o`0001kooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000Doooool2o`000004o`0j
]?l0003o3WSRo`ihhP;o00002OmOT^X01?l0003oMZG`ogJUl?mfYO02o`0000goTJOT0_l00009ojBd
i003o`000?n]]]oo[KKO00Go[KKO00?o0000ok>hgOnc^=d01?nc^=d00ol0003o]k_LokNkg004okNk
g003o`000?nj_]go^[kM00Go^[kM00?o0000okc2gonl`]l01onl`]l00ol0003oa[kCo`00000@olS9
f`03o`000?oCg]oodmkO00[odmkO00?o0000on3Te_oPi=H00ooPi=H2o`0000?ob?gR00Go0000ol;k
__o2nkko`_^no`00000Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool0
01;ooooo00?o0000ooooooooool02oooool3o`0005Sooooo00?o0000o`0j]?l000000ol>N>82o`00
00KoGi;Z00?o0000ogJUl?mfYO001?mfYO02o`0000[oTJOT00?o0000oiRdjonH]>/00_l00008ojBd
i003o`000?n]]]oo[KKO00Go[KKO00?o0000ok>hgOnc^=d00onc^=d00ol0003o]k_LokNkg004okNk
g003o`000?nj_]go^[kM00Co^[kM00?o0000okc2gonl`]l02Onl`]l00ol0003ob<WKolS9f`0;olS9
f`?o000000?oamSVo`000?oCg]l02ooCg]l00ol0003oh>CFon3TeP02on3TeP03o`000?o8oN;ob?gR
00;ob?gR00Go0000ol;k__o2nkko`_^no`00000Rooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01Oooool001;ooooo00?o0000ooooooooool01oooool4o`0005cooooo0ol00004o`ih
hP03o`000?mOT^[oGi;Z00?oGi;Z00?o0000ogJUl?mfYO001_mfYO02o`0000OoTJOT00?o0000oiRd
jonH]>/00onH]>/00ol0003oY;CTojBdi006ojBdi003o`000?n]]]oo[KKO00Co[KKO00?o0000ok>h
gOnc^=d00onc^=d00ol0003o]k_LokNkg003okNkg003o`000?nj_]go^[kM00Co^[kM00?o0000okc2
gonl`]l02?nl`]l00ol0003o_<WTo`00000;olS9f`;o00001?o7f>H00ol0003odmkOom?Ng`0:om?N
g`03o`000?oPi=Koh>CF00;o00001Oo8oN801?l0003o`_^no`000?l0000Tooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01?ooool3o`00
06;ooooo0_l00004o`ihhP;o00000omOT^X00ol0003oMZG`ogJUl008ogJUl0;o00001?nAYn@00ol0
003oV;C[oiRdj`05oiRdj`;o00001onT]>@00ol0003o[KKOojffg`03ojffg`03o`000?nc^=go/kSM
00?o/kSM00?o0000okNkg?ng^m`00ong^m`00ol0003o^[kMokZng@03okZng@03o`000?nl`]oo_<;O
00Ko_<;O0_l00004okc9i003o`000?o8bM_ob<WK00Gob<WK0ol00006olOHiP03o`000?oCg]oodmkO
00[odmkO0ol00006olSmhP03o`000?o2nkko000002Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000Ioooool00ol0003o
3WSRo`ihhP03o`ihhP03o`000?mOT^[o000000goMZG`0_l000000onAYnCo0000oiRdj`09oiRdj`;o
00001_nT]>@01?l0003o[KKOojffgon]]]l>o`0000Co^[kM00?o0000okc2gonl`]l01Onl`]l2o`00
00Oo_<WT00?o0000olS9foo8bM/00_o8bM/2o`0000WoamSV00?o0000om?NgooCg]l02_oCg]l00ol0
003ob?gRolSmhP05olSmhP03o`000?o2nkko000002Sooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0006_ooooo0_l00005o`ihhP?o
00003OmfYO03o`0000_oV;C[00?o0000ojBdi?nT]>@00onT]>@4o`0000;oZ<7/00?o0000oj_2jon[
`^/00_n[`^/00ol0003oZl?[oj_3j`02oj_3j`06o`000?n/a>_o0000o`000?nj_]go00001onl`]l0
0ol0003o_<WTokc9i007okc9i003o`000?o8bM_o000000;o00002oo7f>H00ol0003odmkOom?Ng`06
om?Ng`?o000000?o`o;`o`000?o8oN801Oo8oN83o`0002[ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`04ooooo`004Oooool2o`00073ooooo0_l00003o`ihhP03o`000?m;WoGoBioe
00Co00002OmfYO000ol0003oR;GcohRel`03o`0000WoV;C[0_l000000onT]>Co0000o`000003ojC0
k@05o`000?nX`NcoZ<7/ojS1k?l000000on[`^/01Ol0003oZl?[oj_3jon[`n_o000000?o[<C[0_l0
0006okc2g`;o00002onlbN@00ol0003oamSVolOHiP0<olOHiP03o`000?oCg]oodmkO00?odmkO0ol0
0003ol?bl003o`000?o8oN;ob?gR00Gob?gR00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06oooooo0_l00002
o`ihhP03o`000?m;WoGoBioe00?oBioe0ol00006ogJUl003o`000?n8]O?oR;Gc00?oR;Gc0ol00008
oiRdj`;o00001OnT`>d01?l0003oZ<7/ojS1k?l00003oj_2j`04o`000?n[`n_oZl?[o`0000?o[<C[
00Co0000ojc4k?n/a>co[<C/0_l000000onl`]oo0000o`000009okc9i0?o000000?o^M7/o`000?o7
f>H03Oo7f>H01?l0003odmkOom?NgooCg]l2o`0000Go`o;`00?o0000olSmh_o8oN801Oo8oN800ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool001Co
oooo0_l0001aooooo`04o`000?l>N>;o3WSRo`0000OoBioe1?l000000omfYO3o0000ohRel`08ohRe
l`?o00001OnH]>/01?l0003oW/3`o`000?l00004ojC0k@04o`000?nX`NcoZ<7/o`0000;oZl;[00Go
0000oj_3jon[`n_o0000ojc4j`02o`0000Go[<C/0_l00008okc9i0?o00001?nidN`00ol0003oamSV
olOHiP0<olOHiPCo00001oo3l_000ol0003ob?gRolSmhP04olSmhP03o`000?oooooooooo02oooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0003oooooo`00
001_ooooo`?o00002om;WoD5o`0000WoR;Gc0ol000000onH]>_o0000oik0l003oik0l0;o00000onT
`>d01Ol0003oZ<7/o`000?n[`^_o000000;oZl?[00?o0000ojc4jol000001?n/a>`3o`000003ojc6
kOl0003o_<WT00Co_<WT0ol00007okWAk003o`000?o7f>KoamSV00[oamSV00?o0000olOHi_l00000
2Oo3l_000ol0003ob?gRolSmhP03olSmhP;o0000<_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo000Gooooo`;o0000LOooool2o`0000_oBioe00Co0000ogJfn_mf]_[oM[Kj
1Ol00007ohRel`Co00001?nN`?03o`000009ojC0kOl0003o0000oj_2jol0003oZl?[o`000?n/a>_o
000000;o[<C/0ol00005ojc6k@03o`000?nlbNCo000000;o00002_nidN`00ol0003oamSVolOHiP05
olOHiPGo00000_njiO@00ol0003o`o;`ol?bl006ol?bl003o`000?o8oN;ob?gR00;ob?gR0_l0000e
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool001Sooooo0_l0001boooo
o`?o00002Om;WoD00ol0003oM[KjogJfnP05ogJfnPCo00000on8]O<01?l0003oV<7doiS1m?nH`O@5
o`0000;oW/3`1Ol000000on[`n_o0000o`000003o`0000Co[<K]1_l0000=okWAk003o`000?o7f>Ko
amSV00Go00001_njiO@00ol0003o`o;`ol?bl006ol?bl003o`000?o8oN;ob?gR00?o0000>?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo
077ooooo1_l00004od^Om@03o`000?mf]_[oM[Kj00[oM[Kj2_l000000onH`OCo0000o`00000?o`00
00CoZ/W`00?o0000okWAk?nidN`01OnidN`00ol0003o^M7/okWAk004okWAk0?o00002_njiO@00ol0
003o`o;`ol?bl007ol?bl0Co0000>oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00?ooooo000Kooooo`;o000000?oooooo`000?ooool0L?ooool2o`0000;o5i3W0ol000000om;WoGo
0000ogJfnP0<ogJfnP03o`000?nDa?OoU<Cg00KoU<Cg7_l00007ok3Hm@03o`000?njiOCo^^Gd00Wo
^^Gd00?o0000ol?bl?o3l_001oo3l_03o`0003kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`03ooooo`007Oooool2o`0007;ooooo00Co0000ooooool0003o00000olGT>L>o`000003
ogJfn_l0003o000000Ko000000?oT/Kio`000?l000000ol000000onAb?[o0000o`000006o`0000Oo
Y/cc00?o0000ok3HmOn`f?D02on`f?D00ol0003o^^Gdok[Um00:ok[Um003o`000?o3l_3o`o;`00Co
`o;`1?l00010ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001kooooo
00?o0000ooooooooool0L?ooool01?l0003oooooooooooooool3o`0000?o5i3W0_l0000<ofBho003
o`000?nBa_WoT/Ki00Co00000_nAaoX2o`000006oi78n_l0003o0000oiC:n_l0003oVLci0_l00002
oj3=m`Co00000_nVc?<00ol0003o/=Seok3Hm@0;ok3Hm@03o`000?njiOCo^^Gd00[o^^Gd00Co0000
ol?bl?o3l_3o`o;`1_l00013ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00ooo
ool001oooooo0_l0001`ooooo`03o`000?oooooooooo00?ooooo00Co0000o`1ocOl0003o00000_lG
T>L2o`0000KoI;Sl0_l00003ofBho0;o00001?nAaoX2o`0000;oTLSj00?o0000oi;8n_l000000_nD
b_X00ol0003oVLcioiW<n@02o`0000CoX<gg2Ol00007ok3Hm@03o`000?njiOCo^^Gd00Wo^^Gd1Ol0
00001?n1j>So0000o`000?l00016ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
0oooool0027ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`06ooooo`05o`000?l0
Olgo07o=o`1ocOlGT>L01_l00007oeZio0;o000000?oTLOjo`000?nAb?X00onAb?X01?l0003oT/Sj
oi;8n_l00002oiC:nP04o`000?nIc?WoVLcioiW<n@;o000000?oX<ggo`000?nNf_`02?nNf_`Do`00
00;oPNSX1?l00019ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;o
oooo0ol0001/ooooo`03o`000?oooooooooo00Sooooo0ol00002o`1oc@?o00002_mJ^O`3o`0000;o
TLSj00Go0000oi;8n_nBb?[oT/Sjo`000003oiC:nP03o`000?nIc?WoVLci00Go00002onNf_`2o`00
00[oUnOk0_l00003oh7Xj0Co0000C?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo000Tooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool02oooool3o`0000;o
07o=0_l00002oeZio0Co00001OmH_O`=o`0000GoQ]Ko0ol00007oikJo003o`000?nGio_oUnOk00Oo
UnOk0ol00003oh7Xj0?o0000D?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;o
oooo000Uooooo`;o0000J_ooool00ol0003oooooooooo`0>ooooo`04o`000?l0O/3o0000o`1oc@;o
00002OmH_O`00ol0003oH<?mof33o@03of33o@03o`000?m_c?koKlcn00CoKlcn00?o0000ohKFoon6
e_l01On6e_l3o`0000;oW][l0_l00008oiOWn`;o000000?oPNSXo`000?l000000ol0001Cooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`0Cooooo`03o`000?l0O/3o000000Co00000_mH_O`00ol0003oH<?m
of33o@04of33o@03o`000?m_c?koKlcn00GoKlcn0_l00007ohKFoa3o0000FOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00;ooooo000Xooooo`03o`000?oooooo000006Kooooo00?o
0000ooooooooool05oooool2o`000003o`1n`?l0003o000000Go00000omP`od00ol0003oKlcnofo<
oP06ofo<oP?oQ]Ko1?l00005oegAl@Go0000H?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo000Nooooo`Co000000?o410@ooooooooool01?ooool2o`0006Kooooo00?o0000
ooooooooool07oooool2o`2=aQ7o00000omMdO44o`0006Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0;Oooool8o`0006_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`005Oooool6o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?o
oooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0023ooooo00?o
0000ooooooooool03?ooool2o`00063ooooo00?o0000ooooooooool0X_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo00gooooo0_l0001O
ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01
ooooo`008?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Nooooo`03
oeEEEOmVIVKo000001;ooooo0_l000000ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo0:Go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
000fooooo`;o0000F?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003Sooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00>Oooool0
1?l0003oooooooooool0001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool02Ooo
ool1o`00007ooooo0Oooool003[ooooo0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000
ooooooooool02?ooool1o`00007ooooo0Oooool003cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000mooooo`;o
0000DOooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo000oooooo`03o`000?oooooo000004kooooo00?o0000ooooooooool0[?ooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool1ooooo`00@?ooool2o`0004kooooo00?o0000ooooooooool0[Ooo
ool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o0000
ooooooooool0[_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1o`00
007ooooo0014ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`00A_ooool2o`0004Sooooo00?o0000ooooooooool0
/?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`0004Oooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool00016ooooo`03o`000?oooooooooo
0;;ooooo00Go0000ooooooooooooooooo`000001ooooo`00:_ooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o0000@oooool00ol0003oooooooooo`2c
ooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0/ooo
ool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0]?ooool00ol0003oooooooooo`01o`000000<_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool02?ooool2o`00043ooooo00?o0000ooooooooool0]Oooool1o`00007o
oooo0Ol0000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00[o
oooo0_l0000nooooo`03o`000?oooooooooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`Co00002_ooool2o`0003gooooo00?o0000ooooooooool0]Oooool3o`000000
Doooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool0/?ooool5o`0000?o
oooo001Dooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0[?ooool4o`0000So
oooo001Eooooo`?o0000>?ooool00ol0003oooooooooo`2Xooooo`Co00003?ooool005Oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0000e
ooooo`03o`000?oooooooooo0:3ooooo1?l0000Eooooo`00F_ooool00ol0003oooooo`00000boooo
o`03o`000?oooooooooo09cooooo1?l0000Iooooo`00Foooool2o`0003;ooooo00?o0000oooooooo
ool0Uoooool5o`0001gooooo001Mooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
Toooool4o`0002;ooooo001Nooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0
S_ooool5o`0002Kooooo001Oooooo`?o0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000:ooo
ool0067ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000;oooool0
05?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o0000:oooool00ol0003oooooooooo`21
ooooo`Go0000<oooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooo
000002Sooooo00?o0000ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?oooooooooo
ooooool@41003Oooool2o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo001Coooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo07Cooooo1Ol00010ooooo`00Doooool01Ol0003ooooooooooooooooo0000013ooooo00Co0000
oooooooooooo00008oooool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go410@
oooooooooooooooooa0@400Aooooo`?o00008oooool00ol0003oooooooooo`1[ooooo`Go0000BOoo
ool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00008oooool00ol0003ooooooooo
o`1Wooooo`Co0000C_ooool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o000000?o
ooooo`000?ooool07_ooool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0000O
ooooo`03o`000?oooooooooo05kooooo1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo05[ooooo1?l0001Kooooo`00L?ooool2o`0001gooooo00?o0000oooooooo
ool0E_ooool4o`0005oooooo001booooo`03o`000?oooooo000001[ooooo00?o0000ooooooooool0
DOooool5o`0006?ooooo001cooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000J?oo
ool007Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000K?ooool0
07Kooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`oooo
o`00N?ooool2o`0001Gooooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0>oooool5o`0007Wooooo001jooooo`;o000000?o
ooooo`000?ooool04?ooool00ol0003oooooooooo`0gooooo`Co0000O_ooool006?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo
0_l0000Aooooo`03o`000?oooooooooo03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03o`00
0?oooooooooo02oooooo1Ol00026ooooo`00Hoooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo
1?l0002;ooooo`00Hoooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1_ooool3o`0000_ooooo00?o0000ooooooooool09oooool4o`0008oooooo001Sooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Rooooo`Go0000Toooool006?ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`0Nooooo`Co0000V?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03o`000?oooooooooo00gooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1Ol0002Loooo
o`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0003o
ooooooooo`0Aooooo`Co0000YOooool008Wooooo0_l00003ooooo`03o`000?oooooooooo00cooooo
1Ol0002Yooooo`00R_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002^ooooo`00Rooo
ool2o`000003ooooool0003ooooo00Gooooo1?l0002booooo`00SOooool2o`000003ooooool0003o
000000?o0000]_ooool008kooooo0_l0002kooooo`00oooooom<ooooo`00oooooom<ooooo`00Q?oo
ool4o`000003oa0@4?oooooooooo0<3ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026oooo
o`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`00
0?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooo
oooo0<;ooooo0024ooooo`03oeEEEOmVIVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.54166 .55464 m .54381 .59612 L .61622 .58621 L p .707 .589 .722 r
F P
0 g
s
.61622 .58621 m .60421 .54402 L .54166 .55464 L p .707 .589 .722 r
F P
0 g
s
.62617 .62957 m .61622 .58621 L .54381 .59612 L p .706 .562 .689 r
F P
0 g
s
.60421 .54402 m .61622 .58621 L .68396 .56156 L p .642 .553 .739 r
F P
0 g
s
.61622 .58621 m .62617 .62957 L .7025 .60407 L p .631 .516 .705 r
F P
0 g
s
.7025 .60407 m .68396 .56156 L .61622 .58621 L p .631 .516 .705 r
F P
0 g
s
.48298 .55307 m .47759 .59219 L .54381 .59612 L p .758 .623 .711 r
F P
0 g
s
.54381 .59612 m .54166 .55464 L .48298 .55307 L p .758 .623 .711 r
F P
0 g
s
.54554 .63754 m .54381 .59612 L .47759 .59219 L p .764 .603 .679 r
F P
0 g
s
.54381 .59612 m .54554 .63754 L .62617 .62957 L p .706 .562 .689 r
F P
0 g
s
.48959 .51362 m .48298 .55307 L .54166 .55464 L p .749 .642 .741 r
F P
0 g
s
.54166 .55464 m .53914 .5139 L .48959 .51362 L p .749 .642 .741 r
F P
0 g
s
.53914 .5139 m .54166 .55464 L .60421 .54402 L p .706 .615 .753 r
F P
0 g
s
.60421 .54402 m .59057 .5039 L .53914 .5139 L p .706 .615 .753 r
F P
0 g
s
.59057 .5039 m .60421 .54402 L .6619 .52143 L p .651 .587 .77 r
F P
0 g
s
.68396 .56156 m .6619 .52143 L .60421 .54402 L p .642 .553 .739 r
F P
0 g
s
.63362 .67296 m .62617 .62957 L .54554 .63754 L p .704 .533 .654 r
F P
0 g
s
.62617 .62957 m .63362 .67296 L .71652 .64772 L p .618 .476 .666 r
F P
0 g
s
.71652 .64772 m .7025 .60407 L .62617 .62957 L p .618 .476 .666 r
F P
0 g
s
.47759 .59219 m .47342 .63034 L .54554 .63754 L p .764 .603 .679 r
F P
0 g
s
.54681 .67808 m .54554 .63754 L .47342 .63034 L p .769 .581 .644 r
F P
0 g
s
.54554 .63754 m .54681 .67808 L .63362 .67296 L p .704 .533 .654 r
F P
0 g
s
.49738 .47472 m .48959 .51362 L .53914 .5139 L p .739 .66 .772 r
F P
0 g
s
.53914 .5139 m .53629 .47463 L .49738 .47472 L p .739 .66 .772 r
F P
0 g
s
.53629 .47463 m .53914 .5139 L .59057 .5039 L p .703 .639 .783 r
F P
0 g
s
.59057 .5039 m .5757 .46643 L .53629 .47463 L p .703 .639 .783 r
F P
0 g
s
.5757 .46643 m .59057 .5039 L .63728 .4845 L p .658 .619 .799 r
F P
0 g
s
.6619 .52143 m .63728 .4845 L .59057 .5039 L p .651 .587 .77 r
F P
0 g
s
.63817 .71501 m .63362 .67296 L .54681 .67808 L p .7 .499 .613 r
F P
0 g
s
.63362 .67296 m .63817 .71501 L .72513 .69098 L p .602 .429 .62 r
F P
0 g
s
.72513 .69098 m .71652 .64772 L .63362 .67296 L p .602 .429 .62 r
F P
0 g
s
.47342 .63034 m .47046 .66707 L .54681 .67808 L p .769 .581 .644 r
F P
0 g
s
.54758 .71688 m .54681 .67808 L .47046 .66707 L p .773 .556 .605 r
F P
0 g
s
.54681 .67808 m .54758 .71688 L .63817 .71501 L p .7 .499 .613 r
F P
0 g
s
.44565 .50314 m .43198 .5403 L .48298 .55307 L p .784 .667 .734 r
F P
0 g
s
.48298 .55307 m .48959 .51362 L .44565 .50314 L p .784 .667 .734 r
F P
0 g
s
.47759 .59219 m .48298 .55307 L .43198 .5403 L p .797 .652 .702 r
F P
0 g
s
.43198 .5403 m .42124 .57688 L .47759 .59219 L p .797 .652 .702 r
F P
0 g
s
.47342 .63034 m .47759 .59219 L .42124 .57688 L p .809 .637 .669 r
F P
0 g
s
.46227 .46639 m .44565 .50314 L .48959 .51362 L p .769 .681 .766 r
F P
0 g
s
.48959 .51362 m .49738 .47472 L .46227 .46639 L p .769 .681 .766 r
F P
0 g
s
.50623 .43744 m .49738 .47472 L .53629 .47463 L p .725 .678 .804 r
F P
0 g
s
.53629 .47463 m .53317 .43754 L .50623 .43744 L p .725 .678 .804 r
F P
0 g
s
.53317 .43754 m .53629 .47463 L .5757 .46643 L p .697 .664 .813 r
F P
0 g
s
.6619 .52143 m .68396 .56156 L .73312 .52523 L p .552 .512 .765 r
F P
0 g
s
.68396 .56156 m .7025 .60407 L .75756 .56393 L p .523 .46 .727 r
F P
0 g
s
.75756 .56393 m .73312 .52523 L .68396 .56156 L p .523 .46 .727 r
F P
0 g
s
.63728 .4845 m .6619 .52143 L .70407 .48979 L p .578 .558 .796 r
F P
0 g
s
.73312 .52523 m .70407 .48979 L .6619 .52143 L p .552 .512 .765 r
F P
0 g
s
.5757 .46643 m .5599 .43197 L .53317 .43754 L p .697 .664 .813 r
F P
0 g
s
.5599 .43197 m .5757 .46643 L .61093 .45119 L p .663 .651 .827 r
F P
0 g
s
.63728 .4845 m .61093 .45119 L .5757 .46643 L p .658 .619 .799 r
F P
0 g
s
.42124 .57688 m .41326 .61223 L .47342 .63034 L p .809 .637 .669 r
F P
0 g
s
.47046 .66707 m .47342 .63034 L .41326 .61223 L p .818 .62 .634 r
F P
0 g
s
.7025 .60407 m .71652 .64772 L .77606 .60486 L p .488 .399 .681 r
F P
0 g
s
.77606 .60486 m .75756 .56393 L .7025 .60407 L p .488 .399 .681 r
F P
0 g
s
.61093 .45119 m .63728 .4845 L .67167 .45824 L p .601 .6 .823 r
F P
0 g
s
.70407 .48979 m .67167 .45824 L .63728 .4845 L p .578 .558 .796 r
F P
0 g
s
.48162 .43138 m .46227 .46639 L .49738 .47472 L p .75 .695 .799 r
F P
0 g
s
.49738 .47472 m .50623 .43744 L .48162 .43138 L p .75 .695 .799 r
F P
0 g
s
.63953 .75426 m .63817 .71501 L .54758 .71688 L p .693 .46 .565 r
F P
0 g
s
.63817 .71501 m .63953 .75426 L .72768 .73209 L p .581 .372 .562 r
F P
0 g
s
.72768 .73209 m .72513 .69098 L .63817 .71501 L p .581 .372 .562 r
F P
0 g
s
.47046 .66707 m .46868 .70205 L .54758 .71688 L p .773 .556 .605 r
F P
0 g
s
.54782 .75302 m .54758 .71688 L .46868 .70205 L p .774 .526 .56 r
F P
0 g
s
.54758 .71688 m .54782 .75302 L .63953 .75426 L p .693 .46 .565 r
F P
0 g
s
.41326 .61223 m .40774 .64609 L .47046 .66707 L p .818 .62 .634 r
F P
0 g
s
.46868 .70205 m .47046 .66707 L .40774 .64609 L p .826 .6 .596 r
F P
0 g
s
.43308 .44981 m .40866 .48265 L .44565 .50314 L p .794 .706 .767 r
F P
0 g
s
.44565 .50314 m .46227 .46639 L .43308 .44981 L p .794 .706 .767 r
F P
0 g
s
.43198 .5403 m .44565 .50314 L .40866 .48265 L p .813 .693 .732 r
F P
0 g
s
.61093 .45119 m .58346 .42155 L .5599 .43197 L p .663 .651 .827 r
F P
0 g
s
.58346 .42155 m .61093 .45119 L .63702 .43084 L p .622 .639 .846 r
F P
0 g
s
.67167 .45824 m .63702 .43084 L .61093 .45119 L p .601 .6 .823 r
F P
0 g
s
.40866 .48265 m .38852 .51678 L .43198 .5403 L p .813 .693 .732 r
F P
0 g
s
.42124 .57688 m .43198 .5403 L .38852 .51678 L p .829 .679 .698 r
F P
0 g
s
.51596 .403 m .50623 .43744 L .53317 .43754 L p .707 .697 .838 r
F P
0 g
s
.53317 .43754 m .52983 .40333 L .51596 .403 L p .707 .697 .838 r
F P
0 g
s
.52983 .40333 m .53317 .43754 L .5599 .43197 L p .688 .688 .845 r
F P
0 g
s
.71652 .64772 m .72513 .69098 L .78745 .64665 L p .445 .324 .621 r
F P
0 g
s
.78745 .64665 m .77606 .60486 L .71652 .64772 L p .445 .324 .621 r
F P
0 g
s
.46141 .4196 m .43308 .44981 L .46227 .46639 L p .771 .716 .802 r
F P
0 g
s
.46227 .46639 m .48162 .43138 L .46141 .4196 L p .771 .716 .802 r
F P
0 g
s
.5599 .43197 m .54339 .40068 L .52983 .40333 L p .688 .688 .845 r
F P
0 g
s
.54339 .40068 m .5599 .43197 L .58346 .42155 L p .667 .682 .855 r
F P
0 g
s
.50321 .39963 m .48162 .43138 L .50623 .43744 L p .725 .708 .835 r
F P
0 g
s
.50623 .43744 m .51596 .403 L .50321 .39963 L p .725 .708 .835 r
F P
0 g
s
.38852 .51678 m .37269 .55114 L .42124 .57688 L p .829 .679 .698 r
F P
0 g
s
.41326 .61223 m .42124 .57688 L .37269 .55114 L p .841 .664 .662 r
F P
0 g
s
.49286 .39344 m .46141 .4196 L .48162 .43138 L p .74 .725 .838 r
F P
0 g
s
.48162 .43138 m .50321 .39963 L .49286 .39344 L p .74 .725 .838 r
F P
0 g
s
.46868 .70205 m .46809 .73502 L .54782 .75302 L p .774 .526 .56 r
F P
0 g
s
.5475 .7856 m .54782 .75302 L .46809 .73502 L p .772 .488 .503 r
F P
0 g
s
.54782 .75302 m .5475 .7856 L .63753 .78925 L p .683 .41 .503 r
F P
0 g
s
.63753 .78925 m .63953 .75426 L .54782 .75302 L p .683 .41 .503 r
F P
0 g
s
.40774 .64609 m .40446 .67847 L .46868 .70205 L p .826 .6 .596 r
F P
0 g
s
.46809 .73502 m .46868 .70205 L .40446 .67847 L p .831 .575 .552 r
F P
0 g
s
.58346 .42155 m .55521 .39545 L .54339 .40068 L p .667 .682 .855 r
F P
0 g
s
.55521 .39545 m .58346 .42155 L .60094 .40755 L p .642 .676 .867 r
F P
0 g
s
.63702 .43084 m .60094 .40755 L .58346 .42155 L p .622 .639 .846 r
F P
0 g
s
.63953 .75426 m .63753 .78925 L .72382 .76929 L p .552 .299 .486 r
F P
0 g
s
.72382 .76929 m .72768 .73209 L .63953 .75426 L p .552 .299 .486 r
F P
0 g
s
.37269 .55114 m .3609 .58501 L .41326 .61223 L p .841 .664 .662 r
F P
0 g
s
.40774 .64609 m .41326 .61223 L .3609 .58501 L p .851 .647 .626 r
F P
0 g
s
.63702 .43084 m .67167 .45824 L .68822 .42887 L p .522 .581 .855 r
F P
0 g
s
.67167 .45824 m .70407 .48979 L .72304 .45431 L p .467 .523 .832 r
F P
0 g
s
.72304 .45431 m .68822 .42887 L .67167 .45824 L p .467 .523 .832 r
F P
0 g
s
.72513 .69098 m .72768 .73209 L .79084 .68767 L p .387 .227 .54 r
F P
0 g
s
.79084 .68767 m .78745 .64665 L .72513 .69098 L p .387 .227 .54 r
F P
0 g
s
.4474 .40299 m .41177 .42577 L .43308 .44981 L p .786 .744 .815 r
F P
0 g
s
.43308 .44981 m .46141 .4196 L .4474 .40299 L p .786 .744 .815 r
F P
0 g
s
.40866 .48265 m .43308 .44981 L .41177 .42577 L p .815 .739 .78 r
F P
0 g
s
.70407 .48979 m .73312 .52523 L .75372 .48393 L p .403 .454 .799 r
F P
0 g
s
.75372 .48393 m .72304 .45431 L .70407 .48979 L p .403 .454 .799 r
F P
0 g
s
.41177 .42577 m .38004 .45245 L .40866 .48265 L p .815 .739 .78 r
F P
0 g
s
.38852 .51678 m .40866 .48265 L .38004 .45245 L p .838 .729 .744 r
F P
0 g
s
.60094 .40755 m .63702 .43084 L .6503 .40789 L p .57 .629 .871 r
F P
0 g
s
.68822 .42887 m .6503 .40789 L .63702 .43084 L p .522 .581 .855 r
F P
0 g
s
.52983 .40333 m .52632 .37269 L .51596 .403 L closepath p .694 .725 .874 r
F P
0 g
s
.54339 .40068 m .52632 .37269 L .52983 .40333 L closepath p .686 .719 .875 r
F P
0 g
s
.51596 .403 m .52632 .37269 L .50321 .39963 L closepath p .697 .729 .875 r
F P
0 g
s
.48598 .38504 m .4474 .40299 L .46141 .4196 L p .749 .745 .848 r
F P
0 g
s
.46141 .4196 m .49286 .39344 L .48598 .38504 L p .749 .745 .848 r
F P
0 g
s
.55521 .39545 m .52632 .37269 L .54339 .40068 L closepath p .674 .714 .879 r
F P
0 g
s
.38004 .45245 m .35283 .48207 L .38852 .51678 L p .838 .729 .744 r
F P
0 g
s
.37269 .55114 m .38852 .51678 L .35283 .48207 L p .857 .717 .706 r
F P
0 g
s
.73312 .52523 m .75756 .56393 L .77914 .51723 L p .324 .366 .751 r
F P
0 g
s
.77914 .51723 m .75372 .48393 L .73312 .52523 L p .324 .366 .751 r
F P
0 g
s
.3609 .58501 m .35277 .618 L .40774 .64609 L p .851 .647 .626 r
F P
0 g
s
.40446 .67847 m .40774 .64609 L .35277 .618 L p .858 .628 .588 r
F P
0 g
s
.60094 .40755 m .56396 .38822 L .55521 .39545 L p .642 .676 .867 r
F P
0 g
s
.56396 .38822 m .60094 .40755 L .61019 .39151 L p .614 .672 .882 r
F P
0 g
s
.6503 .40789 m .61019 .39151 L .60094 .40755 L p .57 .629 .871 r
F P
0 g
s
.50321 .39963 m .52632 .37269 L .49286 .39344 L closepath p .698 .73 .875 r
F P
0 g
s
.56396 .38822 m .52632 .37269 L .55521 .39545 L closepath p .66 .712 .887 r
F P
0 g
s
.40446 .67847 m .40328 .70949 L .46809 .73502 L p .831 .575 .552 r
F P
0 g
s
.46873 .76564 m .46809 .73502 L .40328 .70949 L p .833 .543 .498 r
F P
0 g
s
.46809 .73502 m .46873 .76564 L .5475 .7856 L p .772 .488 .503 r
F P
0 g
s
.35283 .48207 m .33051 .5137 L .37269 .55114 L p .857 .717 .706 r
F P
0 g
s
.3609 .58501 m .37269 .55114 L .33051 .5137 L p .871 .701 .667 r
F P
0 g
s
.49286 .39344 m .52632 .37269 L .48598 .38504 L closepath p .699 .732 .876 r
F P
0 g
s
.75756 .56393 m .77606 .60486 L .79819 .55349 L p .222 .252 .681 r
F P
0 g
s
.79819 .55349 m .77914 .51723 L .75756 .56393 L p .222 .252 .681 r
F P
0 g
s
.56865 .37976 m .52632 .37269 L .56396 .38822 L closepath p .647 .715 .897 r
F P
0 g
s
.61019 .39151 m .56865 .37976 L .56396 .38822 L p .614 .672 .882 r
F P
0 g
s
.54661 .81372 m .5475 .7856 L .46873 .76564 L p .764 .435 .429 r
F P
0 g
s
.5475 .7856 m .54661 .81372 L .63217 .81869 L p .664 .343 .419 r
F P
0 g
s
.63217 .81869 m .63753 .78925 L .5475 .7856 L p .664 .343 .419 r
F P
0 g
s
.48335 .37534 m .44127 .38323 L .4474 .40299 L p .749 .765 .866 r
F P
0 g
s
.4474 .40299 m .48598 .38504 L .48335 .37534 L p .749 .765 .866 r
F P
0 g
s
.41177 .42577 m .4474 .40299 L .44127 .38323 L p .791 .776 .84 r
F P
0 g
s
.44127 .38323 m .40098 .39626 L .41177 .42577 L p .791 .776 .84 r
F P
0 g
s
.38004 .45245 m .41177 .42577 L .40098 .39626 L p .827 .782 .809 r
F P
0 g
s
.63753 .78925 m .63217 .81869 L .71361 .80101 L p .507 .198 .377 r
F P
0 g
s
.71361 .80101 m .72382 .76929 L .63753 .78925 L p .507 .198 .377 r
F P
0 g
s
.48598 .38504 m .52632 .37269 L .48335 .37534 L closepath p .699 .735 .879 r
F P
0 g
s
.72768 .73209 m .72382 .76929 L .78577 .7262 L p .303 .094 .421 r
F P
0 g
s
.78577 .7262 m .79084 .68767 L .72768 .73209 L p .303 .094 .421 r
F P
0 g
s
.35277 .618 m .34792 .65006 L .40446 .67847 L p .858 .628 .588 r
F P
0 g
s
.40328 .70949 m .40446 .67847 L .34792 .65006 L p .864 .605 .545 r
F P
0 g
s
.33051 .5137 m .31317 .5466 L .3609 .58501 L p .871 .701 .667 r
F P
0 g
s
.35277 .618 m .3609 .58501 L .31317 .5466 L p .882 .682 .627 r
F P
0 g
s
.40098 .39626 m .36339 .41423 L .38004 .45245 L p .827 .782 .809 r
F P
0 g
s
.35283 .48207 m .38004 .45245 L .36339 .41423 L p .858 .782 .775 r
F P
0 g
s
.56875 .37087 m .52632 .37269 L .56865 .37976 L closepath p .64 .72 .906 r
F P
0 g
s
.56865 .37976 m .61019 .39151 L .61021 .37489 L p .583 .672 .901 r
F P
0 g
s
.61021 .37489 m .56875 .37087 L .56865 .37976 L p .583 .672 .901 r
F P
0 g
s
.61019 .39151 m .6503 .40789 L .64954 .38464 L p .506 .624 .902 r
F P
0 g
s
.64954 .38464 m .61021 .37489 L .61019 .39151 L p .506 .624 .902 r
F P
0 g
s
.55562 .35499 m .52632 .37269 L .56425 .36235 L closepath p .637 .728 .914 r
F P
0 g
s
.48335 .37534 m .52632 .37269 L .48537 .36552 L closepath p .696 .742 .886 r
F P
0 g
s
.56425 .36235 m .52632 .37269 L .56875 .37087 L closepath p .637 .725 .912 r
F P
0 g
s
.54375 .34953 m .52632 .37269 L .55562 .35499 L closepath p .637 .729 .915 r
F P
0 g
s
.5299 .34666 m .52632 .37269 L .54375 .34953 L closepath p .639 .732 .916 r
F P
0 g
s
.51558 .34688 m .52632 .37269 L .5299 .34666 L closepath p .646 .738 .916 r
F P
0 g
s
.50242 .35036 m .52632 .37269 L .51558 .34688 L closepath p .659 .745 .914 r
F P
0 g
s
.49195 .35682 m .52632 .37269 L .50242 .35036 L closepath p .675 .749 .907 r
F P
0 g
s
.48537 .36552 m .52632 .37269 L .49195 .35682 L closepath p .688 .747 .896 r
F P
0 g
s
.6503 .40789 m .68822 .42887 L .6857 .39981 L p .408 .557 .892 r
F P
0 g
s
.6857 .39981 m .64954 .38464 L .6503 .40789 L p .408 .557 .892 r
F P
0 g
s
.44127 .38323 m .48335 .37534 L .48537 .36552 L p .737 .781 .888 r
F P
0 g
s
.77606 .60486 m .78745 .64665 L .80987 .59173 L p .084 .095 .572 r
F P
0 g
s
.80987 .59173 m .79819 .55349 L .77606 .60486 L p .084 .095 .572 r
F P
0 g
s
.40328 .70949 m .40426 .73917 L .46873 .76564 L p .833 .543 .498 r
F P
0 g
s
.47068 .79339 m .46873 .76564 L .40426 .73917 L p .829 .499 .428 r
F P
0 g
s
.46873 .76564 m .47068 .79339 L .54661 .81372 L p .764 .435 .429 r
F P
0 g
s
.36339 .41423 m .32942 .43688 L .35283 .48207 L p .858 .782 .775 r
F P
0 g
s
.33051 .5137 m .35283 .48207 L .32942 .43688 L p .886 .778 .737 r
F P
0 g
s
.56875 .37087 m .61021 .37489 L .60121 .35893 L p .554 .681 .923 r
F P
0 g
s
.60121 .35893 m .56425 .36235 L .56875 .37087 L p .554 .681 .923 r
F P
0 g
s
.48537 .36552 m .44434 .3628 L .44127 .38323 L p .737 .781 .888 r
F P
0 g
s
.40098 .39626 m .44127 .38323 L .44434 .3628 L p .78 .807 .875 r
F P
0 g
s
.68822 .42887 m .72304 .45431 L .71777 .41997 L p .279 .464 .863 r
F P
0 g
s
.71777 .41997 m .6857 .39981 L .68822 .42887 L p .279 .464 .863 r
F P
0 g
s
.44434 .3628 m .48537 .36552 L .49195 .35682 L p .715 .789 .91 r
F P
0 g
s
.31317 .5466 m .30081 .58014 L .35277 .618 L p .882 .682 .627 r
F P
0 g
s
.34792 .65006 m .35277 .618 L .30081 .58014 L p .89 .66 .584 r
F P
0 g
s
.34792 .65006 m .34617 .68124 L .40328 .70949 L p .864 .605 .545 r
F P
0 g
s
.40426 .73917 m .40328 .70949 L .34617 .68124 L p .867 .576 .494 r
F P
0 g
s
.44434 .3628 m .40368 .36494 L .40098 .39626 L p .78 .807 .875 r
F P
0 g
s
.36339 .41423 m .40098 .39626 L .40368 .36494 L p .822 .831 .856 r
F P
0 g
s
.56425 .36235 m .60121 .35893 L .58427 .34467 L p .54 .7 .943 r
F P
0 g
s
.58427 .34467 m .55562 .35499 L .56425 .36235 L p .54 .7 .943 r
F P
0 g
s
.61021 .37489 m .64954 .38464 L .63576 .36248 L p .435 .625 .933 r
F P
0 g
s
.63576 .36248 m .60121 .35893 L .61021 .37489 L p .435 .625 .933 r
F P
0 g
s
.72304 .45431 m .75372 .48393 L .74503 .44455 L p .103 .328 .801 r
F P
0 g
s
.74503 .44455 m .71777 .41997 L .72304 .45431 L p .103 .328 .801 r
F P
0 g
s
.32942 .43688 m .29996 .4638 L .33051 .5137 L p .886 .778 .737 r
F P
0 g
s
.31317 .5466 m .33051 .5137 L .29996 .4638 L p .909 .768 .693 r
F P
0 g
s
.54516 .83653 m .54661 .81372 L .47068 .79339 L p .745 .359 .323 r
F P
0 g
s
.54661 .81372 m .54516 .83653 L .62362 .84156 L p .63 .245 .296 r
F P
0 g
s
.62362 .84156 m .63217 .81869 L .54661 .81372 L p .63 .245 .296 r
F P
0 g
s
.45696 .3447 m .49195 .35682 L .50242 .35036 L p .686 .79 .929 r
F P
0 g
s
.49195 .35682 m .45696 .3447 L .44434 .3628 L p .715 .789 .91 r
F P
0 g
s
.72382 .76929 m .71361 .80101 L .77232 .7606 L p .172 0 .235 r
F P
0 g
s
.77232 .7606 m .78577 .7262 L .72382 .76929 L p .172 0 .235 r
F P
0 g
s
.78745 .64665 m .79084 .68767 L .81343 .63075 L p 0 0 .399 r
F P
0 g
s
.81343 .63075 m .80987 .59173 L .78745 .64665 L p 0 0 .399 r
F P
0 g
s
.55562 .35499 m .58427 .34467 L .56098 .33332 L p .548 .726 .957 r
F P
0 g
s
.56098 .33332 m .54375 .34953 L .55562 .35499 L p .548 .726 .957 r
F P
0 g
s
.40368 .36494 m .44434 .3628 L .45696 .3447 L p .748 .831 .915 r
F P
0 g
s
.63217 .81869 m .62362 .84156 L .6975 .82601 L p .429 .045 .208 r
F P
0 g
s
.6975 .82601 m .71361 .80101 L .63217 .81869 L p .429 .045 .208 r
F P
0 g
s
.47795 .33169 m .50242 .35036 L .51558 .34688 L p .652 .784 .945 r
F P
0 g
s
.50242 .35036 m .47795 .33169 L .45696 .3447 L p .686 .79 .929 r
F P
0 g
s
.40368 .36494 m .36411 .37245 L .36339 .41423 L p .822 .831 .856 r
F P
0 g
s
.32942 .43688 m .36339 .41423 L .36411 .37245 L p .863 .852 .83 r
F P
0 g
s
.30081 .58014 m .29335 .6139 L .34792 .65006 L p .89 .66 .584 r
F P
0 g
s
.34617 .68124 m .34792 .65006 L .29335 .6139 L p .896 .636 .536 r
F P
0 g
s
.54375 .34953 m .56098 .33332 L .53349 .32639 L p .576 .752 .961 r
F P
0 g
s
.53349 .32639 m .5299 .34666 L .54375 .34953 L p .576 .752 .961 r
F P
0 g
s
.50465 .3255 m .51558 .34688 L .5299 .34666 L p .614 .772 .956 r
F P
0 g
s
.51558 .34688 m .50465 .3255 L .47795 .33169 L p .652 .784 .945 r
F P
0 g
s
.64954 .38464 m .6857 .39981 L .66668 .37266 L p .255 .526 .914 r
F P
0 g
s
.66668 .37266 m .63576 .36248 L .64954 .38464 L p .255 .526 .914 r
F P
0 g
s
.75372 .48393 m .77914 .51723 L .76687 .47296 L p 0 .133 .678 r
F P
0 g
s
.76687 .47296 m .74503 .44455 L .75372 .48393 L p 0 .133 .678 r
F P
0 g
s
.5299 .34666 m .53349 .32639 L .50465 .3255 L p .614 .772 .956 r
F P
0 g
s
.40426 .73917 m .40765 .76729 L .47068 .79339 L p .829 .499 .428 r
F P
0 g
s
.47406 .81756 m .47068 .79339 L .40765 .76729 L p .815 .432 .33 r
F P
0 g
s
.47068 .79339 m .47406 .81756 L .54516 .83653 L p .745 .359 .323 r
F P
0 g
s
.29996 .4638 m .2759 .49449 L .31317 .5466 L p .909 .768 .693 r
F P
0 g
s
.30081 .58014 m .31317 .5466 L .2759 .49449 L p .929 .753 .642 r
F P
0 g
s
.34617 .68124 m .34759 .7116 L .40426 .73917 L p .867 .576 .494 r
F P
0 g
s
.40765 .76729 m .40426 .73917 L .34759 .7116 L p .866 .537 .427 r
F P
0 g
s
.60121 .35893 m .63576 .36248 L .611 .34217 L p .383 .642 .958 r
F P
0 g
s
.611 .34217 m .58427 .34467 L .60121 .35893 L p .383 .642 .958 r
F P
0 g
s
.4215 .33694 m .45696 .3447 L .47795 .33169 L p .693 .838 .953 r
F P
0 g
s
.45696 .3447 m .4215 .33694 L .40368 .36494 L p .748 .831 .915 r
F P
0 g
s
.36411 .37245 m .40368 .36494 L .4215 .33694 L p .785 .877 .914 r
F P
0 g
s
.36411 .37245 m .32669 .38588 L .32942 .43688 L p .863 .852 .83 r
F P
0 g
s
.29996 .4638 m .32942 .43688 L .32669 .38588 L p .904 .869 .793 r
F P
0 g
s
.29335 .6139 m .29085 .64752 L .34617 .68124 L p .896 .636 .536 r
F P
0 g
s
.34759 .7116 m .34617 .68124 L .29085 .64752 L p .9 .605 .478 r
F P
0 g
s
.6857 .39981 m .71777 .41997 L .69315 .38874 L p 0 .35 .825 r
F P
0 g
s
.69315 .38874 m .66668 .37266 L .6857 .39981 L p 0 .35 .825 r
F P
0 g
s
.79084 .68767 m .78577 .7262 L .80843 .66922 L p 0 0 .129 r
F P
0 g
s
.80843 .66922 m .81343 .63075 L .79084 .68767 L p 0 0 .129 r
F P
0 g
s
.77914 .51723 m .79819 .55349 L .78284 .50455 L p 0 0 .466 r
F P
0 g
s
.78284 .50455 m .76687 .47296 L .77914 .51723 L p 0 0 .466 r
F P
0 g
s
.2759 .49449 m .25807 .52831 L .30081 .58014 L p .929 .753 .642 r
F P
0 g
s
.29335 .6139 m .30081 .58014 L .25807 .52831 L p .946 .731 .582 r
F P
0 g
s
.58427 .34467 m .611 .34217 L .57733 .32477 L p .382 .681 .977 r
F P
0 g
s
.57733 .32477 m .56098 .33332 L .58427 .34467 L p .382 .681 .977 r
F P
0 g
s
.54315 .85325 m .54516 .83653 L .47406 .81756 L p .697 .239 .16 r
F P
0 g
s
.54516 .83653 m .54315 .85325 L .61218 .8572 L p .557 .09 .101 r
F P
0 g
s
.61218 .8572 m .62362 .84156 L .54516 .83653 L p .557 .09 .101 r
F P
0 g
s
.45308 .31737 m .47795 .33169 L .50465 .3255 L p .615 .824 .981 r
F P
0 g
s
.47795 .33169 m .45308 .31737 L .4215 .33694 L p .693 .838 .953 r
F P
0 g
s
.71361 .80101 m .6975 .82601 L .75109 .78953 L p 0 0 0 r
F P
0 g
s
.75109 .78953 m .77232 .7606 L .71361 .80101 L p 0 0 0 r
F P
0 g
s
.34759 .7116 m .35259 .74094 L .40765 .76729 L p .866 .537 .427 r
F P
0 g
s
.4139 .79321 m .40765 .76729 L .35259 .74094 L p .855 .476 .328 r
F P
0 g
s
.40765 .76729 m .4139 .79321 L .47406 .81756 L p .815 .432 .33 r
F P
0 g
s
.63576 .36248 m .66668 .37266 L .63478 .34731 L p .116 .505 .907 r
F P
0 g
s
.63478 .34731 m .611 .34217 L .63576 .36248 L p .116 .505 .907 r
F P
0 g
s
.32669 .38588 m .29278 .40561 L .29996 .4638 L p .904 .869 .793 r
F P
0 g
s
.2759 .49449 m .29996 .4638 L .29278 .40561 L p .944 .88 .74 r
F P
0 g
s
.4215 .33694 m .38611 .33452 L .36411 .37245 L p .785 .877 .914 r
F P
0 g
s
.32669 .38588 m .36411 .37245 L .38611 .33452 L p .823 .926 .902 r
F P
0 g
s
.62362 .84156 m .61218 .8572 L .67627 .84359 L p .283 0 0 r
F P
0 g
s
.67627 .84359 m .6975 .82601 L .62362 .84156 L p .283 0 0 r
F P
0 g
s
.56098 .33332 m .57733 .32477 L .537 .31269 L p .438 .735 .99 r
F P
0 g
s
.537 .31269 m .53349 .32639 L .56098 .33332 L p .438 .735 .99 r
F P
0 g
s
.47897 .83716 m .47406 .81756 L .4139 .79321 L p .776 .326 .178 r
F P
0 g
s
.47406 .81756 m .47897 .83716 L .54315 .85325 L p .697 .239 .16 r
F P
0 g
s
.4937 .30932 m .50465 .3255 L .53349 .32639 L p .524 .787 .993 r
F P
0 g
s
.50465 .3255 m .4937 .30932 L .45308 .31737 L p .615 .824 .981 r
F P
0 g
s
.53349 .32639 m .537 .31269 L .4937 .30932 L p .524 .787 .993 r
F P
0 g
s
.71777 .41997 m .74503 .44455 L .7147 .40982 L p 0 .073 .603 r
F P
0 g
s
.7147 .40982 m .69315 .38874 L .71777 .41997 L p 0 .073 .603 r
F P
0 g
s
.38611 .33452 m .4215 .33694 L .45308 .31737 L p .693 .895 .97 r
F P
0 g
s
.29085 .64752 m .29349 .68063 L .34759 .7116 L p .9 .605 .478 r
F P
0 g
s
.35259 .74094 m .34759 .7116 L .29349 .68063 L p .899 .562 .399 r
F P
0 g
s
.79819 .55349 m .80987 .59173 L .79256 .53867 L p .706 .414 0 r
F P
0 g
s
.79256 .53867 m .78284 .50455 L .79819 .55349 L p .706 .414 0 r
F P
0 g
s
.25807 .52831 m .24716 .56444 L .29335 .6139 L p .946 .731 .582 r
F P
0 g
s
.29085 .64752 m .29335 .6139 L .24716 .56444 L p .956 .7 .507 r
F P
0 g
s
.78577 .7262 m .77232 .7606 L .79485 .70578 L p 0 0 0 r
F P
0 g
s
.79485 .70578 m .80843 .66922 L .78577 .7262 L p 0 0 0 r
F P
0 g
s
.29278 .40561 m .26401 .43177 L .2759 .49449 L p .944 .88 .74 r
F P
0 g
s
.25807 .52831 m .2759 .49449 L .26401 .43177 L p .979 .878 .661 r
F P
0 g
s
.611 .34217 m .63478 .34731 L .59218 .32412 L p .082 .537 .904 r
F P
0 g
s
.59218 .32412 m .57733 .32477 L .611 .34217 L p .082 .537 .904 r
F P
0 g
s
.66668 .37266 m .69315 .38874 L .65488 .35942 L p 0 .232 .692 r
F P
0 g
s
.65488 .35942 m .63478 .34731 L .66668 .37266 L p 0 .232 .692 r
F P
0 g
s
.38611 .33452 m .35175 .33858 L .32669 .38588 L p .823 .926 .902 r
F P
0 g
s
.29278 .40561 m .32669 .38588 L .35175 .33858 L p .857 .974 .864 r
F P
0 g
s
.35259 .74094 m .3618 .76869 L .4139 .79321 L p .855 .476 .328 r
F P
0 g
s
.42348 .81585 m .4139 .79321 L .3618 .76869 L p .819 .372 .174 r
F P
0 g
s
.4139 .79321 m .42348 .81585 L .47897 .83716 L p .776 .326 .178 r
F P
0 g
s
.74503 .44455 m .76687 .47296 L .73125 .43497 L p .699 .232 0 r
F P
0 g
s
.73125 .43497 m .7147 .40982 L .74503 .44455 L p .699 .232 0 r
F P
0 g
s
.42818 .30848 m .45308 .31737 L .4937 .30932 L p .534 .855 .997 r
F P
0 g
s
.45308 .31737 m .42818 .30848 L .38611 .33452 L p .693 .895 .97 r
F P
0 g
s
.24716 .56444 m .24376 .60199 L .29085 .64752 L p .956 .7 .507 r
F P
0 g
s
.29349 .68063 m .29085 .64752 L .24376 .60199 L p .958 .652 .407 r
F P
0 g
s
.54062 .8632 m .54315 .85325 L .47897 .83716 L p .581 .033 0 r
F P
0 g
s
.54315 .85325 m .54062 .8632 L .59826 .86532 L p .395 0 0 r
F P
0 g
s
.59826 .86532 m .61218 .8572 L .54315 .85325 L p .395 0 0 r
F P
0 g
s
.6975 .82601 m .67627 .84359 L .72312 .81206 L p 0 0 0 r
F P
0 g
s
.72312 .81206 m .75109 .78953 L .6975 .82601 L p 0 0 0 r
F P
0 g
s
.80987 .59173 m .81343 .63075 L .7957 .57466 L p .899 .643 .134 r
F P
0 g
s
.7957 .57466 m .79256 .53867 L .80987 .59173 L p .899 .643 .134 r
F P
0 g
s
.29349 .68063 m .30161 .71276 L .35259 .74094 L p .899 .562 .399 r
F P
0 g
s
.3618 .76869 m .35259 .74094 L .30161 .71276 L p .885 .492 .28 r
F P
0 g
s
.35175 .33858 m .38611 .33452 L .42818 .30848 L p .666 .947 .958 r
F P
0 g
s
.4855 .85101 m .47897 .83716 L .42348 .81585 L p .675 .14 0 r
F P
0 g
s
.47897 .83716 m .4855 .85101 L .54062 .8632 L p .581 .033 0 r
F P
0 g
s
.57733 .32477 m .59218 .32412 L .54032 .3062 L p .172 .632 .936 r
F P
0 g
s
.54032 .3062 m .537 .31269 L .57733 .32477 L p .172 .632 .936 r
F P
0 g
s
.61218 .8572 m .59826 .86532 L .65092 .85358 L p .025 0 0 r
F P
0 g
s
.65092 .85358 m .67627 .84359 L .61218 .8572 L p .025 0 0 r
F P
0 g
s
.48296 .29927 m .4937 .30932 L .537 .31269 L p .34 .754 .979 r
F P
0 g
s
.4937 .30932 m .48296 .29927 L .42818 .30848 L p .534 .855 .997 r
F P
0 g
s
.26401 .43177 m .24204 .46404 L .25807 .52831 L p .979 .878 .661 r
F P
0 g
s
.24716 .56444 m .25807 .52831 L .24204 .46404 L p .998 .851 .54 r
F P
0 g
s
.537 .31269 m .54032 .3062 L .48296 .29927 L p .34 .754 .979 r
F P
0 g
s
.77232 .7606 m .75109 .78953 L .77305 .73914 L p .812 .928 .551 r
F P
0 g
s
.77305 .73914 m .79485 .70578 L .77232 .7606 L p .812 .928 .551 r
F P
0 g
s
.76687 .47296 m .78284 .50455 L .74295 .46336 L p .876 .454 .036 r
F P
0 g
s
.74295 .46336 m .73125 .43497 L .76687 .47296 L p .876 .454 .036 r
F P
0 g
s
.35175 .33858 m .31983 .35027 L .29278 .40561 L p .857 .974 .864 r
F P
0 g
s
.26401 .43177 m .29278 .40561 L .31983 .35027 L p .866 .995 .765 r
F P
0 g
s
.69315 .38874 m .7147 .40982 L .67098 .37748 L p .641 .107 0 r
F P
0 g
s
.67098 .37748 m .65488 .35942 L .69315 .38874 L p .641 .107 0 r
F P
0 g
s
.24376 .60199 m .24824 .6399 L .29349 .68063 L p .958 .652 .407 r
F P
0 g
s
.30161 .71276 m .29349 .68063 L .24824 .6399 L p .941 .576 .266 r
F P
0 g
s
.60507 .3311 m .59218 .32412 L .63478 .34731 L p 0 .232 .622 r
F P
0 g
s
.63478 .34731 m .65488 .35942 L .60507 .3311 L p 0 .232 .622 r
F P
0 g
s
.3618 .76869 m .37594 .79381 L .42348 .81585 L p .819 .372 .174 r
F P
0 g
s
.43682 .83375 m .42348 .81585 L .37594 .79381 L p .716 .185 0 r
F P
0 g
s
.42348 .81585 m .43682 .83375 L .4855 .85101 L p .675 .14 0 r
F P
0 g
s
.81343 .63075 m .80843 .66922 L .79195 .61179 L p .984 .782 .377 r
F P
0 g
s
.79195 .61179 m .7957 .57466 L .81343 .63075 L p .984 .782 .377 r
F P
0 g
s
.30161 .71276 m .31568 .74321 L .3618 .76869 L p .885 .492 .28 r
F P
0 g
s
.37594 .79381 m .3618 .76869 L .31568 .74321 L p .834 .369 .089 r
F P
0 g
s
.40394 .30637 m .42818 .30848 L .48296 .29927 L p .342 .812 .912 r
F P
0 g
s
.42818 .30848 m .40394 .30637 L .35175 .33858 L p .666 .947 .958 r
F P
0 g
s
.24204 .46404 m .22842 .50162 L .24716 .56444 L p .998 .851 .54 r
F P
0 g
s
.24376 .60199 m .24716 .56444 L .22842 .50162 L p .978 .774 .356 r
F P
0 g
s
.67627 .84359 m .65092 .85358 L .68972 .82777 L p .537 .919 .789 r
F P
0 g
s
.68972 .82777 m .72312 .81206 L .67627 .84359 L p .537 .919 .789 r
F P
0 g
s
.31983 .35027 m .35175 .33858 L .40394 .30637 L p .555 .932 .836 r
F P
0 g
s
.5376 .86581 m .54062 .8632 L .4855 .85101 L p .312 0 0 r
F P
0 g
s
.54062 .8632 m .5376 .86581 L .58231 .866 L p .084 0 0 r
F P
0 g
s
.59826 .86532 m .54062 .8632 L p .57443 .86547 L .084 0 0 r
F P
0 g
s
.53415 .86067 m .56477 .85953 L p .54229 .86472 L .265 .744 .933 r
F P
0 g
s
.5376 .86581 m .53678 .86459 L p .54229 .86472 L .265 .744 .933 r
F P
0 g
s
.53678 .86459 m .53415 .86067 L p .54229 .86472 L .265 .744 .933 r
F P
0 g
s
.58231 .866 m .58753 .86578 L p .57443 .86547 L .084 0 0 r
F P
0 g
s
.58753 .86578 m .59826 .86532 L p .57443 .86547 L .084 0 0 r
F P
0 g
s
.78284 .50455 m .79256 .53867 L .75 .49442 L p .945 .583 .252 r
F P
0 g
s
.75 .49442 m .74295 .46336 L .78284 .50455 L p .945 .583 .252 r
F P
0 g
s
.49367 .85786 m .4855 .85101 L .43682 .83375 L p .423 0 0 r
F P
0 g
s
.4855 .85101 m .49367 .85786 L .5376 .86581 L p .312 0 0 r
F P
0 g
s
.59218 .32412 m .60507 .3311 L .54333 .30734 L p .236 0 0 r
F P
0 g
s
.54333 .30734 m .54032 .3062 L .59218 .32412 L p .236 0 0 r
F P
0 g
s
.24824 .6399 m .26073 .67707 L .30161 .71276 L p .941 .576 .266 r
F P
0 g
s
.31568 .74321 m .30161 .71276 L .26073 .67707 L p .878 .445 .059 r
F P
0 g
s
.7147 .40982 m .73125 .43497 L .68312 .40034 L p .827 .351 .012 r
F P
0 g
s
.68312 .40034 m .67098 .37748 L .7147 .40982 L p .827 .351 .012 r
F P
0 g
s
.75109 .78953 m .72312 .81206 L .74382 .76817 L p .867 .994 .757 r
F P
0 g
s
.74382 .76817 m .77305 .73914 L .75109 .78953 L p .867 .994 .757 r
F P
0 g
s
.31983 .35027 m .29215 .37044 L .26401 .43177 L p .866 .995 .765 r
F P
0 g
s
.26401 .43177 m .29215 .37044 L p .24299 .46226 L .791 .922 .542 r
F P
0 g
s
.24251 .46334 m .26401 .43177 L p .24299 .46226 L .791 .922 .542 r
F P
0 g
s
.29215 .37044 m .27066 .39936 L .24204 .46404 L p .791 .922 .542 r
F P
0 g
s
.25721 .43655 m .22842 .50162 L p .26879 .40388 L 0 0 0 r
F P
0 g
s
.27066 .39936 m .27007 .40099 L p .26879 .40388 L 0 0 0 r
F P
0 g
s
.27007 .40099 m .25721 .43655 L p .26879 .40388 L 0 0 0 r
F P
0 g
s
.24204 .46404 m .24251 .46334 L p .24299 .46226 L .791 .922 .542 r
F P
0 g
s
.59826 .86532 m .58231 .866 L .62248 .85627 L p .281 .784 .831 r
F P
0 g
s
.62248 .85627 m .65092 .85358 L .59826 .86532 L p .281 .784 .831 r
F P
0 g
s
.47275 .29641 m .48296 .29927 L .54032 .3062 L p 0 .564 .777 r
F P
0 g
s
.48296 .29927 m .47275 .29641 L .40394 .30637 L p .342 .812 .912 r
F P
0 g
s
.80843 .66922 m .79485 .70578 L .78105 .64924 L p .998 .85 .548 r
F P
0 g
s
.78105 .64924 m .79195 .61179 L .80843 .66922 L p .998 .85 .548 r
F P
0 g
s
.54032 .3062 m .54333 .30734 L .47275 .29641 L p 0 .564 .777 r
F P
0 g
s
.31568 .74321 m .33612 .77102 L .37594 .79381 L p .834 .369 .089 r
F P
0 g
s
.39563 .81489 m .37594 .79381 L .33612 .77102 L p .686 .144 0 r
F P
0 g
s
.37594 .79381 m .39563 .81489 L .43682 .83375 L p .716 .185 0 r
F P
0 g
s
.65488 .35942 m .67098 .37748 L .6157 .34509 L p .66 .106 0 r
F P
0 g
s
.6157 .34509 m .60507 .3311 L .65488 .35942 L p .66 .106 0 r
F P
0 g
s
.45414 .8452 m .43682 .83375 L .39563 .81489 L p .45 0 0 r
F P
0 g
s
.43682 .83375 m .45414 .8452 L .49367 .85786 L p .423 0 0 r
F P
0 g
s
.22842 .50162 m .22432 .54318 L .24376 .60199 L p .978 .774 .356 r
F P
0 g
s
.24824 .6399 m .24376 .60199 L .22432 .54318 L p .879 .615 .092 r
F P
0 g
s
.79256 .53867 m .7957 .57466 L .75249 .52782 L p .963 .657 .397 r
F P
0 g
s
.75249 .52782 m .75 .49442 L .79256 .53867 L p .963 .657 .397 r
F P
0 g
s
.26073 .67707 m .28109 .71233 L .31568 .74321 L p .878 .445 .059 r
F P
0 g
s
.33612 .77102 m .31568 .74321 L .28109 .71233 L p .72 .228 0 r
F P
0 g
s
.40394 .30637 m .38137 .31244 L .31983 .35027 L p .555 .932 .836 r
F P
0 g
s
.29215 .37044 m .31983 .35027 L .38137 .31244 L p 0 0 0 r
F P
0 g
s
.73125 .43497 m .74295 .46336 L .69157 .42699 L p .894 .488 .228 r
F P
0 g
s
.69157 .42699 m .68312 .40034 L .73125 .43497 L p .894 .488 .228 r
F P
0 g
s
.38137 .31244 m .40394 .30637 L .47275 .29641 L p .008 0 0 r
F P
0 g
s
.65092 .85358 m .62248 .85627 L .65226 .83669 L p .639 .953 .939 r
F P
0 g
s
.65226 .83669 m .68972 .82777 L .65092 .85358 L p .639 .953 .939 r
F P
0 g
s
.22842 .50162 m .24204 .46404 L .27066 .39936 L p 0 0 0 r
F P
0 g
s
.79485 .70578 m .77305 .73914 L .76286 .68604 L p .978 .878 .665 r
F P
0 g
s
.76286 .68604 m .78105 .64924 L .79485 .70578 L p .978 .878 .665 r
F P
0 g
s
.72312 .81206 m .68972 .82777 L .70817 .792 L p .852 .981 .862 r
F P
0 g
s
.70817 .792 m .74382 .76817 L .72312 .81206 L p .852 .981 .862 r
F P
0 g
s
.60507 .3311 m .6157 .34509 L .54596 .31629 L p .577 .002 0 r
F P
0 g
s
.54596 .31629 m .54333 .30734 L .60507 .3311 L p .577 .002 0 r
F P
0 g
s
.53415 .86067 m .5376 .86581 L .49367 .85786 L p .097 .621 .878 r
F P
0 g
s
.56477 .85953 m .58231 .866 L .5376 .86581 L p .265 .744 .933 r
F P
0 g
s
.50338 .85653 m .49367 .85786 L .45414 .8452 L p .007 .539 .848 r
F P
0 g
s
.49367 .85786 m .50338 .85653 L .53415 .86067 L p .097 .621 .878 r
F P
0 g
s
.22432 .54318 m .23032 .58697 L .24824 .6399 L p .879 .615 .092 r
F P
0 g
s
.26073 .67707 m .24824 .6399 L .23032 .58697 L p .672 .365 0 r
F P
0 g
s
.33612 .77102 m .36317 .79498 L .39563 .81489 L p .686 .144 0 r
F P
0 g
s
.39563 .81489 m .42113 .8302 L .45414 .8452 L p .45 0 0 r
F P
0 g
s
.42113 .8302 m .39563 .81489 L .36317 .79498 L p 0 .202 .614 r
F P
0 g
s
.67098 .37748 m .68312 .40034 L .62397 .36523 L p .806 .33 .079 r
F P
0 g
s
.62397 .36523 m .6157 .34509 L .67098 .37748 L p .806 .33 .079 r
F P
0 g
s
.58231 .866 m .56477 .85953 L .59183 .85226 L p .481 .861 .98 r
F P
0 g
s
.59183 .85226 m .62248 .85627 L .58231 .866 L p .481 .861 .98 r
F P
0 g
s
.7957 .57466 m .79195 .61179 L .75022 .56337 L p .961 .703 .501 r
F P
0 g
s
.75022 .56337 m .75249 .52782 L .7957 .57466 L p .961 .703 .501 r
F P
0 g
s
.46344 .30175 m .47275 .29641 L .54333 .30734 L p .39 0 0 r
F P
0 g
s
.47275 .29641 m .46344 .30175 L .38137 .31244 L p .008 0 0 r
F P
0 g
s
.54333 .30734 m .54596 .31629 L .46344 .30175 L p .39 0 0 r
F P
0 g
s
.47529 .84855 m .45414 .8452 L .42113 .8302 L p 0 .506 .855 r
F P
0 g
s
.45414 .8452 m .47529 .84855 L .50338 .85653 L p .007 .539 .848 r
F P
0 g
s
.28109 .71233 m .30891 .74452 L .33612 .77102 L p .72 .228 0 r
F P
0 g
s
.36317 .79498 m .33612 .77102 L .30891 .74452 L p 0 .075 .567 r
F P
0 g
s
.74295 .46336 m .75 .49442 L .69665 .45678 L p .914 .564 .363 r
F P
0 g
s
.69665 .45678 m .69157 .42699 L .74295 .46336 L p .914 .564 .363 r
F P
0 g
s
.77305 .73914 m .74382 .76817 L .7374 .72109 L p .943 .885 .746 r
F P
0 g
s
.7374 .72109 m .76286 .68604 L .77305 .73914 L p .943 .885 .746 r
F P
0 g
s
.22432 .54318 m .22842 .50162 L .25721 .43655 L p 0 0 .201 r
F P
0 g
s
.23032 .58697 m .24628 .63103 L .26073 .67707 L p .672 .365 0 r
F P
0 g
s
.28109 .71233 m .26073 .67707 L .24628 .63103 L p 0 0 .512 r
F P
0 g
s
.68972 .82777 m .65226 .83669 L .66734 .81001 L p .811 .94 .912 r
F P
0 g
s
.66734 .81001 m .70817 .792 L .68972 .82777 L p .811 .94 .912 r
F P
0 g
s
.38137 .31244 m .36175 .32788 L .29215 .37044 L p 0 0 0 r
F P
0 g
s
.27066 .39936 m .29215 .37044 L .36175 .32788 L p .037 0 0 r
F P
0 g
s
.62248 .85627 m .59183 .85226 L .61195 .83915 L p .663 .912 .978 r
F P
0 g
s
.61195 .83915 m .65226 .83669 L .62248 .85627 L p .663 .912 .978 r
F P
0 g
s
.79195 .61179 m .78105 .64924 L .74276 .60084 L p .949 .736 .581 r
F P
0 g
s
.74276 .60084 m .75022 .56337 L .79195 .61179 L p .949 .736 .581 r
F P
0 g
s
.36175 .32788 m .38137 .31244 L .46344 .30175 L p .327 0 0 r
F P
0 g
s
.68312 .40034 m .69157 .42699 L .62986 .39067 L p .86 .457 .269 r
F P
0 g
s
.62986 .39067 m .62397 .36523 L .68312 .40034 L p .86 .457 .269 r
F P
0 g
s
.6157 .34509 m .62397 .36523 L .54811 .33302 L p .737 .249 .08 r
F P
0 g
s
.54811 .33302 m .54596 .31629 L .6157 .34509 L p .737 .249 .08 r
F P
0 g
s
.36317 .79498 m .39667 .81371 L .42113 .8302 L p 0 .202 .614 r
F P
0 g
s
.45216 .83805 m .42113 .8302 L .39667 .81371 L p .067 .525 .897 r
F P
0 g
s
.42113 .8302 m .45216 .83805 L .47529 .84855 L p 0 .506 .855 r
F P
0 g
s
.75 .49442 m .75249 .52782 L .69852 .48939 L p .916 .613 .455 r
F P
0 g
s
.69852 .48939 m .69665 .45678 L .75 .49442 L p .916 .613 .455 r
F P
0 g
s
.30891 .74452 m .34348 .77256 L .36317 .79498 L p 0 .075 .567 r
F P
0 g
s
.39667 .81371 m .36317 .79498 L .34348 .77256 L p 0 .371 .821 r
F P
0 g
s
.53036 .84754 m .53415 .86067 L .50338 .85653 L p .411 .76 .995 r
F P
0 g
s
.53415 .86067 m .53036 .84754 L .546 .84624 L p .481 .803 1 r
F P
0 g
s
.546 .84624 m .56477 .85953 L .53415 .86067 L p .481 .803 1 r
F P
0 g
s
.51439 .84617 m .50338 .85653 L .47529 .84855 L p .372 .727 .989 r
F P
0 g
s
.50338 .85653 m .51439 .84617 L .53036 .84754 L p .411 .76 .995 r
F P
0 g
s
.74382 .76817 m .70817 .792 L .705 .75313 L p .9 .879 .806 r
F P
0 g
s
.705 .75313 m .7374 .72109 L .74382 .76817 L p .9 .879 .806 r
F P
0 g
s
.56477 .85953 m .546 .84624 L .55964 .84216 L p .573 .841 .996 r
F P
0 g
s
.55964 .84216 m .59183 .85226 L .56477 .85953 L p .573 .841 .996 r
F P
0 g
s
.24628 .63103 m .27139 .6734 L .28109 .71233 L p 0 0 .512 r
F P
0 g
s
.30891 .74452 m .28109 .71233 L .27139 .6734 L p 0 .181 .715 r
F P
0 g
s
.4997 .84249 m .47529 .84855 L .45216 .83805 L p .362 .707 .985 r
F P
0 g
s
.47529 .84855 m .4997 .84249 L .51439 .84617 L p .372 .727 .989 r
F P
0 g
s
.25721 .43655 m .2532 .48062 L .22432 .54318 L p 0 0 .201 r
F P
0 g
s
.23032 .58697 m .22432 .54318 L .2532 .48062 L p 0 0 .462 r
F P
0 g
s
.54596 .31629 m .54811 .33302 L .45551 .31614 L p .603 .104 .041 r
F P
0 g
s
.45551 .31614 m .46344 .30175 L .54596 .31629 L p .603 .104 .041 r
F P
0 g
s
.46344 .30175 m .45551 .31614 L .36175 .32788 L p .327 0 0 r
F P
0 g
s
.78105 .64924 m .76286 .68604 L .72949 .63976 L p .932 .761 .648 r
F P
0 g
s
.72949 .63976 m .74276 .60084 L .78105 .64924 L p .932 .761 .648 r
F P
0 g
s
.65226 .83669 m .61195 .83915 L .6226 .82185 L p .764 .893 .935 r
F P
0 g
s
.6226 .82185 m .66734 .81001 L .65226 .83669 L p .764 .893 .935 r
F P
0 g
s
.69157 .42699 m .69665 .45678 L .63343 .42072 L p .879 .533 .391 r
F P
0 g
s
.63343 .42072 m .62986 .39067 L .69157 .42699 L p .879 .533 .391 r
F P
0 g
s
.59183 .85226 m .55964 .84216 L .56975 .83561 L p .657 .856 .976 r
F P
0 g
s
.56975 .83561 m .61195 .83915 L .59183 .85226 L p .657 .856 .976 r
F P
0 g
s
.75249 .52782 m .75022 .56337 L .69706 .52484 L p .911 .648 .526 r
F P
0 g
s
.69706 .52484 m .69852 .48939 L .75249 .52782 L p .911 .648 .526 r
F P
0 g
s
.36175 .32788 m .34648 .35336 L .27066 .39936 L p .037 0 0 r
F P
0 g
s
.25721 .43655 m .27066 .39936 L .34648 .35336 L p .253 0 .271 r
F P
0 g
s
.34348 .77256 m .38381 .79548 L .39667 .81371 L p 0 .371 .821 r
F P
0 g
s
.43597 .82586 m .39667 .81371 L .38381 .79548 L p .224 .575 .942 r
F P
0 g
s
.39667 .81371 m .43597 .82586 L .45216 .83805 L p .067 .525 .897 r
F P
0 g
s
.48776 .83703 m .45216 .83805 L .43597 .82586 L p .382 .697 .982 r
F P
0 g
s
.45216 .83805 m .48776 .83703 L .4997 .84249 L p .362 .707 .985 r
F P
0 g
s
.70817 .792 m .66734 .81001 L .66636 .78084 L p .852 .866 .851 r
F P
0 g
s
.66636 .78084 m .705 .75313 L .70817 .792 L p .852 .866 .851 r
F P
0 g
s
.62397 .36523 m .62986 .39067 L .54971 .35727 L p .799 .392 .281 r
F P
0 g
s
.54971 .35727 m .54811 .33302 L .62397 .36523 L p .799 .392 .281 r
F P
0 g
s
.27139 .6734 m .30424 .71236 L .30891 .74452 L p 0 .181 .715 r
F P
0 g
s
.34348 .77256 m .30891 .74452 L .30424 .71236 L p .095 .375 .838 r
F P
0 g
s
.76286 .68604 m .7374 .72109 L .70982 .67926 L p .909 .78 .706 r
F P
0 g
s
.70982 .67926 m .72949 .63976 L .76286 .68604 L p .909 .78 .706 r
F P
0 g
s
.34648 .35336 m .36175 .32788 L .45551 .31614 L p .493 .091 .206 r
F P
0 g
s
.2532 .48062 m .25926 .52939 L .23032 .58697 L p 0 0 .462 r
F P
0 g
s
.24628 .63103 m .23032 .58697 L .25926 .52939 L p .155 .17 .623 r
F P
0 g
s
.61195 .83915 m .56975 .83561 L .57519 .82734 L p .714 .845 .944 r
F P
0 g
s
.57519 .82734 m .6226 .82185 L .61195 .83915 L p .714 .845 .944 r
F P
0 g
s
.52632 .82641 m .53036 .84754 L .51439 .84617 L closepath p .573 .777 .975 r
F P
0 g
s
.52632 .82641 m .546 .84624 L .53036 .84754 L closepath p .588 .787 .975 r
F P
0 g
s
.52632 .82641 m .51439 .84617 L .4997 .84249 L closepath p .568 .77 .974 r
F P
0 g
s
.75022 .56337 m .74276 .60084 L .69187 .56319 L p .903 .676 .585 r
F P
0 g
s
.69187 .56319 m .69706 .52484 L .75022 .56337 L p .903 .676 .585 r
F P
0 g
s
.69665 .45678 m .69852 .48939 L .63468 .45492 L p .882 .583 .477 r
F P
0 g
s
.63468 .45492 m .63343 .42072 L .69665 .45678 L p .882 .583 .477 r
F P
0 g
s
.66734 .81001 m .6226 .82185 L .62262 .80295 L p .8 .846 .886 r
F P
0 g
s
.62262 .80295 m .66636 .78084 L .66734 .81001 L p .8 .846 .886 r
F P
0 g
s
.52632 .82641 m .55964 .84216 L .546 .84624 L closepath p .613 .798 .97 r
F P
0 g
s
.30424 .71236 m .34311 .74663 L .34348 .77256 L p .095 .375 .838 r
F P
0 g
s
.38381 .79548 m .34348 .77256 L .34311 .74663 L p .265 .515 .905 r
F P
0 g
s
.38381 .79548 m .42868 .81246 L .43597 .82586 L p .224 .575 .942 r
F P
0 g
s
.47979 .83032 m .43597 .82586 L .42868 .81246 L p .431 .694 .975 r
F P
0 g
s
.43597 .82586 m .47979 .83032 L .48776 .83703 L p .382 .697 .982 r
F P
0 g
s
.52632 .82641 m .4997 .84249 L .48776 .83703 L closepath p .567 .768 .973 r
F P
0 g
s
.54811 .33302 m .54971 .35727 L .44943 .33999 L p .689 .284 .274 r
F P
0 g
s
.44943 .33999 m .45551 .31614 L .54811 .33302 L p .689 .284 .274 r
F P
0 g
s
.7374 .72109 m .705 .75313 L .68345 .71794 L p .881 .793 .759 r
F P
0 g
s
.68345 .71794 m .70982 .67926 L .7374 .72109 L p .881 .793 .759 r
F P
0 g
s
.52632 .82641 m .56975 .83561 L .55964 .84216 L closepath p .642 .802 .96 r
F P
0 g
s
.52632 .82641 m .48776 .83703 L .47979 .83032 L closepath p .568 .766 .972 r
F P
0 g
s
.45551 .31614 m .44943 .33999 L .34648 .35336 L p .493 .091 .206 r
F P
0 g
s
.62986 .39067 m .63343 .42072 L .55069 .38854 L p .821 .479 .408 r
F P
0 g
s
.55069 .38854 m .54971 .35727 L .62986 .39067 L p .821 .479 .408 r
F P
0 g
s
.34648 .35336 m .33691 .3887 L .25721 .43655 L p .253 0 .271 r
F P
0 g
s
.2532 .48062 m .25721 .43655 L .33691 .3887 L p .376 .162 .457 r
F P
0 g
s
.25926 .52939 m .27514 .58016 L .24628 .63103 L p .155 .17 .623 r
F P
0 g
s
.27139 .6734 m .24628 .63103 L .27514 .58016 L p .273 .316 .724 r
F P
0 g
s
.6226 .82185 m .57519 .82734 L .57533 .81839 L p .742 .821 .913 r
F P
0 g
s
.57533 .81839 m .62262 .80295 L .6226 .82185 L p .742 .821 .913 r
F P
0 g
s
.34311 .74663 m .38621 .77541 L .38381 .79548 L p .265 .515 .905 r
F P
0 g
s
.42868 .81246 m .38381 .79548 L .38621 .77541 L p .395 .618 .94 r
F P
0 g
s
.52632 .82641 m .57519 .82734 L .56975 .83561 L closepath p .663 .797 .946 r
F P
0 g
s
.74276 .60084 m .72949 .63976 L .68231 .60424 L p .891 .701 .639 r
F P
0 g
s
.68231 .60424 m .69187 .56319 L .74276 .60084 L p .891 .701 .639 r
F P
0 g
s
.42868 .81246 m .4767 .82289 L .47979 .83032 L p .431 .694 .975 r
F P
0 g
s
.52632 .82641 m .47979 .83032 L .4767 .82289 L closepath p .572 .762 .968 r
F P
0 g
s
.705 .75313 m .66636 .78084 L .65063 .75397 L p .846 .801 .806 r
F P
0 g
s
.65063 .75397 m .68345 .71794 L .705 .75313 L p .846 .801 .806 r
F P
0 g
s
.69852 .48939 m .69706 .52484 L .6335 .49301 L p .878 .619 .543 r
F P
0 g
s
.6335 .49301 m .63468 .45492 L .69852 .48939 L p .878 .619 .543 r
F P
0 g
s
.38621 .77541 m .43194 .79833 L .42868 .81246 L p .395 .618 .94 r
F P
0 g
s
.4767 .82289 m .42868 .81246 L .43194 .79833 L p .499 .695 .956 r
F P
0 g
s
.52632 .82641 m .57533 .81839 L .57519 .82734 L closepath p .674 .789 .935 r
F P
0 g
s
.33691 .3887 m .34648 .35336 L .44943 .33999 L p .571 .252 .39 r
F P
0 g
s
.66636 .78084 m .62262 .80295 L .61231 .78531 L p .803 .802 .85 r
F P
0 g
s
.61231 .78531 m .65063 .75397 L .66636 .78084 L p .803 .802 .85 r
F P
0 g
s
.27514 .58016 m .29968 .63017 L .27139 .6734 L p .273 .316 .724 r
F P
0 g
s
.30424 .71236 m .27139 .6734 L .29968 .63017 L p .359 .424 .793 r
F P
0 g
s
.43194 .79833 m .47899 .81531 L .4767 .82289 L p .499 .695 .956 r
F P
0 g
s
.52632 .82641 m .4767 .82289 L .47899 .81531 L closepath p .585 .756 .96 r
F P
0 g
s
.72949 .63976 m .70982 .67926 L .66774 .64729 L p .875 .723 .69 r
F P
0 g
s
.66774 .64729 m .68231 .60424 L .72949 .63976 L p .875 .723 .69 r
F P
0 g
s
.52632 .82641 m .56019 .80314 L .57015 .80996 L closepath p .678 .779 .926 r
F P
0 g
s
.52632 .82641 m .54648 .79873 L .56019 .80314 L closepath p .677 .777 .926 r
F P
0 g
s
.52632 .82641 m .53046 .79717 L .54648 .79873 L closepath p .675 .774 .925 r
F P
0 g
s
.52632 .82641 m .51388 .7985 L .53046 .79717 L closepath p .667 .767 .924 r
F P
0 g
s
.52632 .82641 m .49865 .80238 L .51388 .7985 L closepath p .652 .759 .928 r
F P
0 g
s
.52632 .82641 m .48656 .80823 L .49865 .80238 L closepath p .63 .753 .936 r
F P
0 g
s
.52632 .82641 m .47899 .81531 L .48656 .80823 L closepath p .606 .752 .948 r
F P
0 g
s
.52632 .82641 m .57015 .80996 L .57533 .81839 L closepath p .678 .782 .929 r
F P
0 g
s
.62262 .80295 m .57533 .81839 L .57015 .80996 L p .749 .797 .891 r
F P
0 g
s
.57015 .80996 m .61231 .78531 L .62262 .80295 L p .749 .797 .891 r
F P
0 g
s
.63343 .42072 m .63468 .45492 L .55101 .42618 L p .828 .537 .496 r
F P
0 g
s
.55101 .42618 m .55069 .38854 L .63343 .42072 L p .828 .537 .496 r
F P
0 g
s
.54971 .35727 m .55069 .38854 L .44564 .37311 L p .725 .392 .416 r
F P
0 g
s
.44564 .37311 m .44943 .33999 L .54971 .35727 L p .725 .392 .416 r
F P
0 g
s
.69706 .52484 m .69187 .56319 L .62971 .53473 L p .87 .648 .598 r
F P
0 g
s
.62971 .53473 m .6335 .49301 L .69706 .52484 L p .87 .648 .598 r
F P
0 g
s
.33691 .3887 m .33404 .43272 L .2532 .48062 L p .376 .162 .457 r
F P
0 g
s
.25926 .52939 m .2532 .48062 L .33404 .43272 L p .45 .291 .573 r
F P
0 g
s
.29968 .63017 m .33107 .67696 L .30424 .71236 L p .359 .424 .793 r
F P
0 g
s
.34311 .74663 m .30424 .71236 L .33107 .67696 L p .425 .51 .842 r
F P
0 g
s
.4463 .78443 m .48656 .80823 L .47899 .81531 L p .567 .699 .93 r
F P
0 g
s
.47899 .81531 m .43194 .79833 L .4463 .78443 L p .567 .699 .93 r
F P
0 g
s
.70982 .67926 m .68345 .71794 L .64779 .69094 L p .854 .742 .738 r
F P
0 g
s
.64779 .69094 m .66774 .64729 L .70982 .67926 L p .854 .742 .738 r
F P
0 g
s
.61231 .78531 m .57015 .80996 L .56019 .80314 L p .747 .778 .879 r
F P
0 g
s
.44943 .33999 m .44564 .37311 L .33691 .3887 L p .571 .252 .39 r
F P
0 g
s
.33107 .67696 m .36722 .71878 L .34311 .74663 L p .425 .51 .842 r
F P
0 g
s
.38621 .77541 m .34311 .74663 L .36722 .71878 L p .479 .581 .879 r
F P
0 g
s
.40616 .75469 m .4463 .78443 L .43194 .79833 L p .525 .643 .908 r
F P
0 g
s
.43194 .79833 m .38621 .77541 L .40616 .75469 L p .525 .643 .908 r
F P
0 g
s
.36722 .71878 m .40616 .75469 L .38621 .77541 L p .479 .581 .879 r
F P
0 g
s
.47047 .77231 m .49865 .80238 L .48656 .80823 L p .624 .707 .906 r
F P
0 g
s
.48656 .80823 m .4463 .78443 L .47047 .77231 L p .624 .707 .906 r
F P
0 g
s
.68345 .71794 m .65063 .75397 L .62258 .73313 L p .828 .758 .785 r
F P
0 g
s
.62258 .73313 m .64779 .69094 L .68345 .71794 L p .828 .758 .785 r
F P
0 g
s
.65063 .75397 m .61231 .78531 L .59291 .77136 L p .793 .77 .832 r
F P
0 g
s
.56019 .80314 m .59291 .77136 L .61231 .78531 L p .747 .778 .879 r
F P
0 g
s
.59291 .77136 m .56019 .80314 L .54648 .79873 L p .738 .764 .874 r
F P
0 g
s
.69187 .56319 m .68231 .60424 L .62303 .57958 L p .859 .671 .647 r
F P
0 g
s
.62303 .57958 m .62971 .53473 L .69187 .56319 L p .859 .671 .647 r
F P
0 g
s
.59291 .77136 m .62258 .73313 L .65063 .75397 L p .793 .77 .832 r
F P
0 g
s
.63468 .45492 m .6335 .49301 L .55062 .46926 L p .827 .578 .562 r
F P
0 g
s
.55062 .46926 m .55101 .42618 L .63468 .45492 L p .827 .578 .562 r
F P
0 g
s
.50131 .76374 m .51388 .7985 L .49865 .80238 L p .668 .72 .887 r
F P
0 g
s
.49865 .80238 m .47047 .77231 L .50131 .76374 L p .668 .72 .887 r
F P
0 g
s
.54648 .79873 m .56621 .76276 L .59291 .77136 L p .738 .764 .874 r
F P
0 g
s
.56621 .76276 m .54648 .79873 L .53046 .79717 L p .724 .75 .873 r
F P
0 g
s
.33404 .43272 m .33691 .3887 L .44564 .37311 L p .612 .355 .504 r
F P
0 g
s
.33404 .43272 m .33834 .48329 L .25926 .52939 L p .45 .291 .573 r
F P
0 g
s
.27514 .58016 m .25926 .52939 L .33834 .48329 L p .499 .383 .653 r
F P
0 g
s
.53459 .76026 m .53046 .79717 L .51388 .7985 L p .701 .735 .877 r
F P
0 g
s
.51388 .7985 m .50131 .76374 L .53459 .76026 L p .701 .735 .877 r
F P
0 g
s
.53046 .79717 m .53459 .76026 L .56621 .76276 L p .724 .75 .873 r
F P
0 g
s
.55069 .38854 m .55101 .42618 L .44448 .41459 L p .74 .463 .509 r
F P
0 g
s
.44448 .41459 m .44564 .37311 L .55069 .38854 L p .74 .463 .509 r
F P
0 g
s
.44226 .73599 m .47047 .77231 L .4463 .78443 L p .614 .662 .874 r
F P
0 g
s
.4463 .78443 m .40616 .75469 L .44226 .73599 L p .614 .662 .874 r
F P
0 g
s
.68231 .60424 m .66774 .64729 L .61324 .62661 L p .845 .692 .693 r
F P
0 g
s
.61324 .62661 m .62303 .57958 L .68231 .60424 L p .845 .692 .693 r
F P
0 g
s
.62258 .73313 m .59291 .77136 L .56621 .76276 L p .777 .747 .825 r
F P
0 g
s
.6335 .49301 m .62971 .53473 L .54952 .51665 L p .822 .61 .616 r
F P
0 g
s
.54952 .51665 m .55062 .46926 L .6335 .49301 L p .822 .61 .616 r
F P
0 g
s
.66774 .64729 m .64779 .69094 L .6003 .67428 L p .827 .711 .737 r
F P
0 g
s
.6003 .67428 m .61324 .62661 L .66774 .64729 L p .827 .711 .737 r
F P
0 g
s
.64779 .69094 m .62258 .73313 L .58443 .72048 L p .806 .729 .78 r
F P
0 g
s
.56621 .76276 m .58443 .72048 L .62258 .73313 L p .777 .747 .825 r
F P
0 g
s
.33834 .48329 m .34962 .53756 L .27514 .58016 L p .499 .383 .653 r
F P
0 g
s
.29968 .63017 m .27514 .58016 L .34962 .53756 L p .534 .455 .713 r
F P
0 g
s
.44564 .37311 m .44448 .41459 L .33404 .43272 L p .612 .355 .504 r
F P
0 g
s
.41481 .69341 m .44226 .73599 L .40616 .75469 L p .6 .617 .84 r
F P
0 g
s
.40616 .75469 m .36722 .71878 L .41481 .69341 L p .6 .617 .84 r
F P
0 g
s
.58443 .72048 m .6003 .67428 L .64779 .69094 L p .806 .729 .78 r
F P
0 g
s
.58443 .72048 m .56621 .76276 L .53459 .76026 L p .754 .727 .827 r
F P
0 g
s
.48893 .72256 m .50131 .76374 L .47047 .77231 L p .676 .683 .849 r
F P
0 g
s
.47047 .77231 m .44226 .73599 L .48893 .72256 L p .676 .683 .849 r
F P
0 g
s
.38926 .64512 m .41481 .69341 L .36722 .71878 L p .583 .568 .803 r
F P
0 g
s
.36722 .71878 m .33107 .67696 L .38926 .64512 L p .583 .568 .803 r
F P
0 g
s
.34962 .53756 m .36703 .59244 L .29968 .63017 L p .534 .455 .713 r
F P
0 g
s
.33107 .67696 m .29968 .63017 L .36703 .59244 L p .561 .515 .761 r
F P
0 g
s
.53459 .76026 m .53853 .71697 L .58443 .72048 L p .754 .727 .827 r
F P
0 g
s
.53853 .71697 m .53459 .76026 L .50131 .76374 L p .721 .705 .834 r
F P
0 g
s
.33834 .48329 m .33404 .43272 L .44448 .41459 L p .636 .427 .583 r
F P
0 g
s
.50131 .76374 m .48893 .72256 L .53853 .71697 L p .721 .705 .834 r
F P
0 g
s
.55101 .42618 m .55062 .46926 L .44612 .4628 L p .747 .514 .577 r
F P
0 g
s
.44612 .4628 m .44448 .41459 L .55101 .42618 L p .747 .514 .577 r
F P
0 g
s
.36703 .59244 m .38926 .64512 L .33107 .67696 L p .561 .515 .761 r
F P
0 g
s
.62971 .53473 m .62303 .57958 L .5477 .5669 L p .814 .637 .662 r
F P
0 g
s
.5477 .5669 m .54952 .51665 L .62971 .53473 L p .814 .637 .662 r
F P
0 g
s
.6003 .67428 m .58443 .72048 L .53853 .71697 L p .776 .704 .784 r
F P
0 g
s
.62303 .57958 m .61324 .62661 L .54521 .61832 L p .804 .66 .703 r
F P
0 g
s
.54521 .61832 m .5477 .5669 L .62303 .57958 L p .804 .66 .703 r
F P
0 g
s
.47717 .67568 m .48893 .72256 L .44226 .73599 L p .678 .646 .811 r
F P
0 g
s
.44226 .73599 m .41481 .69341 L .47717 .67568 L p .678 .646 .811 r
F P
0 g
s
.61324 .62661 m .6003 .67428 L .54211 .66901 L p .792 .682 .744 r
F P
0 g
s
.53853 .71697 m .54211 .66901 L .6003 .67428 L p .776 .704 .784 r
F P
0 g
s
.44448 .41459 m .44612 .4628 L .33834 .48329 L p .636 .427 .583 r
F P
0 g
s
.54211 .66901 m .54521 .61832 L .61324 .62661 L p .792 .682 .744 r
F P
0 g
s
.54211 .66901 m .53853 .71697 L .48893 .72256 L p .734 .676 .794 r
F P
0 g
s
.55062 .46926 m .54952 .51665 L .45053 .5155 L p .75 .554 .631 r
F P
0 g
s
.45053 .5155 m .44612 .4628 L .55062 .46926 L p .75 .554 .631 r
F P
0 g
s
.34962 .53756 m .33834 .48329 L .44612 .4628 L p .652 .483 .643 r
F P
0 g
s
.48893 .72256 m .47717 .67568 L .54211 .66901 L p .734 .676 .794 r
F P
0 g
s
.4665 .62431 m .47717 .67568 L .41481 .69341 L p .676 .609 .774 r
F P
0 g
s
.41481 .69341 m .38926 .64512 L .4665 .62431 L p .676 .609 .774 r
F P
0 g
s
.54952 .51665 m .5477 .5669 L .45746 .57018 L p .749 .588 .676 r
F P
0 g
s
.45746 .57018 m .45053 .5155 L .54952 .51665 L p .749 .588 .676 r
F P
0 g
s
.54521 .61832 m .54211 .66901 L .47717 .67568 L p .742 .647 .755 r
F P
0 g
s
.44612 .4628 m .45053 .5155 L .34962 .53756 L p .652 .483 .643 r
F P
0 g
s
.36703 .59244 m .34962 .53756 L .45053 .5155 L p .663 .53 .692 r
F P
0 g
s
.45746 .57018 m .4665 .62431 L .38926 .64512 L p .671 .571 .734 r
F P
0 g
s
.38926 .64512 m .36703 .59244 L .45746 .57018 L p .671 .571 .734 r
F P
0 g
s
.47717 .67568 m .4665 .62431 L .54521 .61832 L p .742 .647 .755 r
F P
0 g
s
.45053 .5155 m .45746 .57018 L .36703 .59244 L p .663 .53 .692 r
F P
0 g
s
.5477 .5669 m .54521 .61832 L .4665 .62431 L p .747 .619 .717 r
F P
0 g
s
.4665 .62431 m .45746 .57018 L .5477 .5669 L p .747 .619 .717 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Sooooo`So0000?oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo000S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1K
ooooo`Oo000000?o0P00o`000?mS00001OmS0007o`0003Sooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04ooooo`;o00004_ooool00ol0
003oooooooooo`1Cooooo`Oo00000ol20008o`0000_oH`001ol0000aooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0:oooool002?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04cooooo1_l000000ol2003o0000o`000007o`0000Co
D`0000Co0000oiXJ2_nJ6P[oVQX:1ol0000;of<000Go0000;?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02[ooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`18ooooo`[o00003?mC00000ol0003oVQX:oiXJ2P09oiXJ2PKo
00002?mS00000ol0003oT`00o`000002o`0002Wooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Yooooo`008Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0A?ooool5o`0001CoD`0000?o0000oiXJ2_nJ6PX03onJ6PX7o`0000;oH`00
00Co0000oi<00?nC003oT`000_l0000Wooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`11ooooo`;o0000
5?mC0007o`0001OoVQX:1?l00004oi<000?o00009?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Sooooo000Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0?ooo
ool2o`0000koD`001ol00004oghG=003o`000?n`B4Ko/4Q600Go00005?nJ6PX00ol0003o_3lDo`00
0002o`0000CoT`000_l0000Rooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?oo
ool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0looooo`;o00002?mC0008
o`0000_oOQLd00?o0000ok18A_n`B4H01On`B4H5o`0000ooVQX:00?o0000ok`o5?nl?a@00_nl?a@2
o`0000CoT`000ol0000Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09oooool0
02Wooooo0_l0000Jooooo`03o`000?oooooooooo03Wooooo0ol00002oe<000Oo00004_mn5c@00ol0
003o/4Q6ok18AP0;ok18APGo00002_nJ6PX00ol0003o_3lDok`o5004ok`o50?o00001?nC0002o`00
01kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo03Oooooo1_l0000IoghG=003o`000?n`B4Ko/4Q6013o
/4Q61Ol00006oiXJ2P03o`000?nl?aCo_3lD00Ko_3lD0_l00004oi<000?o00006oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0=?ooool3o`000003o`T00?l0003oOQLd01_oOQLd00?o0000ok18A_n`B4H0
5On`B4H5o`000003oiXJ2_l0003o_3lD00Wo_3lD0_l00005oi<000;o00006Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0<Oooool4o`000003o`T00?l0003oOQLd01coOQLd00?o0000ok18A_n`B4H06_n`
B4H3o`0000_o_3lD0ol00002oi<00004o`000?nX6`3o0000o`0001Oooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02oooooo0ol00003o`T00003o`000?mn5cCoOQLd01[oOQLd00?o0000ok18A_n`B4H07?n`
B4H01?l0003oc6A7o`000?l0000<ok`o50;o000000GoT`00o`000?nX6`3oZ1/0o`00000Fooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0/ooooo`?o00001?l900000ol0003oOQLdoghG=00GoghG=0So0000
6on`B4H01?l0003oc6A7olaTAoo<I4L3o`0000_o_3lD0ol00002ojPK00;o00005?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0003ooooo
ooooo`0Yooooo`Co00001Ol900000ol0003oOQLdoghG=00?oghG=0So00001?nB@6<01?l0003o^FAZ
okUTJ_niI6X6o`0001Go/4Q600?o0000olaTAoo<I4L01?o<I4L2o`0000co_3lD0_l00002ojPK00;o
00004_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool09oooool3o`0000Ko2@0000?o0000oghG=?mn5c@0
2?mn5c@8o`0000coTT1S00?o0000okUTJ_niI6X01oniI6X7o`0000ko/4Q600?o0000olaTAoo<I4L0
1_o<I4L2o`0000[o_3lD00Co0000oliD5?l0003o00000_nX6`02o`00013ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Rooooo`00:?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo02Cooooo0ol00008o`T00003o`000?mn5cCoOQLd00So00005?nB@6<00ol0003o^FAZ
okUTJP0>okUTJPKo00002?n`B4H00ol0003oc6A7olaTA`08olaTA`?o00001onl?a@01Ol0003ocU@D
oliD5?o>E1Co000000;oZ1/00_l0000?ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool08Oooool002Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`?o0000
1ol90005o`0001coTT1S00?o0000okUTJ_niI6X05?niI6X6o`0000;o/4Q600?o0000olaTAoo<I4L0
2oo<I4L2o`0000Ko_3lD00Co0000oliD5?o>E1CocU@D0_l00002ojPK00;o00003Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo027ooooo000Wooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool08?ooool2o`0000Oo2@000_l000000om004Go0000oi90H`0Noi90H`03o`00
0?niI6[o^FAZ01[o^FAZ1?l0000>olaTA`;o00001?nl?a@00ol0003ocU@DoliD5003oliD50;o0000
0_nX6`000ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
8?ooool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Mooooo`?o00001ol9
00001Ol0003o@015od00AOm004Go000001koTT1S00?o0000okUTJ_niI6X07OniI6X01?l0003odWYX
o`000?l0000>olaTA`?o000000?o_3lDo`000?o>E1@01_o>E1@00ol0003oZ1/0ojPK0002o`0000[o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo01_ooooo0_l00007o`T000;o00000om004D00ol0003oTT1S
oi90H`0Moi90H`03o`000?niI6[o^FAZ01go^FAZ00Co0000om9jJ?oBNVSodWYX0ol0000>olaTA`?o
00001oo>E1@2o`000003ojPK0?l0003o000000Wooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0Oooooo`009oooool2o`0002Wooooo00?o0000ooooooooool06Oooool00ol0003o2@00
o`T00005o`T000;o00001Om004D00ol0003oTT1Soi90H`0Moi90H`03o`000?niI6[o^FAZ01go^FAZ
00?o0000om9jJ?oBNVP01?oBNVP2o`0000koc6A70_l00008oliD50Co00002?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool05oooool00ol0003o2@00o`T00005o`T00003o`000?m004Go@01500Go@01500?o
0000oi90HonB@6<07OnB@6<00ol0003o^FAZokUTJP0MokUTJP03o`000?oBNVSodWYX00KodWYX0_l0
000<olaTA`04o`000?oLM4Co0000o`0000SocU@D1?l00006ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool07_ooool002Oooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?l9003o2@0000?o2@000_l00007od00A@03o`000?nB@6?oTT1S01_oTT1S1ol0
000LokUTJP03o`000?oBNVSodWYX00SodWYX0ol00009olaTA`05o`000?oLM4Cog7A4omadA?l00000
2?o>E1@2o`000003oj@K0?l0003ooooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Cooooo00?o
0000o`T00?l900000_l90002o`0000Wo@01500?o0000oi90HonB@6<05?nB@6<7o`0000?oW5Z100Co
0000okefP_nmMX;o_GJ21ol0000FokUTJP03o`000?oBNVSodWYX00[odWYX0_l00008olaTA`04o`00
0?oLM4Cog7A4omadA0;o00002?o>E1@3o`0000Cooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Mooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01;ooooo
00Co0000o`T00?l9003o2@000_l0000;od00A@03o`000?nB@6?oTT1S00goTT1S1ol0000:oiaJP@03
o`000?nmMX;o_GJ200So_GJ21ol0000?okUTJP03o`000?oBNVSodWYX00codWYX0_l00006olaTA`03
o`000?oLM4Cog7A400?og7A40_l00006oliD5003o`000?oCF@?o000000;o00000_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo01cooooo000Vooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool04?ooool01Ol0003o2@00o`T00?l9003o000000go@01500?o0000oi90HonB
@6<01_nB@6<7o`00017oW5Z100?o0000okefP_nmMX803onmMX86o`0000Wo^FAZ00?o0000om9jJ?oB
NVP03_oBNVP2o`0000Coc6A700?o0000omadA?oLM4@01OoLM4@2o`0000GocU@D00Oo0000om=I0ol0
003oY1/0o`000?oooooo000004;ooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_oooo
o`03o`000?oooooooooo00kooooo00?o0000o`T00?l900000_l0000=od00A@03o`000?nB@6?oTT1S
00Oo00006?nLFX400ol0003o_GJ2okefPP0EokefPPOo00000_niI6X00ol0003odWYXom9jJ00@om9j
J0?o000000?oc6A7o`000?oLM4@02?oLM4@00ol0003ocU@DoliD5002oliD5008o`000?oCF@?odeT3
o`000?nT6`3o0000ooooool00011ooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03Oooool3o`0000ko@0151?l0000OoiaJP@03o`000?nm
MX;o_GJ201co_GJ21?l0000Dom9jJ0?o00002OoLM4@2o`0000?ocU@D00?o0000om=I0ooCF@<01?l0
0012ooooo`03o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02oooool2o`0000ko@0150_l000000omP:GCo0000oiaJP@0PoiaJP@03o`00
0?nmMX;o_GJ201ko_GJ200?o0000om>9O_l000000_l0000Com9jJ0;o00002_oLM4@2o`000003oliD
5?l0003odeT300?odeT30_l00012ooooo`03o`000?oooooooooo01[ooooo000;ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Wooooo0_l0000>od00A@05o`000?mP:GCoH2Udof0YM?l0
00008?nLFX400ol0003o_GJ2okefPP0OokefPP03o`000?oCRGkodhUn00;odhUn0_l0000Aom9jJ004
o`000?oQR6Co0000o`0000[og7A400?o0000oliD5?l000001?oCF@<2o`0004;ooooo00?o0000oooo
ooooool06Oooool000?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0
003o@015od00A@0<od00A@;o00001?mP:G@00ol0003oW5Z1oiaJP@0NoiaJP@03o`000?nmMX;o_GJ2
01oo_GJ200?o0000om>9O_oCRGh01?oCRGh3o`0000kodWYX00Co0000on68I?oQR6CohHQT0_l00009
omadA0;o00001?oCF@<3o`0004;ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`06ooooo`03o`000?m004Go@01500[o@0150_l00006of0YM003o`000?nLFX7o
W5Z101koW5Z100?o0000okefP_nmMX807onmMX800ol0003odhUnom>9OP07om>9OP;o00003?oBNVP0
0ol0003ohHQTon68I003on68I003o`000?oLM4Cog7A400Sog7A40_l00002om=I0`04o`000?oCF@?o
deT3o`00047ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Cooooo00?o0000od00AOm004D02_m004D00ol0003oH2Udof0YM006of0YM003o`00
0?nLFX7oW5Z101koW5Z100?o0000okefP_nmMX807onmMX800ol0003odhUnom>9OP09om>9OP?o0000
2OoBNVP00ol0003ohHQTon68I004on68I0;o00002?oLM4@01Ol0003oi7`jo`000?oCF@?o000000?o
deT300?o0000ooooooooool0?oooool00ol0003oooooooooo`0Gooooo`002oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0003Sooooo00?o0000oooooooo
ool00oooool00ol0003o@015od00A@08od00A@;o00002OmP:G@00ol0003oW5Z1oiaJP@0NoiaJP@03
o`000?nmMX;o_GJ201oo_GJ200?o0000om>9O_oCRGh03?oCRGh2o`0000SodWYX00?o0000on68I?oQ
R6@01OoQR6@2o`0000Oog7A400Co0000onAl>_l0003o00001?oCF@<00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooooooo0_l00008
od00A@;o00002omP:G@00ol0003oW5Z1oiaJP@0NoiaJP@03o`000?nmMX;o_GJ201oo_GJ200?o0000
om>9O_oCRGh03_oCRGh3o`0000GodWYX00?o0000on68I?oQR6@01ooQR6@2o`0000Gog7A400?o0000
onAl>_oTO3X00_l00004om=I0`03o`000?oooooooooo03kooooo00?o0000ooooooooool05_ooool0
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0i
ooooo`04o`000?ooooooooooo`0000So@01500?o0000of0YM?mP:G@02_mP:G@00ol0003oW5Z1oiaJ
P@0LoiaJP@So00007OnmMX800ol0003odhUnom>9OP0Aom>9OP;o00000ooBNVP00ol0003ohHQTon68
I009on68I0;o00000ooLM4@01Ol0003oi7`jonAl>_l0003oi7`j00;o00000_oCF@<00ol0003ooooo
ooooo`0mooooo`?o00005oooool002Cooooo00?o0000ooooooooool0>_ooool01?l0003ooooooooo
ool00006od00A@;o00003OmP:G@00ol0003oW5Z1oiaJP@0FoiaJP@Ko00000onRKID00ol0003o_h>C
okn3T`02okn3T`Wo00005?nmMX800ol0003odhUnom>9OP0Com>9OPCo00003OoQR6@01ol0003og7A4
omadA?oLM4Co0000onAl>_l000000ooTO3X01?l0003odeT3om=I0ol0000kooooo`?o00000_ooool0
0ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0kooooo`?o00001?m004D2o`00
00ooH2Ud00?o0000oiaJPOnLFX404OnLFX45o`0000WoXVfE00?o0000okn3TonoPi<02onoPi<8o`00
00co_GJ200?o0000om>9O_oCRGh05_oCRGh2o`0000gohHQT0_l000001?oLM4Co0000onAl>_l00004
onAl>P;o000000?odeT3o`000?ooool0=_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool0
02Cooooo00?o0000ooooooooool0??ooool00ol0003o@015od00A@02od00A@03o`000?mP:GCoH2Ud
00ooH2Ud00?o0000oiaJPOnLFX402onLFX46o`0000koXVfE00?o0000okn3TonoPi<04onoPi<9o`00
00?o_GJ200?o0000om>9O_oCRGh05_oCRGh01?l0003ohIEjo`000?l0000=on68I0;o000000?oi7`j
o`000?oTO3X01OoTO3X00ol0003odeT3o`00000cooooo`?o00002?ooool00ol0003oooooooooo`0E
ooooo`009?ooool00ol0003oooooooooo`0kooooo`;o00000_m004D2o`0001;oH2Ud00?o0000oiaJ
POnLFX401OnLFX46o`0001CoXVfE00?o0000okn3TonoPi<07?noPi<5o`0001OodhUn00Co0000on6E
N_oQUG[ohIEj0_l0000=on68I0;o00001ooTO3X3o`0002oooooo0ol0000;ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`;o0000??ooool4o`0001CoH2Ud00?o0000oiaJPOnLFX401Ol0000Joj9]
U@03o`000?noPi?o_h>C01oo_h>C00?o0000om>CSol000000_l0000Dom>9OP03o`000?oQUG[ohIEj
00?ohIEj00?o0000on68I?oQR6@02_oQR6@3o`0000Soi7`j0_l0000[ooooo`?o00003oooool00ol0
003oooooooooo`0Dooooo`009?ooool00ol0003oooooooooo`0jooooo`?o00005OmP:G@4o`0001oo
XVfE00?o0000okn3TonoPi<07onoPi<00ol0003odi>?om>CS`02om>CS`?o00004OoCRGh00ol0003o
hIEjon6ENP04on6ENP;o00002_oQR6@2o`000003onV@G?l0003o000000Ooi7`j0_l0000Wooooo`?o
00004_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0kooooo`;o0000
5?mP:G@2o`000003og=:T_l0003oXVfE023oXVfE00?o0000okn3TonoPi<07onoPi<00ol0003odi>?
om>CS`05om>CS`?o00003_oCRGh00ol0003ohIEjon6ENP06on6ENP;o00002?oQR6@2o`0000?ojI1L
00?o0000onAl>_oTO3X01?oTO3X00ol0003o/S/0o`00000Sooooo`?o00005Oooool00ol0003ooooo
ooooo`0Dooooo`008oooool00ol0003oooooooooo`0kooooo`;o00004omP:G@01Ol0003oLdZBog=:
T_mcBY;o000002;oXVfE00?o0000okn3TonoPi<07_noPi<00ol0003odi>?om>CS`08om>CS`?o0000
3?oCRGh00ol0003ohIEjon6ENP07on6ENP;o00001_oQR6@2o`0000CojI1L0_l00005onAl>P03o`00
0?nb>`3o000001oooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oo
oooooooo03[ooooo0ol0000Aof0YM0;o00001?mcBY800ol0003oXVfEoj9]U@0Poj9]U@03o`000?no
Pi?o_h>C01ko_h>C00?o0000om>CSooCThl02ooCThl3o`0000WodhUn00?o0000on6EN_oQUGX02OoQ
UGX2o`0000GohHQT0_l00005onV@G003o`000?oTO3[oi7`j00;oi7`j0_l000000onb>`3o0000oooo
o`0Jooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0j
ooooo`03o`000?l003?o000000ooH2Ud0_l00006og=:TP03o`000?nRKIGoXVfE023oXVfE00?o0000
okn3TonoPi<07_noPi<00ol0003odi>?om>CS`0>om>CS`?o00001_oCRGh00ol0003ohIEjon6ENP0;
on6ENP03o`000?oQR6CohHQT00;ohHQT0_l00006onV@G003o`000?oTO3[oi7`j00;oi7`j0ol0000H
ooooo`?o00007_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`0ioooo
o`?o00003_mP:G@2o`0000SoLdZB00?o0000oj9]UOnRKID08?nRKID00ol0003o_h>Cokn3T`0Mokn3
T`03o`000?oCThoodi>?01;odi>?0ol00003om>9OP03o`000?oQUG[ohIEj00cohIEj0_l00002on68
I0;o00001ooYT5`2o`0000;oi7`j00Co0000on1d2Ol0003o00005?ooool3o`00027ooooo00?o0000
ooooooooool05?ooool002?ooooo0_l0000jooooo`?o00003OmP:G@00ol0003oLdZBog=:TP08og=:
TP03o`000?nRKIGoXVfE023oXVfE00?o0000okn3TonoPi<07OnoPi<00ol0003odi>?om>CS`0Eom>C
S`Co00004?oQUGX4o`0000WojI1L00?o0000onAl>_l000000_oPM0T2o`00013ooooo0ol0000Uoooo
o`03o`000?oooooooooo01?ooooo000Sooooo`03o`000?oooooooooo03Sooooo0_l000000ol003?o
0000of0YM00:of0YM0;o00002omcBY800ol0003oXVfEoj9]U@0Poj9]U@03o`000?noPi?o_h>C01go
_h>C00?o0000om>CSooCThl06?oCThl2o`00017ohIEj0_l0000:onV@G0?o00000_oPM0T2o`0000co
oooo0ol0000Xooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo03Wooooo
0_l000000ol003?o0000of0YM008of0YM0;o00003OmcBY800ol0003oXVfEoj9]U@0Poj9]U@03o`00
0?noPi?o_h>C01go_h>C00?o0000om>CSooCThl06?oCThl01?l0003oh9j;o`000?l0000?on6ENP?o
00002ooYT5`01?l0003oh7@9on1d2OoPM0T2o`0000Sooooo0ol0000[ooooo`03o`000?oooooooooo
01?ooooo000Rooooo`03o`000?oooooooooo03Sooooo0ol000000ol003?o0000of0YM007of0YM003
o`000?mcBY;oLdZB00koLdZB00?o0000oj9]UOnRKID07OnRKID;o`0001Oo_h>C00?o0000om>CSooC
Thl06?oCThl01?l0003oh9j;on2NRooPWX/2o`0000gohIEj0_l000000ooZW7Co0000o`00000:onV@
G005o`000?oPM0Woh7@9on1d2Ol000001Oooool3o`0002kooooo00?o0000ooooooooool04oooool0
02;ooooo00?o0000ooooooooool0>?ooool2o`0000;o000c00?o0000of0YM?mP:G@01?mP:G@2o`00
017oLdZB00?o0000oj9]UOnRKID06?nRKID5o`0000;oYW^T00?o0000okn=XOnoSJ401_noSJ4@o`00
00Oo_h>C00?o0000om>CSooCThl06?oCThl00ol0003oh9j;on2NR`03on2NR`;o00002ooQUGX2o`00
00?ojYad00?o0000onV@G?oYT5`01ooYT5`00ol0003oh7@9on1d2@02on1d2@03o`000?oooooo0000
00;o0000<Oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0hooooo`;o
00000_l003<00ol0003oH2Udof0YM002of0YM0;o00004omcBY800ol0003oXVfEoj9]U@0Coj9]U@Go
00001onVNj@00ol0003o_hfQokn=X@0Fokn=X@[o00006?oCThl00ol0003oh9j;on2NR`05on2NR`;o
00002OoQUGX2o`0000CojYad00?o0000onV@G?oYT5`01_oYT5`2o`0000Coh7@900?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0gooooo`;o0000
0_l003<01?l0003oH2Udof0YM?mP:G@2o`0001GoLdZB00?o0000oj9]UOnRKID03_nRKID5o`0000co
YW^T00?o0000okn=XOnoSJ407OnoSJ400ol0003odYbMom:LW@03o`0001Godi>?00?o0000on2NRooP
WX/01ooPWX/2o`0000OohIEj0_l00005onZLM0;o00001ooYT5`2o`0000Coh7@900?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Cooooo`008Oooool3o`0003Sooooo0_l00002o`00<`04o`00
0?mP:GCoH2Udo`0001OoLdZB00?o0000oj9]UOnRKID02OnRKID5o`00017oYW^T00?o0000okn=XOno
SJ407OnoSJ400ol0003odYbMom:LW@03om:LW@?o00004_oCThl00ol0003oh9j;on2NR`09on2NR`;o
00001_oQUGX00ol0003ojYadonZLM005onZLM003o`000?oYT5cojI1L00CojI1L00?o0000oo6E@?l0
00000ooPM0T00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`00
0?oooooooooo03Sooooo00Co0000o`00<ol003?o000c0ol0000Hog=:TP03o`000?nRKIGoXVfE00Co
XVfE1Ol0000FojIkY003o`000?noSJ7o_hfQ01go_hfQ00?o0000om:LWOoBW9d01_oBW9d3o`0000ko
di>?00?o0000on2NRooPWX/03?oPWX/2o`0000CohIEj00?o0000onZLM?oZW7@01_oZW7@2o`0000Co
jI1L00Co0000oo6E@?oaUD3o00000ooPM0T00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01;ooooo000Qooooo`03o`000?oooooooooo03Oooooo0_l00003o`00<`03o`000?mcBY;oLdZB01So
LdZB00?o0000oj9]UOl000001?l0000KojIkY003o`000?noSJ7o_hfQ01go_hfQ00?o0000om:LWOoB
W9d02OoBW9d4o`0000[odi>?00?o0000on2NRooPWX/03_oPWX/2o`0000;ohIEj00?o0000onZLM?oZ
W7@02?oZW7@01Ol0003ojI1LonV@G?oYT5co000000?olIE000Co0000on1d2OoPM0Wo0000<oooool0
0ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?l003?o000c
00;o000c00?o0000og=:T_mcBY805omcBY83o`00023oYW^T00?o0000okn=XOnoSJ407OnoSJ400ol0
003odYbMom:LW@0=om:LW@?o00001ooCThl00ol0003oh9j;on2NR`0@on2NR`?o00002ooZW7@01?l0
003ojI1LonV@G?l00004oo6E@004o`000?oPM0Woh7@9o`0003;ooooo00?o0000ooooooooool04_oo
ool0027ooooo00?o0000ooooooooool0=oooool01?l0003o000co`00<ol003<2o`0001OoLdZB0_l0
00000omoHZOo0000ojIkY00PojIkY003o`000?noSJ7o_hfQ01go_hfQ00?o0000om:LWOoBW9d04?oB
W9d3o`0000Codi>?00?o0000on2NRooPWX/04_oPWX/2o`0000_ojYad0_l000000ooYT5co0000oo6E
@003oo6E@003o`000?oPM0Wo000003;ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000
ooooooooool0=_ooool2o`0000?o000c0_l0000Fog=:TP05o`000?moHZOoOf:WogmRYol000008_nV
Nj@00ol0003o_hfQokn=X@0Lokn=X@03o`000?oBW9godYbM01?odYbM0ol000000ooCThoo0000on2N
R`0Con2NR`03o`000?oYYHKo000000cojYad0_l00005oo6E@003o`000?oPM0Wo0000037ooooo00?o
0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0=_ooool01ol0003o000co`00<ol0
03?o0000o`00M_l000005?mcBY82o`0000GoOf:W00?o0000ojIkY?nVNj@07onVNj@00ol0003o_hfQ
okn=X@0Lokn=X@03o`000?oBW9godYbM01KodYbM0ol0000Con2NR`03o`000?oYYHKojJF600;o0000
2ooZW7@00ol0003olIE0oo6E@004oo6E@0;o0000<Oooool00ol0003oooooooooo`0Booooo`008?oo
ool3o`0003Oooooo00Go0000o`00<ol003?o000co`000002o`00MP03o`000?mcBY;oLdZB00ooLdZB
0_l00007ogmRY`03o`000?nVNjCoYW^T01ooYW^T00?o0000okn=XOnoSJ407?noSJ400ol0003odYbM
om:LW@0Gom:LW@04o`000?oNYIWo0000o`00017oh9j;00?o0000onVUQ_oYYHH00_oYYHH00ol0003o
jYadonZLM008onZLM003o`000?oaUD3olIE000GolIE00_l0000aooooo`03o`000?oooooooooo017o
oooo000Pooooo`03o`000?oooooooooo03Kooooo00Go0000o`00<ol003?o000co`000003o`00MP03
o`000?mcBY;oLdZB00goLdZB0_l00009ogmRY`03o`000?nVNjCoYW^T01ooYW^T00?o0000okn=XOno
SJ407?noSJ400ol0003odYbMom:LW@0Gom:LW@04o`000?oNYIWogZFIomjUV@;o00003ooPWX/2o`00
00CojJF600?o0000onZLM?oZW7@01ooZW7@2o`0000OolIE000?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0=_ooool01Ol0003o000co`00<ol003?o000000?o001f00?o0000og=:T_mcBY802omcBY82
o`0000_oOf:W00?o0000ojIkY?nVNj@07onVNj@00ol0003o_hfQokn=X@0Lokn=X@03o`000?oBW9go
dYbM01OodYbM00?o0000omjUVOoNYIT00ooNYIT2o`0000goh9j;0_l00005onVUQP;o00001ooZW7@0
0ol0003omZQUo`000007oo6E@003o`000?oooooooooo02kooooo00?o0000ooooooooool04Oooool0
01Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03Kooooo00Co0000
o`00<ol003?o00001?l007H00ol0003oLdZBog=:TP0:og=:TP03o`000?moHZOoOf:W00coOf:W00?o
0000ojIkY?nVNj@07_nVNj@00ol0003o_hfQokn=X@0Lokn=X@03o`000?oBW9godYbM01OodYbM00?o
0000omjUVOoNYIT01OoNYIT2o`0000_oh9j;0_l00007onVUQP03o`000?oZW7CojYad00CojYad00Co
0000ooJXIOofZ6Go00001_oaUD000ol0003oooooooooo`0^ooooo`03o`000?oooooooooo017ooooo
000Eooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0fooooo`04o`00
0?l003?o000co`0000Co001f00?o0000og=:T_mcBY802?mcBY82o`0000ooOf:W00?o0000ojIkY?nV
Nj@07_nVNj@00ol0003o_hfQokn=X@0Lokn=X@03o`000?oBW9godYbM01OodYbM00?o0000omjUVOoN
YIT01ooNYIT2o`0000Soh9j;00?o0000onVUQ_l000002?oYYHH2o`0000CojYad00Go0000ooJXIOof
Z6GomZQUo`000005oo6E@003o`000?oooooooooo02kooooo00?o0000ooooooooool04Oooool001Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo03Gooooo00Co0000o`00
<ol003?o00001Ol007H00ol0003oLdZBog=:TP06og=:TP;o00004OmoHZL00ol0003oYW^TojIkY00N
ojIkY003o`000?noSJ7o_hfQ01co_hfQ00?o0000om:LWOoBW9d05ooBW9d00ol0003ogZFIomjUV@09
omjUV@;o00001_oPWX/00ol0003ojJF6o`00000:onVUQP03o`000?oZW7CojYad00;ojYad00Go0000
ooJXIOofZ6GomZQUo`000005oo6E@003o`000?oooooooooo02gooooo00?o0000ooooooooool04Ooo
ool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03Kooooo00Co
0000o`00<ol003?o00001Ol007H00ol0003oLdZBog=:TP04og=:TP;o00004omoHZL00ol0003oYW^T
ojIkY00LojIkY2Co00005_oBW9d00ol0003ogZFIomjUV@0<omjUV@;o00001?oPWX/00ol0003ojJF6
o`00000;onVUQP05o`000?oZW7CojYadonZLM?l000001?ofZ6D00ol0003olIE0oo6E@002oo6E@003
o`000?oooooooooo02gooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000=oooool01?l0003o000co`00<ol00006o`00MP04o`000?mcBY;oLdZB
og=:TP;o00005OmoHZL00ol0003oYW^TojIkY00GojIkY0Go00000_nYQk400ol0003o_iJ]oknF[@0L
oknF[@03o`000?o@XjWod:>Y00Co00004_oBW9d00ol0003ogZFIomjUV@0>omjUV@;o00000_oPWX/0
0ol0003ojJF6o`00000<onVUQP;o000000?ojYado`000?ofZ6D01?ofZ6D01Ol0003olIE0oo6E@?oa
UD3o000002oooooo00?o0000ooooooooool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`03o`000?oooooooooo03Kooooo00?o0000o`00<ol000001ol007H01?l0003oLdZBog=:
T_l0000HogmRY`03o`000?nVNjCoYW^T01;oYW^T1?l00007ojV7/@03o`000?noUZgo_iJ]01co_iJ]
00?o0000om2SZOo@XjT01?o@XjT4o`0000kodYbM00?o0000omjUVOoNYIT04?oNYIT3o`000003onVU
Q_l0003ojJF600gojJF60_l00006ooJXI@05o`000?oaUD3olIE0oo6E@?l00000;oooool00ol0003o
ooooooooo`0@ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool0=_ooool00ol0003o000co`000007o`00MP?o00006OmoHZL00ol0003oYW^TojIkY00=ojIkY0Go
00002onYQk400ol0003o_iJ]oknF[@0LoknF[@03o`000?o@XjWod:>Y00Sod:>Y1Ol00009om:LW@03
o`000?oNYIWogZFI01;ogZFI0ol0000?onVUQP03o`000?ofZ6GomZQU00GomZQU00Co0000oo6E@?oa
UD3o0000;oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`0fooooo`;o
00002?l007H00ol0003oOf:WogmRY`0IogmRY`03o`000?nVNjCoYW^T00WoYW^T1?l0000@ojV7/@03
o`000?noUZgo_iJ]01co_iJ]00?o0000om2SZOo@XjT03Oo@XjT4o`0000GodYbM00?o0000omjUVOoN
YIT04_oNYIT00ol0003oijfEo`00000?onVUQP03o`000?ofZ6GomZQU00KomZQU00?o0000oo6E@?l0
0000;oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003oooooooooo`0fooooo`03o`00
<ol0003o001f00Oo001f00?o0000ogmRYomoHZL06OmoHZL00ol0003oYW^TojIkY005ojIkY0Co0000
5OnYQk400ol0003o_iJ]oknF[@0KoknF[@03o`000?o@XjWod:>Y017od:>Y1?l000000ooBW9go0000
omjUV@0ComjUV@03o`000?oW[IGo000000;o00003OoYYHH2o`0000SomZQU0ol0000^ooooo`03o`00
0?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo03Gooooo0_l00008o`00MP;o00007?mo
HZL00ol0003oYW^To`000004o`0001WoZHNa00?o0000oknF[OnoUZd06onoUZd00ol0003od:>Yom2S
Z@0Eom2SZ@?o00004ooNYIT00ol0003oijfEo`000002onN]U@03o`000?oYYHKojJF600[ojJF600?o
0000ooJcP?l000002?ofZ6D2o`0002kooooo00?o0000ooooooooool04?ooool001kooooo00?o0000
ooooooooool0=_ooool2o`0000So001f00?o0000obL[Wol000006_moHZL3o`0001koZHNa00?o0000
oknF[OnoUZd06onoUZd00ol0003od:>Yom2SZ@0Fom2SZ@04o`000?oKZjGo0000o`00017ogZFI00?o
0000onN]UOl000000ooW[ID00ol0003ojJF6onVUQP09onVUQP04o`000?of/h3om[>0o`0000SomZQU
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003ooooooooo
o`0fooooo`03o`000?l007Ko001f00Ko001f00Co0000obL[WolW:ioo00006?moHZL2o`000003ohQd
]_l0003oZHNa01koZHNa00?o0000oknF[OnoUZd06onoUZd00ol0003od:>Yom2SZ@0Fom2SZ@04o`00
0?oKZjGofj^Uom^[Y@?o00003_oNYIT00ol0003oijfEo`000004onN]U@;o00002OoYYHH01Ol0003o
m[>0ooJcP?of/h3o000000OomZQU0_l0000]ooooo`03o`000?oooooooooo013ooooo000Nooooo`;o
0000=oooool00ol0003o001fo`00MP06o`00MP04o`000?lW:ioo9b^Oo`0001KoOf:W0_l00003ohQd
]P03o`000?nYQk7oZHNa01goZHNa00?o0000oknF[OnoUZd06onoUZd00ol0003od:>Yom2SZ@0Fom2S
Z@03o`000?oKZjGofj^U00Cofj^U0_l0000<omjUV@03o`000?oW[IGo000000KoijfE00?o0000onVU
Q_oYYHH01_oYYHH00ol0003om[>0ooJcP002ooJcP003o`000?ofZ6GomZQU00ComZQU0_l0000^oooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03Kooooo00?o0000o`00M_l0
07H01Ol007H00ol0003o9b^OobL[W`02obL[W`03o`000?moHZOoOf:W01;oOf:W00?o0000ohQd]_n8
M;H01?n8M;H00ol0003oZHNaojV7/@0LojV7/@03o`000?noUZgo_iJ]01_o_iJ]00?o0000om2SZOo@
XjT05Oo@XjT00ol0003ofj^Uom^[Y@07om^[Y@;o00002OoNYIT01?l0003oijfEonN]UOl00007onN]
U@;o00001OoYYHH00ol0003om[>0ooJcP004ooJcP003o`000?ofZ6GomZQU00?omZQU0_l0000^oooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03Kooooo00?o0000o`00M_l0
07H01Ol007H00ol0003o9b^OobL[W`02obL[W`03o`000?moHZOoOf:W013oOf:W0_l00007ohQd]P03
o`000?nYQk7oZHNa01coZHNa00?o0000oknF[OnoUZd06onoUZd00ol0003od:>Yom2SZ@0Eom2SZ@03
o`000?oKZjGofj^U00Wofj^U0_l00007omjUV@04o`000?oW[IGoijfEo`0000WoijfE00?o0000onVU
Q_oYYHH00_oYYHH00ol0003om[>0ooJcP005ooJcP003o`000?ofZ6GomZQU00;omZQU0ol0000]oooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000o`00M_l0
07H00ol007H00ol0003o9b^OobL[W`03obL[W`03o`000?moHZOoOf:W00koOf:W0_l00009ohQd]P03
o`000?nYQk7oZHNa01coZHNa00?o0000oknF[OnoUZd06onoUZd00ol0003od:>Yom2SZ@0Eom2SZ@03
o`000?oKZjGofj^U00_ofj^U0_l00005omjUV@04o`000?oW[IGoijfEo`0000[oijfE00Go0000onVU
Q_oYYHKojJF6o`000007ooJcP003o`000?ofZ6GomZQU00;omZQU00?o0000onJT8_l00000;Oooool0
0ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?l007Ko001f
00?o001f00?o0000obL[WolW:il01?lW:il00ol0003oOf:WogmRY`0;ogmRY`;o00003?n8M;H00ol0
003oZHNaojV7/@0KojV7/@03o`000?noUZgo_iJ]01_o_iJ]00?o0000om2SZOo@XjT05Oo@XjT00ol0
003ofj^Uom^[Y@0=om^[Y@?o00000_oNYIT01?l0003oijfEonN]UOl0000;onN]U@;o000000?ojJF6
o`000?of/h001oof/h000ol0003omZQUooJXI@02ooJXI@;o0000;Oooool00ol0003oooooooooo`0?
ooooo`007Oooool00ol0003oooooooooo`0hooooo`03o`000?l007Ko001f00;o001f00?o0000obL[
WolW:il01OlW:il00ol0003oOf:WogmRY`09ogmRY`;o00003_n8M;H00ol0003oZHNaojV7/@0LojV7
/@03o`000?noUZgo_iJ]01[o_iJ]00?o0000om2SZOo@XjT05Oo@XjT00ol0003ofj^Uom^[Y@0@om^[
Y@?o00000ooW[ID00ol0003oijfEonN]U@0:onN]U@;o00002Oof/h001?l0003omZQUooJXIOofZ6D3
o`0002cooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0>?ooool00ol0
003o001fo`00MP02o`00MP03o`000?lW:ioo9b^O00Go9b^O00?o0000ogmRYomoHZL01omoHZL2o`00
013oR7Bf00?o0000ojV7/OnYQk407?nYQk400ol0003o_iJ]oknF[@0JoknF[@03o`000?o@XjWod:>Y
01God:>Y00?o0000om^[YOoKZjD04_oKZjD2o`0000;oijfE00?o0000onN]UOoW[ID02ooW[ID00ol0
003om[>0ooJcP008ooJcP006o`000?ofZ6GomZQUo`000?oVY2;o0000;?ooool00ol0003ooooooooo
o`0?ooooo`007Oooool2o`0003Wooooo00Go0000o`00M_l007Ko001fo`000009obL[W`03o`000?mo
HZOoOf:W00CoOf:W0_l0000CohQd]P03o`000?nYQk7oZHNa01_oZHNa00?o0000oknF[OnoUZd03?no
UZdBo`0001Cod:>Y00?o0000om^[YOoKZjD04_oKZjD01Ol0003oi;>So`000?oW[IGo000000goijfE
00?o0000ooJcP?of/h002Oof/h001Ol0003omZQUo`000?oVY2;o000002gooooo00?o0000oooooooo
ool03_ooool001gooooo00?o0000ooooooooool0>?ooool01Ol0003o001fo`00M_l007Ko000000Wo
9b^O00?o0000ogmRYomoHZL00omoHZL00ol0003oR7BfohQd]P0CohQd]P03o`000?nYQk7oZHNa01Wo
ZHNa4Ol0000>oknN]`04o`000?o=Z;?ocJRcolfX/`Ko00003Oo@XjT00ol0003ofj^Uom^[Y@0Com^[
Y@03o`000?oT/j?oi;>S00;o00003OoW[ID2o`0000_om[>00_l00002onJT8P03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0>?ooool01?l0003o
001fo`00M_l0000:obL[W`04o`000?moHZOoOf:WogmRY`;o00005_n8M;H00ol0003oZHNaojV7/@0E
ojV7/@Co00000_n[T[/00ol0003o_ijgoknN]`0JoknN]`03o`000?o=Z;?ocJRc00OocJRc1Ol00008
om2SZ@03o`000?oKZjGofj^U01;ofj^U00?o0000onBcXooT/j<00_oT/j<2o`0000coijfE00?o0000
oo:lU?l000002oof/h001?l0003oiZ@RonJT8_l0000/ooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo03[ooooo00?o0000o`00M_l000002olW:il3o`0001SoR7Bf00?o0000
ojV7/OnYQk404OnYQk44o`0000KoZi:k00?o0000oknN]onoW[L06_noW[L00ol0003ocJRcolfX/`0<
olfX/`Ko00000_o@XjT00ol0003ofj^Uom^[Y@0Bom^[Y@03o`000?oT/j?oi;>S00;oi;>S00Co0000
onBcXol0003o00002OoW[ID01Ol0003ol[bDoo:lU?ob_9Co000000[om[>000Co0000onJT8_oVY2;o
0000;?ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o0000
3?lW:il00ol0003oR7BfohQd]P0IohQd]P03o`000?nYQk7oZHNa00coZHNa1?l0000:oj^B^`03o`00
0?noW[Oo_ijg01[o_ijg00?o0000olfX/oo=Z;<04_o=Z;<4o`0001?ofj^U00?o0000onBcXooT/j<0
0_oT/j<01Ol0003oi;>SonBcXooT/j?o000000SoijfE00?o0000oo:lU?ob_9@00_ob_9@00ol0003o
m[>0ooJcP007ooJcP0;o00000_oVY2800ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00ko
oooo000Looooo`03o`000?oooooooooo03[ooooo0_l0000<obL[W`03o`000?n8M;KoR7Bf01WoR7Bf
00?o0000ojV7/OnYQk402?nYQk44o`0000ooZi:k00?o0000oknN]onoW[L06OnoW[L00ol0003ocJRc
olfX/`0DolfX/`03o`000?oH/K7o000000;o00004?oKZjD00ol0003oi;>SonBcX`02onBcX`03o`00
0?oT/j?oi;>S00;oi;>S00?o0000onN]UOoW[ID01OoW[ID00ol0003ol[bDoo:lU003oo:lU003o`00
0?of/h3om[>000Kom[>00_l00002onJT8P03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0>_ooool00ol0003o9b^OobL[W`0:obL[W`03o`000?m5
D;Wo000001[oR7Bf00?o0000ojV7/OnYQk401?nYQk44o`0001?oZi:k00?o0000oknN]onoW[L06Ono
W[L00ol0003ocJRcolfX/`0DolfX/`03o`000?oH/K7of;6a00;of;6a0ol0000<om^[Y@04o`000?oT
/j?oi;>SonBcX`?o00001OoT/j<2o`0000GoijfE00?o0000oo:lU?ob_9@01?ob_9@00ol0003om[>0
ooJcP005ooJcP0;o00000_oVY2800ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo03[ooooo00?o0000obL[WolW:il02_lW:il00ol0003oAE2io`00
000KohQd]P03o`000?nYQk7o000000?o00005on[T[/00ol0003o_ijgoknN]`0IoknN]`03o`000?o=
Z;?ocJRc01?ocJRc00?o0000omRa/OoH/K401_oH/K43o`0000Wofj^U1?l00002onBcX`03o`000?oT
/j?oi;>S00Goi;>S00?o0000onN]UOoW[ID00_oW[ID00ol0003ol[bDoo:lU005oo:lU003o`000?of
/h3om[>000Com[>000?o0000oo_8H?l000000_oVY2800ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00gooooo000Looooo`;o0000??ooool00ol0003o9b^OobL[W`08obL[W`05o`000?m5D;Wo
AE2iodE@^Ol000006On8M;H3o`0001_oZi:k00?o0000oknN]onoW[L06OnoW[L00ol0003ocJRcolfX
/`0ColfX/`03o`000?oH/K7of;6a00Wof;6a0_l00005om^[Y@?o00001_oT/j<00ol0003oi;>SonBc
X`05onBcX`;o000000?oijfEo`000?ob_9@01oob_9@00ol0003om[>0ooJcP004ooJcP003o`000?ok
b63o000000;oiZ@R00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`006oooool0
0ol0003oooooooooo`0looooo`03o`000?lW:ioo9b^O00Oo9b^O00?o0000odE@^Om5D;T00_m5D;T0
0ol0003oR7BfohQd]P0EohQd]P;o000000?oSh?2o`000?n[T[/06on[T[/00ol0003o_ijgoknN]`0H
oknN]`03o`000?o=Z;?ocJRc01CocJRc00?o0000omRa/OoH/K402ooH/K45o`0000;ofj^U00?o0000
onBcXooT/j<01OoT/j<00ol0003oi;>SonBcX`06onBcX`;o00002Oob_9@00ol0003om[>0ooJcP002
ooJcP004o`000?okb63onlQPo`0000;oiZ@R00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0=ooooo`006oooool00ol0003oooooooooo`0looooo`03o`000?lW:ioo9b^O00Oo9b^O00?o0000
odE@^Om5D;T00om5D;T00ol0003oR7BfohQd]P0CohQd]P03o`000?n?Pl;oSh?200;oSh?200?o0000
oj^B^on[T[/06_n[T[/00ol0003o_ijgoknN]`0GoknN]`03o`000?o=Z;?ocJRc01CocJRc00?o0000
omRa/OoH/K402OoH/K44o`000003omRa/Ol0003o000000;o00002OoT/j<00ol0003oi;>SonBcX`06
onBcX`03o`000?ob_9Col[bD00Sol[bD00Go0000ooJcP?of/h3om[>0o`000003oo_8H003o`000?oV
Y2;o000002_ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0?Oooool0
0ol0003o9b^OobL[W`05obL[W`03o`000?m5D;WoAE2i00CoAE2i00?o0000ohQd]_n8M;H04On8M;H2
o`0000GoSh?200?o0000oj^B^on[T[/06_n[T[/00ol0003o_ijgoknN]`0GoknN]`03o`000?o=Z;?o
cJRc01CocJRc00?o0000omRa/OoH/K401_oH/K43o`0000Sof;6a0_l00009onBcX`03o`000?oT/j?o
i;>S00Goi;>S00?o0000oo:lU?ob_9@02Oob_9@01?l0003om[>0ooJcP?l00003oo_8H003o`000?oV
Y2;o000002_ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0?Oooool0
0ol0003o9b^OobL[W`05obL[W`03o`000?m5D;WoAE2i00GoAE2i00?o0000ohQd]_n8M;H03_n8M;H2
o`0000SoSh?200?o0000oj^B^on[T[/06On[T[/00ol0003o_ijgoknN]`0GoknN]`03o`000?o=Z;?o
cJRc01?ocJRc00?o0000omRa/OoH/K401?oH/K43o`0000_of;6a00?o0000omni/?l000002?oT/j<0
0ol0003oi;>SonBcX`04onBcX`03o`000?o^`ZGo000000_ol[bD00?o0000ooJcP?l000000ookb600
0ol0003oiZ@Ro`00000[ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo
03gooooo00?o0000obL[WolW:il01?lW:il00ol0003oAE2iodE@^@06odE@^@03o`000?n8M;KoR7Bf
00coR7Bf0_l0000:ohn3`P03o`000?n[T[_oZi:k01WoZi:k00?o0000oknN]onoW[L05onoW[L00ol0
003ocJRcolfX/`0ColfX/`04o`000?oH/K7of;6aomRa/@?o00003OoH/K401Ol0003ogkV`omni/?oO
^K3o000000Soi;>S00?o0000onBcXooT/j<00ooT/j<01?l0003ok/:Uonk2YOl0000;oo:lU0;o0000
1?okb602o`0002_ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0?_oo
ool00ol0003o9b^OobL[W`03obL[W`03o`000?m5D;WoAE2i00OoAE2i00?o0000ohQd]_n8M;H02_n8
M;H00ol0003oSh?2ohn3`P0:ohn3`P03o`000?n[T[_oZi:k01WoZi:k00?o0000oknN]onoW[L05ono
W[L00ol0003ocJRcolfX/`0ColfX/`Co00004?oH/K400ol0003ogkV`omni/002omni/003o`000?oT
/j?oi;>S00Koi;>S00?o0000onBcXooT/j<00_oT/j<01Ol0003ok/:Uonk2YOo^`ZGo000000_ol[bD
00?o0000oo_8H?okb6000_okb6000ol0003oiZ@Ro`00000Zooooo`03o`000?oooooooooo00gooooo
000Kooooo`;o0000?oooool00ol0003o9b^OobL[W`02obL[W`03o`000?m5D;WoAE2i00SoAE2i00?o
0000ohQd]_n8M;H02?n8M;H2o`0000koSh?200?o0000oj^B^on[T[/06?n[T[/00ol0003o_ijgoknN
]`0GoknN]`03o`000?o=Z;?ocJRc013ocJRc1?l0000ComRa/@03o`000?oO^K3ogkV`00?ogkV`00?o
0000onBcXooT/j<01_oT/j<01?l0003oi;>SonBcXol00005onk2Y@03o`000?ob_9Col[bD00Sol[bD
00?o0000oo_8H?okb6000_okb6000ol0003oiZ@Ro`00000[ooooo`03o`000?oooooooooo00cooooo
000Jooooo`03o`000?oooooooooo03oooooo00?o0000obL[WolW:il00_lW:il00ol0003oAE2iodE@
^@09odE@^@03o`000?n8M;KoR7Bf00GoR7Bf0_l0000@ohn3`P03o`000?n[T[_oZi:k01WoZi:k00?o
0000oknN]onoW[L04?noW[L<o`0000[ocJRc0ol00003olfX/`03o`000?oH/K7of;6a013of;6a00?o
0000omni/?oO^K001OoO^K000ol0003oi;>SonBcX`06onBcX`03o`000?oT/j?o000000Gok/:U00?o
0000oo:lU?ob_9@02?ob_9@00ol0003onlQPoo_8H003oo_8H0;o0000:oooool00ol0003ooooooooo
o`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo043ooooo00Co0000obL[WolW:ioo00003?m5D;T00ol0003o
R7BfohQd]P03ohQd]P;o00004on?Pl800ol0003oZi:koj^B^`0Hoj^B^`03o`000?noW[Oo_ijg00?o
_ijg3Ol00006okfU`@03o`000?o:[[kobZjn00?obZjn2ol00004olfX/`03o`000?oH/K7of;6a017o
f;6a00?o0000omni/?oO^K001_oO^K02o`0000Ooi;>S00?o0000onk2YOo^`ZD01Oo^`ZD00ol0003o
l[bDoo:lU006oo:lU003o`000?oofHco000000ConlQP0_l0000[ooooo`03o`000?oooooooooo00co
oooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo043ooooo00?o0000obL[Wol000003_m5D;T01Ol0003oR7BfohQd]_n8M;Ko0000
01GoSh?200?o0000oj^B^on[T[/05_n[T[/8o`0001?o_JG100?o0000olZ^__o:[[h01_o:[[h4o`00
00CobZjn1_l0000BomRa/@03o`000?oO^K3ogkV`00SogkV`00?o0000onBcXooT/j<01?oT/j<00ol0
003ok/:Uonk2Y@06onk2Y@03o`000?ob_9Col[bD00Gol[bD00?o0000oooIS?l000001?okb602o`00
02_ooooo00?o0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo043ooooo00?o0000obL[Wol000003_m5D;T01?l0003o
R7Bfo`000?l0000Gohn3`P03o`000?n[T[_oZi:k017oZi:k1?l00002ojfKaP03o`000?nmYL7o_JG1
01Ko_JG100?o0000olZ^__o:[[h00oo:[[h3o`0000cobZjn00?o0000om>f_?l000000_l0000>omRa
/@03o`000?oO^K3ogkV`00[ogkV`00?o0000onBcXooT/j<00ooT/j<2o`0000Sok/:U00?o0000oo:l
U?ob_9@01?ob_9@00ol0003oomV<o`000005oo_8H003o`000?oooooooooo02Wooooo00?o0000oooo
ooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo047ooooo00?o0000odE@^Om5D;T03_m5D;T00ol0003oSh?2ohn3`P0Gohn3`P03
o`000?n[T[_oZi:k00goZi:k1?l00006ojfKaP03o`000?nmYL7o_JG101Ko_JG100?o0000olZ^__o:
[[h00ol0000?olZ^_P03o`000?oC][codkJl00;odkJl0_l0000<omRa/@03o`000?oO^K3ogkV`00_o
gkV`00Go0000onBcXooT/j?oi;>So`000002onk2Y@03o`000?o^`ZGok/:U00Kok/:U00?o0000oo:l
U?ob_9@00_ob_9@01Ol0003oomV<oooIS?oofHco000000ConlQP00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0<ooooo`000oooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`11ooooo`03o`000?m5D;WoAE2i00koAE2i00?o0000
ohn3`_n?Pl805on?Pl800ol0003oZi:koj^B^`09oj^B^`Co00002_n]VlH00ol0003o_JG1okfU`@0F
okfU`@?o00004Oo:[[h00ol0003odkJlom>f_005om>f_0?o00002OoH/K400ol0003ogkV`omni/00<
omni/004o`000?oT/j?oi;>So`0000?ok/:U00?o0000onk2YOo^`ZD01Oo^`ZD00ol0003ol[bDoo:l
U002oo:lU005o`000?oofHcoomV<oooIS?l000001?okb6000ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00cooooo0003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`12ooooo`;o00003_m5D;T00ol0003oFfc;o`00000Iohn3`P03o`000?n[
T[_oZi:k00CoZi:k1?l0000?ojfKaP03o`000?nmYL7o_JG1017o_JG11Ol0000ColZ^_P03o`000?oC
][codkJl00SodkJl0_l00006omRa/@03o`000?oO^K3ogkV`00kogkV`00?o0000onBcXol000001?o^
`ZD00ol0003ok/:Uonk2Y@05onk2Y@05o`000?ob_9Col[bDoo:lU?l000000ooofH`00ol0003onlQP
oo_8H002oo_8H003o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00004oiRHV?oo
ooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`0004Cooooo00?o0023o`000?m5D;T0
2om5D;T01Ol0003oFfc;oe]/bomKK<_o000001SoSh?200?o0000oj^B^on[T[/01?l0000CojfKaP03
o`000?nmYL7o_JG100ko_JG10ol00004okfU`@03o`000?o:[[kobZjn017obZjn00?o0000om>f_?oC
][`02_oC][`2o`0000Cof;6a00?o0000omni/?oO^K003ooO^K000ol0003ok/:Uonk2Y@03onk2Y@03
o`000?o^`ZGok/:U00Kok/:U00Co0000oo:lU?ob_9Co00000ooofH`00ol0003onlQPoo_8H002oo_8
H003o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00004oc8b<_l0003o<S8bonk^
kPcooooo1?l00005ooooo`03o`000?oooooooooo04?ooooo0_l0000<odE@^@03o`000?mKK<_oFfc;
00;oFfc;00?o0000ohn3`_n?Pl805On?Pl83o`0001Oo[I_600?o0000okfU`OnmYL402onmYL43o`00
00Oo_JG100?o0000olZ^__o:[[h04Oo:[[h00ol0003odkJlom>f_00<om>f_0?o000000?of;6ao`00
0?oO^K004?oO^K000ol0003ok/:Uonk2Y@04onk2Y@03o`000?o^`ZGok/:U00Kok/:U0_l00005oooI
S004o`000?okb63onlQPo`0002gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooo
ooooool0A?ooool00ol008?o0000odE@^@09odE@^@03o`000?mKK<_oFfc;00?oFfc;00?o0000ohn3
`_n?Pl804on?Pl82o`000003oiFAcOl0003o[I_601Oo[I_600?o0000okfU`OnmYL402?nmYL43o`00
00Wo_JG100?o0000olZ^__o:[[h04Oo:[[h00ol0003odkJlom>f_00@om>f_0;o00004?oO^K000ol0
003oj<Ndo`000006onk2Y@03o`000?o^`ZGok/:U00Kok/:U00?o0000oooIS?oofH`00ooofH`01?l0
003onlQPoo_8H?l0000]ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo
04Cooooo00?o0023o`000?m5D;T02?m5D;T00ol0003oFfc;oe]/b`05oe]/b`03o`000?n?Pl;oSh?2
013oSh?20_l00004oiFAc@03o`000?n]VlKo[I_601Go[I_600?o0000okfU`OnmYL401?nmYL44o`00
00co_JG100?o0000olZ^__o:[[h04Oo:[[h00ol0003odkJlom>f_00@om>f_003o`000?oJ_Kco0000
00oogkV`00Co0000onS7]?oXakCo00001_o^`ZD00ol0003ok/:Uonk2Y@05onk2Y@03o`000?oofHco
omV<00?oomV<00Co0000oo_8H?okb63o0000;Oooool00ol0003oooooooooo`0;ooooo`006Oooool0
0ol0003oooooooooo`14ooooo`03o`000?l008?o000000OoAE2i00?o0000oe]/bomKK</01omKK</0
0ol0003oSh?2ohn3`P0>ohn3`P03o`000?nETLgoUI7=00CoUI7=00?o0000ojfKa_n]VlH05_n]VlH0
0ol0003o_JG1okfU`@03o`00013o_JG100?o0000olZ^__o:[[h04Oo:[[h00ol0003odkJlom>f_00?
om>f_005o`000?oJ_Kcof[flomZm_?l000003OoO^K000ol0003oj<NdonS7]002onS7]003o`000?o^
`ZGok/:U00Cok/:U00?o0000onk2YOo^`ZD00oo^`ZD2o`0000GoomV<00Co0000oo_8H?okb63o0000
;Oooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`16ooooo`;o002300?o
0000odE@^Om5D;T01?m5D;T00ol0003oFfc;oe]/b`07oe]/b`03o`000?n?Pl;oSh?200coSh?20_l0
0008oiFAc@03o`000?n]VlKo[I_601Go[I_60ol0000CokfU`@03o`000?o:[[kobZjn013obZjn00?o
0000om>f_?oC][`04?oC][`00ol0003of[flomZm_002omZm_0;o00002ooO^K000ol0003oj<NdonS7
]003onS7]003o`000?o^`ZGok/:U00Cok/:U00?o0000onk2YOo^`ZD00_o^`ZD00ol0003on^2Zo`00
0005oooIS003o`000?okb63o000002gooooo00?o0000ooooooooool02oooool001Sooooo00?o0000
ooooooooool0A_ooool00ol0003o0023o`000005odE@^@03o`000?mKK<_oFfc;00WoFfc;00?o0000
ohn3`_n?Pl802On?Pl82o`0000[oUI7=00?o0000ojfKa_n]VlH04_n]VlH4o`0001Go_JG100?o0000
olZ^__o:[[h04?o:[[h00ol0003odkJlom>f_00?om>f_003o`000?oJ_Kcof[fl00Gof[fl00?o0000
omni/?oO^K001ooO^K000ol0003oj<NdonS7]004onS7]003o`000?o^`ZGok/:U00Cok/:U00Go0000
onk2YOo^`ZGok/:Uo`000002oo[PZP03o`000?oofHcoomV<00?oomV<00?o0000oo_8H?l00000;_oo
ool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`16ooooo`04o`000?l008?o
0023o`0000?oAE2i00?o0000oe]/bomKK</02omKK</00ol0003oSh?2ohn3`P06ohn3`P;o00003OnE
TLd00ol0003o[I_6ojfKaP0=ojfKaPCo00000on]VlH00ol0003o_JG1okfU`@0CokfU`@03o`000?o:
[[kobZjn013obZjn00?o0000om>f_?oC][`03ooC][`00ol0003of[flomZm_006omZm_003o`000?oO
^K3ogkV`00KogkV`00?o0000onS7]?oXak@01OoXak@00ol0003ok/:Uonk2Y@04onk2Y@04o`000?o^
`ZGok/:Uo`0000;on^2Z00?o0000oooIS?oofH`00ooofH`2o`0002oooooo00?o0000ooooooooool0
2_ooool001Sooooo0_l00018ooooo`03o`000?l008?o000000?oAE2i00?o0000oe]/bomKK</03?mK
K</00ol0003oSh?2ohn3`P03ohn3`P;o00003onETLd00ol0003o[I_6ojfKaP0:ojfKaP?o00001on]
VlH00ol0003o_JG1okfU`@0CokfU`@03o`000?o:[[kobZjn013obZjn00?o0000om>f_?oC][`03ooC
][`00ol0003of[flomZm_007omZm_003o`000?oO^K3ogkV`00CogkV`00?o0000onS7]?oXak@01ooX
ak@00ol0003ok/:Uonk2Y@04onk2Y@;o00000oojh:X00ol0003oomV<oooIS004oooIS003o`000?oo
oooooooo02gooooo00?o0000ooooooooool02_ooool001Sooooo00?o0000ooooooooool0Aoooool0
1_l0003o0023o`00Pol0003oAE2io`0000ooFfc;00?o0000ohn3`_n?Pl800_n?Pl800ol0003oUI7=
oiFAc@0@oiFAc@03o`000?n]VlKo[I_600Ko[I_60ol0000;ojfKaP03o`000?nmYL7o_JG100go_JG1
3ol00008olZ^_P03o`000?oC][codkJl00oodkJl00?o0000omZm_?oJ_K`02OoJ_K`2o`0000CogkV`
00?o0000onS7]?oXak@02?oXak@00ol0003ok/:Uonk2Y@04onk2Y@05o`000?ojh:[on^2Zoo[PZ_l0
00001_oofH`00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo000Hooooo`03o`00
0?oooooooooo04Oooooo00Go0000o`00Pol008?o0023o`00000Aoe]/b`04o`000?n?Pl;o0000o`00
01CoUI7=00?o0000ojfKa_n]VlH00_n]VlH3o`0000ko[I_600?o0000okfU`OnmYL400_nmYL4;o`00
00Go^jg;00?o0000olJdb?o6]<P01oo6]<P:o`00013odkJl00?o0000omZm_?oJ_K`02ooJ_K`01?l0
003ogkV`omni/?l0000;onS7]003o`000?o^`ZGok/:U00?ok/:U00?o0000oo[PZ_l000000oojh:X0
0ol0003oomV<oooIS003oooIS003o`000?oooooooooo02gooooo00?o0000ooooooooool02_ooool0
01Oooooo00?o0000ooooooooool0BOooool01?l0003o0023o`00Pol0000Boe]/b`03o`000?nETLgo
UI7=01CoUI7=1Ol0000?ojfKaPOo00004?nk[L/00ol0003oa[C8olJdb00?olJdb003o`000?o>^/Oo
000000;o00003?oC][`00ol0003of[flomZm_00=omZm_003o`000?oO^K3o000000coj<Nd00?o0000
onk2YOo^`ZD00_o^`ZD00ol0003on^2Zo`000003oo[PZP03o`000?oofHcoomV<00;oomV<00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`19oooo
o`03o`000?l008?o002300;o00004OmKK</00ol0003oUI7=oiFAc@0BoiFAc@Co00003_n]VlH4o`00
00;o[JG?00?o0000ok^]bonk[L/04_nk[L/00ol0003oa[C8olJdb00>olJdb003o`000?o>^/Ooc[[7
00?oc[[70_l0000:om>f_003o`000?oJ_Kcof[fl00kof[fl00?o0000onS7]?oXak@03?oXak@01?l0
003ok/:Uonk2YOl00003oo[PZP04o`000?ojh:[on^2Zo`0000CoomV<00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1:ooooo`05o`000?l008?o
0023o`0^]ol000003omKK</00ol0003oK8;Go`00000@oiFAc@?o00000onETLd00ol0003o[I_6ojfK
aP08ojfKaPCo00001_n]YLl00ol0003o^jg;ok^]b`0Bok^]b`03o`000?o6]<Soa[C800koa[C800?o
0000oljjaoo>^/L01Oo>^/L3o`0000KodkJl00?o0000omZm_?oJ_K`03ooJ_K`00ol0003oj<NdonS7
]00=onS7]003o`000?o^`ZGo000000Con^2Z00?o0000oo[PZ_l000001?oofH`00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo04[ooooo00Ko0000
o`00Pol008?o0000o`0^]ol0000=oe]/b`05o`000?m/P]OoK8;Gofb2eol000003?nETLd3o`0000Oo
UI7=00?o0000ojfKa_n]VlH01?n]VlH3o`0000_o[JG?00?o0000ok^]bonk[L/04Onk[L/00ol0003o
a[C8olJdb00>olJdb003o`000?o>^/Ooc[[700Soc[[70_l00004om>f_003o`000?oJ_Kcof[fl00ko
f[fl00?o0000on7;`_l000003ooXak@00ol0003on^2Zoo[PZP04oo[PZP03o`000?ojh:[o000000;o
omV<00?o0000ooooooooool0<?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003ooooo
ooooo`1;ooooo`03o`000?l008?o000000;o02jg00?o0000oe]/bomKK</02OmKK</00ol0003oK8;G
ofb2e`03ofb2e`03o`000?nETLgoUI7=00GoUI7=1?l0000:oiFAc@03o`000?n]VlKo[I_600Co0000
3_n]YLl00ol0003o^jg;ok^]b`0Aok^]b`03o`000?o6]<Soa[C800goa[C800?o0000oljjaoo>^/L0
2oo>^/L3o`000003om>f_?l0003of[fl00kof[fl00Go0000on7;`_oQbl;ohL_2o`00000>onS7]003
o`000?ojh:[on^2Z00Gon^2Z0_l00002oooIS003o`000?oooooooooo033ooooo00?o0000oooooooo
ool02Oooool001Oooooo00?o0000ooooooooool0Boooool00ol0003o0023o`000003o`0^]`03o`00
0?mKK<_oFfc;00OoFfc;00?o0000ofb2eom/P]L01Om/P]L01?l0003oUI7=oiFAcOnETLd3o`0000ko
UI7=0ol0000BojfUc`03o`000?nk[L_o^jg;017o^jg;00?o0000olJdb?o6]<P03Oo6]<P00ol0003o
c[[7oljja`0>oljja`;o00003ooJ_K`01Ol0003ohL_2on7;`_oQbl;o000000goj<Nd0_l00007oo[P
ZP;o00000_oofH`00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Gooooo`;o
0000COooool00ol0003o0023o`000002o`0^]`03o`000?mKK<_oFfc;00KoFfc;00?o0000ofb2eom/
P]L01om/P]L3o`0000ooUI7=0_l000000onIWMOo0000ojfUc`0CojfUc`03o`000?nk[L_o^jg;00oo
^jg;00?o0000olJdb?o6]<P03_o6]<P00ol0003oc[[7oljja`0>oljja`03o`000?oC`/So000000go
f[fl00?o0000on7;`_oQbl800ooQbl800ol0003oj<NdonS7]009onS7]003o`000?oah[ko000000So
n^2Z00?o0000oooIS?l00000<oooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003ooooo
ooooo`1>ooooo`03o`00Pol0003o02jg00;o02jg00?o0000oe]/bomKK</01OmKK</00ol0003oK8;G
ofb2e`04ofb2e`?o000000?oK8;Go`000?nETLd03OnETLd2o`0000CoVIgG00?o0000ojfUcon]YLl0
4On]YLl00ol0003o^jg;ok^]b`0?ok^]b`03o`000?o6]<Soa[C800goa[C800?o0000oljjaoo>^/L0
3_o>^/L01Ol0003odl;8om?2b?oC`/So000000_of[fl00?o0000on7;`_oQbl801OoQbl800ol0003o
j<NdonS7]007onS7]005o`000?oah[kolN:noo7R__l000001oojh:X3o`0003?ooooo00?o0000oooo
ooooool02Oooool001Kooooo00?o0000ooooooooool0C_ooool00ol008?o0000o`0^]`03o`0^]`03
o`000?mKK<_oFfc;00?oFfc;00Co0000ofb2eom/P]OoK8;G1?l00004ofb2e`03o`000?nETLgoUI7=
00[oUI7=0_l00007oiVMe`03o`000?n]YLoo[JG?013o[JG?00?o0000ok^]bonk[L/03onk[L/00ol0
003oa[C8olJdb00=olJdb003o`000?o>^/Ooc[[700goc[[700?o0000om?2b?oC`/P00ooC`/P2o`00
00Wof[fl00?o0000on7;`_oQbl801_oQbl800ol0003oj<NdonS7]006onS7]005o`000?oah[kolN:n
oo7R__l000002?ojh:X2o`0003?ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooo
ooooool0Coooool00ol0003o02jgo`0^]`03o`0^]`06o`000?mKK<_oFfc;oe]/bol0003oK8;G0ol0
0009ofb2e`03o`000?nETLgoUI7=00SoUI7=00?o0000oiVMeonIWML01onIWML00ol0003o[JG?ojfU
c`0@ojfUc`03o`000?nk[L_o^jg;00oo^jg;00?o0000olJdb?o6]<P03Oo6]<P00ol0003oc[[7oljj
a`0=oljja`03o`000?oC`/Sodl;800Godl;800?o0000omZm_?oJ_K`01OoJ_K`00ol0003ohL_2on7;
`P07on7;`P03o`000?oXakCoj<Nd00Goj<Nd00?o0000oo7R__oah[h00_oah[h00ol0003on^2Zoo[P
ZP06oo[PZP03o`000?oooooo000003;ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000
ooooooooool0Coooool00ol008?o0000o`0^]`04o`0^]`03o`000?mKK<_o000000;o00003Om/P]L0
0ol0003oUI7=oiFAc@05oiFAc@;o00002onIWML00ol0003o[JG?ojfUc`0@ojfUc`03o`000?nk[L_o
^jg;00ko^jg;00?o0000olJdb?o6]<P03?o6]<P00ol0003oc[[7oljja`0=oljja`03o`000?oC`/So
dl;800Oodl;80_l00004omZm_003o`000?oQbl;ohL_200WohL_200?o0000onS7]?oXak@00ooXak@0
0ol0003olN:noo7R_P03oo7R_P03o`000?ojh:[on^2Z00Kon^2Z00Co0000oooooooooooo0000<_oo
ool00ol0003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1@ooooo`03o`000?l0;[Oo
02jg00;o02jg1?l0000@ofb2e`03o`000?nETLgoUI7=00;oUI7=0_l0000>oiVMe`03o`000?n]YLoo
[JG?00oo[JG?00?o0000ok^]bonk[L/03_nk[L/00ol0003oa[C8olJdb00<olJdb003o`000?o>^/Oo
c[[700goc[[700?o0000om?2b?oC`/P02OoC`/P01Ol0003of[flomZm_?oJ_Kco000000cohL_200?o
0000onS7]?oXak@00_oXak@00ol0003olN:noo7R_P03oo7R_P03o`000?ojh:[on^2Z00Gon^2Z00Go
0000ooooooooooooooooo`00000booooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oo
oooooooo053ooooo1Ol00002o`0^]`;o65oF00?o0000ofb2eom/P]L03_m/P]L01?l0003oUI7=o`00
0?l0000@oiVMe`03o`000?n]YLoo[JG?00oo[JG?00?o0000ok^]bonk[L/03_nk[L/00ol0003oa[C8
olJdb00<olJdb003o`000?o>^/Ooc[[700coc[[700?o0000om?2b?oC`/P02ooC`/P00ol0003of[fl
o`00000=on7;`P05o`000?oXakCoj<NdonS7]?l000001ooah[h00ol0003on^2Zoo[PZP03oo[PZP;o
00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`00
0?oooooooooo04oooooo1?l00005o`0^]`04o`000?lHGmKo65oFo`00013oK8;G0_l0000BoiVMe`03
o`000?n]YLoo[JG?00oo[JG?00?o0000ok^]bonk[L/01Onk[L/@o`0000Koa[C800?o0000oljjaoo>
^/L03?o>^/L00ol0003odl;8om?2b00=om?2b003o`000?oQbl;ohL_200gohL_200?o0000onS7]?l0
00002?oah[h00ol0003on^2Zoo[PZP03oo[PZP;o00001Oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00Sooooo000Eooooo`?o0000C?ooool3o`0000Cooooo00?o0000o`0^]ol0;[L0
0ol0;[L01?l0003o65oFoaQOe_l0000?ofb2e`;oNYCQ00?o0000oiVMeonIWML03onIWML00ol0003o
[JG?ojfUc`0>ojfUc`Wo00002?nh]=D00ol0003o`K[Col6jd`05ol6jd`Wo00003?o>^/L00ol0003o
dl;8om?2b00=om?2b003o`000?oQbl;ohL_200kohL_200?o0000oo7R__oah[h01ooah[h00ol0003o
n^2Zoo[PZP02oo[PZP;o00001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo04Wooooo0ol00008ooooo`03o`000?l0;[Oo02jg00;o02jg
00Go0000oaQOe_lHGmKo65oFo`00000=ofb2e`05o`000?mjU>7oNYCQogZDhOl000004OnIWML00ol0
003o[JG?ojfUc`0:ojfUc`?o000000?o[JkIo`000?nh]=D03_nh]=D00ol0003o`K[Col6jd`0;ol6j
d`03o`000?o6_m?oa[oC00?o00002?o>^/L00ol0003odl;8om?2b00=om?2b003o`000?oHcLko0000
00kohL_20_l00009oo7R_P07o`000?ojh:[on^2Zoo[PZ_l0003ocnf=o`000008ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0AOooool4
o`0000cooooo00Go0000o`0^]ol0;[Oo02jgo`000004oaQOeP;o00002_m/P]L00ol0003oNYCQogZD
h@03ogZDh@03o`000?nIWMOoVIgG00ooVIgG00?o0000ojfUcon]YLl01_n]YLl3o`0000Co[JkI00?o
0000okRdeOnh]=D03Onh]=D00ol0003o`K[Col6jd`0:ol6jd`03o`000?o6_m?oa[oC00Coa[oC0ol0
0005oljja`03o`000?oC`/Sodl;800codl;800Go0000omS=c_oHcLkof<g>o`00000<on7;`P03o`00
0?oVhLko000000WolN:n00Co0000oo[PZ_ojh:[on^2Z0_l00009ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0@_ooool3o`00017ooooo
00Co0000o`0^]ol0;[Oo00001_lHGmH00ol0003oK8;Gofb2e`06ofb2e`03o`000?mjU>7oNYCQ00Go
NYCQ00?o0000oiVMeonIWML03_nIWML00ol0003o[JG?ojfUc`03ojfUc`?o00002?n][]T00ol0003o
^;CEokRde@0;okRde@03o`000?o1^]?o`K[C00_o`K[C00?o0000olJodoo6_m<01oo6_m<3o`000003
oljjaol0003odl;800godl;800?o0000omS=c_oHcLh00_oHcLh00ol0003ohL_2on7;`P09on7;`P04
o`000?oVhLkoi^7>o`0000WolN:n00Ko0000oo[PZ_ojh:[o0000olo]SOl0000:ooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool01oooool001Gooooo00?o0000ooooooooool0?oooool3
o`0001Gooooo00?o0000o`0^]ol000001olHGmH00ol0003oK8;Gofb2e`04ofb2e`03o`000?mjU>7o
NYCQ00OoNYCQ00?o0000oiVMeonIWML03_nIWML00ol0003o[JG?o`000002o`0000_o[JkI00?o0000
okRdeOnh]=D02onh]=D00ol0003o`K[Col6jd`0:ol6jd`03o`000?o6_m?oa[oC00_oa[oC0_l0000=
om?2b003o`000?oHcLkof<g>00Cof<g>00?o0000on7;`_oQbl801ooQbl801Ol0003oi^7>onKQc_oV
hLko000000[olN:n00Co0000oo[PZ_l0003o00003?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03gooooo0ol0000Iooooo`03o`000?l0
;[Oo000000Oo65oF00?o0000ofb2eom/P]L00om/P]L00ol0003oNYCQogZDh@08ogZDh@03o`000?nI
WMOoVIgG00goVIgG0_l0000>ojf^f@03o`000?nh]=Go^;CE00_o^;CE00?o0000ol6jdoo1^]<02_o1
^]<00ol0003oa[oColJod`0;olJod`03o`000?o;aMCo000000_odl;800?o0000omS=c_oHcLh01_oH
cLh00ol0003ohL_2on7;`P05on7;`P03o`000?oVhLkoi^7>00?oi^7>00?o0000oo7R__oah[h01ooa
h[h2o`000003olo]SOl0003ooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0iooooo`Co00007Oooool00ol0;[Oo0000oaQOeP07
oaQOeP05o`000?m/P]OoK8;Gofb2eol000003?mjU>400ol0003oVIgGoiVMe`09oiVMe`?o000000?o
WJWOo`000?n][]T03_n][]T00ol0003o^;CEokRde@0:okRde@03o`000?o1^]?o`K[C00Wo`K[C00?o
0000olJodoo6_m<02oo6_m<01?l0003oblGDol_5e?o;aM@2o`0000Sodl;800?o0000omS=c_oHcLh0
1ooHcLh00ol0003ohL_2on7;`P04on7;`P03o`000?oVhLkoi^7>00Coi^7>00?o0000oo7R__oah[h0
1ooah[h01?l0003ocnf=olo]SOl0000>ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01oooool001Cooooo00?o0000ooooooooool0=_ooool3o`0002;ooooo0_l00008oaQOeP03o`00
0?m/P]Oo000000koNYCQ00?o0000oiVMeonIWML01_nIWML2o`0000GoWJWO00?o0000ojf^fOn][]T0
3?n][]T00ol0003o^;CEokRde@0:okRde@03o`000?o1^]?o`K[C00Wo`K[C00?o0000olJodoo6_m<0
2_o6_m<00ol0003oblGDol_5e004ol_5e003o`000?oC`/Sodl;800Codl;800?o0000omS=c_oHcLh0
2OoHcLh00ol0003ohL_2on7;`P02on7;`P03o`000?oVhLkoi^7>00Goi^7>00?o0000oo7R__oah[h0
1_oah[h2o`000003olo]SOl0003ooooo00kooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`07ooooo`005?ooool3o`0003?ooooo0ol0000Uooooo`03o`000?l04i7o000000So65oF0_l0
000?ogZDh@03o`000?nIWMOoVIgG00?oVIgG0_l00008oifYg`03o`000?n][]Wo[JkI00_o[JkI00?o
0000okRdeOnh]=D02_nh]=D00ol0003o`K[Col6jd`09ol6jd`03o`000?o6_m?oa[oC00Woa[oC00?o
0000ol_5e?o;aM@01_o;aM@2o`0000?odl;800?o0000omS=c_oHcLh02_oHcLh01Ol0003ohL_2on7;
`_oQbl;o000000Soi^7>00?o0000oo7R__oah[h01Ooah[h2o`0000;ocnf=00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oo
oooooooo033ooooo0ol0000Yooooo`03o`000?l04i7o000000Oo65oF0_m3PnL00ol0003oNYCQogZD
h@0=ogZDh@03o`000?nIWMOo000000;o00002onMZMl00ol0003o[JkIojf^f@0;ojf^f@03o`000?nh
]=Go^;CE00Wo^;CE00?o0000ol6jdoo1^]<02?o1^]<00ol0003oa[oColJod`0:olJod`03o`000?o;
aMCoblGD00SoblGD00?o0000om?2b?l000003_oHcLh00ol0003ohL_2o`000009onKQcP03o`000?oa
h[kolN:n00ColN:n00Go0000omgn`Ol0003ocnf=o`00000Booooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01oooool000[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo02cooooo1?l0000]ooooo`03o`000?l04i7o000000Ko65oF00?o0000od>3iom3PnL00_l0
000>ogZDh@;o00003OnMZMl00ol0003o[JkIojf^f@0;ojf^f@03o`000?nh]=Go^;CE00So^;CE00?o
0000ol6jdoo1^]<02Oo1^]<00ol0003oa[oColJod`09olJod`03o`000?o;aMCoblGD00[oblGD00?o
0000omS=c_oHcLh03_oHcLh00ol0003oi^7>onKQcP08onKQcP03o`000?oah[kolN:n00?olN:n00?o
0000omgn`Ol000000_o?kHd00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Z
ooooo`?o0000<_ooool01?l0003o01>Ao`000?l00004oaQOeP03o`000?m3PnOo@h?W00;o@h?W00?o
0000ogZDhOmjU>402omjU>400ol0003oQZCXo`00000=oifYg`03o`000?n][]Wo[JkI00[o[JkI00?o
0000okRdeOnh]=D02?nh]=D00ol0003o`K[Col6jd`08ol6jd`03o`000?o6_m?oa[oC00Woa[oC00?o
0000ol_5e?o;aM@02_o;aM@00oo=cMWo0000omS=cP0=omS=cP03o`000?oJgMWo000000[oi^7>00?o
0000oo7R__oah[h00_oah[h01?l0003ogOk1omgn`Ol00002olo]S@03o`000?oooooooooo01;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Oooooo0ol0000fooooo`04o`000?l04i7o01>Ao`0000?o65oF
00?o0000od>3iom3PnL00om3PnL2o`0000[oNYCQ00Go0000ohJTj?n6Y>SoQZCXo`00000=oifYg`03
o`000?n][]Wo[JkI00[o[JkI00?o0000okRdeOnh]=D00_nh]=D;o`0000Go`K[C00?o0000olJodoo6
_m<02?o6_m<00ol0003oblGDol_5e009ol_5e005o`000?o=cMWocLgIolg=fOl000003?oHcLh01?l0
003of]gIom[MfOl0000;onKQcP04o`000?oah[kolN:no`0000;ogOk100Co0000olo]SOo?kHgo0000
5_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09?ooool3o`0003[ooooo00Co0000o`0CTOl04i7o0000
0_lHGmH00ol0003o@h?Wod>3i`05od>3i`03o`000?mjU>7oNYCQ00KoNYCQ00?o0000ohJTj?n6Y>P0
0on6Y>P2o`0000_oWJWO00?o0000ojf^fOn][]T02?n][]T7o`0000Go/kcP00?o0000okVogoni_ml0
0oni_ml7o`0000Woa[oC00?o0000ol_5e?o;aM@02?o;aM@00ol0003ocLgIolg=f@02olg=f@03o`00
0?oHcLkof<g>00Sof<g>0_l00003om[Mf@03o`000?oVhLkoi^7>00Woi^7>00?o0000oo7R__l00000
0ooMo/401?l0003ocnf=olo]SOl0000Fooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Pooooo`Co0000
?_ooool00ol0003o01>Ao`0CT@02oaQOeP03o`000?m3PnOo@h?W00Ko@h?W00?o0000ogZDhOmjU>40
1?mjU>400ol0003oQZCXohJTj006ohJTj003o`000?nMZMooWJWO00WoWJWO00?o0000ojf^fOn][]T0
1?n][]T3o`0000;oZkSS00?o0000ok>lh?nc_>001onc_>000ol0003o^KoOokVog`07okVog`03o`00
0?nl`moo_<?O00?o00001Oo6_m<00ol0003oblGDol_5e008ol_5e003o`000?o=cMWocLgI00CocLgI
00?o0000omS=c_oHcLh01_oHcLh00ol0003of]gIom[Mf@03om[Mf@03o`000?oVhLkoi^7>00Woi^7>
0_l00003omgn`@04o`000?o?kHgocnf=o`0001Sooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo
0ol00013ooooo`05o`000?l04i7o01>AoaQOe_l000002Om3PnL2o`0000?oNYCQ00?o0000ohJTj?n6
Y>P02?n6Y>P00ol0003oWJWOoifYg`09oifYg`03o`000?n][]Wo[JkI00?o00001_n[^><00ol0003o
/kcPok>lh006ok>lh003o`000?ni_moo^KoO00Ko^KoO00?o0000okc3gonl`ml01?nl`ml3o`000003
olJodol0003oblGD00SoblGD0_l00008olg=f@03o`000?oHcLkof<g>00Cof<g>00?o0000om[MfOoJ
gMT01?oJgMT00ol0003oi^7>onKQcP08onKQcP;o00001?oMo/400ol0003ocnf=o`00000Jooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Jooooo`?o0000Aoooool2o`000003o`0CTOl0003o000000[o@h?W
00?o0000ogZDhOl000003?n6Y>P00ol0003oWJWOoifYg`08oifYg`?o00002On[^><00ol0003o/kcP
ok>lh006ok>lh003o`000?ni_moo^KoO00Ko^KoO00?o0000okc3gonl`ml01onl`ml00ol0003oblGD
ol_5e007ol_5e003o`000?o=cMWocLgI00SocLgI00?o0000omS=c_oHcLh00_oHcLh2o`0000Oof]gI
00?o0000onKQc_oVhLh01ooVhLh00ol0003of__Lo`000004omgn`@;o00007?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0
000Hooooo`?o0000C?ooool2o`000003o`1Nd_l0003o000000Wo@h?W0_l0000=ohJTj0;o00001_nM
ZMl2o`0000;oWkCW00?o0000oj^hhon[^><01on[^><00ol0003o/kcPok>lh006ok>lh003o`000?ni
_moo^KoO00Go^KoO00?o0000okc3gonl`ml01onl`ml3oko7h@03o`000?o;aMCoblGD00CoblGD00?o
0000olg=fOo=cMT02_o=cMT01?l0003of<g>omS=c_l0000:om[Mf@03o`000?oVhLkoi^7>00Coi^7>
0_l000000ooJnmco0000omgn`@03omgn`@;o00007_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Kooooo000Booooo`03o`000?oooooooooo01Cooooo1?l0001@ooooo`;o00000_l0
G]800ol0003o@h?Wod>3i`06od>3i`04o`000?mUW_3o0000o`0000goQZCX00?o0000oifYgonMZMl0
0_nMZMl00ol0003oWkCWoindi`03oindi`03o`000?n[^>?oZkSS00OoZkSS00?o0000ok>lh?nc_>00
1Onc_>000ol0003o^KoOokVog`05okVog`03o`000?nl`moo_<?O00Go_<?O00?o0000oko7hOnoan40
0onoan42o`0000?oblGD00?o0000olg=fOo=cMT02oo=cMT00ol0003of<g>o`00000;om[Mf@03o`00
0?oVhLkoi^7>00;oi^7>0_l00003om[kg003o`000?oMo/7ogOk100;ogOk10_l0000Nooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool04Ooo
ool3o`0005Gooooo0_l00002o`1NdP;o00001_m3PnL01?l0003oIIk`ofFNl?mUW_02o`0000coQZCX
00Co0000oifYgol0003o00001onO]>L00ol0003oZkSSoj^hh`06oj^hh`03o`000?nc_>3o/kcP00Co
/kcP00?o0000okVogoni_ml01Oni_ml00ol0003o_<?Ookc3g`05okc3g`03o`000?noan7o_lOQ00Ko
_lOQ00?o0000ol_5e?l000003oo=cMT00ol0003of]gIom[Mf@0:om[Mf@05o`000?oVhLkoi^7>onKQ
c_l000001?oJnm`00ol0003ogOk1omgn`@02omgn`@;o00008?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0001Jooooo`04
o`000?l0G];o05kBo`1NdP;o00001?m3PnL00ol0003oIIk`ofFNl003ofFNl0;o00002_n6Y>P3o`00
00WoWkCW00?o0000oj^hhon[^><01On[^><00ol0003o/kcPok>lh004ok>lh003o`000?ni_moo^KoO
00Co^KoO00?o0000okc3gonl`ml01Onl`ml00ol0003o_lOQoko7h@08oko7h@03o`000?o=cMWocLgI
00_ocLgI0_l000000oo<f>;o0000om[Mf@0;om[Mf@04o`000?oVhLko0000o`0000Gof__L00?o0000
omgn`OoMo/400_oMo/400ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01Oooool001;ooooo00?o0000ooooooooool02oooool3o`0005kooooo00?o0000o`1N
d_l0G]800_l0G]801?l0003o@h?Wod>3iol00008ofFNl0;o00001on6Y>P01?l0003oTK;^oi6bk_nA
/^h2o`0000SoWkCW00?o0000oj^hhon[^><01On[^><00ol0003o/kcPok>lh003ok>lh003o`000?ni
_moo^KoO00Co^KoO00?o0000okc3gonl`ml01?nl`ml00ol0003o_lOQoko7h@08oko7h@03oko<i?l0
003ocLgI00[ocLgI0_l00003olcHhP03o`000?oJgMWof]gI00[of]gI0_l00006om[kg004o`000?oM
o/7ogOk1omgn`@;o00009?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo
000Booooo`03o`000?oooooooooo00Oooooo1?l0001Rooooo`03o`000?l0G];o05kB00;o05kB00?o
0000od>3iol000002_mUW_02o`0000CoQZCX00?o0000oi6bk_nA/^h01?nA/^h00ol0003oWkCWoind
i`06oindi`03o`000?n[^>?oZkSS00CoZkSS00?o0000ok>lh?nc_>000onc_>000ol0003o^KoOokVo
g`03okVog`03o`000?nl`moo_<?O00Co_<?O00?o0000oko7hOnoan401_noan42o`0000?o_lcT00?o
0000olg=fOo=cMT01_o=cMT2o`0000Goc=SR00?o0000om[MfOoJgMT02_oJgMT00ol0003of__Lom[k
g004om[kg005o`000?oMo/7ogOk1omgn`Ol000009oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Cooooo0ol0001Wooooo`;o00001?l0
G]82o`0000_oIIk`0_l000000on6Y>So0000oi6bkP07oi6bkP;o00001onO]>L00ol0003oZkSSoj^h
h`03oj^hh`03o`000?nc_>3o/kcP00?o/kcP00?o0000okVogoni_ml00oni_ml00ol0003o_<?Ookc3
g`03okc3g`03o`000?noan7o_lOQ00Go_lOQ0_l00005oko<i003o`000?o=cMWocLgI00CocLgI0_l0
0007olcHhP03o`000?oJgMWof]gI00Oof]gI0_l000000oo?l>Wo0000om[kg005om[kg004o`000?oM
o/7ogOk1o`0002Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`004Ooo
ool00ol0003oooooooooo`02ooooo`?o0000K?ooool2o`0000;o05kB00?o0000ocVClOl000000_l0
000:ofFNl0?o00002OnA/^h2o`0000KoWkCW00Co0000oj^hhon[^>?oZkSS3_l00004okc3g`03o`00
0?noan7o_lOQ00Go_lOQ00?o0000oko<i?noc>@01_noc>@01?l0003ocLgIolg=fOo=cMT2o`0000Wo
c=SR00?o0000om[MfOoJgMT01OoJgMT2o`0000;oco3Y00?o0000om[kg?oJnm`01?oJnm`01?l0003o
gOk1o`000?l0000Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0017o
oooo00?o0000ooooool000000_l0001`ooooo`05o`0cWOl0003o05kBo`1Nd_l000000oliTo42o`00
00SoIIk`00?o0000ognam?mo/O@00ol00008oi6bkP03o`000?nO]>OoWkCW00?oWkCW1?l00002ojK2
k@03o`000?nZa>coZ/C/00;oZ/C/00?o0000ojc6k?n/a^`00_n/a^`01_l0003o[LK]o`000?l0003o
_<?Oo`0000Ko_lOQ0_l00009oko<i004o`000?o=cMWo0000o`0000_oc=SR00?o0000om[MfOoJgMT0
0_oJgMT3o`0000Coco3Y00?o0000om[kg?oJnm`01?oJnm`2o`0002gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0007Gooooo0_l000000ol0G];o0000ocVC
l@03ocVCl@;o00001_mUW_000ol0003oOk7dognam003ognam0?o00001_nA/^h2o`000003oindiol0
003o000000?oXL3_00Go0000ojK2kOnV`^goY/;]o`000003oj[4k005o`000?n/a^co[<K/ojc6k?l0
00000on]a^d3o`0000Co_lOQ0_l0000<oko<i003o`000?o<f>;oc=SR00_oc=SR00?o0000om[MfOoJ
gMT00_l00006olo`j@03o`000?oJnmcof__L00Cof__L0_l0000_ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01?ooool001?ooooo00?o0000ooooooooool0M?ooool2o`0000Ko>I?a
0ol00002ofFNl003o`000?mo/OCoOk7d00OoOk7d0ol00005oi6bkP;o00001OnQ`>l01?l0003oY/;]
ojK2kOl00003oj[4k004o`000?n/a^co[<K/o`0000?o[LK]00Co0000ojg7kOn]ango[LO]0_l00000
0onoan7o0000oko<i009oko<i0;o00000_nmd^T00ol0003oc=SRolcHhP0;olcHhP?o00002?o?l>T0
0ol0003of__Lom[kg004om[kg003o`000?oooooooooo02oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`005?ooool2o`0007Gooooo00?o03>Mo`000?liTo401oliTo400ol0
003oIIk`o`00000<ognam0?o000000CoTK;^o`000?nK`?;oVl3b0_l00004oj70k`04o`000?nV`^go
Y/;]o`0000;oZ/C/00Go0000ojc6k?n/a^co0000ojg6k@02o`0000Go[LO]0_l00006oko<i0?o0000
1_nmd^T00ol0003oc=SRolcHhP0;olcHhP03o`000?o?l>Woco3Y00Ooco3Y00?o0000om[kg?oJnm`0
0ooJnm`2o`0003?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005_oo
ool00ol0003oooooo`00001dooooo`?o00001oliTo44o`0000coOk7d0ol00003oi_0lP;o00000onQ
`>l01Ol0003oY/;]o`000?nZa>co000000;o[<K/00?o0000ojg6kOl000001?n]and3o`000004ojg8
kOl0003o_lcToko<i0Co00002Onmd^T00ol0003oc=SRolcHhP04olcHhPGo00000_o3i>l00ol0003o
co3Yolo`j@06olo`j@03o`000?oJnmcof__L00;of__L0_l0000eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool001Oooooo0_l0001fooooo`04oa66iOl0003o0000o`0000Co
>I?a00Co0000ofjanOm^/OWoK[7i1Ol00007ognam003o`000?nE`OGoUL7e00Co000000GoVl3bo`00
0?l0003o0000oj70k`02o`000006oj[4k?l0003o[<K/o`000?n]a^go00000_n]and3o`0000?o[LS]
1?l0000=okgBj@03o`000?o<f>;o000000Co00001_o3i>l00ol0003oco3Yolo`j@07olo`j@03o`00
0?oJnmcof__L00?o0000=oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo
000Hooooo`;o0000M_ooool00ol0003o4HKUoa66i@03o`0000;o>I?a00?o0000ofjanOm^/OT01Om^
/OT4o`0000;oOk7d00?o0000oiG1mOnE`OD01OnE`OD3o`000003oi_0l_l0003o000000?o000000?o
[<K/o`000?l000000ol000000on]b>go0000o`000003o`0000;o[<W_00?o0000okgBjOnmd^T03?nm
d^T2o`0000[o`nC_00?o0000olo`jOo?l>T01oo?l>T00ol0003of__Lo`000002o`0003[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_ooool00ol0003oooooooooo`1d
ooooo`?o00000_lAQ^D2o`000003ocVClOl0003oK[7i00[oK[7i2_l00002oiG1m@go00001on/bNl0
1?l0003o_M;YokgBjOnmd^T7o`0000Co]]Sa00?o0000ol?Tkoo3i>l02Oo3i>l00ol0003oco3Yolo`
j@07olo`j@;o000000?oRN_9o`000?ooool0>oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0LOooool01?l0003oooooooooool0
0004oa66i@Wo00001?m^/OT00ol0003oT/?goi;3m`06oi;3ma[o00002_nff?400ol0003o`nC_ol?T
k`09ol?Tk`03o`000?o?l>Woco3Y00Goco3Y0ol000000on9jlWo0000o`00000nooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00oooool001gooooo0_l0001booooo`04o`000?oooooo
ooooooooo`?o00001?lAQ^D00ol0003oHK;kof6bn`03of6bn`Co000000?oK[7io`000?l000001_l0
00000onAa?So0000o`000003o`000003oi75nOl0003o000000Ko00001onYc?800ol0003o]]SaokKH
l@0;okKHl@03o`000?o3i>oo`nC_00Wo`nC_00Co0000olo`jOo?l>Woco3Y1Ol00002ohW[b@03o`00
0?oooooooooo03kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007_oo
ool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00?ooooo00?o087Jo`000?l000000olA
Q^D00ol0003oHK;kof6bn`09of6bn`03o`000?nAa?SoTLCh00Co00000_nAa?T2o`000006oi75nOl0
003o0000oiK9nOl0003oW<ch0_l00002ojC=m@Co00000_nYc?800ol0003o]]SaokKHl@0;okKHl@03
o`000?o3i>oo`nC_00Wo`nC_1Ol00002oj?cl0;o000000?oRN_9o`000?l00000@_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003ooooo
ooooo`05ooooo`06o`000?l0PM[o0000o`000?lAQ^Go00001_mQ/_/3o`0000;oHK;k0_l00004oi74
n@;o00000_nAaOT00ol0003oT/Kio`000002oiK9n@03o`000?nLc?SoW<ch00;o00001?nTcOD9o`00
00Oo]]Sa00?o0000ol?Tkoo3i>l00_o3i>l8o`0000GoXo?`00Co0000ohW[bOn9jlWo0000AOooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?ooooo000Qooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool01oooool2o`000003o`21f_l0003o000000Go00001omL]?`2o`00
0003oi74nOl0003oTLGi00?oTLGi00Co0000oi;6nOnBa_Wo00000_nFbOT01?l0003oW<choic<n?nL
c?P2o`000003ojC=mOl0003oZ=_i00SoZ=_i3?l00004ojWYnP03o`000?nSlo3oXo?`00CoXo?`0_l0
0002ohW[b@03o`000?oooooooooo04Gooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`008_ooool3o`0006cooooo00?o0000ooooooooool02Oooool2o`0000;o087J0ol0000:
oebdo0?o00000_nAaOT01Ol0003oT/Kioi;6nOnBa_Wo000000?oU/Wi00?o0000oic<n?nLc?P01Ol0
000;ojSKn@;o00002OnYjOX2o`0000KoXo?`00?o0000ohW[bOn9jlT00_l00019ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0J_ooool0
0ol0003oooooooooo`0;ooooo`Co000000?o087Jo`000?l000000_mL]?`4o`0000GoGk[m1Ol00000
1?nBa_Wo0000oiK9nOnFbOT4o`0000GoT]On0ol00007ojSKn@03o`000?nYjO[oZNWj00SoZNWj00?o
0000oj?cl?nSlo001?nSlo05o`0004cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`009Oooool2o`0006[ooooo00?o0000ooooooooool03_ooool00ol0003o0HWIo`000003
o`0000WoGk[m00?o0000ofW2o_mY`_h00_mY`_h4o`0000CoNlgo00?o0000oi;Go_nBeoh01OnBeoh3
o`0000;oZ=_i0_l00009ojWYnP;o00001_nSlo03o`0004oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`02ooooo`009oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo
017ooooo0ol000000ol1RMWo0000o`000003o`0000;oGk[m00?o0000ofW2o_mY`_h01?mY`_h00ol0
003oNlgoog_=o`05og_=o`;o00001onBeoh8o`0000GoZNWj00Co0000oj?cl?nSlo3oXo?`1Ol0001C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool002Sooooo00?o0000oooo
ool00000I_ooool00ol0003oooooooooo`0Dooooo`?o00000ol1RMT2o`000003ofW2o_l0003oJL;n
00CoJL;n00?o0000og_=oomkcOl01omkcOl3oi;GoPCo00002?mkg?X;o`0005Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Co
oooo0_l0001Vooooo`03o`000?oooooooooo01Oooooo0ol00004oaRNh0Go000000?oJL;no`000?mk
cOl00omkcOl7o`0000WoNmcj2_l0001Looooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00_ooool0023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo01cooooo0ol00004oaRNh0Ko00001om3_^h3o`0000;oNmcj1?l000000om7b=Co0000
o`000002o`0006;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Ooo
ool6o`0000Gooooo00?o0000ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool08ooo
oolGo`0006Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`008?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo0000063ooooo00?o0000ooooooooool0XOooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo
00cooooo0_l0001Pooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`01ooooo`008?ooool00ol0003oooooooooo`0=ooooo`;o0000Goooool00ol0003o
ooooooooo`2Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0023ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`007_ooool00omEEEGoIVIVo`00
000Booooo`;o000000?oooooo`000?ooool0F?ooool00ol0003oooooooooo`2Uooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00Oooool003Gooooo0_l0001Iooooo`03o`000?oooooo
oooo0:Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00=_ooool2o`00
05Sooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo000hooooo`05o`000?ooooooooooooooool00000Doooool00ol0003oooooooooo`2Xoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool003Wooooo00Co0000oooooooo
oooo0000Doooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Wooooo0Ol00001oooo
o`7ooooo000jooooo`?o0000Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00So
oooo0Ol00001ooooo`7ooooo000looooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0
Z_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00?Oooool2o`00057ooooo00?o
0000ooooooooool0Zoooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00?oooool0
0ol0003oooooo`00001>ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool01_ooool1
o`00007ooooo0Oooool0043ooooo0_l0001>ooooo`03o`000?oooooooooo0:gooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool0047ooooo0_l0001=ooooo`03o`000?oooooooooo0:ko
oooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00A?oo
ool2o`000003ooooool0003ooooo04Oooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool004Kooooo0_l00018ooooo`03o`000?oooooooooo0;3ooooo00?o0000
ooooooooool00oooool1o`00007ooooo000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l00017ooooo`03o`000?oooooooooo0;7ooooo00?o
0000ooooooooool00_ooool1o`00007ooooo000booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000A_ooool00ol0003oooooooooo`2booooo`05o`00
0?ooooooooooooooool000000Oooool002[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03o`0004?ooooo00?o0000ooooooooool0/oooool01?l0003o
ooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooo
oooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Cooooo00?o
0000ooooooooool00Ol0000003;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oo
oooooooo00Sooooo0_l00010ooooo`03o`000?oooooooooo0;Gooooo0Ol00001ooooo`7o0000000b
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o0000?_oo
ool00ol0003oooooooooo`2fooooo`;o0000000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000[ooooo0_l0000mooooo`03o`000?oooooooooo0;Gooooo0ol0000005?ooooo00Go0000
ooooooooooooooooo`00000hooooo`03o`000?oooooooooo0;3ooooo1Ol00003ooooo`00E?ooool0
1?l0003oooooooooool0000hooooo`03o`000?oooooooooo0:cooooo1?l00008ooooo`00EOooool3
o`0003Sooooo00?o0000ooooooooool0Z?ooool4o`0000cooooo001Gooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0Y?ooool5o`00013ooooo001Hooooo`;o0000=Oooool00ol0003o
ooooooooo`2Pooooo`Co00005Oooool005[ooooo00?o0000ooooool00000<_ooool00ol0003ooooo
ooooo`2Looooo`Co00006Oooool005_ooooo0_l0000booooo`03o`000?oooooooooo09Oooooo1Ol0
000Mooooo`00GOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000R
ooooo`00G_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo08kooooo1Ol0000V
ooooo`00Goooool3o`0002gooooo00?o0000ooooooooool0R_ooool4o`0002_ooooo001Qooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_ooool4o`0002oooooo001Cooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0002_ooooo00?o0000ooooooooool0POooool5o`0003?o
oooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooo`00000Xooooo`03
o`000?oooooooooo07gooooo1?l0000hooooo`00Doooool01Ol@413ooooooooooooooooo410@00go
oooo0_l0000Xooooo`03o`000?oooooooooo07Wooooo1?l0000looooo`00Doooool01Ol0003ooooo
oooooooooooo000000oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Go
0000@?ooool005?ooooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool0L?ooool4o`0004Gooooo001Cooooo`05oa0@4?oooooooooooooo
ool@41004Oooool3o`0002?ooooo00?o0000ooooooooool0Joooool5o`0004Wooooo001Cooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`0002?ooooo00?o0000ooooooooool0Ioooool4o`00
04kooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0003ooooo
01kooooo00?o0000ooooooooool0Hoooool4o`0005;ooooo001^ooooo`;o00007oooool00ol0003o
ooooooooo`1Nooooo`Go0000E_ooool006oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Jooooo`Co0000Foooool0073ooooo0_l0000Mooooo`03o`000?oooooooooo05Kooooo1?l0
001Oooooo`00L_ooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo057ooooo1Ol0001S
ooooo`00Loooool2o`0001[ooooo00?o0000ooooooooool0COooool4o`0006Sooooo001eooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0006cooooo001fooooo`;o0000
00?oooooo`000?ooool05?ooool00ol0003oooooooooo`14ooooo`Go0000L?ooool007Sooooo0_l0
000Eooooo`03o`000?oooooooooo043ooooo1?l0001eooooo`00NOooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03_ooooo1Ol0001iooooo`00N_ooool2o`000003ooooool0003ooooo
013ooooo00?o0000ooooooooool0=oooool4o`0007kooooo001Sooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o00004Oooool0
0ol0003oooooooooo`0cooooo`Co0000P_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`;o00003oooool00ol0003oooooooooo`0_
ooooo`Go0000Q_ooool006?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`Co0000Roooool0
06?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;
ooooo`03o`000?oooooooooo02Oooooo1?l0002?ooooo`00Hoooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c009ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool08_ooool5o`0009?ooooo001Sooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
7_ooool4o`0009Sooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003ooooo
ooooo`0=ooooo`?o00001oooool00ol0003oooooooooo`0Iooooo`Go0000W?ooool006?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo1?l0002Qooooo`00Qoooool2o`0000Gooooo00?o0000ooooooooool04Ooo
ool4o`000:Gooooo0029ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Go0000ZOooool0
08[ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000[_ooool008_ooooo0_l000000ooo
oooo0000ooooo`05ooooo`Co0000/_ooool008gooooo0_l000000ooooooo0000o`000003o`000;Ko
oooo002>ooooo`;o0000^oooool00?ooooooC?ooool00?ooooooC?ooool008Cooooo1?l000000ol@
413oooooooooo`30ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003ooooo
ooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32
ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00
Q?ooool00omEEEGoIVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.48101 .5517 m .47468 .59273 L .54471 .59679 L p .753 .631 .725 r
F P
0 g
s
.54471 .59679 m .54227 .5535 L .48101 .5517 L p .753 .631 .725 r
F P
0 g
s
.54672 .6409 m .54471 .59679 L .47468 .59273 L p .759 .608 .691 r
F P
0 g
s
.54227 .5535 m .54471 .59679 L .61845 .58629 L p .691 .585 .732 r
F P
0 g
s
.54471 .59679 m .54672 .6409 L .6291 .63094 L p .688 .555 .699 r
F P
0 g
s
.6291 .63094 m .61845 .58629 L .54471 .59679 L p .688 .555 .699 r
F P
0 g
s
.47468 .59273 m .4696 .63376 L .54672 .6409 L p .759 .608 .691 r
F P
0 g
s
.54823 .68467 m .54672 .6409 L .4696 .63376 L p .763 .584 .655 r
F P
0 g
s
.54672 .6409 m .54823 .68467 L .63712 .6759 L p .684 .523 .662 r
F P
0 g
s
.63712 .6759 m .6291 .63094 L .54672 .6409 L p .684 .523 .662 r
F P
0 g
s
.48844 .51144 m .48101 .5517 L .54227 .5535 L p .745 .651 .756 r
F P
0 g
s
.54227 .5535 m .5395 .51195 L .48844 .51144 L p .745 .651 .756 r
F P
0 g
s
.5395 .51195 m .54227 .5535 L .60572 .54326 L p .692 .613 .764 r
F P
0 g
s
.61845 .58629 m .60572 .54326 L .54227 .5535 L p .691 .585 .732 r
F P
0 g
s
.60572 .54326 m .61845 .58629 L .68245 .56177 L p .615 .539 .746 r
F P
0 g
s
.61845 .58629 m .6291 .63094 L .70051 .60383 L p .6 .499 .711 r
F P
0 g
s
.70051 .60383 m .68245 .56177 L .61845 .58629 L p .6 .499 .711 r
F P
0 g
s
.6291 .63094 m .63712 .6759 L .71412 .64691 L p .583 .454 .67 r
F P
0 g
s
.71412 .64691 m .70051 .60383 L .6291 .63094 L p .583 .454 .67 r
F P
0 g
s
.60572 .54326 m .59146 .5028 L .5395 .51195 L p .692 .613 .764 r
F P
0 g
s
.59146 .5028 m .60572 .54326 L .66087 .5219 L p .627 .576 .777 r
F P
0 g
s
.68245 .56177 m .66087 .5219 L .60572 .54326 L p .615 .539 .746 r
F P
0 g
s
.4696 .63376 m .46587 .67398 L .54823 .68467 L p .763 .584 .655 r
F P
0 g
s
.54915 .72675 m .54823 .68467 L .46587 .67398 L p .765 .555 .613 r
F P
0 g
s
.54823 .68467 m .54915 .72675 L .64205 .71958 L p .677 .485 .619 r
F P
0 g
s
.64205 .71958 m .63712 .6759 L .54823 .68467 L p .677 .485 .619 r
F P
0 g
s
.49684 .47269 m .48844 .51144 L .5395 .51195 L p .735 .669 .786 r
F P
0 g
s
.5395 .51195 m .53646 .47278 L .49684 .47269 L p .735 .669 .786 r
F P
0 g
s
.53646 .47278 m .5395 .51195 L .59146 .5028 L p .691 .64 .793 r
F P
0 g
s
.42907 .53899 m .41694 .57662 L .47468 .59273 L p .805 .675 .72 r
F P
0 g
s
.47468 .59273 m .48101 .5517 L .42907 .53899 L p .805 .675 .72 r
F P
0 g
s
.4696 .63376 m .47468 .59273 L .41694 .57662 L p .819 .66 .686 r
F P
0 g
s
.44396 .50147 m .42907 .53899 L .48101 .5517 L p .79 .688 .752 r
F P
0 g
s
.48101 .5517 m .48844 .51144 L .44396 .50147 L p .79 .688 .752 r
F P
0 g
s
.63712 .6759 m .64205 .71958 L .72248 .68954 L p .562 .401 .621 r
F P
0 g
s
.72248 .68954 m .71412 .64691 L .63712 .6759 L p .562 .401 .621 r
F P
0 g
s
.59146 .5028 m .57612 .46544 L .53646 .47278 L p .691 .64 .793 r
F P
0 g
s
.57612 .46544 m .59146 .5028 L .63668 .48504 L p .639 .611 .806 r
F P
0 g
s
.66087 .5219 m .63668 .48504 L .59146 .5028 L p .627 .576 .777 r
F P
0 g
s
.41694 .57662 m .40757 .61369 L .4696 .63376 L p .819 .66 .686 r
F P
0 g
s
.46587 .67398 m .4696 .63376 L .40757 .61369 L p .831 .643 .648 r
F P
0 g
s
.46148 .46495 m .44396 .50147 L .48844 .51144 L p .772 .699 .782 r
F P
0 g
s
.48844 .51144 m .49684 .47269 L .46148 .46495 L p .772 .699 .782 r
F P
0 g
s
.46587 .67398 m .46361 .71253 L .54915 .72675 L p .765 .555 .613 r
F P
0 g
s
.54942 .76571 m .54915 .72675 L .46361 .71253 L p .766 .52 .562 r
F P
0 g
s
.54915 .72675 m .54942 .76571 L .6435 .76026 L p .667 .44 .566 r
F P
0 g
s
.6435 .76026 m .64205 .71958 L .54915 .72675 L p .667 .44 .566 r
F P
0 g
s
.50605 .43617 m .49684 .47269 L .53646 .47278 L p .722 .687 .816 r
F P
0 g
s
.53646 .47278 m .53323 .43637 L .50605 .43617 L p .722 .687 .816 r
F P
0 g
s
.53323 .43637 m .53646 .47278 L .57612 .46544 L p .688 .665 .822 r
F P
0 g
s
.40757 .61369 m .4009 .64973 L .46587 .67398 L p .831 .643 .648 r
F P
0 g
s
.46361 .71253 m .46587 .67398 L .4009 .64973 L p .841 .621 .604 r
F P
0 g
s
.57612 .46544 m .56004 .43136 L .53323 .43637 L p .688 .665 .822 r
F P
0 g
s
.56004 .43136 m .57612 .46544 L .61065 .45163 L p .649 .645 .832 r
F P
0 g
s
.63668 .48504 m .61065 .45163 L .57612 .46544 L p .639 .611 .806 r
F P
0 g
s
.64205 .71958 m .6435 .76026 L .72496 .73008 L p .533 .336 .559 r
F P
0 g
s
.72496 .73008 m .72248 .68954 L .64205 .71958 L p .533 .336 .559 r
F P
0 g
s
.63668 .48504 m .66087 .5219 L .69834 .4928 L p .542 .535 .798 r
F P
0 g
s
.66087 .5219 m .68245 .56177 L .72463 .52761 L p .508 .484 .765 r
F P
0 g
s
.72463 .52761 m .69834 .4928 L .66087 .5219 L p .508 .484 .765 r
F P
0 g
s
.68245 .56177 m .70051 .60383 L .74631 .56486 L p .47 .425 .726 r
F P
0 g
s
.74631 .56486 m .72463 .52761 L .68245 .56177 L p .47 .425 .726 r
F P
0 g
s
.48136 .43052 m .46148 .46495 L .49684 .47269 L p .75 .708 .813 r
F P
0 g
s
.49684 .47269 m .50605 .43617 L .48136 .43052 L p .75 .708 .813 r
F P
0 g
s
.61065 .45163 m .63668 .48504 L .66834 .4611 L p .573 .582 .824 r
F P
0 g
s
.69834 .4928 m .66834 .4611 L .63668 .48504 L p .542 .535 .798 r
F P
0 g
s
.70051 .60383 m .71412 .64691 L .76249 .60367 L p .424 .355 .676 r
F P
0 g
s
.76249 .60367 m .74631 .56486 L .70051 .60383 L p .424 .355 .676 r
F P
0 g
s
.40859 .48259 m .38841 .51673 L .42907 .53899 L p .827 .723 .75 r
F P
0 g
s
.42907 .53899 m .44396 .50147 L .40859 .48259 L p .827 .723 .75 r
F P
0 g
s
.41694 .57662 m .42907 .53899 L .38841 .51673 L p .849 .716 .715 r
F P
0 g
s
.43305 .44977 m .40859 .48259 L .44396 .50147 L p .803 .729 .782 r
F P
0 g
s
.44396 .50147 m .46148 .46495 L .43305 .44977 L p .803 .729 .782 r
F P
0 g
s
.4009 .64973 m .3969 .68439 L .46361 .71253 L p .841 .621 .604 r
F P
0 g
s
.46291 .74855 m .46361 .71253 L .3969 .68439 L p .849 .592 .55 r
F P
0 g
s
.46361 .71253 m .46291 .74855 L .54942 .76571 L p .766 .52 .562 r
F P
0 g
s
.38841 .51673 m .37252 .55111 L .41694 .57662 L p .849 .716 .715 r
F P
0 g
s
.40757 .61369 m .41694 .57662 L .37252 .55111 L p .868 .706 .678 r
F P
0 g
s
.51594 .4026 m .50605 .43617 L .53323 .43637 L p .704 .703 .846 r
F P
0 g
s
.53323 .43637 m .52984 .40295 L .51594 .4026 L p .704 .703 .846 r
F P
0 g
s
.52984 .40295 m .53323 .43637 L .56004 .43136 L p .683 .69 .851 r
F P
0 g
s
.54902 .80014 m .54942 .76571 L .46291 .74855 L p .762 .475 .498 r
F P
0 g
s
.54942 .76571 m .54902 .80014 L .6413 .79623 L p .651 .381 .498 r
F P
0 g
s
.6413 .79623 m .6435 .76026 L .54942 .76571 L p .651 .381 .498 r
F P
0 g
s
.61065 .45163 m .58336 .42181 L .56004 .43136 L p .649 .645 .832 r
F P
0 g
s
.58336 .42181 m .61065 .45163 L .63547 .43297 L p .602 .626 .847 r
F P
0 g
s
.66834 .4611 m .63547 .43297 L .61065 .45163 L p .573 .582 .824 r
F P
0 g
s
.4614 .41958 m .43305 .44977 L .46148 .46495 L p .775 .732 .814 r
F P
0 g
s
.46148 .46495 m .48136 .43052 L .4614 .41958 L p .775 .732 .814 r
F P
0 g
s
.50318 .39936 m .48136 .43052 L .50605 .43617 L p .723 .717 .844 r
F P
0 g
s
.50605 .43617 m .51594 .4026 L .50318 .39936 L p .723 .717 .844 r
F P
0 g
s
.56004 .43136 m .54341 .40049 L .52984 .40295 L p .683 .69 .851 r
F P
0 g
s
.54341 .40049 m .56004 .43136 L .58336 .42181 L p .659 .678 .858 r
F P
0 g
s
.71412 .64691 m .72248 .68954 L .77239 .64298 L p .366 .269 .611 r
F P
0 g
s
.77239 .64298 m .76249 .60367 L .71412 .64691 L p .366 .269 .611 r
F P
0 g
s
.37252 .55111 m .36068 .58501 L .40757 .61369 L p .868 .706 .678 r
F P
0 g
s
.4009 .64973 m .40757 .61369 L .36068 .58501 L p .885 .693 .637 r
F P
0 g
s
.6435 .76026 m .6413 .79623 L .72124 .76686 L p .492 .25 .474 r
F P
0 g
s
.72124 .76686 m .72496 .73008 L .6435 .76026 L p .492 .25 .474 r
F P
0 g
s
.49286 .39343 m .4614 .41958 L .48136 .43052 L p .74 .733 .845 r
F P
0 g
s
.48136 .43052 m .50318 .39936 L .49286 .39343 L p .74 .733 .845 r
F P
0 g
s
.58336 .42181 m .5552 .39552 L .54341 .40049 L p .659 .678 .858 r
F P
0 g
s
.5552 .39552 m .58336 .42181 L .60045 .40872 L p .631 .667 .867 r
F P
0 g
s
.63547 .43297 m .60045 .40872 L .58336 .42181 L p .602 .626 .847 r
F P
0 g
s
.3969 .68439 m .39557 .71741 L .46291 .74855 L p .849 .592 .55 r
F P
0 g
s
.46384 .78116 m .46291 .74855 L .39557 .71741 L p .852 .553 .482 r
F P
0 g
s
.46291 .74855 m .46384 .78116 L .54902 .80014 L p .762 .475 .498 r
F P
0 g
s
.36068 .58501 m .3525 .61806 L .4009 .64973 L p .885 .693 .637 r
F P
0 g
s
.3969 .68439 m .4009 .64973 L .3525 .61806 L p .9 .675 .589 r
F P
0 g
s
.44783 .40398 m .41314 .42766 L .43305 .44977 L p .794 .76 .822 r
F P
0 g
s
.43305 .44977 m .4614 .41958 L .44783 .40398 L p .794 .76 .822 r
F P
0 g
s
.40859 .48259 m .43305 .44977 L .41314 .42766 L p .828 .762 .789 r
F P
0 g
s
.41314 .42766 m .383 .4551 L .40859 .48259 L p .828 .762 .789 r
F P
0 g
s
.38841 .51673 m .40859 .48259 L .383 .4551 L p .858 .76 .753 r
F P
0 g
s
.72248 .68954 m .72496 .73008 L .77539 .68156 L p .288 .155 .519 r
F P
0 g
s
.77539 .68156 m .77239 .64298 L .72248 .68954 L p .288 .155 .519 r
F P
0 g
s
.63547 .43297 m .66834 .4611 L .68303 .43381 L p .486 .552 .848 r
F P
0 g
s
.66834 .4611 m .69834 .4928 L .71402 .46021 L p .416 .483 .821 r
F P
0 g
s
.71402 .46021 m .68303 .43381 L .66834 .4611 L p .416 .483 .821 r
F P
0 g
s
.52984 .40295 m .52632 .37269 L .51594 .4026 L closepath p .692 .727 .877 r
F P
0 g
s
.54341 .40049 m .52632 .37269 L .52984 .40295 L closepath p .68 .719 .878 r
F P
0 g
s
.60045 .40872 m .63547 .43297 L .64791 .41128 L p .547 .61 .867 r
F P
0 g
s
.68303 .43381 m .64791 .41128 L .63547 .43297 L p .486 .552 .848 r
F P
0 g
s
.51594 .4026 m .52632 .37269 L .50318 .39936 L closepath p .698 .735 .879 r
F P
0 g
s
.48603 .38532 m .44783 .40398 L .4614 .41958 L p .752 .753 .853 r
F P
0 g
s
.4614 .41958 m .49286 .39343 L .48603 .38532 L p .752 .753 .853 r
F P
0 g
s
.5552 .39552 m .52632 .37269 L .54341 .40049 L closepath p .665 .712 .883 r
F P
0 g
s
.383 .4551 m .35797 .48506 L .38841 .51673 L p .858 .76 .753 r
F P
0 g
s
.37252 .55111 m .38841 .51673 L .35797 .48506 L p .883 .754 .714 r
F P
0 g
s
.69834 .4928 m .72463 .52761 L .74023 .4898 L p .332 .4 .782 r
F P
0 g
s
.74023 .4898 m .71402 .46021 L .69834 .4928 L p .332 .4 .782 r
F P
0 g
s
.54794 .82879 m .54902 .80014 L .46384 .78116 L p .751 .412 .408 r
F P
0 g
s
.54902 .80014 m .54794 .82879 L .63546 .82602 L p .625 .301 .401 r
F P
0 g
s
.63546 .82602 m .6413 .79623 L .54902 .80014 L p .625 .301 .401 r
F P
0 g
s
.50318 .39936 m .52632 .37269 L .49286 .39343 L closepath p .701 .739 .881 r
F P
0 g
s
.60045 .40872 m .56389 .38856 L .5552 .39552 L p .631 .667 .867 r
F P
0 g
s
.56389 .38856 m .60045 .40872 L .60943 .39324 L p .601 .66 .88 r
F P
0 g
s
.64791 .41128 m .60943 .39324 L .60045 .40872 L p .547 .61 .867 r
F P
0 g
s
.56389 .38856 m .52632 .37269 L .5552 .39552 L closepath p .651 .71 .891 r
F P
0 g
s
.72463 .52761 m .74631 .56486 L .76117 .52191 L p .228 .295 .724 r
F P
0 g
s
.76117 .52191 m .74023 .4898 L .72463 .52761 L p .228 .295 .724 r
F P
0 g
s
.35797 .48506 m .33818 .51642 L .37252 .55111 L p .883 .754 .714 r
F P
0 g
s
.36068 .58501 m .37252 .55111 L .33818 .51642 L p .905 .744 .671 r
F P
0 g
s
.3525 .61806 m .34762 .65017 L .3969 .68439 L p .9 .675 .589 r
F P
0 g
s
.39557 .71741 m .3969 .68439 L .34762 .65017 L p .911 .65 .531 r
F P
0 g
s
.49286 .39343 m .52632 .37269 L .48603 .38532 L closepath p .701 .74 .881 r
F P
0 g
s
.6413 .79623 m .63546 .82602 L .71136 .79839 L p .428 .126 .349 r
F P
0 g
s
.71136 .79839 m .72124 .76686 L .6413 .79623 L p .428 .126 .349 r
F P
0 g
s
.56855 .38024 m .52632 .37269 L .56389 .38856 L closepath p .641 .712 .899 r
F P
0 g
s
.60943 .39324 m .56855 .38024 L .56389 .38856 L p .601 .66 .88 r
F P
0 g
s
.48344 .37581 m .44202 .38499 L .44783 .40398 L p .756 .774 .868 r
F P
0 g
s
.44783 .40398 m .48603 .38532 L .48344 .37581 L p .756 .774 .868 r
F P
0 g
s
.41314 .42766 m .44783 .40398 L .44202 .38499 L p .803 .791 .841 r
F P
0 g
s
.44202 .38499 m .40337 .39981 L .41314 .42766 L p .803 .791 .841 r
F P
0 g
s
.383 .4551 m .41314 .42766 L .40337 .39981 L p .845 .802 .809 r
F P
0 g
s
.48603 .38532 m .52632 .37269 L .48344 .37581 L closepath p .701 .742 .883 r
F P
0 g
s
.39557 .71741 m .397 .74846 L .46384 .78116 L p .852 .553 .482 r
F P
0 g
s
.46643 .80947 m .46384 .78116 L .397 .74846 L p .847 .496 .389 r
F P
0 g
s
.46384 .78116 m .46643 .80947 L .54794 .82879 L p .751 .412 .408 r
F P
0 g
s
.74631 .56486 m .76249 .60367 L .77644 .55586 L p .097 .159 .639 r
F P
0 g
s
.77644 .55586 m .76117 .52191 L .74631 .56486 L p .097 .159 .639 r
F P
0 g
s
.72496 .73008 m .72124 .76686 L .77115 .71814 L p .177 0 .384 r
F P
0 g
s
.77115 .71814 m .77539 .68156 L .72496 .73008 L p .177 0 .384 r
F P
0 g
s
.33818 .51642 m .32338 .54834 L .36068 .58501 L p .905 .744 .671 r
F P
0 g
s
.3525 .61806 m .36068 .58501 L .32338 .54834 L p .923 .73 .624 r
F P
0 g
s
.56867 .37128 m .52632 .37269 L .56855 .38024 L closepath p .637 .716 .904 r
F P
0 g
s
.56855 .38024 m .60943 .39324 L .60957 .37648 L p .571 .66 .897 r
F P
0 g
s
.60957 .37648 m .56867 .37128 L .56855 .38024 L p .571 .66 .897 r
F P
0 g
s
.60943 .39324 m .64791 .41128 L .64749 .38794 L p .486 .601 .892 r
F P
0 g
s
.64749 .38794 m .60957 .37648 L .60943 .39324 L p .486 .601 .892 r
F P
0 g
s
.40337 .39981 m .36859 .41961 L .383 .4551 L p .845 .802 .809 r
F P
0 g
s
.35797 .48506 m .383 .4551 L .36859 .41961 L p .881 .806 .771 r
F P
0 g
s
.55564 .3548 m .52632 .37269 L .56422 .36251 L closepath p .636 .719 .907 r
F P
0 g
s
.48344 .37581 m .52632 .37269 L .48546 .36599 L closepath p .7 .745 .886 r
F P
0 g
s
.56422 .36251 m .52632 .37269 L .56867 .37128 L closepath p .636 .718 .907 r
F P
0 g
s
.54379 .34906 m .52632 .37269 L .55564 .3548 L closepath p .636 .721 .909 r
F P
0 g
s
.52991 .3461 m .52632 .37269 L .54379 .34906 L closepath p .641 .728 .912 r
F P
0 g
s
.51556 .34647 m .52632 .37269 L .52991 .3461 L closepath p .652 .738 .913 r
F P
0 g
s
.50241 .35028 m .52632 .37269 L .51556 .34647 L closepath p .668 .747 .91 r
F P
0 g
s
.49199 .35709 m .52632 .37269 L .50241 .35028 L closepath p .684 .751 .902 r
F P
0 g
s
.48546 .36599 m .52632 .37269 L .49199 .35709 L closepath p .695 .749 .893 r
F P
0 g
s
.44202 .38499 m .48344 .37581 L .48546 .36599 L p .748 .791 .888 r
F P
0 g
s
.64791 .41128 m .68303 .43381 L .68121 .40497 L p .376 .521 .874 r
F P
0 g
s
.68121 .40497 m .64749 .38794 L .64791 .41128 L p .376 .521 .874 r
F P
0 g
s
.34762 .65017 m .34586 .68141 L .39557 .71741 L p .911 .65 .531 r
F P
0 g
s
.397 .74846 m .39557 .71741 L .34586 .68141 L p .916 .614 .457 r
F P
0 g
s
.56867 .37128 m .60957 .37648 L .60099 .35958 L p .551 .671 .917 r
F P
0 g
s
.60099 .35958 m .56422 .36251 L .56867 .37128 L p .551 .671 .917 r
F P
0 g
s
.48546 .36599 m .44503 .36466 L .44202 .38499 L p .748 .791 .888 r
F P
0 g
s
.40337 .39981 m .44202 .38499 L .44503 .36466 L p .797 .822 .871 r
F P
0 g
s
.36859 .41961 m .33849 .44361 L .35797 .48506 L p .881 .806 .771 r
F P
0 g
s
.33818 .51642 m .35797 .48506 L .33849 .44361 L p .912 .803 .727 r
F P
0 g
s
.76249 .60367 m .77239 .64298 L .7857 .59099 L p 0 0 .51 r
F P
0 g
s
.7857 .59099 m .77644 .55586 L .76249 .60367 L p 0 0 .51 r
F P
0 g
s
.32338 .54834 m .31313 .5803 L .3525 .61806 L p .923 .73 .624 r
F P
0 g
s
.34762 .65017 m .3525 .61806 L .31313 .5803 L p .936 .711 .573 r
F P
0 g
s
.54621 .85067 m .54794 .82879 L .46643 .80947 L p .723 .316 .276 r
F P
0 g
s
.54794 .82879 m .54621 .85067 L .62623 .8485 L p .574 .179 .254 r
F P
0 g
s
.62623 .8485 m .63546 .82602 L .54794 .82879 L p .574 .179 .254 r
F P
0 g
s
.68303 .43381 m .71402 .46021 L .70991 .42667 L p .231 .41 .834 r
F P
0 g
s
.70991 .42667 m .68121 .40497 L .68303 .43381 L p .231 .41 .834 r
F P
0 g
s
.44503 .36466 m .48546 .36599 L .49199 .35709 L p .727 .799 .909 r
F P
0 g
s
.56422 .36251 m .60099 .35958 L .58445 .3439 L p .547 .693 .935 r
F P
0 g
s
.58445 .3439 m .55564 .3548 L .56422 .36251 L p .547 .693 .935 r
F P
0 g
s
.44503 .36466 m .40589 .36888 L .40337 .39981 L p .797 .822 .871 r
F P
0 g
s
.36859 .41961 m .40337 .39981 L .40589 .36888 L p .843 .847 .847 r
F P
0 g
s
.60957 .37648 m .64749 .38794 L .63505 .3639 L p .434 .606 .92 r
F P
0 g
s
.63505 .3639 m .60099 .35958 L .60957 .37648 L p .434 .606 .92 r
F P
0 g
s
.45727 .34577 m .49199 .35709 L .50241 .35028 L p .697 .796 .926 r
F P
0 g
s
.49199 .35709 m .45727 .34577 L .44503 .36466 L p .727 .799 .909 r
F P
0 g
s
.63546 .82602 m .62623 .8485 L .69572 .82348 L p .318 0 .15 r
F P
0 g
s
.69572 .82348 m .71136 .79839 L .63546 .82602 L p .318 0 .15 r
F P
0 g
s
.33849 .44361 m .31357 .47097 L .33818 .51642 L p .912 .803 .727 r
F P
0 g
s
.32338 .54834 m .33818 .51642 L .31357 .47097 L p .937 .794 .677 r
F P
0 g
s
.71402 .46021 m .74023 .4898 L .73319 .45205 L p .037 .255 .754 r
F P
0 g
s
.73319 .45205 m .70991 .42667 L .71402 .46021 L p .037 .255 .754 r
F P
0 g
s
.55564 .3548 m .58445 .3439 L .56126 .33131 L p .564 .72 .946 r
F P
0 g
s
.56126 .33131 m .54379 .34906 L .55564 .3548 L p .564 .72 .946 r
F P
0 g
s
.397 .74846 m .40137 .77704 L .46643 .80947 L p .847 .496 .389 r
F P
0 g
s
.4707 .83262 m .46643 .80947 L .40137 .77704 L p .825 .408 .253 r
F P
0 g
s
.46643 .80947 m .4707 .83262 L .54621 .85067 L p .723 .316 .276 r
F P
0 g
s
.72124 .76686 m .71136 .79839 L .75962 .75144 L p .009 0 .173 r
F P
0 g
s
.75962 .75144 m .77115 .71814 L .72124 .76686 L p .009 0 .173 r
F P
0 g
s
.40589 .36888 m .44503 .36466 L .45727 .34577 L p .769 .843 .908 r
F P
0 g
s
.47789 .33134 m .50241 .35028 L .51556 .34647 L p .663 .784 .939 r
F P
0 g
s
.50241 .35028 m .47789 .33134 L .45727 .34577 L p .697 .796 .926 r
F P
0 g
s
.34586 .68141 m .3473 .71181 L .397 .74846 L p .916 .614 .457 r
F P
0 g
s
.40137 .77704 m .397 .74846 L .3473 .71181 L p .911 .559 .358 r
F P
0 g
s
.31313 .5803 m .30701 .61209 L .34762 .65017 L p .936 .711 .573 r
F P
0 g
s
.34586 .68141 m .34762 .65017 L .30701 .61209 L p .946 .686 .512 r
F P
0 g
s
.54379 .34906 m .56126 .33131 L .53356 .32397 L p .593 .746 .949 r
F P
0 g
s
.53356 .32397 m .52991 .3461 L .54379 .34906 L p .593 .746 .949 r
F P
0 g
s
.77239 .64298 m .77539 .68156 L .78868 .62663 L p 0 0 .317 r
F P
0 g
s
.78868 .62663 m .7857 .59099 L .77239 .64298 L p 0 0 .317 r
F P
0 g
s
.5045 .32376 m .51556 .34647 L .52991 .3461 L p .628 .767 .946 r
F P
0 g
s
.51556 .34647 m .5045 .32376 L .47789 .33134 L p .663 .784 .939 r
F P
0 g
s
.40589 .36888 m .36897 .37877 L .36859 .41961 L p .843 .847 .847 r
F P
0 g
s
.33849 .44361 m .36859 .41961 L .36897 .37877 L p .887 .866 .812 r
F P
0 g
s
.52991 .3461 m .53356 .32397 L .5045 .32376 L p .628 .767 .946 r
F P
0 g
s
.64749 .38794 m .68121 .40497 L .66514 .37498 L p .266 .502 .896 r
F P
0 g
s
.66514 .37498 m .63505 .3639 L .64749 .38794 L p .266 .502 .896 r
F P
0 g
s
.60099 .35958 m .63505 .3639 L .61161 .34043 L p .413 .633 .946 r
F P
0 g
s
.61161 .34043 m .58445 .3439 L .60099 .35958 L p .413 .633 .946 r
F P
0 g
s
.74023 .4898 m .76117 .52191 L .75103 .48021 L p 0 .043 .61 r
F P
0 g
s
.75103 .48021 m .73319 .45205 L .74023 .4898 L p 0 .043 .61 r
F P
0 g
s
.31357 .47097 m .29408 .50092 L .32338 .54834 L p .937 .794 .677 r
F P
0 g
s
.31313 .5803 m .32338 .54834 L .29408 .50092 L p .956 .778 .621 r
F P
0 g
s
.42251 .33931 m .45727 .34577 L .47789 .33134 L p .717 .847 .944 r
F P
0 g
s
.45727 .34577 m .42251 .33931 L .40589 .36888 L p .769 .843 .908 r
F P
0 g
s
.36897 .37877 m .40589 .36888 L .42251 .33931 L p .812 .888 .899 r
F P
0 g
s
.36897 .37877 m .33524 .39432 L .33849 .44361 L p .887 .866 .812 r
F P
0 g
s
.31357 .47097 m .33849 .44361 L .33524 .39432 L p .928 .878 .766 r
F P
0 g
s
.30701 .61209 m .30479 .6437 L .34586 .68141 L p .946 .686 .512 r
F P
0 g
s
.3473 .71181 m .34586 .68141 L .30479 .6437 L p .95 .651 .436 r
F P
0 g
s
.54389 .86517 m .54621 .85067 L .4707 .83262 L p .653 .158 .063 r
F P
0 g
s
.54621 .85067 m .54389 .86517 L .61402 .86309 L p .468 0 .012 r
F P
0 g
s
.61402 .86309 m .62623 .8485 L .54621 .85067 L p .468 0 .012 r
F P
0 g
s
.68121 .40497 m .70991 .42667 L .69041 .39192 L p .026 .335 .817 r
F P
0 g
s
.69041 .39192 m .66514 .37498 L .68121 .40497 L p .026 .335 .817 r
F P
0 g
s
.58445 .3439 m .61161 .34043 L .57824 .32016 L p .435 .68 .967 r
F P
0 g
s
.57824 .32016 m .56126 .33131 L .58445 .3439 L p .435 .68 .967 r
F P
0 g
s
.3473 .71181 m .35234 .74116 L .40137 .77704 L p .911 .559 .358 r
F P
0 g
s
.40896 .80245 m .40137 .77704 L .35234 .74116 L p .885 .47 .214 r
F P
0 g
s
.40137 .77704 m .40896 .80245 L .4707 .83262 L p .825 .408 .253 r
F P
0 g
s
.77539 .68156 m .77115 .71814 L .78508 .66209 L p 0 0 .052 r
F P
0 g
s
.78508 .66209 m .78868 .62663 L .77539 .68156 L p 0 0 .052 r
F P
0 g
s
.76117 .52191 m .77644 .55586 L .76362 .51043 L p 0 0 .392 r
F P
0 g
s
.76362 .51043 m .75103 .48021 L .76117 .52191 L p 0 0 .392 r
F P
0 g
s
.29408 .50092 m .2801 .5328 L .31313 .5803 L p .956 .778 .621 r
F P
0 g
s
.30701 .61209 m .31313 .5803 L .2801 .5328 L p .97 .755 .558 r
F P
0 g
s
.45286 .31659 m .47789 .33134 L .5045 .32376 L p .645 .828 .97 r
F P
0 g
s
.47789 .33134 m .45286 .31659 L .42251 .33931 L p .717 .847 .944 r
F P
0 g
s
.71136 .79839 m .69572 .82348 L .74109 .78034 L p 0 0 0 r
F P
0 g
s
.74109 .78034 m .75962 .75144 L .71136 .79839 L p 0 0 0 r
F P
0 g
s
.47661 .84984 m .4707 .83262 L .40896 .80245 L p .758 .261 .042 r
F P
0 g
s
.4707 .83262 m .47661 .84984 L .54389 .86517 L p .653 .158 .063 r
F P
0 g
s
.62623 .8485 m .61402 .86309 L .67502 .84141 L p .121 0 0 r
F P
0 g
s
.67502 .84141 m .69572 .82348 L .62623 .8485 L p .121 0 0 r
F P
0 g
s
.63505 .3639 m .66514 .37498 L .63613 .34437 L p .206 .52 .917 r
F P
0 g
s
.63613 .34437 m .61161 .34043 L .63505 .3639 L p .206 .52 .917 r
F P
0 g
s
.56126 .33131 m .57824 .32016 L .53722 .3071 L p .491 .735 .98 r
F P
0 g
s
.53722 .3071 m .53356 .32397 L .56126 .33131 L p .491 .735 .98 r
F P
0 g
s
.49322 .30529 m .5045 .32376 L .53356 .32397 L p .566 .788 .983 r
F P
0 g
s
.5045 .32376 m .49322 .30529 L .45286 .31659 L p .645 .828 .97 r
F P
0 g
s
.42251 .33931 m .38834 .33848 L .36897 .37877 L p .812 .888 .899 r
F P
0 g
s
.33524 .39432 m .36897 .37877 L .38834 .33848 L p .855 .931 .876 r
F P
0 g
s
.33524 .39432 m .30571 .41543 L .31357 .47097 L p .928 .878 .766 r
F P
0 g
s
.29408 .50092 m .31357 .47097 L .30571 .41543 L p .962 .879 .705 r
F P
0 g
s
.53356 .32397 m .53722 .3071 L .49322 .30529 L p .566 .788 .983 r
F P
0 g
s
.30479 .6437 m .3066 .67513 L .3473 .71181 L p .95 .651 .436 r
F P
0 g
s
.35234 .74116 m .3473 .71181 L .3066 .67513 L p .942 .596 .331 r
F P
0 g
s
.38834 .33848 m .42251 .33931 L .45286 .31659 L p .733 .904 .954 r
F P
0 g
s
.70991 .42667 m .73319 .45205 L .71056 .41362 L p 0 .089 .641 r
F P
0 g
s
.71056 .41362 m .69041 .39192 L .70991 .42667 L p 0 .089 .641 r
F P
0 g
s
.2801 .5328 m .27165 .56608 L .30701 .61209 L p .97 .755 .558 r
F P
0 g
s
.30479 .6437 m .30701 .61209 L .27165 .56608 L p .977 .724 .483 r
F P
0 g
s
.77644 .55586 m .7857 .59099 L .77119 .54224 L p .729 .454 0 r
F P
0 g
s
.77119 .54224 m .76362 .51043 L .77644 .55586 L p .729 .454 0 r
F P
0 g
s
.77115 .71814 m .75962 .75144 L .77466 .69656 L p .739 .759 .251 r
F P
0 g
s
.77466 .69656 m .78508 .66209 L .77115 .71814 L p .739 .759 .251 r
F P
0 g
s
.61161 .34043 m .63613 .34437 L .59422 .31612 L p .223 .584 .945 r
F P
0 g
s
.59422 .31612 m .57824 .32016 L .61161 .34043 L p .223 .584 .945 r
F P
0 g
s
.35234 .74116 m .3616 .7689 L .40896 .80245 L p .885 .47 .214 r
F P
0 g
s
.42001 .82369 m .40896 .80245 L .3616 .7689 L p .809 .321 0 r
F P
0 g
s
.40896 .80245 m .42001 .82369 L .47661 .84984 L p .758 .261 .042 r
F P
0 g
s
.30571 .41543 m .28139 .44179 L .29408 .50092 L p .962 .879 .705 r
F P
0 g
s
.2801 .5328 m .29408 .50092 L .28139 .44179 L p .988 .867 .623 r
F P
0 g
s
.66514 .37498 m .69041 .39192 L .65728 .35525 L p 0 .317 .798 r
F P
0 g
s
.65728 .35525 m .63613 .34437 L .66514 .37498 L p 0 .317 .798 r
F P
0 g
s
.38834 .33848 m .35571 .34413 L .33524 .39432 L p .855 .931 .876 r
F P
0 g
s
.30571 .41543 m .33524 .39432 L .35571 .34413 L p .893 .968 .827 r
F P
0 g
s
.4277 .30714 m .45286 .31659 L .49322 .30529 L p .601 .873 .992 r
F P
0 g
s
.45286 .31659 m .4277 .30714 L .38834 .33848 L p .733 .904 .954 r
F P
0 g
s
.54107 .87202 m .54389 .86517 L .47661 .84984 L p .477 0 0 r
F P
0 g
s
.54389 .86517 m .54107 .87202 L .59938 .86971 L p .244 0 0 r
F P
0 g
s
.59938 .86971 m .61402 .86309 L .54389 .86517 L p .244 0 0 r
F P
0 g
s
.73319 .45205 m .75103 .48021 L .7257 .43898 L p 0 0 .367 r
F P
0 g
s
.7257 .43898 m .71056 .41362 L .73319 .45205 L p 0 0 .367 r
F P
0 g
s
.3066 .67513 m .31293 .70623 L .35234 .74116 L p .942 .596 .331 r
F P
0 g
s
.3616 .7689 m .35234 .74116 L .31293 .70623 L p .909 .503 .175 r
F P
0 g
s
.69572 .82348 m .67502 .84141 L .71612 .80392 L p .491 .82 .518 r
F P
0 g
s
.71612 .80392 m .74109 .78034 L .69572 .82348 L p .491 .82 .518 r
F P
0 g
s
.27165 .56608 m .26883 .60031 L .30479 .6437 L p .977 .724 .483 r
F P
0 g
s
.3066 .67513 m .30479 .6437 L .26883 .60031 L p .975 .679 .385 r
F P
0 g
s
.48407 .86039 m .47661 .84984 L .42001 .82369 L p .589 .014 0 r
F P
0 g
s
.47661 .84984 m .48407 .86039 L .54107 .87202 L p .477 0 0 r
F P
0 g
s
.7857 .59099 m .78868 .62663 L .77384 .57534 L p .888 .641 .123 r
F P
0 g
s
.77384 .57534 m .77119 .54224 L .7857 .59099 L p .888 .641 .123 r
F P
0 g
s
.35571 .34413 m .38834 .33848 L .4277 .30714 L p .735 .962 .941 r
F P
0 g
s
.57824 .32016 m .59422 .31612 L .54081 .29641 L p .307 .68 .976 r
F P
0 g
s
.54081 .29641 m .53722 .3071 L .57824 .32016 L p .307 .68 .976 r
F P
0 g
s
.61402 .86309 m .59938 .86971 L .65017 .85193 L p 0 0 0 r
F P
0 g
s
.65017 .85193 m .67502 .84141 L .61402 .86309 L p 0 0 0 r
F P
0 g
s
.48189 .29224 m .49322 .30529 L .53722 .3071 L p .443 .788 .998 r
F P
0 g
s
.49322 .30529 m .48189 .29224 L .4277 .30714 L p .601 .873 .992 r
F P
0 g
s
.53722 .3071 m .54081 .29641 L .48189 .29224 L p .443 .788 .998 r
F P
0 g
s
.28139 .44179 m .26324 .47292 L .2801 .5328 L p .988 .867 .623 r
F P
0 g
s
.27165 .56608 m .2801 .5328 L .26324 .47292 L p .999 .834 .514 r
F P
0 g
s
.75962 .75144 m .74109 .78034 L .75726 .72914 L p .867 .918 .52 r
F P
0 g
s
.75726 .72914 m .77466 .69656 L .75962 .75144 L p .867 .918 .52 r
F P
0 g
s
.69041 .39192 m .71056 .41362 L .67462 .3723 L p 0 .026 .545 r
F P
0 g
s
.67462 .3723 m .65728 .35525 L .69041 .39192 L p 0 .026 .545 r
F P
0 g
s
.35571 .34413 m .32587 .35708 L .30571 .41543 L p .893 .968 .827 r
F P
0 g
s
.28139 .44179 m .30571 .41543 L .32587 .35708 L p .912 .981 .729 r
F P
0 g
s
.75103 .48021 m .76362 .51043 L .73621 .46708 L p .82 .433 0 r
F P
0 g
s
.73621 .46708 m .7257 .43898 L .75103 .48021 L p .82 .433 0 r
F P
0 g
s
.63613 .34437 m .65728 .35525 L .6087 .31949 L p 0 .379 .808 r
F P
0 g
s
.6087 .31949 m .59422 .31612 L .63613 .34437 L p 0 .379 .808 r
F P
0 g
s
.26883 .60031 m .27185 .63508 L .3066 .67513 L p .975 .679 .385 r
F P
0 g
s
.31293 .70623 m .3066 .67513 L .27185 .63508 L p .953 .606 .247 r
F P
0 g
s
.3616 .7689 m .3758 .794 L .42001 .82369 L p .809 .321 0 r
F P
0 g
s
.43473 .83959 m .42001 .82369 L .3758 .794 L p .622 .071 0 r
F P
0 g
s
.42001 .82369 m .43473 .83959 L .48407 .86039 L p .589 .014 0 r
F P
0 g
s
.31293 .70623 m .32454 .73648 L .3616 .7689 L p .909 .503 .175 r
F P
0 g
s
.3758 .794 m .3616 .7689 L .32454 .73648 L p .814 .34 0 r
F P
0 g
s
.78868 .62663 m .78508 .66209 L .77139 .60957 L p .969 .764 .329 r
F P
0 g
s
.77139 .60957 m .77384 .57534 L .78868 .62663 L p .969 .764 .329 r
F P
0 g
s
.40308 .30442 m .4277 .30714 L .48189 .29224 L p .484 .883 .955 r
F P
0 g
s
.4277 .30714 m .40308 .30442 L .35571 .34413 L p .735 .962 .941 r
F P
0 g
s
.26324 .47292 m .2521 .50809 L .27165 .56608 L p .999 .834 .514 r
F P
0 g
s
.26883 .60031 m .27165 .56608 L .2521 .50809 L p .984 .77 .367 r
F P
0 g
s
.67502 .84141 m .65017 .85193 L .68553 .82149 L p .662 .968 .797 r
F P
0 g
s
.68553 .82149 m .71612 .80392 L .67502 .84141 L p .662 .968 .797 r
F P
0 g
s
.32587 .35708 m .35571 .34413 L .40308 .30442 L p .682 .979 .849 r
F P
0 g
s
.49782 .86319 m .48407 .86039 L p .49504 .86261 L 0 .453 .697 r
F P
0 g
s
.53781 .87128 m .54107 .87202 L .49782 .86319 L p 0 .453 .697 r
F P
0 g
s
.53781 .87128 m .49782 .86319 L .49504 .86261 L 0 .453 .697 r
F
.48407 .86039 m .49298 .86368 L .53781 .87128 L p F P
0 g
s
.49298 .86368 m .48407 .86039 L .43473 .83959 L p 0 .327 .673 r
F P
0 g
s
.43473 .83959 m .45313 .84885 L .48374 .86024 L p 0 .327 .673 r
F P
0 g
s
.48374 .86024 m .49298 .86368 L p .48562 .86064 L 0 .327 .673 r
F P
0 g
s
.48562 .86064 m .43473 .83959 L .48374 .86024 L 0 .327 .673 r
F
.54107 .87202 m .53781 .87128 L .58285 .86874 L p .101 .656 .781 r
F P
0 g
s
.58285 .86874 m .59938 .86971 L .54107 .87202 L p .101 .656 .781 r
F P
0 g
s
.76362 .51043 m .77119 .54224 L .74251 .49739 L p .931 .588 .151 r
F P
0 g
s
.74251 .49739 m .73621 .46708 L .76362 .51043 L p .931 .588 .151 r
F P
0 g
s
.59422 .31612 m .6087 .31949 L .54422 .29298 L p 0 .507 .844 r
F P
0 g
s
.54422 .29298 m .54081 .29641 L .59422 .31612 L p 0 .507 .844 r
F P
0 g
s
.27185 .63508 m .28109 .66986 L .31293 .70623 L p .953 .606 .247 r
F P
0 g
s
.32454 .73648 m .31293 .70623 L .28109 .66986 L p .883 .477 .041 r
F P
0 g
s
.71056 .41362 m .7257 .43898 L .68803 .39461 L p .73 .26 0 r
F P
0 g
s
.68803 .39461 m .67462 .3723 L .71056 .41362 L p .73 .26 0 r
F P
0 g
s
.32587 .35708 m .30033 .37787 L .28139 .44179 L p .912 .981 .729 r
F P
0 g
s
.26324 .47292 m .28139 .44179 L .30033 .37787 L p .875 .93 .546 r
F P
0 g
s
.74109 .78034 m .71612 .80392 L .73284 .75883 L p .905 .98 .707 r
F P
0 g
s
.73284 .75883 m .75726 .72914 L .74109 .78034 L p .905 .98 .707 r
F P
0 g
s
.59938 .86971 m .58285 .86874 L .62211 .85523 L p .437 .875 .889 r
F P
0 g
s
.62211 .85523 m .65017 .85193 L .59938 .86971 L p .437 .875 .889 r
F P
0 g
s
.47082 .2861 m .48189 .29224 L .54081 .29641 L p .187 .695 .902 r
F P
0 g
s
.48189 .29224 m .47082 .2861 L .40308 .30442 L p .484 .883 .955 r
F P
0 g
s
.78508 .66209 m .77466 .69656 L .76336 .64464 L p .996 .838 .489 r
F P
0 g
s
.76336 .64464 m .77139 .60957 L .78508 .66209 L p .996 .838 .489 r
F P
0 g
s
.54081 .29641 m .54422 .29298 L .47082 .2861 L p .187 .695 .902 r
F P
0 g
s
.32454 .73648 m .34228 .76493 L .3758 .794 L p .814 .34 0 r
F P
0 g
s
.39555 .81503 m .3758 .794 L .34228 .76493 L p .591 .07 0 r
F P
0 g
s
.3758 .794 m .39555 .81503 L .43473 .83959 L p .622 .071 0 r
F P
0 g
s
.65728 .35525 m .67462 .3723 L .62125 .33034 L p .484 0 0 r
F P
0 g
s
.62125 .33034 m .6087 .31949 L .65728 .35525 L p .484 0 0 r
F P
0 g
s
.2521 .50809 m .24863 .54639 L .26883 .60031 L p .984 .77 .367 r
F P
0 g
s
.27185 .63508 m .26883 .60031 L .24863 .54639 L p .92 .656 .166 r
F P
0 g
s
.45313 .84885 m .43473 .83959 L .39555 .81503 L p 0 .267 .686 r
F P
0 g
s
.77119 .54224 m .77384 .57534 L .74482 .52969 L p .978 .681 .318 r
F P
0 g
s
.74482 .52969 m .74251 .49739 L .77119 .54224 L p .978 .681 .318 r
F P
0 g
s
.28109 .66986 m .29699 .70395 L .32454 .73648 L p .883 .477 .041 r
F P
0 g
s
.34228 .76493 m .32454 .73648 L .29699 .70395 L p .714 .259 0 r
F P
0 g
s
.40308 .30442 m .38005 .30997 L .32587 .35708 L p .682 .979 .849 r
F P
0 g
s
.30033 .37787 m .32587 .35708 L .38005 .30997 L p .498 .846 .579 r
F P
0 g
s
.7257 .43898 m .73621 .46708 L .69755 .42134 L p .882 .463 .049 r
F P
0 g
s
.69755 .42134 m .68803 .39461 L .7257 .43898 L p .882 .463 .049 r
F P
0 g
s
.38005 .30997 m .40308 .30442 L .47082 .2861 L p .21 .729 .711 r
F P
0 g
s
.65017 .85193 m .62211 .85523 L .65025 .83265 L p .717 .975 .924 r
F P
0 g
s
.65025 .83265 m .68553 .82149 L .65017 .85193 L p .717 .975 .924 r
F P
0 g
s
.30033 .37787 m .28071 .40659 L .26324 .47292 L p .875 .93 .546 r
F P
0 g
s
.2521 .50809 m .26324 .47292 L .28071 .40659 L p .736 .763 .259 r
F P
0 g
s
.77466 .69656 m .75726 .72914 L .74908 .68004 L p .991 .879 .613 r
F P
0 g
s
.74908 .68004 m .76336 .64464 L .77466 .69656 L p .991 .879 .613 r
F P
0 g
s
.71612 .80392 m .68553 .82149 L .70165 .78451 L p .888 .98 .821 r
F P
0 g
s
.70165 .78451 m .73284 .75883 L .71612 .80392 L p .888 .98 .821 r
F P
0 g
s
.24863 .54639 m .25324 .58667 L .27185 .63508 L p .92 .656 .166 r
F P
0 g
s
.28109 .66986 m .27185 .63508 L .25324 .58667 L p .78 .472 0 r
F P
0 g
s
.53423 .86322 m .53781 .87128 L .49298 .86368 L p .229 .691 .947 r
F P
0 g
s
.53781 .87128 m .53423 .86322 L .56495 .86081 L p .383 .803 .974 r
F P
0 g
s
.56495 .86081 m .58285 .86874 L .53781 .87128 L p .383 .803 .974 r
F P
0 g
s
.6087 .31949 m .62125 .33034 L .54732 .29782 L p .423 0 0 r
F P
0 g
s
.54732 .29782 m .54422 .29298 L .6087 .31949 L p .423 0 0 r
F P
0 g
s
.50315 .85926 m .49298 .86368 L .45313 .84885 L p .142 .603 .927 r
F P
0 g
s
.49298 .86368 m .50315 .85926 L .53423 .86322 L p .229 .691 .947 r
F P
0 g
s
.34228 .76493 m .36684 .7902 L .39555 .81503 L p .591 .07 0 r
F P
0 g
s
.39555 .81503 m .42109 .83029 L .45313 .84885 L p 0 .267 .686 r
F P
0 g
s
.42109 .83029 m .39555 .81503 L .36684 .7902 L p 0 .267 .731 r
F P
0 g
s
.67462 .3723 m .68803 .39461 L .63147 .34849 L p .749 .235 0 r
F P
0 g
s
.63147 .34849 m .62125 .33034 L .67462 .3723 L p .749 .235 0 r
F P
0 g
s
.77384 .57534 m .77139 .60957 L .74302 .564 L p .991 .74 .442 r
F P
0 g
s
.74302 .564 m .74482 .52969 L .77384 .57534 L p .991 .74 .442 r
F P
0 g
s
.58285 .86874 m .56495 .86081 L .59171 .85176 L p .567 .894 .985 r
F P
0 g
s
.59171 .85176 m .62211 .85523 L .58285 .86874 L p .567 .894 .985 r
F P
0 g
s
.47082 .2861 m .46048 .2885 L .38005 .30997 L p .21 .729 .711 r
F P
0 g
s
.46048 .2885 m .47082 .2861 L .54422 .29298 L p .211 0 0 r
F P
0 g
s
.29699 .70395 m .31992 .73635 L .34228 .76493 L p .714 .259 0 r
F P
0 g
s
.36684 .7902 m .34228 .76493 L .31992 .73635 L p 0 .045 .574 r
F P
0 g
s
.47496 .85027 m .45313 .84885 L .42109 .83029 L p .117 .55 .918 r
F P
0 g
s
.45313 .84885 m .47496 .85027 L .50315 .85926 L p .142 .603 .927 r
F P
0 g
s
.73621 .46708 m .74251 .49739 L .70331 .45184 L p .947 .587 .246 r
F P
0 g
s
.70331 .45184 m .69755 .42134 L .73621 .46708 L p .947 .587 .246 r
F P
0 g
s
.54422 .29298 m .54732 .29782 L .46048 .2885 L p .211 0 0 r
F P
0 g
s
.75726 .72914 m .73284 .75883 L .72788 .71487 L p .964 .898 .709 r
F P
0 g
s
.72788 .71487 m .74908 .68004 L .75726 .72914 L p .964 .898 .709 r
F P
0 g
s
.28071 .40659 m .26849 .44269 L .2521 .50809 L p .736 .763 .259 r
F P
0 g
s
.24863 .54639 m .2521 .50809 L .26849 .44269 L p 0 0 .076 r
F P
0 g
s
.25324 .58667 m .26601 .62765 L .28109 .66986 L p .78 .472 0 r
F P
0 g
s
.29699 .70395 m .28109 .66986 L .26601 .62765 L p 0 0 .371 r
F P
0 g
s
.38005 .30997 m .35995 .32509 L .30033 .37787 L p .498 .846 .579 r
F P
0 g
s
.28071 .40659 m .30033 .37787 L .35995 .32509 L p 0 0 0 r
F P
0 g
s
.68553 .82149 m .65025 .83265 L .66425 .80504 L p .845 .949 .886 r
F P
0 g
s
.66425 .80504 m .70165 .78451 L .68553 .82149 L p .845 .949 .886 r
F P
0 g
s
.77139 .60957 m .76336 .64464 L .73658 .60033 L p .987 .781 .542 r
F P
0 g
s
.73658 .60033 m .74302 .564 L .77139 .60957 L p .987 .781 .542 r
F P
0 g
s
.62211 .85523 m .59171 .85176 L .6113 .8372 L p .713 .925 .963 r
F P
0 g
s
.6113 .8372 m .65025 .83265 L .62211 .85523 L p .713 .925 .963 r
F P
0 g
s
.35995 .32509 m .38005 .30997 L .46048 .2885 L p .151 0 0 r
F P
0 g
s
.36684 .7902 m .39843 .81059 L .42109 .83029 L p 0 .267 .731 r
F P
0 g
s
.45215 .83809 m .42109 .83029 L .39843 .81059 L p .143 .533 .92 r
F P
0 g
s
.42109 .83029 m .45215 .83809 L .47496 .85027 L p .117 .55 .918 r
F P
0 g
s
.68803 .39461 m .69755 .42134 L .63904 .37361 L p .871 .432 .135 r
F P
0 g
s
.63904 .37361 m .63147 .34849 L .68803 .39461 L p .871 .432 .135 r
F P
0 g
s
.74251 .49739 m .74482 .52969 L .70533 .48569 L p .969 .664 .387 r
F P
0 g
s
.70533 .48569 m .70331 .45184 L .74251 .49739 L p .969 .664 .387 r
F P
0 g
s
.62125 .33034 m .63147 .34849 L .54996 .31178 L p .687 .152 0 r
F P
0 g
s
.54996 .31178 m .54732 .29782 L .62125 .33034 L p .687 .152 0 r
F P
0 g
s
.31992 .73635 m .35 .76581 L .36684 .7902 L p 0 .045 .574 r
F P
0 g
s
.39843 .81059 m .36684 .7902 L .35 .76581 L p 0 .34 .814 r
F P
0 g
s
.73284 .75883 m .70165 .78451 L .69938 .74778 L p .925 .899 .783 r
F P
0 g
s
.69938 .74778 m .72788 .71487 L .73284 .75883 L p .925 .899 .783 r
F P
0 g
s
.53037 .84818 m .53423 .86322 L .50315 .85926 L p .459 .768 .996 r
F P
0 g
s
.53423 .86322 m .53037 .84818 L .54603 .84656 L p .53 .816 .998 r
F P
0 g
s
.54603 .84656 m .56495 .86081 L .53423 .86322 L p .53 .816 .998 r
F P
0 g
s
.26601 .62765 m .28672 .66797 L .29699 .70395 L p 0 0 .371 r
F P
0 g
s
.31992 .73635 m .29699 .70395 L .28672 .66797 L p 0 .047 .614 r
F P
0 g
s
.51436 .84685 m .50315 .85926 L .47496 .85027 L p .416 .726 .989 r
F P
0 g
s
.50315 .85926 m .51436 .84685 L .53037 .84818 L p .459 .768 .996 r
F P
0 g
s
.26849 .44269 m .26481 .48498 L .24863 .54639 L p 0 0 .076 r
F P
0 g
s
.25324 .58667 m .24863 .54639 L .26481 .48498 L p 0 0 .359 r
F P
0 g
s
.76336 .64464 m .74908 .68004 L .72469 .63842 L p .97 .809 .626 r
F P
0 g
s
.72469 .63842 m .73658 .60033 L .76336 .64464 L p .97 .809 .626 r
F P
0 g
s
.56495 .86081 m .54603 .84656 L .55962 .84203 L p .615 .852 .988 r
F P
0 g
s
.55962 .84203 m .59171 .85176 L .56495 .86081 L p .615 .852 .988 r
F P
0 g
s
.49966 .84293 m .47496 .85027 L .45215 .83809 L p .4 .698 .981 r
F P
0 g
s
.47496 .85027 m .49966 .84293 L .51436 .84685 L p .416 .726 .989 r
F P
0 g
s
.65025 .83265 m .6113 .8372 L .6216 .81938 L p .791 .905 .921 r
F P
0 g
s
.6216 .81938 m .66425 .80504 L .65025 .83265 L p .791 .905 .921 r
F P
0 g
s
.45146 .30089 m .46048 .2885 L .54732 .29782 L p .513 0 0 r
F P
0 g
s
.46048 .2885 m .45146 .30089 L .35995 .32509 L p .151 0 0 r
F P
0 g
s
.54732 .29782 m .54996 .31178 L .45146 .30089 L p .513 0 0 r
F P
0 g
s
.35995 .32509 m .34426 .35052 L .28071 .40659 L p 0 0 0 r
F P
0 g
s
.26849 .44269 m .28071 .40659 L .34426 .35052 L p .079 0 .198 r
F P
0 g
s
.74482 .52969 m .74302 .564 L .70346 .52266 L p .969 .713 .492 r
F P
0 g
s
.70346 .52266 m .70533 .48569 L .74482 .52969 L p .969 .713 .492 r
F P
0 g
s
.59171 .85176 m .55962 .84203 L .56967 .83511 L p .688 .864 .966 r
F P
0 g
s
.56967 .83511 m .6113 .8372 L .59171 .85176 L p .688 .864 .966 r
F P
0 g
s
.70165 .78451 m .66425 .80504 L .66372 .7771 L p .875 .888 .84 r
F P
0 g
s
.66372 .7771 m .69938 .74778 L .70165 .78451 L p .875 .888 .84 r
F P
0 g
s
.28672 .66797 m .31477 .70623 L .31992 .73635 L p 0 .047 .614 r
F P
0 g
s
.35 .76581 m .31992 .73635 L .31477 .70623 L p 0 .278 .78 r
F P
0 g
s
.35 .76581 m .38689 .79089 L .39843 .81059 L p 0 .34 .814 r
F P
0 g
s
.43654 .82434 m .39843 .81059 L .38689 .79089 L p .227 .547 .929 r
F P
0 g
s
.39843 .81059 m .43654 .82434 L .45215 .83809 L p .143 .533 .92 r
F P
0 g
s
.69755 .42134 m .70331 .45184 L .64369 .40517 L p .914 .548 .321 r
F P
0 g
s
.64369 .40517 m .63904 .37361 L .69755 .42134 L p .914 .548 .321 r
F P
0 g
s
.48776 .83704 m .45215 .83809 L .43654 .82434 L p .405 .682 .974 r
F P
0 g
s
.45215 .83809 m .48776 .83704 L .49966 .84293 L p .4 .698 .981 r
F P
0 g
s
.74908 .68004 m .72788 .71487 L .70652 .67753 L p .944 .827 .698 r
F P
0 g
s
.70652 .67753 m .72469 .63842 L .74908 .68004 L p .944 .827 .698 r
F P
0 g
s
.26481 .48498 m .27021 .53159 L .25324 .58667 L p 0 0 .359 r
F P
0 g
s
.26601 .62765 m .25324 .58667 L .27021 .53159 L p 0 .034 .555 r
F P
0 g
s
.63147 .34849 m .63904 .37361 L .55199 .33527 L p .792 .353 .208 r
F P
0 g
s
.55199 .33527 m .54996 .31178 L .63147 .34849 L p .792 .353 .208 r
F P
0 g
s
.34426 .35052 m .35995 .32509 L .45146 .30089 L p .383 0 .138 r
F P
0 g
s
.6113 .8372 m .56967 .83511 L .57506 .82668 L p .733 .854 .938 r
F P
0 g
s
.57506 .82668 m .6216 .81938 L .6113 .8372 L p .733 .854 .938 r
F P
0 g
s
.74302 .564 m .73658 .60033 L .69736 .56253 L p .957 .745 .575 r
F P
0 g
s
.69736 .56253 m .70346 .52266 L .74302 .564 L p .957 .745 .575 r
F P
0 g
s
.31477 .70623 m .34928 .74112 L .35 .76581 L p 0 .278 .78 r
F P
0 g
s
.38689 .79089 m .35 .76581 L .34928 .74112 L p .193 .453 .877 r
F P
0 g
s
.52632 .82641 m .53037 .84818 L .51436 .84685 L closepath p .581 .775 .971 r
F P
0 g
s
.52632 .82641 m .54603 .84656 L .53037 .84818 L closepath p .602 .79 .971 r
F P
0 g
s
.66425 .80504 m .6216 .81938 L .62178 .80102 L p .818 .867 .883 r
F P
0 g
s
.62178 .80102 m .66372 .7771 L .66425 .80504 L p .818 .867 .883 r
F P
0 g
s
.52632 .82641 m .51436 .84685 L .49966 .84293 L closepath p .572 .763 .969 r
F P
0 g
s
.52632 .82641 m .55962 .84203 L .54603 .84656 L closepath p .63 .801 .965 r
F P
0 g
s
.72788 .71487 m .69938 .74778 L .68152 .71627 L p .91 .836 .759 r
F P
0 g
s
.68152 .71627 m .70652 .67753 L .72788 .71487 L p .91 .836 .759 r
F P
0 g
s
.38689 .79089 m .42967 .81014 L .43654 .82434 L p .227 .547 .929 r
F P
0 g
s
.47986 .82992 m .43654 .82434 L .42967 .81014 L p .43 .675 .965 r
F P
0 g
s
.43654 .82434 m .47986 .82992 L .48776 .83704 L p .405 .682 .974 r
F P
0 g
s
.52632 .82641 m .49966 .84293 L .48776 .83704 L closepath p .57 .757 .966 r
F P
0 g
s
.70331 .45184 m .70533 .48569 L .64519 .44249 L p .924 .619 .447 r
F P
0 g
s
.64519 .44249 m .64369 .40517 L .70331 .45184 L p .924 .619 .447 r
F P
0 g
s
.27021 .53159 m .28453 .58027 L .26601 .62765 L p 0 .034 .555 r
F P
0 g
s
.28672 .66797 m .26601 .62765 L .28453 .58027 L p .125 .212 .684 r
F P
0 g
s
.52632 .82641 m .56967 .83511 L .55962 .84203 L closepath p .656 .804 .954 r
F P
0 g
s
.34426 .35052 m .33441 .38613 L .26849 .44269 L p .079 0 .198 r
F P
0 g
s
.26481 .48498 m .26849 .44269 L .33441 .38613 L p .248 .061 .42 r
F P
0 g
s
.52632 .82641 m .48776 .83704 L .47986 .82992 L closepath p .571 .755 .965 r
F P
0 g
s
.34928 .74112 m .3891 .77145 L .38689 .79089 L p .193 .453 .877 r
F P
0 g
s
.42967 .81014 m .38689 .79089 L .3891 .77145 L p .353 .581 .928 r
F P
0 g
s
.6216 .81938 m .57506 .82668 L .57522 .81786 L p .753 .836 .915 r
F P
0 g
s
.57522 .81786 m .62178 .80102 L .6216 .81938 L p .753 .836 .915 r
F P
0 g
s
.73658 .60033 m .72469 .63842 L .68656 .60481 L p .938 .768 .644 r
F P
0 g
s
.68656 .60481 m .69736 .56253 L .73658 .60033 L p .938 .768 .644 r
F P
0 g
s
.52632 .82641 m .57506 .82668 L .56967 .83511 L closepath p .671 .8 .944 r
F P
0 g
s
.69938 .74778 m .66372 .7771 L .64973 .75273 L p .869 .838 .813 r
F P
0 g
s
.64973 .75273 m .68152 .71627 L .69938 .74778 L p .869 .838 .813 r
F P
0 g
s
.54996 .31178 m .55199 .33527 L .44443 .32419 L p .643 .218 .221 r
F P
0 g
s
.44443 .32419 m .45146 .30089 L .54996 .31178 L p .643 .218 .221 r
F P
0 g
s
.45146 .30089 m .44443 .32419 L .34426 .35052 L p .383 0 .138 r
F P
0 g
s
.42967 .81014 m .47683 .82227 L .47986 .82992 L p .43 .675 .965 r
F P
0 g
s
.52632 .82641 m .47986 .82992 L .47683 .82227 L closepath p .572 .754 .963 r
F P
0 g
s
.28453 .58027 m .30693 .62866 L .28672 .66797 L p .125 .212 .684 r
F P
0 g
s
.31477 .70623 m .28672 .66797 L .30693 .62866 L p .243 .346 .77 r
F P
0 g
s
.63904 .37361 m .64369 .40517 L .55325 .36814 L p .826 .469 .38 r
F P
0 g
s
.55325 .36814 m .55199 .33527 L .63904 .37361 L p .826 .469 .38 r
F P
0 g
s
.3891 .77145 m .43286 .79624 L .42967 .81014 L p .353 .581 .928 r
F P
0 g
s
.47683 .82227 m .42967 .81014 L .43286 .79624 L p .478 .676 .952 r
F P
0 g
s
.52632 .82641 m .57522 .81786 L .57506 .82668 L closepath p .678 .795 .937 r
F P
0 g
s
.70533 .48569 m .70346 .52266 L .64338 .48472 L p .918 .665 .539 r
F P
0 g
s
.64338 .48472 m .64519 .44249 L .70533 .48569 L p .918 .665 .539 r
F P
0 g
s
.66372 .7771 m .62178 .80102 L .61203 .78463 L p .819 .832 .859 r
F P
0 g
s
.61203 .78463 m .64973 .75273 L .66372 .7771 L p .819 .832 .859 r
F P
0 g
s
.72469 .63842 m .70652 .67753 L .67065 .64861 L p .914 .783 .703 r
F P
0 g
s
.67065 .64861 m .68656 .60481 L .72469 .63842 L p .914 .783 .703 r
F P
0 g
s
.33441 .38613 m .34426 .35052 L .44443 .32419 L p .497 .181 .361 r
F P
0 g
s
.43286 .79624 m .4791 .81473 L .47683 .82227 L p .478 .676 .952 r
F P
0 g
s
.52632 .82641 m .47683 .82227 L .4791 .81473 L closepath p .578 .751 .959 r
F P
0 g
s
.52632 .82641 m .56022 .80334 L .57011 .80977 L closepath p .679 .791 .934 r
F P
0 g
s
.52632 .82641 m .54653 .79923 L .56022 .80334 L closepath p .678 .787 .932 r
F P
0 g
s
.52632 .82641 m .53047 .79776 L .54653 .79923 L closepath p .673 .779 .929 r
F P
0 g
s
.52632 .82641 m .51386 .79893 L .53047 .79776 L closepath p .66 .767 .929 r
F P
0 g
s
.52632 .82641 m .49864 .80247 L .51386 .79893 L closepath p .64 .756 .933 r
F P
0 g
s
.52632 .82641 m .48661 .80793 L .49864 .80247 L closepath p .616 .75 .941 r
F P
0 g
s
.52632 .82641 m .4791 .81473 L .48661 .80793 L closepath p .594 .748 .951 r
F P
0 g
s
.52632 .82641 m .57011 .80977 L .57522 .81786 L closepath p .679 .792 .934 r
F P
0 g
s
.62178 .80102 m .57522 .81786 L .57011 .80977 L p .757 .818 .9 r
F P
0 g
s
.57011 .80977 m .61203 .78463 L .62178 .80102 L p .757 .818 .9 r
F P
0 g
s
.30693 .62866 m .33601 .67458 L .31477 .70623 L p .243 .346 .77 r
F P
0 g
s
.34928 .74112 m .31477 .70623 L .33601 .67458 L p .336 .452 .831 r
F P
0 g
s
.33441 .38613 m .33146 .4307 L .26481 .48498 L p .248 .061 .42 r
F P
0 g
s
.27021 .53159 m .26481 .48498 L .33146 .4307 L p .352 .218 .556 r
F P
0 g
s
.44671 .78339 m .48661 .80793 L .4791 .81473 L p .538 .684 .933 r
F P
0 g
s
.4791 .81473 m .43286 .79624 L .44671 .78339 L p .538 .684 .933 r
F P
0 g
s
.70652 .67753 m .68152 .71627 L .64949 .69245 L p .884 .794 .756 r
F P
0 g
s
.64949 .69245 m .67065 .64861 L .70652 .67753 L p .884 .794 .756 r
F P
0 g
s
.33601 .67458 m .37009 .71633 L .34928 .74112 L p .336 .452 .831 r
F P
0 g
s
.3891 .77145 m .34928 .74112 L .37009 .71633 L p .413 .54 .875 r
F P
0 g
s
.70346 .52266 m .69736 .56253 L .63816 .53078 L p .905 .696 .609 r
F P
0 g
s
.63816 .53078 m .64338 .48472 L .70346 .52266 L p .905 .696 .609 r
F P
0 g
s
.61203 .78463 m .57011 .80977 L .56022 .80334 L p .753 .801 .892 r
F P
0 g
s
.40749 .7528 m .44671 .78339 L .43286 .79624 L p .479 .616 .908 r
F P
0 g
s
.43286 .79624 m .3891 .77145 L .40749 .7528 L p .479 .616 .908 r
F P
0 g
s
.37009 .71633 m .40749 .7528 L .3891 .77145 L p .413 .54 .875 r
F P
0 g
s
.64369 .40517 m .64519 .44249 L .55363 .40948 L p .834 .54 .491 r
F P
0 g
s
.55363 .40948 m .55325 .36814 L .64369 .40517 L p .834 .54 .491 r
F P
0 g
s
.68152 .71627 m .64973 .75273 L .62337 .73436 L p .849 .8 .803 r
F P
0 g
s
.62337 .73436 m .64949 .69245 L .68152 .71627 L p .849 .8 .803 r
F P
0 g
s
.47039 .77261 m .49864 .80247 L .48661 .80793 L p .598 .698 .913 r
F P
0 g
s
.48661 .80793 m .44671 .78339 L .47039 .77261 L p .598 .698 .913 r
F P
0 g
s
.55199 .33527 m .55325 .36814 L .44001 .35847 L p .695 .355 .397 r
F P
0 g
s
.44001 .35847 m .44443 .32419 L .55199 .33527 L p .695 .355 .397 r
F P
0 g
s
.64973 .75273 m .61203 .78463 L .59315 .77206 L p .806 .803 .848 r
F P
0 g
s
.56022 .80334 m .59315 .77206 L .61203 .78463 L p .753 .801 .892 r
F P
0 g
s
.59315 .77206 m .56022 .80334 L .54653 .79923 L p .741 .784 .887 r
F P
0 g
s
.59315 .77206 m .62337 .73436 L .64973 .75273 L p .806 .803 .848 r
F P
0 g
s
.33146 .4307 m .33591 .482 L .27021 .53159 L p .352 .218 .556 r
F P
0 g
s
.28453 .58027 m .27021 .53159 L .33591 .482 L p .419 .329 .647 r
F P
0 g
s
.44443 .32419 m .44001 .35847 L .33441 .38613 L p .497 .181 .361 r
F P
0 g
s
.50112 .76516 m .51386 .79893 L .49864 .80247 L p .649 .717 .897 r
F P
0 g
s
.49864 .80247 m .47039 .77261 L .50112 .76516 L p .649 .717 .897 r
F P
0 g
s
.69736 .56253 m .68656 .60481 L .62955 .57934 L p .889 .719 .666 r
F P
0 g
s
.62955 .57934 m .63816 .53078 L .69736 .56253 L p .889 .719 .666 r
F P
0 g
s
.54653 .79923 m .56658 .76443 L .59315 .77206 L p .741 .784 .887 r
F P
0 g
s
.56658 .76443 m .54653 .79923 L .53047 .79776 L p .721 .763 .886 r
F P
0 g
s
.53468 .76218 m .53047 .79776 L .51386 .79893 L p .69 .739 .888 r
F P
0 g
s
.51386 .79893 m .50112 .76516 L .53468 .76218 L p .69 .739 .888 r
F P
0 g
s
.33146 .4307 m .33441 .38613 L .44001 .35847 L p .556 .308 .495 r
F P
0 g
s
.53047 .79776 m .53468 .76218 L .56658 .76443 L p .721 .763 .886 r
F P
0 g
s
.44198 .7365 m .47039 .77261 L .44671 .78339 L p .578 .647 .882 r
F P
0 g
s
.44671 .78339 m .40749 .7528 L .44198 .7365 L p .578 .647 .882 r
F P
0 g
s
.62337 .73436 m .59315 .77206 L .56658 .76443 L p .785 .775 .844 r
F P
0 g
s
.33591 .482 m .34754 .53702 L .28453 .58027 L p .419 .329 .647 r
F P
0 g
s
.30693 .62866 m .28453 .58027 L .34754 .53702 L p .467 .413 .714 r
F P
0 g
s
.68656 .60481 m .67065 .64861 L .61768 .62884 L p .868 .737 .715 r
F P
0 g
s
.61768 .62884 m .62955 .57934 L .68656 .60481 L p .868 .737 .715 r
F P
0 g
s
.64519 .44249 m .64338 .48472 L .55309 .45771 L p .832 .588 .57 r
F P
0 g
s
.55309 .45771 m .55363 .40948 L .64519 .44249 L p .832 .588 .57 r
F P
0 g
s
.41419 .69402 m .44198 .7365 L .40749 .7528 L p .556 .596 .848 r
F P
0 g
s
.40749 .7528 m .37009 .71633 L .41419 .69402 L p .556 .596 .848 r
F P
0 g
s
.64949 .69245 m .62337 .73436 L .58562 .72329 L p .818 .764 .802 r
F P
0 g
s
.56658 .76443 m .58562 .72329 L .62337 .73436 L p .785 .775 .844 r
F P
0 g
s
.67065 .64861 m .64949 .69245 L .60287 .67746 L p .845 .752 .76 r
F P
0 g
s
.60287 .67746 m .61768 .62884 L .67065 .64861 L p .845 .752 .76 r
F P
0 g
s
.34754 .53702 m .36543 .59254 L .30693 .62866 L p .467 .413 .714 r
F P
0 g
s
.33601 .67458 m .30693 .62866 L .36543 .59254 L p .503 .482 .766 r
F P
0 g
s
.4883 .72492 m .50112 .76516 L .47039 .77261 L p .652 .678 .862 r
F P
0 g
s
.47039 .77261 m .44198 .7365 L .4883 .72492 L p .652 .678 .862 r
F P
0 g
s
.58562 .72329 m .60287 .67746 L .64949 .69245 L p .818 .764 .802 r
F P
0 g
s
.58562 .72329 m .56658 .76443 L .53468 .76218 L p .753 .744 .844 r
F P
0 g
s
.55325 .36814 m .55363 .40948 L .43869 .40266 L p .717 .441 .507 r
F P
0 g
s
.43869 .40266 m .44001 .35847 L .55325 .36814 L p .717 .441 .507 r
F P
0 g
s
.38818 .64561 m .41419 .69402 L .37009 .71633 L p .532 .541 .81 r
F P
0 g
s
.37009 .71633 m .33601 .67458 L .38818 .64561 L p .532 .541 .81 r
F P
0 g
s
.36543 .59254 m .38818 .64561 L .33601 .67458 L p .503 .482 .766 r
F P
0 g
s
.53882 .72015 m .53468 .76218 L .50112 .76516 L p .709 .71 .849 r
F P
0 g
s
.50112 .76516 m .4883 .72492 L .53882 .72015 L p .709 .71 .849 r
F P
0 g
s
.53468 .76218 m .53882 .72015 L .58562 .72329 L p .753 .744 .844 r
F P
0 g
s
.44001 .35847 m .43869 .40266 L .33146 .4307 L p .556 .308 .495 r
F P
0 g
s
.33591 .482 m .33146 .4307 L .43869 .40266 L p .59 .394 .584 r
F P
0 g
s
.64338 .48472 m .63816 .53078 L .55163 .51061 L p .826 .625 .63 r
F P
0 g
s
.55163 .51061 m .55309 .45771 L .64338 .48472 L p .826 .625 .63 r
F P
0 g
s
.60287 .67746 m .58562 .72329 L .53882 .72015 L p .776 .723 .804 r
F P
0 g
s
.47579 .67829 m .4883 .72492 L .44198 .7365 L p .651 .639 .825 r
F P
0 g
s
.44198 .7365 m .41419 .69402 L .47579 .67829 L p .651 .639 .825 r
F P
0 g
s
.63816 .53078 m .62955 .57934 L .54932 .56567 L p .817 .654 .68 r
F P
0 g
s
.54932 .56567 m .55163 .51061 L .63816 .53078 L p .817 .654 .68 r
F P
0 g
s
.55363 .40948 m .55309 .45771 L .44067 .45462 L p .727 .501 .584 r
F P
0 g
s
.44067 .45462 m .43869 .40266 L .55363 .40948 L p .727 .501 .584 r
F P
0 g
s
.61768 .62884 m .60287 .67746 L .54275 .67246 L p .793 .702 .765 r
F P
0 g
s
.53882 .72015 m .54275 .67246 L .60287 .67746 L p .776 .723 .804 r
F P
0 g
s
.43869 .40266 m .44067 .45462 L .33591 .482 L p .59 .394 .584 r
F P
0 g
s
.34754 .53702 m .33591 .482 L .44067 .45462 L p .613 .459 .65 r
F P
0 g
s
.54275 .67246 m .53882 .72015 L .4883 .72492 L p .721 .681 .811 r
F P
0 g
s
.62955 .57934 m .61768 .62884 L .54631 .62037 L p .806 .679 .724 r
F P
0 g
s
.54631 .62037 m .54932 .56567 L .62955 .57934 L p .806 .679 .724 r
F P
0 g
s
.4883 .72492 m .47579 .67829 L .54275 .67246 L p .721 .681 .811 r
F P
0 g
s
.54275 .67246 m .54631 .62037 L .61768 .62884 L p .793 .702 .765 r
F P
0 g
s
.46409 .62597 m .47579 .67829 L .41419 .69402 L p .646 .599 .787 r
F P
0 g
s
.41419 .69402 m .38818 .64561 L .46409 .62597 L p .646 .599 .787 r
F P
0 g
s
.44067 .45462 m .44587 .51135 L .34754 .53702 L p .613 .459 .65 r
F P
0 g
s
.36543 .59254 m .34754 .53702 L .44587 .51135 L p .628 .512 .702 r
F P
0 g
s
.45389 .56951 m .46409 .62597 L .38818 .64561 L p .639 .558 .747 r
F P
0 g
s
.38818 .64561 m .36543 .59254 L .45389 .56951 L p .639 .558 .747 r
F P
0 g
s
.55309 .45771 m .55163 .51061 L .44587 .51135 L p .731 .547 .642 r
F P
0 g
s
.44587 .51135 m .44067 .45462 L .55309 .45771 L p .731 .547 .642 r
F P
0 g
s
.44587 .51135 m .45389 .56951 L .36543 .59254 L p .628 .512 .702 r
F P
0 g
s
.54631 .62037 m .54275 .67246 L .47579 .67829 L p .728 .651 .773 r
F P
0 g
s
.47579 .67829 m .46409 .62597 L .54631 .62037 L p .728 .651 .773 r
F P
0 g
s
.55163 .51061 m .54932 .56567 L .45389 .56951 L p .733 .585 .69 r
F P
0 g
s
.45389 .56951 m .44587 .51135 L .55163 .51061 L p .733 .585 .69 r
F P
0 g
s
.54932 .56567 m .54631 .62037 L .46409 .62597 L p .731 .619 .733 r
F P
0 g
s
.46409 .62597 m .45389 .56951 L .54932 .56567 L p .731 .619 .733 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Wooooo`Wo0000?Oooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo000Qooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06;ooooo2_l00003ocH000_o0000<_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02gooooo000Sooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Mooooo`Co000000?o9P00o`000?n30000
1on3000=o`000003ocH00?l0003o000000Co0000;?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02cooooo000Hooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0F?ooool4o`0000Co9P0000?o0000oh<00?n300005?n3
000:o`0002Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`008oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0D_ooool5
o`0000Go9P001ol0000Ioh<00003o`000?n_9P3o000000Co00009_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l0000Boooo
o`03o`000?oooooooooo04gooooo1?l00007obH000?o00000_mR02<00ol0003oY3Lhoj@g>002oj@g
>0So00004On300001?l0003o[bH0ojlV0?n_9P02o`000003of`00?l0003o000002Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B?ooool4o`0000Oo9P001?l00005of80
8`03o`000?nT=cSoY3Lh00[oY3Lh1ol0000;oh<00003o`000?n_9P3o[bH000;o[bH01_l0000Qoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:_ooool002?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Cooooo0ol00008obH000?o
00002?mR02<00ol0003oY3Lhoj@g>00Boj@g>0So00000on300000ol0003o[bH0ojlV0005ojlV00;o
000000?oK000o`000?l000007oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wo
oooo000Qooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`12ooooo`03o`000?lV003o9P0000Go9P001?l0000;of808`03o`000?nT=cSoY3Lh01[oY3Lh
1Ol00008ojlV00;o000000CoK000o`000?l0003o00007?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02Wooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
@?ooool00ol0003o9P00obH00003obH000?o00003omR02<00ol0003oY3Lhoj@g>00Moj@g>003o`00
0?o:FSGo000000;o00001on_9P02o`0000;oK0000ol0000Iooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0nooooo`03o`000?lV003o9P0000Co00004_mR02<00ol0003oY3Lhoj@g>00Moj@g>003o`000?o:
FSGobUXe00;obUXe0_l00007ojlV00;o00000om/0002o`0001Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03cooooo1?l0000Eof808`03o`000?nT=cSoY3Lh01koY3Lh00?o0000olYJ=Oo:FSD01?o:FSD2
o`0000Oo[bH00ol000000om/003o0000o`00000Fooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool09oooool002Wooooo0_l0000Jooooo`03o`000?oooooooooo03Wooooo0ol0000Fof80
8`Wo00006onT=cP00ol0003obUXeolYJ=@05olYJ=@?o00001on_9P04o`0001Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo03Oooooo0ol0000Cof808`Co00000_mo;U`00ol0003o/EYUok5JI@04ok5JI@_o
00004?nT=cP00ol0003obUXeolYJ=@08olYJ=@;o00001on_9P04o`0001Cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo03Gooooo0ol0000@of808`Co00001_mo;U`00ol0003o/EYUok5JI@0?ok5JI@_o0000
1OnT=cP00ol0003obUXeolYJ=@0:olYJ=@;o00001on_9P03o`0001?ooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Uooooo`00:Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo03?ooooo0ol0000=of808`Co00002_mo;U`00ol0003o/EYUok5JI@0Jok5JI@Oo00003Oo:
FSD3o`0000Co[bH000?o0000okll0?l000000_l0000Aooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0a
ooooo`Co00002_mR02<3o`0000koObiL00?o0000ok5JIOnaFVD07onaFVD01?l0003odgQQo`000?l0
000>olYJ=@;o00000on_9P001Ol0003o_c`0o`000?mk003o0000013ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02oooooo1?l00007of808`Co00004Omo;U`00ol0003o/EYUok5JI@0Ook5JI@04o`000?oC
N67odgQQom=hH@?o00003Oo:FSD2o`0000;o[bH000Go0000okll0?l0003oN`00o`00000?ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo0_l0000Qooooo`03o`00
0?oooooooooo02gooooo1Ol00003of808`Co00005?mo;U`00ol0003o/EYUok5JI@0Pok5JI@03o`00
0?oCN67odgQQ00CodgQQ0_l0000=olYJ=@?o00000_no?004o`0000gooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Sooooo`00:?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo02_ooooo2Ol0000Hogl^G003o`000?naFVGo/EYU023o/EYU00?o0000om=hHOoCN6401_oC
N642o`0000kobUXe0_l00002okll0003o`000?mk003o000000cooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Rooooo`00:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo02Sooooo1ol0000Logl^G003o`000?naFVGo/EYU023o/EYU00?o0000om=hHOoCN6402?oCN642
o`0000cobUXe00?o0000omi^8_l000000_no?0000ol0003oN`00o`00000;ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08Oooool002Sooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Vooooo`Go000000?o500bo`000?mo;U`07?mo;U`00ol0003o/EYUok5JI@0Pok5J
I@03o`000?oCN67odgQQ00[odgQQ0ol00009olYJ=@04o`000?oNKR;ogVhRo`0000;o_c`000?o0000
og/00?l000002_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo000Woooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool5o`0000;o500b00?o0000ogl^
G?mo;U`06Omo;U`9o`0001co/EYU00?o0000om=hHOoCN6403OoCN642o`0000SobUXe00Co0000omi^
8_oNKR;o00000_no?002o`0000[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0P
ooooo`009oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02;ooooo1Ol00002oa@0
<P03o`000?mo;UcoObiL01KoObiL1?l00002ohi>OP03o`000?ngL87o]g2100Co]g213?l0000@ok5J
I@03o`000?oCN67odgQQ00oodgQQ0_l00006olYJ=@05o`000?oNKR;ogVhRomi^8_l000000_no?002
o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`009oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo023ooooo1Ol00003oa@0<P03o`000?mo;UcoObiL
01?oObiL0ol00006ohi>OP03o`000?ngL87o]g21013o]g212ol00005ok5JI@03o`000?oCN67odgQQ
017odgQQ0_l00004olYJ=@03o`000?oNKR;ogVhR00;ogVhR00Go0000okll0?no?03o_c`0o`000008
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07oooool002Oooooo0_l0000Yoooo
o`03o`000?oooooooooo01kooooo1Ol00004oa@0<P03o`000?mo;UcoObiL00ooObiL1?l00009ohi>
OP03o`000?ngL87o]g2101_o]g211ol0000Dom=hH@?o000000?obUXeo`000?oNKR801?oNKR801Ol0
003o_c`0okll0?no?03o000000Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0N
ooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo1Ol00004oa@0
<P03o`000?mo;UcoObiL00coObiL1?l0000=ohi>OP03o`000?ngL87o]g21023o]g2100?o0000omF:
OOl000000_l0000Dom=hH@?o00001OoNKR82o`0000;o_c`000?o0000ooooooooool01?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06_ooool5o`0000Go500b00?o0000ogl^G?mo;U`02Omo;U`3o`00017o
STin00?o0000okM`POngL8408?ngL8400ol0003oeHYmomF:O@02omF:O@;o00005?oCN642o`0000Ko
gVhR00Co0000okll0?no?03o00001Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool06?ooool5o`0000Ko
500b00?o0000ogl^G?mo;U`01Omo;U`4o`0001CoSTin00?o0000okM`POngL8408?ngL8400ol0003o
eHYmomF:O@04omF:O@;o00004_oCN6400ol0003ojHaBo`000006omi^8P03o`000?no?03o000000Go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Mooooo`009_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo01Kooooo1Ol00007oa@0<P04o`000?mo;UcoObiLogl^G0Co
00006?n>CWh00ol0003o]g21okM`P@0PokM`P@03o`000?oERWgoeHYm00KoeHYm0ol0000?om=hH@04
o`000?oYS5;ojHaBo`0000KogVhR00?o0000okll0?l000001?ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01cooooo000Vooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool05Oooool3o`0000So500b00?o0000ogl^G?l000000_l0000Kohi>OP03o`000?ngL87o]g21027o
]g2100?o0000omF:OOoERWd02OoERWd2o`0000kodgQQ00Co0000onV<D_oYS5;o00001_oNKR83o`00
00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Kooooo`009_ooool3o`0002oo
oooo00?o0000ooooooooool04oooool3o`0000So500b0ol0000Nohi>OP03o`000?ngL87o]g21027o
]g2100?o0000omF:OOoERWd02ooERWd3o`0000_odgQQ00Go0000onV<D_oYS5;ojHaBo`000006omi^
8P?o00000oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01_ooooo000Vooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04Oooool3o`0000So500b00?o0000ocl?Jol0
00007on>CWh00ol0003o]g21okM`P@0QokM`P@03o`000?oERWgoeHYm00koeHYm0_l00009om=hH@03
o`000?oYS5;ojHaB00;ojHaB0_l00005omi^8P?o00000_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04?ooool2o`0000So500b00Co0000ocl?Jolo3f_o00007on>CWh00ol0003o]g21okM`P@0Q
okM`P@03o`000?oERWgoeHYm013oeHYm0ol00006om=hH@03o`000?oYS5;ojHaB00CojHaB00?o0000
omi^8_oNKR800ooNKR801Ol0003o^T80o`000?oooooo000004;ooooo00?o0000ooooooooool06_oo
ool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8boooo
o`04ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03_ooool2o`0000So500b00Go
0000ocl?Jolo3f_o?`m[o`00000Oohi>OP03o`000?ngL87o]g21027o]g2100?o0000omF:OOoERWd0
4ooERWd2o`0000CodgQQ00?o0000onV<D_oYS5801OoYS5800ol0003ogVhRomi^8P03omi^8P04o`00
0?nj@P3o0000o`0004?ooooo00?o0000ooooooooool06Oooool000?ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool03?ooool2o`0000So500b00?o0000ocl?Jolo3f/00_lo3f/00ol0003o
STinohi>OP0Mohi>OP03o`000?ngL87o]g21027o]g2100?o0000omF:OOoERWd05OoERWd2o`0000?o
dgQQ00?o0000onV<D_oYS5801OoYS5800ol0003ogVhRomi^8P02omi^8P04o`000?nj@P3o^T80o`00
04Cooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;oooo
o`03o`000?lD03;o500b00Ko500b00?o0000ocl?Jolo3f/00olo3f/00ol0003oSTinohi>OP0Kohi>
OPco00006_ngL8400ol0003oeHYmomF:O@0GomF:O@Co00002?oYS5800ol0003ogVhRomi^8P02omi^
8P04o`000?nj@P3o0000o`0004?ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Wooooo00?o0000oa@0<_lD03801OlD0382o`0000Ko?`m[00?o
0000ohi>O_n>CWh05on>CWh4o`0000;oUfBE00?o0000okZ0UOnjP9D01onjP9DBo`0000So]g2100?o
0000omF:OOoERWd06_oERWd2o`0000SojHaB0_l00002omi^8P?o000000?o^T80o`000?ooool0@_oo
ool00ol0003oooooooooo`0Gooooo`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool2o`0003Sooooo00?o0000ooooooooool01oooool00ol0003o500boa@0
<P05oa@0<P03o`000?lo3f_o?`m[00Ko?`m[00?o0000ohi>O_n>CWh05?n>CWh3o`0000KoUfBE00?o
0000okZ0UOnjP9D06OnjP9D:o`0001_oeHYm00?o0000onbNL_l000002OoYS5801Ol0003ogVhRo`00
0?oQMPco000000;o^T8000?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`002ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000oa@0<_lD03801?lD03800ol0003o?`m[
ocl?J`06ocl?J`03o`000?n>CWkoSTin017oSTin1?l00009oiMTU@03o`000?njP9Go^X2E027o^X2E
00?o0000omBFTOl000000_l0000HomF:O@04o`000?o/WW;ok9ibo`0000WojHaB00?o0000omi^8_l0
00000_l00002okY20003o`000?oooooooooo043ooooo00?o0000ooooooooool05_ooool000_ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Cooooo00?o0000oa@0<_lD03801?lD03800ol0003o?`m[ocl?J`07ocl?J`03
o`000?n>CWkoSTin00goSTin1?l0000=oiMTU@03o`000?njP9Go^X2E027o^X2E00?o0000omBFTOoD
UY400_oDUY43o`0001GoeHYm00Go0000onbNL_o/WW;ok9ibo`000009onV<DP?o000000GohGH<o`00
0?nj@P3o^T80o`000010ooooo`?o00005oooool002Cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`04ooooo`03o`000?lD03;o500b00?o500b00?o0000ocl?Jolo3f/02?lo3f/00ol0
003oSTinohi>OP0:ohi>OP?o00004OnGI9D00ol0003o^X2EokZ0U@0QokZ0U@03o`000?oDUY7oe9JA
00Goe9JA0_l0000ComF:O@03o`000?o/WW;ok9ib00;ok9ib00?o0000onV<D_oYS5801ooYS582o`00
00;ohGH<00?o0000okY20?l00000?Oooool3o`0000;ooooo00?o0000ooooooooool05Oooool002Co
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03o`000?lD03;o500b00;o
500b00?o0000ocl?Jolo3f/02Olo3f/00ol0003oSTinohi>OP06ohi>OPCo00005?nGI9D00ol0003o
^X2EokZ0U@0QokZ0U@03o`000?oDUY7oe9JA00Ooe9JA0ol0000@omF:O@03o`000?o/WW;ok9ib00?o
k9ib0_l00008onV<DP04o`000?oQMPcohGH<o`0000;o^T8000?o0000ooooooooool0=oooool3o`00
00Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0??ooool01Ol0003o
oooooooooooooooo000000?o500b0_l0000<ocl?J`03o`000?n>CWkoSTin00;oSTin1?l0000HoiMT
U@03o`000?njP9Go^X2E027o^X2E00?o0000omBFTOoDUY402_oDUY43o`0000goeHYm00?o0000onbN
L_o/WW801Oo/WW800ol0003ojHaBonV<DP05onV<DP07o`000?oQMPcohGH<on5f3?l0003o^T80o`00
000fooooo`?o00002?ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0m
ooooo`04o`000?ooooooooooo`0000;o500b00?o0000ocl?Jolo3f/03?lo3f/00ol0003oSTino`00
0002o`0001coUfBE00?o0000okZ0UOnjP9D08OnjP9D00ol0003oe9JAomBFT@0=omBFT@;o00002ooE
RWd00ol0003ok9ibonbNLP06onbNLP03o`000?oYS5;ojHaB00CojHaB0_l00003on5f3003o`000?nj
@P3o000003;ooooo0ol0000;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool0
1Ol0003oooooo`000?lD03;o000000ko?`m[0ol0000PoiMTU@03o`000?njP9Go^X2E023o^X2E00?o
0000omBFTOoDUY403ooDUY43o`0000SoeHYm00?o0000onbNL_o/WW801oo/WW800ol0003ojHaBonV<
DP03onV<DP?o00000ooQMP`3o`0002kooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000T
ooooo`03o`000?oooooooooo03oooooo00?o0000oa@0<_l000003_lo3f/00ol0003oFSN>o`00000Q
oiMTU@03o`000?njP9Go^X2E023o^X2E00?o0000omBFTOoDUY404_oDUY42o`0000KoeHYm00?o0000
onbNL_o/WW802?o/WW800ol0003ojHaBonV<DP02onV<DP;o000000?olYHno`000?oQMP`00_oQMP`2
o`0002_ooooo0ol0000Booooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo
043ooooo0_l0000>ocl?J`04o`000?mJ=hkoFSN>o`00027oUfBE00?o0000okZ0UOnjP9D08?njP9D0
0ol0003oe9JAomBFT@0DomBFT@?o00000ooERWd00ol0003ok9ibonbNLP09onbNLP;o00000_oYS582
o`0000;olYHn00Co0000on5f3?oQMPcohGH<0_l0000Wooooo`?o00005Oooool00ol0003ooooooooo
o`0Dooooo`008oooool00ol0003oooooooooo`10ooooo`03o`000?lo3f_o?`m[00co?`m[00Go0000
oeXgS_mJ=hkoFSN>o`00000QoiMTU@03o`000?njP9Go^X2E023o^X2E00?o0000omBFTOoDUY405ooD
UY44o`0000gok9ib00Co0000onV<D_l0003o00000oobUSh01Ol0003ohGH<on5f3?oQMPco000002Co
oooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03oooooo
00?o0000ocl?Jolo3f/02olo3f/2o`0000CoFSN>00?o0000oiMTUOnGI9D07onGI9D00ol0003o^X2E
okZ0U@0PokZ0U@03o`000?oDUY7oe9JA01[oe9JA0_l0000=onbNLP03o`000?oYS5;o000000ColYHn
00?o0000on5f3?oQMP`00_l0000Pooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008ooo
ool00ol0003oooooooooo`0oooooo`03o`000?lo3f_o?`m[00[o?`m[00?o0000oeXgS_mJ=hh01?mJ
=hh00ol0003oUfBEoiMTU@0OoiMTU@03o`000?njP9Go^X2E023o^X2E00?o0000omBFTOoDUY406_oD
UY400ol0003ojjZ9o`00000=onbNLP?o00001?obUSh00ol0003ohGH<on5f3002o`0001cooooo0ol0
000Nooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo03oooooo00?o0000
ocl?Jolo3f/02Olo3f/00ol0003oFSN>oeXgSP05oeXgSP03o`000?nGI9GoUfBE01ooUfBE00?o0000
okZ0UOnjP9D08?njP9D00ol0003oe9JAomBFT@0JomBFT@03o`000?o[ZXWojjZ900;o00003?o/WW82
o`0000GolYHn00Co0000on5f3?l0003o00006Oooool3o`00027ooooo00?o0000ooooooooool05?oo
ool002?ooooo0_l0000oooooo`;o00002_lo3f/00ol0003oFSN>oeXgSP06oeXgSP03o`000?nGI9Go
UfBE01ooUfBE00?o0000okZ0UOnjP9D08?njP9D00ol0003oe9JAomBFT@0JomBFT@03o`000?o[ZXWo
jjZ900;ojjZ900?o0000onbNL_o/WW802Oo/WW82o`0000KolYHn00Co0000on5f3?l0003o00005Ooo
ool3o`0002Gooooo00?o0000ooooooooool04oooool002?ooooo00?o0000ooooooooool0?_ooool2
o`0000So?`m[0_l00009oeXgSP03o`000?nGI9GoUfBE01goUfBE5Ol0000@okZ0U@03o`000?oDUY7o
e9JA01[oe9JA00?o0000on^ZROo[ZXT00oo[ZXT2o`0000Wok9ib0_l00007oo:F?P?o00004_ooool3
o`0002Sooooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0?oooool00ol0
01?o0000ocl?J`06ocl?J`03o`000?mJ=hkoFSN>00[oFSN>00?o0000oiMTUOnGI9D06?nGI9D4o`00
00;oW7FV00?o0000ok^<Y?nkS:@04?nkS:@Co`0001[oe9JA00?o0000on^ZROo[ZXT01Oo[ZXT00ol0
003ok9ibonbNLP06onbNLP?o00001oobUSh3o`0000kooooo0ol0000[ooooo`03o`000?oooooooooo
01?ooooo000Rooooo`03o`000?oooooooooo03oooooo00?o000Co`000?lo3f/01Olo3f/00ol0003o
FSN>oeXgSP0;oeXgSP03o`000?nGI9GoUfBE01CoUfBE1?l00006oiaeYP03o`000?nkS:Co^hbT023o
^hbT00?o0000om>OXOoCWj400ol0000GomBFT@03o`000?o[ZXWojjZ900KojjZ90_l00006onbNLP;o
000000?on:USo`000?obUSh01_obUSh2o`0000_ooooo0ol0000^ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo03kooooo0_l00006ocl?J`03o`000?mJ=hkoFSN>00coFSN>
00?o0000oiMTUOnGI9D04?nGI9D4o`0000[oW7FV00?o0000ok^<Y?nkS:@08?nkS:@00ol0003odinQ
om>OX@03om>OX@Co00004ooDUY400ol0003ojjZ9on^ZR@08on^ZR@03o`000?o/WW;ok9ib00?ok9ib
0_l00002ooRYH`03o`000?obUSkolYHn00GolYHn0_l00007ooooo`?o0000<Oooool00ol0003ooooo
ooooo`0Cooooo`008_ooool00ol0003oooooooooo`0nooooo`;o00001Olo3f/00ol0003oFSN>oeXg
SP0=oeXgSP03o`000?nGI9GoUfBE00_oUfBE1Ol0000>oiaeYP03o`000?nkS:Co^hbT023o^hbT00?o
0000om>OXOoCWj401ooCWj44o`0000ooe9JA00?o0000on^ZROo[ZXT02Oo[ZXT00ol0003ok9ibonbN
LP02onbNLP;o00000oohZF<00ol0003olYHnoo:F?P04oo:F?P?o00000_ooool4o`0003Cooooo00?o
0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0?_ooool2o`0000?o?`m[0_l0000@
oeXgSP03o`000?nGI9GoUfBE00OoUfBE1?l0000DoiaeYP03o`000?nkS:Co^hbT01oo^hbT00?o0000
om>OXOoCWj402ooCWj43o`0000coe9JA00?o0000on^ZROo[ZXT02_o[ZXT2o`0000;ok9ib00?o0000
onbNL_l000000oohZF<00ol0003olYHnoo:F?P03oo:F?PGo0000>?ooool00ol0003oooooooooo`0C
ooooo`008Oooool3o`0003oooooo00Go000Co`000?lo3f_o?`m[o`00000BoeXgSP03o`000?nGI9Go
UfBE00?oUfBE1?l0000HoiaeYP03o`000?nkS:Co^hbT01oo^hbT00?o0000om>OXOoCWj403_oCWj44
o`0000Soe9JA00?o0000on^ZROo[ZXT03?o[ZXT01Ol0003ok9ibo`000?o/WW;o000000Con:US00?o
0000oo:F?_obUSh00oobUSh3o`0003[ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000
ooooooooool0?_ooool01Ol0003o000Co`000?lo3f_o000001?oFSN>00?o0000oiMTUOl000000ol0
000LoiaeYP03o`000?nkS:Co^hbT01oo^hbT00?o0000om>OXOoCWj404_oCWj44o`0000Coe9JA00?o
0000on^ZROo[ZXT03Oo[ZXT2o`000003onbNL_l0003on:US00Con:US00?o0000oo:F?_obUSh00_ob
USh3o`0003[ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0?_ooool0
1?l0003o000Co`000?l0000CoeXgSP?o00008?nLMJH00ol0003o^hbTok^<Y00Ook^<Y003o`000?oC
Wj7odinQ01KodinQ0ol000000ooDUY7o0000on^ZR@0?on^ZR@?o00001_ohZF<01_l0003olYHnoo:F
?_obUSko0000onjF9P;o0000>Oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?l001?o000001?oFSN>00?o0000of]DYOl000008OnLMJH00ol0003o^hbT
ok^<Y00Ook^<Y003o`000?oCWj7odinQ01WodinQ0ol0000?on^ZR@03o`000?o[ZXWo000000Oon:US
00Go0000oo:F?_obUSko0000onjF9P02o`0003Wooooo00?o0000ooooooooool04_ooool0027ooooo
00?o0000ooooooooool0?_ooool00ol0003o000Co`00000BoeXgSP04o`000?m[E:GoJeBUo`00027o
W7FV00?o0000ok^<Y?nkS:@07onkS:@00ol0003odinQom>OX@0Jom>OX@03o`000?oW/Y_o000000ko
jjZ900?o0000on^ZROl000002?ohZF<00ol0003olYHno`000002onjF9P;o0000>?ooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`0mooooo`04o`000?l001?o000Co`00017o
FSN>00?o0000of]DYOm[E:D00_m[E:D00ol0003oW7FVoiaeYP0NoiaeYP03o`000?nkS:Co^hbT01oo
^hbT00?o0000om>OXOoCWj406_oCWj400ol0003oik:KonNbV`02o`0000cojjZ900Co0000on^ZROl0
003o00002?ohZF<01?l0003olYHno`000?o^URH2o`0003Sooooo00?o0000ooooooooool04_ooool0
027ooooo00?o0000ooooooooool0?Oooool01?l0003o000Co`000?l0000?oeXgSP;o00001Om[E:D0
0ol0003oW7FVoiaeYP0NoiaeYP03o`000?nkS:Co^hbT01oo^hbT00?o0000om>OXOoCWj406_oCWj40
0ol0003oik:KonNbV`02onNbV`03o`000?o[ZXWojjZ900WojjZ900Go0000on^ZROl0003on;Imo`00
0008ooRYH`;o00000_o^URH2o`0003Oooooo00?o0000ooooooooool04_ooool0023ooooo0ol0000n
ooooo`04o`000?l001?o0000o`0000koFSN>00?o0000of]DYOm[E:D01Om[E:D00ol0003oW7FVoiae
YP0NoiaeYP03o`000?nkS:Co^hbT01oo^hbT00?o0000om>OXOoCWj406OoCWj400ol0003oik:KonNb
V`04onNbV`;o00002Oo[ZXT00ol0003ojjZ9o`000002ooRfO@03o`000?ohZF?on:US00Kon:US00?o
0000onjF9_o^URH00_l0000hooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`000?oooooo
oooo03kooooo00Go0000o`004ol0003o001Ko`00000<oeXgSP03o`000?m[E:GoJeBU00KoJeBU00?o
0000oiaeY_nLMJH07onLMJH00ol0003o^hbTok^<Y00Nok^<Y003o`000?oCWj7odinQ01WodinQ00?o
0000onNbVooW/Y/01_oW/Y/00ol0003ojjZ9on^ZR@07on^ZR@;o00000ooh]Wd00ol0003on:USooRY
H`05ooRYH`05o`000?o^URKokYHVonjF9_l00000>?ooool00ol0003oooooooooo`0Aooooo`005Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0?Oooool00ol0003o000C
o`004`02o`00F`03o`000?mJ=hkoFSN>00WoFSN>00?o0000of]DYOm[E:D02?m[E:D00ol0003oW7FV
oiaeYP0NoiaeYP03o`000?nkS:Co^hbT01ko^hbT00?o0000om>OXOoCWj406OoCWj400ol0003oik:K
onNbV`07onNbV`;o00001oo[ZXT2o`0000Con;Im00?o0000ooRYHoohZF<01?ohZF<2o`0000?okYHV
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool0?Oooool00ol0003o000Co`000002o`00F`03o`00
0?mJ=hkoFSN>00OoFSN>0_l0000;of]DY@03o`000?nLMJKoW7FV01koW7FV00?o0000ok^<Y?nkS:@0
7_nkS:@00ol0003odinQom>OX@0Iom>OX@03o`000?oW/Y_oik:K00Woik:K00?o0000on^ZROo[ZXT0
1?o[ZXT00ol0003on;ImooRfO@04ooRfO@03o`000?ohZF?on:US00?on:US00?o0000ooZ^DOl00000
0_o^URH00ol0003oooooooooo`0eooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`0mooooo`03o`000?l001?o000000;o001K
00?o0000oeXgS_mJ=hh01_mJ=hh00ol0003oJeBUof]DY@0;of]DY@03o`000?nLMJKoW7FV01coW7FV
9_l0000Iom>OX@03o`000?oW/Y_oik:K00[oik:K0_l00004on^ZR@03o`000?oh]Wgon;Im00Con;Im
00?o0000ooRYHoohZF<00oohZF<00ol0003onZiAo`000003onjF9P03o`000?oooooooooo03Cooooo
00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo03gooooo00?o0000o`004ol000000_l005/00ol0003oFSN>oeXgSP05oeXgSP03o`00
0?m[E:GoJeBU00coJeBU00?o0000oiaeY_nLMJH06?nLMJH4o`0000;oX8>c00?o0000ok^E/?nkUK00
7_nkUK000ol0003odJN^om6W[P05o`0001CodinQ00?o0000onNbVooW/Y/03?oW/Y/01Ol0003ojjZ9
on^ZROo[ZXWo000000Oon;Im00?o0000ooRYHoohZF<00_ohZF<01?l0003onZiAooZ^DOl00002onjF
9P03o`000?oooooooooo03Cooooo00?o0000ooooooooool04Oooool001Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo03kooooo0_l00003o`00F`03o`000?mJ=hkoFSN>
00CoFSN>00?o0000of]DYOm[E:D03Om[E:D00ol0003oW7FVoiaeYP0DoiaeYPCo00001_nPPk<00ol0
003o^iF`ok^E/00Nok^E/003o`000?oAYjkodJN^00GodJN^1?l0000@om>OX@03o`000?oW/Y_oik:K
00goik:K0_l000000oo[ZXWo0000ooRfO@07ooRfO@05o`000?ohZF?on:USooRYHol000000ooj[U40
0ol0003okYHVo`00000fooooo`03o`000?oooooooooo017ooooo000Eooooo`05oa0@4?oooooooooo
ooooool@41001Oooool2o`0003oooooo0_l00003o`00F`03o`000?mJ=hkoFSN>00;oFSN>0_l0000A
of]DY@03o`000?nLMJKoW7FV00ooW7FV1?l0000:oj23/`03o`000?nkUK3o^iF`01ko^iF`00?o0000
om6W[_oAYjh02OoAYjh5o`0000[odinQ00?o0000onNbVooW/Y/04?oW/Y/2o`0000Won;Im00Co0000
ooRYHoohZF?o00000ooj[U401?l0003okYHVonjF9_l0000eooooo`03o`000?oooooooooo017ooooo
000Eooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0nooooo`;o0000
1?l005/01?l0003oFSN>oeXgS_l0000Cof]DY@03o`000?nLMJKoW7FV00coW7FV0ol0000>oj23/`03
o`000?nkUK3o^iF`01ko^iF`00?o0000om6W[_oAYjh03_oAYjh4o`0000KodinQ00?o0000onNbVooW
/Y/04OoW/Y/00ol0003on;ImooRfO@08ooRfO@03o`000?ohZF?o000000ConZiA00?o0000onjF9_l0
0000=_ooool00ol0003oooooooooo`0@ooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool0?_ooool00ol001?o0000o`00F`03o`00F`03o`000?mJ=hko000001Co
JeBU00?o0000oiaeY_nLMJH02?nLMJH4o`00017oX8>c00?o0000ok^E/?nkUK007_nkUK000ol0003o
dJN^om6W[P0Bom6W[PGo000000?odinQo`000?oW/Y/04_oW/Y/2o`0000[on;Im0_l00004ooZ^D@03
o`000?o^URKo000003Kooooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0
?Oooool2o`0000Go001K0_l0000Eof]DY@03o`000?nLMJKoW7FV00CoW7FV1?l0000Foj23/`03o`00
0?nkUK3o^iF`01go^iF`00?o0000om6W[_oAYjh05ooAYjh3o`0001;oik:K00?o0000ooBnTol00000
2_oh]Wd00ol0003onZiAooZ^D@03ooZ^D@03o`000?o^URKo000003Gooooo00?o0000ooooooooool0
4?ooool001oooooo00?o0000ooooooooool0?Oooool2o`0000Go001K00?o0000of]DYOm[E:D05Om[
E:D00ol0003oW7FVo`000003o`0001[oX8>c00?o0000ok^E/?nkUK007OnkUK000ol0003odJN^om6W
[P0Hom6W[P04o`000?oS^:[o0000o`00013oik:K00Co0000ooBnTood_Y?o00002Ooh]Wd00ol0003o
nZiAooZ^D@04ooZ^D@;o0000=Oooool00ol0003oooooooooo`0@ooooo`007oooool00ol0003ooooo
ooooo`0mooooo`;o00001Ol005/00ol0003oJeBUof]DY@0Dof]DY@?o00007_nPPk<00ol0003o^iF`
ok^E/00Mok^E/003o`000?oAYjkodJN^01SodJN^00Co0000on>hZ_oS^:[ohkRZ0_l0000=onNbV`;o
00000ood_Y<00ol0003on;ImooRfO@06ooRfO@;o00001Ooj[U42o`0003Gooooo00?o0000oooooooo
ool04?ooool001kooooo00?o0000ooooooooool0?_ooool2o`0000Co001K0_l0000Eof]DY@03o`00
0?mgJKKo000001ooX8>c00?o0000ok^E/?nkUK007?nkUK000ol0003odJN^om6W[P0Iom6W[P03o`00
0?oS^:[ohkRZ00?ohkRZ00?o0000onNbVooW/Y/02_oW/Y/2o`0000Com;jC00?o0000ooRfOOoh]Wd0
1Ooh]Wd00ol0003ooKeao`000005ooZ^D@;o0000=?ooool00ol0003oooooooooo`0@ooooo`007_oo
ool00ol0003oooooooooo`0nooooo`03o`000?l005_o001K00?o001K00?o0000o`08S_l000004_m[
E:D2o`0000?oMfVf00?o0000oj23/onPPk<07?nPPk<00ol0003o^iF`ok^E/00Lok^E/003o`000?oA
YjkodJN^01SodJN^00?o0000on>hZ_oS^:X01OoS^:X2o`0000[oik:K0_l00005ooBnT`03o`000?oh
]Wgon;Im00Con;Im00?o0000oofmLOl000001_oj[U400ol0003oooooooooo`0booooo`03o`000?oo
oooooooo013ooooo000Nooooo`;o0000?oooool00ol0003o001Ko`00F`03o`00F`03o`000?l028ko
0000017oJeBU00?o0000ogMY]_mgJKH00omgJKH00ol0003oX8>coj23/`0Loj23/`03o`000?nkUK3o
^iF`01co^iF`00?o0000om6W[_oAYjh06?oAYjh00ol0003ohkRZon>hZP07on>hZP;o00002?oW/Y/2
o`0000Kom;jC00?o0000ooRfOOoh]Wd00ooh]Wd01?l0003ooKeaoofmLOl00005ooZ^D@03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0?_ooool0
0ol0003o001Ko`00F`02o`00F`04o`000?l028ko00R>o`00013oJeBU00?o0000ogMY]_mgJKH01?mg
JKH00ol0003oX8>coj23/`0Loj23/`03o`000?nkUK3o^iF`01co^iF`00?o0000om6W[_oAYjh06?oA
Yjh00ol0003ohkRZon>hZP09on>hZP;o00001_oW/Y/2o`0000Oom;jC00?o0000ooRfOOoh]Wd00_oh
]Wd01Ol0003ooKeaoofmLOom_G7o000000ConZiA00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0?ooooo`007_ooool00ol0003oooooooooo`0nooooo`03o`000?l005_o001K00;o001K00Co
0000o`08S_l028ko00003_m[E:D2o`0000SoMfVf00?o0000oj23/onPPk<06onPPk<00ol0003o^iF`
ok^E/00Lok^E/003o`000?oAYjkodJN^01SodJN^00?o0000on>hZ_oS^:X02ooS^:X2o`0000Coik:K
0_l00008ooBnT`05o`000?oh]Wgon;ImooRfOOl000000oom_G400ol0003onZiAooZ^D@02ooZ^D@;o
0000=?ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`0nooooo`03o`00
0?l005_o001K00;o001K00Go0000o`08S_l028ko00R>o`00000<of]DY@03o`000?mgJKKoMfVf00So
MfVf00?o0000oj23/onPPk<06onPPk<00ol0003o^iF`ok^E/00Lok^E/003o`000?oAYjkodJN^01So
dJN^00?o0000on>hZ_oS^:X03OoS^:X01_l0003oik:KonNbVol0003om;jCo`0000Wom;jC00Co0000
ooRfOOoh]Wgo00001?om_G401?l0003onZiAooZ^DOoj[U42o`0003Cooooo00?o0000ooooooooool0
3oooool001gooooo00?o0000ooooooooool0?oooool01Ol0003o001Ko`00Fol005_o000000Co00R>
00?o0000of]DYOm[E:D02?m[E:D2o`0000_oMfVf00?o0000oj23/onPPk<07?nPPk<00ol0003o^iF`
ok^E/00Kok^E/003o`000?oAYjkodJN^01OodJN^00?o0000on>hZ_oS^:X03ooS^:X3o`000003ooBn
Tol0003om;jC00Wom;jC00?o0000ooRfOOl000001?om_G401?l0003onZiAooZ^DOoj[U42o`0003Co
oooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0?oooool01Ol0003o001K
o`00Fol005_o000000Co00R>00?o0000of]DYOm[E:D01om[E:D00ol0003oMfVfogMY]P0<ogMY]P03
o`000?nPPk?oX8>c01_oX8>c00?o0000ok^E/?nkUK006onkUK000ol0003odJN^om6W[P0Gom6W[P03
o`000?oS^:[ohkRZ017ohkRZ0_l000000ood_Y?o0000ooBnT`09ooBnT`;o00001Oom_G400ol0003o
nZiAooZ^D@02o`0003Cooooo00?o0000ooooooooool03oooool001gooooo00?o0000ooooooooool0
?oooool01Ol0003o001Ko`00Fol005_o000000Go00R>00?o0000of]DYOm[E:D01?m[E:D2o`0000oo
MfVf00?o0000oj23/onPPk<06onPPk<00ol0003o^iF`ok^E/00Dok^E/0_o00005_oAYjh00ol0003o
hkRZon>hZP0Aon>hZP04o`000?o`a:Co0000o`0000_om;jC00?o0000oofmLOom_G401?om_G401Ol0
003onZiAo`000?oSY1oo000003?ooooo00?o0000ooooooooool03oooool001gooooo0_l00011oooo
o`03o`000?l005_o000000Ko00R>00?o0000of]DYOm[E:D00om[E:D00ol0003oMfVfogMY]P0?ogMY
]P03o`000?nPPk?oX8>c01_oX8>c00?o0000ok^E/?nkUK001OnkUK0?o`0000Oo^ijk00Co0000olj]
^Oo>[KWocZfi1Ol0000Aom6W[P03o`000?oS^:[ohkRZ017ohkRZ00Co0000oo34Y?o`a:Co00002ood
_Y<00ol0003ooKeaoofmL@04oofmL@05o`000?oj[U7o0000on>T7ol00000=?ooool00ol0003ooooo
ooooo`0>ooooo`007Oooool00ol0003oooooooooo`10ooooo`03o`000?l005_o000000Ko00R>00?o
0000of]DYOm[E:D00_m[E:D00ol0003oMfVfogMY]P0AogMY]P03o`000?nPPk?oX8>c01SoX8>c2_l0
000Fok^N^`03o`000?o>[KWocZfi00KocZfi1Ol0000<om6W[P03o`000?oS^:[ohkRZ013ohkRZ00Co
0000oo34Y?o`a:Col<BT0_l0000:ooBnT`;o00001_om_G42o`000003on>T7ol0003ooooo03?ooooo
00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0@?ooool00ol0003o001Ko`00
0006o`08SP03o`000?m[E:GoJeBU00;o00005?mgJKH00ol0003oX8>coj23/`0Doj23/`Co00000_nS
S[l00ol0003o^ijkok^N^`0Kok^N^`03o`000?o>[KWocZfi00_ocZfi1Ol00006om6W[P03o`000?oS
^:[ohkRZ017ohkRZ00Oo0000oo34Y?o`a:Col<BTo`000?o`a:Co000000Wom;jC00?o0000ooc7R_l0
00001_om_G401?l0003ohj@Oon>T7ol0000cooooo`03o`000?oooooooooo00kooooo000Looooo`03
o`000?oooooooooo047ooooo0_l00008o`08SP;o00005_mgJKH00ol0003oX8>coj23/`0@oj23/`Co
00001_nSS[l00ol0003o^ijkok^N^`0Kok^N^`03o`000?o>[KWocZfi013ocZfi1Ol000000ooAYjko
0000on>hZP0Bon>hZP05o`000?o`a:Col<BToo34Y?l000000_o`a:@00ol0003om;jCooBnT`05ooBn
T`04o`000?olah[oo<N:o`0000KooKea00Co0000on>T7ooSY1oo0000<oooool00ol0003ooooooooo
o`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`03o`00Fol0003o00R>00Oo00R>00?o0000
ogMY]_mgJKH05_mgJKH00ol0003oX8>coj23/`0;oj23/`Co00002_nSS[l00ol0003o^ijkok^N^`0K
ok^N^`03o`000?o>[KWocZfi01GocZfi0ol0000Bon>hZP05o`000?o`a:Col<BToo34Y?l000000oo`
a:@00ol0003om;jCooBnT`04ooBnT`05o`000?olah[oo<N:ooc7R_l000001Oom_G401?l0003ohj@O
on>T7ol0000cooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo047ooooo
00?o001Ko`000?l028h01ol028h00ol0003oMfVfogMY]P0FogMY]P03o`000?nPPk?oX8>c00SoX8>c
0ol0000?oj>>_`03o`000?nkW[_o^ijk01[o^ijk00?o0000olj]^Oo>[KT05_o>[KT01?l0003og[bg
o`000?l0000@on>hZP05o`000?o`a:Col<BToo34Y?l000001?o`a:@00ol0003om;jCooBnT`03ooBn
T`03o`000?olah[oo<N:00;oo<N:00?o0000oofmLOom_G400_om_G42o`000003on>T7ol0003ooooo
03;ooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0@Oooool00ol0003o
00R>o`08SP06o`08SP03o`000?lO=Zoo000001OoMfVf00?o0000oj23/onPPk<01?nPPk<4o`0001;o
Xhjo00?o0000ok^N^onkW[/06_nkW[/00ol0003ocZfiolj]^@0Folj]^@04o`000?oN_;Oog[bgomjl
]`?o00003?oS^:X00ol0003ol<BToo34Y003o`0000Gol<BT00?o0000ooBnTood_Y<00_od_Y<00ol0
003oo<N:ooc7RP02ooc7RP03o`000?om_G7ooKea00;ooKea0_l00002on>T7`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0@Oooool00ol0003o
00R>o`08SP06o`08SP03o`000?lO=Zoo000001SoMfVf00?o0000oj23/ol000000ol0000Foj>>_`03
o`000?nkW[_o^ijk01[o^ijk00?o0000olj]^Oo>[KT05Oo>[KT00ol0003og[bgomjl]`05omjl]`;o
00002_oS^:X3o`0000;ol<BT00?o0000oo34Y?o`a:@01?o`a:@01Ol0003om;jCooBnTood_Y?o0000
00Goo<N:00Co0000oofmLOom_G7ooKea0_l00002on>T7`03o`000?oooooooooo037ooooo00?o0000
ooooooooool03Oooool001cooooo0_l00012ooooo`03o`000?l028ko00R>00Ko00R>00Co0000oalf
[olO=Zoo00005_mgJKH3o`0001[oXhjo00?o0000ok^N^onkW[/06OnkW[/00ol0003ocZfiolj]^@0F
olj]^@03o`000?oN_;Oog[bg00Oog[bg0_l00005on>hZPCo00001Oo`a:@00ol0003ol<BToo34Y004
oo34Y003o`000?od_Y?o000000Koo<N:00Wo0000oofmLOom_G7ooKeao`000?oh`eCo0000on>T7ol0
0000<oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`13ooooo`03o`00
0?l028ko00R>00Co00R>00Go0000oalf[olO=Zoo7cJ_o`00000DogMY]P;o000000?oP7_4o`000?nS
S[l06_nSS[l00ol0003o^ijkok^N^`0Iok^N^`03o`000?o>[KWocZfi01KocZfi00?o0000omjl]ooN
_;L02OoN_;L5o`0000?ohkRZ00?o0000oo34Y?o`a:@01?o`a:@00ol0003ol<BToo34Y004oo34Y0;o
00001oolahX02?l0003ooKeaoofmLOl0003on<=Do`000?oSY1oo0000<oooool00ol0003ooooooooo
o`0=ooooo`006oooool00ol0003oooooooooo`13ooooo`03o`000?l028ko00R>00Co00R>00?o0000
oalf[olO=Zl00_lO=Zl00ol0003oMfVfogMY]P0@ogMY]P03o`000?n0NlCoP7_400;oP7_400?o0000
oj>>_onSS[l06OnSS[l00ol0003o^ijkok^N^`0Hok^N^`03o`000?o>[KWocZfi01KocZfi00?o0000
omjl]ooN_;L01ooN_;L7o`0000?ohkRZ00?o0000oo34Y?o`a:@01Oo`a:@00ol0003ol<BToo34Y004
oo34Y003o`000?olah[oo<N:00Koo<N:00Oo0000oofmLOl0003on<=Do`000?oSY1oo000003?ooooo
00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0@oooool00ol0003o00R>o`08
SP03o`08SP03o`000?lO=Zoo7cJ_00?o7cJ_00?o0000ogMY]_mgJKH03_mgJKH2o`0000GoP7_400?o
0000oj>>_onSS[l06OnSS[l00ol0003o^ijkok^N^`0Hok^N^`03o`000?o>[KWocZfi01GocZfi00?o
0000omjl]ooN_;L01OoN_;L3o`0000Oog[bg0ol00009oo34Y003o`000?o`a:Col<BT00?ol<BT00?o
0000ooc7R_olahX01_olahX00ol0003ooKeao`000002ooS3E0;o0000<oooool00ol0003ooooooooo
o`0=ooooo`006oooool00ol0003oooooooooo`14ooooo`03o`000?l028ko00R>00;o00R>00?o0000
oalf[olO=Zl01?lO=Zl00ol0003oMfVfogMY]P0;ogMY]P;o00002?n0Nl@00ol0003oXhjooj>>_`0H
oj>>_`03o`000?nkW[_o^ijk01So^ijk00?o0000olj]^Oo>[KT05Oo>[KT00ol0003og[bgomjl]`02
omjl]`?o00003?oN_;L2o`0000Sol<BT00?o0000oo34Y?o`a:@00_o`a:@00ol0003on<nPo`000008
ooc7RP;o00000_oh`e@2o`0003?ooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0A?ooool00ol0003o00R>o`08SP02o`08SP03o`000?lO=Zoo7cJ_00Co7cJ_00?o0000ogMY
]_mgJKH02OmgJKH2o`0000[oP7_400?o0000oj>>_onSS[l06?nSS[l00ol0003o^ijkok^N^`0Hok^N
^`03o`000?o>[KWocZfi01GocZfi00?o0000omjl]ol000000_l0000?omjl]`03o`000?oYb;?o0000
00Sol<BT00Oo0000oo34Y?o`a:Col<BTo`000?ohcj3o000000Woo<N:00Ko0000ooS3E?oh`eCo0000
on>T7ol0000booooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo04Cooooo
00Go0000o`08S_l028ko00R>o`000007oalf[`03o`000?mgJKKoMfVf00SoMfVf00?o0000oh1ka?n0
Nl@02_n0Nl@00ol0003oXhjooj>>_`0Hoj>>_`03o`000?nkW[_o^ijk01So^ijk00?o0000olj]^Oo>
[KT04oo>[KT4o`00017og[bg00Go0000onW8/ooYb;?ojLRco`000008oo34Y004o`000?o`a:Col<BT
o`0000;on<nP00?o0000ooc7R_olahX01_olahX01?l0003on<=DooS3E?oh`e@2o`0003;ooooo00?o
0000ooooooooool03Oooool001_ooooo0_l00016ooooo`04o`000?l028ko00R>o`0000So7cJ_00?o
0000ogMY]_mgJKH01OmgJKH2o`0000koP7_400?o0000oj>>_onSS[l05onSS[l00ol0003o^ijkok^N
^`0Hok^N^`03o`000?o>[KWocZfi013ocZfi0ol000000oo>[KWo0000omjl]`0Bomjl]`03o`000?oY
b;?ojLRc00;ojLRc00?o0000oo34Y?o`a:@01_o`a:@2o`0000Con<nP00?o0000ooc7R_olahX01Ool
ahX01?l0003on<=DooS3E?oh`e@2o`0003?ooooo00?o0000ooooooooool03?ooool001[ooooo00?o
0000ooooooooool0A_ooool00ol0003o00R>o`000009oalf[`03o`000?mgJKKoMfVf00?oMfVf0_l0
000@oh1ka003o`000?nSS[ooXhjo01SoXhjo00?o0000ok^N^onkW[/04OnkW[/;o`0000_ocZfi0ol0
0004olj]^@03o`000?oN_;Oog[bg017og[bg00?o0000onW8/ooYb;<00ooYb;<00ol0003ol<BToo34
Y006oo34Y003o`000?ohcj3on<nP00;on<nP00?o0000ooc7R_olahX01?olahX00ol0003oo]Imo`00
0002ooS3E0;o0000<oooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Kooooo
00?o0000o`08S_l000002_lO=Zl01Ol0003oMfVfogMY]_mgJKKo000001?oP7_400?o0000oj>>_onS
S[l05onSS[l00ol0003o^ijkok^N^`04ok^N^`go00001_njY/D00ol0003obk?3ol^c``02ol^c``Oo
000000CocZfio`000?l0003o00001oo>[KT00ol0003og[bgomjl]`0@omjl]`03o`000?oYb;?ojLRc
00GojLRc0_l00006oo34Y0;o00001?ohcj000ol0003oo<N:ooc7RP03ooc7RP03o`000?oneWgo0000
00?on<=D00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`0000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`17oooo
o`03o`08S_l0003o7cJ_00Wo7cJ_00Co0000ogMY]_l0003o00005?n0Nl@00ol0003oXhjooj>>_`0E
oj>>_`Wo00004onjY/D00ol0003obk?3ol^c``06ol^c``[o00000oo>[KT00ol0003og[bgomjl]`0A
omjl]`03o`000?oYb;?ojLRc00OojLRc00?o0000oo34Y?o`a:@00_o`a:@00ol0003on<nPo`000004
ooS?X003o`000?olah[oo<N:00?oo<N:00?o0000ookFOOl000000ooh`e@00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00cooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`17ooooo`03o`000?lO=Zoo7cJ_00[o7cJ_00?o0000oh1k
a?n0Nl@05On0Nl@00ol0003oXhjooj>>_`0@oj>>_`Co00000_nUVLT00ol0003o^ZK5okZVa@0GokZV
a@03o`000?o;/l?obk?300?obk?30ol0000:ol^c``Go00004OoN_;L00ol0003ojLRconW8/`09onW8
/`05o`000?o`a:Col<BToo34Y?l000000_ohcj000ol0003on<nPooS?X002ooS?X005o`000?olah[o
o<N:ooc7R_l000000_oneWd01Ol0003on<=DooS3E?oh`eCo000003?ooooo00?o0000ooooooooool0
3?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04ooooo`03o`000?oo
oooooooo04Oooooo00?o0000oalf[olO=Zl02_lO=Zl00ol0003oP7_4oh1ka00Eoh1ka003o`000?nS
S[ooXhjo00coXhjo1?l00006ojFIb@03o`000?njY/Go^ZK501Oo^ZK500?o0000ol^c`oo;/l<00ol0
000@ol^c``03o`000?oH`<;o000000;o00003_oN_;L00ol0003ojLRconW8/`0:onW8/`04o`000?o`
a:Col<BTo`0000?on<nP00Go0000ooS?X?ohcj3on<nPo`000003ooc7RP05o`000?oneWgoo]ImookF
OOl000000_oh`e@00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo0003ooooo`03
o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
04Sooooo00?o0000oalf[olO=Zl02?lO=Zl00ol0003o?US5o`00000Foh1ka003o`000?nSS[ooXhjo
00WoXhjo0ol0000;ojFIb@03o`000?njY/Go^ZK501Ko^ZK50ol0000Col^c``03o`000?oH`<;of<32
00;of<320ol0000;omjl]`03o`000?oYb;?ojLRc00_ojLRc0_l00005ooS?X005o`000?ohcj3on<nP
ooS?X?l000000_olahX01Ol0003oo]ImookFOOoneWgo000000;on<=D00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0<ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0BOooool00ol0003o7cJ_oalf[`08oalf[`04o`000?lnF<Go
?US5o`0001KoP7_400?o0000oj>>_onSS[l01?nSS[l4o`0000koYIW900?o0000okZVaOnjY/D04_nj
Y/D5o`0001Cobk?300?o0000omS0`_oH`<801_oH`<83o`0000Oog[bg00?o0000onW8/ooYb;<03OoY
b;<00ol0003on<nPooS?X004ooS?X007o`000?ohcj3on<nPooS?X?l0003oo<N:o`000003ookFO@04
o`000?oh`eCon<=Do`0003Cooooo00?o0000ooooooooool02oooool00004oiRHV?ooooooV9RHogMg
M`cooooo00?o0000ooooooooool01_ooool2o`0004[ooooo00?o001No`000?lO=Zl01olO=Zl01Ol0
003o?US5ociHaOlnF<Go000001KoP7_400?o0000oj>>_onSS[l01?l0000BojFIb@03o`000?njY/Go
^ZK500oo^ZK50ol00004okZVa@03o`000?o;/l?obk?301;obk?300?o0000omS0`_oH`<802OoH`<83
o`0000Cog[bg00?o0000onW8/ooYb;<03OoYb;<00ol0003on<nPooS?X004ooS?X004o`000?ohcj3o
n<nPooS?X0;o00001?oneWd01?l0003on<=DooS3E?l0000dooooo`03o`000?oooooooooo00_ooooo
00001?lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool00ol0003oooooooooo`1:ooooo`03o`00
G_l0003o7cJ_00Ko7cJ_00?o0000ociHaOlnF<D00_lnF<D00ol0003oP7_4oh1ka00Coh1ka0?o0000
5_nUVLT00ol0003o^ZK5okZVa@0<okZVa@?o00001onjY/D00ol0003obk?3ol^c``0Bol^c``03o`00
0?oH`<;of<3200cof<320ol000000ooN_;Oo0000onW8/`0=onW8/`03o`000?oadk;o000000Kon<nP
00Go0000ooS?X?ohcj3on<nPo`000005ookFO@;o0000=Oooool00ol0003oooooooooo`0;ooooo`00
6Oooool00ol0003oooooooooo`1:ooooo`03o`00G_l0003o7cJ_00Go7cJ_00?o0000ociHaOlnF<D0
1?lnF<D00ol0003oP7_4oh1ka00@oh1ka0;o000000?oR8[?o`000?nUVLT05onUVLT00ol0003o^ZK5
okZVa@08okZVa@?o00002OnjY/D00ol0003obk?3ol^c``0Col^c``03o`000?oH`<;of<3200oof<32
0_l0000>onW8/`04o`000?oadk;olM>bo`0000Kon<nP00Co0000ooS?X?ohcj3o00001OoneWd2o`00
03Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0Boooool00ol005ko
0000oalf[`04oalf[`03o`000?lnF<Go?US500Co?US500?o0000oh1ka?n0Nl@03_n0Nl@2o`0000Co
R8[?00?o0000ojFIbOnUVLT05OnUVLT00ol0003o^ZK5okZVa@04okZVa@Co00003?njY/D00ol0003o
bk?3ol^c``0Bol^c``03o`000?oH`<;of<32013of<3200?o0000on;;`Ol000003?oYb;<01Ol0003o
lM>boo7C/_oadk;o000000Oon<nP0ol00005ookFO@;o0000=Oooool00ol0003oooooooooo`0;oooo
o`006Oooool00ol0003oooooooooo`1;ooooo`03o`00G_l0003o7cJ_00?o7cJ_00?o0000ociHaOln
F<D01_lnF<D00ol0003oP7_4oh1ka00;oh1ka0;o00001_n8R/l00ol0003oYIW9ojFIb@0EojFIb@04
o`000?njY/Go^ZK5okZVa@?o00004?njY/D00ol0003obk?3ol^c``0Bol^c``03o`000?oH`<;of<32
00oof<3200Go0000on;;`OoRbl7oh/_1o`00000;onW8/`03o`000?oadk;olM>b00;olM>b00?o0000
ooS?X?ohcj001Oohcj000ol0003ooN6Lo`000004ookFO@;o0000=Oooool00ol0003oooooooooo`0;
ooooo`006?ooool00ol0003oooooooooo`1<ooooo`03o`000?l005ko000000?o7cJ_00?o0000ociH
aOlnF<D01_lnF<D00ol0003oP7_4oh1ka009oh1ka0;o00002On8R/l00ol0003oYIW9ojFIb@0DojFI
b@Co00004onjY/D00ol0003obk?3ol^c``0Bol^c``03o`000?oH`<;of<3200oof<3200?o0000on;;
`OoRbl400_oRbl400ol0003ojLRconW8/`07onW8/`03o`000?oadk;olM>b00?olM>b00?o0000ooS?
X?ohcj001Oohcj03o`0000Goo]Im00?o0000ooooooooool0<oooool00ol0003oooooooooo`0;oooo
o`006?ooool00ol0003oooooooooo`1=ooooo`;o001N00?o0000oalf[ol000002_lnF<D00ol0003o
P7_4oh1ka007oh1ka003o`000?n8R/ooR8[?00WoR8[?00?o0000ojFIbOnUVLT04_nUVLT3o`0001Ko
^ZK500?o0000ol^c`oo;/l<04Oo;/l<00ol0003of<32omS0`P0?omS0`P03o`000?oRbl7oh/_100Co
h/_10_l00007onW8/`03o`000?oadk;olM>b00ColM>b00?o0000ooS?X?ohcj000oohcj001?l0003o
oN6Lo`000?l00005ookFO@03o`000?oooooooooo03Cooooo00?o0000ooooooooool02_ooool001So
oooo00?o0000ooooooooool0COooool2o`00GP03o`000?lO=Zoo000000_o?US500?o0000oh1ka?n0
Nl@01?n0Nl@2o`0000goR8[?00?o0000ojFIbOnUVLT03OnUVLT4o`0000?oYIW900?o0000okZVaOnj
Y/D04onjY/D00ol0003obk?3ol^c``0Aol^c``03o`000?oH`<;of<3200oof<3200?o0000on;;`OoR
bl401_oRbl400ol0003ojLRconW8/`03onW8/`03o`000?oadk;olM>b00KolM>b00?o0000ooS?X?oh
cj000_ohcj001?l0003ooN6LoogQW?l00005ookFO@03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool02_ooool001Sooooo0_l0001>ooooo`04o`000?l005ko001No`0000co?US500?o0000oh1k
a?n0Nl@00_n0Nl@2o`0000ooR8[?00?o0000ojFIbOnUVLT02_nUVLT3o`0000OoYIW900?o0000okZV
aOnjY/D04onjY/D00ol0003obk?3ol^c``0Aol^c``03o`000?oH`<;of<3200kof<3200?o0000on;;
`OoRbl402?oRbl400ol0003ojLRconW8/`02onW8/`03o`000?oadk;olM>b00KolM>b00?o0000ooS?
X?ohcj000_ohcj001Ol0003ooN6LoogQW?omhIco000000Coo]Im00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`1>ooooo`;o001N00?o0000ociH
aOlnF<D02olnF<D01?l0003oP7_4o`000?l0000BohR:c`03o`000?nUVLWoYIW900KoYIW90ol0000:
ojFIb@03o`000?njY/Go^ZK501?o^ZK500?o0000ol^c`oo;/l<04Oo;/l<00ol0003of<32omS0`P0>
omS0`P03o`000?oRbl7oh/_100Woh/_100Co0000onW8/ooYb;?o00002_oadk801?l0003on<nPooS?
X?l00004oogQW0;o00000_oneWd00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04kooooo00Co0000o`00G_l0003o00003OlnF<D00ol0003oR8[?
ohR:c`0CohR:c`03o`000?nUVLWoYIW900;oYIW90ol0000=ojFIb@03o`000?njY/Go^ZK500ko^ZK5
4?l00008ol^c``03o`000?oH`<;of<3200kof<3200?o0000on;;`OoRbl402ooRbl400ol0003ojLRc
o`00000:oo7C/P04o`000?ohcj3on<nPo`0000CooN6L00Go0000ookFOOl0003oo]Imo`00000goooo
o`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooooooo053ooooo0_l005h00ol039go
0000ociHa@0;ociHa@03o`000?n8R/ooR8[?01?oR8[?1Ol0000AojFIb@03o`000?njY/Go^ZK500;o
^ZK52ol00005okR^c`03o`000?o6^Lgoa[W=00Soa[W=2_l0000?omS0`P03o`000?oRbl7oh/_100co
h/_100?o0000oo7C/_oadk802_oadk800ol0003on<nPo`000004oogQW005o`000?oneWgo0000ookF
OOl00000=oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1@ooooo`;o
001N00?o0000o`0<WOl000002_lnF<D00ol0003oEW?Do`00000BohR:c`Co00004_nUVLT7o`00013o
^:k?00?o0000olJicOo6^Ld04?o6^Ld00ol0003odL?=o`000002o`0000_of<3200?o0000on;;`OoR
bl403OoRbl400ol0003olM>boo7C/P0;oo7C/P03o`000?omhIcooN6L00CooN6L00Co0000ookFOOl0
003o0000=oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0003oooooooooo`1Aooooo`04
o`00G_l0003o00bMo`0000Wo?US500Go0000oeIce?mFLmCoEW?Do`00000>ohR:c`?o00000on8R/l0
0ol0003oYIW9ojFIb@0;ojFIb@Go00000_nVXm<00ol0003o^:k?okR^c`0BokR^c`03o`000?o6^Lgo
a[W=00ooa[W=00?o0000om73cOoA`ld00ooA`ld3o`0000Sof<3200?o0000on;;`OoRbl403?oRbl40
0ol0003oj=K2o`00000<oo7C/P03o`000?omhIcooN6L00CooN6L00Co0000ookFOOl0003o0000>?oo
ool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1Aooooo`05o`00G_l0003o
00bMo`0<WOl000002?lnF<D00ol0003oEW?DoeIce002oeIce003o`000?n8R/ooR8[?00SoR8[?0ol0
0007ohR:c`03o`000?nUVLWoYIW900GoYIW91Ol00007ojJSd`03o`000?nh[/oo^:k?01;o^:k?00?o
0000olJicOo6^Ld03oo6^Ld00ol0003odL?=om73c@06om73c@?o00001?oH`<800ol0003oh/_1on;;
`@0<on;;`@04o`000?oXe/;oj=K2o`0000_olM>b0_l00006oogQW005o`000?oneWgo0000ooooool0
0000=oooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1Booooo`05o`00
G_l0003o00bMo`0<WOl000001_lnF<D00ol0003oEW?DoeIce004oeIce003o`000?n8R/ooR8[?00?o
R8[?1?l0000:ohR:c`03o`000?nUVLWoYIW900Go00003OnVXm<00ol0003o^:k?okR^c`0AokR^c`03
o`000?o6^Lgoa[W=00ooa[W=00?o0000om73cOoA`ld02OoA`ld3o`000003omS0`_l0003oh/_100go
h/_100Go0000onSF`_oXe/;oj=K2o`000009oo7C/P03o`000?ofiKGo000000KooN6L00?o0000ookF
OOl000000_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Gooooo`03
o`000?oooooooooo05;ooooo00?o001No`000?l039d00_l039d00ol0003o?US5ociHa@03ociHa@03
o`000?mFLmCoEW?D00GoEW?D00?o0000ohR:col000000_l0000>ohR:c`?o00004_nVXm<00ol0003o
^:k?okR^c`0AokR^c`03o`000?o6^Lgoa[W=00koa[W=00?o0000om73cOoA`ld03OoA`ld2o`0000go
h/_100?o0000onSF`_oXe/800ooXe/800ol0003olM>boo7C/P06oo7C/P03o`000?ofiKGo000000Oo
oN6L0_l00002ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool001Oooooo
0_l0001Cooooo`;o00000ol039d00ol0003o?US5ociHa@02ociHa@03o`000?mFLmCoEW?D00GoEW?D
0ol0000?ohR:c`;o000000?oSYSIo`000?nVXm<04_nVXm<00ol0003o^:k?okR^c`0AokR^c`03o`00
0?o6^Lgoa[W=00koa[W=00?o0000om73cOoA`ld03OoA`ld00ol0003ofLc=o`00000;on;;`@03o`00
0?oXe/;oj=K200Coj=K200?o0000oo7C/_oadk801Ooadk801Ol0003om^FeooKU]OofiKGo000000Ko
oN6L0_l00003ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool001Kooooo
00?o0000ooooooooool0E?ooool00ol0003o00bMo`0<W@02o`0<W@04o`000?lnF<Go?US5o`0000Go
EW?D0ol00002oeIce003o`000?n8R/ooR8[?00_oR8[?0_l00004ohjHf@03o`000?nVXm?oYZ?C017o
YZ?C00?o0000okR^conh[/l03onh[/l00ol0003oa[W=olJic@0>olJic@03o`000?oA`lgodL?=00go
dL?=00Co0000omW<cOoIc<gofLc=0_l00009on;;`@03o`000?oXe/;oj=K200Goj=K200?o0000oo7C
/_oadk800ooadk800ol0003om^FeooKU]@02ooKU]@03o`000?omhIcooN6L00CooN6L00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo000Fooooo`03
o`000?oooooooooo05Cooooo00?o001No`000?l039d00ol039d01?l0003o?US5o`000?mFLm@4o`00
00KoEW?D00?o0000ohR:con8R/l02?n8R/l2o`0000KoSYSI00?o0000ojJSdonVXm<04OnVXm<00ol0
003o^:k?okR^c`0?okR^c`03o`000?o6^Lgoa[W=00koa[W=00?o0000om73cOoA`ld03?oA`ld00ol0
003ofLc=omW<c@04omW<c@03o`000?oRbl7oh/_100Goh/_100?o0000onSF`_oXe/801_oXe/800ol0
003olM>boo7C/P03oo7C/P03o`000?ofiKGom^Fe00;om^Fe00?o0000oogQW?omhI`00oomhI`2o`00
00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003o
ooooooooo`1Eooooo`03o`000?l039go00bM00?o00bM0ol0000;oeIce003o`000?n8R/ooR8[?00Go
R8[?0_l00009ohjHf@03o`000?nVXm?oYZ?C013oYZ?C00?o0000okR^conh[/l03onh[/l00ol0003o
a[W=olJic@0>olJic@03o`000?oA`lgodL?=00codL?=00?o0000omW<cOoIc<d01OoIc<d00ol0003o
h/_1on;;`@03on;;`@03o`000?oXe/;oj=K200Soj=K200Go0000oo7C/_oadk;olM>bo`000005ooKU
]@03o`000?omhIcooN6L00;ooN6L0ol00007ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool02Oooool001Kooooo00?o0000ooooooooool0EOooool00ol0003o00bMo`0<W@04o`0000ko
EW?D00?o0000ohR:con8R/l00_n8R/l2o`0000coSYSI00?o0000ojJSdonVXm<03onVXm<00ol0003o
^:k?okR^c`0?okR^c`03o`000?o6^Lgoa[W=00goa[W=00?o0000om73cOoA`ld03?oA`ld00ol0003o
fLc=omW<c@07omW<c@;o00000ooRbl400ol0003oj=K2onSF`P09onSF`P04o`000?oadk;olM>bo`00
00Gom^Fe00?o0000oogQW?omhI`00_omhI`3o`0000Sooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`08ooooo`005_ooool00ol0003oooooooooo`1Eooooo`?o00000ol039d2o`0000ko
EW?D00Co0000ohR:col0003o00003_n>V=T00ol0003oYZ?CojJSd`0@ojJSd`03o`000?nh[/oo^:k?
00ko^:k?00?o0000olJicOo6^Ld03Oo6^Ld00ol0003odL?=om73c@0<om73c@03o`000?oIc<gofLc=
00WofLc=00?o0000on;;`Ol000003?oXe/800ol0003olM>bo`000006ooKU]@06o`000?omhIcooN6L
oogQW?l0003ogN^50_l00008ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?oo
ool001Kooooo00?o0000ooooooooool0DOooool4o`0000;ooooo00Oo0000o`0<WOl039go00bMo`00
0?l0AlOo000000koEW?D00?o0000ohjHfOn>V=T03on>V=T00ol0003oYZ?CojJSd`0?ojJSd`03o`00
0?nh[/oo^:k?00ko^:k?00?o0000olJicOo6^Ld03?o6^Ld00ol0003odL?=om73c@0<om73c@03o`00
0?oIc<gofLc=00_ofLc=00?o0000onSF`_oXe/803?oXe/800ol0003om^FeooKU]@05ooKU]@04o`00
0?omhIcooN6LoogQW0?o00002_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo04oooooo0ol00006ooooo`05o`000?l039go00bMo`0<WOl0
00000_l0AlL00ol0003oEW?DoeIce00;oeIce003ofV:gol0003oSYSI00ooSYSI00?o0000ojJSdonV
Xm<03onVXm<00ol0003o^:k?okR^c`0>okR^c`03o`000?o6^Lgoa[W=00coa[W=00?o0000om73cOoA
`ld02ooA`ld00ol0003ofLc=omW<c@0<omW<c@03o`000?oXe/;oj=K200coj=K200?o0000ooKU]Oof
iKD01_ofiKD01?l0003ooN6Lo`000?oMjhD2o`0000_ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`08ooooo`005Oooool3o`0004cooooo0ol0000:ooooo`04o`000?l039go00bMo`00
00?o04O700?o0000oeIce?mFLm@02OmFLm@01?l0003oJH[OofV:gol0000@ohjHf@03o`000?nVXm?o
YZ?C00ooYZ?C00?o0000okR^conh[/l01Onh[/l@o`0000Ooa[W=00?o0000om73cOoA`ld02ooA`ld0
0ol0003ofLc=omW<c@0;omW<c@03o`000?oNe]3o000000coj=K20_l00008ooKU]@;o00000_oMjhD2
o`0000cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0
003oooooooooo`19ooooo`?o00003_ooool01?l0003o00bMo`0<WOl00003o`17a`03o`000?mFLmCo
EW?D00OoEW?D00?o0000ofV:gomYR]l00_mYR]l00ol0003oSYSIohjHf@0=ohjHf@03o`000?nVXm?o
YZ?C00goYZ?C2_l00008okFef@03o`000?o0_]So`;kH00Go`;kH2Ol0000;om73c@03o`000?oIc<go
fLc=00_ofLc=00Go0000omkFd?oNe]3og]K@o`00000:onSF`P03o`000?o/i/So000000Som^Fe0_l0
00000ooMjhGo0000o`00000>ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02?oo
ool001Gooooo00?o0000ooooooooool0AOooool4o`0001;ooooo0_l039d00ol0003o04O7o`17a`02
o`17a`03o`000?mFLmCoEW?D00GoEW?D00?o0000ofV:gomYR]l01?mYR]l00ol0003oSYSIohjHf@0=
ohjHf@03o`000?nVXm?oYZ?C00SoYZ?C1?l00002ojJ]g003o`000?ne]MWo]KGI00go]KGI00?o0000
ol2nf?o0_]P02oo0_]P00ol0003ob<KHolS6f004o`0000OodL?=00?o0000omW<cOoIc<d02_oIc<d0
0ol0003og]K@omkFd002omkFd003o`000?oXe/;oj=K200Ooj=K200Go0000oncVb?o/i/Sok>K8o`00
0007ooKU]@03o`000?oMjhGogN^500;o00003_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo0ol0000Fooooo`03o`000?l039go
000000Go04O700?o0000oeIce?mFLm@00omFLm@00ol0003oJH[OofV:g`06ofV:g`03o`000?n>V=Wo
SYSI00goSYSI00?o0000ojJSdonVXm<01?nVXm<3o`0000KoYZgL00?o0000okFefOne]MT03One]MT0
0ol0003o`;kHol2nf00:ol2nf003o`000?o8a]Sob<KH00Gob<KH1?l00002om73c@03o`000?oIc<go
fLc=00[ofLc=00?o0000omkFd?oNe]001?oNe]000ol0003oj=K2onSF`P05onSF`P03o`000?o/i/So
k>K800;ok>K800?o0000ooKU]OofiKD01OofiKD00ol0003ogN^5omg[Q@02o`0000oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`005Oooool00ol0003oooooooooo`0ooooo
o`?o00006_ooool00ol039go0000o`17a`05o`17a`05o`000?mFLmCoEW?DoeIce?l000002_mYR]l0
0ol0003oSYSIohjHf@0<ohjHf@03o`000?nVXm?oYZ?C00Co00002_nV[M`00ol0003o]KGIokFef@0;
okFef@03o`000?o0_]So`;kH00_o`;kH00?o0000olS6f?o8a]P02Oo8a]P3o`0000_ofLc=00?o0000
omkFd?oNe]001OoNe]000ol0003oj=K2onSF`P04onSF`P03o`000?o/i/Sok>K800?ok>K800?o0000
ooKU]OofiKD01?ofiKD2o`0000;ogN^500?o0000ooooooooool03oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03gooooo0ol0000Noooo
o`;o00001_l0AlL00ol0003oEW?Do`00000<ofV:g`03o`000?n>V=WoSYSI00_oSYSI0ol0000>ojJ]
g003o`000?ne]MWo]KGI00_o]KGI00?o0000ol2nf?o0_]P02_o0_]P00ol0003ob<KHolS6f00;olS6
f003o`000?o>cMWo000000[ofLc=00?o0000omkFd?oNe]001_oNe]000ol0003oj=K2onSF`P02onSF
`P03o`000?o/i/Sok>K800Cok>K800?o0000ooKU]OofiKD00oofiKD2o`0000;ogN^50_l0000Boooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool0>Oooool4o`00027ooooo0_l02i800ol0003o04O7o`17a`04o`17a`;o00003OmYR]l00ol0003o
SYSIohjHf@08ohjHf@;o000000?oTjGQo`000?nV[M`03_nV[M`00ol0003o]KGIokFef@0;okFef@03
o`000?o0_]So`;kH00[o`;kH00?o0000olS6f?o8a]P02_o8a]P01Ol0003oc/gIolk=fOo>cMWo0000
00SofLc=00?o0000omkFd?oNe]002?oNe]001?l0003oj=K2onSF`_l00007oncVb003o`000?ofiKGo
m^Fe00?om^Fe0_l00002omg[Q@03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0fooooo`?o00009_ooool2o`0;
TP03o`000?l0AlOo04O700?o04O70_laLn000ol0003oJH[OofV:g`0;ofV:g`03o`000?n>V=WoSYSI
00GoSYSI0_l00004oi>Uh@03o`000?nV[McoYZgL00goYZgL00?o0000okFefOne]MT02_ne]MT00ol0
003o`;kHol2nf009ol2nf003o`000?o8a]Sob<KH00[ob<KH00?o0000olk=fOo>cMT00oo>cMT2o`00
00GofLc=00?o0000omkFd?oNe]002OoNe]000ol0003oj=K2o`000008oncVb003o`000?ofiKGom^Fe
00;om^Fe00?o0000onOj]?l000000_oMjhD00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01oooool001Cooooo0ol0000cooooo`?o0000:_ooool2o`0;TP03
o`000?l0AlOo04O700;o04O700Co0000oc5ch?laLn3o00003OmYR]l00ol0003oSYSIohjHf@02ohjH
f@;o00001onCYN400ol0003oYZgLojJ]g00<ojJ]g003o`000?ne]MWo]KGI00[o]KGI00?o0000ol2n
f?o0_]P02Oo0_]P00ol0003ob<KHolS6f009olS6f003o`000?o>cMWoc/gI00Koc/gI00Go0000omW<
cOoIc<gofLc=o`00000=omkFd003o`000?o/i/Sok>K800Ook>K800Oo0000ooKU]OofiKGom^Feo`00
0?oWn[Co000000;ogN^50_l0000Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool0<?ooool3o`0002kooooo0_l02i801Ol0003o04O7o`17
aol0AlOo000000?o<G?P0_l0000<ofV:g`04o`000?n>V=Wo0000o`0000[oTjGQ00?o0000ojJ]g?nV
[M`02onV[M`00ol0003o]KGIokFef@0:okFef@03o`000?o0_]So`;kH00Wo`;kH00?o0000olS6f?o8
a]P02Oo8a]P00ol0003oc/gIolk=f@07olk=f@03o`000?oIc<go000000cog]K@00?o0000omoSeol0
00002_o/i/P00ol0003om^Feo`000002onOj]004o`000?oMjhGogN^5o`0001Oooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0;?ooool4o`0003;ooooo0_l02i801?l0003o04O7o`17aol00005oc5c
h003o`000?mYR]ooJH[O00[oJH[O0_l0000<oi>Uh@03o`000?nV[McoYZgL00_oYZgL00?o0000okFe
fOne]MT02One]MT00ol0003o`;kHol2nf008ol2nf003o`000?o8a]Sob<KH00Wob<KH00?o0000olk=
fOo>cMT02Oo>cMT00ol0003og]K@omkFd00:omkFd004o`000?oOhmOogn?Go`0000[ok>K800?o0000
ooKU]Ol000000_oWn[@01?l0003ogN^5omg[QOl0000Hooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Z
ooooo`?o0000=_ooool01?l0003o00^Bo`0;T_l00002o`17a`03o`000?laLn3o<G?P00?o<G?P00?o
0000ofV:gomYR]l02?mYR]l01?l0003oNYgXogZMj?l0000<oi>Uh@03o`000?nV[McoYZgL00[oYZgL
00?o0000okFefOne]MT02?ne]MT00ol0003o`;kHol2nf009ol2nf003o`000?o8a]Sob<KH00Sob<KH
00?o0000olk=fOo>cMT02Oo>cMT00ooAe=_o0000omkFd00:omkFd005o`000?oOhmOogn?GomoSeol0
00002_o/i/P2o`0000;oioZd00Co0000omg[QOoMjhGo00006_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09oooool3o`0003[ooooo00Ko0000o`0;T_l02i;o0000o`17aol00006oc5ch003o`000?mYR]oo
JH[O00KoJH[O00?o0000ogZMj?mjWNP00_mjWNP00ol0003oTjGQoi>Uh@09oi>Uh@03o`000?nV[Mco
YZgL00[oYZgL00?o0000okFefOne]MT02?ne]MT00ol0003o`;kHol2nf008ol2nf003o`000?o8a]So
b<KH00Sob<KH00?o0000olk=fOo>cMT02?o>cMT01Ol0003odMCKom7DfooAe=_o000000Sog]K@0_l0
0004omoSe`03o`000?o/i/Sok>K800Ook>K80_l00003onOj]003o`000?oMjhGo000001cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Cooooo0ol0000nooooo`05o`000?l02i;o00^Bo`17aol000001ola
Ln02o`0000GoJH[O00?o0000ogZMj?mjWNP01?mjWNP2o`0000[oTjGQ00?o0000ojJ]g?nV[M`02_nV
[M`00ol0003o]KGIokFef@02okFef@_o00001Oo0_]P00ol0003ob<KHolS6f008olS6f003o`000?o>
cMWoc/gI00Ooc/gI00?o0000om7DfooAe=/00ooAe=/00ol0003og]K@omkFd004omkFd003o`000?oO
hmOogn?G00Cogn?G00?o0000oncVb?o/i/P01_o/i/P00ol0003oho[Bo`000003onOj]003o`000?oM
jhGo000001cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`003?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo1?l00012ooooo`03o`000?l02i;o
00^B00;o00002?laLn001Ol0003oJH[OofV:gomYR]oo000000WoNYgX00?o0000oi>UhOnCYN402?nC
YN400ol0003oYZgLojJ]g007ojJ]g0Oo00001On`_N<00ol0003o^<?RokS3hP03okS3hPOo00002?o8
a]P00ol0003oc/gIolk=f@07olk=f@03o`000?oAe=_odMCK00GodMCK00?o0000omkFd?oNe]000_oN
e]000ol0003ogn?GomoSe`05omoSe`03o`000?o/i/Sok>K800Gok>K800?o0000on?jd_l000001?oW
n[@2o`0001kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`003?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo0ol00017ooooo`;o00^B00?o0000
o`1Gd?l000002?laLn000ol0003oJH[Oo`00000;ogZMj003o`000?nCYN7oTjGQ00SoTjGQ00Co0000
ojJ]g?nV[McoYZgL1Ol00002ojJgi@03o`000?n`_N?o/;gS00Oo/;gS00?o0000okS3h_nh`n801onh
`n800ol0003o_LSSokg8h`05o`0000;ob<KH00?o0000olk=fOo>cMT01oo>cMT00ol0003odMCKom7D
f`06om7Df`05o`000?oNe]3og]K@omkFd?l000002OoOhmL00ol0003ok>K8oncVb003oncVb004o`00
0?oSn];oho[Bo`0000?oioZd00?o0000omg[QOl000007oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6_ooool3o`0004_ooooo0_l02i800ol0003o05O@o`000008oc5ch0;o00003?mjWNP2o`0000SoTjGQ
1?l00008ojJgi@03o`000?n`_N?o/;gS00Ko/;gS00?o0000okS3h_nh`n801_nh`n800ol0003o_LSS
okg8h`06okg8h`?o00002?o>cMT00ol0003odMCKom7Df`08om7Df`03o`000?oNe]3o000000[ogn?G
00Co0000oncVb?o/i/Sok>K80_l00002on?jdP03o`000?oWn[CoioZd00;oioZd0_l0000Qooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool000[ooooo00?oEEEEofIVI_l00000
1_ooool2o`0001Sooooo0ol0001?ooooo`;o00^B00Co0000o`1Gd?l0003o00001_laLn001?l0003o
FYC]o`000?l0000<ogZMj003o`000?nCYN7oTjGQ00;oTjGQ0ol00002oiVbj@03o`000?nV]nGoY[OU
00OoY[OU00?o0000ok2mhon`_N<01_n`_N<00ol0003o^<?RokS3hP05okS3hP03o`000?nmb>?o_LSS
00Oo_LSS0oo0cN@00ol0003oc/gIolk=f@04olk=f@03o`000?oAe=_odMCK00[odMCK00?o0000omoS
eooOhmL02OoOhmL01?l0003ok>K8oncVb?l00004on?jdP03o`000?oWn[CoioZd00;oioZd00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Boooo
o`03o`000?oooooooooo01Cooooo1?l0001Cooooo`03o`0;T_l0003o05O@00;o05O@00?o0000oc5c
h?laLn000olaLn001?l0003oFYC]oeZDkOmJU>d2o`0000_oNYgX00Co0000oi>UhOl0003o00001_nI
/^T00ol0003oY[OUojJgi@06ojJgi@03o`000?n`_N?o/;gS00Ko/;gS00?o0000okS3h_nh`n801Onh
`n800ol0003o_LSSokg8h`05okg8h`03o`000?o0cNCo`<gT00?o`<gT0_l00003olk=f@03o`000?oA
e=_odMCK00WodMCK00?o0000om7Mh_l000002ooOhmL00ol0003ok>K8o`000005on?jdP04o`000?oW
n[CoioZdonOj]0;o00008oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo
000Booooo`03o`000?oooooooooo017ooooo0ol0001Hooooo`03o`0;T_l0003o05O@00;o05O@00?o
0000oc5ch?laLn000_laLn000ol0003oFYC]oeZDk@03oeZDk@;o00002_mjWNP2o`0000SoVK;Y00?o
0000ojJgiOnV]nD01_nV]nD00ol0003o/;gSok2mh`04ok2mh`03o`000?nh`n;o^<?R00Go^<?R00?o
0000okg8honmb><01Onmb><00ol0003o`<gTol3=i006ol3=i003o`000?o>cMWo000000[odMCK0_l0
0002om7MhP03o`000?oOhmOogn?G00Wogn?G0_l00005on?jdP04o`000?oWn[CoioZdonOj]0;o0000
9Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oo
oooooooo00kooooo0ol0001Looooo`03o`000?l0Em3o05O@00?o05O@0_laLn000ol0003oFYC]oeZD
k@06oeZDk@;o00001omjWNP01?l0003oRJo^ohV_k_l00008oiVbj@03o`000?nV]nGoY[OU00GoY[OU
00?o0000ok2mhon`_N<01?n`_N<00ol0003o^<?RokS3hP05okS3hP03o`000?nmb>?o_LSS00Co_LSS
00?o0000ol3=i?o0cN@02?o0cN@00ol0003odMCKom7Df`07om7Df`;o00001?oAgN800ol0003ogn?G
omoSe`09omoSe`03o`000?oSn];oho[B00Coho[B00Co0000onOj]?oWn[Co0000:?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00_ooooo
0ol0001Pooooo`03o`000?l0Em3o05O@00?o05O@00?o<G?Po`000?mJU>d02OmJU>d2o`0000CoNYgX
00?o0000ohV_k_n9[nh00_n9[nh2o`0000OoVK;Y00?o0000ojJgiOnV]nD01OnV]nD00ol0003o/;gS
ok2mh`03ok2mh`03o`000?nh`n;o^<?R00Co^<?R00?o0000okg8honmb><01?nmb><00ol0003o`<gT
ol3=i008ol3=i003ol7Ai_l0003odMCK00OodMCK00?o0000om7Mh_oAgN801?oAgN800ol0003ogn?G
omoSe`06omoSe`;o000000?of?;Ro`000?oSn]801?oSn]801?l0003oioZdonOj]?l0000Zooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool0
1oooool4o`0006Cooooo0_l00004o`1Gd0;o00002omJU>d2o`000003ogZMj?l0003oRJo^00KoRJo^
00?o0000oiVbjOnI/^T01OnI/^T00ol0003oY[OUojJgi@04ojJgi@03o`000?n`_N?o/;gS00?o/;gS
00?o0000okS3h_nh`n800onh`n800ol0003o_LSSokg8h`04okg8h`03o`000?o0cNCo`<gT00Ko`<gT
0_l00003ol7AiP03o`000?oAe=_odMCK00?odMCK0_l00007om7MhP03o`000?oOhmOogn?G00Cogn?G
0_l00002omSbhP03o`000?oSn];oho[B00Coho[B00?o0000onOj]?l00000;?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Cooooo0ol0
001Zooooo`;o00000_l0Em000ol0003o>Xc]o`000002o`0000[oFYC]0_l00008ohV_kP;o00001_nI
/^T00ol0003oY[OUojJgi@03ojJgi@03o`000?n`_N?o/;gS00?o/;gS00?o0000okS3h_nh`n800onh
`n800ol0003o_LSSokg8h`03okg8h`03o`000?o0cNCo`<gT00Go`<gT0_l00006ol7AiP03o`000?oA
e=_odMCK00;o00002OoAgN800ol0003ogn?GomoSe`02omoSe`;o00001?oHl^800ol0003oho[Bon?j
dP03on?jdP03o`000?oWn[Co000002kooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000K_ooool01Ol0A;_o0000o`1Gd?l0
Em3o000000?o>Xc]0_l00008oeZDk@03o`000?mj[O?o000000;o00001on9[nh00ol0003oVK;YoiVb
j@04oiVbj@04o`000?nV]nGoY[OUojJgi@ko00001?nmb><00ol0003o`<gTol3=i005ol3=i003o`00
0?o1dNKo`M7V00Ko`M7V00?o0000om7Dfol000002ooAgN800ol0003ogn?GomoSe`02o`0000Gof?;R
00?o0000on?jd_oSn]801?oSn]82o`0002oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`05ooooo`004Oooool00ol0003oooooo`000002o`0007;ooooo0ol000000ol0Em3o0000ocZ<
k@03ocZ<k@;o00001_mJU>d00ol0003oNZgcogZ]l`02ogZ]l`;o00001_n9[nh2o`0000CoVK;Y1?l0
0002oj?1kP03o`000?nXa>goZ<C]00;oZ<C]00?o0000ojc7kOn/and00_n/and01_l0003o[LW^o`00
0?l0003o_LSSo`0000Ko`<gT0_l0000:ol7AiP03o`000?oAgN;odMgR00[odMgR0ol00007omSbhP03
o`000?oSn];oho[B00Coho[B00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Cooooo000Aooooo`;o0000Moooool00ol0A;_o0000o`000006ocZ<k@?o0000
0_mJU>d00ol0003oNZgcogZ]l`05ogZ]l`;o00001_n9[nh01?l0003oVK;Yo`000?l00003oifol005
o`000?nS`NkoXl7^oj?1k_l000000onXa>d01Ol0003o[<O]ojc7kOn/ango000000?o[LW^0ol00004
ol3=i0;o00002Oo1dNH2o`000003ol3Fj_l0003odMgR00_odMgR00?o0000omSbh_oHl^801_oHl^80
0ol0003oho[Bon?jdP03on?jdP;o0000<oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Cooooo000Cooooo`03o`000?oooooooooo07Gooooo0_l0A;/00ol0003o>Xc]ocZ<k@06ocZ<
k@03o`000?mJU>go000000WoNZgc0ol00004ohV_kP;o00001OnM_o001?l0003oXl7^oj?1k_l00003
ojS4k@04o`000?n/ango[<O]o`0000?o[LW^00Co0000ojg:kon]b^oo[L[_0_l000000oo0cNCo0000
ol7AiP06ol7AiP?o00001?o0e^X00ol0003odMgRom7MhP06om7MhP?o000000?ob^O[o`000?oHl^80
1ooHl^801?l0003oho[Bon?jd_oSn]83o`0003Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`04ooooo`005?ooool2o`0007Kooooo00?o0000o`14^ol000000_l00007ocZ<k@?o0000
2_mj[O<2o`000004ohV_k_l0003oV;ocoiRol`;o00001?nM_o001?l0003oXl7^oj?1k_l00002ojS4
k@05o`000?n/ango[<O]o`000?n]bNh00_l00005ojg:k`;o00001Oo1dNH3o`0000Oo`=KZ00?o0000
om7Mh_oAgN800ooAgN83o`0000?ob^O[00?o0000omSbh_oHl^801ooHl^800ol0003oho[Bo`000003
o`0003Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005_ooool00ol0
003oooooo`00001dooooo`04o`000?l0A;_o04BkobB8j`?o00001?ljS>d00ol0003oKZcgofj/m`03
o`0000WoNZgc0ol00003oiRol`;o00000onM_o001Ol0003oXl7^o`000?nXa>go000000;o[<O]00?o
0000ojg9k_l000001?n]b^l3o`000004ojg:kol0003o`M7Vol7AiP?o00002_o0e^X01?l0003odMgR
om7Mh_oAgN82o`0000Kob^O[00?o0000omSbh_oHl^801_oHl^801?l0003oho[Bo`000?nYml`2o`00
03Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005oooool2o`0007Ko
oooo00?o0000o`14^ol000000_lTR>/3o`0000;o>Xc]00?o0000ofj/mom^[?L00_m^[?L4o`0000Go
NZgc00?o0000oi?0mOnC`?D01?l000001OnH_o?o0000o`000?l0003oWKo`00;o000000KoZ<C]o`00
0?n/ango0000ojg9k_l00002ojg:k`?o00000on]b^l4o`0000go`=KZ1?l00007ol[Wj`03o`000?oH
l^;of?;R00Oof?;R0_l000000onYmlco0000o`00000jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool01?ooool001Sooooo0_l0001fooooo`03o`000?l0A;_o000000Co98S[0ol00008
ofj/m`?o000000?oNZgco`000?nC`?D01_nC`?D3o`000003oiRolol0003o000000?o000000?o[<O]
o`000?l000000ol000000on]b^oo0000o`000003o`0000;o[L__00?o0000ol3Fj_o0e^X03?o0e^X0
0ol0003ob^O[ol[Wj`08ol[Wj`03o`000?oHl^;of?;R00Gof?;R0_l00002ojWgc0;o0000??ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo
07Cooooo00?o0000o`14^ol000001_lTR>/4o`0000OoKZcg2_l00002oi?0m@go00001on]bnl01?l0
003o`=KZol3Fj_o0e^X7o`0000Co^m[`00?o0000ol[Wjoo:in/02?o:in/00ol0003of?;RomSbhP02
omSbhP?o00000onYml`2o`0003kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03
ooooo`006oooool2o`000003ooooool0003ooooo077ooooo00Co0000ooooool0003o00001_lTR>/0
0ol0003oIjkiofN^n@06o`0000;oKZcg00?o0000oi;1m_nB`OH01_nB`OHJo`0000[o^m[`00?o0000
ol[Wjoo:in/02?o:in/00ol0003of?;RomSbhP03o`000003okOik?l0003oZOO<00;oZOO<00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo000Moooo
o`;o0000L_ooool01?l0003oooooooooooooool3o`0000Co98S[00?o0000ofN^nOmW[_T01_mW[_T:
o`000003oi;1mol0003o000000?o000000?oT/?ho`000?l000001_l00007oj_<l@03o`000?nkf_3o
^m[`00[o^m[`00?o0000ol[Wjoo:in/02Oo:in/3o`0000?o]oW/00Go0000ojWgc?nYmlcoZOO<o`00
0012ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001kooooo00?o0000
ooooooooool0L?ooool00ol0003oooooooooo`02ooooo`03o`000?lMS>_o000000;o00000_lTR>/0
0ol0003oIjkiofN^n@09ofN^n@03o`000?nB`OOoT/7g00Co00000_nA`OL2o`000006oi;3n?l0003o
0000oi[:n?l0003oXLgg0_l00002ojO=m0Co00000_n[c?400ol0003o^m[`ok_Jl00:ok_Jl003o`00
0?o:in_ob^O[00?ob^O[1ol00005okOik005o`000?nYmlcoZOO<ojWgc?l00000A?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo000Oooooo`;o0000L?ooool00ol0003ooooo
ooooo`04ooooo`;o000000Go7Hc[o`000?l0003o98S[o`000006ofN^n@Co000000?oIjkio`000?l0
00001?nA`OL2o`0000;oT/?h00?o0000oiC6n?l000000_nJb_P00ol0003oXLggoj7=m`02o`0000Co
Ylgd3Ol000000onkf_3o0000o`000005o`0000Co]^cf00?o0000okOik?ngnN`01?ngnN`01Ol0003o
ZOO<ojWgc?nYmlco000004Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03oooo
o`008Oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo0ol00002oaf<j`Oo
00001omV/_/2o`000003oi71mol0003oT/?h00?oT/?h00Co0000oiC6n?nDa_So00000_nJb_P01?l0
003oXLggoj7=monQcOL2o`000003ojO=m?l0003o/=gg00_o/=gg00?o0000okK/m_nfk?H02Onfk?H0
0ol0003o]oW/okOik004okOik005o`000?nYmlcoZOO<ojWgc?l00000B?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00?ooooo000Rooooo`?o0000K?ooool00ol0003oooooooooo`07
ooooo`?o00000olMS>/3o`0000[oI[;k0ol00002oi;3n005o`000?nDa_SoU<KhoiC6n?l000000onJ
b_P00ol0003oXLggoj7=m`05o`0000[o/=gg00?o0000okK/m_nfk?H02?nfk?H2o`0000Ko]oW/00?o
0000ojWgc?nYml`00_l0001:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool002Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`09ooooo`;o00001OlMS>/2
o`0000;oI[;k1?l00005ofZio@Go000000CoU<Kho`000?nJb_SoV/[h1?l00005oigJo0?o00001_n`
gOL00ol0003o]^cfokK/mP08okK/mP03o`000?ngnNco]oW/00Go]oW/1?l0001=ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00_ooool002Gooooo0_l0001Zooooo`03o`000?oooooo
oooo00_ooooo2Ol0000:ofZio@04o`000?mea?koMLCnogG4oPCo00001?n7d?l00ol0003oWM[loigJ
o005oigJo0?o00000_n`gOL00ol0003o]^cfokK/mP08okK/mP03o`000?ngnNco]oW/00Go]oW/0_l0
001@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0=ooooo`;o00001_lTV^d3o`0000GoJ[Wm00?o0000
ogG4o_mea?h00omea?h00ol0003oQm3oohO@o`05ohO@o`03o`000?nMf_coWM[l00OoWM[l1ol00005
okK/mP04o`000?ngnNco]oW/okOik0Go0000Doooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00;ooooo000Xooooo`03o`000?oooooo000006Kooooo00?o0000ooooooooool04?ooool2
o`0000Ko99[]0ol000000omZ^Ogo0000ogG4oP05ogG4oP03o`000?n7d?ooQm3o00KoQm3o00?o0000
oigJo?nMf_`00onMf_`3o`0000OoTNCl2ol0001Gooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04ooooo`;o0000I_ooool00ol0
003oooooooooo`0Booooo`;o00001olTV^d6o`0000?oMLCn00?o0000ohO@oon7d?l01_n7d?l00ol0
003oWM[lo`000002o`0000[oTNCl0ol00002ofoOh`?o0000Foooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Dooooo`?o000000?o99[]o`000?l000001olj/?8@o`0000So
TNCl0ol00002ofoOh`?o0000Goooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo000Eooooo`Ko00001Oooool00ol0003oooooooooo`09ooooo`;o0000Hoooool00ol0003ooooo
ooooo`0Gooooo`03o`000?lj/?;o>[3b00[o>[3b00?o0000of;=nOmRcOT02_mRcOT3o`0000;oTNCl
0ol00002ofoOh`?o0000H_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
000Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003ooooooooo
o`0Looooo`Oo00000_lj/?800ol0003oH/giof;=n@05of;=n@ko0000I_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00cooooo0_l0001P
ooooo`03o`000?oooooooooo02?ooooo3Ol0001booooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00Oooool0023ooooo00?o0000ooooooooool03Oooool2o`0005oooooo00?o0000oooo
ooooool0Xoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`2Uooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool001kooooo00?oEEEEofIVI_l00000
4_ooool2o`000003ooooool0003ooooo05Sooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo007ooooo000eooooo`;o0000FOooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003Kooooo0_l0001H
ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01
ooooo`00>?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo000iooooo`04o`000?oooooooooo
o`0005?ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`09ooooo`7o00000Oooool1
ooooo`00>_ooool3o`0005?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00??ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo0:[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool003gooooo0_l0001Aooooo`03o`00
0?oooooooooo0:_ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool003oooooo00?o
0000ooooool00000C_ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo0010ooooo`;o0000C_ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo0011ooooo`;o0000COooool00ol0003oooooooooo`2^oooo
o`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo0013ooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool004Cooooo
0_l000000ooooooo0000ooooo`17ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo0016ooooo`;o0000B?ooool00ol0003oooooooooo`2`ooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`00<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`04odA4A?l0003o0000oc8b<P;o0000Aoooool00ol0003oooooooooo`2aooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`04ogMgMolb<S;oooooo`0004Kooooo00?o0000ooooooooool0/_ooool01Ol0003o
oooooooooooooooo0000007ooooo000Zooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00ol00013ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooo
oooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`2cooooo`04o`000?oooooo
ooooo`00007ooooo000booooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`2dooooo`03o`00
0?oooooooooo007o0000000booooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`08ooooo`;o0000@?ooool00ol0003oooooooooo`2eooooo`7o00000Oooool1o`000000<_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02_ooool2o`0003kooooo
00?o0000ooooooooool0]_ooool2o`000000<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000:ooooo`;o0000?Oooool00ol0003oooooooooo`2eooooo`?o0000001Cooooo`05o`000?oo
ooooooooooooool00000>?ooool00ol0003oooooooooo`2`ooooo`Go00000oooool005Cooooo00Co
0000oooooooooooo0000>?ooool00ol0003oooooooooo`2/ooooo`Co00002?ooool005Gooooo0ol0
000hooooo`03o`000?oooooooooo0:Sooooo1?l0000<ooooo`00Eoooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0:Cooooo1Ol0000@ooooo`00F?ooool2o`0003Gooooo00?o0000oooo
ooooool0X?ooool4o`0001Gooooo001Jooooo`03o`000?oooooo000003;ooooo00?o0000oooooooo
ool0W?ooool4o`0001Wooooo001Kooooo`;o0000<_ooool00ol0003oooooooooo`2Gooooo`Go0000
7Oooool005gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Cooooo`Co00008_oo
ool005kooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`2>ooooo`Go00009_oo
ool005oooooo0ol0000]ooooo`03o`000?oooooooooo08[ooooo1?l0000[ooooo`00HOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo08Kooooo1?l0000_ooooo`00Doooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00[ooooo0_l0000[ooooo`03o`000?oooooooooo087ooooo1Ol0000coooo
o`00Doooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooool00000:?ooool00ol0
003oooooooooo`1mooooo`Co0000>?ooool005?ooooo00Go410@oooooooooooooooooa0@400=oooo
o`;o0000:?ooool00ol0003oooooooooo`1iooooo`Co0000??ooool005?ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool5o`00
043ooooo001Cooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000S
ooooo`03o`000?oooooooooo073ooooo1?l00015ooooo`00Doooool01Ol@413ooooooooooooooooo
410@017ooooo0ol0000Sooooo`03o`000?oooooooooo06_ooooo1Ol00019ooooo`00Doooool01Omg
MgOoV9RHoooooonHV9SoMgMg01;ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo1?l0001>
ooooo`00Doooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01Cooooo0_l000000ooooooo0000ooooo`0N
ooooo`03o`000?oooooooooo06?ooooo1?l0001Booooo`00K_ooool2o`0001oooooo00?o0000oooo
ooooool0G_ooool5o`0005Kooooo001_ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0F_ooool4o`0005_ooooo001`ooooo`;o00007Oooool00ol0003oooooooooo`1Fooooo`Co0000
Goooool007;ooooo00?o0000ooooool000006_ooool00ol0003oooooooooo`1Aooooo`Go0000Hooo
ool007?ooooo0_l0000Jooooo`03o`000?oooooooooo04gooooo1?l0001Xooooo`00MOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo1?l0001/ooooo`00M_ooool2o`000003
ooooool0003ooooo01Cooooo00?o0000ooooooooool0A?ooool5o`00073ooooo001hooooo`;o0000
5Oooool00ol0003oooooooooo`10ooooo`Co0000MOooool007Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0kooooo`Go0000NOooool007[ooooo0_l000000ooooooo0000ooooo`0@
ooooo`03o`000?oooooooooo03Oooooo1?l0001nooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool2o`00017ooooo00?o
0000ooooooooool0<oooool4o`0008;ooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool2o`0000oooooo00?o0000ooooooooool0;ooo
ool5o`0008Kooooo001Sooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:oooool4o`0008_ooooo001S
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`06ooooo`?o00002ooo
ool00ol0003oooooooooo`0Wooooo`Co0000Soooool006?ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02;ooooo1Ol0002Cooooo`00Hoooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool03?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo01ko
oooo1?l0002Hooooo`00Hoooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool03Oooool3o`0000Oooooo00?o0000ooooooooool06Oooool5o`0009cooooo001Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`Co0000XOooool008Oooooo0_l00005ooooo`03o`000?oooooooooo017ooooo
1?l0002Uooooo`00ROooool2o`0000?ooooo00?o0000ooooooooool03?ooool5o`000:Wooooo002:
ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:kooooo002;ooooo`;o000000?ooooo
o`000?ooool01Oooool4o`000;;ooooo002=ooooo`;o000000?oooooo`000?l000000ol0002foooo
o`00S_ooool2o`000;_ooooo003oooooodcooooo003oooooodcooooo0024ooooo`Co000000?o410@
ooooooooool0`?ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000oooooooo
ool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_oo
ool008Kooooo00?o0000ooooooooool0`_ooool008Kooooo00?o0000ooooooooool0`_ooool008Co
oooo00?oEEEEofIVI_l00000a?ooool00001\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47916 .55042 m .47197 .59324 L .54519 .59715 L p .736 .623 .733 r
F P
0 g
s
.54519 .59715 m .5426 .5529 L .47916 .55042 L p .736 .623 .733 r
F P
0 g
s
.54736 .64269 m .54519 .59715 L .47197 .59324 L p .74 .599 .699 r
F P
0 g
s
.5426 .5529 m .54519 .59715 L .61773 .58626 L p .667 .57 .736 r
F P
0 g
s
.54519 .59715 m .54736 .64269 L .62816 .6305 L p .662 .537 .702 r
F P
0 g
s
.62816 .6305 m .61773 .58626 L .54519 .59715 L p .662 .537 .702 r
F P
0 g
s
.47197 .59324 m .46603 .63696 L .54736 .64269 L p .74 .599 .699 r
F P
0 g
s
.54899 .68818 m .54736 .64269 L .46603 .63696 L p .742 .571 .662 r
F P
0 g
s
.54736 .64269 m .54899 .68818 L .636 .67496 L p .655 .502 .664 r
F P
0 g
s
.636 .67496 m .62816 .6305 L .54736 .64269 L p .655 .502 .664 r
F P
0 g
s
.48735 .50939 m .47916 .55042 L .5426 .5529 L p .73 .646 .765 r
F P
0 g
s
.5426 .5529 m .53969 .51091 L .48735 .50939 L p .73 .646 .765 r
F P
0 g
s
.53969 .51091 m .5426 .5529 L .60524 .54351 L p .671 .6 .767 r
F P
0 g
s
.61773 .58626 m .60524 .54351 L .5426 .5529 L p .667 .57 .736 r
F P
0 g
s
.46603 .63696 m .46159 .68042 L .54899 .68818 L p .742 .571 .662 r
F P
0 g
s
.54998 .73201 m .54899 .68818 L .46159 .68042 L p .743 .539 .619 r
F P
0 g
s
.54899 .68818 m .54998 .73201 L .64081 .71812 L p .645 .461 .62 r
F P
0 g
s
.64081 .71812 m .636 .67496 L .54899 .68818 L p .645 .461 .62 r
F P
0 g
s
.42464 .53698 m .41038 .57624 L .47197 .59324 L p .798 .68 .735 r
F P
0 g
s
.47197 .59324 m .47916 .55042 L .42464 .53698 L p .798 .68 .735 r
F P
0 g
s
.46603 .63696 m .47197 .59324 L .41038 .57624 L p .811 .664 .7 r
F P
0 g
s
.41038 .57624 m .39891 .61593 L .46603 .63696 L p .811 .664 .7 r
F P
0 g
s
.46159 .68042 m .46603 .63696 L .39891 .61593 L p .822 .643 .66 r
F P
0 g
s
.60524 .54351 m .61773 .58626 L .67637 .5626 L p .583 .514 .743 r
F P
0 g
s
.61773 .58626 m .62816 .6305 L .69249 .60287 L p .564 .471 .707 r
F P
0 g
s
.69249 .60287 m .67637 .5626 L .61773 .58626 L p .564 .471 .707 r
F P
0 g
s
.44137 .4989 m .42464 .53698 L .47916 .55042 L p .782 .694 .766 r
F P
0 g
s
.47916 .55042 m .48735 .50939 L .44137 .4989 L p .782 .694 .766 r
F P
0 g
s
.62816 .6305 m .636 .67496 L .70449 .64363 L p .541 .422 .666 r
F P
0 g
s
.70449 .64363 m .69249 .60287 L .62816 .6305 L p .541 .422 .666 r
F P
0 g
s
.49632 .47077 m .48735 .50939 L .53969 .51091 L p .722 .666 .794 r
F P
0 g
s
.53969 .51091 m .53655 .47178 L .49632 .47077 L p .722 .666 .794 r
F P
0 g
s
.53655 .47178 m .53969 .51091 L .59118 .50315 L p .674 .629 .796 r
F P
0 g
s
.60524 .54351 m .59118 .50315 L .53969 .51091 L p .671 .6 .767 r
F P
0 g
s
.59118 .50315 m .60524 .54351 L .65675 .52378 L p .6 .554 .774 r
F P
0 g
s
.67637 .5626 m .65675 .52378 L .60524 .54351 L p .583 .514 .743 r
F P
0 g
s
.39891 .61593 m .39051 .65525 L .46159 .68042 L p .822 .643 .66 r
F P
0 g
s
.45888 .7223 m .46159 .68042 L .39051 .65525 L p .832 .618 .613 r
F P
0 g
s
.46159 .68042 m .45888 .7223 L .54998 .73201 L p .743 .539 .619 r
F P
0 g
s
.46027 .46274 m .44137 .4989 L .48735 .50939 L p .765 .705 .796 r
F P
0 g
s
.48735 .50939 m .49632 .47077 L .46027 .46274 L p .765 .705 .796 r
F P
0 g
s
.55028 .77248 m .54998 .73201 L .45888 .7223 L p .741 .5 .565 r
F P
0 g
s
.54998 .73201 m .55028 .77248 L .64223 .75834 L p .63 .411 .565 r
F P
0 g
s
.64223 .75834 m .64081 .71812 L .54998 .73201 L p .63 .411 .565 r
F P
0 g
s
.636 .67496 m .64081 .71812 L .71181 .68375 L p .514 .365 .616 r
F P
0 g
s
.71181 .68375 m .70449 .64363 L .636 .67496 L p .514 .365 .616 r
F P
0 g
s
.59118 .50315 m .57598 .46576 L .53655 .47178 L p .674 .629 .796 r
F P
0 g
s
.57598 .46576 m .59118 .50315 L .63427 .48718 L p .617 .592 .803 r
F P
0 g
s
.65675 .52378 m .63427 .48718 L .59118 .50315 L p .6 .554 .774 r
F P
0 g
s
.50589 .43497 m .49632 .47077 L .53655 .47178 L p .711 .685 .823 r
F P
0 g
s
.53655 .47178 m .53326 .43574 L .50589 .43497 L p .711 .685 .823 r
F P
0 g
s
.53326 .43574 m .53655 .47178 L .57598 .46576 L p .675 .657 .825 r
F P
0 g
s
.48097 .42919 m .46027 .46274 L .49632 .47077 L p .743 .714 .825 r
F P
0 g
s
.49632 .47077 m .50589 .43497 L .48097 .42919 L p .743 .714 .825 r
F P
0 g
s
.39051 .65525 m .38541 .69339 L .45888 .7223 L p .832 .618 .613 r
F P
0 g
s
.45807 .76119 m .45888 .7223 L .38541 .69339 L p .84 .585 .554 r
F P
0 g
s
.45888 .7223 m .45807 .76119 L .55028 .77248 L p .741 .5 .565 r
F P
0 g
s
.4062 .48055 m .38427 .51474 L .42464 .53698 L p .829 .744 .771 r
F P
0 g
s
.42464 .53698 m .44137 .4989 L .4062 .48055 L p .829 .744 .771 r
F P
0 g
s
.41038 .57624 m .42464 .53698 L .38427 .51474 L p .854 .74 .737 r
F P
0 g
s
.57598 .46576 m .55999 .43156 L .53326 .43574 L p .675 .657 .825 r
F P
0 g
s
.55999 .43156 m .57598 .46576 L .60952 .45339 L p .633 .63 .83 r
F P
0 g
s
.63427 .48718 m .60952 .45339 L .57598 .46576 L p .617 .592 .803 r
F P
0 g
s
.38427 .51474 m .36637 .54983 L .41038 .57624 L p .854 .74 .737 r
F P
0 g
s
.39891 .61593 m .41038 .57624 L .36637 .54983 L p .877 .733 .699 r
F P
0 g
s
.64081 .71812 m .64223 .75834 L .71402 .72198 L p .478 .293 .552 r
F P
0 g
s
.71402 .72198 m .71181 .68375 L .64081 .71812 L p .478 .293 .552 r
F P
0 g
s
.43194 .44818 m .4062 .48055 L .44137 .4989 L p .802 .746 .801 r
F P
0 g
s
.44137 .4989 m .46027 .46274 L .43194 .44818 L p .802 .746 .801 r
F P
0 g
s
.63427 .48718 m .65675 .52378 L .69066 .49683 L p .51 .504 .785 r
F P
0 g
s
.65675 .52378 m .67637 .5626 L .71321 .5308 L p .468 .446 .751 r
F P
0 g
s
.71321 .5308 m .69066 .49683 L .65675 .52378 L p .468 .446 .751 r
F P
0 g
s
.54983 .80791 m .55028 .77248 L .45807 .76119 L p .734 .448 .496 r
F P
0 g
s
.55028 .77248 m .54983 .80791 L .64009 .79399 L p .608 .346 .494 r
F P
0 g
s
.64009 .79399 m .64223 .75834 L .55028 .77248 L p .608 .346 .494 r
F P
0 g
s
.36637 .54983 m .35253 .58511 L .39891 .61593 L p .877 .733 .699 r
F P
0 g
s
.39051 .65525 m .39891 .61593 L .35253 .58511 L p .898 .721 .653 r
F P
0 g
s
.67637 .5626 m .69249 .60287 L .73117 .56611 L p .419 .381 .709 r
F P
0 g
s
.73117 .56611 m .71321 .5308 L .67637 .5626 L p .419 .381 .709 r
F P
0 g
s
.60952 .45339 m .63427 .48718 L .66389 .46492 L p .549 .557 .815 r
F P
0 g
s
.69066 .49683 m .66389 .46492 L .63427 .48718 L p .51 .504 .785 r
F P
0 g
s
.46104 .41868 m .43194 .44818 L .46027 .46274 L p .771 .744 .829 r
F P
0 g
s
.46027 .46274 m .48097 .42919 L .46104 .41868 L p .771 .744 .829 r
F P
0 g
s
.51591 .40221 m .50589 .43497 L .53326 .43574 L p .697 .703 .851 r
F P
0 g
s
.53326 .43574 m .52984 .40275 L .51591 .40221 L p .697 .703 .851 r
F P
0 g
s
.52984 .40275 m .53326 .43574 L .55999 .43156 L p .675 .686 .852 r
F P
0 g
s
.69249 .60287 m .70449 .64363 L .74424 .60208 L p .363 .304 .657 r
F P
0 g
s
.74424 .60208 m .73117 .56611 L .69249 .60287 L p .363 .304 .657 r
F P
0 g
s
.50312 .39895 m .48097 .42919 L .50589 .43497 L p .717 .72 .852 r
F P
0 g
s
.50589 .43497 m .51591 .40221 L .50312 .39895 L p .717 .72 .852 r
F P
0 g
s
.60952 .45339 m .583 .42284 L .55999 .43156 L p .633 .63 .83 r
F P
0 g
s
.583 .42284 m .60952 .45339 L .6334 .43582 L p .586 .607 .84 r
F P
0 g
s
.66389 .46492 m .6334 .43582 L .60952 .45339 L p .549 .557 .815 r
F P
0 g
s
.55999 .43156 m .54341 .40055 L .52984 .40275 L p .675 .686 .852 r
F P
0 g
s
.54341 .40055 m .55999 .43156 L .583 .42284 L p .65 .669 .855 r
F P
0 g
s
.35253 .58511 m .34269 .62003 L .39051 .65525 L p .898 .721 .653 r
F P
0 g
s
.38541 .69339 m .39051 .65525 L .34269 .62003 L p .917 .702 .596 r
F P
0 g
s
.38541 .69339 m .38383 .72947 L .45807 .76119 L p .84 .585 .554 r
F P
0 g
s
.45926 .7957 m .45807 .76119 L .38383 .72947 L p .842 .54 .476 r
F P
0 g
s
.45807 .76119 m .45926 .7957 L .54983 .80791 L p .734 .448 .496 r
F P
0 g
s
.49281 .39317 m .46104 .41868 L .48097 .42919 L p .735 .739 .855 r
F P
0 g
s
.48097 .42919 m .50312 .39895 L .49281 .39317 L p .735 .739 .855 r
F P
0 g
s
.64223 .75834 m .64009 .79399 L .71088 .75709 L p .426 .199 .464 r
F P
0 g
s
.71088 .75709 m .71402 .72198 L .64223 .75834 L p .426 .199 .464 r
F P
0 g
s
.70449 .64363 m .71181 .68375 L .75216 .63805 L p .294 .211 .589 r
F P
0 g
s
.75216 .63805 m .74424 .60208 L .70449 .64363 L p .294 .211 .589 r
F P
0 g
s
.583 .42284 m .55515 .39584 L .54341 .40055 L p .65 .669 .855 r
F P
0 g
s
.55515 .39584 m .583 .42284 L .59979 .41027 L p .622 .655 .862 r
F P
0 g
s
.6334 .43582 m .59979 .41027 L .583 .42284 L p .586 .607 .84 r
F P
0 g
s
.41318 .42771 m .38308 .45517 L .4062 .48055 L p .833 .787 .808 r
F P
0 g
s
.4062 .48055 m .43194 .44818 L .41318 .42771 L p .833 .787 .808 r
F P
0 g
s
.38427 .51474 m .4062 .48055 L .38308 .45517 L p .868 .794 .775 r
F P
0 g
s
.44784 .40401 m .41318 .42771 L .43194 .44818 L p .794 .776 .836 r
F P
0 g
s
.43194 .44818 m .46104 .41868 L .44784 .40401 L p .794 .776 .836 r
F P
0 g
s
.38308 .45517 m .35812 .48514 L .38427 .51474 L p .868 .794 .775 r
F P
0 g
s
.36637 .54983 m .38427 .51474 L .35812 .48514 L p .901 .798 .736 r
F P
0 g
s
.34269 .62003 m .33678 .65424 L .38541 .69339 L p .917 .702 .596 r
F P
0 g
s
.38383 .72947 m .38541 .69339 L .33678 .65424 L p .932 .673 .523 r
F P
0 g
s
.54865 .83686 m .54983 .80791 L .45926 .7957 L p .717 .375 .398 r
F P
0 g
s
.54983 .80791 m .54865 .83686 L .63441 .82367 L p .572 .254 .391 r
F P
0 g
s
.63441 .82367 m .64009 .79399 L .54983 .80791 L p .572 .254 .391 r
F P
0 g
s
.52984 .40275 m .52632 .37269 L .51591 .40221 L closepath p .685 .725 .88 r
F P
0 g
s
.54341 .40055 m .52632 .37269 L .52984 .40275 L closepath p .672 .714 .881 r
F P
0 g
s
.51591 .40221 m .52632 .37269 L .50312 .39895 L closepath p .695 .735 .882 r
F P
0 g
s
.48603 .38532 m .44784 .40401 L .46104 .41868 L p .75 .76 .861 r
F P
0 g
s
.46104 .41868 m .49281 .39317 L .48603 .38532 L p .75 .76 .861 r
F P
0 g
s
.55515 .39584 m .52632 .37269 L .54341 .40055 L closepath p .657 .708 .885 r
F P
0 g
s
.59979 .41027 m .6334 .43582 L .64587 .41415 L p .535 .59 .856 r
F P
0 g
s
.6334 .43582 m .66389 .46492 L .67861 .43802 L p .47 .524 .831 r
F P
0 g
s
.67861 .43802 m .64587 .41415 L .6334 .43582 L p .47 .524 .831 r
F P
0 g
s
.50312 .39895 m .52632 .37269 L .49281 .39317 L closepath p .7 .744 .885 r
F P
0 g
s
.35812 .48514 m .33839 .5165 L .36637 .54983 L p .901 .798 .736 r
F P
0 g
s
.35253 .58511 m .36637 .54983 L .33839 .5165 L p .931 .797 .69 r
F P
0 g
s
.66389 .46492 m .69066 .49683 L .70633 .46524 L p .395 .448 .798 r
F P
0 g
s
.70633 .46524 m .67861 .43802 L .66389 .46492 L p .395 .448 .798 r
F P
0 g
s
.5638 .38901 m .52632 .37269 L .55515 .39584 L closepath p .646 .707 .891 r
F P
0 g
s
.59979 .41027 m .5638 .38901 L .55515 .39584 L p .622 .655 .862 r
F P
0 g
s
.5638 .38901 m .59979 .41027 L .60879 .39471 L p .594 .648 .874 r
F P
0 g
s
.64587 .41415 m .60879 .39471 L .59979 .41027 L p .535 .59 .856 r
F P
0 g
s
.71181 .68375 m .71402 .72198 L .75469 .67337 L p .205 .093 .496 r
F P
0 g
s
.75469 .67337 m .75216 .63805 L .71181 .68375 L p .205 .093 .496 r
F P
0 g
s
.69066 .49683 m .71321 .5308 L .72873 .49482 L p .305 .357 .752 r
F P
0 g
s
.72873 .49482 m .70633 .46524 L .69066 .49683 L p .305 .357 .752 r
F P
0 g
s
.38383 .72947 m .38591 .76263 L .45926 .7957 L p .842 .54 .476 r
F P
0 g
s
.46244 .82457 m .45926 .7957 L .38591 .76263 L p .835 .471 .365 r
F P
0 g
s
.45926 .7957 m .46244 .82457 L .54865 .83686 L p .717 .375 .398 r
F P
0 g
s
.49281 .39317 m .52632 .37269 L .48603 .38532 L closepath p .701 .748 .888 r
F P
0 g
s
.56847 .38064 m .52632 .37269 L .5638 .38901 L closepath p .64 .708 .896 r
F P
0 g
s
.60879 .39471 m .56847 .38064 L .5638 .38901 L p .594 .648 .874 r
F P
0 g
s
.64009 .79399 m .63441 .82367 L .70234 .78789 L p .348 .065 .335 r
F P
0 g
s
.70234 .78789 m .71088 .75709 L .64009 .79399 L p .348 .065 .335 r
F P
0 g
s
.33839 .5165 m .32366 .54839 L .35253 .58511 L p .931 .797 .69 r
F P
0 g
s
.34269 .62003 m .35253 .58511 L .32366 .54839 L p .958 .79 .632 r
F P
0 g
s
.48351 .37612 m .44251 .38614 L .44784 .40401 L p .758 .783 .874 r
F P
0 g
s
.44784 .40401 m .48603 .38532 L .48351 .37612 L p .758 .783 .874 r
F P
0 g
s
.41318 .42771 m .44784 .40401 L .44251 .38614 L p .808 .809 .851 r
F P
0 g
s
.71321 .5308 m .73117 .56611 L .74584 .5259 L p .195 .246 .689 r
F P
0 g
s
.74584 .5259 m .72873 .49482 L .71321 .5308 L p .195 .246 .689 r
F P
0 g
s
.33678 .65424 m .33479 .68744 L .38383 .72947 L p .932 .673 .523 r
F P
0 g
s
.38591 .76263 m .38383 .72947 L .33479 .68744 L p .937 .625 .423 r
F P
0 g
s
.48603 .38532 m .52632 .37269 L .48351 .37612 L closepath p .701 .749 .889 r
F P
0 g
s
.44251 .38614 m .40492 .40213 L .41318 .42771 L p .808 .809 .851 r
F P
0 g
s
.38308 .45517 m .41318 .42771 L .40492 .40213 L p .855 .83 .822 r
F P
0 g
s
.56863 .37145 m .52632 .37269 L .56847 .38064 L closepath p .638 .709 .898 r
F P
0 g
s
.56847 .38064 m .60879 .39471 L .6093 .37714 L p .571 .652 .891 r
F P
0 g
s
.6093 .37714 m .56863 .37145 L .56847 .38064 L p .571 .652 .891 r
F P
0 g
s
.60879 .39471 m .64587 .41415 L .64664 .3893 L p .49 .586 .878 r
F P
0 g
s
.64664 .3893 m .6093 .37714 L .60879 .39471 L p .49 .586 .878 r
F P
0 g
s
.40492 .40213 m .37198 .42312 L .38308 .45517 L p .855 .83 .822 r
F P
0 g
s
.35812 .48514 m .38308 .45517 L .37198 .42312 L p .898 .845 .784 r
F P
0 g
s
.5557 .35435 m .52632 .37269 L .56425 .36235 L closepath p .637 .712 .901 r
F P
0 g
s
.48351 .37612 m .52632 .37269 L .48556 .36649 L closepath p .701 .751 .89 r
F P
0 g
s
.56425 .36235 m .52632 .37269 L .56863 .37145 L closepath p .638 .71 .899 r
F P
0 g
s
.54383 .34851 m .52632 .37269 L .5557 .35435 L closepath p .64 .719 .905 r
F P
0 g
s
.52991 .34568 m .52632 .37269 L .54383 .34851 L closepath p .647 .73 .909 r
F P
0 g
s
.51555 .34637 m .52632 .37269 L .52991 .34568 L closepath p .661 .742 .91 r
F P
0 g
s
.50244 .35053 m .52632 .37269 L .51555 .34637 L closepath p .677 .751 .907 r
F P
0 g
s
.49207 .35757 m .52632 .37269 L .50244 .35053 L closepath p .69 .754 .9 r
F P
0 g
s
.48556 .36649 m .52632 .37269 L .49207 .35757 L closepath p .698 .753 .894 r
F P
0 g
s
.44251 .38614 m .48351 .37612 L .48556 .36649 L p .754 .802 .892 r
F P
0 g
s
.71402 .72198 m .71088 .75709 L .75159 .70734 L p .087 0 .364 r
F P
0 g
s
.75159 .70734 m .75469 .67337 L .71402 .72198 L p .087 0 .364 r
F P
0 g
s
.32366 .54839 m .31347 .58031 L .34269 .62003 L p .958 .79 .632 r
F P
0 g
s
.33678 .65424 m .34269 .62003 L .31347 .58031 L p .978 .772 .559 r
F P
0 g
s
.73117 .56611 m .74424 .60208 L .7579 .55787 L p .063 .111 .601 r
F P
0 g
s
.7579 .55787 m .74584 .5259 L .73117 .56611 L p .063 .111 .601 r
F P
0 g
s
.64587 .41415 m .67861 .43802 L .67936 .40709 L p .391 .505 .854 r
F P
0 g
s
.67936 .40709 m .64664 .3893 L .64587 .41415 L p .391 .505 .854 r
F P
0 g
s
.54678 .85827 m .54865 .83686 L .46244 .82457 L p .678 .261 .247 r
F P
0 g
s
.54865 .83686 m .54678 .85827 L .62539 .84627 L p .505 .114 .233 r
F P
0 g
s
.62539 .84627 m .63441 .82367 L .54865 .83686 L p .505 .114 .233 r
F P
0 g
s
.56863 .37145 m .6093 .37714 L .60121 .35893 L p .56 .667 .909 r
F P
0 g
s
.60121 .35893 m .56425 .36235 L .56863 .37145 L p .56 .667 .909 r
F P
0 g
s
.48556 .36649 m .44576 .36662 L .44251 .38614 L p .754 .802 .892 r
F P
0 g
s
.40492 .40213 m .44251 .38614 L .44576 .36662 L p .808 .842 .876 r
F P
0 g
s
.37198 .42312 m .34441 .448 L .35812 .48514 L p .898 .845 .784 r
F P
0 g
s
.33839 .5165 m .35812 .48514 L .34441 .448 L p .935 .852 .735 r
F P
0 g
s
.44576 .36662 m .48556 .36649 L .49207 .35757 L p .736 .812 .912 r
F P
0 g
s
.67861 .43802 m .70633 .46524 L .70667 .42942 L p .269 .4 .811 r
F P
0 g
s
.70667 .42942 m .67936 .40709 L .67861 .43802 L p .269 .4 .811 r
F P
0 g
s
.56425 .36235 m .60121 .35893 L .58491 .34203 L p .565 .691 .925 r
F P
0 g
s
.58491 .34203 m .5557 .35435 L .56425 .36235 L p .565 .691 .925 r
F P
0 g
s
.38591 .76263 m .39176 .79197 L .46244 .82457 L p .835 .471 .365 r
F P
0 g
s
.46754 .84683 m .46244 .82457 L .39176 .79197 L p .801 .36 .195 r
F P
0 g
s
.46244 .82457 m .46754 .84683 L .54678 .85827 L p .678 .261 .247 r
F P
0 g
s
.33479 .68744 m .33688 .7193 L .38591 .76263 L p .937 .625 .423 r
F P
0 g
s
.39176 .79197 m .38591 .76263 L .33688 .7193 L p .923 .547 .28 r
F P
0 g
s
.6093 .37714 m .64664 .3893 L .63576 .36248 L p .462 .602 .905 r
F P
0 g
s
.63576 .36248 m .60121 .35893 L .6093 .37714 L p .462 .602 .905 r
F P
0 g
s
.44576 .36662 m .40823 .37305 L .40492 .40213 L p .808 .842 .876 r
F P
0 g
s
.37198 .42312 m .40492 .40213 L .40823 .37305 L p .86 .875 .849 r
F P
0 g
s
.45785 .34776 m .49207 .35757 L .50244 .35053 L p .707 .809 .928 r
F P
0 g
s
.49207 .35757 m .45785 .34776 L .44576 .36662 L p .736 .812 .912 r
F P
0 g
s
.74424 .60208 m .75216 .63805 L .76514 .59036 L p 0 0 .48 r
F P
0 g
s
.76514 .59036 m .7579 .55787 L .74424 .60208 L p 0 0 .48 r
F P
0 g
s
.31347 .58031 m .30738 .61204 L .33678 .65424 L p .978 .772 .559 r
F P
0 g
s
.33479 .68744 m .33678 .65424 L .30738 .61204 L p .988 .739 .464 r
F P
0 g
s
.63441 .82367 m .62539 .84627 L .68858 .81335 L p .22 0 .133 r
F P
0 g
s
.68858 .81335 m .70234 .78789 L .63441 .82367 L p .22 0 .133 r
F P
0 g
s
.34441 .448 m .32245 .47565 L .33839 .5165 L p .935 .852 .735 r
F P
0 g
s
.32366 .54839 m .33839 .5165 L .32245 .47565 L p .967 .85 .674 r
F P
0 g
s
.5557 .35435 m .58491 .34203 L .56159 .32894 L p .584 .719 .936 r
F P
0 g
s
.56159 .32894 m .54383 .34851 L .5557 .35435 L p .584 .719 .936 r
F P
0 g
s
.47809 .33241 m .50244 .35053 L .51555 .34637 L p .673 .794 .939 r
F P
0 g
s
.50244 .35053 m .47809 .33241 L .45785 .34776 L p .707 .809 .928 r
F P
0 g
s
.40823 .37305 m .44576 .36662 L .45785 .34776 L p .784 .865 .909 r
F P
0 g
s
.70633 .46524 m .72873 .49482 L .72832 .45513 L p .115 .264 .74 r
F P
0 g
s
.72832 .45513 m .70667 .42942 L .70633 .46524 L p .115 .264 .74 r
F P
0 g
s
.54383 .34851 m .56159 .32894 L .53361 .32216 L p .61 .746 .941 r
F P
0 g
s
.53361 .32216 m .52991 .34568 L .54383 .34851 L p .61 .746 .941 r
F P
0 g
s
.71088 .75709 m .70234 .78789 L .74267 .73921 L p 0 0 .17 r
F P
0 g
s
.74267 .73921 m .75159 .70734 L .71088 .75709 L p 0 0 .17 r
F P
0 g
s
.50447 .32332 m .51555 .34637 L .52991 .34568 L p .64 .771 .943 r
F P
0 g
s
.51555 .34637 m .50447 .32332 L .47809 .33241 L p .673 .794 .939 r
F P
0 g
s
.52991 .34568 m .53361 .32216 L .50447 .32332 L p .64 .771 .943 r
F P
0 g
s
.40823 .37305 m .37411 .38544 L .37198 .42312 L p .86 .875 .849 r
F P
0 g
s
.34441 .448 m .37198 .42312 L .37411 .38544 L p .908 .9 .807 r
F P
0 g
s
.64664 .3893 m .67936 .40709 L .66668 .37266 L p .336 .512 .883 r
F P
0 g
s
.66668 .37266 m .63576 .36248 L .64664 .3893 L p .336 .512 .883 r
F P
0 g
s
.60121 .35893 m .63576 .36248 L .6131 .33622 L p .462 .638 .932 r
F P
0 g
s
.6131 .33622 m .58491 .34203 L .60121 .35893 L p .462 .638 .932 r
F P
0 g
s
.32245 .47565 m .30594 .50511 L .32366 .54839 L p .967 .85 .674 r
F P
0 g
s
.31347 .58031 m .32366 .54839 L .30594 .50511 L p .989 .837 .6 r
F P
0 g
s
.75216 .63805 m .75469 .67337 L .76766 .62314 L p 0 0 .318 r
F P
0 g
s
.76766 .62314 m .76514 .59036 L .75216 .63805 L p 0 0 .318 r
F P
0 g
s
.30738 .61204 m .30517 .6436 L .33479 .68744 L p .988 .739 .464 r
F P
0 g
s
.33688 .7193 m .33479 .68744 L .30517 .6436 L p .978 .68 .335 r
F P
0 g
s
.72873 .49482 m .74584 .5259 L .74451 .48319 L p 0 .093 .631 r
F P
0 g
s
.74451 .48319 m .72832 .45513 L .72873 .49482 L p 0 .093 .631 r
F P
0 g
s
.42438 .34371 m .45785 .34776 L .47809 .33241 L p .736 .867 .942 r
F P
0 g
s
.45785 .34776 m .42438 .34371 L .40823 .37305 L p .784 .865 .909 r
F P
0 g
s
.37411 .38544 m .40823 .37305 L .42438 .34371 L p .832 .914 .892 r
F P
0 g
s
.54429 .87159 m .54678 .85827 L .46754 .84683 L p .582 .069 0 r
F P
0 g
s
.54678 .85827 m .54429 .87159 L .61343 .8612 L p .372 0 0 r
F P
0 g
s
.61343 .8612 m .62539 .84627 L .54678 .85827 L p .372 0 0 r
F P
0 g
s
.33688 .7193 m .34334 .74935 L .39176 .79197 L p .923 .547 .28 r
F P
0 g
s
.40137 .81662 m .39176 .79197 L .34334 .74935 L p .864 .414 .07 r
F P
0 g
s
.39176 .79197 m .40137 .81662 L .46754 .84683 L p .801 .36 .195 r
F P
0 g
s
.37411 .38544 m .34429 .40326 L .34441 .448 L p .908 .9 .807 r
F P
0 g
s
.32245 .47565 m .34441 .448 L .34429 .40326 L p .949 .913 .747 r
F P
0 g
s
.58491 .34203 m .6131 .33622 L .57932 .31471 L p .488 .688 .956 r
F P
0 g
s
.57932 .31471 m .56159 .32894 L .58491 .34203 L p .488 .688 .956 r
F P
0 g
s
.67936 .40709 m .70667 .42942 L .69315 .38874 L p .172 .386 .831 r
F P
0 g
s
.69315 .38874 m .66668 .37266 L .67936 .40709 L p .172 .386 .831 r
F P
0 g
s
.47437 .86183 m .46754 .84683 L .40137 .81662 L p .7 .167 0 r
F P
0 g
s
.46754 .84683 m .47437 .86183 L .54429 .87159 L p .582 .069 0 r
F P
0 g
s
.30594 .50511 m .29446 .53573 L .31347 .58031 L p .989 .837 .6 r
F P
0 g
s
.30738 .61204 m .31347 .58031 L .29446 .53573 L p .999 .81 .51 r
F P
0 g
s
.45353 .31902 m .47809 .33241 L .50447 .32332 L p .669 .844 .967 r
F P
0 g
s
.47809 .33241 m .45353 .31902 L .42438 .34371 L p .736 .867 .942 r
F P
0 g
s
.63576 .36248 m .66668 .37266 L .63942 .33722 L p .318 .554 .919 r
F P
0 g
s
.63942 .33722 m .6131 .33622 L .63576 .36248 L p .318 .554 .919 r
F P
0 g
s
.74584 .5259 m .7579 .55787 L .75572 .51285 L p 0 0 .477 r
F P
0 g
s
.75572 .51285 m .74451 .48319 L .74584 .5259 L p 0 0 .477 r
F P
0 g
s
.75469 .67337 m .75159 .70734 L .76529 .65604 L p 0 0 .111 r
F P
0 g
s
.76529 .65604 m .76766 .62314 L .75469 .67337 L p 0 0 .111 r
F P
0 g
s
.62539 .84627 m .61343 .8612 L .67 .83268 L p .009 0 0 r
F P
0 g
s
.67 .83268 m .68858 .81335 L .62539 .84627 L p .009 0 0 r
F P
0 g
s
.70234 .78789 m .68858 .81335 L .72776 .7681 L p 0 0 0 r
F P
0 g
s
.72776 .7681 m .74267 .73921 L .70234 .78789 L p 0 0 0 r
F P
0 g
s
.56159 .32894 m .57932 .31471 L .53739 .3029 L p .534 .744 .972 r
F P
0 g
s
.53739 .3029 m .53361 .32216 L .56159 .32894 L p .534 .744 .972 r
F P
0 g
s
.4931 .30429 m .50447 .32332 L .53361 .32216 L p .598 .8 .977 r
F P
0 g
s
.50447 .32332 m .4931 .30429 L .45353 .31902 L p .669 .844 .967 r
F P
0 g
s
.30517 .6436 m .30696 .67498 L .33688 .7193 L p .978 .68 .335 r
F P
0 g
s
.34334 .74935 m .33688 .7193 L .30696 .67498 L p .934 .579 .16 r
F P
0 g
s
.53361 .32216 m .53739 .3029 L .4931 .30429 L p .598 .8 .977 r
F P
0 g
s
.42438 .34371 m .39249 .34582 L .37411 .38544 L p .832 .914 .892 r
F P
0 g
s
.34429 .40326 m .37411 .38544 L .39249 .34582 L p .877 .956 .853 r
F P
0 g
s
.34429 .40326 m .31938 .42581 L .32245 .47565 L p .949 .913 .747 r
F P
0 g
s
.30594 .50511 m .32245 .47565 L .31938 .42581 L p .978 .909 .667 r
F P
0 g
s
.39249 .34582 m .42438 .34371 L .45353 .31902 L p .761 .928 .942 r
F P
0 g
s
.70667 .42942 m .72832 .45513 L .7147 .40982 L p 0 .215 .734 r
F P
0 g
s
.7147 .40982 m .69315 .38874 L .70667 .42942 L p 0 .215 .734 r
F P
0 g
s
.29446 .53573 m .28758 .56714 L .30738 .61204 L p .999 .81 .51 r
F P
0 g
s
.30517 .6436 m .30738 .61204 L .28758 .56714 L p .993 .765 .398 r
F P
0 g
s
.7579 .55787 m .76514 .59036 L .76242 .5437 L p 0 0 .285 r
F P
0 g
s
.76242 .5437 m .75572 .51285 L .7579 .55787 L p 0 0 .285 r
F P
0 g
s
.34334 .74935 m .35453 .77688 L .40137 .81662 L p .864 .414 .07 r
F P
0 g
s
.41469 .83574 m .40137 .81662 L .35453 .77688 L p .71 .194 0 r
F P
0 g
s
.40137 .81662 m .41469 .83574 L .47437 .86183 L p .7 .167 0 r
F P
0 g
s
.6131 .33622 m .63942 .33722 L .59661 .30669 L p .338 .625 .957 r
F P
0 g
s
.59661 .30669 m .57932 .31471 L .6131 .33622 L p .338 .625 .957 r
F P
0 g
s
.75159 .70734 m .74267 .73921 L .75759 .68875 L p 0 0 0 r
F P
0 g
s
.75759 .68875 m .76529 .65604 L .75159 .70734 L p 0 0 0 r
F P
0 g
s
.66668 .37266 m .69315 .38874 L .66312 .34509 L p .116 .419 .865 r
F P
0 g
s
.66312 .34509 m .63942 .33722 L .66668 .37266 L p .116 .419 .865 r
F P
0 g
s
.31938 .42581 m .29974 .45237 L .30594 .50511 L p .978 .909 .667 r
F P
0 g
s
.29446 .53573 m .30594 .50511 L .29974 .45237 L p .99 .884 .564 r
F P
0 g
s
.54131 .87677 m .54429 .87159 L .47437 .86183 L p .355 0 0 r
F P
0 g
s
.54429 .87159 m .54131 .87677 L .59902 .8683 L p .113 0 0 r
F P
0 g
s
.59902 .8683 m .61343 .8612 L .54429 .87159 L p .113 0 0 r
F P
0 g
s
.42919 .31133 m .45353 .31902 L .4931 .30429 L p .645 .898 .984 r
F P
0 g
s
.45353 .31902 m .42919 .31133 L .39249 .34582 L p .761 .928 .942 r
F P
0 g
s
.30696 .67498 m .31324 .70605 L .34334 .74935 L p .934 .579 .16 r
F P
0 g
s
.35453 .77688 m .34334 .74935 L .31324 .70605 L p .824 .414 0 r
F P
0 g
s
.39249 .34582 m .36305 .35441 L .34429 .40326 L p .877 .956 .853 r
F P
0 g
s
.31938 .42581 m .34429 .40326 L .36305 .35441 L p .908 .98 .779 r
F P
0 g
s
.72832 .45513 m .74451 .48319 L .73125 .43497 L p 0 0 .577 r
F P
0 g
s
.73125 .43497 m .7147 .40982 L .72832 .45513 L p 0 0 .577 r
F P
0 g
s
.48272 .86928 m .47437 .86183 L .41469 .83574 L p .453 0 0 r
F P
0 g
s
.47437 .86183 m .48272 .86928 L .54131 .87677 L p .355 0 0 r
F P
0 g
s
.28758 .56714 m .2851 .59922 L .30517 .6436 L p .993 .765 .398 r
F P
0 g
s
.30696 .67498 m .30517 .6436 L .2851 .59922 L p .961 .69 .253 r
F P
0 g
s
.70681 .79308 m .72776 .7681 L .68858 .81335 L p 0 0 0 r
F P
0 g
s
.68858 .81335 m .67 .83268 L .70681 .79308 L p 0 0 0 r
F P
0 g
s
.57932 .31471 m .59661 .30669 L .54118 .28907 L p .401 .719 .988 r
F P
0 g
s
.54118 .28907 m .53739 .3029 L .57932 .31471 L p .401 .719 .988 r
F P
0 g
s
.36305 .35441 m .39249 .34582 L .42919 .31133 L p .769 .981 .909 r
F P
0 g
s
.76514 .59036 m .76766 .62314 L .76488 .57562 L p 0 0 .071 r
F P
0 g
s
.76488 .57562 m .76242 .5437 L .76514 .59036 L p 0 0 .071 r
F P
0 g
s
.61343 .8612 m .59902 .8683 L .64714 .84536 L p 0 0 0 r
F P
0 g
s
.64714 .84536 m .67 .83268 L .61343 .8612 L p 0 0 0 r
F P
0 g
s
.48162 .29049 m .4931 .30429 L .53739 .3029 L p .511 .821 1 r
F P
0 g
s
.4931 .30429 m .48162 .29049 L .42919 .31133 L p .645 .898 .984 r
F P
0 g
s
.53739 .3029 m .54118 .28907 L .48162 .29049 L p .511 .821 1 r
F P
0 g
s
.29974 .45237 m .28557 .48226 L .29446 .53573 L p .99 .884 .564 r
F P
0 g
s
.28758 .56714 m .29446 .53573 L .28557 .48226 L p .981 .835 .439 r
F P
0 g
s
.74267 .73921 m .72776 .7681 L .7439 .7207 L p .793 .845 .387 r
F P
0 g
s
.7439 .7207 m .75759 .68875 L .74267 .73921 L p .793 .845 .387 r
F P
0 g
s
.69315 .38874 m .7147 .40982 L .68351 .35967 L p 0 .214 .736 r
F P
0 g
s
.68351 .35967 m .66312 .34509 L .69315 .38874 L p 0 .214 .736 r
F P
0 g
s
.74451 .48319 m .75572 .51285 L .74295 .46336 L p 0 0 .367 r
F P
0 g
s
.74295 .46336 m .73125 .43497 L .74451 .48319 L p 0 0 .367 r
F P
0 g
s
.63942 .33722 m .66312 .34509 L .61299 .30578 L p .097 .494 .901 r
F P
0 g
s
.61299 .30578 m .59661 .30669 L .63942 .33722 L p .097 .494 .901 r
F P
0 g
s
.36305 .35441 m .33705 .36968 L .31938 .42581 L p .908 .98 .779 r
F P
0 g
s
.29974 .45237 m .31938 .42581 L .33705 .36968 L p .91 .966 .654 r
F P
0 g
s
.35453 .77688 m .37087 .80093 L .41469 .83574 L p .71 .194 0 r
F P
0 g
s
.41469 .83574 m .43152 .84858 L .48272 .86928 L p .453 0 0 r
F P
0 g
s
.43152 .84858 m .41469 .83574 L .37087 .80093 L p 0 .112 .574 r
F P
0 g
s
.2851 .59922 m .28715 .63195 L .30696 .67498 L p .961 .69 .253 r
F P
0 g
s
.31324 .70605 m .30696 .67498 L .28715 .63195 L p .882 .567 .058 r
F P
0 g
s
.31324 .70605 m .32478 .73629 L .35453 .77688 L p .824 .414 0 r
F P
0 g
s
.37087 .80093 m .35453 .77688 L .32478 .73629 L p .616 .17 0 r
F P
0 g
s
.76766 .62314 m .76529 .65604 L .76297 .60866 L p .826 .685 .144 r
F P
0 g
s
.76297 .60866 m .76488 .57562 L .76766 .62314 L p .826 .685 .144 r
F P
0 g
s
.40575 .31047 m .42919 .31133 L .48162 .29049 L p .561 .923 .945 r
F P
0 g
s
.42919 .31133 m .40575 .31047 L .36305 .35441 L p .769 .981 .909 r
F P
0 g
s
.28557 .48226 m .27698 .51489 L .28758 .56714 L p .981 .835 .439 r
F P
0 g
s
.2851 .59922 m .28758 .56714 L .27698 .51489 L p .94 .755 .284 r
F P
0 g
s
.67 .83268 m .64714 .84536 L .67995 .81314 L p .681 .959 .723 r
F P
0 g
s
.67995 .81314 m .70681 .79308 L .67 .83268 L p .681 .959 .723 r
F P
0 g
s
.33705 .36968 m .36305 .35441 L .40575 .31047 L p .725 .985 .795 r
F P
0 g
s
.53793 .87423 m .54131 .87677 L .48272 .86928 L p .016 .58 .797 r
F P
0 g
s
.54131 .87677 m .53793 .87423 L .58268 .86786 L p .227 .747 .822 r
F P
0 g
s
.58268 .86786 m .59902 .8683 L .54131 .87677 L p .227 .747 .822 r
F P
0 g
s
.49232 .8692 m .48272 .86928 L .43152 .84858 L p 0 .466 .813 r
F P
0 g
s
.48272 .86928 m .49232 .8692 L .53793 .87423 L p .016 .58 .797 r
F P
0 g
s
.75572 .51285 m .76242 .5437 L .75 .49442 L p .72 .454 0 r
F P
0 g
s
.75 .49442 m .74295 .46336 L .75572 .51285 L p .72 .454 0 r
F P
0 g
s
.59661 .30669 m .61299 .30578 L .54489 .28218 L p .149 .616 .927 r
F P
0 g
s
.54489 .28218 m .54118 .28907 L .59661 .30669 L p .149 .616 .927 r
F P
0 g
s
.28715 .63195 m .29427 .6652 L .31324 .70605 L p .882 .567 .058 r
F P
0 g
s
.32478 .73629 m .31324 .70605 L .29427 .6652 L p .726 .374 0 r
F P
0 g
s
.7147 .40982 m .73125 .43497 L .70002 .38064 L p 0 0 .509 r
F P
0 g
s
.70002 .38064 m .68351 .35967 L .7147 .40982 L p 0 0 .509 r
F P
0 g
s
.33705 .36968 m .31546 .3916 L .29974 .45237 L p .91 .966 .654 r
F P
0 g
s
.28557 .48226 m .29974 .45237 L .31546 .3916 L p .859 .891 .465 r
F P
0 g
s
.72776 .7681 m .70681 .79308 L .72357 .75094 L p .871 .954 .607 r
F P
0 g
s
.72357 .75094 m .7439 .7207 L .72776 .7681 L p .871 .954 .607 r
F P
0 g
s
.59902 .8683 m .58268 .86786 L .62065 .85109 L p .51 .913 .87 r
F P
0 g
s
.62065 .85109 m .64714 .84536 L .59902 .8683 L p .51 .913 .87 r
F P
0 g
s
.47034 .28353 m .48162 .29049 L .54118 .28907 L p .316 .778 .944 r
F P
0 g
s
.48162 .29049 m .47034 .28353 L .40575 .31047 L p .561 .923 .945 r
F P
0 g
s
.76529 .65604 m .75759 .68875 L .75611 .64276 L p .919 .812 .345 r
F P
0 g
s
.75611 .64276 m .76297 .60866 L .76529 .65604 L p .919 .812 .345 r
F P
0 g
s
.54118 .28907 m .54489 .28218 L .47034 .28353 L p .316 .778 .944 r
F P
0 g
s
.32478 .73629 m .34245 .76476 L .37087 .80093 L p .616 .17 0 r
F P
0 g
s
.37087 .80093 m .39259 .82028 L .43152 .84858 L p 0 .112 .574 r
F P
0 g
s
.39259 .82028 m .37087 .80093 L .34245 .76476 L p 0 .12 .649 r
F P
0 g
s
.66312 .34509 m .68351 .35967 L .62781 .31286 L p 0 .245 .708 r
F P
0 g
s
.62781 .31286 m .61299 .30578 L .66312 .34509 L p 0 .245 .708 r
F P
0 g
s
.27698 .51489 m .27411 .54975 L .2851 .59922 L p .94 .755 .284 r
F P
0 g
s
.28715 .63195 m .2851 .59922 L .27411 .54975 L p .851 .63 .09 r
F P
0 g
s
.45158 .85448 m .43152 .84858 L .39259 .82028 L p 0 .405 .835 r
F P
0 g
s
.43152 .84858 m .45158 .85448 L .49232 .8692 L p 0 .466 .813 r
F P
0 g
s
.76242 .5437 m .76488 .57562 L .75249 .52782 L p .866 .63 .098 r
F P
0 g
s
.75249 .52782 m .75 .49442 L .76242 .5437 L p .866 .63 .098 r
F P
0 g
s
.40575 .31047 m .38415 .31763 L .33705 .36968 L p .725 .985 .795 r
F P
0 g
s
.31546 .3916 m .33705 .36968 L .38415 .31763 L p .569 .857 .534 r
F P
0 g
s
.29427 .6652 m .30727 .69853 L .32478 .73629 L p .726 .374 0 r
F P
0 g
s
.34245 .76476 m .32478 .73629 L .30727 .69853 L p 0 0 .467 r
F P
0 g
s
.31546 .3916 m .29924 .4199 L .28557 .48226 L p .859 .891 .465 r
F P
0 g
s
.27698 .51489 m .28557 .48226 L .29924 .4199 L p .737 .738 .219 r
F P
0 g
s
.38415 .31763 m .40575 .31047 L .47034 .28353 L p .338 .808 .727 r
F P
0 g
s
.73125 .43497 m .74295 .46336 L .7122 .40751 L p .727 .33 0 r
F P
0 g
s
.7122 .40751 m .70002 .38064 L .73125 .43497 L p .727 .33 0 r
F P
0 g
s
.64714 .84536 m .62065 .85109 L .64759 .82729 L p .742 .99 .885 r
F P
0 g
s
.64759 .82729 m .67995 .81314 L .64714 .84536 L p .742 .99 .885 r
F P
0 g
s
.75759 .68875 m .7439 .7207 L .74344 .67759 L p .963 .896 .521 r
F P
0 g
s
.74344 .67759 m .75611 .64276 L .75759 .68875 L p .963 .896 .521 r
F P
0 g
s
.70681 .79308 m .67995 .81314 L .69614 .77817 L p .885 .991 .766 r
F P
0 g
s
.69614 .77817 m .72357 .75094 L .70681 .79308 L p .885 .991 .766 r
F P
0 g
s
.27411 .54975 m .27722 .58635 L .28715 .63195 L p .851 .63 .09 r
F P
0 g
s
.29427 .6652 m .28715 .63195 L .27722 .58635 L p .695 .446 0 r
F P
0 g
s
.53426 .8646 m .53793 .87423 L .49232 .8692 L p .33 .75 .976 r
F P
0 g
s
.53793 .87423 m .53426 .8646 L .56489 .8604 L p .461 .848 .981 r
F P
0 g
s
.56489 .8604 m .58268 .86786 L .53793 .87423 L p .461 .848 .981 r
F P
0 g
s
.61299 .30578 m .62781 .31286 L .54835 .28389 L p .254 0 0 r
F P
0 g
s
.54835 .28389 m .54489 .28218 L .61299 .30578 L p .254 0 0 r
F P
0 g
s
.50293 .86184 m .49232 .8692 L .45158 .85448 L p .258 .66 .966 r
F P
0 g
s
.49232 .8692 m .50293 .86184 L .53426 .8646 L p .33 .75 .976 r
F P
0 g
s
.76488 .57562 m .76297 .60866 L .75022 .56337 L p .953 .756 .3 r
F P
0 g
s
.75022 .56337 m .75249 .52782 L .76488 .57562 L p .953 .756 .3 r
F P
0 g
s
.34245 .76476 m .36694 .79007 L .39259 .82028 L p 0 .12 .649 r
F P
0 g
s
.41967 .83363 m .39259 .82028 L .36694 .79007 L p .001 .38 .842 r
F P
0 g
s
.39259 .82028 m .41967 .83363 L .45158 .85448 L p 0 .405 .835 r
F P
0 g
s
.68351 .35967 m .70002 .38064 L .64039 .32859 L p .621 .09 0 r
F P
0 g
s
.64039 .32859 m .62781 .31286 L .68351 .35967 L p .621 .09 0 r
F P
0 g
s
.58268 .86786 m .56489 .8604 L .59123 .8498 L p .616 .922 .974 r
F P
0 g
s
.59123 .8498 m .62065 .85109 L .58268 .86786 L p .616 .922 .974 r
F P
0 g
s
.47034 .28353 m .45974 .28518 L .38415 .31763 L p .338 .808 .727 r
F P
0 g
s
.45974 .28518 m .47034 .28353 L .54489 .28218 L p .051 0 0 r
F P
0 g
s
.30727 .69853 m .32704 .73106 L .34245 .76476 L p 0 0 .467 r
F P
0 g
s
.36694 .79007 m .34245 .76476 L .32704 .73106 L p 0 .159 .699 r
F P
0 g
s
.7439 .7207 m .72357 .75094 L .72398 .71232 L p .965 .939 .663 r
F P
0 g
s
.72398 .71232 m .74344 .67759 L .7439 .7207 L p .965 .939 .663 r
F P
0 g
s
.29924 .4199 m .28925 .45399 L .27698 .51489 L p .737 .738 .219 r
F P
0 g
s
.27411 .54975 m .27698 .51489 L .28925 .45399 L p 0 0 .048 r
F P
0 g
s
.47445 .85293 m .45158 .85448 L .41967 .83363 L p .242 .598 .951 r
F P
0 g
s
.45158 .85448 m .47445 .85293 L .50293 .86184 L p .258 .66 .966 r
F P
0 g
s
.74295 .46336 m .75 .49442 L .71965 .43973 L p .895 .543 .066 r
F P
0 g
s
.71965 .43973 m .7122 .40751 L .74295 .46336 L p .895 .543 .066 r
F P
0 g
s
.54489 .28218 m .54835 .28389 L .45974 .28518 L p .051 0 0 r
F P
0 g
s
.27722 .58635 m .28664 .62412 L .29427 .6652 L p .695 .446 0 r
F P
0 g
s
.30727 .69853 m .29427 .6652 L .28664 .62412 L p 0 0 .395 r
F P
0 g
s
.38415 .31763 m .36554 .33376 L .31546 .3916 L p .569 .857 .534 r
F P
0 g
s
.29924 .4199 m .31546 .3916 L .36554 .33376 L p 0 0 0 r
F P
0 g
s
.67995 .81314 m .64759 .82729 L .66164 .80083 L p .855 .976 .865 r
F P
0 g
s
.66164 .80083 m .69614 .77817 L .67995 .81314 L p .855 .976 .865 r
F P
0 g
s
.76297 .60866 m .75611 .64276 L .74276 .60084 L p .991 .837 .467 r
F P
0 g
s
.74276 .60084 m .75022 .56337 L .76297 .60866 L p .991 .837 .467 r
F P
0 g
s
.62065 .85109 m .59123 .8498 L .61043 .83461 L p .737 .946 .949 r
F P
0 g
s
.61043 .83461 m .64759 .82729 L .62065 .85109 L p .737 .946 .949 r
F P
0 g
s
.36554 .33376 m .38415 .31763 L .45974 .28518 L p .005 0 0 r
F P
0 g
s
.36694 .79007 m .39847 .81051 L .41967 .83363 L p .001 .38 .842 r
F P
0 g
s
.45168 .83969 m .41967 .83363 L .39847 .81051 L p .259 .562 .934 r
F P
0 g
s
.41967 .83363 m .45168 .83969 L .47445 .85293 L p .242 .598 .951 r
F P
0 g
s
.72357 .75094 m .69614 .77817 L .69708 .74559 L p .935 .948 .77 r
F P
0 g
s
.69708 .74559 m .72398 .71232 L .72357 .75094 L p .935 .948 .77 r
F P
0 g
s
.28925 .45399 m .28614 .49297 L .27411 .54975 L p 0 0 .048 r
F P
0 g
s
.27722 .58635 m .27411 .54975 L .28614 .49297 L p 0 0 .292 r
F P
0 g
s
.32704 .73106 m .35422 .76143 L .36694 .79007 L p 0 .159 .699 r
F P
0 g
s
.39847 .81051 m .36694 .79007 L .35422 .76143 L p .085 .386 .846 r
F P
0 g
s
.28664 .62412 m .30275 .66228 L .30727 .69853 L p 0 0 .395 r
F P
0 g
s
.32704 .73106 m .30727 .69853 L .30275 .66228 L p 0 .043 .61 r
F P
0 g
s
.75 .49442 m .75249 .52782 L .72206 .47659 L p .973 .681 .289 r
F P
0 g
s
.72206 .47659 m .71965 .43973 L .75 .49442 L p .973 .681 .289 r
F P
0 g
s
.70002 .38064 m .7122 .40751 L .65001 .35325 L p .836 .367 .012 r
F P
0 g
s
.65001 .35325 m .64039 .32859 L .70002 .38064 L p .836 .367 .012 r
F P
0 g
s
.53038 .84853 m .53426 .8646 L .50293 .86184 L p .503 .787 .996 r
F P
0 g
s
.53426 .8646 m .53038 .84853 L .54602 .84646 L p .57 .836 .995 r
F P
0 g
s
.54602 .84646 m .56489 .8604 L .53426 .8646 L p .57 .836 .995 r
F P
0 g
s
.62781 .31286 m .64039 .32859 L .55137 .29569 L p .602 .037 0 r
F P
0 g
s
.55137 .29569 m .54835 .28389 L .62781 .31286 L p .602 .037 0 r
F P
0 g
s
.51433 .8475 m .50293 .86184 L .47445 .85293 L p .461 .738 .988 r
F P
0 g
s
.50293 .86184 m .51433 .8475 L .53038 .84853 L p .503 .787 .996 r
F P
0 g
s
.75611 .64276 m .74344 .67759 L .72949 .63976 L p .992 .882 .599 r
F P
0 g
s
.72949 .63976 m .74276 .60084 L .75611 .64276 L p .992 .882 .599 r
F P
0 g
s
.56489 .8604 m .54602 .84646 L .55956 .84153 L p .645 .87 .983 r
F P
0 g
s
.55956 .84153 m .59123 .8498 L .56489 .8604 L p .645 .87 .983 r
F P
0 g
s
.64759 .82729 m .61043 .83461 L .62076 .81729 L p .802 .931 .918 r
F P
0 g
s
.62076 .81729 m .66164 .80083 L .64759 .82729 L p .802 .931 .918 r
F P
0 g
s
.49959 .8436 m .47445 .85293 L .45168 .83969 L p .445 .7 .975 r
F P
0 g
s
.47445 .85293 m .49959 .8436 L .51433 .8475 L p .461 .738 .988 r
F P
0 g
s
.36554 .33376 m .35116 .35934 L .29924 .4199 L p 0 0 0 r
F P
0 g
s
.28925 .45399 m .29924 .4199 L .35116 .35934 L p 0 0 .16 r
F P
0 g
s
.45045 .29706 m .45974 .28518 L .54835 .28389 L p .401 0 0 r
F P
0 g
s
.45974 .28518 m .45045 .29706 L .36554 .33376 L p .005 0 0 r
F P
0 g
s
.69614 .77817 m .66164 .80083 L .66263 .77557 L p .886 .933 .844 r
F P
0 g
s
.66263 .77557 m .69708 .74559 L .69614 .77817 L p .886 .933 .844 r
F P
0 g
s
.59123 .8498 m .55956 .84153 L .56955 .83444 L p .705 .88 .963 r
F P
0 g
s
.56955 .83444 m .61043 .83461 L .59123 .8498 L p .705 .88 .963 r
F P
0 g
s
.28614 .49297 m .2903 .53562 L .27722 .58635 L p 0 0 .292 r
F P
0 g
s
.28664 .62412 m .27722 .58635 L .2903 .53562 L p 0 0 .485 r
F P
0 g
s
.30275 .66228 m .32581 .6998 L .32704 .73106 L p 0 .043 .61 r
F P
0 g
s
.35422 .76143 m .32704 .73106 L .32581 .6998 L p .026 .261 .761 r
F P
0 g
s
.75249 .52782 m .75022 .56337 L .71918 .51731 L p .995 .761 .453 r
F P
0 g
s
.71918 .51731 m .72206 .47659 L .75249 .52782 L p .995 .761 .453 r
F P
0 g
s
.54835 .28389 m .55137 .29569 L .45045 .29706 L p .401 0 0 r
F P
0 g
s
.35422 .76143 m .38888 .78792 L .39847 .81051 L p .085 .386 .846 r
F P
0 g
s
.43655 .82429 m .39847 .81051 L .38888 .78792 L p .298 .55 .921 r
F P
0 g
s
.39847 .81051 m .43655 .82429 L .45168 .83969 L p .259 .562 .934 r
F P
0 g
s
.74344 .67759 m .72398 .71232 L .70982 .67926 L p .968 .9 .7 r
F P
0 g
s
.70982 .67926 m .72949 .63976 L .74344 .67759 L p .968 .9 .7 r
F P
0 g
s
.4877 .83745 m .45168 .83969 L .43655 .82429 L p .446 .676 .962 r
F P
0 g
s
.45168 .83969 m .4877 .83745 L .49959 .8436 L p .445 .7 .975 r
F P
0 g
s
.7122 .40751 m .71965 .43973 L .65598 .38654 L p .915 .532 .269 r
F P
0 g
s
.65598 .38654 m .65001 .35325 L .7122 .40751 L p .915 .532 .269 r
F P
0 g
s
.35116 .35934 m .36554 .33376 L .45045 .29706 L p .266 0 .101 r
F P
0 g
s
.61043 .83461 m .56955 .83444 L .57494 .82612 L p .74 .872 .942 r
F P
0 g
s
.57494 .82612 m .62076 .81729 L .61043 .83461 L p .74 .872 .942 r
F P
0 g
s
.32581 .6998 m .35577 .73533 L .35422 .76143 L p .026 .261 .761 r
F P
0 g
s
.38888 .78792 m .35422 .76143 L .35577 .73533 L p .218 .431 .855 r
F P
0 g
s
.66164 .80083 m .62076 .81729 L .62143 .80023 L p .824 .901 .894 r
F P
0 g
s
.62143 .80023 m .66263 .77557 L .66164 .80083 L p .824 .901 .894 r
F P
0 g
s
.2903 .53562 m .30177 .58047 L .28664 .62412 L p 0 0 .485 r
F P
0 g
s
.30275 .66228 m .28664 .62412 L .30177 .58047 L p .03 .121 .626 r
F P
0 g
s
.35116 .35934 m .34217 .3941 L .28925 .45399 L p 0 0 .16 r
F P
0 g
s
.28614 .49297 m .28925 .45399 L .34217 .3941 L p .126 0 .381 r
F P
0 g
s
.52632 .82641 m .53038 .84853 L .51433 .8475 L closepath p .595 .781 .969 r
F P
0 g
s
.52632 .82641 m .54602 .84646 L .53038 .84853 L closepath p .618 .798 .968 r
F P
0 g
s
.52632 .82641 m .51433 .8475 L .49959 .8436 L closepath p .581 .764 .965 r
F P
0 g
s
.72398 .71232 m .69708 .74559 L .68345 .71794 L p .929 .9 .776 r
F P
0 g
s
.68345 .71794 m .70982 .67926 L .72398 .71232 L p .929 .9 .776 r
F P
0 g
s
.75022 .56337 m .74276 .60084 L .71083 .56091 L p .987 .805 .572 r
F P
0 g
s
.71083 .56091 m .71918 .51731 L .75022 .56337 L p .987 .805 .572 r
F P
0 g
s
.64039 .32859 m .65001 .35325 L .55372 .31855 L p .753 .293 .16 r
F P
0 g
s
.55372 .31855 m .55137 .29569 L .64039 .32859 L p .753 .293 .16 r
F P
0 g
s
.52632 .82641 m .55956 .84153 L .54602 .84646 L closepath p .644 .808 .962 r
F P
0 g
s
.38888 .78792 m .43031 .80863 L .43655 .82429 L p .298 .55 .921 r
F P
0 g
s
.47986 .82991 m .43655 .82429 L .43031 .80863 L p .458 .664 .951 r
F P
0 g
s
.43655 .82429 m .47986 .82991 L .4877 .83745 L p .446 .676 .962 r
F P
0 g
s
.52632 .82641 m .49959 .8436 L .4877 .83745 L closepath p .577 .751 .96 r
F P
0 g
s
.52632 .82641 m .56955 .83444 L .55956 .84153 L closepath p .663 .809 .953 r
F P
0 g
s
.52632 .82641 m .4877 .83745 L .47986 .82991 L closepath p .578 .746 .957 r
F P
0 g
s
.35577 .73533 m .39213 .76728 L .38888 .78792 L p .218 .431 .855 r
F P
0 g
s
.43031 .80863 m .38888 .78792 L .39213 .76728 L p .366 .56 .909 r
F P
0 g
s
.62076 .81729 m .57494 .82612 L .57517 .81765 L p .754 .858 .926 r
F P
0 g
s
.57517 .81765 m .62143 .80023 L .62076 .81729 L p .754 .858 .926 r
F P
0 g
s
.30177 .58047 m .32025 .62589 L .30275 .66228 L p .03 .121 .626 r
F P
0 g
s
.32581 .6998 m .30275 .66228 L .32025 .62589 L p .17 .273 .728 r
F P
0 g
s
.69708 .74559 m .66263 .77557 L .65063 .75397 L p .88 .889 .835 r
F P
0 g
s
.65063 .75397 m .68345 .71794 L .69708 .74559 L p .88 .889 .835 r
F P
0 g
s
.52632 .82641 m .57494 .82612 L .56955 .83444 L closepath p .673 .807 .947 r
F P
0 g
s
.71965 .43973 m .72206 .47659 L .65781 .42757 L p .932 .624 .435 r
F P
0 g
s
.65781 .42757 m .65598 .38654 L .71965 .43973 L p .932 .624 .435 r
F P
0 g
s
.74276 .60084 m .72949 .63976 L .69698 .60623 L p .964 .829 .66 r
F P
0 g
s
.69698 .60623 m .71083 .56091 L .74276 .60084 L p .964 .829 .66 r
F P
0 g
s
.43031 .80863 m .47691 .82186 L .47986 .82991 L p .458 .664 .951 r
F P
0 g
s
.52632 .82641 m .47986 .82991 L .47691 .82186 L closepath p .579 .745 .955 r
F P
0 g
s
.44317 .32022 m .45045 .29706 L .55137 .29569 L p .572 .143 .189 r
F P
0 g
s
.45045 .29706 m .44317 .32022 L .35116 .35934 L p .266 0 .101 r
F P
0 g
s
.39213 .76728 m .43382 .79404 L .43031 .80863 L p .366 .56 .909 r
F P
0 g
s
.47691 .82186 m .43031 .80863 L .43382 .79404 L p .484 .661 .94 r
F P
0 g
s
.34217 .3941 m .33946 .43696 L .28614 .49297 L p .126 0 .381 r
F P
0 g
s
.2903 .53562 m .28614 .49297 L .33946 .43696 L p .248 .137 .526 r
F P
0 g
s
.55137 .29569 m .55372 .31855 L .44317 .32022 L p .572 .143 .189 r
F P
0 g
s
.52632 .82641 m .57517 .81765 L .57494 .82612 L closepath p .676 .805 .944 r
F P
0 g
s
.34217 .3941 m .35116 .35934 L .44317 .32022 L p .409 .108 .34 r
F P
0 g
s
.66263 .77557 m .62143 .80023 L .61231 .78531 L p .823 .869 .88 r
F P
0 g
s
.61231 .78531 m .65063 .75397 L .66263 .77557 L p .823 .869 .88 r
F P
0 g
s
.32025 .62589 m .3451 .67021 L .32581 .6998 L p .17 .273 .728 r
F P
0 g
s
.35577 .73533 m .32581 .6998 L .3451 .67021 L p .284 .395 .8 r
F P
0 g
s
.43382 .79404 m .47923 .81412 L .47691 .82186 L p .484 .661 .94 r
F P
0 g
s
.52632 .82641 m .47691 .82186 L .47923 .81412 L closepath p .581 .744 .954 r
F P
0 g
s
.72949 .63976 m .70982 .67926 L .67778 .65185 L p .933 .839 .729 r
F P
0 g
s
.67778 .65185 m .69698 .60623 L .72949 .63976 L p .933 .839 .729 r
F P
0 g
s
.52632 .82641 m .5603 .80385 L .57015 .80996 L closepath p .677 .8 .941 r
F P
0 g
s
.52632 .82641 m .54659 .79983 L .5603 .80385 L closepath p .674 .791 .937 r
F P
0 g
s
.52632 .82641 m .53048 .7982 L .54659 .79983 L closepath p .665 .778 .933 r
F P
0 g
s
.52632 .82641 m .51385 .79903 L .53048 .7982 L closepath p .649 .762 .932 r
F P
0 g
s
.52632 .82641 m .49868 .80219 L .51385 .79903 L closepath p .627 .75 .936 r
F P
0 g
s
.52632 .82641 m .48671 .80737 L .49868 .80219 L closepath p .605 .744 .942 r
F P
0 g
s
.52632 .82641 m .47923 .81412 L .48671 .80737 L closepath p .589 .742 .949 r
F P
0 g
s
.52632 .82641 m .57015 .80996 L .57517 .81765 L closepath p .676 .803 .943 r
F P
0 g
s
.62143 .80023 m .57517 .81765 L .57015 .80996 L p .756 .841 .916 r
F P
0 g
s
.57015 .80996 m .61231 .78531 L .62143 .80023 L p .756 .841 .916 r
F P
0 g
s
.65001 .35325 m .65598 .38654 L .5552 .35257 L p .8 .436 .367 r
F P
0 g
s
.5552 .35257 m .55372 .31855 L .65001 .35325 L p .8 .436 .367 r
F P
0 g
s
.3451 .67021 m .37538 .71182 L .35577 .73533 L p .284 .395 .8 r
F P
0 g
s
.39213 .76728 m .35577 .73533 L .37538 .71182 L p .377 .498 .854 r
F P
0 g
s
.72206 .47659 m .71918 .51731 L .65524 .47475 L p .925 .679 .546 r
F P
0 g
s
.65524 .47475 m .65781 .42757 L .72206 .47659 L p .925 .679 .546 r
F P
0 g
s
.44748 .78146 m .48671 .80737 L .47923 .81412 L p .526 .667 .926 r
F P
0 g
s
.47923 .81412 m .43382 .79404 L .44748 .78146 L p .526 .667 .926 r
F P
0 g
s
.37538 .71182 m .40993 .7493 L .39213 .76728 L p .377 .498 .854 r
F P
0 g
s
.43382 .79404 m .39213 .76728 L .40993 .7493 L p .456 .586 .895 r
F P
0 g
s
.33946 .43696 m .34345 .486 L .2903 .53562 L p .248 .137 .526 r
F P
0 g
s
.30177 .58047 m .2903 .53562 L .34345 .486 L p .332 .26 .624 r
F P
0 g
s
.70982 .67926 m .68345 .71794 L .65364 .69614 L p .896 .842 .784 r
F P
0 g
s
.65364 .69614 m .67778 .65185 L .70982 .67926 L p .896 .842 .784 r
F P
0 g
s
.40993 .7493 m .44748 .78146 L .43382 .79404 L p .456 .586 .895 r
F P
0 g
s
.61231 .78531 m .57015 .80996 L .5603 .80385 L p .749 .821 .908 r
F P
0 g
s
.47066 .77168 m .49868 .80219 L .48671 .80737 L p .576 .681 .912 r
F P
0 g
s
.48671 .80737 m .44748 .78146 L .47066 .77168 L p .576 .681 .912 r
F P
0 g
s
.68345 .71794 m .65063 .75397 L .62529 .73736 L p .854 .84 .83 r
F P
0 g
s
.62529 .73736 m .65364 .69614 L .68345 .71794 L p .854 .84 .83 r
F P
0 g
s
.65063 .75397 m .61231 .78531 L .59376 .77377 L p .807 .833 .871 r
F P
0 g
s
.5603 .80385 m .59376 .77377 L .61231 .78531 L p .749 .821 .908 r
F P
0 g
s
.59376 .77377 m .5603 .80385 L .54659 .79983 L p .734 .794 .9 r
F P
0 g
s
.59376 .77377 m .62529 .73736 L .65063 .75397 L p .807 .833 .871 r
F P
0 g
s
.44317 .32022 m .4386 .35478 L .34217 .3941 L p .409 .108 .34 r
F P
0 g
s
.33946 .43696 m .34217 .3941 L .4386 .35478 L p .486 .252 .484 r
F P
0 g
s
.71918 .51731 m .71083 .56091 L .64831 .52603 L p .909 .714 .626 r
F P
0 g
s
.64831 .52603 m .65524 .47475 L .71918 .51731 L p .909 .714 .626 r
F P
0 g
s
.50107 .76551 m .51385 .79903 L .49868 .80219 L p .627 .703 .9 r
F P
0 g
s
.49868 .80219 m .47066 .77168 L .50107 .76551 L p .627 .703 .9 r
F P
0 g
s
.4386 .35478 m .44317 .32022 L .55372 .31855 L p .642 .305 .386 r
F P
0 g
s
.34345 .486 m .35399 .53868 L .30177 .58047 L p .332 .26 .624 r
F P
0 g
s
.32025 .62589 m .30177 .58047 L .35399 .53868 L p .393 .354 .696 r
F P
0 g
s
.54659 .79983 m .56701 .7664 L .59376 .77377 L p .734 .794 .9 r
F P
0 g
s
.56701 .7664 m .54659 .79983 L .53048 .7982 L p .708 .763 .895 r
F P
0 g
s
.55372 .31855 m .5552 .35257 L .4386 .35478 L p .642 .305 .386 r
F P
0 g
s
.53475 .76363 m .53048 .7982 L .51385 .79903 L p .672 .731 .895 r
F P
0 g
s
.51385 .79903 m .50107 .76551 L .53475 .76363 L p .672 .731 .895 r
F P
0 g
s
.53048 .7982 m .53475 .76363 L .56701 .7664 L p .708 .763 .895 r
F P
0 g
s
.44286 .73489 m .47066 .77168 L .44748 .78146 L p .546 .621 .878 r
F P
0 g
s
.44748 .78146 m .40993 .7493 L .44286 .73489 L p .546 .621 .878 r
F P
0 g
s
.65598 .38654 m .65781 .42757 L .55564 .39672 L p .812 .519 .493 r
F P
0 g
s
.55564 .39672 m .5552 .35257 L .65598 .38654 L p .812 .519 .493 r
F P
0 g
s
.35399 .53868 m .37038 .59225 L .32025 .62589 L p .393 .354 .696 r
F P
0 g
s
.3451 .67021 m .32025 .62589 L .37038 .59225 L p .44 .432 .753 r
F P
0 g
s
.62529 .73736 m .59376 .77377 L .56701 .7664 L p .778 .79 .863 r
F P
0 g
s
.71083 .56091 m .69698 .60623 L .63736 .57907 L p .89 .739 .688 r
F P
0 g
s
.63736 .57907 m .64831 .52603 L .71083 .56091 L p .89 .739 .688 r
F P
0 g
s
.41612 .69211 m .44286 .73489 L .40993 .7493 L p .514 .561 .841 r
F P
0 g
s
.40993 .7493 m .37538 .71182 L .41612 .69211 L p .514 .561 .841 r
F P
0 g
s
.37038 .59225 m .39153 .64409 L .3451 .67021 L p .44 .432 .753 r
F P
0 g
s
.37538 .71182 m .3451 .67021 L .39153 .64409 L p .48 .499 .8 r
F P
0 g
s
.39153 .64409 m .41612 .69211 L .37538 .71182 L p .48 .499 .8 r
F P
0 g
s
.48814 .72551 m .50107 .76551 L .47066 .77168 L p .623 .659 .864 r
F P
0 g
s
.47066 .77168 m .44286 .73489 L .48814 .72551 L p .623 .659 .864 r
F P
0 g
s
.65364 .69614 m .62529 .73736 L .58702 .72661 L p .813 .783 .824 r
F P
0 g
s
.56701 .7664 m .58702 .72661 L .62529 .73736 L p .778 .79 .863 r
F P
0 g
s
.69698 .60623 m .67778 .65185 L .62298 .6315 L p .867 .758 .739 r
F P
0 g
s
.62298 .6315 m .63736 .57907 L .69698 .60623 L p .867 .758 .739 r
F P
0 g
s
.4386 .35478 m .43723 .39965 L .33946 .43696 L p .486 .252 .484 r
F P
0 g
s
.34345 .486 m .33946 .43696 L .43723 .39965 L p .532 .349 .578 r
F P
0 g
s
.58702 .72661 m .56701 .7664 L .53475 .76363 L p .738 .745 .858 r
F P
0 g
s
.67778 .65185 m .65364 .69614 L .60594 .68124 L p .842 .772 .784 r
F P
0 g
s
.58702 .72661 m .60594 .68124 L .65364 .69614 L p .813 .783 .824 r
F P
0 g
s
.60594 .68124 m .62298 .6315 L .67778 .65185 L p .842 .772 .784 r
F P
0 g
s
.53904 .72254 m .53475 .76363 L .50107 .76551 L p .686 .7 .857 r
F P
0 g
s
.50107 .76551 m .48814 .72551 L .53904 .72254 L p .686 .7 .857 r
F P
0 g
s
.65781 .42757 m .65524 .47475 L .55498 .44886 L p .812 .575 .579 r
F P
0 g
s
.55498 .44886 m .55564 .39672 L .65781 .42757 L p .812 .575 .579 r
F P
0 g
s
.53475 .76363 m .53904 .72254 L .58702 .72661 L p .738 .745 .858 r
F P
0 g
s
.43723 .39965 m .4386 .35478 L .5552 .35257 L p .674 .405 .505 r
F P
0 g
s
.5552 .35257 m .55564 .39672 L .43723 .39965 L p .674 .405 .505 r
F P
0 g
s
.47544 .67895 m .48814 .72551 L .44286 .73489 L p .617 .616 .827 r
F P
0 g
s
.44286 .73489 m .41612 .69211 L .47544 .67895 L p .617 .616 .827 r
F P
0 g
s
.43723 .39965 m .4393 .45256 L .34345 .486 L p .532 .349 .578 r
F P
0 g
s
.35399 .53868 m .34345 .486 L .4393 .45256 L p .561 .421 .647 r
F P
0 g
s
.60594 .68124 m .58702 .72661 L .53904 .72254 L p .759 .724 .82 r
F P
0 g
s
.65524 .47475 m .64831 .52603 L .55324 .50599 L p .807 .615 .643 r
F P
0 g
s
.55324 .50599 m .55498 .44886 L .65524 .47475 L p .807 .615 .643 r
F P
0 g
s
.46349 .62639 m .47544 .67895 L .41612 .69211 L p .608 .573 .789 r
F P
0 g
s
.41612 .69211 m .39153 .64409 L .46349 .62639 L p .608 .573 .789 r
F P
0 g
s
.54323 .67507 m .53904 .72254 L .48814 .72551 L p .695 .669 .82 r
F P
0 g
s
.48814 .72551 m .47544 .67895 L .54323 .67507 L p .695 .669 .82 r
F P
0 g
s
.53904 .72254 m .54323 .67507 L .60594 .68124 L p .759 .724 .82 r
F P
0 g
s
.4393 .45256 m .4447 .51031 L .35399 .53868 L p .561 .421 .647 r
F P
0 g
s
.37038 .59225 m .35399 .53868 L .4447 .51031 L p .582 .478 .702 r
F P
0 g
s
.62298 .6315 m .60594 .68124 L .54323 .67507 L p .776 .701 .781 r
F P
0 g
s
.45299 .56935 m .46349 .62639 L .39153 .64409 L p .597 .528 .748 r
F P
0 g
s
.39153 .64409 m .37038 .59225 L .45299 .56935 L p .597 .528 .748 r
F P
0 g
s
.4393 .45256 m .43723 .39965 L .55564 .39672 L p .69 .472 .587 r
F P
0 g
s
.4447 .51031 m .45299 .56935 L .37038 .59225 L p .582 .478 .702 r
F P
0 g
s
.64831 .52603 m .63736 .57907 L .55056 .56474 L p .799 .648 .695 r
F P
0 g
s
.55056 .56474 m .55324 .50599 L .64831 .52603 L p .799 .648 .695 r
F P
0 g
s
.55564 .39672 m .55498 .44886 L .4393 .45256 L p .69 .472 .587 r
F P
0 g
s
.63736 .57907 m .62298 .6315 L .54714 .62193 L p .789 .676 .74 r
F P
0 g
s
.54323 .67507 m .54714 .62193 L .62298 .6315 L p .776 .701 .781 r
F P
0 g
s
.54714 .62193 m .55056 .56474 L .63736 .57907 L p .789 .676 .74 r
F P
0 g
s
.54714 .62193 m .54323 .67507 L .47544 .67895 L p .7 .636 .782 r
F P
0 g
s
.47544 .67895 m .46349 .62639 L .54714 .62193 L p .7 .636 .782 r
F P
0 g
s
.4447 .51031 m .4393 .45256 L .55498 .44886 L p .698 .524 .648 r
F P
0 g
s
.55498 .44886 m .55324 .50599 L .4447 .51031 L p .698 .524 .648 r
F P
0 g
s
.55056 .56474 m .54714 .62193 L .46349 .62639 L p .702 .602 .742 r
F P
0 g
s
.46349 .62639 m .45299 .56935 L .55056 .56474 L p .702 .602 .742 r
F P
0 g
s
.45299 .56935 m .4447 .51031 L .55324 .50599 L p .702 .566 .698 r
F P
0 g
s
.55324 .50599 m .55056 .56474 L .45299 .56935 L p .702 .566 .698 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`1X
oooooaco0000:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo000[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0I?ooool?o`0000koIP0000?o0000oiX9
0?l000000_l0000Wooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool0027o
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0H?ooool4o`0001coIP0000?o0000oiX90?nJ2@000_nJ2@03o`0002Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0]ooooo`008oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0GOooool2o`0000;o0@0000?o0000ofH00?mV0000
7?mV00000ol0003oVPT0oiX90004oiX900?o00008Oooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02cooooo000Hooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0F_ooool2o`0000;o0@008ol00008oiX900?o00007_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo000Sooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Fooooo`?o00000_l10002
o`000003od@06Ol0003oTR@`01koTR@`00?o0000ol1;:?l000000_l00008oiX900?o00006oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo
00Cooooo0_l0000Booooo`03o`000?oooooooooo05?ooooo0_l00003o`4000;o00000om401T00ol0
003oTR@`oi8T<00Moi8T<003o`000?o0BbSo`4/X00;o`4/X0ol00007oiX900Co00006?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1?ooooo`?o00000_l10003o`0000Co
A00I00?o0000oi8T<?nB93007_nB93000ol0003o`4/Xol1;:005ol1;:0?o00001onJ2@03o`0001Ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`008oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0C?ooool2o`0000?o0@00
0_l00007od@06@03o`000?nB933oTR@`01koTR@`00?o0000ol1;:?o0BbP02?o0BbP3o`0000OoVPT0
0ol0000Cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Sooooo0ol0
0003o`4000;o00002Om401T00ol0003oTR@`oi8T<00Noi8T<003o`000?o0BbSo`4/X00_o`4/X0_l0
0008oiX900;o00004Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Wooooo000Z
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0AOooool3o`0000?o0@000_l0000;
od@06@03o`000?nB933oTR@`01koTR@`00?o0000ol1;:?o0BbP03Oo0BbP3o`0000GoVPT000?o0000
oihG0?l000004?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Yoooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0@oooool00ol0003o0@00o`400002o`40
00;o00003?m401T00ol0003oTR@`oi8T<00>oi8T<1?o00004Oo0BbP3o`0000?oVPT000?o0000oihG
0?l000003oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Yooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0@Oooool01?l0003o0@00o`400?l10002o`00
00goA00I4_l0000AojA>HP03o`000?o<Kego000000;o00004Oo0BbP3o`000004oiX90?l0003oWQL0
o`0000kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Wooooo`00:Oooool2o`00
01[ooooo00?o0000ooooooooool0?oooool00ol0003o0@00o`000002o`0000coA00I0ol000000omX
6eOo0000ojA>HP0PojA>HP03o`000?o<Kegoc6mM00;oc6mM0ol0000Aol1;:0?o000000?oWQL0o`00
0?ooool03Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo000Yooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0?Oooool3o`0000goA00I0_l00004ofPKE`03
o`000?nTCV;oY4iR01ooY4iR00?o0000ola_GOo<Ked01Oo<Ked3o`00017o`4/X0ol0000=ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool09_ooool002Wooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0kooooo`;o00003Om401T2o`0000GoJ1]G00?o0000ojA>H_nTCV80
8?nTCV800ol0003oc6mMola_G@08ola_G@?o00003_o0BbP01?l0003oeUd3o`000?l0000<ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0iooooo`03o`000?m401WoA00I00[oA00I0ol00007ofPKE`03o`00
0?nTCV;oY4iR023oY4iR00?o0000ola_GOo<Ked02oo<Ked3o`0000co`4/X00?o0000omIM0ol00000
0_l0000:ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0hooooo`03o`000?m401WoA00I00SoA00I0_l0
000:ofPKE`03o`000?nTCV;oY4iR027oY4iR00?o0000ola_GOo<Ked03Oo<Ked2o`0000[o`4/X00Ko
0000omIM0ooFG@?o0000oihG0?l00009ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool09?ooool002Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0fooooo`03o`00
0?m401WoA00I00KoA00I0ol0000<ofPKE`03o`000?nTCV;oY4iR027oY4iR00?o0000ola_GOo<Ked0
3oo<Ked3o`0000Oo`4/X00Oo0000omIM0ooFG@?oeUd3o`000?nN5`3o000000Sooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Sooooo`00:?ooool2o`00027ooooo00?o0000oooooooo
ool0=?ooool00ol0003oA00Iod@06@05od@06@;o00003omX6eL00ol0003oY4iRojA>HP0QojA>HP03
o`000?o<Kegoc6mM01;oc6mM0ol00005ol1;:007o`000?oFG@?oeUd3omIM0ol0003oWQL0o`000007
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool002Sooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0booooo`;o00001?m401T3o`00013oJ1]G00?o0000ojA>
H_nTCV808_nTCV800ol0003oc6mMola_G@0Eola_G@?o00000_o0BbP00ol0003oeUd3omIM0`02omIM
0`03o`000?nN5`3o000000Kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Roooo
o`00:?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo033ooooo0_l00003od@06@;o
00004omX6eL00ol0003oY4iRojA>HP0RojA>HP03o`000?o<Kegoc6mM01Soc6mM0ol00005omIM0`03
o`000?nN5`3o000000Gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Qooooo`00
:?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo0ol000000om401Wo0000
o`00000DofPKEbWo00006oo<Ked2o`0000CoeUd30ol00004ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool08Oooool002Oooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0/ooooo`Go00005?mX6eL2o`000003oga0Nol0003o[6N102?o[6N100?o0000oln4O_o?Q7h00ol0
000Hola_G@03o`000?oZR4Co000000GoeUd30_l00003ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08?ooool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Z
ooooo`?o00005?mX6eL3o`0000?oO41k00?o0000ojaWPOn/Ih408_n/Ih400ol0003ochAnoln4OP03
oln4OP?o00005Oo<Ked01?l0003ojXQ4onZ8A?l00005omIM0`;o00000_ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0:?ooool4o`0001;oJ1]G0_l00006oga0N`03o`000?n/Ih7o[6N102;o[6N100?o0000
oln4O_o?Q7h01_o?Q7h3o`0001;oc6mM00Go0000onZ8A?oZR4CojXQ4o`000005omIM0`04o`000?oo
ooooooooo`0003kooooo00?o0000ooooooooool07oooool002Oooooo0_l0000Yooooo`03o`000?oo
oooooooo02Oooooo1?l0000@ofPKE`;o00002?ml@7/00ol0003o[6N1ojaWP@0RojaWP@03o`000?o?
Q7kochAn00WochAn0ol0000?ola_G@03o`000?oZR4CojXQ400;ojXQ400?o0000omIM0ooFG@<00ooF
G@<00ol0003oooooo`00000oooooo`03o`000?oooooooooo01kooooo000Wooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09Oooool4o`0000koJ1]G0ol0000:oga0N`03o`000?n/Ih7o
[6N102;o[6N100?o0000oln4O_o?Q7h03?o?Q7h3o`0000coc6mM00?o0000onZ8A?oZR4@00ooZR4@0
0ol0003oeUd3omIM0`03omIM0`;o0000?oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo02?ooooo0ol000000ol002So0000ofPKE`0;ofPK
E`;o00003Oml@7/00ol0003o[6N1ojaWP@0RojaWP@03o`000?o?Q7kochAn00oochAn0ol0000:ola_
G@03o`000?oZR4CojXQ400?ojXQ400?o0000omIM0ooFG@<00ooFG@<00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01gooooo000Wooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool08Oooool3o`0000;o000X00?o0000ofPKEomX6eL02?mX6eL2o`0000ooO41k00?o0000ojaWPOn/
Ih408_n/Ih400ol0003ochAnoln4OP0Boln4OP?o00001oo<Ked00ol0003ojXQ4onZ8A004onZ8A003
o`000?oFG@?oeUd300;oeUd30_l0000oooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool07oooool3o`0000;o000X00?o0000ofPKEomX6eL0
1_mX6eL3o`00017oO41k00?o0000ojaWPOn/Ih408_n/Ih400ol0003ochAnoln4OP0Eoln4OP?o0000
1?o<Ked00ol0003ojXQ4onZ8A005onZ8A0;o00000_oFG@<00ol0003oeUd3o`00000oooooo`03o`00
0?oooooooooo01cooooo000Vooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07Ooo
ool4o`0000;o000X00?o0000ofPKEomX6eL01?mX6eL2o`0001CoO41k00?o0000ojaWPOn/Ih408_n/
Ih400ol0003ochAnoln4OP0Holn4OP?o000000?oc6mMo`000?oZR4@02?oZR4@01Ol0003oeUd3o`00
0?oFG@?o0000043ooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_ooooo`03o`000?oo
oooooooo01_ooooo1?l00003o`00:003o`000?mX6eOoJ1]G00;oJ1]G0_l0000Foga0N`03o`000?n/
Ih7o[6N102;o[6N100?o0000oln4O_o?Q7h06oo?Q7h3o`0000WojXQ400Go0000omIM0ol0003oeUd3
o`00000oooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool06Oooool4o`0000Co000X00?o0000ofPKEol000000_l0000Hoga0N`03o`000?n/
Ih7o[6N102;o[6N100?o0000oln4O_o?Q7h07?o?Q7h00ol0003okYm_o`000009onZ8A0;o000000?o
eUd3o`000?ooool0?oooool00ol0003oooooooooo`0Jooooo`002oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01Oooooo1?l00004o`00:0?o00006oml@7/00ol0003o[6N1
ojaWP@0RojaWP@03o`000?o?Q7kochAn01cochAn00Co0000onjOKoo^Wfoo00002OoZR4@01?l0003o
eUd3omIM0ol0000oooooo`03o`000?oooooooooo01[ooooo000;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Kooooo0ol00005o`00:003o`000?ml@7_oO41k01_oO41k00?o0000ojaW
POn/Ih404?n/Ih4Eo`0001cochAn00Go0000onjOKoo^WfookYm_o`000008onZ8A0;o000000?oeUd3
o`000?l00000?oooool00ol0003oooooooooo`0Iooooo`000oooool6o`0000;ooooo00Go410@oooo
oooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Dooooo`?o00001_l002P00ol0003oO41koga0N`0Joga0NaCo00004_n`N9H0
0ol0003oci>DolnCU003o`0001WochAn00?o0000onjOKoo^Wfl00_o^Wfl00ol0003ojXQ4onZ8A005
onZ8A003o`000?oZR4Co000000;o0000@?ooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0
003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo01?ooooo0_l00006o`00:0;o00006Oml@7/3o`000003ohQITol0003o
/7RF02?o/7RF00?o0000olnCU?o?Ti@00oo?Ti@3o`0001KochAn00?o0000onjOKoo^Wfl00oo^Wfl0
0ol0003ojXQ4onZ8A004onZ8A003o`000?oZR4CojXQ400?o0000?oooool00ol0003oooooooooo`0H
ooooo`002oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04Oooool3o`0000Go000X00?o
0000ob00HOl000005oml@7/2o`0000CoR5VC00?o0000ok1hU_n`N9H08_n`N9H00ol0003oci>DolnC
U006olnCU0?o00004oo?Q7h00ol0003okYm_onjOK`04onjOK`;o00001?oZR4@01?l0003ojXQ4onZ8
A?oZR4@2o`00043ooooo00?o0000ooooooooool05oooool000_ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000hooooo`03o`000?oooooooooo00oooooo
0ol00005o`00:004o`000?lP067o801Qo`0001CoO41k0ol00006ohQIT`03o`000?n`N9Ko/7RF02;o
/7RF00?o0000olnCU?o?Ti@02Oo?Ti@3o`00017ochAn00?o0000onjOKoo^Wfl01Oo^Wfl01Ol0003o
jXQ4onZ8A?oZR4Co000000CojXQ40_l0000oooooo`03o`000?oooooooooo01Oooooo000;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool03_ooool2o`0000Go000X00Go0000ob00HOlP067o801Qo`00000A
oga0N`?o00002On8FI<00ol0003o/7RFok1hUP0Rok1hUP03o`000?o?TiCoci>D00coci>D1?l0000=
oln4OP03o`000?o^WfookYm_00KokYm_00Co0000onZ8A?oZR4Co00001?oZR4@00ol0003o^U@0o`00
000oooooo`03o`000?oooooooooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`;o00001Ol0
02P00ol0003o801Qob00H@02ob00H@03o`000?ml@7_oO41k00goO41k0_l0000<ohQIT`03o`000?n`
N9Ko/7RF02;o/7RF00?o0000olnCU?o?Ti@04?o?Ti@3o`0000[ochAn00?o0000onjOKoo^Wfl01oo^
Wfl00ol0003ojXQ4o`000004onZ8A0?o0000?_ooool3o`0001Oooooo000Tooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03?ooool00ol0003o000Xo`00:003o`00:003o`000?lP067o
801Q00;o801Q00?o0000oga0Noml@7/02oml@7/3o`0000koR5VC00?o0000ok1hU_n`N9H08_n`N9H0
0ol0003oci>DolnCU00ColnCU0?o00001oo?Q7h00ol0003okYm_onjOK`08onjOK`;o00001OoZR4@0
0ol0003o^U@0o`00000jooooo`?o00000_ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000o`00:?l002P00ol002P00ol0
003o801Qob00H@03ob00H@03o`000?ml@7_oO41k00WoO41k0_l0000AohQIT`03o`000?n`N9Ko/7RF
02;o/7RF00?o0000olnCU?o?Ti@05_o?Ti@3o`0000CochAn00?o0000onjOKoo^Wfl02Oo^Wfl2o`00
00CojXQ40ol0000gooooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo00Wooooo00?o0000o`00:?l002P00_l002P00ol0003o
801Qob00H@04ob00H@03o`000?ml@7_oO41k00KoO41k0ol0000CohQIT`03o`000?n`N9Ko/7RF02;o
/7RF00?o0000olnCU?o?Ti@06Oo?Ti@3o`000003oln4O_l0003okYm_00[okYm_00?o0000onjOKol0
00000ooZR4@01?l0003oiH/@o`000?l0000cooooo`?o00002?ooool00ol0003oooooooooo`0Eoooo
o`009?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Sooooo00?o0000o`00:?l0
02P00_l002P00ol0003o801Qob00H@04ob00H@03o`000?ml@7_oO41k00?oO41k0ol0000GohQIT`03
o`000?n`N9Ko/7RF027o/7RF00?o0000olnCU?o?Ti@07?o?Ti@3o`0000[okYm_00Co0000onjOKoo^
Wfoo00000_oZR4@01Ol0003oiH/@o`000?njE03o000002oooooo0ol0000;ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`;o0000?oooool00ol0003oooooooooo`06ooooo`03o`000?l002So000X
00;o000X00?o0000ob00HOlP06401OlP06401?l0003oO41koga0Noml@7/2o`0001[oR5VC00?o0000
ok1hU_n`N9H08On`N9H00ol0003oci>DolnCU00MolnCU003o`000?o/[H_o000000WokYm_00Oo0000
onjOKoo^WfookYm_o`000?oZR4Co000000;oiH/@0_l0000/ooooo`?o00003oooool00ol0003ooooo
ooooo`0Dooooo`009?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo00Go
0000o`00:?l002So000Xo`000008ob00H@Co00007?n8FI<00ol0003o/7RFok1hUP0Qok1hUP03o`00
0?o?TiCoci>D01goci>D00Co0000onb]Roo/[H_o00002?o^Wfl00ol0003okYm_onjOK`02onjOK`07
o`000?oZR4Co0000onF;4?l0003o^U@0o`00000Xooooo`?o00004_ooool00ol0003oooooooooo`0D
ooooo`008oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00Cooooo00Co0000o`00
:?l002So00002OlP06400ol0003oR5VCohQIT`0MohQIT`03o`000?n`N9Ko/7RF027o/7RF00?o0000
olnCU?o?Ti@07Oo?Ti@01?l0003ok:f;onb]Roo/[H/2o`0000KokYm_00?o0000onjOKoo^Wfl00oo^
Wfl2o`0000;oiH/@0_l0000Uooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`008oooool0
0ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00Co0000o`00:?l002So00002_lP
06400ol0003oR5VCohQIT`0MohQIT`03o`000?n`N9Ko/7RF027o/7RF00?o0000olnCU?o?Ti@07Oo?
Ti@00ol0003ok:f;onb]R`03onb]R`03o`000?o^WfookYm_00?okYm_00?o0000onjOKoo^Wfl01?o^
Wfl01?l0003oiH/@onF;4?oURa02o`00027ooooo0ol0000Hooooo`03o`000?oooooooooo01Cooooo
000Sooooo`03o`000?oooooooooo04?ooooo00Oo0000ooooooooooooooooo`000?l002So000000[o
801Q0_l0000OohQIT`03o`000?n`N9Ko/7RF027o/7RF00?o0000olnCU?o?Ti@07Oo?Ti@00ol0003o
k:f;onb]R`04onb]R`03o`000?o^WfookYm_00?okYm_00?o0000onjOKoo^Wfl00oo^Wfl01?l0003o
iH/@onF;4?oURa02o`0001kooooo0ol0000Kooooo`03o`000?oooooooooo01Cooooo000Sooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool00_l0000:ob00H@03o`000?lo8hKo000001oo
R5VC00?o0000ok1hU_n`N9H08On`N9H00ol0003oci>DolnCU00MolnCU003o`000?o/[H_ok:f;00Go
k:f;0_l00003onjOK`03o`000?o^WfookYm_00?okYm_0_l00003onF;40;o00006_ooool3o`0001ko
oooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0AOooool3o`0000[o801Q
00Co0000oclSQ_lo8hKo00007on8FI<00ol0003o/7RFok1hUP0?ok1hUQGo00007Oo?Ti@00ol0003o
k:f;onb]R`07onb]R`04o`000?o^WfookYm_o`0000GokYm_0_l00003onF;40;o00005oooool3o`00
027ooooo00?o0000ooooooooool05?ooool002?ooooo0_l00017ooooo`03o`000?lP067o801Q00So
801Q00?o0000oclSQ_lo8hH00_lo8hH00ol0003oR5VCohQIT`0KohQITa?o00004_nbQZD00ol0003o
cYfToljMY004o`0001Soci>D00?o0000onb]Roo/[H/02Oo/[H/00ol0003okYm_o`000005onjOK`03
o`000?oi[TWo000000?oiH/@00?o0000ooooooooool04_ooool3o`0002Gooooo00?o0000oooooooo
ool04oooool002?ooooo00?o0000ooooooooool0A_ooool00ol0003o801Qob00H@07ob00H@03o`00
0?lo8hKo?b>600?o?b>600?o0000ohQITon8FI<06?n8FI<3o`000003ohm[YOl0003o/XJU02;o/XJU
00?o0000oljMY?o>WJ@01?o>WJ@4o`0001Coci>D00?o0000onb]Roo/[H/02_o/[H/2o`0000GokYm_
00Co0000ooV^BOoi[TWo00000ooURa000ol0003oooooooooo`0>ooooo`?o0000:?ooool00ol0003o
ooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`17ooooo`03o`000?lP067o801Q00Ko801Q
00?o0000oclSQ_lo8hH01?lo8hH00ol0003oR5VCohQIT`0EohQIT`?o00001?n?JjD00ol0003o/XJU
ok:6Y@0Qok:6Y@03o`000?o>WJCocYfT00SocYfT1?l0000@olnCU003o`000?o/[H_ok:f;00_ok:f;
0_l00005onjOK`03o`000?oi[TWo000000?oiH/@00?o0000ooooooooool02oooool3o`0002_ooooo
00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool0A_ooool2o`0000Oo801Q00?o
0000oclSQ_lo8hH01Olo8hH00ol0003oR5VCohQIT`0BohQIT`?o00001on?JjD00ol0003o/XJUok:6
Y@0Qok:6Y@03o`000?o>WJCocYfT00cocYfT0ol0000=olnCU003o`000?o/[H_ok:f;00_ok:f;00?o
0000onb]Rol000001?o^Wfl01?l0003onJi9ooV^BOl00003onF;4003o`000?oooooooooo00Oooooo
0ol0000^ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04Kooooo0_l0
0006ob00H@03o`000?lo8hKo?b>600Ko?b>600?o0000ohQITon8FI<03on8FI<3o`0000[oSf^U00?o
0000ok:6YOnbQZD08OnbQZD00ol0003ocYfToljMY00?oljMY0Co00002Oo?Ti@00ol0003ok:f;onb]
R`0;onb]R`03o`000?o/[H_ok:f;00;o00000_o^Wfl01?l0003onJi9ooV^BOl00003onF;4003o`00
0?oooooooooo00Cooooo0ol0000aooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oo
oooooooo04Kooooo00?o000<o`000?lP06401OlP06400ol0003o?b>6oclSQP06oclSQP03o`000?n8
FI?oR5VC00coR5VC0ol0000=ohm[Y@03o`000?nbQZGo/XJU027o/XJU00?o0000oljMY?o>WJ@04oo>
WJ@4o`0000Goci>D00?o0000onb]Roo/[H/02oo/[H/00ol0003ok:f;onb]R`02onb]R`03o`000?o^
Wfoo000000?onJi900Co0000onF;4?oURa3o00000_ooool4o`0003Cooooo00?o0000ooooooooool0
4oooool002;ooooo00?o0000ooooooooool0A_ooool00ol000co0000ob00H@04ob00H@03o`000?lo
8hKo?b>600Oo?b>600?o0000ohQITon8FI<02On8FI<3o`00013oSf^U00?o0000ok:6YOnbQZD08Onb
QZD00ol0003ocYfToljMY00GoljMY0Co000000?oci>Do`000?o/[H/03?o/[H/00ol0003ok:f;onb]
R`03onb]R`;o00001?oi[TT00ol0003oiH/@onF;4002o`0003Sooooo00?o0000ooooooooool04ooo
ool0027ooooo0ol00017ooooo`03o`000?lP067o801Q00?o801Q00?o0000oclSQ_lo8hH02Olo8hH0
0ol0003oR5VCohQIT`05ohQIT`?o00004on?JjD00ol0003o/XJUok:6Y@0Qok:6Y@03o`000?o>WJCo
cYfT01_ocYfT0ol0000<onb]R`03o`000?o/[H_ok:f;00Cok:f;00?o0000ooV^BOoi[TT00_oi[TT0
1?l0003oiH/@onF;4?l0000jooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooo
oooo04Kooooo0_l00004ob00H@03o`000?lo8hKo?b>600[o?b>600?o0000ohQITon8FI<00_n8FI<3
o`0001KoSf^U00?o0000ok:6YOnbQZD08OnbQZD00ol0003ocYfToljMY00LoljMY003o`000?oX]Z3o
000000_ok:f;00?o0000onb]Roo/[H/01?o/[H/00ol0003onJi9ooV^B@03ooV^B@03o`000?oURa3o
000003[ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0A_ooool2o`00
00?o801Q00?o0000oclSQ_lo8hH02olo8hH00ol0003oR5VCo`000002o`0001WoSf^U00?o0000ok:6
YOnbQZD08?nbQZD00ol0003ocYfToljMY00MoljMY003o`000?oX]Z3oj;JP00;o00002Oo/[H/00ol0
003ok:f;onb]R`04onb]R`;o00001?oi[TT00ol0003oiH/@o`00000jooooo`03o`000?oooooooooo
01;ooooo000Qooooo`03o`000?oooooooooo04Kooooo0_l00002ob00H@03o`000?lo8hKo?b>600_o
?b>60ol0000Mohm[Y@03o`000?nbQZGo/XJU01oo/XJU00?o0000oljMY?o>WJ@07Oo>WJ@00ol0003o
j;JPonRfX002onRfX003o`000?o/[H_ok:f;00Kok:f;00?o0000onb]Roo/[H/01?o/[H/00ol0003o
o/9co`000004ooV^B@?o0000>Oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooo
ooooo`16ooooo`04o`003?l0003o801Qo`0000go?b>600?o0000oeA2Wol000007_n?JjD00ol0003o
/XJUok:6Y@0Ook:6Y@03o`000?o>WJCocYfT01gocYfT00?o0000onRfX?oX]Z000ooX]Z02o`0000Ko
k:f;00?o0000onb]Roo/[H/01?o/[H/00ol0003oo/9co`000005ooV^B@;o0000>Oooool00ol0003o
ooooooooo`0Booooo`008Oooool00ol0003oooooooooo`16ooooo`03o`003?l0003o000000go?b>6
00Co0000oeA2WomD@Yoo00007_n?JjD00ol0003o/XJUok:6Y@0Ook:6Y@03o`000?o>WJCocYfT01co
cYfT00?o0000onRfX?oX]Z001_oX]Z000ol0003ok:f;onb]R`03onb]R`03o`000?o/[H_ok:f;00Co
k:f;00Co0000ook2Loon`W?o00001?oi[TT2o`0003Wooooo00?o0000ooooooooool04_ooool0027o
oooo00?o0000ooooooooool0AOooool00ol0003o000<o`00000=oclSQP05o`000?mD@YooE4:OoeA2
Wol000007_n?JjD00ol0003o/XJUok:6Y@0Ook:6Y@03o`000?o>WJCocYfT01cocYfT00?o0000onRf
X?oX]Z001ooX]Z02o`0000?ok:f;00?o0000onb]Roo/[H/01?o/[H/01?l0003oo/9cook2Lol00005
ooV^B@03o`000?oooooooooo03Oooooo00?o0000ooooooooool04_ooool0023ooooo0ol00016oooo
o`03o`000?l000co000000co?b>600?o0000oeA2WomD@Yl00omD@Yl00ol0003oSf^Uohm[Y@0Kohm[
Y@03o`000?nbQZGo/XJU01oo/XJU00?o0000oljMY?o>WJ@07?o>WJ@00ol0003oj;JPonRfX009onRf
X0;o000000?ok:f;o`000?o/[H/01?o/[H/00ol0003oo/9cook2L`02ook2L`03o`000?oi[TWonJi9
00;onJi90_l0000iooooo`03o`000?oooooooooo017ooooo000Pooooo`03o`000?oooooooooo04Ko
oooo00?o0000o`003?l000002olo8hH00ol0003oE4:OoeA2W`04oeA2W`03o`000?n?JjGoSf^U01_o
Sf^U00?o0000ok:6YOnbQZD07onbQZD00ol0003ocYfToljMY00LoljMY003o`000?oX]Z3oj;JP00_o
j;JP00?o0000onb]Rol000001?o/[H/00ol0003oo/9cook2L`03ook2L`04o`000?oi[TWonJi9ooV^
B@;o0000>Oooool00ol0003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0A_ooool3o`0000[o?b>600?o0000oeA2WomD@Yl01OmD@Yl00ol0
003oSf^Uohm[Y@0Kohm[Y@03o`000?nbQZGo/XJU01oo/XJU00?o0000oljMY?o>WJ@07?o>WJ@00ol0
003oj;JPonRfX00<onRfX0;o00001?o/[H/00ol0003oo/9cook2L`03ook2L`04o`000?oi[TWonJi9
ooV^B@;o0000>Oooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0A_ooool00ol000co0000o`000009oclSQP03o`000?mD@Yoo
E4:O00KoE4:O00?o0000ohm[YOn?JjD06on?JjD00ol0003o/XJUok:6Y@0>ok:6YAGo00006oo>WJ@0
0ol0003oj;JPonRfX00=onRfX0;o00000oo/[H/00ol0003oo/9cook2L`04ook2L`03o`000?oi[TWo
nJi900;o0000>Oooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0AOooool01?l0003o000<o`000?l00008oclSQP03o`000?mD
@YooE4:O00OoE4:O00?o0000ohm[YOn?JjD06On?JjDCo`00017o/i2b00Co0000olbU/Oo<YK7oc:Fa
1Ol0000FoljMY003o`000?oX]Z3oj;JP00goj;JP00Ko0000onRfX?l0003o0000onb]Rol00007ook2
L`03o`000?oi[TWo000000;o0000>?ooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0AOooool01?l0003o000<o`000?l00007
oclSQP03o`000?mD@YooE4:O00WoE4:O00?o0000ohm[YOn?JjD05On?JjD3o`0000;oU7Zc00?o0000
ok>@/_ncT;807oncT;800ol0003oc:FaolbU/@06olbU/@Go00004Oo>WJ@00ol0003oj;JPonRfX00=
onRfX004o`000?oX]Z3oj;JPonRfX0;o00001oon`W<00ol0003onJi9ooV^B@02o`0003Sooooo00?o
0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo04Kooooo0_l00002o`00BP03o`000?lo8hKo?b>600?o?b>600?o0000oeA2WomD@Yl02_mD
@Yl00ol0003oSf^Uohm[Y@0Bohm[Y@?o00001OnDN[<00ol0003o/i2bok>@/P0Ook>@/P03o`000?o<
YK7oc:Fa00_oc:Fa1Ol0000;oljMY003o`000?oX]Z3oj;JP00koj;JP00?o0000onRfX?oX]Z000_oX
]Z000ol0003oo/9cook2L`06ook2L`04o`000?oi[TWo0000o`0003Sooooo00?o0000ooooooooool0
4Oooool001Gooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000Aoooool2o`0000;o001:
00?o0000oclSQ_lo8hH00_lo8hH00ol0003oE4:OoeA2W`0;oeA2W`03o`000?n?JjGoSf^U00ooSf^U
0ol00008oiAj/`03o`000?ncT;;o/i2b01oo/i2b00?o0000olbU/Oo<YK404?o<YK45o`0000KocYfT
00?o0000onRfX?oX]Z003_oX]Z000ol0003oj;JPonRfX002onRfX003o`000?on`W?oo/9c00Koo/9c
00Co0000ooV^BOl0003o0000>?ooool00ol0003oooooooooo`0Aooooo`005Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0A_ooool2o`0000;o001:00Go0000oclSQ_lo
8hKo?b>6o`00000>oeA2W`03o`000?n?JjGoSf^U00coSf^U0ol0000<oiAj/`03o`000?ncT;;o/i2b
01ko/i2b00?o0000olbU/Oo<YK405Oo<YK45o`000003oljMY?l0003oj;JP00ooj;JP00?o0000onRf
X?oX]Z000_oX]Z02o`0000Soo/9c1?l0000hooooo`03o`000?oooooooooo013ooooo000Eooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`16ooooo`05o`003?l0003o001:
o`00B_l000000_lo8hH00ol0003oE4:OoeA2W`0=oeA2W`03o`000?n?JjGoSf^U00WoSf^U0ol0000?
oiAj/`03o`000?ncT;;o/i2b01ko/i2b00?o0000olbU/Oo<YK406_o<YK43o`0000ooj;JP00?o0000
onRfX?oX]Z000_oX]Z000ol0003oo<jBo`000008ook2L`03o`000?oMXAWo000003Sooooo00?o0000
ooooooooool04?ooool001oooooo00?o0000ooooooooool0A_ooool01ol000co0000o`00B_l004[o
0000oclSQ_l000004?mD@Yl00ol0003oSf^Uohm[Y@06ohm[Y@?o00004_nDN[<00ol0003o/i2bok>@
/P0Nok>@/P03o`000?o<YK7oc:Fa01_oc:Fa00Co0000on>m/?l0003o00003OoX]Z001Ol0003oj;JP
onRfX?oX]Z3o000000;oo<jB00?o0000ook2Loon`W<01_on`W<00ol0003ogJ4Io`00000hooooo`03
o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo04Gooooo0_l00003o`00BP;o0000
4_mD@Yl00ol0003oSf^Uohm[Y@02ohm[Y@?o00005OnDN[<00ol0003o/i2bok>@/P0Nok>@/P03o`00
0?o<YK7oc:Fa01_oc:Fa00Co0000on>m/?oS_K3ohkf`0_l0000;onRfX005o`000?oX]Z3oj;JPonRf
X?l000000oolcY800ol0003oo/9cook2L`05ook2L`03o`000?oMXAWo000003Sooooo00?o0000oooo
ooooool04?ooool001oooooo00?o0000ooooooooool0AOooool2o`0000?o001:00?o0000oeA2WomD
@Yl04OmD@Yl00ol0003oSf^Uo`000002o`0001SoU7Zc00?o0000ok>@/_ncT;807_ncT;800ol0003o
c:FaolbU/@0KolbU/@03o`000?oS_K3ohkf`00?ohkf`00?o0000onRfX?oX]Z002?oX]Z001Ol0003o
j;JPonRfX?oX]Z3o000000Coo<jB00?o0000ook2Loon`W<01?on`W<3o`0003Sooooo00?o0000oooo
ooooool04?ooool001kooooo00?o0000ooooooooool0A_ooool2o`0000?o001:00?o0000oeA2WomD
@Yl04?mD@Yl3o`0001_oU7Zc00?o0000ok>@/_ncT;807OncT;800ol0003oc:FaolbU/@0KolbU/@03
o`000?oS_K3ohkf`00Gohkf`0_l00008onRfX005o`000?oX]Z3oj;JPonRfX?l000001?olcY800ol0
003oo/9cook2L`04ook2L`;o000000?ogJ4Io`000?ooool0=_ooool00ol0003oooooooooo`0@oooo
o`007_ooool00ol0003oooooooooo`16ooooo`;o00000ol004X00ol0003oE4:OoeA2W`0?oeA2W`03
o`000?mTF[;o000001goU7Zc00?o0000ok>@/_ncT;807?ncT;800ol0003oc:FaolbU/@0KolbU/@03
o`000?oS_K3ohkf`00Oohkf`0_l00006onRfX005o`000?oX]Z3oj;JPonRfX?l000001OolcY800ol0
003oo/9cook2L`03ook2L`;o000000?ogJ4Io`000?ooool0=_ooool00ol0003oooooooooo`0@oooo
o`007_ooool2o`0004Oooooo00Oo0000o`00B_l004[o001:o`000?l007co000000ooE4:O00Co0000
ofAJ/_mTF[;o00007OnDN[<00ol0003o/i2bok>@/P0Lok>@/P03o`000?o<YK7oc:Fa01_oc:Fa00?o
0000on>m/?oS_K002OoS_K02o`0000Coj;JP00Go0000onRfX?oX]Z3oj;JPo`000006ooc>TP03o`00
0?on`W?oo/9c00;oo/9c0_l000000ooMXAWo0000ooooo`0gooooo`03o`000?oooooooooo00oooooo
000Nooooo`03o`000?oooooooooo04Kooooo00Oo0000o`00B_l004[o001:o`000?l007co000000ko
E4:O00?o0000ofAJ/_mTF[800_mTF[800ol0003oU7ZcoiAj/`0JoiAj/`03o`000?ncT;;o/i2b01co
/i2b00?o0000olbU/Oo<YK406oo<YK400ol0003ohkf`on>m/00;on>m/0;o00000_oX]Z001Ol0003o
j;JPonRfX?oX]Z3o000000Koo<jB00Go0000ook2Loon`W?oo/9co`000002oo?1C0;o0000>?ooool0
0ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`16ooooo`07o`000?l004[o001:
o`00B_l0003o001lo`00000<oeA2W`;o00001OmTF[800ol0003oU7ZcoiAj/`0JoiAj/`03o`000?nc
T;;o/i2b01co/i2b00?o0000olbU/Oo<YK406oo<YK400ol0003ohkf`on>m/00=on>m/003o`000?oX
]Z3o000000;oj;JP00?o0000ooc>T_olcY801_olcY801?l0003oo/9cook2Lol00002oo?1C0;o0000
>?ooool00ol0003oooooooooo`0?ooooo`007_ooool00ol0003oooooooooo`16ooooo`05o`000?l0
04[o001:o`00B_l000000_l007`00ol0003oE4:OoeA2W`08oeA2W`03o`000?mTF[;oI5Zb00GoI5Zb
00?o0000oiAj/onDN[<06_nDN[<00ol0003o/i2bok>@/P0Lok>@/P03o`000?o<YK7oc:Fa01[oc:Fa
00?o0000on>m/?oS_K003ooS_K02o`0000;oj;JP00?o0000ooc>T_olcY801oolcY800ol0003oo/9c
o`000002oo?1C0;o0000>?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003ooooooooo
o`17ooooo`04o`000?l004[o001:o`0000?o001l00?o0000oeA2WomD@Yl01omD@Yl00ol0003oI5Zb
ofAJ/P07ofAJ/P03o`000?nDN[?oU7Zc01WoU7Zc00?o0000ok>@/_ncT;807?ncT;800ol0003oc:Fa
olbU/@0JolbU/@03o`000?oS_K3ohkf`013ohkf`1?l00009ooc>TP03o`000?on`W?o000000?oll5<
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003ooooooooo
o`17ooooo`04o`000?l004[o001:o`0000?o001l00?o0000oeA2WomD@Yl01_mD@Yl00ol0003oI5Zb
ofAJ/P08ofAJ/P03o`000?nDN[?oU7Zc01[oU7Zc00?o0000ok>@/_ncT;806oncT;800ol0003oc:Fa
olbU/@0JolbU/@03o`000?oS_K3ohkf`017ohkf`00?o0000on>m/?l000002_olcY82o`0000?oll5<
0_l0000gooooo`03o`000?oooooooooo00oooooo000Mooooo`03o`000?oooooooooo04Oooooo00Co
0000o`00B_l004[o00000ol007`00ol0003oE4:OoeA2W`05oeA2W`03o`000?mTF[;oI5Zb00WoI5Zb
00?o0000oiAj/onDN[<06_nDN[<00ol0003o/i2bok>@/P0<ok>@/Q?o00006Oo<YK400ol0003ohkf`
on>m/00Aon>m/003o`000?oS_K3o000000_oo<jB00Co0000oo?1C?oc`Dcoll5<0_l0000gooooo`03
o`000?oooooooooo00oooooo000Mooooo`;o0000B?ooool01?l0003o001:o`00B_l00004o`00O003
o`000?mD@YooE4:O00;oE4:O0_l0000=ofAJ/P03o`000?nDN[?oU7Zc01OoU7Zc4Ol0000?ok>J_@04
o`000?o9[KgobJfmolV]_@Go00005?o<YK400ol0003ohkf`on>m/00Aon>m/0;o000000?om]BXo`00
0?olcY802OolcY801?l0003oll5<oo?1C?oc`D`2o`0003Sooooo00?o0000ooooooooool03_ooool0
01gooooo00?o0000ooooooooool0B?ooool2o`0000Go001l00Go0000oeA2WomD@YooE4:Oo`00000?
ofAJ/P03o`000?nDN[?oU7Zc01CoU7Zc0ol00002oiR7_`03o`000?ncV[go/iZm01_o/iZm00?o0000
olV]_Oo9[Kd01_o9[Kd6o`0000koc:Fa00?o0000on>m/?oS_K004OoS_K02o`0000;om]BX00?o0000
ooc>T_olcY801oolcY800ol0003oll5<oo?1C002oo?1C003o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool001gooooo00?o0000ooooooooool0B?ooool2o`0000Go001l00Co0000oeA2
WomD@Yoo00004?mTF[800ol0003oU7ZcoiAj/`0AoiAj/`?o00001OnHQkl00ol0003o/iZmok>J_@0K
ok>J_@03o`000?o9[KgobJfm00cobJfm1_l00007olbU/@03o`000?oS_K3ohkf`01;ohkf`0_l00003
ooKDZ003o`000?olcY;oo<jB00Koo<jB0_l00003oo?1C003o`000?oooooooooo03Kooooo00?o0000
ooooooooool03_ooool001cooooo00?o0000ooooooooool0BOooool00ol004[o0000o`00O005o`00
O0;o00004OmTF[800ol0003oU7ZcoiAj/`0>oiAj/`?o00002?nHQkl00ol0003o/iZmok>J_@0Kok>J
_@03o`000?o9[KgobJfm01;obJfm1Ol00002olbU/@03o`000?oS_K3ohkf`01;ohkf`00?o0000ooKD
Z?ofe:P00oofe:P00ol0003oo<jBooc>TP04ooc>TP03o`000?omeWOo000000?oll5<00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`19ooooo`03
o`00B_l0003o001l00Go001l00?o0000ofAJ/_mTF[804OmTF[800ol0003oU7ZcoiAj/`09oiAj/`Co
00003?nHQkl00ol0003o/iZmok>J_@0Jok>J_@03o`000?o9[KgobJfm01OobJfm1?l0000Con>m/003
o`000?ofe:Som]BX00Com]BX00?o0000ooc>T_olcY800oolcY800ol0003ooMIgo`000003oo?1C003
o`000?oooooooooo03Kooooo00?o0000ooooooooool03_ooool001cooooo00?o0000ooooooooool0
BOooool00ol0003o001lo`00O005o`00O003o`000?mTF[;oI5Zb017oI5Zb00?o0000oiAj/onDN[<0
1_nDN[<3o`00013oV8No00?o0000ok>J_OncV[d06_ncV[d00ol0003obJfmolV]_@0IolV]_@04o`00
0?oM`[go0000o`00017ohkf`00?o0000ooKDZ?ofe:P01?ofe:P00ol0003oo<jBooc>TP03ooc>TP04
o`000?omeWOooMIgo`0000;oll5<00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0>oooo
o`007?ooool00ol0003oooooooooo`19ooooo`03o`000?l007co001l00Co001l00?o0000o`LNX?l0
00004_mTF[800ol0003oU7ZcoiAj/`03oiAj/`?o00004onHQkl00ol0003o/iZmok>J_@0Jok>J_@03
o`000?o9[KgobJfm01WobJfm00Co0000omg2_OoM`[gogL:m0ol0000<on>m/0?o00001oofe:P00ol0
003oo<jBooc>TP02ooc>TP04o`000?omeWOooMIgo`0000;oll5<00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`19ooooo`03o`000?l007co001l
00Co001l00?o0000o`LNX?l000004omTF[800ol0003oU7Zco`000002o`0001KoV8No00?o0000ok>J
_OncV[d06_ncV[d00ol0003obJfmolV]_@0HolV]_@03o`000?oM`[gogL:m00GogL:m0_l00007on>m
/0?o000000?ohkf`o`000?l000002?ofe:P01Ol0003oo<jBooc>T_olcY;o000000;ooMIg00Co0000
oo?1C?oc`Dco0000>Oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0004[ooooo00?o0000
o`00O?l007`01?l007`00ol0003o1ajPo`00000BofAJ/P?o00006OnHQkl00ol0003o/iZmok>J_@0J
ok>J_@03o`000?o9[KgobJfm01SobJfm00?o0000omg2_OoM`[d01ooM`[d2o`0000;ohkf`0ol00004
on>m/003o`000?ofe:So000000Som]BX00?o0000ooc>T_l000000oomeWL01?l0003oll5<o`000?l0
000iooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo04_ooooo00?o0000
o`00O?l007`00_l007`01Ol0003o1ajPo`LNX?l77Z3o0000013oI5Zb00?o0000og1^`?l000006_nH
Qkl00ol0003o/iZmok>J_@0Iok>J_@03o`000?o9[KgobJfm01WobJfm00?o0000omg2_OoM`[d02?oM
`[d3o`0000Kohkf`00Go0000ooKDZ?ofe:Som]BXo`000008ooKDZ0;o00001?omeWL3o`0003Wooooo
00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0Boooool00ol0003o001lo`00
O002o`00O005o`000?l77Z3o1ajPo`LNX?l000003_mTF[82o`0000?oL6k000?o0000oiR7_onHQkl0
6?nHQkl00ol0003o/iZmok>J_@0Hok>J_@03o`000?o9[KgobJfm01SobJfm00?o0000omg2_OoM`[d0
1OoM`[d4o`0000?ogL:m0ol00003on>m/003o`000?ofe:Som]BX00;om]BX00?o0000ooKDZ?ofe:P0
1_ofe:P00ol0003ooMIgoogFM`02oogFM`?o0000>Oooool00ol0003oooooooooo`0=ooooo`006ooo
ool00ol0003oooooooooo`1;ooooo`03o`000?l007co001l00;o001l00Go0000o`LNX?l77Z3o1ajP
o`00000<ofAJ/P;o00001Om`K/000ol0003oV8NooiR7_`0HoiR7_`03o`000?ncV[go/iZm01So/iZm
00?o0000olV]_Oo9[Kd06?o9[Kd00ol0003ogL:momg2_@02omg2_@?o00002_oM`[d2o`000003on>m
/?l0003om]BX00Com]BX00?o0000ooKDZ?ofe:P01Oofe:P00ol0003ooMIgoogFM`02oogFM`?o0000
>Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003oooooooooo`1;ooooo`05o`000?l0
07co001lo`00O?l000001Ol77Z000ol0003oI5ZbofAJ/P08ofAJ/P03o`000?m`K/3oL6k000KoL6k0
00?o0000oiR7_onHQkl05onHQkl00ol0003o/iZmok>J_@0Hok>J_@03o`000?o9[KgobJfm01SobJfm
00?o0000omg2_Ol000000_l0000?omg2_@03o`000?ofe:Som]BX00Com]BX00?o0000ooKDZ?ofe:P0
1?ofe:P2o`0000GooMIg0_l0000iooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oo
oooooooo04_ooooo00Go/G80o`000?l007co001lo`000005o`LNX003o`000?mTF[;oI5Zb00KoI5Zb
0_l00009og1^`003o`000?nHQkooV8No01OoV8No00?o0000ok>J_OncV[d06?ncV[d00ol0003obJfm
olV]_@0GolV]_@?o00004_oM`[d00ol0003om]BXooKDZ005ooKDZ003o`000?ofe:Som]BX00?om]BX
00?o0000oogQVOl000001?omeWL2o`0003Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o
0000ooooooooool0C?ooool01?l0003o001lo`00O?l00005o`LNX003o`000?mTF[;oI5Zb00GoI5Zb
00?o0000og1^`?m`K/002Om`K/000ol0003oV8NooiR7_`0GoiR7_`03o`000?ncV[go/iZm01So/iZm
00?o0000olV]_Oo9[Kd04oo9[Kd5o`0001?ogL:m00?o0000onkF^_l000001oofe:P00ol0003om]BX
ooKDZ002ooKDZ003o`000?omhIWo000000CooMIg0_l0000iooooo`03o`000?oooooooooo00gooooo
000Kooooo`;o0000COooool00ol0003o001lo`000007o`LNX003o`000?mTF[;oI5Zb00;oI5Zb0_l0
000=og1^`003o`000?nHQkooV8No01KoV8No00?o0000ok>J_OncV[d06?ncV[d00ol0003obJfmolV]
_@0@olV]_@?o00001?o9[Kd00ol0003ogL:momg2_@0Aomg2_@04o`000?o^e[[ok]Jjo`0000Oom]BX
00Co0000ooKDZ?ofe:So00000_omhIT00ol0003ooMIgoogFM`02oogFM`;o0000>_ooool00ol0003o
ooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`1=ooooo`03o`000?l007co000000Oo1ajP
00?o0000ofAJ/_mTF[800_l0000?og1^`003o`000?nHQkooV8No01OoV8No00?o0000ok>J_OncV[d0
5oncV[d00ol0003obJfmolV]_@0=olV]_@?o00001_o9[Kd00ol0003ogL:momg2_@0Aomg2_@03o`00
0?o^e[[ok]Jj00;ok]Jj00?o0000ooKDZ?ofe:P01Oofe:P00ol0003om]BXo`000003oogQV@03o`00
0?omeWOooMIg00?o0000>_ooool00ol0003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04go
oooo00?o/G80o`00O?l000001ol77Z000ol0003oI5Zbo`00000Bog1^`003o`000?nHQkooV8No01Ko
V8No00?o0000ok>J_OncV[d02_ncV[dBo`0000SobJfm0ol00009olV]_@03o`000?oM`[gogL:m017o
gL:m00?o0000onkF^_o^e[X00oo^e[X00ol0003om]BXooKDZ005ooKDZ003o`000?omhIWooN6I00;o
oN6I00?o0000oogFMoomeWL00ol0000jooooo`03o`000?oooooooooo00cooooo00001?nHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04go
oooo00?o/G80o`000?l77Z002?l77Z000ol0003oL6k0og1^`00Aog1^`003o`000?nHQkooV8No01Co
V8No3ol0000=ok>Rb003o`000?o6/lOoa[?700;oa[?72?l0000<olV]_@03o`000?oM`[gogL:m017o
gL:m00?o0000onkF^_o^e[X01?o^e[X00ol0003om]BXooKDZ004ooKDZ003o`000?omhIWooN6I00;o
oN6I00?o0000oogFMoomeWL00ol0000jooooo`03o`000?oooooooooo00cooooo0003ooooo`03oa0@
4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03o`00
0?l77Z3o1ajP00Oo1ajP00?o0000og1^`?m`K/004_m`K/000ol0003oV8NooiR7_`0?oiR7_`Co0000
0_nKT/T00ol0003o/j;8ok>Rb00Gok>Rb003o`000?o6/lOoa[?700?oa[?70ol00004olJca`So0000
0oo9[Kd00ol0003ogL:momg2_@0Aomg2_@03o`000?o^e[[ok]Jj00Kok]Jj00?o0000ooKDZ?ofe:P0
0oofe:P2o`0000CooN6I00?o0000oogFMol000000_l0000jooooo`03o`000?oooooooooo00cooooo
0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`1>ooooo`03o`00IOl0003o1ajP00Ko1ajP00?o0000ob]5^_l000004om`K/000ol0003oV8NooiR7
_`0<oiR7_`?o00001_nKT/T00ol0003o/j;8ok>Rb00Gok>Rb003o`000?o6/lOoa[?700?o00003oo6
/lL5o`0001;ogL:m00?o0000onkF^_o^e[X01oo^e[X01Ol0003om]BXooKDZ?ofe:So000000;ooN6I
00Ko0000oogQVOomhIWooN6Io`000?omeWL3o`0003[ooooo00?o0000ooooooooool03?ooool000?o
oooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool0C_ooool2o`0000Oo1ajP00?o0000ob]5^_l000004om`K/000ol0003oV8NooiR7_`08oiR7
_`Co00002_nKT/T00ol0003o/j;8ok>Rb00Fok>Rb0?o00005Oo6/lL00ol0003oelG8o`000002o`00
00kogL:m00?o0000onkF^_o^e[X02Oo^e[X01?l0003om]BXooKDZ?l00003oogQV@03o`000?omhIWo
oN6I00;o00000_o[ceP00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00cooooo0003oooo
o`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?oooo
o`03ok5b0?l0003o1ajP00Ko1ajP00Co0000ob]5^_l[AK[o00004om`K/000ol0003oV8NooiR7_`03
oiR7_`Co00003_nKT/T00ol0003o/j;8ok>Rb00Bok>Rb0Go00005_o6/lL00ol0003oelG8omO5b003
omO5b0?o00002ooM`[d00ol0003ok]JjonkF^P0:onkF^P03o`000?ofe:So000000CooN6I00Co0000
oogQVOomhIWo00000_o[ceP00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo0000
1?nHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo0_l0001@ooooo`03ok5b0?l0
06Go000000Go1ajP00?o0000ob]5^_l[AKX00_l[AKX00ol0003oL6k0og1^`00@og1^`003o`000?nH
QkooV8No00?o00004_nKT/T00ol0003o/j;8ok>Rb00?ok>Rb0?o00001?ncX/P00ol0003oa[?7olJc
a`0DolJca`03o`000?oGaLSoelG800KoelG80ol00007omg2_@03o`000?o^e[[ok]Jj00cok]Jj00?o
0000oogQVOomhIT00oomhIT01?l0003ooN6IoogQVOl00002on_?F003o`000?oooooooooo03Wooooo
00?o0000ooooooooool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`00
0?oooooooooo053ooooo00?o001Uo`000?l77Z001?l77Z000ol0003o:dFjob]5^P02ob]5^P03o`00
0?m`K/3oL6k0013oL6k00ol0000Eoi^Bb@03o`000?ncX/So/j;800co/j;80ol00007ok>Rb003o`00
0?o6/lOoa[?701Coa[?700?o0000omO5b?oGaLP02OoGaLP3o`0000CogL:m00?o0000onkF^_o^e[X0
3?o^e[X00ol0003ooN6IoogQV@04oogQV@03o`000?omhIWo000000;ojlmH00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`1@ooooo`03o`000?l0
06Go000000?o1ajP00?o0000ob]5^_l[AKX01?l[AKX00ol0003oL6k0og1^`00=og1^`0;o000000?o
NWo<o`000?nKT/T05_nKT/T00ol0003o/j;8ok>Rb008ok>Rb0?o00002_ncX/P00ol0003oa[?7olJc
a`0ColJca`03o`000?oGaLSoelG800goelG80ol000000ooM`[go0000onkF^P0<onkF^P03o`000?og
i[?o000000KooN6I0_l00002on_?F003o`000?oooooooooo03Wooooo00?o0000ooooooooool02ooo
ool001Wooooo00?o0000ooooooooool0D?ooool00ol0003o001Uo`000003o`LNX003o`000?l[AK[o
:dFj00Co:dFj00?o0000og1^`?m`K/002om`K/02o`0000CoNWo<00?o0000oi^BbOnKT/T05?nKT/T0
0ol0003o/j;8ok>Rb004ok>Rb0Co00003?ncX/P00ol0003oa[?7olJca`0DolJca`03o`000?oGaLSo
elG8013oelG80_l0000=onkF^P03o`000?ogi[?o000000KooN6I0_l00002on_?F003o`000?oooooo
oooo03Wooooo00?o0000ooooooooool02oooool001Wooooo00?o0000ooooooooool0D?ooool01_l0
003o001Uo`00IOl0003o1ajPo`0000So:dFj00?o0000og1^`?m`K/002?m`K/02o`0000KoNWo<00?o
0000oi^BbOnKT/T05?nKT/T01?l0003o/j;8ok>Rb?ncX/P3o`00013o/j;800?o0000olJcaoo6/lL0
5?o6/lL00ol0003oelG8omO5b00@omO5b003o`000?oUelSo000000_ok]Jj00Go0000ooOV/oogi[?o
mnJco`000005oogQV@?o000000?ojlmHo`000?ooool0>_ooool00ol0003oooooooooo`0;ooooo`00
6?ooool00ol0003oooooooooo`1Aooooo`06ok5b0?l006Go001Uo`000?l77Z3o00002?l[AKX00ol0
003oL6k0og1^`007og1^`003o`000?mjOlcoNWo<00OoNWo<00?o0000oi^BbOnKT/T04onKT/T4o`00
01?o/j;800?o0000olJcaoo6/lL04oo6/lL00ol0003oelG8omO5b00@omO5b005o`000?oUelSoiMO8
onGGb?l000002_o^e[X01Ol0003omnJcooOV/oogi[?o000000CooN6I00Co0000ooKUQOl0003ojlmH
0_l0000kooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`000?oooooooooo05;ooooo00Go
0000o`00IOl0003o1ajPo`000009ob]5^P03o`000?m`K/3oL6k000CoL6k00_l0000:ogYoc003o`00
0?nKT/WoVi;9017oVi;90ol0000Fok>Rb003o`000?o6/lOoa[?701?oa[?700?o0000omO5b?oGaLP0
4?oGaLP00ol0003oiMO8onGGb002onGGb003o`000?o^e[[ok]Jj00Kok]Jj00?o0000ooOV/oogi[<0
0oogi[<02?l0003ooN6IoogQVOomhIWo0000ooKUQOl0003ojlmH0_l0000looooo`03o`000?oooooo
oooo00[ooooo000Hooooo`03o`000?oooooooooo05;ooooo00Co0000o`00IOl006Go00002ol[AKX0
1?l0003oL6k0og1^`?m`K/02o`0000goNWo<00?o0000oi^BbOnKT/T03?nKT/T4o`0000?oVi;900?o
0000ok>Rb?ncX/P04oncX/P00ol0003oa[?7olJca`0ColJca`03o`000?oGaLSoelG800ooelG800?o
0000onGGb?oUelP01?oUelP00ol0003ok]JjonkF^P05onkF^P03o`000?ogi[?omnJc00?omnJc00Oo
0000oogQVOomhIWooN6Io`000?ofiHGo000000;ojlmH00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0:ooooo`006?ooool2o`0005?ooooo00Co0000o`00IOl006Go00002ol[AKX01?l0003o
L6k0o`000?l0000?ogYoc003o`000?nKT/WoVi;900WoVi;90ol00007oi^Bb@03o`000?ncX/So/j;8
01?o/j;800?o0000olJcaoo6/lL04_o6/lL00ol0003oelG8omO5b00@omO5b003o`000?oUelSoiMO8
00GoiMO800?o0000onkF^_o^e[X00oo^e[X00ol0003omnJcooOV/`04ooOV/`04o`000?omhIWooN6I
o`0000;om^F500Go0000on_?F?l0003oooooo`00000kooooo`03o`000?oooooooooo00[ooooo000H
ooooo`03o`000?oooooooooo05?ooooo00Co0000o`00IOl0003o00002ol[AKX00ol0003oNWo<ogYo
c00@ogYoc003o`000?nKT/WoVi;900GoVi;90ol0000:oi^Bb@03o`000?ncX/So/j;801?o/j;800?o
0000olJcaoo6/lL04_o6/lL00ol0003oelG8omO5b00?omO5b003o`000?oUelSoiMO800OoiMO800?o
0000onkF^_o^e[X00_o^e[X00ol0003omnJcooOV/`05ooOV/`03o`000?omhIWo000000;om^F500?o
0000on_?F?l000000_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo000H
ooooo`03o`000?oooooooooo05?ooooo00Go0000o`00IOl0003o00^Lo`00000:ob]5^P03o`000?mj
OlcoNWo<013oNWo<00?o0000oi^BbOnKT/T00_nKT/T3o`0000goVi;900?o0000ok>Rb?ncX/P04onc
X/P00ol0003oa[?7olJca`0BolJca`03o`000?oGaLSoelG800ooelG800?o0000onGGb?oUelP02?oU
elP01?l0003ok]JjonkF^_l00008ooOV/`03o`000?omhIWo000000;om^F500?o0000on_?F?l00000
0oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oo
oooooooo05Cooooo00Go0000o`00IOl0003o00^Lo`000009ob]5^P03o`000?m8ILco0000017oNWo<
1Ol0000Aoi^Bb@03o`000?ncX/So/j;800So/j;85Ol00009olJca`03o`000?oGaLSoelG800ooelG8
00?o0000onGGb?oUelP02_oUelP00ol0003ok]Jjo`000009ooOV/`04o`000?ofiHGom^F5ooKUQ@;o
00001?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`00
0?oooooooooo05Gooooo00Go001Uo`000?l02ico00^Lo`000007ob]5^P05o`000?m8ILcoB6G<odQU
c?l000003_mjOl`4o`0001;oVi;93Ol0000:ok6[d@03o`000?o2^M7o`[WA00So`[WA3?l0000?omO5
b003o`000?oUelSoiMO800_oiMO800?o0000ooOV/oogi[<02?ogi[<01?l0003om^F5ooKUQOofiHD2
o`0000Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`005oooool00ol0
003oooooooooo`1Eooooo`03o`000?l006Go000000;o00^L00?o0000ob]5^_l[AKX01?l[AKX00ol0
003oB6G<odQUc002odQUc003o`000?mjOlcoNWo<00SoNWo<0ol00003ogYoc003o`000?nKT/WoVi;9
00_oVi;91Ol00002oifMd`03o`000?naZm7o/J_A01;o/J_A00?o0000ol:idOo2^M404Oo2^M400ol0
003od<SBom38dP03o`0000_oelG800?o0000onGGb?oUelP03?oUelP00ol0003omnJcooOV/`07ooOV
/`;o00000oofiHD2o`0000Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09oooo
o`005oooool00ol0003oooooooooo`1Eooooo`03o`000?l006Go000000;o00^L00?o0000ob]5^_l[
AKX00ol[AKX00ol0003oB6G<odQUc003odQUc003o`000?mjOlcoNWo<00GoNWo<0ol00007ogYoc003
o`000?nKT/WoVi;900GoVi;91Ol00007oifMd`03o`000?naZm7o/J_A01;o/J_A00?o0000ol:idOo2
^M404?o2^M400ol0003od<SBom38dP04om38dP?o00002?oGaLP00ol0003oiMO8onGGb00;onGGb003
o`000?o]i/Ko000000SomnJc0_l00003ooKUQ@03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`1Fooooo`03o`00
IOl0003o00^L00;o00^L00Go0000ob]5^_l[AK[o:dFjo`000007odQUc003o`000?mjOlcoNWo<00Co
00002_mjOl`00ol0003oVi;9oi^Bb@05o`0000goWIgC00?o0000ok6[dOnaZm404OnaZm400ol0003o
`[WAol:id@0@ol:id@03o`000?o@b=;od<SB00Ood<SB0ol00004omO5b003o`000?oUelSoiMO800_o
iMO800Co0000ongVa_o]i/Ko00001oogi[<00ol0003omo2Yo`000003ooKUQ@03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`005oooool00ol0003o
ooooooooo`1Fooooo`03o`00IOl0003o00^L00;o00^L00Go0000ob]5^_l[AK[o:dFjo`000007odQU
c0?o00003_mjOl`3o`0001;oWIgC00?o0000ok6[dOnaZm404OnaZm400ol0003o`[WAol:id@0@ol:i
d@03o`000?o@b=;od<SB00[od<SB0ol000000ooGaLSo0000onGGb00<onGGb005o`000?o]i/KokNK6
ongVa_l000001_ogi[<00ol0003omo2Yo`000003ooKUQ@03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`005oooool2o`0005Oooooo0_l00004o`0;
W003o`000?l[AK[o000000GoB6G<0ol00002odQUc003o`000?mjOlcoNWo<00[oNWo<0_l000000on3
SmOo0000oifMd`0BoifMd`03o`000?naZm7o/J_A017o/J_A00?o0000ol:idOo2^M403oo2^M400ol0
003od<SBom38dP0>om38dP;o00003?oUelP00ol0003okNK6ongVaP02ongVaP03o`000?ogi[?omnJc
00?omnJc00Co0000ooO`ZOogl:Wo00000_ofiHD2o`0000[ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`1Hooooo`03o`000?l02ico00^L
00?o00^L00Co0000odQUc?m8ILcoB6G<0ol00006odQUc003o`000?mjOlcoNWo<00OoNWo<0_l00004
oh>?e`03o`000?nMWM?oWIgC017oWIgC00?o0000ok6[dOnaZm404?naZm400ol0003o`[WAol:id@0?
ol:id@03o`000?o@b=;od<SB00kod<SB00?o0000om[Ge?l000002_oUelP00ol0003okNK6ongVaP04
ongVaP05o`000?ogi[?omnJcooOV/ol000000oogl:T01?l0003om^F5ooKUQOl0000<ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0F?oo
ool00ol0003o00^Lo`0;W003o`0;W0Co00002Om8IL`00ol0003oNWo<ogYoc005ogYoc0;o00001on3
SmL00ol0003oWIgCoifMd`0@oifMd`03o`000?naZm7o/J_A00oo/J_A00?o0000ol:idOo2^M403oo2
^M400ol0003od<SBom38dP0>om38dP05o`000?oJemCof]ODom[Ge?l000002OoUelP00ol0003okNK6
ongVaP04ongVaP05o`000?ogi[?omnJcooOV/ol000000oogl:T01?l0003om^F5ooKUQOl0000=oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooooooo
ool0FOooool00ol0003o00^Lo`000004o`0000coB6G<00?o0000ogYoc?mjOl`00_mjOl`2o`0000Wo
PhoG00?o0000oifMdonMWM<04?nMWM<00ol0003o/J_Aok6[d@0?ok6[d@03o`000?o2^M7o`[WA00oo
`[WA00?o0000om38d_o@b=803Oo@b=800ol0003of]ODom[Ge003om[Ge0;o00001_oUelP00ol0003o
kNK6ongVaP06ongVaP03o`000?ogi[?o000000Como2Y00Co0000ooKUQOl0003o00003_ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo05So
oooo0ol00003o`0;W003o`000?l6@/;o000000coB6G<00Co0000ogYoc?l0003o00003?n3SmL00ol0
003oWIgCoifMd`0?oifMd`03o`000?naZm7o/J_A00oo/J_A00?o0000ol:idOo2^M403oo2^M400ol0
003od<SBom38dP0=om38dP03o`000?oJemCof]OD00Gof]OD00?o0000onGGb?oUelP00_oUelP00ol0
003okNK6ongVaP07ongVaP03o`000?ogi[?o000000Como2Y00Co0000ooKUQOl0003o00003oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooooooo
05Gooooo0ol00002ooooo`05o`000?l02ico00^Lo`0;W?l000000_l6@/800ol0003oB6G<odQUc00:
odQUc003o`000?n3SmOoPhoG00goPhoG00?o0000oifMdonMWM<03onMWM<00ol0003o/J_Aok6[d@0>
ok6[d@03o`000?o2^M7o`[WA00ko`[WA00?o0000om38d_o@b=803Oo@b=800ol0003of]ODom[Ge007
om[Ge005o`000?oUelSoiMO8onGGb?l000002_o]i/H00ol0003omo2YooO`Z@03ooO`Z@?o00004?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Fooooo`03o`000?oooooo
oooo057ooooo1?l00005ooooo`05o`00Mol0003o00^Lo`0;W?l000000ol6@/800ol0003oB6G<odQU
c008odQUc0;o00004?n3SmL00ol0003oWIgCoifMd`0>oifMd`03o`000?naZm7o/J_A00ko/J_A00?o
0000ol:idOo2^M403_o2^M400ol0003od<SBom38dP0<om38dP03o`000?oJemCof]OD00Wof]OD00?o
0000onGGb?l000002oo]i/H00ol0003omo2YooO`Z@03ooO`Z@?o00004Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04oooooo0ol0000:
ooooo`05o`00Mol0003o00^Lo`0;W?l000000ol6@/800ol0003oB6G<odQUc006odQUc004o`000?mP
Om[oH7oJo`0000ooPhoG00?o0000oifMdonMWM<03_nMWM<00ol0003o/J_Aok6[d@0>ok6[d@03o`00
0?o2^M7o`[WA00go`[WA00?o0000om38d_o@b=803?o@b=800ol0003of]ODom[Ge00;om[Ge003o`00
0?o]i/KokNK600WokNK60_l00005ooO`Z@?o00004_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Sooooo000Eooooo`?o0000C?ooool3o`0000gooooo0_l007L00ol0003o00^Lo`00
0003o`I2`P03o`000?m8ILcoB6G<00GoB6G<00?o0000of1of_mPOmX00_mPOmX00ol0003oPhoGoh>?
e`0=oh>?e`03o`000?nMWM?oWIgC00koWIgC00?o0000ok6[dOnaZm401OnaZm4=o`0000_o`[WA00?o
0000om38d_o@b=803?o@b=800ol0003of]ODom[Ge00;om[Ge003o`000?o]i/KokNK600SokNK600?o
0000onobaOl000001Oogl:T00ol0003obmQSo`00000Cooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0BOooool3o`00017ooooo00Co001g
o`000?l02ico00001?l6@/800ol0003oB6G<odQUc003odQUc003o`000?mPOm[oH7oJ00CoH7oJ00?o
0000oh>?eon3SmL03On3SmL00ol0003oWIgCoifMd`0;oifMd`[o00002?n_/m/00ol0003o_;kKokbn
f`02okbnf`Oo00001?o2^M400ol0003od<SBom38dP0;om38dP03o`000?oJemCof]OD00_of]OD00?o
0000on7SeOl000002?o]i/H01?l0003oko;5onobaOl00005ooO`Z@;o00005Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Gooooo1?l0
000Dooooo`;o001g00?o00^Lo`000?l6@/801?l6@/801Ol0003oB6G<odQUc?m8ILco000000SoH7oJ
00?o0000oh>?eon3SmL03?n3SmL00ol0003oWIgCoifMd`06oifMd`Go00000_nOZ=d00ol0003o[k?K
ojncf`0=ojncf`03o`000?nl_]_o_;kK00Wo_;kK1_l0000;om38dP03o`000?oJemCof]OD00_of]OD
00Co0000on7SeOoQhmGo00001oo]i/H01Ol0003oko;5onobaOo_l/Go000000Como2Y00?o0000ol_H
Hol000005Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03
o`000?oooooooooo04;ooooo0ol0000Iooooo`;o001g00?o0000o`I2`_l6@/801?l6@/800ol0003o
B6G<o`00000:of1ofP03o`000?n3SmOoPhoG00coPhoG00?o0000oifMdonMWM<01Ol00007oinXg@03
o`000?n_/m_o[k?K00go[k?K00?o0000okbnfonl_]/03?nl_]/00ol0003oal[LolO:g004o`0000Oo
d<SB00?o0000om[Ge?oJem@02_oJem@00ol0003ohN?Eon7Se@02on7Se@03o`000?o]i/KokNK600?o
kNK600?o0000onobaOo_l/D00_o_l/D01?l0003omo2YooO`ZOogl:T2o`000003ol_HHol0003ooooo
01Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`005Oooool00ol0003o
ooooooooo`0oooooo`?o00007?ooool00ol0003o001go`000007o`I2`P;o00002_mPOmX00ol0003o
PhoGoh>?e`0<oh>?e`?o00003OnOZ=d00ol0003o[k?Kojncf`0<ojncf`03o`000?nl_]_o_;kK00_o
_;kK00?o0000olO:g?o7b]`01Oo7b]`4o`0000;od<SB00?o0000om[Ge?oJem@02_oJem@00ol0003o
hN?Eon7Se@03on7Se@03o`000?o]i/KokNK600?okNK600?o0000onobaOo_l/D00_o_l/D01?l0003o
mo2YooO`ZOogl:T2o`000003ol_HHol0003ooooo01Kooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0mooooo`?o00008?ooool2o`00M`03
o`000?l6@/;o1T;200Co1T;20_lgK]X00ol0003oH7oJof1ofP08of1ofP03o`000?n3SmOoPhoG00Wo
PhoG0_l000000on;W^3o0000oinXg@0=oinXg@03o`000?n_/m_o[k?K00co[k?K00?o0000okbnfonl
_]/02onl_]/00ol0003oal[LolO:g009olO:g0?o00002ooJem@00ol0003ohN?Eon7Se@04on7Se@03
o`000?o]i/KokNK600;okNK600?o0000onobaOo_l/D00oo_l/D00ol0003omo2YooO`Z@02o`000003
ol_HHol0003ooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0iooooo`Co00008oooool01?l0003o001go`000?l00005o`I2`P04
o`000?lgK][o=fkJo`0000[oH7oJ00?o0000oh>?eon3SmL01On3SmL3o`0000CoRikP00?o0000oinX
gOnOZ=d02onOZ=d00ol0003o[k?Kojncf`0<ojncf`03o`000?nl_]_o_;kK00[o_;kK00?o0000olO:
g?o7b]`02oo7b]`00ol0003oc]GNo`000009om[Ge003o`000?oQhmGohN?E00KohN?E00Co0000ongV
a_o]i/Ko00001_o_l/D01ol0003omo2Yo`000?oNm9_o0000ol_HHol000006_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Kooooo0ol0
000Xooooo`04o`00Mol0003o02Rbo`0000Co1T;200Go0000ocM^f_lgK][o=fkJo`00000:of1ofP03
o`000?n3SmOoPhoG00;oPhoG0_l00008oh^Nh003o`000?nOZ=goWjSM00_oWjSM00?o0000ojncfon_
/m/02_n_/m/00ol0003o_;kKokbnf`0;okbnf`03o`000?o7b]coal[L00[oal[L00Co0000olkEg_o>
eMkoc]GN0_l00006om[Ge003o`000?oQhmGohN?E00OohN?E00?o0000ongVa_l000001oo_l/D01ol0
003omo2Yo`000?oNm9_o0000ol_HHol000006_ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`?o0000<oooool3o`0002_ooooo00Go0000o`00Mol0003o02Rbo`00
0003o`I2`P03o`000?lgK][o=fkJ00;o=fkJ00?o0000of1of_mPOmX02?mPOmX01?l0003oPhoGo`00
0?l0000:oh^Nh003o`000?nOZ=goWjSM00_oWjSM00?o0000ojncfon_/m/02_n_/m/00ol0003o_;kK
okbnf`0:okbnf`03o`000?o7b]coal[L00[oal[L00?o0000olkEg_o>eMh01?o>eMh2o`0000?of]OD
00?o0000on7SeOoQhmD02OoQhmD00ol0003oko;5onoba@06onoba@;o000000Cog_BKo`000?o;f6?o
00007?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`00
0?oooooooooo033ooooo0ol0000_ooooo`04o`00Mol0003o02Rbo`0000?o1T;200?o0000ocM^f_lg
K]X00olgK]X2o`0000WoH7oJ0_l0000<oh^Nh003o`000?nOZ=goWjSM00[oWjSM00?o0000ojncfon_
/m/02_n_/m/00ol0003o_;kKokbnf`0:okbnf`03o`000?o7b]coal[L00Woal[L00?o0000olkEg_o>
eMh01oo>eMh00ol0003of]ODo`00000:on7Se@03o`000?oRk]So000000Soko;500Ko0000omkdVooN
m9_o0000ol_HHol0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool0
00[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02cooooo1?l0000coooo
o`04o`000?l0:;;o02Rbo`0000;o1T;200?o0000ocM^f_lgK]X01OlgK]X00ol0003oH7oJof1ofP05
of1ofP04o`000?mdU^GoM9KUo`0000coRikP00?o0000oinXgOnOZ=d02_nOZ=d00ol0003o[k?Kojnc
f`09ojncf`03o`000?nl_]_o_;kK00Wo_;kK00?o0000olO:g?o7b]`02Oo7b]`00ol0003oc]GNolkE
gP09olkEgP03o`000?oQhmGohN?E00SohN?E00Co0000on;^f?oRk]So00001oo_l/D2o`0000;og_BK
0_l0000Oooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool000cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`?o0000=oooool01ol007Oo0000o`0X
/_l0:;;o0000o`I2`_l000002?lgK]X00ol0003oH7oJof1ofP03of1ofP03o`000?mdU^GoM9KU00;o
M9KU00?o0000oh^Nh?n;W^002On;W^000ol0003oWjSMoinXg@0:oinXg@03o`000?n_/m_o[k?K00Wo
[k?K00?o0000okbnfonl_]/02Onl_]/00ol0003oal[LolO:g008olO:g003o`000?o>eMkoc]GN00Wo
c]GN00?od]kQo`000?oQhmD02?oQhmD01Ol0003oh^kHon;^f?oRk]So000000Koko;50_l00002omkd
V`;o00008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo000<ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0003_ooooo00Ko0000o`0X/_l0
:;;o02Rbo`I2`_l00009ocM^fP05o`000?mPOm[oH7oJof1of_l000001_mdU^D00ol0003oRikPoh^N
h009oh^Nh003o`000?nOZ=goWjSM00WoWjSM00?o0000ojncfon_/m/02On_/m/00ol0003o_;kKokbn
f`08okbnf`03o`000?o7b]coal[L00Soal[L00?o0000olkEg_o>eMh02?o>eMh01Ol0003od]kQom;N
hOoBg^7o000000OohN?E00?o0000on;^f?oRk]P00_oRk]P00ol0003oko;5onoba@03onoba@03o`00
0?oRoLCo000000;og_BK0_l0000Rooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`?o0000?_oo
ool00ol0003o02Rbo`0X/P02o`0X/P;o00002OlgK]X00ol0003oH7oJo`000008ogBFi@03o`000?n;
W^3oRikP00WoRikP00?o0000oinXgOnOZ=d02OnOZ=d00ol0003o[k?Kojncf`03ojncf`_o00001Onl
_]/00ol0003oal[LolO:g007olO:g003o`000?o>eMkoc]GN00Soc]GN00?o0000om;NhOoBg^400_oB
g^400ol0003ohN?Eon7Se@04on7Se@03o`000?oRk]Soh^kH00?oh^kH00?o0000onobaOo_l/D00_o_
l/D00ol0003oh_g4o`000003omkdV`03o`000?oooooooooo027ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo023ooooo1?l00012ooooo`04o`000?l0:;;o02Rbo`0X/P;o5F;H00?o0000ocM^f_lgK]X01olg
K]X2o`0000WoM9KU0_l00009oh^Nh003o`000?nOZ=goWjSM00OoWjSM2?l00005ojbki@03o`000?ne
`nGo]L?U00?o]L?U1ol00007olO:g003o`000?o>eMkoc]GN00Soc]GN00?o0000om;NhOoBg^401?oB
g^400ol0003ohN?Eon7Se@02on7Se@03o`000?oRk]Soh^kH00Coh^kH00Go0000onobaOo_l/Goko;5
o`000002on;ma003o`000?oNm9_og_BK00;o00009?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Ooo
ool3o`0004Kooooo00?o01jVo`000?l0:;800_l0:;82oaERf003o`000?lgK][o=fkJ00Ko=fkJ0_mM
SnP00ol0003oM9KUogBFi@08ogBFi@03o`000?n;W^3oRikP00OoRikP00Co0000oinXgOnOZ=goWjSM
1Ol00002oj2ciP03o`000?n/^nGo[;_U00So[;_U00?o0000okG3iOne`nD01one`nD00ol0003o^l_V
ok_;iP04o`0000;oal[L00?o0000olkEg_o>eMh01oo>eMh2o`0000Sod]kQ00Co0000on7SeOoQhmGo
00001ooRk]P01?l0003oko;5onobaOl00002on;ma005o`000?oNm9_og_BKomkdVol000009_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06_ooool3o`0004[ooooo00Go01jVo`000?l0:;;o02Rbo`000002
oaERf0;o00001_lgK]X00ol0003oGHoXoef?j002o`0000WoM9KU00?o0000oh^Nh?n;W^001_n;W^04
o`0000SoX;?V00?o0000ojbkiOn/^nD01on/^nD00ol0003o]L?UokG3i@06okG3i@03o`000?nkbnKo
^l_V00Go^l_V0_l00009olkEgP03o`000?oBg^7od]kQ00Sod]kQ00?o0000on7SeOl000002?oRk]P0
0ol0003oko;5o`000003on;ma003o`000?oNm9_og_BK00;o00009oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0000Hoooo
o`?o0000C_ooool01Ol07ZKo0000o`0X/_l0:;;o000000?o5F;H00?o0000ocM^f_lgK]X00olgK]X0
0ol0003oGHoXoef?j002oef?j003o`000?mdU^GoM9KU00OoM9KU00?o0000oh^Nh?n;W^000_n;W^03
o`0000;oTjkY00?o0000oj2ci_nP/nH01onP/nH00ol0003o[;_Uojbki@06ojbki@03o`000?ne`nGo
]L?U00Ko]L?U00?o0000ok_;i_nkbnH01_nkbnH01?l0003o_m;XokoBj?l00006olkEgP03o`000?oB
g^7od]kQ00[od]kQ00?o0000on;^f?oRk]P01ooRk]P2o`0000Coh_g400Co0000omkdVol0003o0000
:Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo000Booooo`03o`000?oo
oooooooo01Cooooo1?l0001Booooo`04o`0NY_l0003o02Rbo`0000Co5F;H0_l00002ocM^fP03o`00
0?mMSnSoGHoX00CoGHoX0_l00008ogBFi@04o`000?n;W^3o0000o`0000KoTjkY00?o0000oj2ci_nP
/nH01_nP/nH00ol0003o[;_Uojbki@06ojbki@03o`000?ne`nGo]L?U00Ko]L?U00?o0000ok_;i_nk
bnH01OnkbnH00ol0003o_m;XokoBj002okoBj0;o00000oo>eMh00ol0003od]kQom;Nh@09om;Nh@03
o`000?oBi^Co000000Woh^kH00?o0000on;ma?oRoL@00_oRoL@01?l0003og_BKo`000?l0000Zoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000oooooooo
ool04Oooool3o`0005Oooooo00?o01jVo`000?l000001_lEH]P2ocM^fP03o`000?mMSnSoGHoX00Ko
GHoX00?o0000ogBFiOmdU^D01_mdU^D2o`0000SoTjkY00?o0000oj2ci_nP/nH01_nP/nH00ol0003o
[;_Uojbki@05ojbki@03o`000?ne`nGo]L?U00Go]L?U00?o0000ok_;i_nkbnH01OnkbnH00ol0003o
_m;XokoBj005okoBj003o`000?o>eMko000000[od]kQ0_l00002om;Vi003o`000?oRk]Soh^kH00Go
h^kH00?o0000om[igOl000001?oRoL@3o`0002cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000Foooool00ol07ZKo02Rb
o`000006oaERf003ocM^f_l0003oGHoX00SoGHoX00?o0000ogBFiOmdU^D01?mdU^D01?l0003oQZ[]
ohJZkOl00008oi>^j@03o`000?nP/nKoX;?V00GoX;?V00?o0000ojbkiOn/^nD01On/^nD00ol0003o
]L?UokG3i@04okG3i@03o`000?nkbnKo^l_V00Go^l_V00?o0000okoBj?nod^P01onod^P00ol0003o
d]kQom;Nh@07om;Nh@;o00001?oBi^@00ol0003oh^kHon;^f003on;^f0;o000000?of_WMo`000?oR
oL@00ooRoL@3o`0002kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`00
4_ooool00ol0003oooooooooo`0;ooooo`?o0000G_ooool00ol0003o01jVo`000007oaERf0;o0000
2OmMSnP2o`0000?oM9KU00?o0000ohJZkOn6Z^d00_n6Z^d2o`0000OoTjkY00?o0000oj2ci_nP/nH0
1OnP/nH00ol0003o[;_Uojbki@04ojbki@03o`000?ne`nGo]L?U00Co]L?U00?o0000ok_;i_nkbnH0
1?nkbnH00ol0003o_m;XokoBj007okoBj003ol7Gj_l0003od]kQ00Ood]kQ00?o0000om;Vi?oBi^@0
1?oBi^@01?l0003oh^kHon;^f?oRk]P2o`0000?of_WM00?o0000on;ma?oRoL@00_oRoL@2o`00033o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003ooooo
ooooo`07ooooo`Co0000H_ooool01?l0003o01jVo`000?l00005oaERf004o`000?m<S>_o0000o`00
00WoGHoX0_mdU^D00ol0003oQZ[]ohJZk@05ohJZk@03o`000?nC[^WoTjkY00GoTjkY00?o0000oj2c
i_nP/nH01?nP/nH00ol0003o[;_Uojbki@03ojbki@03o`000?ne`nGo]L?U00Co]L?U00?o0000ok_;
i_nkbnH01?nkbnH00ol0003o_m;XokoBj005okoBj0;o00000oo1enX00ol0003od]kQom;Nh@03om;N
h@;o00001_oBi^@01Ol0003oh^kHon;^f?oRk]So000000Cof_WM00Co0000on;ma?oRoLCoh_g40ol0
000booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000
ooooooooool01?ooool3o`0006Oooooo0_l000000ol0HMOo0000o`000004oaERf003o`000?m<S>_o
C8c[00;o00002?mMSnP2o`0000SoQZ[]0_l00006oi>^j@03o`000?nP/nKoX;?V00?oX;?V00?o0000
ojbkiOn/^nD00on/^nD00ol0003o]L?UokG3i@04okG3i@03o`000?nkbnKo^l_V00?o^l_V00?o0000
okoBj?nod^P01?nod^P2o`0000Ko`MOZ00?o0000om;NhOoBg^400_l00008om;Vi004o`000?oRk]So
0000o`0000Gof_WM00Go0000on;ma?oRoLCo0000ojke^@02o`0003?ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000Jooo
ool2o`0000;o067G00Go0000oaERf?lEH]So5F;Ho`000004odb<j`?o00001OmMSnP00ol0003oNjW`
o`000002o`0000OoQZ[]00?o0000oi>^jOnC[^T01?nC[^T01?l0003oX;?Voj2ci_nP/nH;o`0000;o
]L?U00?o0000ok_;i_nkbnH00onkbnH00ol0003o_m;XokoBj004okoBj003o`000?o1en[o`MOZ00Ko
`MOZ00?o0000om;NhOl000002_oBi^@2o`0000Kof_WM00Go0000on;ma?oRoLCo0000ojke^@02o`00
03Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`004Oooool00ol0003o
ooooo`000002o`0006oooooo0_l00002o`1Qe`;o00000_lEH]P00ol0003oC8c[odb<j`04odb<j`;o
00000omMSnP00ol0003oNjW`og^Yl002og^Yl0;o00001_n6Z^d2o`0000CoTjkY1?l00002oj2ok`03
o`000?nV`nkoY/?^00;oY/?^00Co0000oj[7k_nZankoZ/O^1Ol00002ok_;iP03o`000?nod^So_m;X
00?o_m;X0_l0000:ol7GjP03o`000?oBi^Cod^KT00Wod^KT00?o0000om[igOoJnMd01OoJnMd01?l0
003oh_g4o`000?n^mKT2o`0003Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04
ooooo`004Oooool2o`0007Cooooo00Oo0000o`1Qeol0HMOo067Go`000?lEH]So000000SoC8c[00?o
0000oef?j?l000001omkZO02o`0000KoQZ[]00Co0000oi>^jOl0003o00000onJ__401Ol0003oX;o_
oj2okonP_noo000000?oY/?^00?o0000oj[7k_nZanh00_nZanh01?l0003o[<[_ojc:kon/b^l3o`00
00?o_m;X0_l00009ol7GjP;o000000?o`M_]o`000?oBi^@01_oBi^@3o`000003olg^jol0003of_WM
00Kof_WM0_l000000on^mKWo0000o`00000hooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01?ooool001?ooooo00?o0000ooooooooool0L_ooool00ol0003o067Go`1Qe`02o`1Qe`03
o`000?m<S>_oC8c[00SoC8c[0_l00008og^Yl0?o00001?n6Z^d2o`0000GoV[ka00Co0000oj2okonP
_noo00000onV`nh01Ol0003oZ/O^oj[7k_nZanko000000?o[<[_00Oo0000ojg<l?n]c?3o[Lc`o`00
0?nod^So000000Oo`MOZ0ol00004ol7Kk@03o`000?oBi^Cod^KT00;od^KT0ol00003olg^j`03o`00
0?oJnMgof_WM00Gof_WM0_l000000on^mKWo0000o`00000jooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool001Cooooo0_l0001cooooo`03o`000?l0HMOo067G00;o067G0ol0
0007odb<j`03o`000?meZO?o000000;o00002?mkZO02o`000004ohJZkOl0003oU[gboiJmlP;o0000
1?nJ__401?l0003oX;o_oj2okol00002ojK3kP04o`000?nZankoZ/O^o`0000;o[<[_0_l00004ojg<
l0;o00001Oo1enX3o`0000Ko`M_]00Co0000om;Vi?oBi^Cod^KT0_l00006olg^j`03o`000?oJnMgo
f_WM00Gof_WM00Co0000ojke^Ol0003o0000??ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Cooooo000Fooooo`03o`000?oooooo0000077ooooo00Go0000o`1Qeol0HMOo067Go`00
0002od:?k`?o00001Om<S>/01?l0003oMJWcogFYlomeZO<3o`0000OoNjW`0ol00003oiJmlP;o0000
0onJ__401Ol0003oX;o_o`000?nV`nko000000;oZ/O^00Co0000ojc:kol0003o00000on]c?03o`00
0004ojg=lOl0003o`MOZol7GjP?o00002Oo1fnd4o`0000OocNk[00?o0000om[igOoJnMd01?oJnMd2
o`000003ojke^Ol0003o000003gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04
ooooo`005oooool2o`0007;ooooo00Go0000o`1Qeol0HMOo067Go`000004od:?k`?o00000_m<S>/0
0ol0003oMJWcogFYl`04ogFYl`?o00001?mkZO000ol0003oU;kdoiBnm004o`000005oiJml_l0003o
0000o`000?nJ__400_l000001?nV`nko0000oj[7k_nZanh2o`0000;o[Lc`0ol00003ojg=l@Co0000
3?o1fnd00ol0003ocNk[olg^j`08olg^j`04o`000?oJnMgof_WMom[ig@Co00000_n^mKT00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool001Sooooo
0_l0001booooo`;o00000_l0HML00ol0003o@Xo_od:?k`04od:?k`?o00002OmeZO<2o`000003og^Y
l?l0003oU;kd00KoU;kd0ol000000onF_O;o0000o`000003o`000003oj[7k_l0003o000000?o0000
00?o[Lgao`000?l000000ol00002ojg>l@03o`000?o1fngo`M_]00Co`M_]1Ol00002okgOl@03o`00
0?o=k^_ocNk[00OocNk[00?o0000om[igOoJnMd00_l00002okgmhP04o`000?n^mKWo[_Fio`00047o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_ooool00ol0003ooooo
ooooo`1aooooo`;o000000?o067Go`000?m2Snl01om2Snl4o`0000SoMJWc2Ol00002oiBnm0go0000
1on]c_400ol0003o`M_]o`000004o`0000Ko_Moa00?o0000olg^joo=k^/02?o=k^/3o`0000?o_OgR
00Co0000ojke^On^mKWo0000@oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo000Kooooo`;o000000?oooooo`000?ooool0Koooool01?l0ImGo0000o`000?l00008od:?k`03
o`000?mb[OKoLZgf00Oo000000?oMJWco`000?nD__@01onD__@Ho`0000[o_Moa00?o0000olg^joo=
k^/01Oo=k^/4o`0000Go_OgR00Co0000ojke^On^mKWo0000AOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo000Mooooo`;o0000LOooool01?l0003o06OEo`000?l00008od:?
k`03o`000?mb[OKoLZgf00KoLZgf2_l000000onC__Co0000o`000003o`000003oiC3mol0003o0000
00Wo00000on/c_800ol0003o_MoaokgOl@0:okgOl@03o`000?o=k^_o000000Go000000?o_?;bo`00
0?nmoN801OnmoN801?l0003o[_Fiojke^Ol00016ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool00oooool001kooooo00?o0000ooooooooool0L?ooool2o`000003o`1WeOl0003o0000
00;o00001Om2Snl00ol0003oLZgfog:]mP09og:]mP03o`000?nC__CoTkkd00Co00000_nC`?D2o`00
0006oiC3mol0003o0000oik<mol0003oY<kf0_l00005ojW?l`go00000_nmgo43o`0000Ko_?;b00?o
0000okgmh_nmoN801?nmoN801?l0003o[_Fio`000?l00018ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00oooool001oooooo0_l0001`ooooo`03o`000?oooooo000000;o06OE00?o
0000ocfIlol000001?l000000om2Snoo0000og:]mP05og:]mPCo000000?oLZgfo`000?l000001?nC
`?D2o`0000?oU<?g0_l00002oik<m`03o`000?nTc_KoY<kf00;o00001?nYco<00ol0003o]>7fokCQ
mP09okCQmP03o`000?nll_;o_?;b00Oo_?;b00?o0000okgmh_nmoN801?nmoN83o`0004_ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`008Oooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo00;o000000?o06OEo`000?l000001?lmVO<8o`0000OoLK?i0_l00000
0onC`?Go0000oiC3m`03oiC3m`04o`000?nHaoSoV<Oho`0000;oW/cg00Co0000ojC>m_nTc_KoY<kf
0_l000000onYco?o0000okCQmP0:okCQmP03o`000?nll_;o_?;b00Oo_?;b00?o0000okgmh_nmoN80
1?nmoN82o`0004kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`008_oo
ool3o`0006cooooo00?o0000ooooooooool00_ooool01?l0003o06OEo`1WeOl00007ocfIl`;o0000
2oma/oT2o`0000?oU<?g00Go0000oiS7n?nHaoSoV<Oho`000003oik<m`03o`000?nTc_KoY<kf00Ko
00002?ndhOH00ol0003o_?;bokcblP07okcblP03o`000?nmoN;o_OgR00Co_OgR0_l0001@ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool002Cooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`03ooooo`04o`000?l0ImGo06OEo`0000So?IWc00?o0000og6cnOma
/oT01?ma/oT3o`0000?oM[cl0_l000000onD`oOo0000oiS7n002oiS7n003o`000?nNc?OoW/cg00Co
00001_nUg_/5o`0000;o]>7f00?o0000okcbl_nll_801onll_800ol0003o_OgRokgmhP02okgmhP?o
0000Doooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o0000
J_ooool00ol0003oooooooooo`04ooooo`Go00001olmVO<2o`000004og6cnOl0003o0000o`0000So
M[cl2?l00004oi7FoP03o`000?nUg__oYMkk00SoYMkk1ol00004okcblPOo0000EOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Wooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool01_ooool4o`0000Co?IWc1Ol0000;ogJlo003o`000?n0bOkoP<Wn00;oP<Wn
00?o0000oi7Fo_nAe_h01OnAe_h00ol0003oYMkkojGNn`05ojGNn`;o00001onMk?T5o`0000;oP^WN
0_l0001Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool002Sooooo00?o
0000ooooool00000I_ooool00ol0003oooooooooo`09ooooo`Go00001om2Z?L3o`0000GoM[cl00?o
0000oh39o_n0bOh00on0bOh00ol0003oTMKnoi7FoP06oi7FoP03o`000?nUg__oYMkk00;oYMkk0_l0
0009oig/n@;o00000_n2jMh3o`0005_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001Vooooo`03o`000?oooooo
oooo00cooooo0ol00009od:Xm`?o000000?oM[clo`000?n0bOh01_n0bOh00ol0003oTMKnoi7FoP06
oi7FoP04o`000?nUg__o0000o`0000SoWNci0ol00002oh;YgP;o0000Goooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0>ooooo`Go00002?m2Z?L6o`0000?oP<Wn00?o0000
oi7Fo_nAe_h00_nAe_h8o`0000KoWNci0_l00003oh;YgP;o0000H_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo000Eooooo`Ko00001Oooool00ol0003oooooooooo`09oooo
o`;o0000Hoooool00ol0003oooooooooo`0Aooooo`Go00000_m2Z?L2o`0000OoE;oi2?l00008ogKI
n`?o000000?oWNcio`000?l000000on2jMh2o`0006Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000063o
oooo00?o0000ooooooooool05?ooool4o`0000coE;oi00?o0000ogKInomffO/02_mffO/9o`0006Oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`008?ooool00ol0003ooooo
ooooo`0<ooooo`;o0000H?ooool00ol0003oooooooooo`0Hooooo`;o00000_l4U<`7o`0000;oE;oi
00?o0000ogKInomffO/00_mffO/<o`0006cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`01ooooo`008?ooool00ol0003oooooooooo`0=ooooo`;o0000Goooool00ol0003ooooooooo
o`0Ooooooa7o0000Loooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo000P
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0V
ooooo`Go0000N_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo000Noooo
o`03oeEEEOmVIVKo000001;ooooo0_l000000ooooooo0000ooooo`1Hooooo`03o`000?oooooooooo
0:Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00=Oooool2o`0005Wo
oooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007o
oooo000fooooo`;o0000F?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00Oooool003Sooooo00Go0000ooooooooooooooooo`00001Cooooo`03o`00
0?oooooooooo0:Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00>Ooo
ool01?l0003oooooooooool0001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool0
2Oooool1o`00007ooooo0Oooool003[ooooo0ol0001Cooooo`03o`000?oooooooooo0:[ooooo00?o
0000ooooooooool02?ooool1o`00007ooooo0Oooool003cooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000moooo
o`;o0000DOooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00Oooooo0Ol00001oooo
o`7ooooo000oooooo`03o`000?oooooo000004kooooo00?o0000ooooooooool0[?ooool00ol0003o
ooooooooo`06ooooo`7o00000Oooool1ooooo`00@?ooool2o`0004kooooo00?o0000ooooooooool0
[Oooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00@Oooool2o`0004gooooo00?o
0000ooooooooool0[_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00@oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01Oooool1
o`00007ooooo0014ooooo`;o000000?oooooo`000?ooool0Aoooool00ol0003oooooooooo`2_oooo
o`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00A_ooool2o`0004Sooooo00?o0000oooooooo
ool0/?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool003;ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01?m4A4Co0000o`000?lb<S82o`0004Oooooo00?o0000oooo
ooooool0/Oooool00ol0003oooooooooo`02ooooo`7o00000Oooool003;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8booooool00016ooooo`03o`000?oooooo
oooo0;;ooooo00Go0000ooooooooooooooooo`000001ooooo`00:_ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o0000@oooool00ol0003ooooooooo
o`2cooooo`04o`000?ooooooooooo`00007ooooo000booooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0
/oooool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool0]?ooool00ol0003oooooooooo`01o`000000<_ooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool02?ooool2o`00043ooooo00?o0000ooooooooool0]Oooool1o`00
007ooooo0Ol0000003;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00[ooooo0_l0000nooooo`03o`000?oooooooooo0;Kooooo0_l0000003;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`Co00002_ooool2o`0003gooooo00?o0000ooooooooool0]Oooool3o`00
0000Doooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool0/?ooool5o`00
00?ooooo001Dooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0[?ooool4o`00
00Sooooo001Eooooo`?o0000>?ooool00ol0003oooooooooo`2Xooooo`Co00003?ooool005Oooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2Tooooo`Go00004?ooool005Sooooo0_l0
000eooooo`03o`000?oooooooooo0:3ooooo1?l0000Eooooo`00F_ooool00ol0003oooooo`00000b
ooooo`03o`000?oooooooooo09cooooo1?l0000Iooooo`00Foooool2o`0003;ooooo00?o0000oooo
ooooool0Uoooool5o`0001gooooo001Mooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0Toooool4o`0002;ooooo001Nooooo`04o`000?ooooooooooo`0002gooooo00?o0000oooooooo
ool0S_ooool5o`0002Kooooo001Oooooo`?o0000;Oooool00ol0003oooooooooo`2:ooooo`Co0000
:oooool0067ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`26ooooo`Co0000;ooo
ool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0:ooooo`;o0000:oooool00ol0003ooooooooo
o`21ooooo`Go0000<oooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooo000002Sooooo00?o0000ooooooooool0OOooool4o`0003Sooooo001Cooooo`05oa0@4?oooooo
ooooooooool@41003Oooool2o`0002Sooooo00?o0000ooooooooool0NOooool4o`0003cooooo001C
ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo07Cooooo1Ol00010ooooo`00Doooool01Ol0003ooooooooooooooooo0000013ooooo00Co
0000oooooooooooo00008oooool00ol0003oooooooooo`1`ooooo`Co0000AOooool005?ooooo00Go
410@oooooooooooooooooa0@400Aooooo`?o00008oooool00ol0003oooooooooo`1[ooooo`Go0000
BOooool005?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`;o00008oooool00ol0003ooooo
ooooo`1Wooooo`Co0000C_ooool005?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Dooooo`;o0000
00?oooooo`000?ooool07_ooool00ol0003oooooooooo`1Sooooo`Co0000D_ooool006kooooo0_l0
000Oooooo`03o`000?oooooooooo05kooooo1Ol0001Fooooo`00Koooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo05[ooooo1?l0001Kooooo`00L?ooool2o`0001gooooo00?o0000oooo
ooooool0E_ooool4o`0005oooooo001booooo`03o`000?oooooo000001[ooooo00?o0000oooooooo
ool0DOooool5o`0006?ooooo001cooooo`;o00006_ooool00ol0003oooooooooo`1=ooooo`Co0000
J?ooool007Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`Co0000K?oo
ool007Kooooo0_l000000ooooooo0000ooooo`0Dooooo`03o`000?oooooooooo04Cooooo1Ol0001`
ooooo`00N?ooool2o`0001Gooooo00?o0000ooooooooool0@?ooool4o`0007Gooooo001iooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0>oooool5o`0007Wooooo001jooooo`;o0000
00?oooooo`000?ooool04?ooool00ol0003oooooooooo`0gooooo`Co0000O_ooool006?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?o
oooo0_l0000Aooooo`03o`000?oooooooooo03?ooooo1?l00022ooooo`00Hoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000?ooooo`03
o`000?oooooooooo02oooooo1Ol00026ooooo`00Hoooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_o
oooo1?l0002;ooooo`00Hoooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool01_ooool3o`0000_ooooo00?o0000ooooooooool09oooool4o`0008oooooo001Sooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Rooooo`Go0000Toooool006?ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0Nooooo`Co0000V?ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00gooooo0ol00007ooooo`03o`000?oooooooooo01Wooooo1Ol0002L
ooooo`00Hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0000>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05Oooool4o`000:7ooooo0027ooooo`;o00001Oooool00ol0
003oooooooooo`0Aooooo`Co0000YOooool008Wooooo0_l00003ooooo`03o`000?oooooooooo00co
oooo1Ol0002Yooooo`00R_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002^ooooo`00
Roooool2o`000003ooooool0003ooooo00Gooooo1?l0002booooo`00SOooool2o`000003ooooool0
003o000000?o0000]_ooool008kooooo0_l0002kooooo`00oooooom<ooooo`00oooooom<ooooo`00
Q?ooool4o`000003oa0@4?oooooooooo0<3ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026
ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03
o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oooooooooo0<;ooooo0026ooooo`03o`000?oo
oooooooo0<;ooooo0024ooooo`03oeEEEOmVIVKo00000<Cooooo0000\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.47813 .54971 m .47045 .59353 L .54508 .59707 L p .714 .605 .734 r
F P
0 g
s
.54508 .59707 m .54253 .55304 L .47813 .54971 L p .714 .605 .734 r
F P
0 g
s
.54721 .64227 m .54508 .59707 L .47045 .59353 L p .716 .579 .7 r
F P
0 g
s
.54253 .55304 m .54508 .59707 L .61434 .58614 L p .642 .546 .73 r
F P
0 g
s
.54508 .59707 m .54721 .64227 L .6237 .62842 L p .634 .512 .697 r
F P
0 g
s
.6237 .62842 m .61434 .58614 L .54508 .59707 L p .634 .512 .697 r
F P
0 g
s
.47045 .59353 m .46404 .63873 L .54721 .64227 L p .716 .579 .7 r
F P
0 g
s
.54881 .68735 m .54721 .64227 L .46404 .63873 L p .716 .549 .663 r
F P
0 g
s
.54721 .64227 m .54881 .68735 L .63065 .67048 L p .623 .474 .659 r
F P
0 g
s
.63065 .67048 m .6237 .62842 L .54721 .64227 L p .623 .474 .659 r
F P
0 g
s
.42038 .53505 m .40411 .57587 L .47045 .59353 L p .779 .669 .741 r
F P
0 g
s
.47045 .59353 m .47813 .54971 L .42038 .53505 L p .779 .669 .741 r
F P
0 g
s
.46404 .63873 m .47045 .59353 L .40411 .57587 L p .79 .649 .706 r
F P
0 g
s
.40411 .57587 m .39065 .61806 L .46404 .63873 L p .79 .649 .706 r
F P
0 g
s
.45921 .68399 m .46404 .63873 L .39065 .61806 L p .8 .627 .667 r
F P
0 g
s
.46404 .63873 m .45921 .68399 L .54881 .68735 L p .716 .549 .663 r
F P
0 g
s
.48675 .50824 m .47813 .54971 L .54253 .55304 L p .71 .629 .765 r
F P
0 g
s
.54253 .55304 m .53965 .51116 L .48675 .50824 L p .71 .629 .765 r
F P
0 g
s
.53965 .51116 m .54253 .55304 L .60293 .54467 L p .65 .578 .761 r
F P
0 g
s
.61434 .58614 m .60293 .54467 L .54253 .55304 L p .642 .546 .73 r
F P
0 g
s
.43888 .49644 m .42038 .53505 L .47813 .54971 L p .766 .685 .773 r
F P
0 g
s
.47813 .54971 m .48675 .50824 L .43888 .49644 L p .766 .685 .773 r
F P
0 g
s
.54979 .73078 m .54881 .68735 L .45921 .68399 L p .713 .515 .62 r
F P
0 g
s
.54881 .68735 m .54979 .73078 L .63489 .71114 L p .61 .432 .616 r
F P
0 g
s
.63489 .71114 m .63065 .67048 L .54881 .68735 L p .61 .432 .616 r
F P
0 g
s
.39065 .61806 m .38059 .66053 L .45921 .68399 L p .8 .627 .667 r
F P
0 g
s
.45625 .72773 m .45921 .68399 L .38059 .66053 L p .808 .599 .619 r
F P
0 g
s
.45921 .68399 m .45625 .72773 L .54979 .73078 L p .713 .515 .62 r
F P
0 g
s
.49604 .4697 m .48675 .50824 L .53965 .51116 L p .706 .652 .794 r
F P
0 g
s
.53965 .51116 m .53653 .47202 L .49604 .4697 L p .706 .652 .794 r
F P
0 g
s
.53653 .47202 m .53965 .51116 L .58982 .50483 L p .656 .61 .79 r
F P
0 g
s
.60293 .54467 m .58982 .50483 L .53965 .51116 L p .65 .578 .761 r
F P
0 g
s
.4591 .46061 m .43888 .49644 L .48675 .50824 L p .75 .699 .803 r
F P
0 g
s
.48675 .50824 m .49604 .4697 L .4591 .46061 L p .75 .699 .803 r
F P
0 g
s
.60293 .54467 m .61434 .58614 L .66795 .56374 L p .558 .484 .729 r
F P
0 g
s
.61434 .58614 m .6237 .62842 L .68138 .60155 L p .533 .438 .693 r
F P
0 g
s
.68138 .60155 m .66795 .56374 L .61434 .58614 L p .533 .438 .693 r
F P
0 g
s
.58982 .50483 m .60293 .54467 L .65106 .52636 L p .58 .528 .761 r
F P
0 g
s
.66795 .56374 m .65106 .52636 L .60293 .54467 L p .558 .484 .729 r
F P
0 g
s
.6237 .62842 m .63065 .67048 L .69114 .63909 L p .506 .388 .652 r
F P
0 g
s
.69114 .63909 m .68138 .60155 L .6237 .62842 L p .506 .388 .652 r
F P
0 g
s
.55008 .77089 m .54979 .73078 L .45625 .72773 L p .708 .473 .567 r
F P
0 g
s
.54979 .73078 m .55008 .77089 L .63617 .74918 L p .591 .379 .562 r
F P
0 g
s
.63617 .74918 m .63489 .71114 L .54979 .73078 L p .591 .379 .562 r
F P
0 g
s
.38059 .66053 m .37444 .70198 L .45625 .72773 L p .808 .599 .619 r
F P
0 g
s
.45538 .76822 m .45625 .72773 L .37444 .70198 L p .813 .562 .56 r
F P
0 g
s
.45625 .72773 m .45538 .76822 L .55008 .77089 L p .708 .473 .567 r
F P
0 g
s
.37774 .5116 m .35668 .54782 L .40411 .57587 L p .842 .743 .753 r
F P
0 g
s
.40411 .57587 m .42038 .53505 L .37774 .5116 L p .842 .743 .753 r
F P
0 g
s
.39065 .61806 m .40411 .57587 L .35668 .54782 L p .865 .734 .715 r
F P
0 g
s
.58982 .50483 m .57534 .46727 L .53653 .47202 L p .656 .61 .79 r
F P
0 g
s
.57534 .46727 m .58982 .50483 L .63095 .49012 L p .601 .57 .791 r
F P
0 g
s
.65106 .52636 m .63095 .49012 L .58982 .50483 L p .58 .528 .761 r
F P
0 g
s
.40241 .47731 m .37774 .5116 L .42038 .53505 L p .817 .747 .786 r
F P
0 g
s
.42038 .53505 m .43888 .49644 L .40241 .47731 L p .817 .747 .786 r
F P
0 g
s
.50579 .4343 m .49604 .4697 L .53653 .47202 L p .699 .675 .823 r
F P
0 g
s
.53653 .47202 m .53325 .43589 L .50579 .4343 L p .699 .675 .823 r
F P
0 g
s
.53325 .43589 m .53653 .47202 L .57534 .46727 L p .663 .642 .819 r
F P
0 g
s
.35668 .54782 m .33971 .58526 L .39065 .61806 L p .865 .734 .715 r
F P
0 g
s
.38059 .66053 m .39065 .61806 L .33971 .58526 L p .887 .719 .668 r
F P
0 g
s
.4806 .42791 m .4591 .46061 L .49604 .4697 L p .732 .71 .83 r
F P
0 g
s
.49604 .4697 m .50579 .4343 L .4806 .42791 L p .732 .71 .83 r
F P
0 g
s
.63065 .67048 m .63489 .71114 L .69703 .67573 L p .474 .329 .604 r
F P
0 g
s
.69703 .67573 m .69114 .63909 L .63065 .67048 L p .474 .329 .604 r
F P
0 g
s
.43017 .44565 m .40241 .47731 L .43888 .49644 L p .79 .749 .815 r
F P
0 g
s
.43888 .49644 m .4591 .46061 L .43017 .44565 L p .79 .749 .815 r
F P
0 g
s
.57534 .46727 m .55979 .43249 L .53325 .43589 L p .663 .642 .819 r
F P
0 g
s
.55979 .43249 m .57534 .46727 L .60796 .45581 L p .623 .613 .82 r
F P
0 g
s
.63095 .49012 m .60796 .45581 L .57534 .46727 L p .601 .57 .791 r
F P
0 g
s
.33971 .58526 m .32724 .62315 L .38059 .66053 L p .887 .719 .668 r
F P
0 g
s
.37444 .70198 m .38059 .66053 L .32724 .62315 L p .907 .698 .609 r
F P
0 g
s
.46048 .41726 m .43017 .44565 L .4591 .46061 L p .761 .746 .84 r
F P
0 g
s
.4591 .46061 m .4806 .42791 L .46048 .41726 L p .761 .746 .84 r
F P
0 g
s
.54964 .80609 m .55008 .77089 L .45538 .76822 L p .696 .418 .498 r
F P
0 g
s
.55008 .77089 m .54964 .80609 L .63435 .78335 L p .564 .312 .492 r
F P
0 g
s
.63435 .78335 m .63617 .74918 L .55008 .77089 L p .564 .312 .492 r
F P
0 g
s
.63489 .71114 m .63617 .74918 L .69891 .71079 L p .434 .259 .543 r
F P
0 g
s
.69891 .71079 m .69703 .67573 L .63489 .71114 L p .434 .259 .543 r
F P
0 g
s
.37444 .70198 m .3726 .74101 L .45538 .76822 L p .813 .562 .56 r
F P
0 g
s
.4567 .8038 m .45538 .76822 L .3726 .74101 L p .813 .512 .481 r
F P
0 g
s
.45538 .76822 m .4567 .8038 L .54964 .80609 L p .696 .418 .498 r
F P
0 g
s
.5159 .402 m .50579 .4343 L .53325 .43589 L p .691 .697 .851 r
F P
0 g
s
.53325 .43589 m .52984 .40279 L .5159 .402 L p .691 .697 .851 r
F P
0 g
s
.52984 .40279 m .53325 .43589 L .55979 .43249 L p .669 .676 .848 r
F P
0 g
s
.50307 .39855 m .4806 .42791 L .50579 .4343 L p .71 .718 .856 r
F P
0 g
s
.50579 .4343 m .5159 .402 L .50307 .39855 L p .71 .718 .856 r
F P
0 g
s
.63095 .49012 m .65106 .52636 L .68394 .50035 L p .501 .479 .765 r
F P
0 g
s
.65106 .52636 m .66795 .56374 L .70322 .53359 L p .456 .418 .728 r
F P
0 g
s
.70322 .53359 m .68394 .50035 L .65106 .52636 L p .456 .418 .728 r
F P
0 g
s
.60796 .45581 m .63095 .49012 L .66001 .46826 L p .542 .536 .798 r
F P
0 g
s
.68394 .50035 m .66001 .46826 L .63095 .49012 L p .501 .479 .765 r
F P
0 g
s
.55979 .43249 m .54338 .40085 L .52984 .40279 L p .669 .676 .848 r
F P
0 g
s
.54338 .40085 m .55979 .43249 L .5825 .42425 L p .644 .657 .848 r
F P
0 g
s
.60796 .45581 m .5825 .42425 L .55979 .43249 L p .623 .613 .82 r
F P
0 g
s
.66795 .56374 m .68138 .60155 L .71792 .5672 L p .405 .352 .685 r
F P
0 g
s
.71792 .5672 m .70322 .53359 L .66795 .56374 L p .405 .352 .685 r
F P
0 g
s
.5825 .42425 m .60796 .45581 L .63159 .4383 L p .581 .591 .827 r
F P
0 g
s
.66001 .46826 m .63159 .4383 L .60796 .45581 L p .542 .536 .798 r
F P
0 g
s
.32724 .62315 m .31968 .66067 L .37444 .70198 L p .907 .698 .609 r
F P
0 g
s
.3726 .74101 m .37444 .70198 L .31968 .66067 L p .922 .665 .531 r
F P
0 g
s
.49274 .39274 m .46048 .41726 L .4806 .42791 L p .727 .74 .862 r
F P
0 g
s
.4806 .42791 m .50307 .39855 L .49274 .39274 L p .727 .74 .862 r
F P
0 g
s
.41187 .42591 m .38025 .45264 L .40241 .47731 L p .825 .802 .829 r
F P
0 g
s
.40241 .47731 m .43017 .44565 L .41187 .42591 L p .825 .802 .829 r
F P
0 g
s
.37774 .5116 m .40241 .47731 L .38025 .45264 L p .863 .815 .8 r
F P
0 g
s
.38025 .45264 m .3532 .48228 L .37774 .5116 L p .863 .815 .8 r
F P
0 g
s
.35668 .54782 m .37774 .5116 L .3532 .48228 L p .9 .825 .764 r
F P
0 g
s
.68138 .60155 m .69114 .63909 L .72825 .60068 L p .348 .277 .634 r
F P
0 g
s
.72825 .60068 m .71792 .5672 L .68138 .60155 L p .348 .277 .634 r
F P
0 g
s
.44743 .40306 m .41187 .42591 L .43017 .44565 L p .785 .784 .852 r
F P
0 g
s
.43017 .44565 m .46048 .41726 L .44743 .40306 L p .785 .784 .852 r
F P
0 g
s
.5825 .42425 m .55508 .39627 L .54338 .40085 L p .644 .657 .848 r
F P
0 g
s
.55508 .39627 m .5825 .42425 L .59921 .41162 L p .618 .645 .854 r
F P
0 g
s
.63159 .4383 m .59921 .41162 L .5825 .42425 L p .581 .591 .827 r
F P
0 g
s
.3532 .48228 m .33106 .5139 L .35668 .54782 L p .9 .825 .764 r
F P
0 g
s
.33971 .58526 m .35668 .54782 L .33106 .5139 L p .936 .83 .716 r
F P
0 g
s
.63617 .74918 m .63435 .78335 L .69659 .74362 L p .381 .169 .462 r
F P
0 g
s
.69659 .74362 m .69891 .71079 L .63617 .74918 L p .381 .169 .462 r
F P
0 g
s
.48598 .38506 m .44743 .40306 L .46048 .41726 L p .742 .763 .87 r
F P
0 g
s
.46048 .41726 m .49274 .39274 L .48598 .38506 L p .742 .763 .87 r
F P
0 g
s
.52984 .40279 m .52632 .37269 L .5159 .402 L closepath p .678 .718 .88 r
F P
0 g
s
.54338 .40085 m .52632 .37269 L .52984 .40279 L closepath p .664 .709 .881 r
F P
0 g
s
.54848 .83496 m .54964 .80609 L .4567 .8038 L p .674 .339 .4 r
F P
0 g
s
.54964 .80609 m .54848 .83496 L .6294 .81251 L p .522 .219 .394 r
F P
0 g
s
.6294 .81251 m .63435 .78335 L .54964 .80609 L p .522 .219 .394 r
F P
0 g
s
.5159 .402 m .52632 .37269 L .50307 .39855 L closepath p .689 .731 .883 r
F P
0 g
s
.55508 .39627 m .52632 .37269 L .54338 .40085 L closepath p .653 .703 .884 r
F P
0 g
s
.69114 .63909 m .69703 .67573 L .73445 .63374 L p .282 .192 .572 r
F P
0 g
s
.73445 .63374 m .72825 .60068 L .69114 .63909 L p .282 .192 .572 r
F P
0 g
s
.3726 .74101 m .37529 .77622 L .4567 .8038 L p .813 .512 .481 r
F P
0 g
s
.46021 .83302 m .4567 .8038 L .37529 .77622 L p .802 .436 .365 r
F P
0 g
s
.4567 .8038 m .46021 .83302 L .54848 .83496 L p .674 .339 .4 r
F P
0 g
s
.50307 .39855 m .52632 .37269 L .49274 .39274 L closepath p .696 .744 .888 r
F P
0 g
s
.33106 .5139 m .31391 .54672 L .33971 .58526 L p .936 .83 .716 r
F P
0 g
s
.32724 .62315 m .33971 .58526 L .31391 .54672 L p .967 .826 .651 r
F P
0 g
s
.59921 .41162 m .63159 .4383 L .64497 .41542 L p .542 .58 .843 r
F P
0 g
s
.63159 .4383 m .66001 .46826 L .67667 .43987 L p .484 .514 .813 r
F P
0 g
s
.67667 .43987 m .64497 .41542 L .63159 .4383 L p .484 .514 .813 r
F P
0 g
s
.31968 .66067 m .31732 .69697 L .3726 .74101 L p .922 .665 .531 r
F P
0 g
s
.37529 .77622 m .3726 .74101 L .31732 .69697 L p .928 .611 .419 r
F P
0 g
s
.56373 .3894 m .52632 .37269 L .55508 .39627 L closepath p .646 .702 .888 r
F P
0 g
s
.59921 .41162 m .56373 .3894 L .55508 .39627 L p .618 .645 .854 r
F P
0 g
s
.56373 .3894 m .59921 .41162 L .60851 .39535 L p .595 .642 .867 r
F P
0 g
s
.64497 .41542 m .60851 .39535 L .59921 .41162 L p .542 .58 .843 r
F P
0 g
s
.66001 .46826 m .68394 .50035 L .70294 .46746 L p .421 .442 .776 r
F P
0 g
s
.70294 .46746 m .67667 .43987 L .66001 .46826 L p .421 .442 .776 r
F P
0 g
s
.49274 .39274 m .52632 .37269 L .48598 .38506 L closepath p .699 .752 .893 r
F P
0 g
s
.56843 .38081 m .52632 .37269 L .56373 .3894 L closepath p .643 .703 .89 r
F P
0 g
s
.60851 .39535 m .56843 .38081 L .56373 .3894 L p .595 .642 .867 r
F P
0 g
s
.68394 .50035 m .70322 .53359 L .72366 .49703 L p .349 .36 .73 r
F P
0 g
s
.72366 .49703 m .70294 .46746 L .68394 .50035 L p .349 .36 .73 r
F P
0 g
s
.48351 .37614 m .44255 .38623 L .44743 .40306 L p .752 .788 .882 r
F P
0 g
s
.44743 .40306 m .48598 .38506 L .48351 .37614 L p .752 .788 .882 r
F P
0 g
s
.41187 .42591 m .44743 .40306 L .44255 .38623 L p .803 .823 .867 r
F P
0 g
s
.44255 .38623 m .40505 .40231 L .41187 .42591 L p .803 .823 .867 r
F P
0 g
s
.38025 .45264 m .41187 .42591 L .40505 .40231 L p .851 .855 .845 r
F P
0 g
s
.31391 .54672 m .30169 .58016 L .32724 .62315 L p .967 .826 .651 r
F P
0 g
s
.31968 .66067 m .32724 .62315 L .30169 .58016 L p .991 .807 .56 r
F P
0 g
s
.48598 .38506 m .52632 .37269 L .48351 .37614 L closepath p .699 .756 .896 r
F P
0 g
s
.69703 .67573 m .69891 .71079 L .7366 .66622 L p .206 .091 .493 r
F P
0 g
s
.7366 .66622 m .73445 .63374 L .69703 .67573 L p .206 .091 .493 r
F P
0 g
s
.63435 .78335 m .6294 .81251 L .68993 .77344 L p .306 .048 .349 r
F P
0 g
s
.68993 .77344 m .69659 .74362 L .63435 .78335 L p .306 .048 .349 r
F P
0 g
s
.40505 .40231 m .37224 .4234 L .38025 .45264 L p .851 .855 .845 r
F P
0 g
s
.3532 .48228 m .38025 .45264 L .37224 .4234 L p .898 .883 .81 r
F P
0 g
s
.56866 .37131 m .52632 .37269 L .56843 .38081 L closepath p .642 .703 .891 r
F P
0 g
s
.56843 .38081 m .60851 .39535 L .60952 .3766 L p .58 .65 .884 r
F P
0 g
s
.60952 .3766 m .56866 .37131 L .56843 .38081 L p .58 .65 .884 r
F P
0 g
s
.70322 .53359 m .71792 .5672 L .73909 .52766 L p .268 .268 .674 r
F P
0 g
s
.73909 .52766 m .72366 .49703 L .70322 .53359 L p .268 .268 .674 r
F P
0 g
s
.60851 .39535 m .64497 .41542 L .64733 .38819 L p .513 .587 .866 r
F P
0 g
s
.64733 .38819 m .60952 .3766 L .60851 .39535 L p .513 .587 .866 r
F P
0 g
s
.55577 .35381 m .52632 .37269 L .56432 .36193 L closepath p .642 .711 .897 r
F P
0 g
s
.48351 .37614 m .52632 .37269 L .48562 .36682 L closepath p .698 .757 .897 r
F P
0 g
s
.56432 .36193 m .52632 .37269 L .56866 .37131 L closepath p .642 .705 .893 r
F P
0 g
s
.54386 .34808 m .52632 .37269 L .55577 .35381 L closepath p .646 .722 .904 r
F P
0 g
s
.52992 .34556 m .52632 .37269 L .54386 .34808 L closepath p .655 .736 .909 r
F P
0 g
s
.51557 .34661 m .52632 .37269 L .52992 .34556 L closepath p .67 .749 .91 r
F P
0 g
s
.50249 .35102 m .52632 .37269 L .51557 .34661 L closepath p .684 .757 .907 r
F P
0 g
s
.49215 .35809 m .52632 .37269 L .50249 .35102 L closepath p .693 .759 .902 r
F P
0 g
s
.48562 .36682 m .52632 .37269 L .49215 .35809 L closepath p .697 .758 .899 r
F P
0 g
s
.44255 .38623 m .48351 .37614 L .48562 .36682 L p .753 .811 .899 r
F P
0 g
s
.37224 .4234 m .34487 .44835 L .3532 .48228 L p .898 .883 .81 r
F P
0 g
s
.33106 .5139 m .3532 .48228 L .34487 .44835 L p .94 .904 .76 r
F P
0 g
s
.64497 .41542 m .67667 .43987 L .68087 .40536 L p .439 .514 .838 r
F P
0 g
s
.68087 .40536 m .64733 .38819 L .64497 .41542 L p .439 .514 .838 r
F P
0 g
s
.56866 .37131 m .60952 .3766 L .60178 .35722 L p .577 .669 .902 r
F P
0 g
s
.60178 .35722 m .56432 .36193 L .56866 .37131 L p .577 .669 .902 r
F P
0 g
s
.54664 .85649 m .54848 .83496 L .46021 .83302 L p .626 .218 .249 r
F P
0 g
s
.54848 .83496 m .54664 .85649 L .62142 .83571 L p .45 .081 .246 r
F P
0 g
s
.62142 .83571 m .6294 .81251 L .54848 .83496 L p .45 .081 .246 r
F P
0 g
s
.31732 .69697 m .3204 .73116 L .37529 .77622 L p .928 .611 .419 r
F P
0 g
s
.38251 .80633 m .37529 .77622 L .3204 .73116 L p .909 .516 .25 r
F P
0 g
s
.37529 .77622 m .38251 .80633 L .46021 .83302 L p .802 .436 .365 r
F P
0 g
s
.48562 .36682 m .44625 .36794 L .44255 .38623 L p .753 .811 .899 r
F P
0 g
s
.40505 .40231 m .44255 .38623 L .44625 .36794 L p .807 .861 .889 r
F P
0 g
s
.30169 .58016 m .29434 .61377 L .31968 .66067 L p .991 .807 .56 r
F P
0 g
s
.31732 .69697 m .31968 .66067 L .29434 .61377 L p .996 .76 .428 r
F P
0 g
s
.44625 .36794 m .48562 .36682 L .49215 .35809 L p .739 .825 .918 r
F P
0 g
s
.46576 .8548 m .46021 .83302 L .38251 .80633 L p .76 .31 .182 r
F P
0 g
s
.46021 .83302 m .46576 .8548 L .54664 .85649 L p .626 .218 .249 r
F P
0 g
s
.71792 .5672 m .72825 .60068 L .74973 .55876 L p .176 .164 .605 r
F P
0 g
s
.74973 .55876 m .73909 .52766 L .71792 .5672 L p .176 .164 .605 r
F P
0 g
s
.69891 .71079 m .69659 .74362 L .73455 .69794 L p .113 0 .39 r
F P
0 g
s
.73455 .69794 m .7366 .66622 L .69891 .71079 L p .113 0 .39 r
F P
0 g
s
.56432 .36193 m .60178 .35722 L .58546 .33977 L p .585 .695 .918 r
F P
0 g
s
.58546 .33977 m .55577 .35381 L .56432 .36193 L p .585 .695 .918 r
F P
0 g
s
.67667 .43987 m .70294 .46746 L .70931 .42718 L p .356 .429 .8 r
F P
0 g
s
.70931 .42718 m .68087 .40536 L .67667 .43987 L p .356 .429 .8 r
F P
0 g
s
.60952 .3766 m .64733 .38819 L .63759 .35878 L p .501 .611 .894 r
F P
0 g
s
.63759 .35878 m .60178 .35722 L .60952 .3766 L p .501 .611 .894 r
F P
0 g
s
.34487 .44835 m .32315 .47602 L .33106 .5139 L p .94 .904 .76 r
F P
0 g
s
.31391 .54672 m .33106 .5139 L .32315 .47602 L p .973 .912 .685 r
F P
0 g
s
.44625 .36794 m .40981 .37584 L .40505 .40231 L p .807 .861 .889 r
F P
0 g
s
.37224 .4234 m .40505 .40231 L .40981 .37584 L p .86 .907 .864 r
F P
0 g
s
.45847 .3499 m .49215 .35809 L .50249 .35102 L p .712 .825 .935 r
F P
0 g
s
.49215 .35809 m .45847 .3499 L .44625 .36794 L p .739 .825 .918 r
F P
0 g
s
.55577 .35381 m .58546 .33977 L .56184 .32711 L p .601 .723 .93 r
F P
0 g
s
.56184 .32711 m .54386 .34808 L .55577 .35381 L p .601 .723 .93 r
F P
0 g
s
.47849 .33449 m .50249 .35102 L .51557 .34661 L p .679 .809 .945 r
F P
0 g
s
.50249 .35102 m .47849 .33449 L .45847 .3499 L p .712 .825 .935 r
F P
0 g
s
.40981 .37584 m .44625 .36794 L .45847 .3499 L p .788 .889 .917 r
F P
0 g
s
.6294 .81251 m .62142 .83571 L .67879 .79945 L p .193 0 .179 r
F P
0 g
s
.67879 .79945 m .68993 .77344 L .6294 .81251 L p .193 0 .179 r
F P
0 g
s
.54386 .34808 m .56184 .32711 L .53363 .32165 L p .622 .752 .94 r
F P
0 g
s
.53363 .32165 m .52992 .34556 L .54386 .34808 L p .622 .752 .94 r
F P
0 g
s
.72825 .60068 m .73445 .63374 L .75609 .59008 L p .074 .047 .52 r
F P
0 g
s
.75609 .59008 m .74973 .55876 L .72825 .60068 L p .074 .047 .52 r
F P
0 g
s
.70294 .46746 m .72366 .49703 L .73229 .45262 L p .261 .331 .747 r
F P
0 g
s
.73229 .45262 m .70931 .42718 L .70294 .46746 L p .261 .331 .747 r
F P
0 g
s
.50455 .32436 m .51557 .34661 L .52992 .34556 L p .648 .782 .946 r
F P
0 g
s
.51557 .34661 m .50455 .32436 L .47849 .33449 L p .679 .809 .945 r
F P
0 g
s
.52992 .34556 m .53363 .32165 L .50455 .32436 L p .648 .782 .946 r
F P
0 g
s
.29434 .61377 m .29186 .64724 L .31732 .69697 L p .996 .76 .428 r
F P
0 g
s
.3204 .73116 m .31732 .69697 L .29186 .64724 L p .96 .665 .239 r
F P
0 g
s
.64733 .38819 m .68087 .40536 L .67073 .36659 L p .412 .539 .874 r
F P
0 g
s
.67073 .36659 m .63759 .35878 L .64733 .38819 L p .412 .539 .874 r
F P
0 g
s
.32315 .47602 m .30688 .50545 L .31391 .54672 L p .973 .912 .685 r
F P
0 g
s
.30169 .58016 m .31391 .54672 L .30688 .50545 L p .986 .896 .576 r
F P
0 g
s
.40981 .37584 m .37757 .38993 L .37224 .4234 L p .86 .907 .864 r
F P
0 g
s
.34487 .44835 m .37224 .4234 L .37757 .38993 L p .907 .944 .817 r
F P
0 g
s
.60178 .35722 m .63759 .35878 L .61488 .33114 L p .506 .651 .923 r
F P
0 g
s
.61488 .33114 m .58546 .33977 L .60178 .35722 L p .506 .651 .923 r
F P
0 g
s
.69659 .74362 m .68993 .77344 L .72794 .72857 L p 0 0 .246 r
F P
0 g
s
.72794 .72857 m .73455 .69794 L .69659 .74362 L p 0 0 .246 r
F P
0 g
s
.3204 .73116 m .32906 .76233 L .38251 .80633 L p .909 .516 .25 r
F P
0 g
s
.39406 .83029 m .38251 .80633 L .32906 .76233 L p .824 .347 0 r
F P
0 g
s
.38251 .80633 m .39406 .83029 L .46576 .8548 L p .76 .31 .182 r
F P
0 g
s
.4264 .34845 m .45847 .3499 L .47849 .33449 L p .743 .894 .947 r
F P
0 g
s
.45847 .3499 m .4264 .34845 L .40981 .37584 L p .788 .889 .917 r
F P
0 g
s
.72366 .49703 m .73909 .52766 L .74983 .48076 L p .155 .218 .677 r
F P
0 g
s
.74983 .48076 m .73229 .45262 L .72366 .49703 L p .155 .218 .677 r
F P
0 g
s
.73445 .63374 m .7366 .66622 L .75842 .62161 L p 0 0 .414 r
F P
0 g
s
.75842 .62161 m .75609 .59008 L .73445 .63374 L p 0 0 .414 r
F P
0 g
s
.5442 .87008 m .54664 .85649 L .46576 .8548 L p .518 .015 0 r
F P
0 g
s
.54664 .85649 m .5442 .87008 L .61062 .85223 L p .317 0 .005 r
F P
0 g
s
.61062 .85223 m .62142 .83571 L .54664 .85649 L p .317 0 .005 r
F P
0 g
s
.37757 .38993 m .40981 .37584 L .4264 .34845 L p .835 .948 .894 r
F P
0 g
s
.37757 .38993 m .35037 .40926 L .34487 .44835 L p .907 .944 .817 r
F P
0 g
s
.32315 .47602 m .34487 .44835 L .35037 .40926 L p .94 .961 .737 r
F P
0 g
s
.58546 .33977 m .61488 .33114 L .58014 .31053 L p .526 .703 .951 r
F P
0 g
s
.58014 .31053 m .56184 .32711 L .58546 .33977 L p .526 .703 .951 r
F P
0 g
s
.68087 .40536 m .70931 .42718 L .70029 .38042 L p .304 .446 .839 r
F P
0 g
s
.70029 .38042 m .67073 .36659 L .68087 .40536 L p .304 .446 .839 r
F P
0 g
s
.30688 .50545 m .29559 .53596 L .30169 .58016 L p .986 .896 .576 r
F P
0 g
s
.29434 .61377 m .30169 .58016 L .29559 .53596 L p .963 .84 .421 r
F P
0 g
s
.47312 .86857 m .46576 .8548 L .39406 .83029 L p .639 .09 0 r
F P
0 g
s
.46576 .8548 m .47312 .86857 L .5442 .87008 L p .518 .015 0 r
F P
0 g
s
.45484 .32375 m .47849 .33449 L .50455 .32436 L p .68 .87 .971 r
F P
0 g
s
.47849 .33449 m .45484 .32375 L .4264 .34845 L p .743 .894 .947 r
F P
0 g
s
.29186 .64724 m .29443 .68023 L .3204 .73116 L p .96 .665 .239 r
F P
0 g
s
.32906 .76233 m .3204 .73116 L .29443 .68023 L p .848 .497 0 r
F P
0 g
s
.63759 .35878 m .67073 .36659 L .64339 .3286 L p .4 .588 .918 r
F P
0 g
s
.64339 .3286 m .61488 .33114 L .63759 .35878 L p .4 .588 .918 r
F P
0 g
s
.56184 .32711 m .58014 .31053 L .53744 .3017 L p .562 .762 .972 r
F P
0 g
s
.53744 .3017 m .53363 .32165 L .56184 .32711 L p .562 .762 .972 r
F P
0 g
s
.73909 .52766 m .74973 .55876 L .76216 .51088 L p .036 .088 .587 r
F P
0 g
s
.76216 .51088 m .74983 .48076 L .73909 .52766 L p .036 .088 .587 r
F P
0 g
s
.62142 .83571 m .61062 .85223 L .66312 .82074 L p .017 0 0 r
F P
0 g
s
.66312 .82074 m .67879 .79945 L .62142 .83571 L p .017 0 0 r
F P
0 g
s
.49339 .30669 m .50455 .32436 L .53363 .32165 L p .615 .822 .98 r
F P
0 g
s
.50455 .32436 m .49339 .30669 L .45484 .32375 L p .68 .87 .971 r
F P
0 g
s
.53363 .32165 m .53744 .3017 L .49339 .30669 L p .615 .822 .98 r
F P
0 g
s
.68993 .77344 m .67879 .79945 L .7162 .75748 L p 0 0 .041 r
F P
0 g
s
.7162 .75748 m .72794 .72857 L .68993 .77344 L p 0 0 .041 r
F P
0 g
s
.7366 .66622 m .73455 .69794 L .75661 .65339 L p 0 0 .278 r
F P
0 g
s
.75661 .65339 m .75842 .62161 L .7366 .66622 L p 0 0 .278 r
F P
0 g
s
.35037 .40926 m .32855 .43278 L .32315 .47602 L p .94 .961 .737 r
F P
0 g
s
.30688 .50545 m .32315 .47602 L .32855 .43278 L p .944 .944 .615 r
F P
0 g
s
.4264 .34845 m .39696 .35374 L .37757 .38993 L p .835 .948 .894 r
F P
0 g
s
.35037 .40926 m .37757 .38993 L .39696 .35374 L p .868 .989 .831 r
F P
0 g
s
.29559 .53596 m .28884 .56722 L .29434 .61377 L p .963 .84 .421 r
F P
0 g
s
.29186 .64724 m .29434 .61377 L .28884 .56722 L p .885 .728 .217 r
F P
0 g
s
.70931 .42718 m .73229 .45262 L .72552 .39988 L p .174 .329 .781 r
F P
0 g
s
.72552 .39988 m .70029 .38042 L .70931 .42718 L p .174 .329 .781 r
F P
0 g
s
.39696 .35374 m .4264 .34845 L .45484 .32375 L p .764 .96 .933 r
F P
0 g
s
.32906 .76233 m .3433 .78955 L .39406 .83029 L p .824 .347 0 r
F P
0 g
s
.40954 .8474 m .39406 .83029 L .3433 .78955 L p .604 .069 0 r
F P
0 g
s
.39406 .83029 m .40954 .8474 L .47312 .86857 L p .639 .09 0 r
F P
0 g
s
.61488 .33114 m .64339 .3286 L .59846 .29943 L p .409 .661 .963 r
F P
0 g
s
.59846 .29943 m .58014 .31053 L .61488 .33114 L p .409 .661 .963 r
F P
0 g
s
.74973 .55876 m .75609 .59008 L .76957 .54251 L p 0 0 .473 r
F P
0 g
s
.76957 .54251 m .76216 .51088 L .74973 .55876 L p 0 0 .473 r
F P
0 g
s
.67073 .36659 m .70029 .38042 L .67017 .33282 L p .253 .491 .891 r
F P
0 g
s
.67017 .33282 m .64339 .3286 L .67073 .36659 L p .253 .491 .891 r
F P
0 g
s
.29443 .68023 m .30243 .71229 L .32906 .76233 L p .848 .497 0 r
F P
0 g
s
.3433 .78955 m .32906 .76233 L .30243 .71229 L p .633 .247 0 r
F P
0 g
s
.32855 .43278 m .31204 .45947 L .30688 .50545 L p .944 .944 .615 r
F P
0 g
s
.29559 .53596 m .30688 .50545 L .31204 .45947 L p .904 .879 .448 r
F P
0 g
s
.54125 .87565 m .5442 .87008 L .47312 .86857 L p .281 0 0 r
F P
0 g
s
.5442 .87008 m .54125 .87565 L .59732 .86163 L p .074 0 0 r
F P
0 g
s
.59732 .86163 m .61062 .85223 L .5442 .87008 L p .074 0 0 r
F P
0 g
s
.73455 .69794 m .72794 .72857 L .7501 .68533 L p 0 0 .097 r
F P
0 g
s
.7501 .68533 m .75661 .65339 L .73455 .69794 L p 0 0 .097 r
F P
0 g
s
.4321 .31945 m .45484 .32375 L .49339 .30669 L p .656 .928 .973 r
F P
0 g
s
.45484 .32375 m .4321 .31945 L .39696 .35374 L p .764 .96 .933 r
F P
0 g
s
.28884 .56722 m .28638 .59913 L .29186 .64724 L p .885 .728 .217 r
F P
0 g
s
.29186 .64724 m .28638 .59913 L p .29287 .66451 L .743 .555 0 r
F P
0 g
s
.29375 .67143 m .29186 .64724 L p .29287 .66451 L .743 .555 0 r
F P
0 g
s
.28638 .59913 m .28836 .6317 L .29443 .68023 L p .743 .555 0 r
F P
0 g
s
.29531 .66483 m .30243 .71229 L p .28971 .63945 L 0 0 .27 r
F P
0 g
s
.28836 .6317 m .2893 .63619 L p .28971 .63945 L 0 0 .27 r
F P
0 g
s
.2893 .63619 m .29531 .66483 L p .28971 .63945 L 0 0 .27 r
F P
0 g
s
.29443 .68023 m .29375 .67143 L p .29287 .66451 L .743 .555 0 r
F P
0 g
s
.73229 .45262 m .74983 .48076 L .7458 .42445 L p .016 .179 .69 r
F P
0 g
s
.7458 .42445 m .72552 .39988 L .73229 .45262 L p .016 .179 .69 r
F P
0 g
s
.39696 .35374 m .37098 .36551 L .35037 .40926 L p .868 .989 .831 r
F P
0 g
s
.32855 .43278 m .35037 .40926 L .37098 .36551 L p .866 .985 .707 r
F P
0 g
s
.48196 .87428 m .47312 .86857 L .40954 .8474 L p .353 0 0 r
F P
0 g
s
.47312 .86857 m .48196 .87428 L .54125 .87565 L p .281 0 0 r
F P
0 g
s
.58014 .31053 m .59846 .29943 L .54129 .28697 L p .453 .757 .994 r
F P
0 g
s
.54129 .28697 m .53744 .3017 L .58014 .31053 L p .453 .757 .994 r
F P
0 g
s
.67879 .79945 m .66312 .82074 L .69874 .78369 L p 0 0 0 r
F P
0 g
s
.69874 .78369 m .7162 .75748 L .67879 .79945 L p 0 0 0 r
F P
0 g
s
.37098 .36551 m .39696 .35374 L .4321 .31945 L p .751 .994 .857 r
F P
0 g
s
.75609 .59008 m .75842 .62161 L .77219 .57539 L p 0 0 .329 r
F P
0 g
s
.77219 .57539 m .76957 .54251 L .75609 .59008 L p 0 0 .329 r
F P
0 g
s
.48226 .29468 m .49339 .30669 L .53744 .3017 L p .54 .854 .998 r
F P
0 g
s
.49339 .30669 m .48226 .29468 L .4321 .31945 L p .656 .928 .973 r
F P
0 g
s
.61062 .85223 m .59732 .86163 L .643 .83637 L p 0 0 0 r
F P
0 g
s
.643 .83637 m .66312 .82074 L .61062 .85223 L p 0 0 0 r
F P
0 g
s
.53744 .3017 m .54129 .28697 L .48226 .29468 L p .54 .854 .998 r
F P
0 g
s
.31204 .45947 m .30051 .48852 L .29559 .53596 L p .904 .879 .448 r
F P
0 g
s
.28884 .56722 m .29559 .53596 L .30051 .48852 L p .813 .762 .249 r
F P
0 g
s
.70029 .38042 m .72552 .39988 L .69426 .34439 L p .044 .339 .818 r
F P
0 g
s
.69426 .34439 m .67017 .33282 L .70029 .38042 L p .044 .339 .818 r
F P
0 g
s
.64339 .3286 m .67017 .33282 L .61629 .2952 L p .213 .57 .94 r
F P
0 g
s
.61629 .2952 m .59846 .29943 L .64339 .3286 L p .213 .57 .94 r
F P
0 g
s
.74983 .48076 m .76216 .51088 L .76066 .45357 L p 0 0 .556 r
F P
0 g
s
.76066 .45357 m .7458 .42445 L .74983 .48076 L p 0 0 .556 r
F P
0 g
s
.72794 .72857 m .7162 .75748 L .73806 .717 L p 0 0 0 r
F P
0 g
s
.73806 .717 m .7501 .68533 L .72794 .72857 L p 0 0 0 r
F P
0 g
s
.3433 .78955 m .36301 .81194 L .40954 .8474 L p .604 .069 0 r
F P
0 g
s
.40954 .8474 m .42841 .8573 L .48196 .87428 L p .353 0 0 r
F P
0 g
s
.42841 .8573 m .40954 .8474 L .36301 .81194 L p 0 .259 .714 r
F P
0 g
s
.30243 .71229 m .29443 .68023 L .28836 .6317 L p 0 0 .27 r
F P
0 g
s
.37098 .36551 m .34909 .38325 L .32855 .43278 L p .866 .985 .707 r
F P
0 g
s
.31204 .45947 m .32855 .43278 L .34909 .38325 L p .806 .912 .517 r
F P
0 g
s
.30243 .71229 m .31632 .74273 L .3433 .78955 L p .633 .247 0 r
F P
0 g
s
.36301 .81194 m .3433 .78955 L .31632 .74273 L p 0 .037 .598 r
F P
0 g
s
.75842 .62161 m .75661 .65339 L .76983 .6094 L p 0 0 .143 r
F P
0 g
s
.76983 .6094 m .77219 .57539 L .75842 .62161 L p 0 0 .143 r
F P
0 g
s
.41094 .32219 m .4321 .31945 L .48226 .29468 L p .561 .935 .89 r
F P
0 g
s
.4321 .31945 m .41094 .32219 L .37098 .36551 L p .751 .994 .857 r
F P
0 g
s
.30051 .48852 m .29359 .51943 L .28884 .56722 L p .813 .762 .249 r
F P
0 g
s
.28638 .59913 m .28884 .56722 L .29359 .51943 L p 0 0 0 r
F P
0 g
s
.66312 .82074 m .643 .83637 L .67513 .80591 L p .563 .867 .566 r
F P
0 g
s
.67513 .80591 m .69874 .78369 L .66312 .82074 L p .563 .867 .566 r
F P
0 g
s
.34909 .38325 m .37098 .36551 L .41094 .32219 L p .66 .937 .669 r
F P
0 g
s
.5379 .87354 m .54125 .87565 L .48196 .87428 L p .086 .642 .8 r
F P
0 g
s
.54125 .87565 m .5379 .87354 L .58185 .8637 L p .251 .762 .768 r
F P
0 g
s
.58185 .8637 m .59732 .86163 L .54125 .87565 L p .251 .762 .768 r
F P
0 g
s
.49195 .87231 m .48196 .87428 L .42841 .8573 L p .038 .559 .867 r
F P
0 g
s
.48196 .87428 m .49195 .87231 L .5379 .87354 L p .086 .642 .8 r
F P
0 g
s
.76216 .51088 m .76957 .54251 L .76972 .48661 L p 0 0 .369 r
F P
0 g
s
.76972 .48661 m .76066 .45357 L .76216 .51088 L p 0 0 .369 r
F P
0 g
s
.59846 .29943 m .61629 .2952 L .54508 .27909 L p .233 .686 .952 r
F P
0 g
s
.54508 .27909 m .54129 .28697 L .59846 .29943 L p .233 .686 .952 r
F P
0 g
s
.31632 .74273 m .30243 .71229 L .29531 .66483 L p 0 0 .49 r
F P
0 g
s
.72552 .39988 m .7458 .42445 L .71458 .36367 L p 0 .107 .659 r
F P
0 g
s
.71458 .36367 m .69426 .34439 L .72552 .39988 L p 0 .107 .659 r
F P
0 g
s
.34909 .38325 m .33171 .40635 L .31204 .45947 L p .806 .912 .517 r
F P
0 g
s
.31204 .45947 m .33171 .40635 L p .30365 .48025 L .689 .77 .284 r
F P
0 g
s
.30229 .48403 m .31204 .45947 L p .30365 .48025 L .689 .77 .284 r
F P
0 g
s
.33171 .40635 m .31909 .43416 L .30051 .48852 L p .689 .77 .284 r
F P
0 g
s
.31141 .46606 m .29359 .51943 L p .31354 .45271 L 0 0 0 r
F P
0 g
s
.31909 .43416 m .31682 .44356 L p .31354 .45271 L 0 0 0 r
F P
0 g
s
.31682 .44356 m .31141 .46606 L p .31354 .45271 L 0 0 0 r
F P
0 g
s
.30051 .48852 m .30229 .48403 L p .30365 .48025 L .689 .77 .284 r
F P
0 g
s
.7162 .75748 m .69874 .78369 L .71951 .74748 L p .673 .839 .418 r
F P
0 g
s
.71951 .74748 m .73806 .717 L .7162 .75748 L p .673 .839 .418 r
F P
0 g
s
.59732 .86163 m .58185 .8637 L .61866 .84543 L p .483 .894 .784 r
F P
0 g
s
.61866 .84543 m .643 .83637 L .59732 .86163 L p .483 .894 .784 r
F P
0 g
s
.75661 .65339 m .7501 .68533 L .76202 .64429 L p 0 0 0 r
F P
0 g
s
.76202 .64429 m .76983 .6094 L .75661 .65339 L p 0 0 0 r
F P
0 g
s
.47149 .28967 m .48226 .29468 L .54129 .28697 L p .359 .819 .925 r
F P
0 g
s
.48226 .29468 m .47149 .28967 L .41094 .32219 L p .561 .935 .89 r
F P
0 g
s
.54129 .28697 m .54508 .27909 L .47149 .28967 L p .359 .819 .925 r
F P
0 g
s
.31632 .74273 m .33656 .77058 L .36301 .81194 L p 0 .037 .598 r
F P
0 g
s
.38787 .82865 m .36301 .81194 L .33656 .77058 L p 0 .285 .786 r
F P
0 g
s
.36301 .81194 m .38787 .82865 L .42841 .8573 L p 0 .259 .714 r
F P
0 g
s
.67017 .33282 m .69426 .34439 L .63289 .29934 L p 0 .368 .803 r
F P
0 g
s
.63289 .29934 m .61629 .2952 L .67017 .33282 L p 0 .368 .803 r
F P
0 g
s
.29359 .51943 m .29109 .55199 L .28638 .59913 L p 0 0 0 r
F P
0 g
s
.28836 .6317 m .28638 .59913 L .29109 .55199 L p 0 0 .179 r
F P
0 g
s
.45008 .85994 m .42841 .8573 L .38787 .82865 L p .091 .504 .903 r
F P
0 g
s
.42841 .8573 m .45008 .85994 L .49195 .87231 L p .038 .559 .867 r
F P
0 g
s
.76957 .54251 m .77219 .57539 L .77266 .5229 L p 0 0 .13 r
F P
0 g
s
.77266 .5229 m .76972 .48661 L .76957 .54251 L p 0 0 .13 r
F P
0 g
s
.41094 .32219 m .39209 .33245 L .34909 .38325 L p .66 .937 .669 r
F P
0 g
s
.33171 .40635 m .34909 .38325 L .39209 .33245 L p 0 0 0 r
F P
0 g
s
.29359 .51943 m .30051 .48852 L .31909 .43416 L p 0 0 0 r
F P
0 g
s
.29531 .66483 m .30808 .6981 L .31632 .74273 L p 0 0 .49 r
F P
0 g
s
.33656 .77058 m .31632 .74273 L .30808 .6981 L p 0 .117 .661 r
F P
0 g
s
.54864 .2799 m .54508 .27909 L .61629 .2952 L p 0 .436 .69 r
F P
0 g
s
.54508 .27909 m .54864 .2799 L .46691 .29228 L p 0 0 0 r
F P
0 g
s
.39209 .33245 m .41094 .32219 L .46996 .29049 L p 0 0 0 r
F P
0 g
s
.39209 .33245 m .46996 .29049 L .4699 .29053 L 0 0 0 r
F
.46996 .29049 m .47149 .28967 L p .4699 .29053 L F P
0 g
s
.47149 .28967 m .46151 .2931 L .39209 .33245 L p 0 0 0 r
F P
0 g
s
.46691 .29228 m .46151 .2931 L p .46712 .29216 L 0 0 0 r
F P
0 g
s
.46712 .29216 m .54508 .27909 L .46691 .29228 L 0 0 0 r
F
.643 .83637 m .61866 .84543 L .64528 .82264 L p .691 .979 .816 r
F P
0 g
s
.64528 .82264 m .67513 .80591 L .643 .83637 L p .691 .979 .816 r
F P
0 g
s
.7501 .68533 m .73806 .717 L .74803 .67959 L p .762 .818 .345 r
F P
0 g
s
.74803 .67959 m .76202 .64429 L .7501 .68533 L p .762 .818 .345 r
F P
0 g
s
.7458 .42445 m .76066 .45357 L .73003 .39067 L p 0 0 .383 r
F P
0 g
s
.73003 .39067 m .71458 .36367 L .7458 .42445 L p 0 0 .383 r
F P
0 g
s
.69874 .78369 m .67513 .80591 L .69373 .7754 L p .783 .969 .671 r
F P
0 g
s
.69373 .7754 m .71951 .74748 L .69874 .78369 L p .783 .969 .671 r
F P
0 g
s
.29109 .55199 m .29318 .58614 L .28836 .6317 L p 0 0 .179 r
F P
0 g
s
.29531 .66483 m .28836 .6317 L .29318 .58614 L p 0 0 .376 r
F P
0 g
s
.53426 .86428 m .5379 .87354 L .49195 .87231 L p .38 .793 .979 r
F P
0 g
s
.5379 .87354 m .53426 .86428 L .56462 .85845 L p .486 .878 .965 r
F P
0 g
s
.56462 .85845 m .58185 .8637 L .5379 .87354 L p .486 .878 .965 r
F P
0 g
s
.50281 .8633 m .49195 .87231 L .45008 .85994 L p .329 .709 .982 r
F P
0 g
s
.49195 .87231 m .50281 .8633 L .53426 .86428 L p .38 .793 .979 r
F P
0 g
s
.61629 .2952 m .63289 .29934 L .54864 .2799 L p 0 .436 .69 r
F P
0 g
s
.77219 .57539 m .76983 .6094 L .76919 .5617 L p .79 .682 .135 r
F P
0 g
s
.76919 .5617 m .77266 .5229 L .77219 .57539 L p .79 .682 .135 r
F P
0 g
s
.33656 .77058 m .36343 .79463 L .38787 .82865 L p 0 .285 .786 r
F P
0 g
s
.41741 .83895 m .38787 .82865 L .36343 .79463 L p .177 .468 .889 r
F P
0 g
s
.38787 .82865 m .41741 .83895 L .45008 .85994 L p .091 .504 .903 r
F P
0 g
s
.58185 .8637 m .56462 .85845 L .59058 .84711 L p .617 .941 .95 r
F P
0 g
s
.59058 .84711 m .61866 .84543 L .58185 .8637 L p .617 .941 .95 r
F P
0 g
s
.69426 .34439 m .71458 .36367 L .64732 .31315 L p .526 0 0 r
F P
0 g
s
.64732 .31315 m .63289 .29934 L .69426 .34439 L p .526 0 0 r
F P
0 g
s
.29109 .55199 m .29359 .51943 L .31141 .46606 L p 0 0 .161 r
F P
0 g
s
.46151 .2931 m .47149 .28967 L .54508 .27909 L p 0 0 0 r
F P
0 g
s
.73806 .717 m .71951 .74748 L .72716 .71439 L p .862 .944 .58 r
F P
0 g
s
.72716 .71439 m .74803 .67959 L .73806 .717 L p .862 .944 .58 r
F P
0 g
s
.30808 .6981 m .3276 .73064 L .33656 .77058 L p 0 .117 .661 r
F P
0 g
s
.36343 .79463 m .33656 .77058 L .3276 .73064 L p .087 .302 .782 r
F P
0 g
s
.47396 .8555 m .45008 .85994 L .41741 .83895 L p .329 .64 .965 r
F P
0 g
s
.45008 .85994 m .47396 .8555 L .50281 .8633 L p .329 .709 .982 r
F P
0 g
s
.39209 .33245 m .37633 .3505 L .33171 .40635 L p 0 0 0 r
F P
0 g
s
.31909 .43416 m .33171 .40635 L .37633 .3505 L p 0 0 0 r
F P
0 g
s
.29318 .58614 m .30036 .62176 L .29531 .66483 L p 0 0 .376 r
F P
0 g
s
.30808 .6981 m .29531 .66483 L .30036 .62176 L p 0 0 .543 r
F P
0 g
s
.76066 .45357 m .76972 .48661 L .73961 .42493 L p .833 .482 0 r
F P
0 g
s
.73961 .42493 m .73003 .39067 L .76066 .45357 L p .833 .482 0 r
F P
0 g
s
.67513 .80591 m .64528 .82264 L .66049 .79899 L p .812 .999 .84 r
F P
0 g
s
.66049 .79899 m .69373 .7754 L .67513 .80591 L p .812 .999 .84 r
F P
0 g
s
.61866 .84543 m .59058 .84711 L .60968 .83236 L p .723 .967 .936 r
F P
0 g
s
.60968 .83236 m .64528 .82264 L .61866 .84543 L p .723 .967 .936 r
F P
0 g
s
.76983 .6094 m .76202 .64429 L .75905 .60218 L p .909 .838 .381 r
F P
0 g
s
.75905 .60218 m .76919 .5617 L .76983 .6094 L p .909 .838 .381 r
F P
0 g
s
.37633 .3505 m .39209 .33245 L .46151 .2931 L p 0 0 0 r
F P
0 g
s
.31141 .46606 m .30886 .50149 L .29109 .55199 L p 0 0 .161 r
F P
0 g
s
.29318 .58614 m .29109 .55199 L .30886 .50149 L p 0 0 .341 r
F P
0 g
s
.71951 .74748 m .69373 .7754 L .69895 .74737 L p .888 .99 .751 r
F P
0 g
s
.69895 .74737 m .72716 .71439 L .71951 .74748 L p .888 .99 .751 r
F P
0 g
s
.36343 .79463 m .3968 .81348 L .41741 .83895 L p .177 .468 .889 r
F P
0 g
s
.45094 .84223 m .41741 .83895 L .3968 .81348 L p .354 .594 .936 r
F P
0 g
s
.41741 .83895 m .45094 .84223 L .47396 .8555 L p .329 .64 .965 r
F P
0 g
s
.30036 .62176 m .31342 .6585 L .30808 .6981 L p 0 0 .543 r
F P
0 g
s
.3276 .73064 m .30808 .6981 L .31342 .6585 L p .04 .171 .675 r
F P
0 g
s
.3276 .73064 m .35455 .76109 L .36343 .79463 L p .087 .302 .782 r
F P
0 g
s
.3968 .81348 m .36343 .79463 L .35455 .76109 L p .25 .451 .862 r
F P
0 g
s
.53038 .84844 m .53426 .86428 L .50281 .8633 L p .532 .812 .997 r
F P
0 g
s
.53426 .86428 m .53038 .84844 L .54598 .84597 L p .591 .859 .994 r
F P
0 g
s
.54598 .84597 m .56462 .85845 L .53426 .86428 L p .591 .859 .994 r
F P
0 g
s
.51431 .84786 m .50281 .8633 L .47396 .8555 L p .495 .759 .989 r
F P
0 g
s
.50281 .8633 m .51431 .84786 L .53038 .84844 L p .532 .812 .997 r
F P
0 g
s
.37633 .3505 m .36443 .37629 L .31909 .43416 L p 0 0 0 r
F P
0 g
s
.31141 .46606 m .31909 .43416 L .36443 .37629 L p 0 0 .194 r
F P
0 g
s
.76972 .48661 m .77266 .5229 L .74255 .46545 L p .962 .674 .249 r
F P
0 g
s
.74255 .46545 m .73961 .42493 L .76972 .48661 L p .962 .674 .249 r
F P
0 g
s
.71458 .36367 m .73003 .39067 L .65855 .33738 L p .799 .305 0 r
F P
0 g
s
.65855 .33738 m .64732 .31315 L .71458 .36367 L p .799 .305 0 r
F P
0 g
s
.63289 .29934 m .64732 .31315 L .55177 .29107 L p .528 0 0 r
F P
0 g
s
.55177 .29107 m .54864 .2799 L .63289 .29934 L p .528 0 0 r
F P
0 g
s
.56462 .85845 m .54598 .84597 L .55947 .84085 L p .654 .889 .982 r
F P
0 g
s
.55947 .84085 m .59058 .84711 L .56462 .85845 L p .654 .889 .982 r
F P
0 g
s
.76202 .64429 m .74803 .67959 L .74214 .64329 L p .956 .924 .574 r
F P
0 g
s
.74214 .64329 m .75905 .60218 L .76202 .64429 L p .956 .924 .574 r
F P
0 g
s
.64528 .82264 m .60968 .83236 L .62039 .81637 L p .783 .96 .924 r
F P
0 g
s
.62039 .81637 m .66049 .79899 L .64528 .82264 L p .783 .96 .924 r
F P
0 g
s
.49952 .84425 m .47396 .8555 L .45094 .84223 L p .482 .713 .972 r
F P
0 g
s
.47396 .8555 m .49952 .84425 L .51431 .84786 L p .495 .759 .989 r
F P
0 g
s
.30886 .50149 m .31166 .53991 L .29318 .58614 L p 0 0 .341 r
F P
0 g
s
.30036 .62176 m .29318 .58614 L .31166 .53991 L p 0 0 .489 r
F P
0 g
s
.45287 .30618 m .46151 .2931 L .54864 .2799 L p .325 0 0 r
F P
0 g
s
.46151 .2931 m .45287 .30618 L .37633 .3505 L p 0 0 0 r
F P
0 g
s
.69373 .7754 m .66049 .79899 L .66352 .77682 L p .861 .978 .856 r
F P
0 g
s
.66352 .77682 m .69895 .74737 L .69373 .7754 L p .861 .978 .856 r
F P
0 g
s
.59058 .84711 m .55947 .84085 L .56945 .83385 L p .702 .898 .967 r
F P
0 g
s
.56945 .83385 m .60968 .83236 L .59058 .84711 L p .702 .898 .967 r
F P
0 g
s
.31342 .6585 m .33316 .69552 L .3276 .73064 L p .04 .171 .675 r
F P
0 g
s
.35455 .76109 m .3276 .73064 L .33316 .69552 L p .19 .325 .772 r
F P
0 g
s
.54864 .2799 m .55177 .29107 L .45287 .30618 L p .325 0 0 r
F P
0 g
s
.35455 .76109 m .38904 .78768 L .3968 .81348 L p .25 .451 .862 r
F P
0 g
s
.43601 .82575 m .3968 .81348 L .38904 .78768 L p .384 .568 .91 r
F P
0 g
s
.3968 .81348 m .43601 .82575 L .45094 .84223 L p .354 .594 .936 r
F P
0 g
s
.36443 .37629 m .37633 .3505 L .45287 .30618 L p .205 0 .127 r
F P
0 g
s
.74803 .67959 m .72716 .71439 L .71851 .68381 L p .951 .954 .711 r
F P
0 g
s
.71851 .68381 m .74214 .64329 L .74803 .67959 L p .951 .954 .711 r
F P
0 g
s
.4876 .83811 m .45094 .84223 L .43601 .82575 L p .486 .681 .952 r
F P
0 g
s
.45094 .84223 m .4876 .83811 L .49952 .84425 L p .482 .713 .972 r
F P
0 g
s
.77266 .5229 m .76919 .5617 L .73844 .51074 L p .998 .778 .455 r
F P
0 g
s
.73844 .51074 m .74255 .46545 L .77266 .5229 L p .998 .778 .455 r
F P
0 g
s
.36443 .37629 m .35708 .40939 L .31141 .46606 L p 0 0 .194 r
F P
0 g
s
.30886 .50149 m .31141 .46606 L .35708 .40939 L p .087 0 .372 r
F P
0 g
s
.31166 .53991 m .3201 .58068 L .30036 .62176 L p 0 0 .489 r
F P
0 g
s
.31342 .6585 m .30036 .62176 L .3201 .58068 L p .092 .129 .608 r
F P
0 g
s
.60968 .83236 m .56945 .83385 L .5749 .82588 L p .729 .892 .954 r
F P
0 g
s
.5749 .82588 m .62039 .81637 L .60968 .83236 L p .729 .892 .954 r
F P
0 g
s
.33316 .69552 m .3601 .73146 L .35455 .76109 L p .19 .325 .772 r
F P
0 g
s
.38904 .78768 m .35455 .76109 L .3601 .73146 L p .315 .453 .841 r
F P
0 g
s
.66049 .79899 m .62039 .81637 L .62171 .80088 L p .808 .935 .915 r
F P
0 g
s
.62171 .80088 m .66352 .77682 L .66049 .79899 L p .808 .935 .915 r
F P
0 g
s
.73003 .39067 m .73961 .42493 L .66559 .37198 L p .895 .5 .265 r
F P
0 g
s
.66559 .37198 m .65855 .33738 L .73003 .39067 L p .895 .5 .265 r
F P
0 g
s
.52632 .82641 m .53038 .84844 L .51431 .84786 L closepath p .608 .791 .969 r
F P
0 g
s
.52632 .82641 m .54598 .84597 L .53038 .84844 L closepath p .63 .807 .968 r
F P
0 g
s
.52632 .82641 m .51431 .84786 L .49952 .84425 L closepath p .592 .771 .965 r
F P
0 g
s
.52632 .82641 m .55947 .84085 L .54598 .84597 L closepath p .65 .814 .962 r
F P
0 g
s
.72716 .71439 m .69895 .74737 L .68855 .72231 L p .917 .95 .802 r
F P
0 g
s
.68855 .72231 m .71851 .68381 L .72716 .71439 L p .917 .95 .802 r
F P
0 g
s
.38904 .78768 m .43036 .80851 L .43601 .82575 L p .384 .568 .91 r
F P
0 g
s
.47979 .83029 m .43601 .82575 L .43036 .80851 L p .496 .662 .936 r
F P
0 g
s
.43601 .82575 m .47979 .83029 L .4876 .83811 L p .486 .681 .952 r
F P
0 g
s
.52632 .82641 m .49952 .84425 L .4876 .83811 L closepath p .586 .753 .957 r
F P
0 g
s
.52632 .82641 m .56945 .83385 L .55947 .84085 L closepath p .662 .815 .957 r
F P
0 g
s
.64732 .31315 m .65855 .33738 L .55422 .31374 L p .698 .238 .156 r
F P
0 g
s
.55422 .31374 m .55177 .29107 L .64732 .31315 L p .698 .238 .156 r
F P
0 g
s
.3201 .58068 m .33444 .62294 L .31342 .6585 L p .092 .129 .608 r
F P
0 g
s
.33316 .69552 m .31342 .6585 L .33444 .62294 L p .212 .265 .701 r
F P
0 g
s
.76919 .5617 m .75905 .60218 L .72734 .55893 L p .989 .829 .593 r
F P
0 g
s
.72734 .55893 m .73844 .51074 L .76919 .5617 L p .989 .829 .593 r
F P
0 g
s
.52632 .82641 m .4876 .83811 L .47979 .83029 L closepath p .587 .743 .95 r
F P
0 g
s
.3601 .73146 m .39416 .7645 L .38904 .78768 L p .315 .453 .841 r
F P
0 g
s
.43036 .80851 m .38904 .78768 L .39416 .7645 L p .42 .561 .89 r
F P
0 g
s
.35708 .40939 m .35479 .44894 L .30886 .50149 L p .087 0 .372 r
F P
0 g
s
.31166 .53991 m .30886 .50149 L .35479 .44894 L p .196 .09 .499 r
F P
0 g
s
.62039 .81637 m .5749 .82588 L .57521 .81782 L p .741 .878 .943 r
F P
0 g
s
.57521 .81782 m .62171 .80088 L .62039 .81637 L p .741 .878 .943 r
F P
0 g
s
.52632 .82641 m .5749 .82588 L .56945 .83385 L closepath p .667 .814 .954 r
F P
0 g
s
.45287 .30618 m .44617 .32968 L .36443 .37629 L p .205 0 .127 r
F P
0 g
s
.35708 .40939 m .36443 .37629 L .44617 .32968 L p .342 .064 .339 r
F P
0 g
s
.44617 .32968 m .45287 .30618 L .55177 .29107 L p .503 .092 .194 r
F P
0 g
s
.69895 .74737 m .66352 .77682 L .65301 .75724 L p .867 .928 .863 r
F P
0 g
s
.65301 .75724 m .68855 .72231 L .69895 .74737 L p .867 .928 .863 r
F P
0 g
s
.43036 .80851 m .47692 .82183 L .47979 .83029 L p .496 .662 .936 r
F P
0 g
s
.52632 .82641 m .47979 .83029 L .47692 .82183 L closepath p .59 .738 .946 r
F P
0 g
s
.33444 .62294 m .35481 .66554 L .33316 .69552 L p .212 .265 .701 r
F P
0 g
s
.3601 .73146 m .33316 .69552 L .35481 .66554 L p .313 .381 .772 r
F P
0 g
s
.39416 .7645 m .43447 .79257 L .43036 .80851 L p .42 .561 .89 r
F P
0 g
s
.47692 .82183 m .43036 .80851 L .43447 .79257 L p .511 .654 .923 r
F P
0 g
s
.52632 .82641 m .57521 .81782 L .5749 .82588 L closepath p .668 .813 .953 r
F P
0 g
s
.55177 .29107 m .55422 .31374 L .44617 .32968 L p .503 .092 .194 r
F P
0 g
s
.75905 .60218 m .74214 .64329 L .70973 .60796 L p .961 .852 .689 r
F P
0 g
s
.70973 .60796 m .72734 .55893 L .75905 .60218 L p .961 .852 .689 r
F P
0 g
s
.66352 .77682 m .62171 .80088 L .61306 .78707 L p .809 .897 .905 r
F P
0 g
s
.61306 .78707 m .65301 .75724 L .66352 .77682 L p .809 .897 .905 r
F P
0 g
s
.73961 .42493 m .74255 .46545 L .6677 .41587 L p .912 .603 .447 r
F P
0 g
s
.6677 .41587 m .66559 .37198 L .73961 .42493 L p .912 .603 .447 r
F P
0 g
s
.43447 .79257 m .47931 .8137 L .47692 .82183 L p .511 .654 .923 r
F P
0 g
s
.52632 .82641 m .47692 .82183 L .47931 .8137 L closepath p .592 .737 .945 r
F P
0 g
s
.35479 .44894 m .35787 .49365 L .31166 .53991 L p .196 .09 .499 r
F P
0 g
s
.3201 .58068 m .31166 .53991 L .35787 .49365 L p .281 .207 .592 r
F P
0 g
s
.52632 .82641 m .56039 .80445 L .57024 .81047 L closepath p .671 .803 .946 r
F P
0 g
s
.52632 .82641 m .54663 .80028 L .56039 .80445 L closepath p .667 .788 .939 r
F P
0 g
s
.52632 .82641 m .53048 .79832 L .54663 .80028 L closepath p .656 .77 .933 r
F P
0 g
s
.52632 .82641 m .51387 .79878 L .53048 .79832 L closepath p .638 .753 .932 r
F P
0 g
s
.52632 .82641 m .49874 .80166 L .51387 .79878 L closepath p .618 .742 .935 r
F P
0 g
s
.52632 .82641 m .48682 .80677 L .49874 .80166 L closepath p .603 .738 .94 r
F P
0 g
s
.52632 .82641 m .47931 .8137 L .48682 .80677 L closepath p .594 .737 .943 r
F P
0 g
s
.52632 .82641 m .57024 .81047 L .57521 .81782 L closepath p .67 .811 .951 r
F P
0 g
s
.62171 .80088 m .57521 .81782 L .57024 .81047 L p .744 .858 .933 r
F P
0 g
s
.57024 .81047 m .61306 .78707 L .62171 .80088 L p .744 .858 .933 r
F P
0 g
s
.35481 .66554 m .38104 .70699 L .3601 .73146 L p .313 .381 .772 r
F P
0 g
s
.39416 .7645 m .3601 .73146 L .38104 .70699 L p .398 .481 .829 r
F P
0 g
s
.44831 .77938 m .48682 .80677 L .47931 .8137 L p .535 .655 .912 r
F P
0 g
s
.47931 .8137 m .43447 .79257 L .44831 .77938 L p .535 .655 .912 r
F P
0 g
s
.74214 .64329 m .71851 .68381 L .68647 .65579 L p .925 .861 .758 r
F P
0 g
s
.68647 .65579 m .70973 .60796 L .74214 .64329 L p .925 .861 .758 r
F P
0 g
s
.38104 .70699 m .41256 .74555 L .39416 .7645 L p .398 .481 .829 r
F P
0 g
s
.43447 .79257 m .39416 .7645 L .41256 .74555 L p .47 .571 .874 r
F P
0 g
s
.41256 .74555 m .44831 .77938 L .43447 .79257 L p .47 .571 .874 r
F P
0 g
s
.44617 .32968 m .44197 .36356 L .35708 .40939 L p .342 .064 .339 r
F P
0 g
s
.35479 .44894 m .35708 .40939 L .44197 .36356 L p .423 .203 .473 r
F P
0 g
s
.65855 .33738 m .66559 .37198 L .55576 .34808 L p .755 .394 .37 r
F P
0 g
s
.55576 .34808 m .55422 .31374 L .65855 .33738 L p .755 .394 .37 r
F P
0 g
s
.61306 .78707 m .57024 .81047 L .56039 .80445 L p .737 .828 .921 r
F P
0 g
s
.35787 .49365 m .36633 .54186 L .3201 .58068 L p .281 .207 .592 r
F P
0 g
s
.33444 .62294 m .3201 .58068 L .36633 .54186 L p .349 .304 .665 r
F P
0 g
s
.47119 .76987 m .49874 .80166 L .48682 .80677 L p .569 .665 .902 r
F P
0 g
s
.48682 .80677 m .44831 .77938 L .47119 .76987 L p .569 .665 .902 r
F P
0 g
s
.71851 .68381 m .68855 .72231 L .65869 .70062 L p .885 .862 .812 r
F P
0 g
s
.65869 .70062 m .68647 .65579 L .71851 .68381 L p .885 .862 .812 r
F P
0 g
s
.74255 .46545 m .73844 .51074 L .66455 .46694 L p .904 .662 .563 r
F P
0 g
s
.66455 .46694 m .6677 .41587 L .74255 .46545 L p .904 .662 .563 r
F P
0 g
s
.44197 .36356 m .44617 .32968 L .55422 .31374 L p .584 .259 .386 r
F P
0 g
s
.65301 .75724 m .61306 .78707 L .59449 .77583 L p .792 .845 .891 r
F P
0 g
s
.56039 .80445 m .59449 .77583 L .61306 .78707 L p .737 .828 .921 r
F P
0 g
s
.59449 .77583 m .56039 .80445 L .54663 .80028 L p .719 .79 .908 r
F P
0 g
s
.68855 .72231 m .65301 .75724 L .62762 .74099 L p .841 .856 .855 r
F P
0 g
s
.62762 .74099 m .65869 .70062 L .68855 .72231 L p .841 .856 .855 r
F P
0 g
s
.50118 .76467 m .51387 .79878 L .49874 .80166 L p .611 .685 .895 r
F P
0 g
s
.49874 .80166 m .47119 .76987 L .50118 .76467 L p .611 .685 .895 r
F P
0 g
s
.59449 .77583 m .62762 .74099 L .65301 .75724 L p .792 .845 .891 r
F P
0 g
s
.36633 .54186 m .37988 .59169 L .33444 .62294 L p .349 .304 .665 r
F P
0 g
s
.35481 .66554 m .33444 .62294 L .37988 .59169 L p .406 .386 .725 r
F P
0 g
s
.54663 .80028 m .56735 .76792 L .59449 .77583 L p .719 .79 .908 r
F P
0 g
s
.56735 .76792 m .54663 .80028 L .53048 .79832 L p .69 .751 .898 r
F P
0 g
s
.53477 .76404 m .53048 .79832 L .51387 .79878 L p .653 .715 .893 r
F P
0 g
s
.51387 .79878 m .50118 .76467 L .53477 .76404 L p .653 .715 .893 r
F P
0 g
s
.44457 .73178 m .47119 .76987 L .44831 .77938 L p .534 .596 .863 r
F P
0 g
s
.44831 .77938 m .41256 .74555 L .44457 .73178 L p .534 .596 .863 r
F P
0 g
s
.53048 .79832 m .53477 .76404 L .56735 .76792 L p .69 .751 .898 r
F P
0 g
s
.55422 .31374 m .55576 .34808 L .44197 .36356 L p .584 .259 .386 r
F P
0 g
s
.37988 .59169 m .39798 .64117 L .35481 .66554 L p .406 .386 .725 r
F P
0 g
s
.38104 .70699 m .35481 .66554 L .39798 .64117 L p .454 .46 .776 r
F P
0 g
s
.44197 .36356 m .4407 .40681 L .35479 .44894 L p .423 .203 .473 r
F P
0 g
s
.35787 .49365 m .35479 .44894 L .4407 .40681 L p .475 .301 .565 r
F P
0 g
s
.41984 .68842 m .44457 .73178 L .41256 .74555 L p .496 .529 .821 r
F P
0 g
s
.41256 .74555 m .38104 .70699 L .41984 .68842 L p .496 .529 .821 r
F P
0 g
s
.39798 .64117 m .41984 .68842 L .38104 .70699 L p .454 .46 .776 r
F P
0 g
s
.73844 .51074 m .72734 .55893 L .65626 .52232 L p .887 .701 .644 r
F P
0 g
s
.65626 .52232 m .66455 .46694 L .73844 .51074 L p .887 .701 .644 r
F P
0 g
s
.62762 .74099 m .59449 .77583 L .56735 .76792 L p .76 .786 .874 r
F P
0 g
s
.66559 .37198 m .6677 .41587 L .55622 .39303 L p .773 .485 .499 r
F P
0 g
s
.55622 .39303 m .55576 .34808 L .66559 .37198 L p .773 .485 .499 r
F P
0 g
s
.48852 .7241 m .50118 .76467 L .47119 .76987 L p .601 .633 .855 r
F P
0 g
s
.47119 .76987 m .44457 .73178 L .48852 .7241 L p .601 .633 .855 r
F P
0 g
s
.4407 .40681 m .44197 .36356 L .55576 .34808 L p .624 .364 .504 r
F P
0 g
s
.56735 .76792 m .58811 .72918 L .62762 .74099 L p .76 .786 .874 r
F P
0 g
s
.58811 .72918 m .56735 .76792 L .53477 .76404 L p .715 .729 .861 r
F P
0 g
s
.65869 .70062 m .62762 .74099 L .58811 .72918 L p .793 .777 .839 r
F P
0 g
s
.72734 .55893 m .70973 .60796 L .64346 .57885 L p .868 .728 .705 r
F P
0 g
s
.64346 .57885 m .65626 .52232 L .72734 .55893 L p .868 .728 .705 r
F P
0 g
s
.4407 .40681 m .44257 .45747 L .35787 .49365 L p .475 .301 .565 r
F P
0 g
s
.36633 .54186 m .35787 .49365 L .44257 .45747 L p .511 .376 .633 r
F P
0 g
s
.5391 .72323 m .53477 .76404 L .50118 .76467 L p .662 .678 .855 r
F P
0 g
s
.50118 .76467 m .48852 .7241 L .5391 .72323 L p .662 .678 .855 r
F P
0 g
s
.53477 .76404 m .5391 .72323 L .58811 .72918 L p .715 .729 .861 r
F P
0 g
s
.47627 .67738 m .48852 .7241 L .44457 .73178 L p .588 .585 .816 r
F P
0 g
s
.44457 .73178 m .41984 .68842 L .47627 .67738 L p .588 .585 .816 r
F P
0 g
s
.68647 .65579 m .65869 .70062 L .60832 .68417 L p .821 .765 .799 r
F P
0 g
s
.58811 .72918 m .60832 .68417 L .65869 .70062 L p .793 .777 .839 r
F P
0 g
s
.70973 .60796 m .68647 .65579 L .62712 .63357 L p .846 .749 .756 r
F P
0 g
s
.62712 .63357 m .64346 .57885 L .70973 .60796 L p .846 .749 .756 r
F P
0 g
s
.60832 .68417 m .62712 .63357 L .68647 .65579 L p .821 .765 .799 r
F P
0 g
s
.55576 .34808 m .55622 .39303 L .4407 .40681 L p .624 .364 .504 r
F P
0 g
s
.44257 .45747 m .44749 .5128 L .36633 .54186 L p .511 .376 .633 r
F P
0 g
s
.37988 .59169 m .36633 .54186 L .44749 .5128 L p .537 .436 .688 r
F P
0 g
s
.6677 .41587 m .66455 .46694 L .55553 .4463 L p .776 .545 .585 r
F P
0 g
s
.55553 .4463 m .55622 .39303 L .6677 .41587 L p .776 .545 .585 r
F P
0 g
s
.46493 .6254 m .47627 .67738 L .41984 .68842 L p .574 .537 .776 r
F P
0 g
s
.41984 .68842 m .39798 .64117 L .46493 .6254 L p .574 .537 .776 r
F P
0 g
s
.60832 .68417 m .58811 .72918 L .5391 .72323 L p .734 .706 .824 r
F P
0 g
s
.44749 .5128 m .45513 .56974 L .37988 .59169 L p .537 .436 .688 r
F P
0 g
s
.39798 .64117 m .37988 .59169 L .45513 .56974 L p .557 .489 .734 r
F P
0 g
s
.45513 .56974 m .46493 .6254 L .39798 .64117 L p .557 .489 .734 r
F P
0 g
s
.54336 .67581 m .5391 .72323 L .48852 .7241 L p .667 .643 .817 r
F P
0 g
s
.48852 .7241 m .47627 .67738 L .54336 .67581 L p .667 .643 .817 r
F P
0 g
s
.44257 .45747 m .4407 .40681 L .55622 .39303 L p .646 .436 .584 r
F P
0 g
s
.5391 .72323 m .54336 .67581 L .60832 .68417 L p .734 .706 .824 r
F P
0 g
s
.66455 .46694 m .65626 .52232 L .5537 .50466 L p .774 .589 .649 r
F P
0 g
s
.5537 .50466 m .55553 .4463 L .66455 .46694 L p .774 .589 .649 r
F P
0 g
s
.62712 .63357 m .60832 .68417 L .54336 .67581 L p .749 .681 .786 r
F P
0 g
s
.55622 .39303 m .55553 .4463 L .44257 .45747 L p .646 .436 .584 r
F P
0 g
s
.54738 .62238 m .54336 .67581 L .47627 .67738 L p .669 .608 .779 r
F P
0 g
s
.47627 .67738 m .46493 .6254 L .54738 .62238 L p .669 .608 .779 r
F P
0 g
s
.44749 .5128 m .44257 .45747 L .55553 .4463 L p .658 .49 .645 r
F P
0 g
s
.64346 .57885 m .62712 .63357 L .54738 .62238 L p .76 .654 .745 r
F P
0 g
s
.54336 .67581 m .54738 .62238 L .62712 .63357 L p .749 .681 .786 r
F P
0 g
s
.65626 .52232 m .64346 .57885 L .55091 .56447 L p .768 .624 .701 r
F P
0 g
s
.55091 .56447 m .5537 .50466 L .65626 .52232 L p .768 .624 .701 r
F P
0 g
s
.54738 .62238 m .55091 .56447 L .64346 .57885 L p .76 .654 .745 r
F P
0 g
s
.55091 .56447 m .54738 .62238 L .46493 .6254 L p .668 .573 .739 r
F P
0 g
s
.46493 .6254 m .45513 .56974 L .55091 .56447 L p .668 .573 .739 r
F P
0 g
s
.55553 .4463 m .5537 .50466 L .44749 .5128 L p .658 .49 .645 r
F P
0 g
s
.45513 .56974 m .44749 .5128 L .5537 .50466 L p .665 .534 .695 r
F P
0 g
s
.5537 .50466 m .55091 .56447 L .45513 .56974 L p .665 .534 .695 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0O_ooool8o`0002Wooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0_ooooo`00:oooool3o`0000[ooooo00?o0000
ooooooooool0MOooool:o`0000?oD`0000?o0000ohL00?n700001Ol0000Tooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1]ooooo`[o00002omC00000ol0003oQ`00ohL00004ohL000Co00008?ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo000Qooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06Kooooo2Ol0000?oe<000Ko
00002?n70004o`0001cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0]ooooo`00
8oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Hoooool4o`00013oD`001_l00003oh0G<@03o`000?nb?2Oo/S`W00Co00002?n70005o`0001Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`006?ooool6o`0000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo1?l0
000;oe<000Oo00002On05c400ol0003o/S`Wok8l9`04ok8l9`Go00002?n70004o`0001?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`008oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0GOooool5o`0000KoD`001_l0000@
oh0G<@03o`000?nb?2Oo/S`W00Wo/S`W1?l00008ohL000?o00004?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo00Cooooo0_l0000Boooo
o`03o`000?oooooooooo05_ooooo1Ol000000omC003o0000o`000004o`0001OoP1La00?o0000ok8l
9onb?2L03?nb?2L4o`0000OoQ`0000?o0000ooooooooool03Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo02_ooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1Hooooo`So00007On05c400ol0003o/S`Wok8l9`0@ok8l9`Go
00000on700000ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:_ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo05Gooooo1_l000000old023o0000oh0G<@0Noh0G<@03o`000?nb?2Oo/S`W01Go/S`W
1_l0000<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o
EEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05;ooooo1_l0
0003oc@08003o`000?n05c7oP1La01[oP1La1_l0000Iok8l9`?o00002oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo000Zooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0Coooool7o`0000?o=00P00?o0000oh0G<On05c405?n05c47o`0000?oUD9R00?o0000
ol5TG_o1I5h01?l0000Fok8l9`03o`000?o<CP3o000000[ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04cooooo1ol00005oc@08003o`000?n05c7oP1La00goP1La1ol0000:oiE2HP03o`000?o1I5ko`FAN
00Co`FAN1?l0000Cok8l9`04o`000?o<CP3o0000o`0000Sooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04[ooooo1_l00007oc@08003o`000?n05c7oP1La00KoP1La1ol0000AoiE2HP03o`000?o1I5ko`FAN
00So`FAN1?l0000?ok8l9`03o`000?o<CP3oc4h000;o00001oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Oooooo000Yooooo`;o00006_ooool00ol0003oooooooooo`17ooooo`Oo
00001old02000ol0003oP1Laoh0G<@07o`0001SoUD9R00?o0000ol5TG_o1I5h03?o1I5h4o`0000_o
/S`W00?o0000ola>0?o<CP000_o<CP02o`0000Kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo
1ol00008oc@080Co00007onE@V800ol0003o`FANol5TGP0@ol5TGPCo00002?nb?2L00ol0003oc4h0
ola>0002ola>00;o00001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo
000Yooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool6o`0000So=00P0_l0
00000omG45Ko0000oiE2HP0PoiE2HP03o`000?o1I5ko`FAN01Co`FAN1?l00004ok8l9`03o`000?o<
CP3oc4h000?oc4h00_l00004ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09Ooo
ool002Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`Co00002Old0200
1Ol0003oEa1FoeL@E_mG45Ko0000027oUD9R00?o0000ol5TG_o1I5h06?o1I5h5o`0000Ooc4h00_l0
0002ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0oooooo`Co00002?ld0202o`0000CoEa1F00?o0000
oiE2H_nE@V807onE@V800ol0003o`FANol5TGP0Lol5TGP?o00001_o<CP02o`000003ooooool0003o
oooo03Sooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0mooooo`?o00002?ld0202o`0000GoEa1F00?o0000oiE2H_nE@V808?nE@V800ol0
003o`FANol5TGP0Mol5TGP03o`000?oUOd?o000000Koc4h00ol0000jooooo`03o`000?oooooooooo
02?ooooo000Xooooo`;o00008Oooool00ol0003oooooooooo`0kooooo`;o00002?ld0202o`0000Oo
Ea1F00?o0000oiE2H_nE@V808?nE@V800ol0003o`FANol5TGP0Mol5TGP04o`000?oUOd?oiGm3o`00
00Koc4h00ol0000iooooo`03o`000?oooooooooo02?ooooo000Xooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0>Oooool2o`0000So=00P00?o0000oeL@E_mG45H01omG45H00ol0003o
UD9RoiE2HP0LoiE2HPOo00007Oo1I5h01?l0003oiGm3onEo@ooUOd<2o`0000Goc4h00ol0000ioooo
o`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0=oooool00ol0003o=00Poc@08006oc@080;o00002_mG45H00ol0003oUD9RoiE2HP0EoiE2HPOo
00001?nOGH400ol0003oaGaoolElO`04o`0001[o`FAN00?o0000onEo@ooUOd<00_oUOd<00ol0003o
c4h0ola>0002ola>0004o`000?o<CP3o0000o`0003Wooooo00?o0000ooooooooool08Oooool002So
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0eooooo`;o00001_ld0202o`0000co
Ea1F00?o0000oiE2H_nE@V803_nE@V87o`0000_oWef100?o0000olElOoo5O7l01?o5O7l5o`0001Go
`FAN00?o0000onEo@ooUOd<00ooUOd<01Ol0003oc4h0ola>0?o<CP3o000000;oc4h00_l0000hoooo
o`03o`000?oooooooooo027ooooo000Wooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0<oooool2o`0000Ko=00P00?o0000oeL@E_mG45H02omG45H00ol0003oUD9RoiE2HP08oiE2HPOo
00004_nOGH400ol0003oaGaoolElO`09olElO`Co00004Oo1I5h00ol0003oiGm3onEo@`04onEo@`;o
000000?oc4h0o`000?o<CP000oo<CP000ol0003oooooooooo`0fooooo`03o`000?oooooooooo023o
oooo000Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0<_ooool2o`0000Co=00P
0_l0000>oeL@EP04o`000?nE@V;oUD9RoiE2HPOo00006OnOGH400ol0003oaGaoolElO`0=olElO`Co
00003Oo1I5h00ol0003oiGm3onEo@`06onEo@`;o00001Oo<CP000ol0003oooooooooo`0eooooo`03
o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
<?ooool2o`0000?o=00P0_l0000?oeL@EPGo00008?nOGH400ol0003oaGaoolElO`0AolElO`Co0000
2Oo1I5h00ol0003oiGm3onEo@`07onEo@`;o00001Oo<CP000ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0^ooooo`?o000000?o
=00Po`000?l000003omG45H2o`000003of`cNOl0003oWef102;oWef100?o0000olElOoo5O7l05Oo5
O7l5o`0000Go`FAN00?o0000onEo@ooUOd<01_oUOd<00ol0003oiGm3o`000004ola>0003o`000?oo
oooooooo03Kooooo00?o0000ooooooooool07_ooool002Oooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0/ooooo`?o000000?o=00Po`000?mG45H03_mG45H2o`0000?oK3=i00?o0000
oimMPOnOGH408OnOGH400ol0003oaGaoolElO`0JolElO`Co000000?o`FANo`000?oUOd<01ooUOd<0
1?l0003oiGm3onEo@ol00004ola>0003o`000?oooooooooo03Gooooo00?o0000ooooooooool07_oo
ool002Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Zooooo`Go00003_mG45H2
o`0000GoK3=i00?o0000oimMPOnOGH408OnOGH400ol0003oaGaoolElO`0NolElO`?o00001ooUOd<0
1?l0003oiGm3onEo@ooUOd<2o`0000;oc4h000?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Sooooo1?l0000?
oeL@EP03o`000?m/<gWoK3=i00GoK3=i00?o0000oimMPOnOGH408OnOGH400ol0003oaGaoolElO`0O
olElO`03o`000?oYVW;o000000KoiGm300?o0000onEo@ooUOd<00ooUOd<01?l0003oc4h0ola>0?l0
000gooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool09_ooool5o`0000goEa1F0_l00008of`cN@03o`000?nOGH7oWef1027oWef100?o0000
olElOoo5O7l07oo5O7l00ol0003ojIYbonVJLP02o`0000CoiGm300?o0000onEo@ooUOd<01?oUOd<0
1?l0003oc4h0ola>0?l0000gooooo`03o`000?oooooooooo01cooooo000Vooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool09?ooool6o`0000_oEa1F0_l0000:of`cN@03o`000?nOGH7o
Wef1027oWef100?o0000olElOoo5O7l07oo5O7l00ol0003ojIYbonVJLP02onVJLP05o`000?oUOd?o
iGm3onEo@ol000001ooUOd<3o`0003Sooooo00?o0000ooooooooool06oooool002Kooooo0ol0000_
ooooo`03o`000?oooooooooo02?ooooo1Ol0000:oeL@EP;o00003?m/<gT00ol0003oWef1oimMP@0Q
oimMP@03o`000?o5O7ooaGao01ooaGao00?o0000onVJL_oYVW800ooYVW82o`0000;oiGm300?o0000
onEo@ooUOd<01_oUOd<2o`0003Oooooo00?o0000ooooooooool06oooool002Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Qooooo`Co000000?o000ao`000?mG45H01omG45H2o`00
00koK3=i00?o0000oimMPOnOGH408OnOGH400ol0003oaGaoolElO`0OolElO`03o`000?oYVW;ojIYb
00GojIYb00?o0000onEo@ol000002OoUOd<00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool07oooool4
o`0000;o000a00?o0000oeL@E_mG45H01?mG45H2o`00013oK3=i00?o0000oimMPOnOGH407OnOGH48
o`0001koaGao00?o0000onVJL_oYVW801_oYVW82o`0000[oiGm300?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Jooooo`002oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0M
ooooo`Go00000_l003400ol0003oEa1FoeL@EP02oeL@EP;o00004_m/<gT00ol0003oWef1oimMP@0F
oimMP@Oo00001?nUKiD01?l0003oaX^EolJ;UOo6RiD5o`0001[oaGao00?o0000onVJL_oYVW801_oY
VW82o`0000WoiGm300?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`000oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Looooo`Co00000ol003401Ol0003oEa1FoeL@
E_mG45Ko000001CoK3=i00?o0000oimMPOnOGH403onOGH47o`0000_oYFnE00?o0000olJ;UOo6RiD0
1_o6RiD5o`0001GoaGao00?o0000onVJL_oYVW801_oYVW801?l0003ojIYbo`000?l00007onEo@`;o
0000>?ooool00ol0003oooooooooo`0Hooooo`002oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01[o
oooo1?l00003o`00<@03o`000?mG45KoEa1F00;o00005Om/<gT00ol0003oWef1oimMP@08oimMP@Oo
00004_nUKiD00ol0003oaX^EolJ;U@0;olJ;U@Go00004?o5O7l00ol0003ojIYbonVJLP06onVJLP05
o`000?oYVW;ojIYbonVJL_l000001ooUOd<00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Sooooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Hooooo`Co00001?l00343
o`0001OoK3=i00Co0000oimMPOnOGH7oWef11ol0000IojE_U@03o`000?o6RiGoaX^E013oaX^E1Ol0
000;olElO`03o`000?oYVW;ojIYb00KojIYb00?o0000onVJL_oYVW800_oYVW82o`0000GoiGm30_l0
000hooooo`03o`000?oooooooooo01Oooooo000;ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00ol0003oooooooooo`06ooooo`;o0000>?ooool00ol0003oooooooooo`0Gooooo`Co00001?l0
03400ol0003oK3=iof`cN@0Fof`cN@Go00008?nUKiD00ol0003oaX^EolJ;U@0EolJ;U@Go00001_o5
O7l00ol0003ojIYbonVJLP06onVJLP03o`000?oYVW;ojIYb00CojIYb00?o0000onEo@ooUOd<00_oU
Od<2o`0003Sooooo00?o0000ooooooooool05oooool000_ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Eooooo`Co00001Ol003400ol0003oK3=iof`cN@0Dof`cN@;o000000?oNDf@o`000?nUKiD08_nU
KiD00ol0003oaX^EolJ;U@0JolJ;U@Go000000?oaGaoo`000?oYVW801ooYVW800ol0003ojIYbonVJ
LP05onVJLP;o00000ooUOd<2o`0003Sooooo00?o0000ooooooooool05_ooool000_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01Cooooo0ol00005o`00<@;o00005?m/<gT2o`0000?oNDf@00?o0000ojE_UOnUKiD08OnU
KiD00ol0003oaX^EolJ;U@0OolJ;U@?o00001ooYVW800ol0003ojIYbonVJLP07onVJLP03o`000?oU
Od?oiGm300;o0000=oooool3o`0001Oooooo000Tooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool04oooool3o`0000Go000a00?o0000oaH0Gol000004_m/<gT2o`0000GoNDf@00?o0000
ojE_UOnUKiD08OnUKiD00ol0003oaX^EolJ;U@0PolJ;U@03o`000?oWZI3o000000KojIYb00?o0000
onVJL_oYVW802?oYVW83o`000003omEk0?l0003ooooo03;ooooo0ol00002ooooo`03o`000?oooooo
oooo01Gooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04_ooool2o`00
00Go000a00Co0000oaH0GolF05oo00004?m/<gT2o`0000OoNDf@00?o0000ojE_UOnUKiD08OnUKiD0
0ol0003oaX^EolJ;U@0PolJ;U@03o`000?oWZI3oijV@00;o00001?oYVW800ol0003ojIYbonVJLP0:
onVJLP?o0000<?ooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Aooooo`;o00001?l003401Ol0003o5P1OoaH0GolF05oo
000000koK3=i0_l00009ogU=T003o`000?nUKiGoYFnE027oYFnE00?o0000olJ;UOo6RiD08?o6RiD0
0ol0003oijV@onNYT002onNYT005o`000?oYVW;ojIYbonVJL_l000003OoYVW800ol0003oeG/0o`00
000/ooooo`?o00002?ooool00ol0003oooooooooo`0Eooooo`009?ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo00oooooo0_l00005o`00<@05o`000?lF05oo5P1OoaH0Gol000002om/
<gT3o`0000_oNDf@00?o0000ojE_UOnUKiD08OnUKiD00ol0003oaX^EolJ;U@0PolJ;U@03o`000?oW
ZI3oijV@00?oijV@0_l000000ooYVW;o0000onVJLP0<onVJLP03o`000?oEN`3o000002Wooooo0ol0
000;ooooo`03o`000?oooooooooo01Gooooo000Tooooo`;o0000?oooool00ol0003oooooooooo`0>
ooooo`03o`000?l0037o000a00?o000a00Go0000oaH0GolF05oo5P1Oo`00000:of`cN@;o00003_mi
CI000ol0003oYFnEojE_U@0QojE_U@03o`000?o6RiGoaX^E023oaX^E00?o0000onNYT?oWZI001OoW
ZI02o`0000gojIYb1?l0000Uooooo`?o00003oooool00ol0003oooooooooo`0Dooooo`009?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo00cooooo00?o0000o`00<Ol003400ol00340
0ol0003o5P1OoaH0G`02oaH0G`03o`000?m/<gWoK3=i00KoK3=i0_l0000AogU=T003o`000?nUKiGo
YFnE023oYFnE00?o0000olJ;UOo6RiD08?o6RiD00ol0003oijV@onNYT006onNYT0;o00003?oYVW82
o`000003omEk0?l0003ooooo027ooooo0ol0000Booooo`03o`000?oooooooooo01Cooooo000Soooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02oooool00ol0003o000ao`00<@02o`00
<@03o`000?lF05oo5P1O00?o5P1O00?o0000of`cNOm/<gT01?m/<gT2o`0001?oNDf@00?o0000ojE_
UOnUKiD08?nUKiD00ol0003oaX^EolJ;U@0PolJ;U@03o`000?oWZI3oijV@00KoijV@00?o0000onNY
T?l000002ooYVW800ol0003omZ`oo`000002o`0001kooooo0ol0000Eooooo`03o`000?oooooooooo
01Cooooo000Sooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool2o`0000Co
000a00?o0000oaH0GolF05l00olF05l00ol0003oK3=iof`cN@02of`cN@;o00005OmiCI000ol0003o
YFnEojE_U@0PojE_U@03o`000?o6RiGoaX^E023oaX^E00?o0000onNYT?oWZI001_oWZI000ol0003o
ijV@onNYT002o`0000WojIYb00Go0000ooJ/?ol0003oeG/0o`00000Kooooo`?o00006?ooool00ol0
003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00So
oooo00?o0000o`00<Ol003400_l003400ol0003o5P1OoaH0G`04oaH0G`03o`000?m/<gWoK3=i00;o
00005omiCI000ol0003oYFnEojE_U@0PojE_U@03o`000?o6RiGoaX^E01ooaX^E00?o0000onNYT?oW
ZI002?oWZI001Ol0003oijV@onNYT?oWZI3o000000SojIYb00Go0000ooJ/?ol0003oeG/0o`00000H
ooooo`?o00006oooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo00Oooooo00Go0000o`00<Ol0037o000ao`000007oaH0G`?o00006OmiCI00
0ol0003oYFnEojE_U@0JojE_U@[o00007_o6RiD00ol0003oijV@onNYT008onNYT003o`000?oWZI3o
ijV@00;oijV@0_l00007onVJLP05o`000?of[3oo0000omEk0?l000005?ooool3o`0001kooooo00?o
0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`05
ooooo`;o00000_l003400ol0003o5P1OoaH0G`06oaH0G`03o`000?miCI3oNDf@01WoNDf@00?o0000
ojE_UOnUKiD03_nUKiD<o`0000KoZ7fU00Co0000olJFY_o6UZKoaYJV1_l0000HolJ;U@03o`000?oW
ZI3oijV@00SoijV@00?o0000onNYT?oWZI001?oWZI000ol0003ojIYbonVJLP04onVJLP05o`000?of
[3oo0000omEk0?l000004Oooool3o`00027ooooo00?o0000ooooooooool05?ooool002?ooooo0_l0
0017ooooo`03o`000?oooooooooo00Cooooo0_l000000ol0037o0000oaH0G`08oaH0G`03o`000?mi
CI3oNDf@01WoNDf@00?o0000ojE_UOnUKiD00onUKiD;o`0001;oZ7fU00?o0000olJFY_o6UZH01oo6
UZH5o`0001?oaX^E00?o0000onNYT?oWZI002?oWZI000ol0003oijV@onNYT005onNYT0;o00001?oY
VW801_l0003omZ`oooJ/?ol0003oeG/0o`0000gooooo0ol0000Uooooo`03o`000?oooooooooo01?o
oooo000Sooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool00oooool2o`000003o`00
<Ol0003o5P1O00Oo5P1O0_l0000JogU=T0Oo00007OnXOJD00ol0003oaYJVolJFYP0<olJFYPKo0000
3Oo6RiD00ol0003oijV@onNYT008onNYT003o`000?oWZI3oijV@00OoijV@00Go0000onVJL_oYVW;o
jIYbo`000002ooJ/?`03o`000?oEN`3o000000[ooooo0ol0000Xooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooooooo0_l000000ol0037o
0000oaH0G`07oaH0G`03o`000?lb5goo000001SoNDf@0_l000000on2H:;o0000ojQmY@0QojQmY@03
o`000?o6UZKoaYJV01;oaYJV1_l00007olJ;U@03o`000?oWZI3oijV@00SoijV@00?o0000onNYT?oW
ZI002?oWZI02o`000003onVJL_l0003omZ`o00;omZ`o0_l00007ooooo`?o0000:oooool00ol0003o
ooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00?o0000
2?lF05l01?l0003o<QMooc8GOol0000EogU=T0?o00000on2H:800ol0003oZ7fUojQmY@0PojQmY@03
o`000?o6UZKoaYJV01SoaYJV1Ol00002olJ;U@03o`000?oWZI3oijV@00SoijV@00?o0000onNYT?oW
ZI002_oWZI02o`0000?omZ`o00?o0000omEk0?l000000oooool3o`0002kooooo00?o0000oooooooo
ool04oooool002;ooooo00?o0000ooooooooool0Boooool01?l0003oooooo`000?l00008oaH0G`05
o`000?lb5goo<QMooc8GOol000004omiCI02o`0000KoPV2R00?o0000ojQmYOnXOJD08?nXOJD00ol0
003oaYJVolJFYP0MolJFYPCo00002OoWZI000ol0003oijV@onNYT00;onNYT003o`000?of[3oomZ`o
00;omZ`o1Ol0000aooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oooooooooo04co
oooo0ol00007oaH0G`03o`000?lb5goo<QMo00;o<QMo00?o0000ogU=T?miCI003omiCI02o`0000So
PV2R00?o0000ojQmYOnXOJD08?nXOJD00ol0003oaYJVolJFYP0OolJFYP03o`000?oS/jCo000000So
ijV@00?o0000onNYT?oWZI002ooWZI000ol0003omZ`oooJ/?`02ooJ/?`;o0000=?ooool00ol0003o
ooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`1<ooooo`?o00001_lF05l00ol0003o<QMo
oc8GO`03oc8GO`03o`000?miCI3oNDf@00goNDf@0_l0000:oh9PXP03o`000?nXOJGoZ7fU023oZ7fU
00?o0000olJFY_o6UZH07oo6UZH00ol0003ohk>Ton>cY002o`0000KoijV@00?o0000onNYT?oWZI00
2ooWZI02o`0000ComZ`o0_l0000cooooo`03o`000?oooooooooo01?ooooo000Qooooo`?o0000COoo
ool3o`0000Go5P1O00?o0000oc8GOolb5gl01Olb5gl00ol0003oNDf@ogU=T009ogU=T0?o00003?n2
H:800ol0003oZ7fUojQmY@0PojQmY@03o`000?o6UZKoaYJV01ooaYJV00?o0000on>cY?oS/j@00_oS
/j@2o`0000CoijV@00?o0000onNYT?oWZI002ooWZI02o`0000ComZ`o0_l0000dooooo`03o`000?oo
oooooooo01;ooooo000Qooooo`03o`000?oooooooooo04cooooo0_l000000ol002Wo0000oaH0G`04
oaH0G`03o`000?lb5goo<QMo00Go<QMo00?o0000ogU=T?miCI001omiCI02o`0000ooPV2R00?o0000
ojQmYOnXOJD07onXOJD00ol0003oaYJVolJFYP0PolJFYP03o`000?oS/jCohk>T00Cohk>T00Go0000
onNYT?oWZI3oijV@o`00000<onNYT004o`000?ooagCoolMdo`0000?omZ`o0_l0000dooooo`03o`00
0?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04cooooo0_l000000ol002Wo0000oaH0
G`03oaH0G`03o`000?lb5goo<QMo00Ko<QMo00?o0000ogU=T?miCI001OmiCI02o`00017oPV2R00?o
0000ojQmYOnXOJD07onXOJD00ol0003oaYJVolJFYP0OolJFYP03o`000?oS/jCohk>T00Kohk>T0_l0
00000ooWZI3o0000onNYT00;onNYT004o`000?ooagCoolMdo`0000ComZ`o00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`1<ooooo`?o00001?lF
05l00ol0003o<QMooc8GO`07oc8GO`03o`000?miCI3oNDf@00?oNDf@0_l0000Coh9PXP03o`000?nX
OJGoZ7fU01ooZ7fU00?o0000olJFY_o6UZH07oo6UZH00ol0003ohk>Ton>cY008on>cY0;o00003?oW
ZI001Ol0003oolMdooo7M?ooagCo000000?omZ`o0_l0000cooooo`03o`000?oooooooooo01;ooooo
000Qooooo`03o`000?oooooooooo04_ooooo1?l00003oaH0G`03o`000?lb5goo<QMo00So<QMo00?o
0000ogU=T?miCI000ol0000Foh9PXP03o`000?nXOJGoZ7fU01koZ7fU00?o0000olJFY_o6UZH07oo6
UZH00ol0003ohk>Ton>cY009on>cY0;o00002ooWZI001Ol0003oolMdooo7M?ooagCo000000ComZ`o
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003ooooooooo
o`1;ooooo`;o000000Go000Yo`000?lF05oo5P1Oo`00000;oc8GO`?o00006On2H:800ol0003oZ7fU
ojQmY@0NojQmY@03o`000?o6UZKoaYJV01ooaYJV00?o0000on>cY?oS/j@02OoS/j@01?l0003ohk>T
o`000?l00009onNYT003o`000?ooagCoolMd00;oolMd00Go0000ooJ/?oof[3oomZ`oo`00000coooo
o`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo04_ooooo0_l000001?l002Wo
0000oaH0Gol0000<oc8GO`03o`000?n2H:;oPV2R01WoPV2R00?o0000ojQmYOnXOJD07_nXOJD00ol0
003oaYJVolJFYP0OolJFYP03o`000?oS/jCohk>T00Wohk>T00Co0000on>cY?oS/jCohk>T0_l00007
onNYT003o`000?ooagCoolMd00;oolMd00Go0000ooJ/?oof[3oomZ`oo`00000cooooo`03o`000?oo
oooooooo01;ooooo000Pooooo`?o0000Boooool3o`000003o`00:Ol0003o000000co<QMo0_l0000K
oh9PXP03o`000?nXOJGoZ7fU01koZ7fU00?o0000olJFY_o6UZH07oo6UZH00ol0003ohk>Ton>cY009
on>cY003o`000?oS/jCohk>T00?ohk>T00?o0000onNYT?oWZI001?oWZI000ol0003oolMdooo7M003
ooo7M004o`000?of[3oomZ`oo`0003Cooooo00?o0000ooooooooool04Oooool0023ooooo00?o0000
ooooooooool0Boooool2o`0000;o000Y00?o0000oc8GOolb5gl02_lb5gl00ol0003oAcBGo`00000K
oh9PXP03o`000?nXOJGoZ7fU01koZ7fU00?o0000olJFY_o6UZH07oo6UZH00ol0003ohk>Ton>cY00:
on>cY003o`000?oS/jCohk>T00?ohk>T0_l00003onNYT003o`000?ooagCoolMd00CoolMd00Co0000
ooJ/?oof[3oo0000=?ooool00ol0003oooooooooo`0Aooooo`005Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0Boooool2o`0000;o000Y00?o0000oc8GOolb5gl02Olb
5gl01Ol0003oAcBGodLdUom7=9Oo000001[oPV2R00?o0000ojQmYOnXOJD06OnXOJD9o`0001koaYJV
00?o0000on>cY?oS/j@02_oS/j@00ol0003ohk>Ton>cY005on>cY0;o000000?oijV@o`000?ooag@0
1_ooag@00ol0003omZ`oo`00000dooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`1;ooooo`;o000000?o000Yo`000?l00000
2_lb5gl00ol0003oAcBGodLdU`02odLdU`03o`000?n2H:;oPV2R01SoPV2R00?o0000ojQmYOnXOJD0
3_nXOJD;o`0000GoZXRa00Co0000olBO/oo4Wk?oa9nc1Ol0000IolJFYP03o`000?oS/jCohk>T00[o
hk>T00?o0000on>cY?oS/j@01ooS/j@2o`0000OoolMd00Co0000ooJ/?oof[3oo0000<oooool00ol0
003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooo
ooooool0Boooool00ol0003o000Yo`00:@02o`0000Wo<QMo00?o0000odLdUom7=9L00om7=9L00ol0
003oPV2Roh9PXP0Hoh9PXP03o`000?nXOJGoZ7fU00?oZ7fU2ol0000@ojZ8/@03o`000?o4Wk?oa9nc
00Koa9nc1_l0000BolJFYP03o`000?oS/jCohk>T00_ohk>T00?o0000on>cY?oS/j@02?oS/j@00ol0
003oolMdooo7M006ooo7M003o`000?of[3oo000003?ooooo00?o0000ooooooooool04Oooool001Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo04[ooooo0_l00002o`00
:@;o00002?lb5gl00ol0003oAcBGodLdU`04odLdU`03o`000?n2H:;oPV2R01OoPV2R1ol0000KojZ8
/@03o`000?o4Wk?oa9nc00coa9nc1Ol0000=olJFYP03o`000?oS/jCohk>T00_ohk>T00?o0000on>c
Y?oS/j@02?oS/j@00ol0003oolMdooo7M006ooo7M003o`000?of[3oo000003?ooooo00?o0000oooo
ooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
04_ooooo0_l000001?l002Wo0000o`00Eol00007oc8GO`03o`000?m7=9OoAcBG00GoAcBG00?o0000
oh9PX_n2H:805?n2H:83o`000003ohU_/?l0003oZXRa01ooZXRa00?o0000olBO/oo4Wk<04Oo4Wk<6
o`0000OoaYJV00?o0000on>cY?oS/j@02ooS/j@00ol0003ohk>Ton>cY008on>cY0;o00002?ooag@2
o`0003?ooooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o0000C?ooool01_l0003o000Yo`00:Ol0003o001Go`0000Ko<QMo00?o0000odLdUom7=9L0
1om7=9L00ol0003oPV2Roh9PXP0@oh9PXP?o00001?n9Kk000ol0003oZXRaojZ8/@0NojZ8/@03o`00
0?o4Wk?oa9nc01Ooa9nc1Ol00002olJFYP03o`000?oS/jCohk>T00_ohk>T00?o0000on>cY?oS/j@0
1ooS/j@01?l0003ooMBGoogDUol00007ooo7M0;o0000<oooool00ol0003oooooooooo`0Aooooo`00
5Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0Boooool01?l0003o
000Yo`00:Ol00002o`00E`03o`000?lb5goo<QMo00;o<QMo00?o0000odLdUom7=9L02?m7=9L00ol0
003oPV2Roh9PXP0=oh9PXP?o00001on9Kk000ol0003oZXRaojZ8/@0NojZ8/@03o`000?o4Wk?oa9nc
01coa9nc1?l0000<on>cY003o`000?oS/jCohk>T00Oohk>T00Co0000oogDUoome9Oo00002?ooag@0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo000Eooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`1;ooooo`03o`000?l002Wo000000?o001G00Go0000
oc8GOolb5goo<QMoo`00000;odLdU`03o`000?n2H:;oPV2R00[oPV2R0ol0000;ohU_/003o`000?nZ
R;7oZXRa01goZXRa00?o0000olBO/oo4Wk<07_o4Wk<01?l0003og[Zdo`000?l0000:on>cY003o`00
0?oS/jCohk>T00Oohk>T00Go0000oogDUoome9OooMBGo`000007ooo7M003o`000?oooooooooo03;o
oooo00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0Boooool00ol0003o000Y
o`000003o`00E`04o`000?lb5goo<QMoo`0000coAcBG00?o0000oh9PX_n2H:802?n2H:82o`0000ko
RFn`00?o0000ojZ8/OnZR;407OnZR;400ol0003oa9ncolBO/`0NolBO/`04o`000?oN^[Cog[Zdomjj
]0;o00002?oS/j@00ol0003ohk>Ton>cY007on>cY005o`000?ome9OooMBGoogDUol000001oooag@0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo
04_ooooo0_l00004o`00E`03o`000?lb5goo000000goAcBG00?o0000oh9PX_n2H:801On2H:83o`00
013oRFn`00?o0000ojZ8/OnZR;407OnZR;400ol0003oa9ncolBO/`0MolBO/`03o`000?oN^[Cog[Zd
00Cog[Zd0_l00006on>cY003o`000?oS/jCohk>T00Oohk>T00?o0000oogDUoome9L00_ome9L00ol0
003oolMdooo7M004ooo7M003o`000?oooooooooo03;ooooo00?o0000ooooooooool04?ooool001oo
oooo00?o0000ooooooooool0Boooool2o`0000Co001G0_l0000?odLdU`04o`000?n2H:;oPV2Roh9P
XP?o00004on9Kk000ol0003oZXRaojZ8/@0MojZ8/@03o`000?o4Wk?oa9nc01goa9nc00?o0000omjj
]?oN^[@01_oN^[@2o`0000Cohk>T00?o0000on>cY?oS/j@01_oS/j@00ol0003ooMBGoogDU`04oogD
U`03o`000?ooagCoolMd00?oolMd00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0@oooo
o`007_ooool00ol0003oooooooooo`1;ooooo`03o`000?l002Wo000000Co001G00?o0000odLdUom7
=9L03_m7=9L4o`0001KoRFn`00?o0000ojZ8/OnZR;407OnZR;400ol0003oa9ncolBO/`0MolBO/`03
o`000?oN^[Cog[Zd00Sog[Zd0_l00002on>cY003o`000?oS/jCohk>T00Kohk>T00?o0000oogDUoom
e9L01?ome9L00ol0003oolMdooo7M003ooo7M003o`000?oooooooooo03;ooooo00?o0000oooooooo
ool04?ooool001kooooo00?o0000ooooooooool0Boooool2o`0000Go001G00?o0000odLdUom7=9L0
3Om7=9L2o`0001WoRFn`00?o0000ojZ8/OnZR;407OnZR;400ol0003oa9ncolBO/`0MolBO/`03o`00
0?oN^[Cog[Zd00[og[Zd0ol00008on>cY003o`000?ome9OooMBG00GooMBG00?o0000ooo7M?ooag@0
0_ooag@00ol0003oooooooooo`0booooo`03o`000?oooooooooo013ooooo000Nooooo`;o0000C?oo
ool2o`0000Co001G0_l0000>odLdU`03o`000?mICJ[o000001[oRFn`00?o0000ojZ8/OnZR;407?nZ
R;400ol0003oa9ncolBO/`0LolBO/`03o`000?oN^[Cog[Zd00gog[Zd0_l00007on>cY003o`000?om
e9OooMBG00KooMBG00?o0000ooo7M?ooag@00_l0000eooooo`03o`000?oooooooooo00oooooo000N
ooooo`03o`000?oooooooooo04_ooooo0_l00004o`00E`;o00003Om7=9L01?l0003oFDfZoeU=Z_l0
000JohU_/003o`000?nZR;7oZXRa01coZXRa00?o0000olBO/oo4Wk<07?o4Wk<00ol0003og[Zdomjj
]00=omjj]004o`000?oN^[Co0000o`0000Gohk>T00?o0000oogDUoome9L01_ome9L00ol0003oolMd
ooo7M002o`0003Gooooo00?o0000ooooooooool03oooool001kooooo00?o0000ooooooooool0Booo
ool00ol0003o001Go`00E`03o`00E`03o`000?l007go000000_oAcBG00?o0000oeU=Z_mICJX00_mI
CJX00ol0003oRFn`ohU_/00GohU_/003o`000?nZR;7oZXRa01coZXRa00?o0000olBO/oo4Wk<07?o4
Wk<00ol0003og[Zdomjj]00=omjj]004o`000?oN^[Cog[Zdomjj]0;o00000_oS/j@00ol0003ooMBG
oogDU`08oogDU`04o`000?ooagCo0000o`0003Gooooo00?o0000ooooooooool03oooool001kooooo
00?o0000ooooooooool0Boooool00ol0003o001Go`00E`02o`00E`04o`000?l007go001mo`0000Wo
AcBG0_l00005oeU=ZP03o`000?n9Kk3oRFn`01OoRFn`00?o0000ojZ8/OnZR;407?nZR;400ol0003o
a9ncolBO/`0LolBO/`03o`000?oN^[Cog[Zd00gog[Zd00?o0000omjj]?oN^[@00ooN^[@3o`0000[o
oMBG00Co0000ooo7M?l0003o0000=Oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?l005Oo001G00;o001G00Co0000o`00OOl007go00002?m7=9L00ol0
003oFDfZoeU=ZP05oeU=ZP03o`000?n9Kk3oRFn`01OoRFn`00?o0000ojZ8/OnZR;407?nZR;400ol0
003oa9ncolBO/`0LolBO/`03o`000?oN^[Cog[Zd00gog[Zd00?o0000omjj]?oN^[@01OoN^[@00ol0
003ooMBGoogDU`09oogDU`?o0000=Oooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003o
ooooooooo`1<ooooo`05o`000?l005Oo001Go`00Eol000000ol007d00ol0003oAcBGodLdU`05odLd
U`03o`000?mICJ[oFDfZ00KoFDfZ00?o0000ohU_/?n9Kk005on9Kk000ol0003oZXRaojZ8/@0LojZ8
/@03o`000?o4Wk?oa9nc01_oa9nc00?o0000omjj]?oN^[@03ooN^[@00ol0003og[Zdomjj]004omjj
]003o`000?ome9OooMBG00[ooMBG0_l0000eooooo`03o`000?oooooooooo00oooooo000Mooooo`03
o`000?oooooooooo04cooooo00Go0000o`00Eol005Oo001Go`000003o`00O@03o`000?m7=9OoAcBG
00CoAcBG00?o0000oeU=Z_mICJX02?mICJX00ol0003oRFn`ohU_/00GohU_/003o`000?nZR;7oZXRa
01CoZXRa3?l0000IolBO/`03o`000?oN^[Cog[Zd00oog[Zd00?o0000omjj]?oN^[@00ooN^[@00ol0
003om]Z`o`00000;oogDU`;o0000=Oooool00ol0003oooooooooo`0?ooooo`007Oooool2o`0004go
oooo00Go0000o`00Eol005Oo001Go`000003o`00O@03o`000?m7=9OoAcBG00;oAcBG0_l0000;oeU=
ZP03o`000?n9Kk3oRFn`01OoRFn`00?o0000ojZ8/OnZR;401OnZR;4?o`0000OoZi:m00?o0000ol:W
__o2Ykh00_o2Ykh7o`0001;oa9nc00?o0000omjj]?oN^[@03ooN^[@00ol0003og[Zdomjj]003omjj
]004o`000?off[3om]Z`o`0000[ooMBG0_l0000fooooo`03o`000?oooooooooo00kooooo000Moooo
o`03o`000?oooooooooo04cooooo00Co000]o`000?l005Oo00001?l007d01Ol0003oAcBGodLdUom7
=9Oo000000goFDfZ00?o0000ohU_/?n9Kk005On9Kk0:o`0001KoZi:m00?o0000ol:W__o2Ykh02Oo2
Ykh7o`0000_oa9nc00?o0000omjj]?oN^[@03ooN^[@00ol0003og[Zdomjj]003omjj]005o`000?of
f[3om]Z`ooKJ/?l000002?ome9L3o`0003Kooooo00?o0000ooooooooool03_ooool001gooooo00?o
0000ooooooooool0C?ooool01?l002go0000o`00Eol00005o`00O@03o`000?m7=9Oo000000ooFDfZ
00?o0000ohU_/?n9Kk004?n9Kk04o`0000;oSWfk00?o0000oj^B_On[T[d06on[T[d00ol0003o`ZNn
ol:W_P0@ol:W_POo00000oo4Wk<00ol0003og[Zdomjj]00@omjj]003o`000?oN^[Cog[Zd00;og[Zd
00?o0000ooKJ/?off[000_off[000ol0003ooMBGoogDU`06oogDU`?o0000=_ooool00ol0003ooooo
ooooo`0>ooooo`007?ooool00ol0003oooooooooo`1<ooooo`04o`000?l002go0000o`0000Ko001m
0_l0000@oeU=ZP03o`000?n9Kk3oRFn`00coRFn`1?l00006ohim^`03o`000?n[T[goZi:m01_oZi:m
00?o0000ol:W__o2Ykh05oo2Ykh5o`00017og[Zd00?o0000omjj]?oN^[@00_oN^[@00ol0003om]Z`
ooKJ/003ooKJ/003o`000?ome9OooMBG00GooMBG0ol0000fooooo`03o`000?oooooooooo00kooooo
000Looooo`03o`000?oooooooooo04cooooo00Co0000o`00;Ol0003o00001_l007d00ol0003oFDfZ
oeU=ZP0?oeU=ZP03o`000?n9Kk3oRFn`00SoRFn`1?l0000:ohim^`03o`000?n[T[goZi:m01[oZi:m
00?o0000ol:W__o2Ykh06oo2Ykh01?l0003of;o1o`000?l0000?omjj]003o`000?oN^[Cog[Zd00;o
g[Zd00?o0000ooKJ/?off[001?off[000ol0003ooMBGoogDU`04oogDU`?o0000=_ooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`1<ooooo`04o`000?l002go001Go`0000Ko
001m00?o0000oeU=Z_mICJX03omICJX00ol0003oRFn`ohU_/004ohU_/0Co00003on>OK/00ol0003o
Zi:moj^B_@0Ioj^B_@03o`000?o2Ykko`ZNn01[o`ZNn00?o0000omRo`OoH_l400_oH_l42o`0000go
g[Zd00Go0000omjj]?oN^[Cog[Zdo`000007ooKJ/003o`000?ome9OooMBG00?ooMBG00Co0000onSF
HOl0003o0000=_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`1<oooo
o`03o`000?l002go000000Ko001m00?o0000oaLQVol000004OmICJX00ol0003oRFn`o`000003o`00
01?oSWfk00?o0000oj^B_On[T[d06On[T[d00ol0003o`ZNnol:W_P0Jol:W_P03o`000?oH_l7of;o1
00Cof;o10_l00009omjj]0?o00000ooN^[@00ol0003om]Z`ooKJ/006ooKJ/003o`000?ome9OooMBG
00;ooMBG00Co0000onSFHOl0003o0000=_ooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0
003oooooooooo`1<ooooo`03o`000?l002go000000Ko001m00?o0000oaLQVol000004?mICJX3o`00
01OoSWfk00?o0000oj^B_On[T[d06On[T[d00ol0003o`ZNnol:W_P0Jol:W_P03o`000?oH_l7of;o1
00Kof;o10_l00004omjj]0?o00000_oN^[@01?l0003og[Zdomjj]?l0000:ooKJ/006o`000?ome9Oo
oMBGoogDUol0003oj=IQ0_l0000gooooo`03o`000?oooooooooo00gooooo000Looooo`;o0000COoo
ool00ol0003o000]o`000005o`00O@04o`000?lG8I_o5b6Ko`0000ooFDfZ00?o0000ofMR^Ol00000
6?n>OK/00ol0003oZi:moj^B_@0Ioj^B_@03o`000?o2Ykko`ZNn01Wo`ZNn00?o0000omRo`OoH_l40
2OoH_l44o`0000Kog[Zd00?o0000omjj]?l000002ooff[001_l0003ooMBGoogDUol0003oj=IQo`00
03Sooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000ooooooooool0COooool2o`00;@03
o`000?l007go001m00?o001m00Go0000oaLQVolG8I_o5b6Ko`00000<oeU=ZP;o00000omWH[T00ol0
003oSWfkohim^`0Eohim^`03o`000?n[T[goZi:m01WoZi:m00?o0000ol:W__o2Ykh06Oo2Ykh00ol0
003of;o1omRo`@07omRo`@?o000000?of;o1o`000?l000001ooN^[@2o`0000_om]Z`00Ko0000oogD
Uoome9Oo0000onSFHOl0000hooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooo
oooo04gooooo00Co000]o`000?l0063o00000ol007d00ol0003o5b6KoaLQV`02oaLQV`03o`000?mI
CJ[oFDfZ00WoFDfZ00?o0000ofMR^OmWH[T00omWH[T00ol0003oSWfkohim^`0Fohim^`03o`000?n[
T[goZi:m01SoZi:m00?o0000ol:W__o2Ykh06Oo2Ykh00ol0003of;o1omRo`@03omRo`@Co00001_oH
_l42o`0000Gog[Zd0_l0000<ooKJ/0;o00000_oXeV400ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00gooooo000Kooooo`03o`000?oooooooooo04gooooo00Co000]o`000?l0063o00000ol0
07d00ol0003o5b6KoaLQV`03oaLQV`03o`000?mICJ[oFDfZ00OoFDfZ00?o0000ofMR^OmWH[T01?mW
H[T00ol0003oSWfkohim^`0Fohim^`03o`000?n[T[goZi:m01SoZi:m00?o0000ol:W__o2Ykh06?o2
Ykh01?l0003of;o1omRo`OoH_l43o`0000cof;o10_l00003omjj]003o`000?off[3o000000com]Z`
00Co0000onSFHOoXeV7o0000>?ooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003ooooo
ooooo`1=ooooo`04o`00;Ol0003o001Po`0000?o001m00?o0000oaLQVolG8I/00olG8I/00ol0003o
FDfZoeU=ZP05oeU=ZP;o00002?mWH[T00ol0003oSWfkohim^`0Eohim^`03o`000?n[T[goZi:m01So
Zi:m00?o0000ol:W__o2Ykh06?o2Ykh4o`00017of;o10_l000001?oN^[Co0000ooKJ/?l0000<ooKJ
/004o`000?oXeV7oj=IQo`0003Sooooo00?o0000ooooooooool03Oooool001_ooooo00?o0000oooo
ooooool0COooool01?l002go0000o`00H?l00002o`00O@03o`000?lG8I_o5b6K00Co5b6K00?o0000
oeU=Z_mICJX01?mICJX00ol0003oIf:iofMR^@08ofMR^@03o`000?n>OK_oSWfk01GoSWfk00?o0000
oj^B_On[T[d05on[T[d00ol0003o`ZNnol:W_P0Gol:W_P?o00005_oH_l401Ol0003om]Z`ooKJ/?of
f[3o000000[om]Z`0_l00002onSFH@03o`000?oooooooooo03Kooooo00?o0000ooooooooool03Ooo
ool001_ooooo00?o0000ooooooooool0COooool01?l002go0000o`00H?l00002o`00O@03o`000?lG
8I_o5b6K00Go5b6K00Co0000oeU=Z_mICJ[oFDfZ0_l0000;ofMR^@03o`000?n>OK_oSWfk01GoSWfk
00?o0000oj^B_On[T[d05on[T[d00ol0003o`ZNnol:W_P0Col:W_PCo000000?o`ZNno`000?oH_l40
5_oH_l400ol0003om]Z`ooKJ/002ooKJ/003o`000?off[3om]Z`00Oom]Z`0_l00002onSFH@03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03Oooool001_ooooo0_l0001>ooooo`04o`00;Ol0
003o001Po`00H0;o00002?lG8I/01?l0003oFDfZoeU=Z_l0000>ofMR^@03o`000?n>OK_oSWfk01Co
SWfk00?o0000oj^B_On[T[d05on[T[d00ol0003o`ZNnol:W_P0@ol:W_P?o00001Oo2Ykh00ol0003o
f;o1omRo`@0DomRo`@03o`000?o/g<;o000000Com]Z`00?o0000ooKJ/?off[001Ooff[000ol0003o
m>bBo`000002onSFH@03o`000?oooooooooo03Oooooo00?o0000ooooooooool03?ooool001[ooooo
00?o0000ooooooooool0C_ooool01_l002go0000o`00H?l0063o001mo`0000So5b6K00?o0000oeU=
Z_l000003omWH[T00ol0003oSWfkohim^`0Eohim^`03o`000?n[T[goZi:m01KoZi:m00?o0000ol:W
__o2Ykh03Oo2Ykh3o`0000So`ZNn00?o0000omRo`OoH_l405?oH_l401?l0003ok=c2oncL`_l00004
ooKJ/003o`000?off[3om]Z`00Com]Z`00?o0000ooC/T_l000000_oXeV400ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00cooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0C_ooool01Ol0003o001Po`00
H?l0063o000000[o5b6K00?o0000ofMR^OmWH[T03omWH[T00ol0003oSWfkohim^`0Dohim^`03o`00
0?n[T[goZi:m00[oZi:m4?l00009ol:W_P?o00002_o2Ykh00ol0003of;o1omRo`@0DomRo`@03o`00
0?o/g<;ok=c200;ok=c200?o0000ooKJ/?off[000_off[000ol0003om]Z`ooKJ/002ooKJ/006o`00
0?odk9;om>bBo`000?oXeV7o0000>_ooool00ol0003oooooooooo`0<ooooo`0000CoV9RHoooooonH
V9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`1>oooo
o`05o`000?l0063o001Po`00H?l000002_lG8I/00ol0003oIf:iofMR^@0?ofMR^@03o`000?n>OK_o
SWfk01;oSWfk3ol0000<oj^Ka`04o`000?no[/Wo_jk9okn^b@Wo00003Oo2Ykh00ol0003of;o1omRo
`@0DomRo`@03o`000?o/g<;ok=c200?ok=c200Go0000ooKJ/?off[3om]Z`o`000004ooKJ/004o`00
0?odk9;om>bBooC/TP;o0000>_ooool00ol0003oooooooooo`0<ooooo`000oooool00ol@413ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C_ooool01_l0003o001P
o`00H?l0063o002;o`0000So5b6K00?o0000ocI3/ol000004?mWH[T00ol0003oSWfkohim^`0>ohim
^`Co00000_nBRLH00ol0003oZi_7oj^Ka`0Foj^Ka`03o`000?no[/Wo_jk900?o_jk90ol000000ono
[/Wo0000o`000005o`0000Wo`ZNn00?o0000omRo`OoH_l404ooH_l400ol0003ok=c2oncL`P05oncL
`P05o`000?off[3om]Z`ooKJ/?l000000ooff[001?l0003om>bBooC/T_odk982o`0003[ooooo00?o
0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`04
ooooo`03o`000?oooooooooo04kooooo00Ko0000o`00H?l0063o001Po`00Rol00007oaLQV`04o`00
0?lf@k?o=T>co`00017oIf:i00?o0000ohim^on>OK/02?n>OK/5o`0000KoTXW600?o0000oj^Kaon[
VlL05_n[VlL00ol0003o_jk9okn^b@03o`0000_o_jk91_l00002ol:W_P03o`000?oH_l7of;o101Co
f;o100?o0000oncL`_o/g<801_o/g<801ol0003om]Z`ooKJ/?off[3o0000ooKJ/?l000001?odk982
o`0003[ooooo00?o0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool02_ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0C_ooool01_l0003o001Po`00H?l0
063o002;o`0000Oo5b6K00Go0000ocI3/olf@k?o=T>co`00000@ofMR^@03o`000?n>OK_oSWfk00Co
SWfk1?l0000;oi:9aP03o`000?n[VlOoZi_701KoZi_70ol0000Dokn^b@Co00005?oH_l400ol0003o
k=c2oncL`P08oncL`P04o`000?off[3om]Z`ooKJ/0;o00001?odk982o`0003[ooooo00?o0000oooo
ooooool03?ooool000?ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04oooooo00Oo0000o`00H?l0063o001Po`000?l008_o000000Go5b6K00?o0000
ocI3/olf@k<00_lf@k<00ol0003oIf:iofMR^@0>ofMR^@03o`000?n>OK_oSWfk00Co00004?nBRLH0
0ol0003oZi_7oj^Ka`0Aoj^Ka`Go00006?no[/T00ol0003od/?<o`000002o`00017of;o100?o0000
oncL`_o/g<802Oo/g<800ol0003om]Z`ooKJ/002o`0000Com>bB00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06
ooooo`;o0000D?ooool2o`0000;o001P00?o0000o`00Rol000001?lG8I/00ol0003o=T>cocI3/`03
ocI3/`03o`000?mWH[WoIf:i00koIf:i0ol0000Doi:9aP03o`000?n[VlOoZi_700koZi_70ol00004
oj^Ka`03o`000?no[/Wo_jk901Go_jk900?o0000om;3c?oB`l`00ooB`l`3o`0000kof;o100?o0000
oncL`_o/g<802_o/g<801?l0003om]Z`o`000?l00004ooC/TP03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02oooool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oo
oooooooo04oooooo0_l000001Ol0063o0000o`00Rol008_o000000Co5b6K00?o0000ocI3/olf@k<0
1?lf@k<00ol0003oIf:iofMR^@0;ofMR^@;o000000?oM7G6o`000?nBRLH05?nBRLH00ol0003oZi_7
oj^Ka`0;oj^Ka`?o00001on[VlL00ol0003o_jk9okn^b@0Eokn^b@03o`000?oB`lcod/?<00Kod/?<
0ol0000:omRo`@03o`000?o/g<;ok=c200cok=c200Co0000ooC/T_odk9;o00000oodk9800ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo00_ooooo000Iooooo`03o`000?oooooooooo053ooooo
00?o0000o`00H?l000000ol008/01?l0003o5b6KoaLQVol00007ocI3/`03o`000?mWH[WoIf:i00[o
If:i00?o0000ogAea_mdMLH00_mdMLH00ol0003oTXW6oi:9aP0Boi:9aP03o`000?n[VlOoZi_700So
Zi_70ol0000:oj^Ka`03o`000?no[/Wo_jk901Go_jk900?o0000om;3c?oB`l`02OoB`l`2o`0000So
f;o100?o0000oncL`_o/g<803?o/g<801Ol0003om>bBooC/T_odk9;o000000;om>bB00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`1@ooooo`?o
00000ol008/01?l0003o5b6KoaLQVol00008ocI3/`03o`000?mWH[WoIf:i00OoIf:i0_l00005ogAe
aP03o`000?nBRLKoTXW601;oTXW600?o0000oj^Kaon[VlL01?n[VlL4o`0000coZi_700?o0000okn^
bOno[/T05Ono[/T00ol0003od/?<om;3c00<om;3c0?o00001?oH_l400ol0003ok=c2oncL`P0<oncL
`P;o00001?odk983o`0003cooooo00?o0000ooooooooool02oooool001Wooooo00?o0000oooooooo
ool0D?ooool3o`0000?o002;00?o0000oaLQVol000002Olf@k<00ol0003oIf:iofMR^@05ofMR^@;o
00002?mdMLH00ol0003oTXW6oi:9aP0Boi:9aP03o`000?n[VlOoZi_700?o00004?n[VlL00ol0003o
_jk9okn^b@0Eokn^b@03o`000?oB`lcod/?<00ood/?<0ol000000ooH_l7o0000oncL`P0=oncL`P;o
00001Oodk9800ol0003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo000Hooooo`03o`00
0?oooooooooo057ooooo0ol00004o`00R`03o`000?lf@k?o=T>c00Wo=T>c00?o0000ofMR^OmWH[T0
0_mWH[T2o`0000[oM7G600?o0000oi:9a_nBRLH04_nBRLH3o`0001?oZi_700?o0000okn^bOno[/T0
5Ono[/T00ol0003od/?<om;3c00Bom;3c0;o00003Oo/g<801?l0003oloBfoo?d]_l00003ooC/TP?o
0000??ooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?l004Go000000Co002;00?o0000ocI3/olf@k<02Olf@k<01Ol0003oIf:iofMR^OmWH[Wo000000go
M7G600?o0000oi:9a_nBRLH03_nBRLH4o`0001GoZi_700?o0000okn^bOno[/T05?no[/T00ol0003o
d/?<om;3c00Com;3c003o`000?oRg<oo000000_ok=c200Go0000oo?d]_ocm;KoloBfo`000003ooC/
TP?o0000?Oooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003oooooooooo`1Aooooo`03
o`000?l004Go000000Co002;00?o2R^/o`000?lf@k<02Olf@k<01?l0003oIf:io`000?l0000>ogAe
aP03o`000?nBRLKoTXW600[oTXW61?l00003oi:9aP03o`000?n[VlOoZi_701?oZi_700?o0000okn^
bOno[/T05?no[/T00ol0003od/?<om;3c00Bom;3c005o`000?oRg<ooh]c?on;Lcol000002_o/g<80
1Ol0003oloBfoo?d]_ocm;Ko000000;om>bB0_l00002ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool02_ooool001Sooooo0_l0001Booooo`03o`000?l004Go000000Co002;0_l0000;
ocI3/`03o`000?mdMLKoM7G600ooM7G600?o0000oi:9a_nBRLH01_nBRLH3o`0000OoTXW600?o0000
oj^Kaon[VlL04on[VlL00ol0003o_jk9okn^b@0Dokn^b@03o`000?oB`lcod/?<017od/?<00?o0000
on;LcooRg<l00ooRg<l00ol0003ok=c2oncL`P06oncL`P03o`000?ocm;KoloBf00;oloBf00?o0000
ooC/T_odk9800_l00003ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02_ooool0
01Sooooo00?o0000ooooooooool0D_ooool00ol0003o001mo`000003o`00R`03o`000?l::jco0000
00[o=T>c00?o0000ogAea_mdMLH03omdMLH00ol0003oTXW6oi:9aP03oi:9aP?o00002onBRLH00ol0
003oZi_7oj^Ka`0Boj^Ka`03o`000?no[/Wo_jk901?o_jk900?o0000om;3c?oB`l`04_oB`l`00ol0
003oh]c?on;Lc`04on;Lc`;o00001_o/g<800ol0003oloBfoo?d]P02oo?d]P03o`000?odk9;om>bB
00;o00001?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00[ooooo000Hooooo`03
o`000?oooooooooo05;ooooo0ol00003o`00R`03o`000?l::jco000000Wo=T>c00?o0000oe1QaOl0
00004?mdMLH00ol0003oTXW6oi:9aP03o`0000koTXW600?o0000oj^Kaon[VlL04_n[VlL00ol0003o
_jk9okn^b@0Cokn^b@03o`000?oB`lcod/?<017od/?<00?o0000on;LcooRg<l01ooRg<l00ol0003o
k=c2oncL`P02oncL`P03o`000?ocm;KoloBf00ColoBf0ol00006ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0Doooool3o`0000?o002;
00Co0000o`X[[?l::jco00001olf@k<01Ol0003oD675oe1QaOm@HLGo000000koM7G61?l0000?oi:9
aQgo00004?no[/T00ol0003od/?<om;3c00@om;3c003o`000?oRg<ooh]c?00Woh]c?00Co0000oncL
`_o/g<;o00001oocm;H3o`0000Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0:
ooooo`005oooool00ol0003oooooooooo`1Cooooo`06o`000?l004Go001mo`000?l008_o00000ol:
:j`00ol0003o=T>cocI3/`04ocI3/`03o`000?m@HLGoD67500;oD67500?o0000ogAea_mdMLH02Omd
MLH3o`0000;oM7G600?o0000oi:9a_nBRLH02_nBRLH4o`0000;oUYG@00?o0000ojZTdOnZY=404_nZ
Y=400ol0003o^kCBok^ddP03ok^ddP_o00001?no[/T00ol0003od/?<om;3c00Aom;3c003o`000?oR
g<ooh]c?00[oh]c?00?o0000oncL`_l000001oocm;H00ol0003o`m5Ho`000007ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000ooooooooool0Doooool0
1_l0003o0015o`00OOl0003o002;o`0000Co2R^/00?o0000ocI3/olf@k<00_lf@k<00ol0003oD675
oe1Qa@04oe1Qa@03o`000?mdMLKoM7G600GoM7G60ol00006ogAeaP03o`000?nBRLKoTXW600CoTXW6
1Ol00006oiJEd003o`000?nZY=7oZZCA01;oZZCA00?o0000ok^dd_nk]=803_nk]=85o`0001;od/?<
00?o0000on;LcooRg<l03?oRg<l00ol0003oloBfoo?d]P06oo?d]P;o00002Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo00Wooooo000Gooooo`03o`000?oooooooooo05?ooooo1?l0
00000ol008_o0000o`X[[003o`X[[003o`000?lf@k?o=T>c00;o=T>c00?o0000oe1QaOm@HLD01?m@
HLD00ol0003oM7G6ogAeaP02ogAeaP?o00002OmdMLH00ol0003oTXW6oi:9aP04o`0000coUYG@00?o
0000ojZTdOnZY=404OnZY=400ol0003o^kCBok^ddP0Bok^ddP03o`000?o;a]Ko000000;o00003_oB
`l`00ol0003oh]c?on;Lc`0<on;Lc`03o`000?ocm;KoloBf00GoloBf0ol0000:ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0E?ooool2
o`000003o`00OOl0003o000000Go2R^/00Co0000ocI3/olf@k?o00002?m@HLD4o`0000coM7G60ol0
000@oiJEd003o`000?nZY=7oZZCA017oZZCA00?o0000ok^dd_nk]=804Onk]=800ol0003oblKFol_6
eP03ol_6eP;o00002ooB`l`00ol0003oh]c?on;Lc`0<on;Lc`;o00001oocm;H00ol0003o`m5Ho`00
000;ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000
ooooooooool0E?ooool2o`000003o`00OOl0003o000000Go2R^/00?o0000ocI3/ol000001_m@HLD3
o`000003oe1QaOl0003oM7G600_oM7G60_l000000omnQm;o0000oiJEd00@oiJEd003o`000?nZY=7o
ZZCA017oZZCA00?o0000ok^dd_nk]=804Onk]=800ol0003oblKFol_6eP05ol_6eP?o00001ooB`l`0
0ol0003oh]c?on;Lc`0<on;Lc`04o`000?oZllgoj_?=o`0000GoloBf0ol0000<ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool02Oooool001Oooooo0_l0001Eooooo`;o000000?o001m
o`000?l000001_l::j`00ol0003oD675oe1Qa@02oe1Qa@?o00001?m@HLD00ol0003oM7G6ogAeaP08
ogAeaP;o00001?mnQm800ol0003oUYG@oiJEd00>oiJEd003o`000?nZY=7oZZCA017oZZCA00?o0000
ok^dd_nk]=804?nk]=800ol0003oblKFol_6eP09ol_6eP;o00001OoB`l`00ol0003oh]c?on;Lc`0;
on;Lc`05o`000?oZllgoj_?=on[ccOl000001Oocm;H3o`0000gooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`1Fooooo`04o`000?l007go
001mo`0000Ko2R^/00?o0000oe1QaOl000000_l00008oe1Qa@03o`000?mdMLKoM7G600CoM7G60ol0
0006ogj7dP03o`000?nFUM3oUYG@00ooUYG@00?o0000ojZTdOnZY=404?nZY=400ol0003o^kCBok^d
dP0@ok^ddP03o`000?o;a]KoblKF00_oblKF0ol000000ooB`lco0000on;Lc`0=on;Lc`05o`000?oZ
llgoj_?=on[ccOl000001?ocm;H01?l0003og?6Do`000?l0000>ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0E_ooool2o`000003o`00
OOl0003o2R^/00?o2R^/1?l0000;oe1Qa@03o`000?mdMLKoM7G600;oM7G60_l0000:ogj7dP03o`00
0?nFUM3oUYG@00koUYG@00?o0000ojZTdOnZY=403onZY=400ol0003o^kCBok^ddP0@ok^ddP03o`00
0?o;a]KoblKF00ooblKF0_l0000=on;Lc`03o`000?oZllgoj_?=00?oj_?=00Go0000oo?d]_ocm;Ko
0000omcaU002o`00013ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00
5_ooool00ol0003oooooooooo`1Fooooo`;o000000?o001mo`000?l000000ol00002o`X[[003o`00
0?l`DlGo000000_oD67500Co0000ogAea_l0003o00003?mnQm800ol0003oUYG@oiJEd00>oiJEd003
o`000?nZY=7oZZCA00ooZZCA00?o0000ok^dd_nk]=804?nk]=800ol0003oblKFol_6eP0?ol_6eP04
o`000?oGfm[o0000o`0000[oh]c?00?o0000on[ccOoZlld01?oZlld01Ol0003oloBfoo?d]_l0003o
g?6D00;o00004Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo000Foooo
o`03o`000?oooooooooo05Oooooo1Ol00004o`X[[004o`000?l`DlGo<5?5o`0000_oD67500?o0000
ogj7d_mnQm803OmnQm800ol0003oUYG@oiJEd00>oiJEd003o`000?nZY=7oZZCA00koZZCA00?o0000
ok^dd_nk]=803onk]=800ol0003oblKFol_6eP0?ol_6eP03o`000?oGfm[oem_J00;oem_J00?o0000
on;LcooRg<l01_oRg<l00ol0003oj_?=on[cc@05on[cc@03o`000?ocm;Ko000000;og?6D00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Foooo
o`03o`000?oooooooooo05Gooooo0ol00002o`00O@03o`0MZOl0003o2R^/00?o2R^/00Go0000oc1C
aOl`DlGo<5?5o`00000:oe1Qa@03o`000?mnQm;oOXOB00koOXOB00?o0000oiJEd?nFUM003OnFUM00
0ol0003oZZCAojZTd@0>ojZTd@03o`000?nk]=;o^kCB00oo^kCB00?o0000ol_6e_o;a]H03_o;a]H0
0ol0003oem_JomOKfP04omOKfP;o00001_oRg<l00ol0003oj_?=on[cc@06on[cc@;o00000_oLlI@0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool0
01Kooooo00?o0000ooooooooool0DOooool4o`0000;ooooo00Ko0000o`00OOl007go0000o`0MZOl0
0002o`X[[003o`000?l`DlGo<5?500?o<5?500?o0000oe1QaOm@HLD01_m@HLD00ol0003oIG_Do`00
000?ogj7dP03o`000?nFUM3oUYG@00goUYG@00?o0000ojZTdOnZY=403_nZY=400ol0003o^kCBok^d
dP0>ok^ddP03o`000?o;a]KoblKF00koblKF00?o0000omOKf_oGfmX01ooGfmX2o`0000?oh]c?00?o
0000on[ccOoZlld01ooZlld00ol0003og?6DomcaU002o`0001Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`1?ooooo`?o00001oooool0
1Ol0003o001mo`000?l07JWo000000;o2R^/00?o0000oc1CaOl`DlD00ol`DlD00ol0003oD675oe1Q
a@05oe1Qa@05o`000?mUNmCoIG_DofEke?l000003omnQm800ol0003oUYG@oiJEd00<oiJEd003o`00
0?nZY=7oZZCA00koZZCA00?o0000ok^dd_nk]=803_nk]=800ol0003oblKFol_6eP0>ol_6eP03o`00
0?oGfm[oem_J00Woem_J00?o0000on;Lcol000002_oZlld01?l0003og?6DomcaU?l0000Fooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001<ooooo`?o0000
2_ooool00ol0003o001mo`000002o`0MZ@03o`000?l::jco000000Ko<5?500?o0000oe1QaOm@HLD0
0om@HLD00ol0003oIG_DofEke003ofEke003o`000?mnQm;oOXOB00coOXOB00?o0000oiJEd?nFUM00
3OnFUM000ol0003oZZCAojZTd@0=ojZTd@03o`000?nk]=;o^kCB00go^kCB00?o0000ol_6e_o;a]H0
3_o;a]H00ol0003oem_JomOKfP0;omOKfP03o`000?oZllgoj_?=00Soj_?=0_l00002omcaU003o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`08ooooo`005Ooo
ool00ol0003oooooooooo`19ooooo`?o00003Oooool00ol0003o001mo`000003o`0MZ@03o`X[[?l0
003o<5?500Ko<5?500Go0000oe1QaOm@HLGoD675o`000007ofEke003o`000?mnQm;oOXOB00coOXOB
00?o0000oiJEd?nFUM002OnFUM0Lo`0000Oo^kCB00?o0000ol_6e_o;a]H03Oo;a]H00ol0003oem_J
omOKfP0;omOKfP;o00002OoZlld2o`0000;og?6D00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Gooooo1?l0
000Aooooo`;o00000ol07JT2o`0000So<5?500?o0000oe1QaOl000002OmUNm@00ol0003oOXOBogj7
dP0;ogj7dP03o`000?nFUM3oUYG@00;oUYG@1ol00003oiVRfP03o`000?nY[M[oZJgJ00goZJgJ00?o
0000okNjg?ng^]`01_ng^]`9o`0000goblKF00?o0000omOKf_oGfmX02ooGfmX01?l0003ogNgLomg]
g?l00007on[cc@04o`000?oSoL3o0000omcaU0;o00006Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;ooooo0ol0000Eooooo`;o0000
1?l07JT00ol0003o<5?5oc1Ca@07oc1Ca@03o`000?mUNmCoIG_D00SoIG_D00?o0000ogj7d_mnQm80
2omnQm85o`0000[oVJ;J00?o0000ojV]f_nY[MX03OnY[MX00ol0003o]k[LokNjg00<okNjg003o`00
0?o2bMoo`/WO00?o00002_o;a]H00ol0003oem_JomOKfP0:omOKfP05o`000?oMkMcogNgLomg]g?l0
00001_oZlld01_l0003ohog0on?m`?l0003og?6Do`0001_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`07ooooo`005Oooool00ol0003oooooooooo`0oooooo`?o00006Oooool00ol0
07go0000o`0MZ@02o`0MZ@03o`000?l`DlGo<5?500Oo<5?500?oD7?Go`000?mUNm@02OmUNm@00ol0
003oOXOBogj7dP08ogj7dP;o000000?oR9SLo`000?nIX]X03OnIX]X00ol0003oZJgJojV]fP0<ojV]
fP03o`000?ng^]co]k[L00_o]k[L00?o0000ol;9goo2bMl01?o2bMl3o`0000KoblKF00?o0000omOK
f_oGfmX02_oGfmX00ol0003ogNgLomg]g002omg]g003o`000?oZllgoj_?=00?oj_?=00Ko0000on?m
`?oSoL3o0000omcaU?l0000Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01ooo
ool001Cooooo00?o0000ooooooooool0?Oooool3o`0001cooooo00?o001mo`000?l07JT00_l07JT2
o`0000So<5?500?o0000oe1ceol000002_mUNm@00ol0003oOXOBogj7dP05ogj7dP;o00001?n8V=`0
0ol0003oVJ;JoiVRfP0;oiVRfP03o`000?nY[M[oZJgJ00coZJgJ00?o0000okNjg?ng^]`02ong^]`0
0ol0003o`/WOol;9g`07ol;9g`?o00000_o;a]H00ol0003oem_JomOKfP0:omOKfP03o`000?oMkMco
gNgL00CogNgL00Go0000on[ccOoZllgoj_?=o`000003on?m`0?o00007_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo03Wooooo1?l0000O
ooooo`;o00000ol07JT00ol0003o5Tg8o`000006oc1Ca@05o`000?m@LmOoD7?Goe1ceol000002_mU
Nm@00ol0003oOXOBogj7dP02ogj7dP;o00001on8V=`00ol0003oVJ;JoiVRfP0:oiVRfP03o`000?nY
[M[oZJgJ00coZJgJ00?o0000okNjg?ng^]`02_ng^]`00ol0003o`/WOol;9g`0;ol;9g`?o00002ooG
fmX00ol0003ogNgLomg]g005omg]g004o`000?oZllgoj_?=o`0000Cohog00_l0000Pooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0=_oo
ool3o`0002Cooooo00?o0000o`0MZOl07JT00_l07JT00ol0003o5Tg8o`000005oc1Ca@03o`000?m@
LmOoD7?G00;oD7?G00?o0000ofEke?mUNm@02?mUNm@01?l0003oOXOBo`000?l0000:ohRHg003o`00
0?nIX][oVJ;J00[oVJ;J00?o0000ojV]f_nY[MX02onY[MX00ol0003o]k[LokNjg00:okNjg003o`00
0?o2bMoo`/WO00_o`/WO00Co0000ol[Hi?o:f>Co00002OoGfmX00ol0003ogNgLomg]g006omg]g003
o`000?oZllgo000000Cohog00ol0000Pooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01oooool001Cooooo0ol0000cooooo`?o00009oooool00ol0003o01fYo`0MZ@02o`0MZ@04o`00
0?lFCLSo5Tg8o`0000Co<5?500?o0000oe1ceom@LmL00om@LmL00ol0003oIG_DofEke008ofEke0;o
00002on8V=`00ol0003oVJ;JoiVRfP0:oiVRfP03o`000?nY[M[oZJgJ00[oZJgJ00?o0000okNjg?ng
^]`02_ng^]`00ol0003o`/WOol;9g`0;ol;9g`03o`000?o:f>Cob]ST00;ob]ST0_l00006omOKfP03
o`000?oMkMcogNgL00SogNgL00?o0000on?m`?oSoL000ooSoL02o`0002;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o0000
:oooool01Ol0003o01fYo`0MZOl07JWo000000?o5Tg800Go0000oc1CaOl`DlGo<5?5o`000006oe1c
e`03o`000?mUNmCoIG_D00OoIG_D0_mhT]l00ol0003oR9SLohRHg009ohRHg003o`000?nIX][oVJ;J
00WoVJ;J00?o0000ojV]f_nY[MX02_nY[MX00ol0003o]k[LokNjg00:okNjg003o`000?o2bMoo`/WO
00[o`/WO00?o0000ol[Hi?o:f>@01Oo:f>@2o`0000?oem_J00?o0000omg]g?oMkM`01ooMkM`00ol0
003og?[Ko`000005on?m`003o`000?oooooooooo02;ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`07ooooo`002_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0;?ooool4o`0002oooooo00Co0000o`0MZOl07JWo00001?lFCLP01?l0003o<5?5oc1CaOl00007
oe1ce`03o`000?mUNmCoIG_D00GoIG_D00Go0000ogRBgomhT]ooN9;Oo`00000;ohRHg003o`000?nI
X][oVJ;J00WoVJ;J00?o0000ojV]f_nY[MX02OnY[MX00ol0003o]k[LokNjg00:okNjg003o`000?o2
bMoo`/WO00Wo`/WO00?o0000ol[Hi?o:f>@02?o:f>@00ol0003oem_Jo`000009omg]g004o`000?oL
n]_og?[Ko`0000Cohog00_l0000Uooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`?o0000<ooo
ool2o`000003o`0MZOl0003o5Tg800Co5Tg800?o<5?5o`000?m@LmL02?m@LmL00ol0003oIG_DofEk
e003ofEke003o`000?mhT]ooN9;O00?oN9;O00?o0000ohRHg?n8V=`02On8V=`00ol0003oVJ;JoiVR
fP08oiVRfP03o`000?nY[M[oZJgJ00WoZJgJ00?o0000okNjg?ng^]`02Ong^]`00ol0003o`/WOol;9
g`09ol;9g`03o`000?o:f>Cob]ST00[ob]ST00?o0000omg]g?oMkM`01ooMkM`01?l0003og?[Komcj
fol00004on?m`0;o00009oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo
000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09oooool3o`0003Oooooo00?o
0000o`0MZOl000001_lFCLP2o`0000WoD7?G00Go0000ofEke?mUNmCoIG_Do`000007ogRBg`03o`00
0?n8V=coR9SL00SoR9SL00?o0000oiVRf_nIX]X02?nIX]X00ol0003oZJgJojV]fP09ojV]fP03o`00
0?ng^]co]k[L00Wo]k[L00?o0000ol;9goo2bMl02?o2bMl00ol0003ob]STol[Hi009ol[Hi003o`00
0?o?iNOo000000OogNgL0_l00003omcjf`04o`000?oSoL3ohog0on?m`0?o0000:?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool09?ooool3o`0003_ooooo00?o0000o`0MZOl000001OlFCLP2ocmcg003o`00
0?m@LmOoD7?G00OoD7?G00?o0000ofEke?l000002OmhT]l00ol0003oR9SLohRHg008ohRHg003o`00
0?nIX][oVJ;J00SoVJ;J00?o0000ojV]f_nY[MX00onY[MX9o`0000Oo]k[L00?o0000ol;9goo2bMl0
2?o2bMl00ol0003ob]STol[Hi009ol[Hi005o`000?o?iNOocnGWoloUiol000001OoMkM`00ol0003o
g?[Komcjf`03omcjf`06o`000?oSoL3ohog0o`000?o8n:_o0000:Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool08?ooool4o`0003kooooo00?o0000o`0MZOl000001OlFCLP01?l0003o?g?Locmcg?l00009
oe1ce`;o00002_mhT]l00ol0003oR9SLohRHg008ohRHg003o`000?nIX][oVJ;J00?oVJ;J2_l00005
ojNgi004o`000?n``>Go/<3Uok30i@Go00000_ng^]`00ol0003o`/WOol;9g`07ol;9g`03o`000?o:
f>Cob]ST00Sob]ST0_l00004oloUi`03o`000?oMkMcogNgL00;ogNgL00?o0000omcjfooLn]/01?oL
n]/01?l0003ohog0o`000?o8n:/2o`0002[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`06ooooo`003?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo0ol0
0013ooooo`03o`09VOl0003o000000Go5Tg800Co0000ocmcg?loLmco00002?m@LmL2of^?h`03o`00
0?mhT]ooN9;O00SoN9;O00?o0000ohRHg?n8V=`01on8V=`6o`0000CoW:oU00?o0000ojNgi?nW]n@0
2?nW]n@00ol0003o/<3Uok30i@06ok30i@Co00001oo2bMl00ol0003ob]STol[Hi008ol[Hi003o`00
0?o?iNOocnGW00GocnGW00Co0000omg]g?oMkMco00001ooLn]/2o`0000;ob?R[00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo000<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool06_ooool3o`0004Kooooo00Co0000o`18bOl0B<Wo
00001?lFCLP01?l0003o?g?Locmcg?loLm`2o`0000KoD7?G00?o0000of^?hom[Sn<00_l00009ogRB
g`03o`000?n8V=coR9SL00?oR9SL0ol000000onAZ^Ko0000oib_i@08oib_i@03o`000?nW]nCoYkOT
00OoYkOT00?o0000ok30iOn``>D01on``>D00ol0003o^<[XokS:j004o`0000;o`/WO00?o0000ol[H
i?o:f>@02?o:f>@00ol0003ocnGWoloUi`06oloUi`03o`000?oMkMco000000Oog?[K0_l00002olSh
Z`03o`000?oooooooooo02cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06oooo
o`002_ooool00omEEEGoIVIVo`000006ooooo`;o00006?ooool3o`0004[ooooo00Co0000o`18bOl0
B<Wo00000olFCLP00ol0003o?g?Locmcg003ocmcg003o`000?m@LmOoD7?G00;oD7?G00?o0000of^?
hom[Sn<00om[Sn<00ol0003oN9;OogRBg`07ogRBg`03o`000?n8V=co000000;o00001OnAZ^H00ol0
003oW:oUoib_i@06oib_i@03o`000?nW]nCoYkOT00KoYkOT00?o0000ok30iOn``>D01on``>D00ol0
003o^<[XokS:j005okS:j0;o00002_o:f>@00ol0003ocnGWoloUi`08oloUi`03o`000?oLn]_og?[K
00Kog?[K00Go0000olShZoo8n:_ob?R[o`00000_ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01_ooool001;ooooo00?o0000ooooooooool05?ooool4o`0004kooooo00Co0000o`18
bOl0B<Wo00000olFCLP00ol0003o?g?Locmcg003ocmcg005o`000?m@LmOoD7?Goe1ceol000001_m[
Sn<2o`0000SoN9;O0_l00008oi6ZiP03o`000?nL[nGoW:oU00GoW:oU00?o0000ojNgi?nW]n@01_nW
]n@00ol0003o/<3Uok30i@06ok30i@03o`000?nhb^So^<[X00Ko^<[X0onldn/00ol0003ob]STol[H
i004ol[Hi0;o00002Oo?iNL00ol0003oc^oZo`000006omcjf`03o`000?o?omOo000000;ob?R[00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo000B
ooooo`03o`000?oooooooooo017ooooo0ol0001Booooo`;o00000_l0B<T01?l0003o5Tg8oaI=b?l0
0006ocmcg004o`000?m@LmOoD7?Go`0000SoJhoS00?o0000ogRBgomhT]l01?mhT]l01?l0003oR:OY
ohRWjOl00008oi6ZiP03o`000?nL[nGoW:oU00GoW:oU00?o0000ojNgi?nW]n@01OnW]n@00ol0003o
/<3Uok30i@06ok30i@03o`000?nhb^So^<[X00Co^<[X00?o0000okcCjonldn/00onldn/2o`0000?o
b]ST00?o0000oloUioo?iNL01oo?iNL2o`0000;oc^oZ00?o0000omcjfooLn]/00_oLn]/2o`000003
olooeol0003ob?R[00;ob?R[00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00kooooo0ol0001Fooooo`;o0000
0_l0B<T00ol0003o5Tg8o`000007ocmcg003oe1ceol0003oJhoS00WoJhoS0_l00003ogRBg`03o`00
0?n8YnWoR:OY00;oR:OY0_l00007oi6ZiP03o`000?nL[nGoW:oU00CoW:oU00?o0000ojNgi?nW]n@0
1OnW]n@00ol0003o/<3Uok30i@05ok30i@03o`000?nhb^So^<[X00Co^<[X00?o0000okcCjonldn/0
1_nldn/00ol0003ob]STo`000008oloUi`;o00001?o>knX01Ol0003og?[KomcjfooLn]_o000000;o
cooG00?o0000olShZoo8n:/00_l0000cooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01Oooool001;ooooo00?o0000ooooooooool02oooool3o`0005[ooooo0_l00002o`18b@;o0000
2?loLm`2o`0000_oJhoS0_mhT]l00ol0003oR:OYohRWj@05ohRWj@03o`000?nAZ^KoTJ[V00CoTJ[V
00?o0000oib_iOnL[nD01OnL[nD00ol0003oYkOTojNgi004ojNgi003o`000?n``>Go/<3U00Co/<3U
00?o0000okS:j?nhb^P01?nhb^P00ol0003o_=?[okcCj`08okcCj`03o`000?o?iNOocnGW00KocnGW
00?o0000olk_j_o>knX00oo>knX01Ol0003og?[KomcjfooLn]_o000000?ocooG00Co0000olShZol0
003o0000=Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo000Booooo`03
o`000?oooooooooo00Oooooo1?l0001Mooooo`03o`000?l02IWo000000;o04S900?o5Tg8o`000?lo
Lm`01_loLm`01?l0003oHY7Xo`000?l0000:of^?h`;o00002?n8YnT2o`0000GoTJ[V00?o0000oib_
iOnL[nD01?nL[nD00ol0003oYkOTojNgi003ojNgi003o`000?n``>Go/<3U00Co/<3U00?o0000okS:
j?nhb^P01?nhb^P00ol0003o_=?[okcCj`07okcCj`03o`000?nnfnko000000KocnGW0_l00006olk_
jP04o`000?oLn]_o0000o`0000?ocooG00Co0000olShZol0003o0000=oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo00Cooooo0ol0001R
ooooo`;o00000ol0B<T2o`0000Ko?g?L00Co0000of:Aj?mRTNSoHY7X0_l00008of^?h`04o`000?n2
Ynco0000o`0000SoR:OY00?o0000oi6Zi_nAZ^H00onAZ^H00ol0003oW:oUoib_i@03oib_i@03o`00
0?nW]nCoYkOT00?oYkOT00?o0000ok30iOn``>D01?n``>D00ol0003o^<[XokS:j003okS:j003o`00
0?nldn_o_=?[00Go_=?[0_l00004okkKkP04o`000?o?iNOocnGWoloUi`;o00002?o>knX2o`0000Go
cooG0ol0000iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0017ooooo
00?o0000ooooooooool00_ooool3o`0006Kooooo0_l00002o`18b@04o`000?l]Mn?o0000o`0000Go
?g?L00?o0000of:Aj?mRTNP00_mRTNP3o`0000GoJhoS00Co0000oh:Wk?n2YncoPZO/0_l00007ohRW
j@03o`000?nAZ^KoTJ[V00?oTJ[V00Co0000oib_iOnL[nGoW:oU2ol00002ok30i@03o`000?nhb^So
^<[X00?o^<[X00?o0000okcCjonldn/01?nldn/2o`0000Oo_]_^00?o0000oloUiol000002_o>knX0
0ol0003ocooGolooe`03olooe`?o0000>_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Gooooo000Aooooo`03o`000?oooooo000000;o0000J_ooool2o`0000;o04S900Co0000obeg
hol]Mn?o00001?loLm`00ol0003oHY7Xof:Aj005of:Aj0;o00000_m[Sn<00ol0003oPZO/oh:Wk004
oh:Wk0;o00001_n8YnT2o`0000?oTJ[V1?l00002oijmk`03o`000?nS`>koXl3^00;oXl3^00Co0000
ojO5k_nWaNkoYlG^1Ol00002okS:j003o`000?nldn_o_=?[00Co_=?[00?o0000okkKk_nnfnh02?nn
fnh00ol0003oc^oZolk_jP06olk_jP;o000000?ob?G/o`000?o?omL00oo?omL3o`0003cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`004Oooool2o`0006kooooo00Go0000
o`18bOl0B<Wo04S9o`000002obegh`;o00000_loLm`00ol0003oHY7Xof:Aj007of:Aj003o`000?m[
Sn?o000000SoPZO/0_l00006ohRWj@03o`000?nAZ^Ko000000?oV[c`00Go0000oijmkonN_NooW[g_
o`000003oj?0kP03o`000?nWaNkoYlG^00;oYlG^00Co0000oj[9l?nZbO3oZ/W`0_l00005okcCj`;o
00002?nnfnh2o`000003okgPlOl0003oc^oZ00Goc^oZ0_l00002olSek003o`000?o?omOocooG00?o
cooG0_l0000nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool001?ooooo
00?o0000ooooooooool0K?ooool01Ol0003o04S9o`18bOl0B<Wo000000?o;GOS00?o0000ocmcg?l0
00002omRTNP3o`0000SoPZO/0_l00004ohRWj@?o00001?nJ_?001?l0003oW[g_oijmkol00003oj?0
kP05o`000?nWaNkoYlG^ojO5k_l000000onZbO001_l0003oZlgboj_=l_n[cO;o0000okcCj`;o0000
1_nnfnh3o`0000Co_N3a00Co0000olk_j_o>kn[oc^oZ0ol00003olSek003o`000?o?omOocooG00;o
cooG0ol00010ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool001Cooooo
0_l0001]ooooo`;o000000?o04S9o`000?l]Mn<01?l]Mn<00oloLmco0000of:Aj009of:Aj003o`00
0?mnZNooOZW_00?o00001on2Yn`2o`000003ohRWjOl0003oV;ca00;oV;ca0_l00003oiZll004o`00
0?nN_NooW[g_o`0000;oXl3^00Co0000ojO5k_nWaNko00000_nZbO02o`0000CoZlgb0_l00005okkK
kP?o00001_nmh?400ol0003oc^oZolk_jP02o`0000Kob?G/00?o0000olooeoo?omL00_l000000on@
gI3o0000ooooo`11ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool001Ko
oooo00?o0000ooooool00000K?ooool00ol0003o04S9o`000005obegh`?o00002OmRTNP00ol0003o
OZW_ogjYk`02ogjYk`Co00001On2Yn`3o`0000CoV;ca0_l00002oiZll005o`000?nN_Noo0000oj?0
k_l000000_nWaNh01?l0003oZ/W`o`000?l00003oj_=lP?o000000CoZloco`000?nnfnko_]_^0ol0
0009okgPl@?o00001oo8mN`00ol0003ocooGo`000002o`000003oi3MT?l0003ooooo04;ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`005oooool2o`0006gooooo00?o0000
o`18bOl000001?l]Mn<00ol0003oFYS_oeZHk`03o`0000KoHY7X00?o0000ogjYkomnZNl01_mnZNl3
o`0000;oPZO/00?o0000oiNllOnG_?401?l00002oiRll@;o000000GoV[c`o`000?l0003oXl3^o`00
0002ojO5kP;o00000_n[cO83o`0000?oZloc1?l0000<okgPl@03o`000?o8mNcob?G/00Oob?G/0_l0
00001?n`n]3o0000oi3MT?l00015ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1?ooool001Sooooo0_l0001]ooooo`;o00001Ol]Mn<00ol0003oFYS_oeZHk`02oeZHk`?o00000omR
TNP00ol0003oOZW_ogjYk`09ogjYk`Ko00000onG_?43o`000003oiRllOl0003o000000?o000000?o
YlG^o`000?l000000ol000000on[co?o0000o`000003o`0000;oZm3c00?o0000okgPlOnmh?401?nm
h?45o`0000;o^^Cd00?o0000olSek?o8mN`01_o8mN`2o`000004ok3jd?l0003o0000o`0004Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_ooool00ol0003ooooooooo
o`1[ooooo`;o00001Ol]Mn<00ol0003oFYS_oeZHk`04oeZHk`?o000000?oHY7Xo`000?mnZNl02_mn
ZNl00ol0003oUkcboiNllP02oiNllQ?o00001on[d?<00ol0003o_N3ao`000004o`0000Ko^^Cd00?o
0000olSek?o8mN`01?o8mN`00ol0003ob?G/o`000002ok3jd0;o0000B_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00?ooooo000Kooooo`;o000000?oooooo`000?ooool0J_ooool0
0ol0003o;GOSobegh`03obegh`03o`000?mJV>ooFYS_00KoFYS_2Ol00005ogjYk`03o`000?nG_?;o
Ukcb00GoUkcb6?l0000:ok[Tm004o`000?o8mNcob?G/olSek0Go00000on`n]02o`0004cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007Oooool2o`0006cooooo0ol00003
obegh`03o`000?mJV>ooFYS_00KoFYS_00?o0000ogb^loml[_<01Oml[_<=o`0000?oU[kc0ol00000
0onGaOOo0000o`000009o`0000?oZ]3d00?o0000ok[Tm?nji?@02_nji?@4o`0000?o^OO_00Go0000
ok3jd?n`n]3o/?[@o`00001>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool001kooooo00?o0000ooooooooool0Joooool00ol0003o5h7Wo`000002o`000003obeghol0003o
FYS_00OoFYS_00?o0000ogb^loml[_<02_ml[_<00ol0003oU[kcoiJnl`04oiJnl`Go000000GoUlGg
o`000?l0003oXLkgo`000002ojK@mP;o00001?nYd?@=o`0000;o^^Cd0_l00005okWgk`05o`000?n`
n]3o/?[@ok3jd?l00000D?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
000Oooooo`;o0000KOooool00ol0003o5h7WoaN1i`03o`0000SoFYS_00?o0000ogb^loml[_<02_ml
[_<00ol0003oU[kcoiJnl`03o`0000;oU/3d00Co0000oiO5monGaOOoUlGg0_l00002oj7>m`04o`00
0?nVd?KoY]3fojK@mP?o000000?oZM3do`000?nciOL02onciOL00ol0003o^OO_okWgk`05okWgk`03
o`000?n`n]3o/?[@00;o0000D_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo000Qooooo`03o`000?oooooooooo06_ooooo0_l00003oaN1i`Ko00000omJV>l00ol0003oO:kc
ogb^l`04ogb^l`Go000000?oO:kco`000?l000000onF`?@2o`0000?oUlGg00Co0000oi_:n?nKb_So
00000_nQc_L00ol0003oY]3fojK@mP02ojK@mPGo00002?nciOL2o`0000Oo^OO_1?l0001Eooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool002;ooooo0ol0001[ooooo`;o0000
1?lGPNL01?l0003oE:?goeBSmomDXoL:o`0000SoNkKh00?o0000oiK0m?l000001?nGaOL01Ol0003o
Vl[hoi_:n?nKb_So000000?oXLkg00Co0000ojK@m_l0003o00001OnWho/4o`0000?o/nGg00?o0000
okWgkonimnl01_nimnl3o`0005Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03
ooooo`009?ooool00ol0003oooooooooo`1Zooooo`;o00001OlGPNL00ol0003oE:?goeBSm`05oeBS
m`;o00002omk]_P4o`0000;oUlGg00Go0000oi_:n?nKb_SoVl[ho`000002oj7>m`Co00002onWho/=
o`0005[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`009Oooool2o`00
06[ooooo00Co0000ooooool0003o00001?lGPNL2o`0000OoE:?g00?o0000og^fn?mk]_P01?mk]_P3
o`0000GoO/;m2Ol00004oiOKoP03o`000?nWho_oYn?k00KoYn?k0_l00007oig`l`Co0000G?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Wooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool00_l00005oaN1i`;o00001_mDXoL2o`000004og^fn?l0003o0000
o`0000WoO/;m00?o0000ohS?oon8col00_n8col00ol0003oUm_noiOKoP05oiOKoP;o00001?nWho/2
o`0000OoWO3c1?l0001Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool0
02Sooooo00?o0000ooooool00000I_ooool00ol0003oooooooooo`02ooooo`03o`000?lGPNOo5h7W
00Co5h7W00?o0000oeBSmomDXoL00_mDXoL2o`000005oeBSmol0003oO/;mogk2oOl000002?mn`_d0
0ol0003oR<ooohS?o`03ohS?o`03o`000?nGfokoUm_n00OoUm_n00Co0000ojOSnol0003o00001onM
l?<2o`000003og_Tb?l0003ooooo067ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`02ooooo`007_ooool4o`000003oa0@4?oooooooooo00Cooooo0_l0001Vooooo`03o`000?oooooo
oooo00?ooooo2ol00007oeBen`Go00000_mn`_d00ol0003oR<ooohS?o`05ohS?o`03o`000?nGfoko
Um_n00GoUm_n1?l00006oig`l`;o000000?oNnC8o`000?l00000I?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`06ooooo`03o`000?l9Smgo2HoM00Co2HoM0ol0000:oeBe
n`Oo00000on8col00ol0003oUm_noiOKoP05o`0000CoO>3g0ol000000onMl??o0000o`000003o`00
06Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Oooool6o`0000Go
oooo00?o0000ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool02Oooool3o`0000Co
2HoM0ol00006oeBen`03o`000?mQbo[oHL_j00GoHL_j1_l0000:ogcPm`Go0000J_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooool00000H?ooool00ol0003oooooooooo`0=ooooo`?o00000ol9Smd3o`0000;oE;Gk
00?o0000of7;n_mQboX02OmQboX00ol0003oO>3gogcPm`05ogcPm`Ko0000Koooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00cooooo0_l0
001Pooooo`03o`000?oooooooooo013ooooo0ol00003o`V?g@;o00000_mQboX5o`0000KoHL_j00?o
0000ogcPmol000001Ol0001eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00Ooo
ool0023ooooo00?o0000ooooooooool03Oooool2o`0005oooooo00?o0000ooooooooool04oooool3
o`0000Wo5ZC<2_l0001jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
0:Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`007_ooool00omEEEGo
IVIVo`00000Booooo`;o000000?oooooo`000?ooool0F?ooool00ol0003oooooooooo`2Uooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool003Gooooo0_l0001Iooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00=_oo
ool2o`0005Sooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo007ooooo000hooooo`05o`000?ooooooooooooooool00000Doooool00ol0003ooooooooo
o`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool003Wooooo00Co0000
oooooooooooo0000Doooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Wooooo0Ol0
0001ooooo`7ooooo000jooooo`?o0000Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooo
oooo00Sooooo0Ol00001ooooo`7ooooo000looooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00?Oooool2o`00057o
oooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00
?oooool00ol0003oooooo`00001>ooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool0
1_ooool1o`00007ooooo0Oooool0043ooooo0_l0001>ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool01Oooool1o`00007ooooo0Oooool0047ooooo0_l0001=ooooo`03o`000?oooooo
oooo0:kooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004?ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Gooooo0Ol00001oooo
o`00A?ooool2o`000003ooooool0003ooooo04Oooooo00?o0000ooooooooool0[oooool00ol0003o
ooooooooo`04ooooo`7o00000Oooool004Kooooo0_l00018ooooo`03o`000?oooooooooo0;3ooooo
00?o0000ooooooooool00oooool1o`00007ooooo000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l00017ooooo`03o`000?oooooooooo0;7o
oooo00?o0000ooooooooool00_ooool1o`00007ooooo000booooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000A_ooool00ol0003oooooooooo`2boooo
o`05o`000?ooooooooooooooool000000Oooool002[ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03o`0004?ooooo00?o0000ooooooooool0/oooool0
1?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0;?ooooo00Co
0000oooooooooooo00000Oooool003;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool00Ol0000003;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Sooooo0_l00010ooooo`03o`000?oooooooooo0;Gooooo0Ol00001ooooo`7o
0000000booooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o
0000?_ooool00ol0003oooooooooo`2fooooo`;o0000000booooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000[ooooo0_l0000mooooo`03o`000?oooooooooo0;Gooooo0ol0000005?ooooo
00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo0;3ooooo1Ol00003ooooo`00
E?ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo0:cooooo1?l00008ooooo`00
EOooool3o`0003Sooooo00?o0000ooooooooool0Z?ooool4o`0000cooooo001Gooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0Y?ooool5o`00013ooooo001Hooooo`;o0000=Oooool0
0ol0003oooooooooo`2Pooooo`Co00005Oooool005[ooooo00?o0000ooooool00000<_ooool00ol0
003oooooooooo`2Looooo`Co00006Oooool005_ooooo0_l0000booooo`03o`000?oooooooooo09Oo
oooo1Ol0000Mooooo`00GOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo
1?l0000Rooooo`00G_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo08kooooo
1Ol0000Vooooo`00Goooool3o`0002gooooo00?o0000ooooooooool0R_ooool4o`0002_ooooo001Q
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_ooool4o`0002oooooo001Coooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0002_ooooo00?o0000ooooooooool0POooool5
o`0003?ooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooo`00000X
ooooo`03o`000?oooooooooo07gooooo1?l0000hooooo`00Doooool01Ol@413ooooooooooooooooo
410@00gooooo0_l0000Xooooo`03o`000?oooooooooo07Wooooo1?l0000looooo`00Doooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1d
ooooo`Go0000@?ooool005?ooooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?oooooo
ooooo`0002?ooooo00?o0000ooooooooool0L?ooool4o`0004Gooooo001Cooooo`05oa0@4?oooooo
ooooooooool@41004Oooool3o`0002?ooooo00?o0000ooooooooool0Joooool5o`0004Wooooo001C
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`0002?ooooo00?o0000ooooooooool0Iooo
ool4o`0004kooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0
003ooooo01kooooo00?o0000ooooooooool0Hoooool4o`0005;ooooo001^ooooo`;o00007oooool0
0ol0003oooooooooo`1Nooooo`Go0000E_ooool006oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Jooooo`Co0000Foooool0073ooooo0_l0000Mooooo`03o`000?oooooooooo05Ko
oooo1?l0001Oooooo`00L_ooool00ol0003oooooo`00000Jooooo`03o`000?oooooooooo057ooooo
1Ol0001Sooooo`00Loooool2o`0001[ooooo00?o0000ooooooooool0COooool4o`0006Sooooo001e
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOooool4o`0006cooooo001foooo
o`;o000000?oooooo`000?ooool05?ooool00ol0003oooooooooo`14ooooo`Go0000L?ooool007So
oooo0_l0000Eooooo`03o`000?oooooooooo043ooooo1?l0001eooooo`00NOooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo03_ooooo1Ol0001iooooo`00N_ooool2o`000003ooooool0
003ooooo013ooooo00?o0000ooooooooool0=oooool4o`0007kooooo001Sooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o0000
4Oooool00ol0003oooooooooo`0cooooo`Co0000P_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`;o00003oooool00ol0003ooooo
ooooo`0_ooooo`Go0000Q_ooool006?ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`Co0000
Roooool006?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo
0ol0000;ooooo`03o`000?oooooooooo02Oooooo1?l0002?ooooo`00Hoooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c009ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08_ooool5o`0009?ooooo001Sooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool07_ooool4o`0009Sooooo001Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`0=ooooo`?o00001oooool00ol0003oooooooooo`0Iooooo`Go0000W?ooool006?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo1?l0002Qooooo`00Qoooool2o`0000Gooooo00?o0000oooooooo
ool04Oooool4o`000:Gooooo0029ooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`Go0000
ZOooool008[ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000[_ooool008_ooooo0_l0
00000ooooooo0000ooooo`05ooooo`Co0000/_ooool008gooooo0_l000000ooooooo0000o`000003
o`000;Kooooo002>ooooo`;o0000^oooool00?ooooooC?ooool00?ooooooC?ooool008Cooooo1?l0
00000ol@413oooooooooo`30ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0
003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003ooooo
ooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32
ooooo`00Q?ooool00omEEEGoIVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.41791 .53393 m .40048 .57566 L .47069 .59348 L p .757 .646 .739 r
F P
0 g
s
.47069 .59348 m .47829 .54982 L .41791 .53393 L p .757 .646 .739 r
F P
0 g
s
.46435 .63845 m .47069 .59348 L .40048 .57566 L p .766 .625 .704 r
F P
0 g
s
.47829 .54982 m .47069 .59348 L .54441 .59657 L p .693 .581 .725 r
F P
0 g
s
.47069 .59348 m .46435 .63845 L .54633 .63979 L p .692 .553 .693 r
F P
0 g
s
.54633 .63979 m .54441 .59657 L .47069 .59348 L p .692 .553 .693 r
F P
0 g
s
.40048 .57566 m .38587 .61929 L .46435 .63845 L p .766 .625 .704 r
F P
0 g
s
.45959 .68343 m .46435 .63845 L .38587 .61929 L p .773 .601 .666 r
F P
0 g
s
.46435 .63845 m .45959 .68343 L .54776 .68249 L p .689 .523 .657 r
F P
0 g
s
.54776 .68249 m .54633 .63979 L .46435 .63845 L p .689 .523 .657 r
F P
0 g
s
.43743 .495 m .41791 .53393 L .47829 .54982 L p .747 .665 .77 r
F P
0 g
s
.47829 .54982 m .48684 .50842 L .43743 .495 L p .747 .665 .77 r
F P
0 g
s
.48684 .50842 m .47829 .54982 L .54207 .55388 L p .693 .607 .756 r
F P
0 g
s
.54441 .59657 m .54207 .55388 L .47829 .54982 L p .693 .581 .725 r
F P
0 g
s
.54207 .55388 m .54441 .59657 L .60951 .58597 L p .625 .521 .716 r
F P
0 g
s
.54441 .59657 m .54633 .63979 L .61734 .62546 L p .613 .486 .683 r
F P
0 g
s
.61734 .62546 m .60951 .58597 L .54441 .59657 L p .613 .486 .683 r
F P
0 g
s
.54633 .63979 m .54776 .68249 L .62303 .66408 L p .599 .448 .647 r
F P
0 g
s
.62303 .66408 m .61734 .62546 L .54633 .63979 L p .599 .448 .647 r
F P
0 g
s
.54207 .55388 m .53938 .5126 L .48684 .50842 L p .693 .607 .756 r
F P
0 g
s
.53938 .5126 m .54207 .55388 L .59965 .54631 L p .636 .555 .747 r
F P
0 g
s
.60951 .58597 m .59965 .54631 L .54207 .55388 L p .625 .521 .716 r
F P
0 g
s
.38587 .61929 m .37485 .66358 L .45959 .68343 L p .773 .601 .666 r
F P
0 g
s
.45667 .72687 m .45959 .68343 L .37485 .66358 L p .777 .571 .62 r
F P
0 g
s
.45959 .68343 m .45667 .72687 L .54863 .72348 L p .684 .488 .616 r
F P
0 g
s
.54863 .72348 m .54776 .68249 L .45959 .68343 L p .684 .488 .616 r
F P
0 g
s
.45841 .45936 m .43743 .495 L .48684 .50842 L p .735 .682 .799 r
F P
0 g
s
.48684 .50842 m .49608 .46987 L .45841 .45936 L p .735 .682 .799 r
F P
0 g
s
.49608 .46987 m .48684 .50842 L .53938 .5126 L p .692 .633 .785 r
F P
0 g
s
.54776 .68249 m .54863 .72348 L .62646 .7012 L p .583 .405 .607 r
F P
0 g
s
.62646 .7012 m .62303 .66408 L .54776 .68249 L p .583 .405 .607 r
F P
0 g
s
.53938 .5126 m .53641 .47339 L .49608 .46987 L p .692 .633 .785 r
F P
0 g
s
.53641 .47339 m .53938 .5126 L .5879 .50719 L p .646 .59 .777 r
F P
0 g
s
.59965 .54631 m .5879 .50719 L .53938 .5126 L p .636 .555 .747 r
F P
0 g
s
.37133 .50851 m .34719 .54585 L .40048 .57566 L p .821 .724 .758 r
F P
0 g
s
.40048 .57566 m .41791 .53393 L .37133 .50851 L p .821 .724 .758 r
F P
0 g
s
.38587 .61929 m .40048 .57566 L .34719 .54585 L p .842 .712 .721 r
F P
0 g
s
.39868 .47413 m .37133 .50851 L .41791 .53393 L p .799 .732 .79 r
F P
0 g
s
.41791 .53393 m .43743 .495 L .39868 .47413 L p .799 .732 .79 r
F P
0 g
s
.34719 .54585 m .32716 .58541 L .38587 .61929 L p .842 .712 .721 r
F P
0 g
s
.37485 .66358 m .38587 .61929 L .32716 .58541 L p .861 .696 .676 r
F P
0 g
s
.37485 .66358 m .36809 .70695 L .45667 .72687 L p .777 .571 .62 r
F P
0 g
s
.4558 .76711 m .45667 .72687 L .36809 .70695 L p .779 .533 .564 r
F P
0 g
s
.45667 .72687 m .4558 .76711 L .54889 .76151 L p .675 .446 .566 r
F P
0 g
s
.54889 .76151 m .54863 .72348 L .45667 .72687 L p .675 .446 .566 r
F P
0 g
s
.5879 .50719 m .59965 .54631 L .64597 .52868 L p .577 .509 .743 r
F P
0 g
s
.59965 .54631 m .60951 .58597 L .66041 .56477 L p .553 .465 .709 r
F P
0 g
s
.66041 .56477 m .64597 .52868 L .59965 .54631 L p .553 .465 .709 r
F P
0 g
s
.42843 .44316 m .39868 .47413 L .43743 .495 L p .774 .737 .818 r
F P
0 g
s
.43743 .495 m .45841 .45936 L .42843 .44316 L p .774 .737 .818 r
F P
0 g
s
.60951 .58597 m .61734 .62546 L .6714 .60036 L p .527 .418 .674 r
F P
0 g
s
.6714 .60036 m .66041 .56477 L .60951 .58597 L p .527 .418 .674 r
F P
0 g
s
.48038 .42716 m .45841 .45936 L .49608 .46987 L p .721 .697 .827 r
F P
0 g
s
.49608 .46987 m .50581 .4344 L .48038 .42716 L p .721 .697 .827 r
F P
0 g
s
.50581 .4344 m .49608 .46987 L .53641 .47339 L p .69 .659 .815 r
F P
0 g
s
.53641 .47339 m .53321 .43676 L .50581 .4344 L p .69 .659 .815 r
F P
0 g
s
.53321 .43676 m .53641 .47339 L .57444 .4694 L p .656 .626 .808 r
F P
0 g
s
.5879 .50719 m .57444 .4694 L .53641 .47339 L p .646 .59 .777 r
F P
0 g
s
.57444 .4694 m .5879 .50719 L .62799 .49275 L p .599 .554 .775 r
F P
0 g
s
.64597 .52868 m .62799 .49275 L .5879 .50719 L p .577 .509 .743 r
F P
0 g
s
.54863 .72348 m .54889 .76151 L .62755 .73614 L p .562 .356 .558 r
F P
0 g
s
.62755 .73614 m .62646 .7012 L .54863 .72348 L p .562 .356 .558 r
F P
0 g
s
.32716 .58541 m .31214 .62619 L .37485 .66358 L p .861 .696 .676 r
F P
0 g
s
.36809 .70695 m .37485 .66358 L .31214 .62619 L p .878 .672 .62 r
F P
0 g
s
.61734 .62546 m .62303 .66408 L .67913 .63501 L p .498 .369 .635 r
F P
0 g
s
.67913 .63501 m .6714 .60036 L .61734 .62546 L p .498 .369 .635 r
F P
0 g
s
.45992 .41585 m .42843 .44316 L .45841 .45936 L p .748 .738 .843 r
F P
0 g
s
.45841 .45936 m .48038 .42716 L .45992 .41585 L p .748 .738 .843 r
F P
0 g
s
.57444 .4694 m .55949 .4338 L .53321 .43676 L p .656 .626 .808 r
F P
0 g
s
.55949 .4338 m .57444 .4694 L .60658 .45797 L p .621 .6 .807 r
F P
0 g
s
.62799 .49275 m .60658 .45797 L .57444 .4694 L p .599 .554 .775 r
F P
0 g
s
.62303 .66408 m .62646 .7012 L .68376 .66852 L p .467 .316 .592 r
F P
0 g
s
.68376 .66852 m .67913 .63501 L .62303 .66408 L p .467 .316 .592 r
F P
0 g
s
.36809 .70695 m .36609 .7477 L .4558 .76711 L p .779 .533 .564 r
F P
0 g
s
.4571 .80252 m .4558 .76711 L .36609 .7477 L p .776 .482 .489 r
F P
0 g
s
.4558 .76711 m .4571 .80252 L .54852 .79532 L p .66 .391 .502 r
F P
0 g
s
.54852 .79532 m .54889 .76151 L .4558 .76711 L p .66 .391 .502 r
F P
0 g
s
.5159 .40203 m .50581 .4344 L .53321 .43676 L p .686 .687 .845 r
F P
0 g
s
.53321 .43676 m .52983 .40308 L .5159 .40203 L p .686 .687 .845 r
F P
0 g
s
.52983 .40308 m .53321 .43676 L .55949 .4338 L p .666 .665 .84 r
F P
0 g
s
.31214 .62619 m .30294 .66695 L .36809 .70695 L p .878 .672 .62 r
F P
0 g
s
.36609 .7477 m .36809 .70695 L .30294 .66695 L p .892 .636 .545 r
F P
0 g
s
.50304 .39832 m .48038 .42716 L .50581 .4344 L p .704 .711 .854 r
F P
0 g
s
.50581 .4344 m .5159 .40203 L .50304 .39832 L p .704 .711 .854 r
F P
0 g
s
.54889 .76151 m .54852 .79532 L .62619 .76823 L p .535 .294 .497 r
F P
0 g
s
.62619 .76823 m .62755 .73614 L .54889 .76151 L p .535 .294 .497 r
F P
0 g
s
.37561 .4485 m .34515 .47759 L .37133 .50851 L p .846 .813 .817 r
F P
0 g
s
.37133 .50851 m .39868 .47413 L .37561 .4485 L p .846 .813 .817 r
F P
0 g
s
.34719 .54585 m .37133 .50851 L .34515 .47759 L p .883 .822 .783 r
F P
0 g
s
.40972 .42296 m .37561 .4485 L .39868 .47413 L p .809 .799 .842 r
F P
0 g
s
.39868 .47413 m .42843 .44316 L .40972 .42296 L p .809 .799 .842 r
F P
0 g
s
.55949 .4338 m .54334 .40126 L .52983 .40308 L p .666 .665 .84 r
F P
0 g
s
.54334 .40126 m .55949 .4338 L .58206 .4255 L p .643 .648 .84 r
F P
0 g
s
.60658 .45797 m .58206 .4255 L .55949 .4338 L p .621 .6 .807 r
F P
0 g
s
.60658 .45797 m .62799 .49275 L .65819 .46981 L p .555 .53 .783 r
F P
0 g
s
.62799 .49275 m .64597 .52868 L .6808 .502 L p .52 .476 .747 r
F P
0 g
s
.6808 .502 m .65819 .46981 L .62799 .49275 L p .52 .476 .747 r
F P
0 g
s
.49266 .39233 m .45992 .41585 L .48038 .42716 L p .719 .736 .864 r
F P
0 g
s
.48038 .42716 m .50304 .39832 L .49266 .39233 L p .719 .736 .864 r
F P
0 g
s
.64597 .52868 m .66041 .56477 L .69854 .5349 L p .484 .42 .71 r
F P
0 g
s
.69854 .5349 m .6808 .502 L .64597 .52868 L p .484 .42 .71 r
F P
0 g
s
.34515 .47759 m .31905 .50965 L .34719 .54585 L p .883 .822 .783 r
F P
0 g
s
.32716 .58541 m .34719 .54585 L .31905 .50965 L p .92 .826 .738 r
F P
0 g
s
.58206 .4255 m .60658 .45797 L .63075 .43945 L p .588 .584 .816 r
F P
0 g
s
.65819 .46981 m .63075 .43945 L .60658 .45797 L p .555 .53 .783 r
F P
0 g
s
.44675 .40151 m .40972 .42296 L .42843 .44316 L p .771 .782 .862 r
F P
0 g
s
.42843 .44316 m .45992 .41585 L .44675 .40151 L p .771 .782 .862 r
F P
0 g
s
.62646 .7012 m .62755 .73614 L .68535 .70076 L p .432 .256 .541 r
F P
0 g
s
.68535 .70076 m .68376 .66852 L .62646 .7012 L p .432 .256 .541 r
F P
0 g
s
.66041 .56477 m .6714 .60036 L .71171 .56772 L p .445 .362 .669 r
F P
0 g
s
.71171 .56772 m .69854 .5349 L .66041 .56477 L p .445 .362 .669 r
F P
0 g
s
.31905 .50965 m .29795 .54399 L .32716 .58541 L p .92 .826 .738 r
F P
0 g
s
.31214 .62619 m .32716 .58541 L .29795 .54399 L p .954 .822 .675 r
F P
0 g
s
.58206 .4255 m .55502 .39665 L .54334 .40126 L p .643 .648 .84 r
F P
0 g
s
.55502 .39665 m .58206 .4255 L .59894 .41225 L p .621 .64 .847 r
F P
0 g
s
.63075 .43945 m .59894 .41225 L .58206 .4255 L p .588 .584 .816 r
F P
0 g
s
.48589 .38462 m .44675 .40151 L .45992 .41585 L p .732 .761 .876 r
F P
0 g
s
.45992 .41585 m .49266 .39233 L .48589 .38462 L p .732 .761 .876 r
F P
0 g
s
.52983 .40308 m .52632 .37269 L .5159 .40203 L closepath p .671 .711 .878 r
F P
0 g
s
.54334 .40126 m .52632 .37269 L .52983 .40308 L closepath p .661 .703 .878 r
F P
0 g
s
.5159 .40203 m .52632 .37269 L .50304 .39832 L closepath p .683 .724 .881 r
F P
0 g
s
.30294 .66695 m .30018 .70631 L .36609 .7477 L p .892 .636 .545 r
F P
0 g
s
.36911 .78412 m .36609 .7477 L .30018 .70631 L p .898 .58 .438 r
F P
0 g
s
.36609 .7477 m .36911 .78412 L .4571 .80252 L p .776 .482 .489 r
F P
0 g
s
.6714 .60036 m .67913 .63501 L .72077 .60003 L p .403 .301 .624 r
F P
0 g
s
.72077 .60003 m .71171 .56772 L .6714 .60036 L p .403 .301 .624 r
F P
0 g
s
.55502 .39665 m .52632 .37269 L .54334 .40126 L closepath p .653 .7 .881 r
F P
0 g
s
.50304 .39832 m .52632 .37269 L .49266 .39233 L closepath p .691 .738 .887 r
F P
0 g
s
.46056 .83168 m .4571 .80252 L .36911 .78412 L p .76 .405 .381 r
F P
0 g
s
.4571 .80252 m .46056 .83168 L .5475 .82379 L p .635 .315 .413 r
F P
0 g
s
.5475 .82379 m .54852 .79532 L .4571 .80252 L p .635 .315 .413 r
F P
0 g
s
.59894 .41225 m .63075 .43945 L .64557 .41458 L p .561 .583 .833 r
F P
0 g
s
.63075 .43945 m .65819 .46981 L .67796 .43864 L p .518 .524 .801 r
F P
0 g
s
.67796 .43864 m .64557 .41458 L .63075 .43945 L p .518 .524 .801 r
F P
0 g
s
.56369 .38958 m .52632 .37269 L .55502 .39665 L closepath p .65 .699 .882 r
F P
0 g
s
.59894 .41225 m .56369 .38958 L .55502 .39665 L p .621 .64 .847 r
F P
0 g
s
.29795 .54399 m .28241 .57991 L .31214 .62619 L p .954 .822 .675 r
F P
0 g
s
.30294 .66695 m .31214 .62619 L .28241 .57991 L p .983 .803 .585 r
F P
0 g
s
.54852 .79532 m .5475 .82379 L .6223 .79672 L p .496 .213 .414 r
F P
0 g
s
.6223 .79672 m .62619 .76823 L .54852 .79532 L p .496 .213 .414 r
F P
0 g
s
.56369 .38958 m .59894 .41225 L .60869 .39492 L p .604 .642 .861 r
F P
0 g
s
.64557 .41458 m .60869 .39492 L .59894 .41225 L p .561 .583 .833 r
F P
0 g
s
.62755 .73614 m .62619 .76823 L .68381 .73156 L p .39 .184 .477 r
F P
0 g
s
.68381 .73156 m .68535 .70076 L .62755 .73614 L p .39 .184 .477 r
F P
0 g
s
.49266 .39233 m .52632 .37269 L .48589 .38462 L closepath p .695 .751 .895 r
F P
0 g
s
.65819 .46981 m .6808 .502 L .70518 .46599 L p .474 .463 .765 r
F P
0 g
s
.70518 .46599 m .67796 .43864 L .65819 .46981 L p .474 .463 .765 r
F P
0 g
s
.67913 .63501 m .68376 .66852 L .72617 .63172 L p .359 .236 .574 r
F P
0 g
s
.72617 .63172 m .72077 .60003 L .67913 .63501 L p .359 .236 .574 r
F P
0 g
s
.44212 .38523 m .40369 .40029 L .40972 .42296 L p .788 .827 .883 r
F P
0 g
s
.40972 .42296 m .44675 .40151 L .44212 .38523 L p .788 .827 .883 r
F P
0 g
s
.37561 .4485 m .40972 .42296 L .40369 .40029 L p .834 .865 .868 r
F P
0 g
s
.48346 .37587 m .44212 .38523 L .44675 .40151 L p .741 .787 .89 r
F P
0 g
s
.44675 .40151 m .48589 .38462 L .48346 .37587 L p .741 .787 .89 r
F P
0 g
s
.56845 .3807 m .52632 .37269 L .56369 .38958 L closepath p .65 .7 .883 r
F P
0 g
s
.60869 .39492 m .56845 .3807 L .56369 .38958 L p .604 .642 .861 r
F P
0 g
s
.6808 .502 m .69854 .5349 L .72701 .49557 L p .429 .399 .724 r
F P
0 g
s
.72701 .49557 m .70518 .46599 L .6808 .502 L p .429 .399 .724 r
F P
0 g
s
.40369 .40029 m .36929 .42034 L .37561 .4485 L p .834 .865 .868 r
F P
0 g
s
.34515 .47759 m .37561 .4485 L .36929 .42034 L p .88 .901 .84 r
F P
0 g
s
.48589 .38462 m .52632 .37269 L .48346 .37587 L closepath p .694 .759 .902 r
F P
0 g
s
.56874 .37092 m .52632 .37269 L .56845 .3807 L closepath p .648 .701 .885 r
F P
0 g
s
.56845 .3807 m .60869 .39492 L .61013 .37509 L p .595 .655 .879 r
F P
0 g
s
.61013 .37509 m .56874 .37092 L .56845 .3807 L p .595 .655 .879 r
F P
0 g
s
.60869 .39492 m .64557 .41458 L .64929 .38504 L p .544 .598 .859 r
F P
0 g
s
.64929 .38504 m .61013 .37509 L .60869 .39492 L p .544 .598 .859 r
F P
0 g
s
.36929 .42034 m .33971 .44452 L .34515 .47759 L p .88 .901 .84 r
F P
0 g
s
.31905 .50965 m .34515 .47759 L .33971 .44452 L p .924 .93 .794 r
F P
0 g
s
.28241 .57991 m .27296 .6166 L .30294 .66695 L p .983 .803 .585 r
F P
0 g
s
.30018 .70631 m .30294 .66695 L .27296 .6166 L p .994 .756 .45 r
F P
0 g
s
.55582 .35338 m .52632 .37269 L .56441 .36141 L closepath p .647 .715 .897 r
F P
0 g
s
.48346 .37587 m .52632 .37269 L .48563 .36686 L closepath p .693 .762 .905 r
F P
0 g
s
.56441 .36141 m .52632 .37269 L .56874 .37092 L closepath p .646 .705 .889 r
F P
0 g
s
.54387 .34794 m .52632 .37269 L .55582 .35338 L closepath p .652 .729 .906 r
F P
0 g
s
.52991 .34579 m .52632 .37269 L .54387 .34794 L closepath p .662 .745 .911 r
F P
0 g
s
.51559 .34711 m .52632 .37269 L .52991 .34579 L closepath p .675 .756 .912 r
F P
0 g
s
.50254 .35157 m .52632 .37269 L .51559 .34711 L closepath p .685 .762 .91 r
F P
0 g
s
.4922 .35845 m .52632 .37269 L .50254 .35157 L closepath p .69 .763 .907 r
F P
0 g
s
.48563 .36686 m .52632 .37269 L .4922 .35845 L closepath p .692 .763 .906 r
F P
0 g
s
.44212 .38523 m .48346 .37587 L .48563 .36686 L p .744 .813 .906 r
F P
0 g
s
.30018 .70631 m .3042 .74281 L .36911 .78412 L p .898 .58 .438 r
F P
0 g
s
.37712 .81469 m .36911 .78412 L .3042 .74281 L p .881 .484 .273 r
F P
0 g
s
.36911 .78412 m .37712 .81469 L .46056 .83168 L p .76 .405 .381 r
F P
0 g
s
.69854 .5349 m .71171 .56772 L .74355 .52649 L p .381 .332 .678 r
F P
0 g
s
.74355 .52649 m .72701 .49557 L .69854 .5349 L p .381 .332 .678 r
F P
0 g
s
.68376 .66852 m .68535 .70076 L .72814 .66287 L p .309 .165 .517 r
F P
0 g
s
.72814 .66287 m .72617 .63172 L .68376 .66852 L p .309 .165 .517 r
F P
0 g
s
.64557 .41458 m .67796 .43864 L .68515 .40045 L p .49 .537 .832 r
F P
0 g
s
.68515 .40045 m .64929 .38504 L .64557 .41458 L p .49 .537 .832 r
F P
0 g
s
.56874 .37092 m .61013 .37509 L .60248 .35512 L p .594 .676 .898 r
F P
0 g
s
.60248 .35512 m .56441 .36141 L .56874 .37092 L p .594 .676 .898 r
F P
0 g
s
.62619 .76823 m .6223 .79672 L .67886 .76056 L p .336 .093 .391 r
F P
0 g
s
.67886 .76056 m .68381 .73156 L .62619 .76823 L p .336 .093 .391 r
F P
0 g
s
.48563 .36686 m .44631 .3681 L .44212 .38523 L p .744 .813 .906 r
F P
0 g
s
.40369 .40029 m .44212 .38523 L .44631 .3681 L p .793 .871 .906 r
F P
0 g
s
.33971 .44452 m .31541 .47194 L .31905 .50965 L p .924 .93 .794 r
F P
0 g
s
.29795 .54399 m .31905 .50965 L .31541 .47194 L p .956 .945 .714 r
F P
0 g
s
.44631 .3681 m .48563 .36686 L .4922 .35845 L p .734 .832 .926 r
F P
0 g
s
.46604 .85353 m .46056 .83168 L .37712 .81469 L p .717 .281 .213 r
F P
0 g
s
.46056 .83168 m .46604 .85353 L .54586 .84598 L p .587 .203 .282 r
F P
0 g
s
.54586 .84598 m .5475 .82379 L .46056 .83168 L p .587 .203 .282 r
F P
0 g
s
.5475 .82379 m .54586 .84598 L .61581 .8208 L p .435 .098 .293 r
F P
0 g
s
.61581 .8208 m .6223 .79672 L .5475 .82379 L p .435 .098 .293 r
F P
0 g
s
.67796 .43864 m .70518 .46599 L .71681 .42079 L p .433 .47 .798 r
F P
0 g
s
.71681 .42079 m .68515 .40045 L .67796 .43864 L p .433 .47 .798 r
F P
0 g
s
.56441 .36141 m .60248 .35512 L .58589 .33798 L p .6 .702 .915 r
F P
0 g
s
.58589 .33798 m .55582 .35338 L .56441 .36141 L p .6 .702 .915 r
F P
0 g
s
.71171 .56772 m .72077 .60003 L .75513 .55817 L p .331 .261 .625 r
F P
0 g
s
.75513 .55817 m .74355 .52649 L .71171 .56772 L p .331 .261 .625 r
F P
0 g
s
.61013 .37509 m .64929 .38504 L .63986 .35422 L p .535 .627 .889 r
F P
0 g
s
.63986 .35422 m .60248 .35512 L .61013 .37509 L p .535 .627 .889 r
F P
0 g
s
.44631 .3681 m .41001 .3762 L .40369 .40029 L p .793 .871 .906 r
F P
0 g
s
.36929 .42034 m .40369 .40029 L .41001 .3762 L p .84 .928 .889 r
F P
0 g
s
.4589 .35139 m .4922 .35845 L .50254 .35157 L p .71 .838 .943 r
F P
0 g
s
.4922 .35845 m .4589 .35139 L .44631 .3681 L p .734 .832 .926 r
F P
0 g
s
.55582 .35338 m .58589 .33798 L .56193 .32653 L p .61 .731 .931 r
F P
0 g
s
.56193 .32653 m .54387 .34794 L .55582 .35338 L p .61 .731 .931 r
F P
0 g
s
.27296 .6166 m .27 .65323 L .30018 .70631 L p .994 .756 .45 r
F P
0 g
s
.3042 .74281 m .30018 .70631 L .27 .65323 L p .961 .653 .24 r
F P
0 g
s
.68535 .70076 m .68381 .73156 L .7266 .69355 L p .252 .081 .445 r
F P
0 g
s
.7266 .69355 m .72814 .66287 L .68535 .70076 L p .252 .081 .445 r
F P
0 g
s
.31541 .47194 m .29653 .50179 L .29795 .54399 L p .956 .945 .714 r
F P
0 g
s
.28241 .57991 m .29795 .54399 L .29653 .50179 L p .96 .924 .581 r
F P
0 g
s
.47894 .33679 m .50254 .35157 L .51559 .34711 L p .678 .825 .954 r
F P
0 g
s
.50254 .35157 m .47894 .33679 L .4589 .35139 L p .71 .838 .943 r
F P
0 g
s
.41001 .3762 m .44631 .3681 L .4589 .35139 L p .776 .905 .931 r
F P
0 g
s
.70518 .46599 m .72701 .49557 L .74358 .44547 L p .372 .395 .755 r
F P
0 g
s
.74358 .44547 m .71681 .42079 L .70518 .46599 L p .372 .395 .755 r
F P
0 g
s
.54387 .34794 m .56193 .32653 L .5336 .32262 L p .625 .764 .946 r
F P
0 g
s
.5336 .32262 m .52991 .34579 L .54387 .34794 L p .625 .764 .946 r
F P
0 g
s
.50473 .32648 m .51559 .34711 L .52991 .34579 L p .648 .797 .954 r
F P
0 g
s
.51559 .34711 m .50473 .32648 L .47894 .33679 L p .678 .825 .954 r
F P
0 g
s
.52991 .34579 m .5336 .32262 L .50473 .32648 L p .648 .797 .954 r
F P
0 g
s
.64929 .38504 m .68515 .40045 L .67573 .3591 L p .467 .568 .874 r
F P
0 g
s
.67573 .3591 m .63986 .35422 L .64929 .38504 L p .467 .568 .874 r
F P
0 g
s
.41001 .3762 m .37801 .3905 L .36929 .42034 L p .84 .928 .889 r
F P
0 g
s
.33971 .44452 m .36929 .42034 L .37801 .3905 L p .877 .975 .842 r
F P
0 g
s
.72077 .60003 m .72617 .63172 L .76207 .59026 L p .276 .183 .565 r
F P
0 g
s
.76207 .59026 m .75513 .55817 L .72077 .60003 L p .276 .183 .565 r
F P
0 g
s
.60248 .35512 m .63986 .35422 L .61629 .32713 L p .535 .669 .923 r
F P
0 g
s
.61629 .32713 m .58589 .33798 L .60248 .35512 L p .535 .669 .923 r
F P
0 g
s
.6223 .79672 m .61581 .8208 L .67008 .78709 L p .258 0 .266 r
F P
0 g
s
.67008 .78709 m .67886 .76056 L .6223 .79672 L p .258 0 .266 r
F P
0 g
s
.3042 .74281 m .31499 .77512 L .37712 .81469 L p .881 .484 .273 r
F P
0 g
s
.38979 .83827 m .37712 .81469 L .31499 .77512 L p .801 .309 .008 r
F P
0 g
s
.37712 .81469 m .38979 .83827 L .46604 .85353 L p .717 .281 .213 r
F P
0 g
s
.29653 .50179 m .28307 .53341 L .28241 .57991 L p .96 .924 .581 r
F P
0 g
s
.27296 .6166 m .28241 .57991 L .28307 .53341 L p .902 .835 .373 r
F P
0 g
s
.72701 .49557 m .74355 .52649 L .76493 .47385 L p .304 .311 .703 r
F P
0 g
s
.76493 .47385 m .74358 .44547 L .72701 .49557 L p .304 .311 .703 r
F P
0 g
s
.4278 .35173 m .4589 .35139 L .47894 .33679 L p .732 .917 .956 r
F P
0 g
s
.4589 .35139 m .4278 .35173 L .41001 .3762 L p .776 .905 .931 r
F P
0 g
s
.68381 .73156 m .67886 .76056 L .72107 .72362 L p .179 0 .347 r
F P
0 g
s
.72107 .72362 m .7266 .69355 L .68381 .73156 L p .179 0 .347 r
F P
0 g
s
.37801 .3905 m .41001 .3762 L .4278 .35173 L p .808 .972 .903 r
F P
0 g
s
.37801 .3905 m .35114 .41002 L .33971 .44452 L p .877 .975 .842 r
F P
0 g
s
.31541 .47194 m .33971 .44452 L .35114 .41002 L p .883 .99 .74 r
F P
0 g
s
.68515 .40045 m .71681 .42079 L .70912 .37014 L p .384 .494 .848 r
F P
0 g
s
.70912 .37014 m .67573 .3591 L .68515 .40045 L p .384 .494 .848 r
F P
0 g
s
.58589 .33798 m .61629 .32713 L .58041 .30919 L p .545 .723 .956 r
F P
0 g
s
.58041 .30919 m .56193 .32653 L .58589 .33798 L p .545 .723 .956 r
F P
0 g
s
.54365 .86121 m .54586 .84598 L .46604 .85353 L p .491 .023 .07 r
F P
0 g
s
.54586 .84598 m .54365 .86121 L .60667 .83961 L p .332 0 .104 r
F P
0 g
s
.60667 .83961 m .61581 .8208 L .54586 .84598 L p .332 0 .104 r
F P
0 g
s
.72617 .63172 m .72814 .66287 L .76453 .62262 L p .212 .094 .494 r
F P
0 g
s
.76453 .62262 m .76207 .59026 L .72617 .63172 L p .212 .094 .494 r
F P
0 g
s
.27 .65323 m .27383 .68887 L .3042 .74281 L p .961 .653 .24 r
F P
0 g
s
.31499 .77512 m .3042 .74281 L .27383 .68887 L p .827 .453 0 r
F P
0 g
s
.47332 .8675 m .46604 .85353 L .38979 .83827 L p .604 .069 0 r
F P
0 g
s
.46604 .85353 m .47332 .8675 L .54365 .86121 L p .491 .023 .07 r
F P
0 g
s
.63986 .35422 m .67573 .3591 L .64652 .3218 L p .447 .62 .925 r
F P
0 g
s
.64652 .3218 m .61629 .32713 L .63986 .35422 L p .447 .62 .925 r
F P
0 g
s
.45628 .32897 m .47894 .33679 L .50473 .32648 L p .67 .896 .978 r
F P
0 g
s
.47894 .33679 m .45628 .32897 L .4278 .35173 L p .732 .917 .956 r
F P
0 g
s
.56193 .32653 m .58041 .30919 L .53735 .30396 L p .569 .786 .981 r
F P
0 g
s
.53735 .30396 m .5336 .32262 L .56193 .32653 L p .569 .786 .981 r
F P
0 g
s
.74355 .52649 m .75513 .55817 L .78048 .50527 L p .227 .215 .636 r
F P
0 g
s
.78048 .50527 m .76493 .47385 L .74355 .52649 L p .227 .215 .636 r
F P
0 g
s
.28307 .53341 m .27495 .56629 L .27296 .6166 L p .902 .835 .373 r
F P
0 g
s
.27 .65323 m .27296 .6166 L .27495 .56629 L p .751 .652 .094 r
F P
0 g
s
.49397 .31158 m .50473 .32648 L .5336 .32262 L p .611 .848 .988 r
F P
0 g
s
.50473 .32648 m .49397 .31158 L .45628 .32897 L p .67 .896 .978 r
F P
0 g
s
.35114 .41002 m .32971 .43367 L .31541 .47194 L p .883 .99 .74 r
F P
0 g
s
.29653 .50179 m .31541 .47194 L .32971 .43367 L p .82 .93 .554 r
F P
0 g
s
.5336 .32262 m .53735 .30396 L .49397 .31158 L p .611 .848 .988 r
F P
0 g
s
.71681 .42079 m .74358 .44547 L .73889 .38758 L p .28 .399 .806 r
F P
0 g
s
.73889 .38758 m .70912 .37014 L .71681 .42079 L p .28 .399 .806 r
F P
0 g
s
.61581 .8208 m .60667 .83961 L .65702 .81014 L p .136 0 .073 r
F P
0 g
s
.65702 .81014 m .67008 .78709 L .61581 .8208 L p .136 0 .073 r
F P
0 g
s
.4278 .35173 m .40005 .35923 L .37801 .3905 L p .808 .972 .903 r
F P
0 g
s
.35114 .41002 m .37801 .3905 L .40005 .35923 L p .8 .999 .807 r
F P
0 g
s
.72814 .66287 m .7266 .69355 L .76235 .65514 L p .132 0 .401 r
F P
0 g
s
.76235 .65514 m .76453 .62262 L .72814 .66287 L p .132 0 .401 r
F P
0 g
s
.67886 .76056 m .67008 .78709 L .71082 .75254 L p .075 0 .203 r
F P
0 g
s
.71082 .75254 m .72107 .72362 L .67886 .76056 L p .075 0 .203 r
F P
0 g
s
.40005 .35923 m .4278 .35173 L .45628 .32897 L p .725 .978 .918 r
F P
0 g
s
.31499 .77512 m .33221 .80207 L .38979 .83827 L p .801 .309 .008 r
F P
0 g
s
.40653 .85422 m .38979 .83827 L .33221 .80207 L p .574 .013 0 r
F P
0 g
s
.38979 .83827 m .40653 .85422 L .47332 .8675 L p .604 .069 0 r
F P
0 g
s
.61629 .32713 m .64652 .3218 L .59905 .29711 L p .439 .697 .974 r
F P
0 g
s
.59905 .29711 m .58041 .30919 L .61629 .32713 L p .439 .697 .974 r
F P
0 g
s
.75513 .55817 m .76207 .59026 L .78993 .53911 L p .136 .101 .551 r
F P
0 g
s
.78993 .53911 m .78048 .50527 L .75513 .55817 L p .136 .101 .551 r
F P
0 g
s
.67573 .3591 m .70912 .37014 L .67574 .32313 L p .319 .543 .912 r
F P
0 g
s
.67574 .32313 m .64652 .3218 L .67573 .3591 L p .319 .543 .912 r
F P
0 g
s
.27383 .68887 m .28462 .72257 L .31499 .77512 L p .827 .453 0 r
F P
0 g
s
.33221 .80207 m .31499 .77512 L .28462 .72257 L p 0 0 .415 r
F P
0 g
s
.32971 .43367 m .3136 .46037 L .29653 .50179 L p .82 .93 .554 r
F P
0 g
s
.28307 .53341 m .29653 .50179 L .3136 .46037 L p .666 .768 .288 r
F P
0 g
s
.27495 .56629 m .27219 .60008 L .27 .65323 L p .751 .652 .094 r
F P
0 g
s
.27383 .68887 m .27 .65323 L .27219 .60008 L p 0 0 .201 r
F P
0 g
s
.74358 .44547 m .76493 .47385 L .76381 .41144 L p .147 .273 .738 r
F P
0 g
s
.76381 .41144 m .73889 .38758 L .74358 .44547 L p .147 .273 .738 r
F P
0 g
s
.54092 .86908 m .54365 .86121 L .47332 .8675 L p .292 0 0 r
F P
0 g
s
.54365 .86121 m .54092 .86908 L .59493 .85225 L p .144 0 0 r
F P
0 g
s
.59493 .85225 m .60667 .83961 L .54365 .86121 L p .144 0 0 r
F P
0 g
s
.4353 .32841 m .45628 .32897 L .49397 .31158 L p .614 .943 .945 r
F P
0 g
s
.45628 .32897 m .4353 .32841 L .40005 .35923 L p .725 .978 .918 r
F P
0 g
s
.7266 .69355 m .72107 .72362 L .75505 .68759 L p .024 0 .271 r
F P
0 g
s
.75505 .68759 m .76235 .65514 L .7266 .69355 L p .024 0 .271 r
F P
0 g
s
.40005 .35923 m .37645 .37318 L .35114 .41002 L p .8 .999 .807 r
F P
0 g
s
.32971 .43367 m .35114 .41002 L .37645 .37318 L p .709 .928 .602 r
F P
0 g
s
.48208 .87348 m .47332 .8675 L .40653 .85422 L p .341 0 0 r
F P
0 g
s
.47332 .8675 m .48208 .87348 L .54092 .86908 L p .292 0 0 r
F P
0 g
s
.58041 .30919 m .59905 .29711 L .54109 .29092 L p .458 .79 .999 r
F P
0 g
s
.54109 .29092 m .53735 .30396 L .58041 .30919 L p .458 .79 .999 r
F P
0 g
s
.67008 .78709 m .65702 .81014 L .69499 .77933 L p 0 0 0 r
F P
0 g
s
.69499 .77933 m .71082 .75254 L .67008 .78709 L p 0 0 0 r
F P
0 g
s
.76207 .59026 m .76453 .62262 L .79301 .57475 L p .023 0 .438 r
F P
0 g
s
.79301 .57475 m .78993 .53911 L .76207 .59026 L p .023 0 .438 r
F P
0 g
s
.37645 .37318 m .40005 .35923 L .4353 .32841 L p .639 .954 .76 r
F P
0 g
s
.48357 .30321 m .49397 .31158 L .53735 .30396 L p .517 .877 .983 r
F P
0 g
s
.49397 .31158 m .48357 .30321 L .4353 .32841 L p .614 .943 .945 r
F P
0 g
s
.60667 .83961 m .59493 .85225 L .63933 .8284 L p 0 0 0 r
F P
0 g
s
.63933 .8284 m .65702 .81014 L .60667 .83961 L p 0 0 0 r
F P
0 g
s
.53735 .30396 m .54109 .29092 L .48357 .30321 L p .517 .877 .983 r
F P
0 g
s
.3136 .46037 m .3024 .48931 L .28307 .53341 L p .666 .768 .288 r
F P
0 g
s
.27495 .56629 m .28307 .53341 L .3024 .48931 L p 0 0 0 r
F P
0 g
s
.70912 .37014 m .73889 .38758 L .70277 .3323 L p .121 .413 .86 r
F P
0 g
s
.70277 .3323 m .67574 .32313 L .70912 .37014 L p .121 .413 .86 r
F P
0 g
s
.76493 .47385 m .78048 .50527 L .78265 .44143 L p 0 .103 .627 r
F P
0 g
s
.78265 .44143 m .76381 .41144 L .76493 .47385 L p 0 .103 .627 r
F P
0 g
s
.27219 .60008 m .27502 .63443 L .27383 .68887 L p 0 0 .201 r
F P
0 g
s
.28462 .72257 m .27383 .68887 L .27502 .63443 L p 0 0 .446 r
F P
0 g
s
.64652 .3218 m .67574 .32313 L .61735 .29182 L p .249 .623 .958 r
F P
0 g
s
.61735 .29182 m .59905 .29711 L .64652 .3218 L p .249 .623 .958 r
F P
0 g
s
.33221 .80207 m .35523 .82284 L .40653 .85422 L p .574 .013 0 r
F P
0 g
s
.40653 .85422 m .42659 .8624 L .48208 .87348 L p .341 0 0 r
F P
0 g
s
.42659 .8624 m .40653 .85422 L .35523 .82284 L p 0 .333 .746 r
F P
0 g
s
.72107 .72362 m .71082 .75254 L .74192 .71944 L p 0 0 .08 r
F P
0 g
s
.74192 .71944 m .75505 .68759 L .72107 .72362 L p 0 0 .08 r
F P
0 g
s
.28462 .72257 m .30236 .75334 L .33221 .80207 L p 0 0 .415 r
F P
0 g
s
.35523 .82284 m .33221 .80207 L .30236 .75334 L p 0 .154 .692 r
F P
0 g
s
.37645 .37318 m .35739 .39262 L .32971 .43367 L p .709 .928 .602 r
F P
0 g
s
.3136 .46037 m .32971 .43367 L .35739 .39262 L p 0 0 0 r
F P
0 g
s
.76453 .62262 m .76235 .65514 L .78941 .61152 L p 0 0 .282 r
F P
0 g
s
.78941 .61152 m .79301 .57475 L .76453 .62262 L p 0 0 .282 r
F P
0 g
s
.41664 .3351 m .4353 .32841 L .48357 .30321 L p .446 .871 .757 r
F P
0 g
s
.4353 .32841 m .41664 .3351 L .37645 .37318 L p .639 .954 .76 r
F P
0 g
s
.3024 .48931 m .29569 .52 L .27495 .56629 L p 0 0 0 r
F P
0 g
s
.27219 .60008 m .27495 .56629 L .29569 .52 L p 0 0 .226 r
F P
0 g
s
.65702 .81014 m .63933 .8284 L .67288 .80256 L p 0 0 0 r
F P
0 g
s
.67288 .80256 m .69499 .77933 L .65702 .81014 L p 0 0 0 r
F P
0 g
s
.35739 .39262 m .37645 .37318 L .41664 .3351 L p 0 0 0 r
F P
0 g
s
.53774 .86946 m .54092 .86908 L .48208 .87348 L p 0 0 0 r
F P
0 g
s
.5807 .85786 m .59493 .85225 L .54092 .86908 L p 0 0 0 r
F P
0 g
s
.54092 .86908 m .53774 .86946 L .5807 .85786 L p 0 0 0 r
F P
0 g
s
.78048 .50527 m .78993 .53911 L .79427 .47688 L p 0 0 .452 r
F P
0 g
s
.79427 .47688 m .78265 .44143 L .78048 .50527 L p 0 0 .452 r
F P
0 g
s
.49201 .87182 m .48208 .87348 L .42659 .8624 L p .046 .591 .842 r
F P
0 g
s
.48208 .87348 m .49201 .87182 L .53774 .86946 L p 0 0 0 r
F P
0 g
s
.59905 .29711 m .61735 .29182 L .54472 .28491 L p .223 .712 .925 r
F P
0 g
s
.54109 .29092 m .59905 .29711 L p .54804 .28565 L .223 .712 .925 r
F P
0 g
s
.63452 .29502 m .61735 .29182 L .67574 .32313 L p 0 .426 .815 r
F P
0 g
s
.63452 .29502 m .54809 .28741 L p .61194 .29148 L .169 0 0 r
F P
0 g
s
.61735 .29182 m .61891 .29211 L p .61194 .29148 L .169 0 0 r
F P
0 g
s
.61891 .29211 m .63452 .29502 L p .61194 .29148 L .169 0 0 r
F P
0 g
s
.54472 .28491 m .54447 .28533 L p .54804 .28565 L .223 .712 .925 r
F P
0 g
s
.54447 .28533 m .54109 .29092 L p .54804 .28565 L .223 .712 .925 r
F P
0 g
s
.27502 .63443 m .28382 .6689 L .28462 .72257 L p 0 0 .446 r
F P
0 g
s
.30236 .75334 m .28462 .72257 L .28382 .6689 L p 0 .085 .62 r
F P
0 g
s
.73889 .38758 m .76381 .41144 L .72614 .35021 L p 0 .188 .718 r
F P
0 g
s
.72614 .35021 m .70277 .3323 L .73889 .38758 L p 0 .188 .718 r
F P
0 g
s
.71082 .75254 m .69499 .77933 L .7222 .74977 L p 0 0 0 r
F P
0 g
s
.7222 .74977 m .74192 .71944 L .71082 .75254 L p 0 0 0 r
F P
0 g
s
.35739 .39262 m .34289 .41651 L .3136 .46037 L p 0 0 0 r
F P
0 g
s
.3024 .48931 m .3136 .46037 L .34289 .41651 L p 0 0 0 r
F P
0 g
s
.59493 .85225 m .5807 .85786 L .61689 .84041 L p .336 .783 .625 r
F P
0 g
s
.61689 .84041 m .63933 .8284 L .59493 .85225 L p .336 .783 .625 r
F P
0 g
s
.47382 .30217 m .48357 .30321 L .54109 .29092 L p .291 .79 .826 r
F P
0 g
s
.48357 .30321 m .47382 .30217 L .41664 .3351 L p .446 .871 .757 r
F P
0 g
s
.76235 .65514 m .75505 .68759 L .77887 .64867 L p 0 0 .067 r
F P
0 g
s
.77887 .64867 m .78941 .61152 L .76235 .65514 L p 0 0 .067 r
F P
0 g
s
.54109 .29092 m .54472 .28491 L .47382 .30217 L p .291 .79 .826 r
F P
0 g
s
.30236 .75334 m .32685 .78019 L .35523 .82284 L p 0 .154 .692 r
F P
0 g
s
.3832 .83694 m .35523 .82284 L .32685 .78019 L p .066 .382 .845 r
F P
0 g
s
.35523 .82284 m .3832 .83694 L .42659 .8624 L p 0 .333 .746 r
F P
0 g
s
.67574 .32313 m .70277 .3323 L .63452 .29502 L p 0 .426 .815 r
F P
0 g
s
.29569 .52 m .29324 .55227 L .27219 .60008 L p 0 0 .226 r
F P
0 g
s
.27502 .63443 m .27219 .60008 L .29324 .55227 L p 0 0 .402 r
F P
0 g
s
.4492 .86313 m .42659 .8624 L .3832 .83694 L p .148 .566 .929 r
F P
0 g
s
.42659 .8624 m .4492 .86313 L .49201 .87182 L p .046 .591 .842 r
F P
0 g
s
.78993 .53911 m .79301 .57475 L .79784 .51675 L p 0 0 .197 r
F P
0 g
s
.79784 .51675 m .79427 .47688 L .78993 .53911 L p 0 0 .197 r
F P
0 g
s
.41664 .3351 m .40081 .34873 L .35739 .39262 L p 0 0 0 r
F P
0 g
s
.34289 .41651 m .35739 .39262 L .40081 .34873 L p 0 0 0 r
F P
0 g
s
.40081 .34873 m .41664 .3351 L .47382 .30217 L p 0 0 0 r
F P
0 g
s
.34289 .41651 m .33271 .44395 L .3024 .48931 L p 0 0 0 r
F P
0 g
s
.29569 .52 m .3024 .48931 L .33271 .44395 L p 0 0 .178 r
F P
0 g
s
.63933 .8284 m .61689 .84041 L .64421 .82048 L p .528 .896 .698 r
F P
0 g
s
.64421 .82048 m .67288 .80256 L .63933 .8284 L p .528 .896 .698 r
F P
0 g
s
.28382 .6689 m .29912 .70282 L .30236 .75334 L p 0 .085 .62 r
F P
0 g
s
.32685 .78019 m .30236 .75334 L .29912 .70282 L p .109 .259 .737 r
F P
0 g
s
.75505 .68759 m .74192 .71944 L .76116 .6853 L p 0 0 0 r
F P
0 g
s
.76116 .6853 m .77887 .64867 L .75505 .68759 L p 0 0 0 r
F P
0 g
s
.69499 .77933 m .67288 .80256 L .69532 .77723 L p .548 .846 .526 r
F P
0 g
s
.69532 .77723 m .7222 .74977 L .69499 .77933 L p .548 .846 .526 r
F P
0 g
s
.76381 .41144 m .78265 .44143 L .74424 .37726 L p 0 0 .419 r
F P
0 g
s
.74424 .37726 m .72614 .35021 L .76381 .41144 L p 0 0 .419 r
F P
0 g
s
.29324 .55227 m .29519 .58611 L .27502 .63443 L p 0 0 .402 r
F P
0 g
s
.28382 .6689 m .27502 .63443 L .29519 .58611 L p .056 .051 .533 r
F P
0 g
s
.5342 .86237 m .53774 .86946 L .49201 .87182 L p .366 .81 .952 r
F P
0 g
s
.53774 .86946 m .5342 .86237 L .56424 .8557 L p .444 .874 .917 r
F P
0 g
s
.56424 .8557 m .5807 .85786 L .53774 .86946 L p .444 .874 .917 r
F P
0 g
s
.50283 .86306 m .49201 .87182 L .4492 .86313 L p .345 .745 .983 r
F P
0 g
s
.49201 .87182 m .50283 .86306 L .5342 .86237 L p .366 .81 .952 r
F P
0 g
s
.54809 .28741 m .54472 .28491 L .61735 .29182 L p .169 0 0 r
F P
0 g
s
.5807 .85786 m .56424 .8557 L .59 .84473 L p .554 .93 .906 r
F P
0 g
s
.59 .84473 m .61689 .84041 L .5807 .85786 L p .554 .93 .906 r
F P
0 g
s
.32685 .78019 m .35764 .80216 L .3832 .83694 L p .066 .382 .845 r
F P
0 g
s
.41517 .84422 m .3832 .83694 L .35764 .80216 L p .269 .53 .914 r
F P
0 g
s
.3832 .83694 m .41517 .84422 L .4492 .86313 L p .148 .566 .929 r
F P
0 g
s
.79301 .57475 m .78941 .61152 L .79289 .55962 L p .739 .664 .11 r
F P
0 g
s
.79289 .55962 m .79784 .51675 L .79301 .57475 L p .739 .664 .11 r
F P
0 g
s
.4651 .30916 m .47382 .30217 L .54472 .28491 L p .055 0 0 r
F P
0 g
s
.47382 .30217 m .4651 .30916 L .40081 .34873 L p 0 0 0 r
F P
0 g
s
.33271 .44395 m .32659 .47432 L .29569 .52 L p 0 0 .178 r
F P
0 g
s
.29324 .55227 m .29569 .52 L .32659 .47432 L p 0 0 .334 r
F P
0 g
s
.70277 .3323 m .72614 .35021 L .64954 .30819 L p .514 0 0 r
F P
0 g
s
.64954 .30819 m .63452 .29502 L .70277 .3323 L p .514 0 0 r
F P
0 g
s
.40081 .34873 m .38815 .36881 L .34289 .41651 L p 0 0 0 r
F P
0 g
s
.33271 .44395 m .34289 .41651 L .38815 .36881 L p 0 0 .116 r
F P
0 g
s
.74192 .71944 m .7222 .74977 L .73623 .72032 L p .69 .883 .504 r
F P
0 g
s
.73623 .72032 m .76116 .6853 L .74192 .71944 L p .69 .883 .504 r
F P
0 g
s
.54472 .28491 m .54809 .28741 L .4651 .30916 L p .055 0 0 r
F P
0 g
s
.47367 .857 m .4492 .86313 L .41517 .84422 L p .37 .68 .978 r
F P
0 g
s
.4492 .86313 m .47367 .857 L .50283 .86306 L p .345 .745 .983 r
F P
0 g
s
.29912 .70282 m .3214 .73525 L .32685 .78019 L p .109 .259 .737 r
F P
0 g
s
.35764 .80216 m .32685 .78019 L .3214 .73525 L p .246 .395 .815 r
F P
0 g
s
.67288 .80256 m .64421 .82048 L .66125 .80021 L p .689 .976 .794 r
F P
0 g
s
.66125 .80021 m .69532 .77723 L .67288 .80256 L p .689 .976 .794 r
F P
0 g
s
.29519 .58611 m .30209 .62147 L .28382 .6689 L p .056 .051 .533 r
F P
0 g
s
.29912 .70282 m .28382 .6689 L .30209 .62147 L p .166 .184 .634 r
F P
0 g
s
.38815 .36881 m .40081 .34873 L .4651 .30916 L p .078 0 0 r
F P
0 g
s
.61689 .84041 m .59 .84473 L .60933 .83132 L p .654 .965 .915 r
F P
0 g
s
.60933 .83132 m .64421 .82048 L .61689 .84041 L p .654 .965 .915 r
F P
0 g
s
.78265 .44143 m .79427 .47688 L .75556 .41311 L p .851 .47 0 r
F P
0 g
s
.75556 .41311 m .74424 .37726 L .78265 .44143 L p .851 .47 0 r
F P
0 g
s
.78941 .61152 m .77887 .64867 L .77942 .60385 L p .884 .852 .397 r
F P
0 g
s
.77942 .60385 m .79289 .55962 L .78941 .61152 L p .884 .852 .397 r
F P
0 g
s
.32659 .47432 m .32439 .50732 L .29324 .55227 L p 0 0 .334 r
F P
0 g
s
.29519 .58611 m .29324 .55227 L .32439 .50732 L p .093 .005 .453 r
F P
0 g
s
.7222 .74977 m .69532 .77723 L .70431 .75247 L p .787 .986 .735 r
F P
0 g
s
.70431 .75247 m .73623 .72032 L .7222 .74977 L p .787 .986 .735 r
F P
0 g
s
.35764 .80216 m .39404 .81839 L .41517 .84422 L p .269 .53 .914 r
F P
0 g
s
.45021 .84475 m .41517 .84422 L .39404 .81839 L p .411 .627 .942 r
F P
0 g
s
.41517 .84422 m .45021 .84475 L .47367 .857 L p .37 .68 .978 r
F P
0 g
s
.38815 .36881 m .37891 .39478 L .33271 .44395 L p 0 0 .116 r
F P
0 g
s
.32659 .47432 m .33271 .44395 L .37891 .39478 L p .085 0 .287 r
F P
0 g
s
.53037 .84797 m .5342 .86237 L .50283 .86306 L p .539 .835 .999 r
F P
0 g
s
.5342 .86237 m .53037 .84797 L .54593 .84528 L p .586 .877 .993 r
F P
0 g
s
.54593 .84528 m .56424 .8557 L .5342 .86237 L p .586 .877 .993 r
F P
0 g
s
.30209 .62147 m .31477 .65803 L .29912 .70282 L p .166 .184 .634 r
F P
0 g
s
.3214 .73525 m .29912 .70282 L .31477 .65803 L p .259 .299 .714 r
F P
0 g
s
.3214 .73525 m .35087 .7649 L .35764 .80216 L p .246 .395 .815 r
F P
0 g
s
.39404 .81839 m .35764 .80216 L .35087 .7649 L p .357 .503 .868 r
F P
0 g
s
.51431 .8478 m .50283 .86306 L .47367 .857 L p .51 .784 .994 r
F P
0 g
s
.50283 .86306 m .51431 .8478 L .53037 .84797 L p .539 .835 .999 r
F P
0 g
s
.56424 .8557 m .54593 .84528 L .55939 .84025 L p .637 .902 .984 r
F P
0 g
s
.55939 .84025 m .59 .84473 L .56424 .8557 L p .637 .902 .984 r
F P
0 g
s
.64421 .82048 m .60933 .83132 L .62063 .81698 L p .725 .972 .929 r
F P
0 g
s
.62063 .81698 m .66125 .80021 L .64421 .82048 L p .725 .972 .929 r
F P
0 g
s
.63452 .29502 m .64954 .30819 L .55101 .29976 L p .499 0 0 r
F P
0 g
s
.55101 .29976 m .54809 .28741 L .63452 .29502 L p .499 0 0 r
F P
0 g
s
.45777 .32464 m .4651 .30916 L .54809 .28741 L p .324 0 0 r
F P
0 g
s
.4651 .30916 m .45777 .32464 L .38815 .36881 L p .078 0 0 r
F P
0 g
s
.72614 .35021 m .74424 .37726 L .66129 .33228 L p .774 .274 .01 r
F P
0 g
s
.66129 .33228 m .64954 .30819 L .72614 .35021 L p .774 .274 .01 r
F P
0 g
s
.77887 .64867 m .76116 .6853 L .75792 .6477 L p .935 .945 .609 r
F P
0 g
s
.75792 .6477 m .77942 .60385 L .77887 .64867 L p .935 .945 .609 r
F P
0 g
s
.32439 .50732 m .32625 .54284 L .29519 .58611 L p .093 .005 .453 r
F P
0 g
s
.30209 .62147 m .29519 .58611 L .32625 .54284 L p .186 .124 .549 r
F P
0 g
s
.49948 .84463 m .47367 .857 L .45021 .84475 L p .505 .734 .976 r
F P
0 g
s
.47367 .857 m .49948 .84463 L .51431 .8478 L p .51 .784 .994 r
F P
0 g
s
.79427 .47688 m .79784 .51675 L .75895 .45653 L p .973 .671 .293 r
F P
0 g
s
.75895 .45653 m .75556 .41311 L .79427 .47688 L p .973 .671 .293 r
F P
0 g
s
.37891 .39478 m .38815 .36881 L .45777 .32464 L p .237 0 .208 r
F P
0 g
s
.59 .84473 m .55939 .84025 L .5694 .83358 L p .675 .909 .976 r
F P
0 g
s
.5694 .83358 m .60933 .83132 L .59 .84473 L p .675 .909 .976 r
F P
0 g
s
.69532 .77723 m .66125 .80021 L .66604 .78038 L p .801 .994 .87 r
F P
0 g
s
.66604 .78038 m .70431 .75247 L .69532 .77723 L p .801 .994 .87 r
F P
0 g
s
.54809 .28741 m .55101 .29976 L .45777 .32464 L p .324 0 0 r
F P
0 g
s
.31477 .65803 m .33409 .69498 L .3214 .73525 L p .259 .299 .714 r
F P
0 g
s
.35087 .7649 m .3214 .73525 L .33409 .69498 L p .34 .4 .778 r
F P
0 g
s
.37891 .39478 m .37328 .42601 L .32659 .47432 L p .085 0 .287 r
F P
0 g
s
.32439 .50732 m .32659 .47432 L .37328 .42601 L p .179 .016 .408 r
F P
0 g
s
.35087 .7649 m .3873 .79028 L .39404 .81839 L p .357 .503 .868 r
F P
0 g
s
.43512 .82816 m .39404 .81839 L .3873 .79028 L p .449 .593 .903 r
F P
0 g
s
.39404 .81839 m .43512 .82816 L .45021 .84475 L p .411 .627 .942 r
F P
0 g
s
.4875 .83875 m .45021 .84475 L .43512 .82816 L p .514 .695 .95 r
F P
0 g
s
.45021 .84475 m .4875 .83875 L .49948 .84463 L p .505 .734 .976 r
F P
0 g
s
.32625 .54284 m .33262 .58082 L .30209 .62147 L p .186 .124 .549 r
F P
0 g
s
.31477 .65803 m .30209 .62147 L .33262 .58082 L p .267 .23 .63 r
F P
0 g
s
.76116 .6853 m .73623 .72032 L .72933 .68949 L p .927 .972 .748 r
F P
0 g
s
.72933 .68949 m .75792 .6477 L .76116 .6853 L p .927 .972 .748 r
F P
0 g
s
.60933 .83132 m .5694 .83358 L .57493 .82604 L p .701 .904 .968 r
F P
0 g
s
.57493 .82604 m .62063 .81698 L .60933 .83132 L p .701 .904 .968 r
F P
0 g
s
.66125 .80021 m .62063 .81698 L .62252 .80271 L p .769 .951 .935 r
F P
0 g
s
.62252 .80271 m .66604 .78038 L .66125 .80021 L p .769 .951 .935 r
F P
0 g
s
.33409 .69498 m .36064 .73097 L .35087 .7649 L p .34 .4 .778 r
F P
0 g
s
.3873 .79028 m .35087 .7649 L .36064 .73097 L p .413 .492 .831 r
F P
0 g
s
.79784 .51675 m .79289 .55962 L .75389 .50548 L p .992 .768 .499 r
F P
0 g
s
.75389 .50548 m .75895 .45653 L .79784 .51675 L p .992 .768 .499 r
F P
0 g
s
.52632 .82641 m .53037 .84797 L .51431 .8478 L closepath p .616 .802 .971 r
F P
0 g
s
.52632 .82641 m .54593 .84528 L .53037 .84797 L closepath p .634 .815 .97 r
F P
0 g
s
.52632 .82641 m .51431 .8478 L .49948 .84463 L closepath p .6 .783 .968 r
F P
0 g
s
.52632 .82641 m .55939 .84025 L .54593 .84528 L closepath p .647 .82 .966 r
F P
0 g
s
.37328 .42601 m .37141 .46193 L .32439 .50732 L p .179 .016 .408 r
F P
0 g
s
.32625 .54284 m .32439 .50732 L .37141 .46193 L p .255 .124 .502 r
F P
0 g
s
.52632 .82641 m .49948 .84463 L .4875 .83875 L closepath p .594 .762 .959 r
F P
0 g
s
.3873 .79028 m .42981 .80983 L .43512 .82816 L p .449 .593 .903 r
F P
0 g
s
.47967 .83093 m .43512 .82816 L .42981 .80983 L p .529 .669 .927 r
F P
0 g
s
.43512 .82816 m .47967 .83093 L .4875 .83875 L p .514 .695 .95 r
F P
0 g
s
.45777 .32464 m .45221 .34877 L .37891 .39478 L p .237 0 .208 r
F P
0 g
s
.37328 .42601 m .37891 .39478 L .45221 .34877 L p .335 .076 .365 r
F P
0 g
s
.74424 .37726 m .75556 .41311 L .66869 .36729 L p .858 .465 .298 r
F P
0 g
s
.66869 .36729 m .66129 .33228 L .74424 .37726 L p .858 .465 .298 r
F P
0 g
s
.52632 .82641 m .5694 .83358 L .55939 .84025 L closepath p .652 .82 .964 r
F P
0 g
s
.73623 .72032 m .70431 .75247 L .69488 .72775 L p .89 .963 .835 r
F P
0 g
s
.69488 .72775 m .72933 .68949 L .73623 .72032 L p .89 .963 .835 r
F P
0 g
s
.33262 .58082 m .34414 .62092 L .31477 .65803 L p .267 .23 .63 r
F P
0 g
s
.33409 .69498 m .31477 .65803 L .34414 .62092 L p .338 .326 .698 r
F P
0 g
s
.45221 .34877 m .45777 .32464 L .55101 .29976 L p .467 .09 .239 r
F P
0 g
s
.64954 .30819 m .66129 .33228 L .55328 .32279 L p .649 .211 .197 r
F P
0 g
s
.55328 .32279 m .55101 .29976 L .64954 .30819 L p .649 .211 .197 r
F P
0 g
s
.52632 .82641 m .4875 .83875 L .47967 .83093 L closepath p .595 .746 .949 r
F P
0 g
s
.36064 .73097 m .39441 .76415 L .3873 .79028 L p .413 .492 .831 r
F P
0 g
s
.42981 .80983 m .3873 .79028 L .39441 .76415 L p .48 .576 .874 r
F P
0 g
s
.62063 .81698 m .57493 .82604 L .57531 .81833 L p .717 .888 .959 r
F P
0 g
s
.57531 .81833 m .62252 .80271 L .62063 .81698 L p .717 .888 .959 r
F P
0 g
s
.52632 .82641 m .57493 .82604 L .5694 .83358 L closepath p .654 .82 .963 r
F P
0 g
s
.70431 .75247 m .66604 .78038 L .65595 .76129 L p .84 .937 .89 r
F P
0 g
s
.65595 .76129 m .69488 .72775 L .70431 .75247 L p .84 .937 .89 r
F P
0 g
s
.42981 .80983 m .47685 .82218 L .47967 .83093 L p .529 .669 .927 r
F P
0 g
s
.52632 .82641 m .47967 .83093 L .47685 .82218 L closepath p .6 .737 .94 r
F P
0 g
s
.79289 .55962 m .77942 .60385 L .74057 .55735 L p .971 .814 .629 r
F P
0 g
s
.74057 .55735 m .75389 .50548 L .79289 .55962 L p .971 .814 .629 r
F P
0 g
s
.37141 .46193 m .37349 .50194 L .32625 .54284 L p .255 .124 .502 r
F P
0 g
s
.33262 .58082 m .32625 .54284 L .37349 .50194 L p .321 .217 .578 r
F P
0 g
s
.55101 .29976 m .55328 .32279 L .45221 .34877 L p .467 .09 .239 r
F P
0 g
s
.34414 .62092 m .36146 .66234 L .33409 .69498 L p .338 .326 .698 r
F P
0 g
s
.36064 .73097 m .33409 .69498 L .36146 .66234 L p .402 .413 .757 r
F P
0 g
s
.39441 .76415 m .43455 .79238 L .42981 .80983 L p .48 .576 .874 r
F P
0 g
s
.47685 .82218 m .42981 .80983 L .43455 .79238 L p .544 .656 .909 r
F P
0 g
s
.52632 .82641 m .57531 .81833 L .57493 .82604 L closepath p .657 .818 .961 r
F P
0 g
s
.66604 .78038 m .62252 .80271 L .61399 .78926 L p .785 .901 .924 r
F P
0 g
s
.61399 .78926 m .65595 .76129 L .66604 .78038 L p .785 .901 .924 r
F P
0 g
s
.45221 .34877 m .44876 .38123 L .37328 .42601 L p .335 .076 .365 r
F P
0 g
s
.37141 .46193 m .37328 .42601 L .44876 .38123 L p .4 .188 .472 r
F P
0 g
s
.43455 .79238 m .47932 .81365 L .47685 .82218 L p .544 .656 .909 r
F P
0 g
s
.52632 .82641 m .47685 .82218 L .47932 .81365 L closepath p .605 .734 .936 r
F P
0 g
s
.52632 .82641 m .56047 .80493 L .57036 .81109 L closepath p .664 .798 .946 r
F P
0 g
s
.52632 .82641 m .54664 .80043 L .56047 .80493 L closepath p .659 .779 .937 r
F P
0 g
s
.52632 .82641 m .53048 .79809 L .54664 .80043 L closepath p .647 .759 .931 r
F P
0 g
s
.52632 .82641 m .5139 .79826 L .53048 .79809 L closepath p .631 .744 .929 r
F P
0 g
s
.52632 .82641 m .49882 .80106 L .5139 .79826 L closepath p .617 .737 .931 r
F P
0 g
s
.52632 .82641 m .48689 .80635 L .49882 .80106 L closepath p .609 .734 .934 r
F P
0 g
s
.52632 .82641 m .47932 .81365 L .48689 .80635 L closepath p .606 .734 .935 r
F P
0 g
s
.52632 .82641 m .57036 .81109 L .57531 .81833 L closepath p .662 .812 .955 r
F P
0 g
s
.36146 .66234 m .38493 .70367 L .36064 .73097 L p .402 .413 .757 r
F P
0 g
s
.39441 .76415 m .36064 .73097 L .38493 .70367 L p .458 .495 .809 r
F P
0 g
s
.62252 .80271 m .57531 .81833 L .57036 .81109 L p .726 .859 .944 r
F P
0 g
s
.57036 .81109 m .61399 .78926 L .62252 .80271 L p .726 .859 .944 r
F P
0 g
s
.75556 .41311 m .75895 .45653 L .6709 .4121 L p .872 .567 .468 r
F P
0 g
s
.6709 .4121 m .66869 .36729 L .75556 .41311 L p .872 .567 .468 r
F P
0 g
s
.37349 .50194 m .3797 .5453 L .33262 .58082 L p .321 .217 .578 r
F P
0 g
s
.34414 .62092 m .33262 .58082 L .3797 .5453 L p .378 .301 .643 r
F P
0 g
s
.77942 .60385 m .75792 .6477 L .71993 .60935 L p .938 .835 .716 r
F P
0 g
s
.71993 .60935 m .74057 .55735 L .77942 .60385 L p .938 .835 .716 r
F P
0 g
s
.38493 .70367 m .41437 .74297 L .39441 .76415 L p .458 .495 .809 r
F P
0 g
s
.43455 .79238 m .39441 .76415 L .41437 .74297 L p .51 .573 .855 r
F P
0 g
s
.44888 .77794 m .48689 .80635 L .47932 .81365 L p .559 .652 .897 r
F P
0 g
s
.47932 .81365 m .43455 .79238 L .44888 .77794 L p .559 .652 .897 r
F P
0 g
s
.44876 .38123 m .45221 .34877 L .55328 .32279 L p .54 .235 .399 r
F P
0 g
s
.41437 .74297 m .44888 .77794 L .43455 .79238 L p .51 .573 .855 r
F P
0 g
s
.61399 .78926 m .57036 .81109 L .56047 .80493 L p .722 .819 .925 r
F P
0 g
s
.66129 .33228 m .66869 .36729 L .5547 .35651 L p .706 .359 .387 r
F P
0 g
s
.5547 .35651 m .55328 .32279 L .66129 .33228 L p .706 .359 .387 r
F P
0 g
s
.47178 .76789 m .49882 .80106 L .48689 .80635 L p .58 .656 .889 r
F P
0 g
s
.48689 .80635 m .44888 .77794 L .47178 .76789 L p .58 .656 .889 r
F P
0 g
s
.75792 .6477 m .72933 .68949 L .6934 .65894 L p .9 .844 .78 r
F P
0 g
s
.6934 .65894 m .71993 .60935 L .75792 .6477 L p .9 .844 .78 r
F P
0 g
s
.3797 .5453 m .39019 .59108 L .34414 .62092 L p .378 .301 .643 r
F P
0 g
s
.36146 .66234 m .34414 .62092 L .39019 .59108 L p .429 .378 .7 r
F P
0 g
s
.44876 .38123 m .44769 .4212 L .37141 .46193 L p .4 .188 .472 r
F P
0 g
s
.37349 .50194 m .37141 .46193 L .44769 .4212 L p .447 .273 .55 r
F P
0 g
s
.56047 .80493 m .59506 .77747 L .61399 .78926 L p .722 .819 .925 r
F P
0 g
s
.59506 .77747 m .56047 .80493 L .54664 .80043 L p .704 .774 .906 r
F P
0 g
s
.65595 .76129 m .61399 .78926 L .59506 .77747 L p .772 .833 .899 r
F P
0 g
s
.50142 .76295 m .5139 .79826 L .49882 .80106 L p .609 .67 .884 r
F P
0 g
s
.49882 .80106 m .47178 .76789 L .50142 .76295 L p .609 .67 .884 r
F P
0 g
s
.72933 .68949 m .69488 .72775 L .6627 .70419 L p .86 .846 .829 r
F P
0 g
s
.6627 .70419 m .6934 .65894 L .72933 .68949 L p .86 .846 .829 r
F P
0 g
s
.55328 .32279 m .5547 .35651 L .44876 .38123 L p .54 .235 .399 r
F P
0 g
s
.54664 .80043 m .56746 .76841 L .59506 .77747 L p .704 .774 .906 r
F P
0 g
s
.56746 .76841 m .54664 .80043 L .53048 .79809 L p .676 .731 .892 r
F P
0 g
s
.39019 .59108 m .405 .63799 L .36146 .66234 L p .429 .378 .7 r
F P
0 g
s
.38493 .70367 m .36146 .66234 L .405 .63799 L p .473 .449 .751 r
F P
0 g
s
.44645 .72837 m .47178 .76789 L .44888 .77794 L p .548 .585 .844 r
F P
0 g
s
.44888 .77794 m .41437 .74297 L .44645 .72837 L p .548 .585 .844 r
F P
0 g
s
.69488 .72775 m .65595 .76129 L .62947 .74387 L p .818 .842 .868 r
F P
0 g
s
.59506 .77747 m .62947 .74387 L .65595 .76129 L p .772 .833 .899 r
F P
0 g
s
.53473 .76326 m .53048 .79809 L .5139 .79826 L p .643 .696 .884 r
F P
0 g
s
.5139 .79826 m .50142 .76295 L .53473 .76326 L p .643 .696 .884 r
F P
0 g
s
.62947 .74387 m .6627 .70419 L .69488 .72775 L p .818 .842 .868 r
F P
0 g
s
.53048 .79809 m .53473 .76326 L .56746 .76841 L p .676 .731 .892 r
F P
0 g
s
.75895 .45653 m .75389 .50548 L .66755 .46441 L p .865 .627 .576 r
F P
0 g
s
.66755 .46441 m .6709 .4121 L .75895 .45653 L p .865 .627 .576 r
F P
0 g
s
.405 .63799 m .42392 .68439 L .38493 .70367 L p .473 .449 .751 r
F P
0 g
s
.41437 .74297 m .38493 .70367 L .42392 .68439 L p .513 .517 .798 r
F P
0 g
s
.42392 .68439 m .44645 .72837 L .41437 .74297 L p .513 .517 .798 r
F P
0 g
s
.44769 .4212 m .44914 .46732 L .37349 .50194 L p .447 .273 .55 r
F P
0 g
s
.3797 .5453 m .37349 .50194 L .44914 .46732 L p .483 .342 .612 r
F P
0 g
s
.44769 .4212 m .44876 .38123 L .5547 .35651 L p .581 .331 .502 r
F P
0 g
s
.62947 .74387 m .59506 .77747 L .56746 .76841 L p .739 .765 .873 r
F P
0 g
s
.48929 .72124 m .50142 .76295 L .47178 .76789 L p .595 .612 .839 r
F P
0 g
s
.47178 .76789 m .44645 .72837 L .48929 .72124 L p .595 .612 .839 r
F P
0 g
s
.66869 .36729 m .6709 .4121 L .55513 .39996 L p .728 .449 .505 r
F P
0 g
s
.55513 .39996 m .5547 .35651 L .66869 .36729 L p .728 .449 .505 r
F P
0 g
s
.75389 .50548 m .74057 .55735 L .65883 .52112 L p .851 .666 .652 r
F P
0 g
s
.65883 .52112 m .66755 .46441 L .75389 .50548 L p .851 .666 .652 r
F P
0 g
s
.44914 .46732 m .45311 .5178 L .3797 .5453 L p .483 .342 .612 r
F P
0 g
s
.39019 .59108 m .3797 .5453 L .45311 .5178 L p .513 .402 .665 r
F P
0 g
s
.56746 .76841 m .58846 .73001 L .62947 .74387 L p .739 .765 .873 r
F P
0 g
s
.58846 .73001 m .56746 .76841 L .53473 .76326 L p .696 .704 .853 r
F P
0 g
s
.53898 .72194 m .53473 .76326 L .50142 .76295 L p .646 .652 .842 r
F P
0 g
s
.50142 .76295 m .48929 .72124 L .53898 .72194 L p .646 .652 .842 r
F P
0 g
s
.6627 .70419 m .62947 .74387 L .58846 .73001 L p .768 .752 .838 r
F P
0 g
s
.47794 .67423 m .48929 .72124 L .44645 .72837 L p .579 .559 .796 r
F P
0 g
s
.44645 .72837 m .42392 .68439 L .47794 .67423 L p .579 .559 .796 r
F P
0 g
s
.53473 .76326 m .53898 .72194 L .58846 .73001 L p .696 .704 .853 r
F P
0 g
s
.5547 .35651 m .55513 .39996 L .44769 .4212 L p .581 .331 .502 r
F P
0 g
s
.45311 .5178 m .45944 .57055 L .39019 .59108 L p .513 .402 .665 r
F P
0 g
s
.405 .63799 m .39019 .59108 L .45944 .57055 L p .538 .456 .711 r
F P
0 g
s
.44914 .46732 m .44769 .4212 L .55513 .39996 L p .606 .4 .576 r
F P
0 g
s
.46784 .62339 m .47794 .67423 L .42392 .68439 L p .56 .508 .754 r
F P
0 g
s
.42392 .68439 m .405 .63799 L .46784 .62339 L p .56 .508 .754 r
F P
0 g
s
.74057 .55735 m .71993 .60935 L .64543 .57878 L p .834 .695 .71 r
F P
0 g
s
.64543 .57878 m .65883 .52112 L .74057 .55735 L p .834 .695 .71 r
F P
0 g
s
.45944 .57055 m .46784 .62339 L .405 .63799 L p .538 .456 .711 r
F P
0 g
s
.6934 .65894 m .6627 .70419 L .60908 .68512 L p .793 .737 .8 r
F P
0 g
s
.58846 .73001 m .60908 .68512 L .6627 .70419 L p .768 .752 .838 r
F P
0 g
s
.71993 .60935 m .6934 .65894 L .62844 .63424 L p .815 .718 .758 r
F P
0 g
s
.62844 .63424 m .64543 .57878 L .71993 .60935 L p .815 .718 .758 r
F P
0 g
s
.60908 .68512 m .62844 .63424 L .6934 .65894 L p .793 .737 .8 r
F P
0 g
s
.54311 .67441 m .53898 .72194 L .48929 .72124 L p .646 .613 .802 r
F P
0 g
s
.48929 .72124 m .47794 .67423 L .54311 .67441 L p .646 .613 .802 r
F P
0 g
s
.60908 .68512 m .58846 .73001 L .53898 .72194 L p .71 .677 .816 r
F P
0 g
s
.6709 .4121 m .66755 .46441 L .5545 .4511 L p .736 .509 .585 r
F P
0 g
s
.5545 .4511 m .55513 .39996 L .6709 .4121 L p .736 .509 .585 r
F P
0 g
s
.53898 .72194 m .54311 .67441 L .60908 .68512 L p .71 .677 .816 r
F P
0 g
s
.55513 .39996 m .5545 .4511 L .44914 .46732 L p .606 .4 .576 r
F P
0 g
s
.45311 .5178 m .44914 .46732 L .5545 .4511 L p .622 .454 .634 r
F P
0 g
s
.54693 .62154 m .54311 .67441 L .47794 .67423 L p .644 .576 .763 r
F P
0 g
s
.47794 .67423 m .46784 .62339 L .54693 .62154 L p .644 .576 .763 r
F P
0 g
s
.62844 .63424 m .60908 .68512 L .54311 .67441 L p .721 .65 .778 r
F P
0 g
s
.5545 .4511 m .55283 .50716 L .45311 .5178 L p .622 .454 .634 r
F P
0 g
s
.45944 .57055 m .45311 .5178 L .55283 .50716 L p .632 .498 .681 r
F P
0 g
s
.66755 .46441 m .65883 .52112 L .55283 .50716 L p .737 .554 .646 r
F P
0 g
s
.55283 .50716 m .5545 .4511 L .66755 .46441 L p .737 .554 .646 r
F P
0 g
s
.55024 .56497 m .54693 .62154 L .46784 .62339 L p .639 .538 .724 r
F P
0 g
s
.46784 .62339 m .45944 .57055 L .55024 .56497 L p .639 .538 .724 r
F P
0 g
s
.55283 .50716 m .55024 .56497 L .45944 .57055 L p .632 .498 .681 r
F P
0 g
s
.54311 .67441 m .54693 .62154 L .62844 .63424 L p .721 .65 .778 r
F P
0 g
s
.64543 .57878 m .62844 .63424 L .54693 .62154 L p .729 .621 .738 r
F P
0 g
s
.65883 .52112 m .64543 .57878 L .55024 .56497 L p .734 .59 .695 r
F P
0 g
s
.55024 .56497 m .55283 .50716 L .65883 .52112 L p .734 .59 .695 r
F P
0 g
s
.54693 .62154 m .55024 .56497 L .64543 .57878 L p .729 .621 .738 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`1o
ooooo`Oo0000:?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo000[oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0N_ooool4o`000003o`h00?l0003o0000
00_o00008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo000Qooooo`Co
000000?o410@ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Go
oooo1?l000000ol>003o0000o`000002o`0000;oDP0000?o0000ogl00?mo00000omo000<o`0001[o
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0]ooooo`008oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0LOooool3o`0000;o3P00
0ol00006oe800003o`000?mo003oO`0000coO`002ol0000Booooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;?ooool001Sooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`1/ooooo`Co000000?o3P00o`000?l000000_l0
000:oe800003o`000?mo003oO`0001CoO`001Ol0000?ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;?ooool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo06Oooooo1?l000000ol>003o0000o`000002o`0000coDP002?l0000E
ogl000?o00003Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo000Soooo
o`03o`000?oooooooooo00Cooooo0_l0000Booooo`03o`000?oooooooooo06?ooooo0ol00002o`h0
00?o00003?mB0004o`0000;oMaLm00?o0000ojHf<_nV=S800onV=S8:o`0000coO`0000Co0000oh<0
0?l0003o00002oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo000Soooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Poooo
o`Oo00003?mB0003o`0000KoMaLm00?o0000ojHf<_nV=S803OnV=S8:o`0000?oO`0000?o0000oh<0
0?n300000_l00009ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:_ooool002?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05ko
oooo1?l0000<oe8000Co00002Omg5cd00ol0003oYSHbojHf<P0GojHf<PKo00000_n30002o`0000Oo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`008Oooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Foooool3o`000003oa<0
0?l0003oDP0000SoDP001?l0000=ogLG?@03o`000?nV=S;oYSHb01_oYSHb00Co0000olI60_l0003o
00000_n30002o`0000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`00
:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Sooooo0ol00002oa<00003o`00
0?mB003oDP0000CoDP001?l0000AogLG?@03o`000?nV=S;oYSHb01coYSHb00?o0000olI60_o6AP80
0_l00002oh<00003o`000?oooooooooo00;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Kooooo0ol0
0002oa<00003o`000?mB003oDP0000;oDP000ol0000EogLG?@03o`000?nV=S;oYSHb01coYSHb00?o
0000olI60_o6AP800_o6AP800ol0003oP`00oh<00002o`0000;ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo05?ooooo0ol00004oa<000Go00005_mg5cd9o`0001WoYSHb00?o0000olI60_o6AP800_o6AP82
o`0000;oP`000ol0000gooooo`03o`000?oooooooooo02Oooooo000Yooooo`;o00006_ooool00ol0
003oooooooooo`1@ooooo`?o00001?lC0003o`0001KoMaLm1?l00002ohXlIP03o`000?ndFf?o]5]S
00Co]5]S2ol0000?ojHf<P03o`000?o6AP;oaTH200?oaTH20_l00002oh<000;o0000=oooool00ol0
003oooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04ko
oooo0ol00004oa<00003o`000?ll03Go000001?oMaLm1?l00006ohXlIP03o`000?ndFf?o]5]S00oo
]5]S2ol00004ojHf<P03o`000?o6AP;oaTH200GoaTH20_l000001?n3003o0000o`000?l0000eoooo
o`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0Boooool3o`0000Co4`000_l00002oc`0=@03o`000?mg5cgoMaLm00goMaLm1?l0000:ohXlIP03
o`000?ndFf?o]5]S01[o]5]S1ol00007olI60P;o00000_n30002o`0003Cooooo00?o0000oooooooo
ool09Oooool002Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`18ooooo`?o0000
1OlC00000ol0003o?00eoc`0=@02oc`0=@03o`000?mg5cgoMaLm00[oMaLm0ol0000>ohXlIP03o`00
0?ndFf?o]5]S01oo]5]S00Co0000om]gC?l0003o00001_o6AP83o`0000;oP`0000?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo04Kooooo0ol00004oa<000;o00001?ll03D00ol0003oMaLmogLG?@07ogLG?@Co0000
4On:?6H00ol0003o]5]SokAKH`0OokAKH`04o`000?oKMdcofgM<om]gC0;o00001?o6AP800ol0003o
aTH2olI60P02o`000003oh<00?l0003ooooo03;ooooo00?o0000ooooooooool09?ooool002Sooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`14ooooo`;o00001OlC00000ol0003o?00e
oc`0=@04oc`0=@03o`000?mg5cgoMaLm00?oMaLm1?l0000FohXlIP03o`000?ndFf?o]5]S01ko]5]S
00?o0000om]gC?oKMd`00ooKMd`2o`0000;oaTH200?o0000olI60_o6AP800_o6AP800ol0003oP`00
o`00000cooooo`03o`000?oooooooooo02?ooooo000Xooooo`;o00008Oooool00ol0003ooooooooo
o`12ooooo`03o`000?lC003o4`0000?o4`000_l00007oc`0=@03o`000?mg5cgo000000?o00006_n:
?6H00ol0003o]5]SokAKH`0OokAKH`03o`000?oKMdcofgM<00CofgM<00?o0000olI60_l000001Oo6
AP83o`0003;ooooo00?o0000ooooooooool08oooool002Sooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`10ooooo`03o`000?lC003o4`0000?o4`0000?o0000oc`0=Oll03D01_ll03D3
o`0001koRSaV00?o0000okAKHondFf<07ondFf<00ol0003ofgM<om]gC005om]gC0;o00001oo6AP82
o`0003;ooooo00?o0000ooooooooool08_ooool002Sooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0nooooo`;o00000olC0002o`0000So?00e00?o0000oeDCGOl000007on:?6H00ol0
003o]5]SokAKH`0OokAKH`03o`000?oKMdcofgM<00KofgM<0ol00007olI60P03o`000?oooooooooo
033ooooo00?o0000ooooooooool08Oooool002Sooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0looooo`;o00000olC00000ol0003o?00eoc`0=@06oc`0=@;o00000_mE4ed00ol0003o
RSaVohXlIP0MohXlIP03o`000?ndFf?o]5]S01oo]5]S00?o0000om]gC?oKMd`01_oKMd`00ol0003o
fgM<om]gC002o`0000GoaTH200?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Qooooo`00
9oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03[ooooo0ol000000olC003o0000
o`000008oc`0=@03o`000?mE4egoEA=M00;oEA=M00?o0000ohXlI_n:?6H06on:?6H9o`0001_o]5]S
00?o0000om]gC?oKMd`01_oKMd`00ol0003ofgM<om]gC002om]gC0;o00001?o6AP800ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo023ooooo000Wooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0>?ooool3o`000003oa<00?l0003o?00e00Oo?00e0_l00005oeDCG@03o`000?n:
?6KoRSaV01OoRSaV1?l00002oiADP003o`000?njLX7o^W:100Co^W:13?l0000@okAKH`03o`000?oK
MdcofgM<00GofgM<00?o0000om]gC?oKMd`01?oKMd`2o`0000?oaTH200?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo1Ol00008oc`0=@03o`000?mE4egoEA=M00GoEA=M00?o0000ohXlI_n:?6H04on:?6H4
o`0000KoU5B000?o0000okYbPOnjLX404?njLX4;o`0000Go]5]S00?o0000om]gC?oKMd`01OoKMd`0
0ol0003ofgM<om]gC006om]gC0;o00000_o6AP800ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo01oooooo000Wooooo`;o0000:Oooool00ol0003oooooooooo`0dooooo`Co00002?ll03D2o`00
00OoEA=M00?o0000ohXlI_n:?6H04?n:?6H4o`0000[oU5B000?o0000okYbPOnjLX406onjLX47o`00
00KofgM<00?o0000om]gC?oKMd`02?oKMd`00ol0003oaTH2o`00000booooo`03o`000?oooooooooo
01kooooo000Wooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<_ooool4o`0000Oo
?00e0_l00009oeDCG@03o`000?n:?6KoRSaV00_oRSaV1Ol0000>oiADP003o`000?njLX7o^W:1023o
^W:100Co0000omnAMol0003o00001?oKMd`00ol0003ofgM<om]gC009om]gC0?o0000<Oooool00ol0
003oooooooooo`0Nooooo`009oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo033o
oooo1Ol00006oc`0=@03o`000?mE4egoEA=M00WoEA=M00?o0000ohXlI_n:?6H01on:?6H4o`0001?o
U5B000?o0000okYbPOnjLX408?njLX401?l0003ogi5gomnAMooOTGL2o`0000;ofgM<00?o0000om]g
C?oKMd`02ooKMd`2o`00037ooooo00?o0000ooooooooool07Oooool002Oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0^ooooo`Go00001Oll03D2o`0000coEA=M00?o0000ohXlI_n:
?6H00on:?6H4o`0001OoU5B000?o0000okYbPOnjLX408?njLX400ol0003ogi5gomnAM`03omnAM`?o
00003ooKMd`00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01gooooo000Vooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0;?ooool4o`000003o`007Ol0003o?00e00?o?00e
00?o0000oeDCGOmE4ed03?mE4ed00ol0003oRSaVo`000003o`0001_oU5B000?o0000okYbPOnjLX40
8?njLX400ol0003ogi5gomnAM`05omnAM`03o`000?oKMdcofgM<00gofgM<00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0Looooo`009_ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02[ooooo1?l00002o`007@03o`000?ll03Go?00e00;o00003_mE4ed3o`0001ooU5B000?o
0000okYbPOnjLX408?njLX400ol0003ogi5gomnAM`05omnAM`?o00003_oKMd`00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo01_ooooo000Vooooo`?o0000;oooool00ol0003oooooooooo`0X
ooooo`Co00000_l001d01?l0003o?00eoc`0=Ol0000>oeDCG@;o000000?oIS1ho`000?nDE8007onD
E8000ol0003o^W:1okYbP@0PokYbP@03o`000?oOTGOogi5g00Kogi5g00Co0000omnAMol0003o0000
3?oKMd`2o`00033ooooo00?o0000ooooooooool06oooool002Kooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0Vooooo`Co00000ol001d3o`0000koEA=M00Go0000ofH`N?mV<7SoIS1h
o`00000PoiADP003o`000?njLX7o^W:1023o^W:100?o0000omnAMooOTGL01_oOTGL01?l0003ogi5g
omnAMooOTGL2o`0000[ofgM<0_l0000aooooo`03o`000?oooooooooo01[ooooo000;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool09?ooool4o`0000Co000M00?o0000oeDC
GOmE4ed03?mE4ed2o`0000CoIS1h00?o0000oiADP?nDE8007_nDE8000ol0003o^W:1okYbP@0QokYb
P@03o`000?oOTGOogi5g00Gogi5g00?o0000omnAMooOTGL00ooOTGL2o`0000WofgM<0_l0000`oooo
o`03o`000?oooooooooo01[ooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02?ooooo0ol00004o`007@03o`000?mE4egoEA=M00_oEA=M0_l00006ofH`N003o`000?nDE83oU5B0
01koU5B000?o0000okYbPOnjLX408OnjLX400ol0003ogi5gomnAM`05omnAM`03o`000?oOTGOogi5g
00Gogi5g0_l00007om]gC0;o0000<Oooool00ol0003oooooooooo`0Iooooo`000oooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Qooooo`?o00001?l001d2o`0000coEA=M00?o0000ofH`
N?mV<7P01_mV<7P00ol0003oU5B0oiADP00LoiADP0So00007_njLX400ol0003ogi5gomnAM`05omnA
M`03o`000?oOTGOogi5g00Oogi5g0_l00005om]gC003o`000?oIN03o0000037ooooo00?o0000oooo
ooooool06?ooool000_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Oooooo`?o00001?l001d00ol0
003o5@19o`00000:oeDCG@;o00002OmV<7P00ol0003oU5B0oiADP00GoiADP0Go00000_nKIY<00ol0
003o_8:Eokb2U@03okb2U@Wo00005OnjLX400ol0003ogi5gomnAM`05omnAM`03o`000?oOTGOogi5g
00Wogi5g00?o0000om]gC?oKMd`00ooKMd`00ol0003ofGP0o`00000`ooooo`03o`000?oooooooooo
01Sooooo000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Nooooo`;o00001?l001d0
0ol0003o5@19o`000009oeDCG@;o00002_mV<7P00ol0003oU5B0oiADP00CoiADP0Go00001onKIY<0
0ol0003o_8:Eokb2U@0<okb2U@Wo00003?njLX400ol0003ogi5gomnAM`05omnAM`03o`000?oOTGOo
gi5g00[ogi5g0_l00003om]gC003o`000?oIN03o0000037ooooo00?o0000ooooooooool05oooool0
00_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000h
ooooo`03o`000?oooooooooo01cooooo0_l00004o`007@04o`000?lE04Wo5@19o`0000OoEA=M0_l0
000<ofH`N003o`000?nDE83oU5B000koU5B01Ol0000<oi]VT`03o`000?nlPYGo_8:E01Go_8:E2Ol0
0003okYbP@03o`000?oOTGOogi5g00Gogi5g00?o0000omnAMooOTGL03?oOTGL2o`000005om]gC?l0
003ofGP0omUh0?l00000<?ooool00ol0003oooooooooo`0Gooooo`002oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo01[ooooo0_l00004o`007@05o`000?lE04Wo5@19oaD0BOl000001_mE4ed00ol0003o
IS1hofH`N00<ofH`N003o`000?nDE83oU5B000WoU5B01Ol0000Aoi]VT`03o`000?nlPYGo_8:E01ko
_8:E1Ol00006omnAM`03o`000?oOTGOogi5g00kogi5g0ol000000ooIN03o0000ooooo`0`ooooo`03
o`000?oooooooooo01Kooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Hooooo`;o00001?l001d00ol0003o
5@19oaD0B@02oaD0B@03o`000?mE4egoEA=M00;oEA=M0_l0000?ofH`N003o`000?nDE83oU5B000Co
U5B01Ol0000Foi]VT`03o`000?nlPYGo_8:E027o_8:E00Co0000omfPTol0003o00001?oOTGL00ol0
003ogi5gomnAM`0@omnAM`04o`000?oIN03ofGP0o`0002oooooo0ol0000Gooooo`009?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo01Sooooo00?o0000o`007Ol001d00_l001d00ol0
003o5@19oaD0B@03oaD0B@03o`000?mE4egoEA=M00;o00004OmV<7P00ol0003oU5B0o`000004o`00
01_oVfJC00?o0000okb2UOnlPYD08OnlPYD01?l0003ogJ2ComfPTooMX9<2o`0000;ogi5g00?o0000
omnAMooOTGL04?oOTGL01Ol0003ofGP0omUh0?oIN03o000002_ooooo0ol00002ooooo`03o`000?oo
oooooooo01Gooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05_ooool2
o`0000?o000M00?o0000oaD0BOlE04T00olE04T01?l0003oEA=MoeDCGOl0000BofH`N0?o00008?nK
IY<00ol0003o_8:Eokb2U@0Qokb2U@03o`000?oMX9?ogJ2C00?ogJ2C0ol0000BomnAM`;o00000_oI
N0000ol0003oooooooooo`0Vooooo`?o00001Oooool00ol0003oooooooooo`0Eooooo`009?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo01Cooooo0_l00003o`007@03o`000?lE04Wo
5@1900Co5@190ol0000AofH`N0;o000000?oLTF<o`000?nKIY<08?nKIY<00ol0003o_8:Eokb2U@0Q
okb2U@03o`000?oMX9?ogJ2C00GogJ2C0_l0000AomnAM`03o`000?oiZd_o000000;ofGP000?o0000
ooooooooool08_ooool3o`0000Sooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Cooooo`;o00000_l001d00ol0003o5@19oaD0B@05oaD0
B@03o`000?mV<7SoIS1h00ooIS1h0_l00003og95S003o`000?nKIY?oVfJC01ooVfJC00?o0000okb2
UOnlPYD08OnlPYD00ol0003ogJ2ComfPT`05omfPT`04o`000?oMX9?o0000o`0000oogi5g00?o0000
ooV[Bol000000_oIN0000ol0003oooooooooo`0Oooooo`?o00002oooool00ol0003oooooooooo`0E
ooooo`009?ooool2o`0003oooooo00?o0000ooooooooool04Oooool3o`000003o`007Ol0003o5@19
00Ko5@190_l0000@ofH`N003o`000?mbAHcoLTF<00?oLTF<00?o0000oi]VTonKIY<07onKIY<00ol0
003o_8:Eokb2U@0Qokb2U@03o`000?oMX9?ogJ2C00GogJ2C00Co0000omfPTooMX9?ogJ2C0_l0000=
omnAM`04o`000?oiZd_onJ];o`0000;ofGP000?o0000ooooooooool06oooool3o`0000oooooo00?o
0000ooooooooool05?ooool002Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0?
ooooo`?o000000?o000Mo`000?lE04T01_lE04T00ol0003o;@AXo`00000>ofH`N0;o00001_mbAH`0
0ol0003oVfJCoi]VT`0Ooi]VT`03o`000?nlPYGo_8:E027o_8:E00?o0000omfPTooMX9<01OoMX9<0
0ol0003ogJ2ComfPT`03omfPT`;o00002ooOTGL01?l0003onJ];ooV[Bol00003omUh0003o`000?oo
oooooooo01Oooooo0ol0000Booooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool03_ooool4o`0000Oo5@1900Co0000obd4J?l]16So00003?mV
<7P2o`0000SoLTF<00?o0000oi]VTonKIY<07onKIY<00ol0003o_8:Eokb2U@0Qokb2U@03o`000?oM
X9?ogJ2C00GogJ2C00?o0000omfPTooMX9<01OoMX9<2o`0000[ogi5g00Co0000ooV[BooiZd_o0000
0_oIN0000ol0003oooooooooo`0Dooooo`?o00005Oooool00ol0003oooooooooo`0Dooooo`008ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00cooooo1?l00007oaD0B@05o`000?l]
16So;@AXobd4J?l000002_mV<7P2o`0000[oLTF<00?o0000oi]VTonKIY<07onKIY<00ol0003o_8:E
okb2U@0Pokb2U@03o`000?oMX9?ogJ2C00KogJ2C00?o0000omfPTooMX9<01ooMX9<2o`0000Sogi5g
00Go0000ooV[BooiZd_onJ];o`000002omUh0003o`000?oooooooooo013ooooo0ol0000Hooooo`03
o`000?oooooooooo01Cooooo000Sooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
2_ooool4o`0000Oo5@1900?o0000obd4J?l]16P00_l]16P00ol0003oIS1hofH`N006ofH`N0;o0000
3?mbAH`00ol0003oVfJCoi]VT`0Ooi]VT`03o`000?nlPYGo_8:E023o_8:E00?o0000omfPTooMX9<0
1ooMX9<00ol0003ogJ2ComfPT`08omfPT`;o00001_oOTGL01Ol0003onJ];ooV[BooiZd_o000000;o
fGP000?o0000ooooooooool03Oooool3o`0001_ooooo00?o0000ooooooooool05?ooool002?ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`09ooooo`Co00001_lE04T00ol0003o;@AX
obd4J002obd4J003o`000?mV<7SoIS1h00GoIS1h0_l0000?og95S003o`000?nKIY?oVfJC01koVfJC
00?o0000okb2UOnlPYD08?nlPYD00ol0003ogJ2ComfPT`07omfPT`03o`000?oMX9?ogJ2C00[ogJ2C
0_l00004omnAM`03o`000?oiZd_onJ];00;onJ];00Co0000omUh0?oIN03o00002oooool3o`0001ko
oooo00?o0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`07ooooo`Go00001OlE04T00ol0003o;@AXobd4J003obd4J003o`000?mV<7SoIS1h00?oIS1h
0_l0000Aog95S003o`000?nKIY?oVfJC01_oVfJC2?l0000Nokb2U@03o`000?oMX9?ogJ2C00OogJ2C
00?o0000omfPTooMX9<03?oMX9<2o`0000;ogi5g00?o0000ooV[BooiZd/00_oiZd/01?l0003ofGP0
omUh0?l00008ooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2o`0004Oooooo
00?o0000ooooooooool01_ooool4o`0000Go5@1900?o0000obd4J?l]16P01?l]16P00ol0003oIS1h
ofH`N002ofH`N003o`000?mbAHcoLTF<017oLTF<00?o0000oi]VTonKIY<05_nKIY<5o`0000?oWgBR
00?o0000okb=YOnlSJD00_nlSJD7o`0001Oo_8:E00?o0000omfPTooMX9<01ooMX9<00ol0003ogJ2C
omfPT`0>omfPT`?o00001OoiZd/00ol0003ofGP0o`000005ooooo`?o00009Oooool00ol0003ooooo
ooooo`0Cooooo`008oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Cooooo1Ol0
0004oaD0B@03o`000?l]16So;@AX00Go;@AX00?o0000ofH`N?mV<7P00_l0000Dog95S003o`000?nK
IY?oVfJC013oVfJC1_l00008oimdXP03o`000?nlSJGo_8fU00Wo_8fU1ol0000@okb2U@03o`000?oM
X9?ogJ2C00OogJ2C00?o0000omfPTooMX9<04?oMX9<00ol0003onJ];ooV[B`04ooV[B`04o`000?oI
N03o0000ooooo`?o0000:?ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00;ooooo1?l000000ol002go0000oaD0B@02oaD0B@03o`000?l]
16So;@AX00Ko;@AX0ol0000Fog95S003o`000?nKIY?oVfJC00_oVfJC1Ol0000>oimdXP03o`000?nl
SJGo_8fU013o_8fU1ol00009okb2U@03o`000?oMX9?ogJ2C00OogJ2C00?o0000omfPTooMX9<04?oM
X9<00ol0003onJ];ooV[B`04ooV[B`04o`000?oIN03o0000o`0002_ooooo00?o0000ooooooooool0
4oooool002;ooooo00?o0000ooooooooool0B_ooool01?l0003oooooooooooooool3o`0000;o000]
00Co0000oaD0BOlE04Wo00002Ol]16P00ol0003oLTF<og95S00Fog95S003o`000?nKIY?oVfJC00Go
VfJC1_l0000CoimdXP03o`000?nlSJGo_8fU01Oo_8fU1ol00002okb2U@03o`000?oMX9?ogJ2C00Oo
gJ2C00?o0000omfPTooMX9<04?oMX9<2o`0000KonJ];0_l0000/ooooo`03o`000?oooooooooo01?o
oooo000Rooooo`03o`000?oooooooooo04_ooooo00?o0000ooooool000000ol00002o`00;@03o`00
0?lE04Wo000000Wo;@AX0_l0000Hog95S003o`000?nKIY?oVfJC00Go00006OnOM:800ol0003o_8fU
okb=Y@0Nokb=Y@Co00002?oMX9<00ol0003ogJ2ComfPT`0@omfPT`03o`000?oma7oo000000GonJ];
00?o0000omUh0?l00000:oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooooooo
o`1<ooooo`Co00000_l002d00ol0003o5@19o`000009obd4J003o`000?m17h3o000001OoLTF<1?l0
000NoimdXP03o`000?nlSJGo_8fU023o_8fU00Co0000omVZY_l0003o00001_oMX9<00ol0003ogJ2C
omfPT`0@omfPT`03o`000?oma7oo000000KonJ];0_l0000[ooooo`03o`000?oooooooooo01?ooooo
000Rooooo`03o`000?oooooooooo04gooooo0ol00002o`00;@;o00002Ol]16P01?l0003o@An0od4O
P?l0000Dog95S0?o000000?oNeNLo`000?nOM:807onOM:800ol0003o_8fUokb=Y@0Pokb=Y@04o`00
0?oIZZKofJZVomVZYP?o00000ooMX9<00ol0003ogJ2ComfPT`0?omfPT`05o`000?oma7oooLAooog4
Ool000001_oiZd/00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01?ooooo000Qooooo`?o
0000COooool3o`0000?o000]00?o0000obd4J?l]16P01ol]16P01Ol0003o@An0od4OP?m17h3o0000
01;oLTF<0_l00004og]GW003o`000?nOM:;oWgBR01koWgBR00?o0000okb=YOnlSJD08?nlSJD00ol0
003ofJZVomVZYP04omVZYP;o000000?ogJ2Co`000?oMX9<04?oMX9<01Ol0003ooLAooog4Oooma7oo
000000KonJ];0_l0000[ooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooooooo
04gooooo0_l00004o`00;@03o`000?l]16So;@AX00Ko;@AX00?o0000od4OP?m17h000_m17h000ol0
003oLTF<og95S00>og95S0;o00001_mkEi`00ol0003oWgBRoimdXP0NoimdXP03o`000?nlSJGo_8fU
01oo_8fU00?o0000omVZY_oIZZH01ooIZZH2o`00017ogJ2C00?o0000oog4Oooma7l00_oma7l00ol0
003onJ];ooV[B`04ooV[B`03o`000?oooooooooo02Wooooo00?o0000ooooooooool04_ooool0027o
oooo00?o0000ooooooooool0C?ooool3o`0000?o000]0_l00007obd4J003o`000?m17h3o@An000?o
@An000?o0000og95S?mbAH`02ombAH`3o`0000SoNeNL00?o0000oimdX_nOM:807OnOM:800ol0003o
_8fUokb=Y@0Pokb=Y@03o`000?oIZZKofJZV00SofJZV0ol0000?omfPT`03o`000?oma7oooLAo00?o
oLAo00?o0000ooV[BooiZd/00ooiZd/00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01;o
oooo000Qooooo`03o`000?oooooooooo04cooooo0_l00003o`00;@03o`000?l005Go000000Ko;@AX
00?o0000od4OP?m17h001Om17h000ol0003oLTF<og95S008og95S0;o00002omkEi`00ol0003oWgBR
oimdXP0MoimdXP03o`000?nlSJGo_8fU023o_8fU00?o0000omVZY_oIZZH02?oIZZH00ol0003ofJZV
omVZYP03o`0000cogJ2C00?o0000oog4Oooma7l00ooma7l00ol0003onJ];ooV[B`03ooV[B`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0C?oo
ool00ol0003o000]o`00;@02o`00;@03o`000?l005Go000000Go;@AX00?o0000od4OP?m17h001_m1
7h000ol0003oLTF<og95S005og95S0?o00003OmkEi`00ol0003oWgBRoimdXP0MoimdXP03o`000?nl
SJGo_8fU023o_8fU00?o0000omVZY_oIZZH02?oIZZH00ol0003ofJZVomVZYP03omVZYP;o00002_oM
X9<00ol0003ooLAooog4O`04oog4O`03o`000?oiZd_onJ];00;onJ];00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`1;ooooo`;o00000ol002d0
1?l0003o001Eo`00EOl00004obd4J003o`000?m17h3o@An000Oo@An000?o0000og95S?mbAH`00omb
AH`2o`00013oNeNL00?o0000oimdX_nOM:807OnOM:800ol0003o_8fUokb=Y@0Pokb=Y@03o`000?oI
ZZKofJZV00SofJZV00?o0000omVZY_oIZZH01OoIZZH2o`0000SogJ2C00?o0000oog4Oooma7l01Oom
a7l01Ol0003onJ];ooV[BooiZd_o000002_ooooo00?o0000ooooooooool04_ooool0027ooooo00?o
0000ooooooooool0Boooool2o`0000;o000]00Go0000o`00EOl005Go001Eo`000003obd4J003o`00
0?m17h3o@An000So@An000Co0000og95S?mbAHcoLTF<0_l0000Cog]GW003o`000?nOM:;oWgBR01co
WgBR00?o0000okb=YOnlSJD07onlSJD00ol0003ofJZVomVZYP09omVZYP03o`000?oIZZKofJZV00Oo
fJZV0_l00005omfPT`03o`000?oma7oooLAo00KooLAo00Go0000ooV[BooiZd_onJ];o`00000[oooo
o`03o`000?oooooooooo01;ooooo000Pooooo`?o0000C?ooool01Ol0003o000]o`00;Ol002go0000
00?o001E00Co0000obd4J?l]16So00002om17h04o`0001GoNeNL00?o0000oimdX_nOM:807?nOM:80
0ol0003o_8fUokb=Y@0Ookb=Y@03o`000?oIZZKofJZV00WofJZV00?o0000omVZY_oIZZH02OoIZZH3
o`0000;ogJ2C00?o0000oog4Oooma7l01ooma7l01?l0003onJ];ooV[Bol0000/ooooo`03o`000?oo
oooooooo017ooooo000Pooooo`03o`000?oooooooooo04_ooooo0_l00002o`00;@03o`000?l005Go
001E00;o001E00?o0000obd4J?l000002om17h02o`0001SoNeNL00?o0000oimdX_nOM:807?nOM:80
0ol0003o_8fUokb=Y@0Ookb=Y@03o`000?oIZZKofJZV00[ofJZV00?o0000omVZY_oIZZH02ooIZZH3
o`0000[ooLAo00Co0000ooV[BooiZd_o0000:oooool00ol0003oooooooooo`0Aooooo`005Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0Boooool2o`0000;o000]00?o
0000o`00EOl005D00_l005D2o`0000_o@An000?o0000oe8gTol000006?mkEi`00ol0003oWgBRoimd
XP0LoimdXP03o`000?nlSJGo_8fU01oo_8fU00?o0000omVZY_oIZZH02_oIZZH00ol0003ofJZVomVZ
YP0=omVZYP03o`000?oma7oooLAo00SooLAo00Co0000ooV[BooiZd_o0000:oooool00ol0003ooooo
ooooo`0Aooooo`005Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
B_ooool3o`000003o`00;Ol0003o001E00Co001E00?o0000od4OP?m17h002Om17h001?l0003oDSNC
oe8gTol0000Hog]GW003o`000?nOM:;oWgBR01OoWgBR2_l0000Mokb=Y@03o`000?oIZZKofJZV00[o
fJZV00?o0000omVZY_oIZZH03OoIZZH00ol0003ooLAooog4O`09oog4O`03o`000?oiZd_o000002_o
oooo00?o0000ooooooooool04Oooool001Gooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo04[ooooo1?l00006o`00E@03o`000?m17h3o@An000So@An000Go0000oe8gTomB
=i?oDSNCo`00000Hog]GW003o`000?nOM:;oWgBR00coWgBR2ol00005oj5o[P03o`000?nkUk7o^iNa
00;o^iNa2?l0000Eokb=Y@03o`000?oIZZKofJZV00[ofJZV00?o0000omVZY_oIZZH03OoIZZH2o`00
00[ooLAo00?o0000ooV[Bol00000:oooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0B_ooool2o`000003o`00;Ol0003o001E
00Co001E0_l00009od4OP003o`000?mB=i?oDSNC00?oDSNC00?o0000og]GW?mkEi`05OmkEi`00ol0
003oWgBRoimdXP02oimdXP[o00004?nQOjh00ol0003o^iNaok^G/@0:ok^G/@Wo00002onlSJD00ol0
003ofJZVomVZYP0;omVZYP03o`000?oIZZKofJZV00cofJZV00Co0000ooS@XOohd:7o00002_oma7l2
o`0002_ooooo00?o0000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo04[ooooo1?l00005o`00E@03o`000?lG0G?o000000So@An000?o0000
oe8gTomB=i<01?mB=i<00ol0003oNeNLog]GW00Dog]GW0Ko00006_nQOjh00ol0003o^iNaok^G/@0C
ok^G/@So00000onlSJD00ol0003ofJZVomVZYP0;omVZYP03o`000?oIZZKofJZV00cofJZV00Co0000
ooS@XOohd:7o00002ooma7l00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017ooooo000E
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0004_ooooo0ol00005o`00E@04o`000?lG
0G?o5`5co`0000Ko@An00_l00007oe8gT`03o`000?mkEicoNeNL017oNeNL0ol000000on3IZ[o0000
oj5o[P0Moj5o[P03o`000?nkUk7o^iNa01_o^iNa1Ol0000<omVZYP03o`000?oIZZKofJZV00cofJZV
00Go0000ooS@XOohd:7on=2Qo`00000:oog4O`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo04Wo
oooo1?l00005o`00E@04o`000?lG0G?o5`5co`0000Go@An000?o0000oe8gTomB=i<01omB=i<00ol0
003oNeNLog]GW00?og]GW0;o00001?n3IZX00ol0003oXGn^oj5o[P0Loj5o[P03o`000?nkUk7o^iNa
01ko^iNa00Co0000omFa]Ol0003o00002_oIZZH00ol0003ofJZVomVZYP0<omVZYP03o`000?ohd:7o
n=2Q00;on=2Q00?o0000oog4Oooma7l01ooma7l00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo013ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`19
ooooo`Co00001?l005D01Ol0003o5`5coaL1LolG0G?o000000Co@An000?o0000oe8gTomB=i<02?mB
=i<00ol0003oNeNLog]GW00<og]GW0?o00001_n3IZX00ol0003oXGn^oj5o[P0Loj5o[P03o`000?nk
Uk7o^iNa01ko^iNa00Co0000omFa]OoE/KGoeK6e0_l00008omVZYP03o`000?oIZZKofJZV00_ofJZV
00?o0000ooS@XOohd:401?ohd:400ol0003ooLAooog4O`06oog4O`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool04?ooool001oooooo00?o0000ooooooooool0BOooool4o`0000?o001E00?o
0000oaL1LolG0G<00_lG0G<01Ol0003o@An0od4OP?m17h3o000000_oDSNC00?o0000og]GW?mkEi`0
2OmkEi`3o`0000WoPfJZ00?o0000oj5o[_nQOjh07?nQOjh00ol0003o^iNaok^G/@0Mok^G/@03o`00
0?oE/KGoeK6e00CoeK6e0ol00005omVZYP03o`000?oIZZKofJZV00_ofJZV00?o0000ooS@XOohd:40
1?ohd:400ol0003ooLAooog4O`05oog4O`;o0000;?ooool00ol0003oooooooooo`0@ooooo`007ooo
ool00ol0003oooooooooo`18ooooo`?o000000?o000io`000?l005D00_l005D00ol0003o5`5coaL1
L`02oaL1L`04o`000?m17h3o@An0o`0000coDSNC00?o0000og]GW?mkEi`01omkEi`2o`0000goPfJZ
00?o0000oj5o[_nQOjh06onQOjh00ol0003o^iNaok^G/@0Mok^G/@03o`000?oE/KGoeK6e00OoeK6e
0_l00003omVZYP03o`000?oIZZKofJZV00_ofJZV00?o0000ooS@XOohd:401Oohd:400ol0003ooLAo
oog4O`04oog4O`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool001oooooo00?o
0000ooooooooool0B?ooool3o`000005o`00>Ol0003o001Eo`00EOl000001OlG0G<00ol0003o@An0
o`00000>oe8gT`03o`000?mkEicoNeNL00?oNeNL0ol0000?oh=VZP03o`000?nQOjkoXGn^01_oXGn^
00?o0000ok^G/OnkUk407OnkUk400ol0003oeK6eomFa]@09omFa]@;o000000?ofJZVo`000?oIZZH0
3?oIZZH00ol0003on=2QooS@X@06ooS@X@03o`000?oma7oooLAo00?ooLAo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0@ooooo`007_ooool00ol0003oooooooooo`19ooooo`;o000000Go
000io`000?l005Go001Eo`000006oaL1L`;o00003omB=i<01?l0003oNeNLog]GW?mkEi`2o`0001;o
PfJZ00?o0000oj5o[_nQOjh06_nQOjh00ol0003o^iNaok^G/@0Nok^G/@03o`000?oE/KGoeK6e00_o
eK6e0_l0000=omVZYP03o`000?ohd:7on=2Q00Kon=2Q00?o0000oog4Oooma7l00ooma7l00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo04Sooooo
0ol000001?l003Wo0000o`00EOl00007oaL1L`03o`000?mB=i?oDSNC00koDSNC1?l0000Doh=VZP03
o`000?nQOjkoXGn^01[oXGn^00?o0000ok^G/OnkUk407_nkUk400ol0003oeK6eomFa]@0<omFa]@?o
00002_oIZZH00ol0003on=2QooS@X@08ooS@X@03o`000?oma7oooLAo00;ooLAo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0@ooooo`007_ooool2o`0004Wooooo0_l00002o`00>@03o`00
0?l005Go000000Oo5`5c00?o0000oe8gTomB=i<03OmB=i<2o`0001OoPfJZ00?o0000oj5o[_nQOjh0
6_nQOjh00ol0003o^iNaok^G/@0Mok^G/@03o`000?oE/KGoeK6e00goeK6e00?o0000omFa]OoE/KD0
0_l00008omVZYP03o`000?ohd:7on=2Q00Won=2Q00Go0000oog4Oooma7oooLAoo`00000^ooooo`03
o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04Sooooo0_l00002o`00>@;o0000
1olG0G<2o`0000koDSNC00?o0000of1=Y?l000005on3IZX00ol0003oXGn^oj5o[P0Joj5o[P03o`00
0?nkUk7o^iNa01go^iNa00?o0000omFa]OoE/KD03OoE/KD00ol0003oeK6eomFa]@02omFa]@?o0000
1OoIZZH00ol0003on=2QooS@X@0:ooS@X@04o`000?oma7oooLAoo`0002kooooo00?o0000oooooooo
ool03oooool001kooooo00?o0000ooooooooool0Aoooool3o`0000;o000i00?o0000oaL1LolG0G<0
1OlG0G<00ol0003o;an<o`00000=oe8gT`04o`000?mPCJCoH4fTo`0001OoPfJZ00?o0000oj5o[_nQ
Ojh06_nQOjh00ol0003o^iNaok^G/@0Mok^G/@03o`000?oE/KGoeK6e00goeK6e00?o0000omFa]OoE
/KD01OoE/KD2o`0000?ofJZV00?o0000ooS@XOohd:402_ohd:401?l0003ooLAoo`000?l0000^oooo
o`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo04Oooooo0_l00003o`00>@03
o`000?lG0G?o5`5c00Go5`5c00Co0000oblOS?l_7hco00002_mB=i<2o`0000CoH4fT00?o0000oh=V
Z_n3IZX05?n3IZX00ol0003oXGn^oj5o[P0Joj5o[P03o`000?nkUk7o^iNa01go^iNa00?o0000omFa
]OoE/KD03OoE/KD00ol0003oeK6eomFa]@07omFa]@?o00003_ohd:43o`0002kooooo00?o0000oooo
ooooool03oooool001gooooo00?o0000ooooooooool0B?ooool2o`0000;o000i0_l00006oaL1L`05
o`000?l_7hco;an<oblOS?l000002OmB=i<00ol0003oH4fTof1=Y004of1=Y003o`000?n3IZ[oPfJZ
01CoPfJZ00?o0000oj5o[_nQOjh06_nQOjh00ol0003o^iNaok^G/@0Lok^G/@03o`000?oE/KGoeK6e
00koeK6e00?o0000omFa]OoE/KD02OoE/KD00ol0003on=2QooS@X@0=ooS@X@;o0000;_ooool00ol0
003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`18ooooo`04o`000?l003Wo000io`00
>@;o00001OlG0G<00ol0003o;an<oblOS002oblOS003o`000?mB=i?oDSNC00GoDSNC0_l00007of1=
Y003o`000?n3IZ[oPfJZ01GoPfJZ00?o0000oj5o[_nQOjh06OnQOjh00ol0003o^iNaok^G/@0Lok^G
/@03o`000?oE/KGoeK6e00ooeK6e00?o0000omFa]OoE/KD02?oE/KD00ol0003on=2QooS@X@0=ooS@
X@03o`000?oooooooooo02gooooo00?o0000ooooooooool03oooool001gooooo00?o0000oooooooo
ool0Aoooool2o`0000;o000i00?o0000o`00I_l000001OlG0G<00ol0003o;an<oblOS002oblOS003
o`000?mB=i?oDSNC00CoDSNC00?o0000of1=Y?mPCJ@01omPCJ@00ol0003oPfJZoh=VZP0Eoh=VZP03
o`000?nQOjkoXGn^01;oXGn^3?l0000Jok^G/@03o`000?oE/KGoeK6e00ooeK6e00?o0000omFa]OoE
/KD01ooE/KD00ol0003ol=Fgo`00000>ooS@X@03o`000?oooooooooo02gooooo00?o0000oooooooo
ool03oooool001gooooo0_l00018ooooo`07o`000?l003Wo000io`00>Ol0003o001Vo`000004oaL1
L`03o`000?l_7hco;an<00?o;an<00?o0000oe8gTomB=i<00omB=i<00ol0003oH4fTof1=Y008of1=
Y003o`000?n3IZ[oPfJZ01GoPfJZ00?o0000oj5o[_nQOjh01?nQOjh>o`0000OoXhVi00?o0000okZN
_?njW[`00_njW[`7o`0001?o^iNa00?o0000omFa]OoE/KD03ooE/KD00ol0003oeK6eomFa]@07omFa
]@04o`000?o`eKOol=Fgo`0000con=2Q0_l0000`ooooo`03o`000?oooooooooo00kooooo000Moooo
o`03o`000?oooooooooo04Oooooo00Co0000o`00>Ol003Wo00000ol006H01Ol0003o5`5coaL1LolG
0G?o000000Go;an<00Co0000oe8gTomB=i?oDSNC0_l0000<of1=Y003o`000?n3IZ[oPfJZ01;oPfJZ
2Ol0000Eoj>9^@03o`000?njW[co^Yjl00Wo^Yjl2?l0000;ok^G/@03o`000?oE/KGoeK6e00ooeK6e
00?o0000omFa]OoE/KD01_oE/KD00ol0003ol=Fgoo3E]`02oo3E]`03o`000?ohd:7on=2Q00Won=2Q
0_l0000`ooooo`03o`000?oooooooooo00kooooo000Mooooo`03o`000?oooooooooo04Oooooo00Co
0000o`00>Ol003Wo00000ol006H01?l0003o5`5coaL1Lol00007oblOS003o`000?mB=i?o000000ko
H4fT00?o0000oh=VZ_n3IZX03_n3IZX4o`0000;oRGBf00?o0000oj>9^OnSRKT06OnSRKT00ol0003o
^YjlokZN_00AokZN_0Oo00000onkUk400ol0003oeK6eomFa]@0@omFa]@03o`000?oE/KGoeK6e00Ko
eK6e00?o0000oo3E]oo`eKL00oo`eKL00ol0003on=2QooS@X@08ooS@X@;o0000<?ooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`18ooooo`03o`000?l003Wo000000Co001V
00?o0000oaL1Lol000002?l_7h`2o`0000ooH4fT00?o0000oh=VZ_n3IZX02on3IZX3o`0000KoRGBf
00?o0000oj>9^OnSRKT06OnSRKT00ol0003o^YjlokZN_00HokZN_0Go00004OoE/KD00ol0003oeK6e
omFa]@06omFa]@03o`000?o`eKOol=Fg00Col=Fg00?o0000ooS@XOohd:401_ohd:400ol0003oh]YU
o`00000`ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oooooooooo04Sooooo00?o
0000o`00>Ol000001?l006H00ol0003o5`5co`000008oblOS003o`000?mPCJCoH4fT00koH4fT00?o
0000oh=VZ_n3IZX01on3IZX4o`0000WoRGBf00?o0000oj>9^OnSRKT06OnSRKT00ol0003o^YjlokZN
_00KokZN_004o`000?o@]l;o0000o`0000ooeK6e00?o0000omFa]OoE/KD01OoE/KD00ol0003ol=Fg
oo3E]`06oo3E]`03o`000?ohd:7on=2Q00Gon=2Q00?o0000on;JIOl00000<?ooool00ol0003ooooo
ooooo`0>ooooo`007?ooool00ol0003oooooooooo`18ooooo`03o`000?l003Wo000000Co001V0_l0
0009oblOS003o`000?mPCJCoH4fT00koH4fT00?o0000oh=VZ_n3IZX00on3IZX4o`0000koRGBf00?o
0000oj>9^OnSRKT06?nSRKT00ol0003o^YjlokZN_00KokZN_004o`000?o@]l;od;O2om2g`P?o0000
3?oE/KD00ol0003oeK6eomFa]@05omFa]@03o`000?o`eKOol=Fg00Kol=Fg00?o0000ooS@XOohd:40
1Oohd:400ol0003oh]YUo`00000`ooooo`03o`000?oooooooooo00kooooo000Looooo`03o`000?oo
oooooooo04Oooooo00?o0000o`00>Ol000001Ol006H00ol0003o;an<oblOS007oblOS0;o00004OmP
CJ@00ol0003oPfJZo`000002o`0001;oRGBf00?o0000oj>9^OnSRKT06?nSRKT00ol0003o^YjlokZN
_00JokZN_003o`000?o@]l;od;O200God;O20_l00008omFa]@?o00001_oE/KD00ol0003ol=Fgoo3E
]`08oo3E]`03o`000?ohd:7on=2Q00Con=2Q0ol0000`ooooo`03o`000?oooooooooo00kooooo000L
ooooo`03o`000?oooooooooo04Oooooo00?o0000o`00>Ol000001Ol006H00ol0003o;an<oblOS006
oblOS004o`000?m4>Z7oA3ZQo`0000ooH4fT0ol0000EohUd]P03o`000?nSRKWoXhVi01SoXhVi00?o
0000okZN_?njW[`06_njW[`00ol0003od;O2om2g`P07om2g`P;o00000ooE/KD3o`0000;oeK6e00?o
0000omFa]OoE/KD01?oE/KD00ol0003ol=Fgoo3E]`09oo3E]`03o`000?ohd:7on=2Q00;on=2Q00Co
0000on;JIOl0003o0000<Oooool00ol0003oooooooooo`0=ooooo`007?ooool2o`0004Sooooo0_l0
0005o`00IP;o00002?l_7h`01?l0003oA3ZQod@jXOl0000>of1=Y003o`000?m]H;?o000001KoRGBf
00?o0000oj>9^OnSRKT06?nSRKT00ol0003o^YjlokZN_00JokZN_003o`000?o@]l;od;O200Wod;O2
0ol00006omFa]@03o`000?oE/KGoeK6e00;oeK6e00?o0000oo3E]oo`eKL02oo`eKL01_l0003on=2Q
ooS@XOohd:7o0000on;JI@;o0000<Oooool00ol0003oooooooooo`0=ooooo`006oooool00ol0003o
ooooooooo`18ooooo`;o00001Ol006H2o`0000Oo;an<00Go0000od@jXOm4>Z7oA3ZQo`00000<of1=
Y0;o00000om]H;<00ol0003oRGBfohUd]P0CohUd]P03o`000?nSRKWoXhVi01OoXhVi00?o0000okZN
_?njW[`06_njW[`00ol0003od;O2om2g`P07om2g`P?o00000oo@]l82o`0000GoeK6e00Go0000omFa
]OoE/KGoeK6eo`00000>oo3E]`06o`000?ohd:7on=2Qo`000?oRfVGo0000<_ooool00ol0003ooooo
ooooo`0=ooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?l006Ko001V00?o001V00Co
0000o`h=R?l>3HSo00001Ol_7h`00ol0003oA3ZQod@jX@03od@jX@03o`000?mPCJCoH4fT00SoH4fT
00?o0000ofeP/om]H;<00om]H;<00ol0003oRGBfohUd]P0DohUd]P03o`000?nSRKWoXhVi01KoXhVi
00?o0000okZN_?njW[`06_njW[`00ol0003od;O2om2g`P03om2g`PCo00002?o@]l82o`0000CoeK6e
00Co0000omFa]OoE/KGo00003oo`eKL2o`0000;oh]YU00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0=ooooo`006oooool00ol0003oooooooooo`18ooooo`03o`000?l006Ko001V00?o001V
00Co0000o`h=R?l>3HSo00001?l_7h`00ol0003oA3ZQod@jX@04od@jX@03o`000?mPCJCoH4fT00Oo
H4fT00?o0000ofeP/om]H;<01?m]H;<00ol0003oRGBfohUd]P0DohUd]P03o`000?nSRKWoXhVi01Ko
XhVi00?o0000okZN_?njW[`06_njW[`00ol0003od;O2om2g`P03o`0000kod;O20ol00002omFa]@;o
00004Oo`eKL01?l0003oh]YUon;JIOl0000booooo`03o`000?oooooooooo00gooooo000Kooooo`03
o`000?oooooooooo04Sooooo00?o0000o`00I_l006H00_l006H01Ol0003o3Pf8o`h=R?l>3HSo0000
00Co;an<00?o0000od@jXOm4>Z401?m4>Z400ol0003oH4fTof1=Y005of1=Y0;o00002?m]H;<00ol0
003oRGBfohUd]P0CohUd]P03o`000?nSRKWoXhVi01KoXhVi00?o0000okZN_?njW[`06_njW[`3o`00
01Cod;O21?l0000Aoo3E]`04o`000?oRfVGoh]YUo`0003;ooooo00?o0000ooooooooool03Oooool0
01_ooooo00?o0000ooooooooool0B?ooool00ol0003o001Vo`00IP02o`00IP05o`000?l>3HSo3Pf8
o`h=R?l000000ol_7h`00ol0003oA3ZQod@jX@06od@jX@03o`000?mPCJCoH4fT00?oH4fT00?o0000
ofeP/om]H;<02?m]H;<00ol0003oRGBfohUd]P0CohUd]P03o`000?nSRKWoXhVi01KoXhVi00?o0000
okZN_?njW[`05onjW[`3o`0001Wod;O20_l0000@oo3E]`;o00000_oRfVD00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo04Sooooo00Go0000o`00
I_l006Ko001Vo`000004o`h=R004o`000?l_7hco;an<o`0000WoA3ZQ00Co0000of1=Y?mPCJCoH4fT
0_l0000;ofeP/`03o`000?n9M;KoRGBf01?oRGBf00?o0000oj>9^OnSRKT05_nSRKT00ol0003o^Yjl
okZN_00CokZN_0Co00000_njW[`00ol0003od;O2om2g`P0Gom2g`P?o00003oo`eKL2o`0000;oh]YU
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0=ooooo`006oooool2o`0004Wooooo00Go
0000o`00I_l006Ko001Vo`000005o`h=R003o`000?l_7hco000000WoA3ZQ00Co0000of1=Y?mPCJCo
00003_m]H;<00ol0003oRGBfohUd]P0CohUd]P03o`000?nSRKWoXhVi01GoXhVi00?o0000okZN_?nj
W[`04?njW[`3o`0000Ko^Yjl00?o0000om2g`_o@]l805_o@]l800ol0003oi]S7onKHa`02o`0000go
l=Fg00?o0000onoaVol000000_oRfVD00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00co
oooo000Jooooo`03o`000?oooooooooo04Wooooo00Go000co`000?l006Ko001Vo`000005o`h=R0;o
00002om4>Z42o`0000ooKF2c00?o0000ohUd]_n9M;H04on9M;H00ol0003oXhVioj>9^@0Eoj>9^@03
o`000?njW[co^Yjl00go^Yjl0ol00009okZN_003o`000?o@]l;od;O201Kod;O200Co0000onKHaooV
f<Ooi]S70_l0000<oo3E]`03o`000?o_lI_o000000;oh]YU00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0<ooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo04Wooooo00Co000co`000?l006Ko00001_l>
3HP00ol0003oA3ZQod@jX@0:od@jX@03o`000?m]H;?oKF2c00koKF2c00?o0000ohUd]_n9M;H04On9
M;HNo`0000Wo^Yjl0ol0000;okZN_003o`000?o@]l;od;O201Kod;O200?o0000onKHaooVf<L00ooV
f<L2o`0000[ol=Fg00Ko0000onoaVoo_lI_o0000on;JIOl0000dooooo`03o`000?oooooooooo00co
oooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo04Wooooo00Co000co`000?l006Ko00001_l>3HP00ol0003oA3ZQod@jX@0:od@j
X@03o`000?m]H;?oKF2c00ooKF2c00?o0000ohUd]_n9M;H03?n9M;H4o`0000;oSh;100?o0000ojBC
`onTTl<05OnTTl<01?l0003o^:K7okRVaonhY/L9o`0000ko^Yjl00?o0000om2g`_o@]l805_o@]l80
0ol0003oi]S7onKHa`04onKHa`03o`000?o`eKOol=Fg00Sol=Fg00Ko0000onoaVoo_lI_o0000on;J
IOl0000dooooo`03o`000?oooooooooo00cooooo0003ooooo`03oa0@4?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`19ooooo`03o`00<ol0003o000000Ko3Pf800?o
0000obX_X_l000002_m4>Z400ol0003oEU>bo`00000@ofeP/`03o`000?n9M;KoRGBf00SoRGBf1?l0
0006ohn2`@03o`000?nTTl?oY9?301GoY9?300?o0000okRVaonhY/L00onhY/L3o`0000;o^:K71_l0
000:okZN_003o`000?o@]l;od;O201God;O200?o0000onKHaooVf<L01_oVf<L00ol0003ol=Fgoo3E
]`06oo3E]`07o`000?o_lI_oko6KonoaVol0003oh]YUo`00000dooooo`03o`000?oooooooooo00co
oooo0003ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`19ooooo`03o`00<ol0003o000000Ko3Pf800?o0000obX_X_l000002Om4>Z401?l0003oEU>b
oeIC/_l0000@ofeP/`03o`000?n9M;KoRGBf00CoRGBf1?l0000:ohn2`@03o`000?nTTl?oY9?301Go
Y9?300?o0000okRVaonhY/L00ol0000;okRVa`Oo00000_njW[`00ol0003od;O2om2g`P0Fom2g`P03
o`000?oVf<Ooi]S700Ooi]S700?o0000oo3E]oo`eKL01Oo`eKL01?l0003oko6KonoaVoo_lI/2o`00
03Gooooo00?o0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool02_ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0BOooool00ol003?o0000o`h=R006o`h=
R003o`000?lZ;j;o000000SoA3ZQ00Go0000oeIC/_mFDk;oEU>bo`00000AofeP/`03o`000?n9M;Ko
000000?o00003on?P/400ol0003oY9?3ojBC``0DojBC``?o00005OnhY/L4o`0001Kod;O200?o0000
onKHaooVf<L02OoVf<L00ol0003ol=Fgoo3E]`03oo3E]`03o`000?o_lI_oko6K00;oko6K0_l0000e
ooooo`03o`000?oooooooooo00cooooo0003ooooo`03oa0@4?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`00<ol0003o3Pf800Go3Pf800Go0000obX_
X_lZ;j;o:RnRo`000006od@jX@03o`000?mFDk;oEU>b00?oEU>b00?o0000ofeP/om]H;<03Om]H;<3
o`0001?oSh;100?o0000ojBC`onTTl<04?nTTl<5o`0001Wo^:K700?o0000ol^lc?l000000_l0000C
om2g`P03o`000?oVf<Ooi]S700[oi]S700?o0000oo3E]oo`eKL00_o`eKL00ol0003oko6KonoaV`02
onoaV`;o0000=_ooool00ol0003oooooooooo`0;ooooo`0000CoV9RHoooooonHV9SoMgMg3?ooool0
0ol0003oooooooooo`06ooooo`;o0000Boooool00ol003?o0000o`h=R005o`h=R005o`000?lZ;j;o
:RnRobX_X_l000001Om4>Z400ol0003oEU>boeIC/P04oeIC/P03o`000?m]H;?oKF2c00_oKF2c0_l0
00000omiL/3o0000ohn2`@0Cohn2`@03o`000?nTTl?oY9?300goY9?30ol00004ojBC``03o`000?nh
Y/Oo^:K701Ko^:K700?o0000ol^lc?o;_<`00oo;_<`2o`00013od;O200?o0000onKHaooVf<L02ooV
f<L2o`0000;ol=Fg00?o0000onoaVoo_lI/00oo_lI/2o`0003Kooooo00?o0000ooooooooool02ooo
ool00004oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`03o`000?oooooooooo04[ooooo00?o
000co`00L_l000001?l>3HP00ol0003o:RnRobX_XP02obX_XP03o`000?m4>Z7oA3ZQ00?oA3ZQ00?o
0000oeIC/_mFDk801OmFDk800ol0003oKF2cofeP/`09ofeP/`03o`000?miL/3oNG;000;oNG;000?o
0000ohn2`On?P/404On?P/400ol0003oY9?3ojBC``0:ojBC``?o00001onTTl<00ol0003o^:K7okRV
a`0FokRVa`03o`000?o;_<cobkc<00Gobkc<0ol0000=om2g`P03o`000?oVf<Ooi]S700coi]S70_l0
00000oo`eKOo0000onoaV`04onoaV`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02ooo
ool001Wooooo00?o0000ooooooooool0B_ooool00ol0003o001bo`000004o`h=R003o`000?lZ;j;o
:RnR00?o:RnR00Go0000od@jXOm4>Z7oA3ZQo`000008oeIC/P03o`000?m]H;?oKF2c00OoKF2c0_l0
0005ogUb`003o`000?n?P/7oSh;1017oSh;100?o0000ojBC`onTTl<01onTTl<3o`0000[oY9?300?o
0000okRVaonhY/L05_nhY/L00ol0003obkc<ol^lc008ol^lc0;o00002_o@]l800ol0003oi]S7onKH
a`0>onKHa`;o00001_o_lI/00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo000I
ooooo`03o`000?oooooooooo04[ooooo0ol00004o`h=R003o`000?lZ;j;o:RnR00?o:RnR00Co0000
od@jXOm4>Z7o00002OmFDk800ol0003oKF2cofeP/`05ofeP/`;o00002?miL/000ol0003oSh;1ohn2
`@0Aohn2`@03o`000?nTTl?oY9?300;oY9?31?l0000<ojBC``03o`000?nhY/Oo^:K701Ko^:K700?o
0000ol^lc?o;_<`02oo;_<`3o`0000Ood;O200?o0000onKHaooVf<L03ooVf<L00ol0003oko6Konoa
V`04onoaV`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool001Wooooo00?o0000
ooooooooool0B_ooool2o`000005o`00L_l0003o3Pf8o`h=R?l000001_lZ;j800ol0003oA3ZQo`00
000;oeIC/P03o`000?m]H;?oKF2c00;oKF2c0_l0000:ogUb`003o`000?n?P/7oSh;1017oSh;100?o
0000ojBC`ol000000_l0000@ojBC``03o`000?nhY/Oo^:K701Ko^:K700?o0000ol^lc?o;_<`03_o;
_<`2o`0000Cod;O200?o0000onKHaooVf<L03ooVf<L3o`0000Coko6K00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`1;ooooo`;o000000Go001b
o`000?l>3HSo3Pf8o`000007obX_XP03o`000?mFDk;oEU>b00[oEU>b00Go0000ofeP/om]H;?oKF2c
o`00000<ogUb`003o`000?n?P/7oSh;1013oSh;10ol0000CojBC``03o`000?nhY/Oo^:K701Ko^:K7
00?o0000ol^lc?o;_<`04?o;_<`3o`000003om2g`_l0003oi]S700ooi]S700Go0000ongh_ol0003o
ko6Ko`000003onoaV`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02oooool001Sooooo
00?o0000ooooooooool0Boooool2o`000004o`00L_l0003o3Pf8o`0000So:RnR00?o0000oeIC/_mF
Dk802_mFDk801?l0003oKF2co`000?l0000>ogUb`003o`000?n?P/7oSh;100coSh;10ol000000on?
P/7o0000ojBC``0CojBC``03o`000?nhY/Oo^:K701Go^:K700?o0000ol^lc?o;_<`05?o;_<`2o`00
013oi]S700Go0000ongh_ol0003oko6Ko`000002onoaV`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool02_ooool001Sooooo00?o0000ooooooooool0Boooool2o`000004o`00L_l0003o3Pf8
o`0000Oo:RnR00?o0000od9<]_l000003?mFDk800ol0003oNG;0ogUb`00>ogUb`003o`000?n?P/7o
Sh;100SoSh;11?l00004ohn2`@03o`000?nTTl?oY9?301;oY9?300?o0000okRVaonhY/L05OnhY/L0
0ol0003obkc<ol^lc00Dol^lc003o`000?oLf=Co000000koi]S700Co0000ongh_oo]n;oo00000_o_
lI/00ol0003oko6Ko`00000jooooo`03o`000?oooooooooo00[ooooo000Hooooo`;o0000C?ooool2
o`0000;o001b00?o3Pf8o`000?lZ;j801_lZ;j800ol0003o@Tbfo`00000<oeIC/P03o`000?miL/3o
NG;000ooNG;000?o0000ohn2`On?P/401?n?P/43o`0000WoSh;100?o0000ojBC`onTTl<04OnTTl<0
0ol0003o^:K7okRVa`0DokRVa`03o`000?o;_<cobkc<01Cobkc<00Go0000omcHe?oLf=Cog=SDo`00
000<onKHa`05o`000?o]n;ookORoongh_ol000000oo_lI/00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo00[ooooo000Hooooo`03o`000?oooooooooo04_ooooo0_l00002o`00LP03o`000?lZ
;j;o:RnR00Ko:RnR00Co0000od9<]_m2C;Ko00002_mFDk800ol0003oIVW1o`00000@ogUb`004o`00
0?n?P/7oSh;1ohn2`@?o00003?n?P/400ol0003oY9?3ojBC``0AojBC``03o`000?nhY/Oo^:K701Co
^:K700?o0000ol^lc?o;_<`04oo;_<`00ol0003og=SDomcHe003omcHe003o`000?oVf<Ooi]S700So
i]S700?o0000ongh_oo]n;l00oo]n;l00ol0003oko6KonoaV`02o`0003[ooooo00?o0000oooooooo
ool02_ooool001Sooooo00?o0000ooooooooool0C?ooool01?l0003o001bo`00L_l00007obX_XP05
o`000?m2C;Ko@Tbfod9<]_l000002OmFDk801Ol0003oIVW1ofIY`OmVJL7o0000013oNG;00ol0000<
ohn2`A_o00004onhY/L00ol0003obkc<ol^lc00Col^lc003o`000?oLf=Cog=SD00Cog=SD0_l00008
onKHa`03o`000?o]n;ookORo00?okORo00?o0000onoaVol000000_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00[ooooo000Gooooo`03o`000?oooooooooo04gooooo00Go0000o`00
L_l007;o01FNo`000006obX_XP03o`000?m2C;Ko@Tbf00;o@Tbf00?o0000oeIC/_mFDk801OmFDk80
0ol0003oIVW1ofIY`@02ofIY`@03o`000?miL/3oNG;000[oNG;01Ol00008ohn2`@Ko00000onDSl/0
0ol0003oYIc=ojFLc@0AojFLc@04o`000?ne[M3o]Jg@okF]d0Go00003OnhY/L00ol0003obkc<ol^l
c00Col^lc003o`000?oLf=Cog=SD00Oog=SD00?o0000onKHaooVf<L01?oVf<L00ol0003okORoongh
_`04ongh_`03o`000?o_lI_o000000;ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0:ooooo`005oooool00ol0003oooooooooo`1=ooooo`03o`000?l007;o001b00;o00001_lZ;j80
0ol0003o@Tbfod9<]P02od9<]P03o`000?mFDk;oEU>b00CoEU>b00?o0000ofIY`OmVJL401?mVJL40
0ol0003oNG;0ogUb`006ogUb`0?o00001?miL/001?l0003oSh;1ohn2`On?P/45o`0000WoU8o;00?o
0000ojFLcOnUW<d04OnUW<d00ol0003o]Jg@okF]d006okF]d0Go00002?nhY/L00ol0003obkc<ol^l
c00Bol^lc003o`000?oLf=Cog=SD00Wog=SD00?o0000onKHaooVf<L00_oVf<L00ol0003okORoongh
_`05ongh_`;o00001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo000G
ooooo`03o`000?oooooooooo04gooooo00Ko0000o`00L_l007;o0000o`0EW_l00004obX_XP03o`00
0?m2C;Ko@Tbf00Co@Tbf00?o0000oeIC/_mFDk800omFDk800ol0003oIVW1ofIY`@04ofIY`@03o`00
0?miL/3oNG;000?oNG;00ol00007ogUb`0Co00003onDSl/00ol0003oYIc=ojFLc@0@ojFLc@03o`00
0?ne[M3o]Jg@00_o]Jg@1Ol00003okRVa`03o`000?o;_<cobkc<01;obkc<00?o0000omcHe?oLf=@0
2_oLf=@01Ol0003oi]S7onKHaooVf<Oo000000OokORo0_l00005ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool02Oooool001Oooooo00?o0000ooooooooool0COooool01_l0003o001b
o`00L_l0003o01FNo`0000Co:RnR00?o0000od9<]_m2C;H01?m2C;H00ol0003oEU>boeIC/P02oeIC
/P03o`000?mVJL7oIVW100KoIVW100?o0000ogUb`?l000000_l00008ogUb`0;o000000?oPhC<o`00
0?nDSl/04?nDSl/00ol0003oYIc=ojFLc@0@ojFLc@03o`000?ne[M3o]Jg@013o]Jg@0ol0000Dol^l
c003o`000?oLf=Cog=SD00cog=SD00?o0000onKHaol000002?o]n;l00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool001Oooooo00?o0000oooooooo
ool0COooool01?l0003o001bo`00L_l00002o`0EWP05o`000?lZ;j;o:RnRobX_X_l000001om2C;H0
1?l0003oEU>boeIC/_l00007ofIY`@Co00002_miL/000ol0003oPhC<oh>4c002oh>4c003o`000?nD
Sl_oU8o;00koU8o;00?o0000ojFLcOnUW<d04?nUW<d00ol0003o]Jg@okF]d00BokF]d003o`000?o4
`=Ko000000;o00004?o;_<`00ol0003og=SDomcHe00=omcHe003o`000?o]n;ookORo00OokORo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000G
ooooo`03o`000?oooooooooo04gooooo00Co0000o`00L_l007;o00000_l05Ih01?l0003o:RnRobX_
X_l00008od9<]P03o`000?mFDk;o000000GoIVW10ol00003ofIY`@03o`000?miL/3oNG;000KoNG;0
0_l00005oh>4c003o`000?nDSl_oU8o;00koU8o;00?o0000ojFLcOnUW<d04?nUW<d00ol0003o]Jg@
okF]d00AokF]d003o`000?o4`=Koa<3F00?oa<3F0ol0000<ol^lc003o`000?oLf=Cog=SD00kog=SD
00?o0000ongh_oo]n;l01_o]n;l00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool02Oooool001Oooooo0_l0001>ooooo`04o`000?l007;o001bo`0000?o01FN
00?o0000obX_X_l000002Om2C;H01?l0003oIVW1ofIY`OmVJL43o`0000OoIVW100?o0000ogUb`?mi
L/000omiL/02o`0000SoPhC<00?o0000oiB?bonDSl/03OnDSl/00ol0003oYIc=ojFLc@0@ojFLc@03
o`000?ne[M3o]Jg@017o]Jg@00?o0000olC0e_o4`=H01_o4`=H3o`0000Sobkc<00?o0000omcHe?oL
f=@03_oLf=@2o`0000OokORo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04oooooo00?o0000o`00L_l00000
0ol05Ih00ol0003o:RnRo`000009od9<]PCo00002_mVJL400ol0003oNG;0ogUb`002ogUb`003o`00
0?n3Q<coPhC<00SoPhC<00?o0000oiB?bonDSl/03_nDSl/00ol0003oYIc=ojFLc@0>ojFLc@03o`00
0?ne[M3o]Jg@017o]Jg@00?o0000olC0e_o4`=H02_o4`=H3o`0000Gobkc<00?o0000omcHe?oLf=@0
3OoLf=@01?l0003ohoKEon?feOl00006ongh_`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`09ooooo`005_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?l007;o000000Co01FN00?o0000od9<]_m2C;H01Om2C;H5o`0000goIVW100Co0000ogUb`?l0003o
00003?n3Q<`00ol0003oU8o;oiB?b`0=oiB?b`03o`000?nUW<goYIc=00koYIc=00?o0000okF]d?ne
[M004One[M000ol0003oa<3FolC0eP0=olC0eP?o000000?obkc<o`000?oLf=@03_oLf=@01Ol0003o
hoKEon?feOoSm]Go000000GokORo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04oooooo00?o0000o`00L_l0
00001?l05Ih00ol0003o@Tbfod9<]P02od9<]P?o00000_m2C;H01?l0003oEfK7oeMVaol0000=ofIY
`@03o`000?n3Q<coPhC<00coPhC<00?o0000oiB?bonDSl/03OnDSl/00ol0003oYIc=ojFLc@0>ojFL
c@03o`000?ne[M3o]Jg@013o]Jg@00?o0000olC0e_o4`=H04Oo4`=H2o`0000kog=SD00?o0000on?f
eOoSm]D00_oSm]D00ol0003okORoongh_`02ongh_`;o00003oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo053ooooo0_l00004o`0EWPGo
00001Om2C;H01Ol0003oEfK7oeMVaomGI/Oo000000_oIVW10_l0000?oh>4c003o`000?nDSl_oU8o;
00coU8o;00?o0000ojFLcOnUW<d03_nUW<d00ol0003o]Jg@okF]d00@okF]d003o`000?o4`=Koa<3F
017oa<3F00?o0000om7Gg_l000003?oLf=@00ol0003ohoKEon?fe@04on?fe@05o`000?o]n;ookORo
ongh_ol000004Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo000Foooo
o`03o`000?oooooooooo053ooooo0_l00003o`0EWPCo00001_m2C;H00ol0003oEfK7oeMVa`02oeMV
a`03o`000?mVJL7oIVW100SoIVW100Co0000ogEncomeO/oo00003_n3Q<`00ol0003oU8o;oiB?b`0<
oiB?b`03o`000?nUW<goYIc=00koYIc=00?o0000okF]d?ne[M003one[M000ol0003oa<3FolC0eP0A
olC0eP04o`000?oAemkodMONom7GgP;o00002_oLf=@00ol0003ohoKEon?fe@04on?fe@04o`000?o]
n;ookORoo`0001;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`005_oo
ool00ol0003oooooooooo`1@ooooo`Go000000Co01FNo`000?lK@[co00001_m2C;H00ol0003oEfK7
oeMVa`03oeMVa`03o`000?mVJL7oIVW100KoIVW100?o0000ogEncomeO/l00_meO/l00ol0003oPhC<
oh>4c00<oh>4c003o`000?nDSl_oU8o;00coU8o;00?o0000ojFLcOnUW<d03OnUW<d00ol0003o]Jg@
okF]d00?okF]d003o`000?o4`=Koa<3F013oa<3F00?o0000om7Gg_oAemh01?oAemh00ol0003og=SD
omcHe006omcHe003o`000?oSm]GohoKE00GohoKE00Co0000ongh_oo]n;oo00004oooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04oooooo
1?l00004o`0EWP04o`000?lK@[co6d:lo`0000Go@Tbf00?o0000oeMVaomGI/L01?mGI/L00ol0003o
IVW1ofIY`@04ofIY`@03o`000?meO/ooMGk?00CoMGk?00?o0000oh>4c?n3Q<`02on3Q<`00ol0003o
U8o;oiB?b`0<oiB?b`03o`000?nUW<goYIc=00goYIc=00?o0000okF]d?ne[M003_ne[M000ol0003o
a<3FolC0eP0@olC0eP03o`000?oAemkodMON00KodMON00?o0000omcHe?oLf=@01?oLf=@00ol0003o
hoKEon?fe@07on?fe@;o00005Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00So
oooo000Eooooo`?o0000C?ooool3o`0000?ooooo00?o0000o`0EW_l05Ih00_l05Ih01Ol0003o6d:l
oa]2_?lK@[co000000?o@Tbf00?o0000oeMVaomGI/L01OmGI/L00ol0003oIVW1ofIY`@03ofIY`@03
o`000?meO/ooMGk?00GoMGk?00?o0000oh>4c?n3Q<`03?n3Q<`00ol0003oU8o;oiB?b`08oiB?baOo
00003One[M000ol0003oa<3FolC0eP0?olC0eP03o`000?oAemkodMON00SodMON0_l00003omcHe003
o`000?oSm]GohoKE00SohoKE0_l0000Fooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool0BOooool3o`0000Kooooo00?o0000o`0EW_l05Ih0
0_l05Ih00ol0003o6d:loa]2_002oa]2_004o`000?m2C;Ko@Tbfo`0000SoEfK700Go0000ofIY`OmV
JL7oIVW1o`000009ogEnc`03o`000?n3Q<coPhC<00_oPhC<00Co0000oiB?bonDSl_oU8o;1ol00003
oiRLeP03o`000?nUY]OoYJKG00goYJKG00Co0000ok:df_nb]=[o/[CJ1Ol00007okF]d003o`000?o4
`=Koa<3F00ooa<3F00?o0000om7Gg_oAemh02ooAemh00ol0003og=SDo`00000:on?fe@;o00006?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooo
oooo04Gooooo1?l0000:ooooo`05o`000?l05Iko01FNo`0EW_l000001?lK@[`01?l0003o@Tbfod9<
]_l00009oeMVa`03o`000?mVJL7o000000_oMGk?00?o0000oh>4c?n3Q<`02_n3Q<`4o`0000[oV9cF
00?o0000ojFVeonUY]L03OnUY]L00ol0003o/[CJok:dfP06ok:dfPGo00000_ne[M000ol0003oa<3F
olC0eP0>olC0eP03o`000?oAemkodMON00godMON00?o0000on?feOoSm]D02?oSm]D2o`0001Wooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003ooooooooo
o`12ooooo`?o00003_ooool2o`0000?o01FN00?o0000oa]2_?lK@[`00_lK@[`2o`0000_oEfK70_l0
000<ogEnc`03o`000?n3Q<coPhC<00OoPhC<0_l000000on<UMSo0000oiRLeP0<oiRLeP03o`000?nU
Y]OoYJKG00coYJKG00?o0000ok:df_nb]=X02onb]=X2o`000003olC0e_l0003oa<3F00goa<3F00?o
0000om7Gg_oAemh03?oAemh00ol0003oenoSo`000009on?fe@03o`000?o9o;co000001[ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`005Oooool00ol0003oooooooooo`0o
ooooo`?o00004_ooool01Ol0003o01FNo`0EW_l05Iko000000Go6d:l00?o0000oeMVaomGI/L02OmG
I/L2ofUme003o`000?meO/ooMGk?00WoMGk?00?o0000oh>4c?n3Q<`01On3Q<`2o`0000CoS9GH00?o
0000oiRLe_nHW=H02_nHW=H00ol0003oYJKGojFVe`0<ojFVe`03o`000?nb]=[o/[CJ00co/[CJ00?o
0000okg3gonm`ml00ol0000:olC0eP03o`000?oAemkodMON00codMON00Go0000omO_hooGkn?oenoS
o`000007on?fe@03o`000?o9o;co000001cooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`07ooooo`005?ooool00ol0003oooooooooo`0mooooo`?o00005_ooool01?l0003o01FNo`0E
W_l00005oa]2_003o`000?mGI/OoEfK700WoEfK700Co0000ofUme?mYOMCo00002omeO/l00ol0003o
PhC<oh>4c002oh>4c0;o00001on<UMP00ol0003oV9cFoiRLeP09oiRLeP03o`000?nUY]OoYJKG00co
YJKG00?o0000ok:df_nb]=X02onb]=X00ol0003o_L?Ookg3g`04okg3g`?o00001_o4`=H00ol0003o
dMONom7GgP0<om7GgP03o`000?oGkn?oenoS00;oenoS00?o0000on?feOoSm]D01?oSm]D01?l0003o
bOblo`000?l0000Mooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01oooool001Co
oooo00?o0000ooooooooool0>Oooool4o`0001Wooooo00Co0000o`0EW_l05Iko00001OlK@[`2o`00
00WoEfK700?o0000ofUme?mYOM@00_mYOM@00ol0003oMGk?ogEnc`09ogEnc`04o`000?n3Q<co0000
o`0000WoS9GH00?o0000oiRLe_nHW=H02_nHW=H00ol0003oYJKGojFVe`0;ojFVe`03o`000?nb]=[o
/[CJ00_o/[CJ00?o0000okg3gonm`ml01onm`ml3o`0000;oa<3F00?o0000om7Gg_oAemh03?oAemh0
0ol0003oenoSomO_h`03omO_h`03o`000?oSm]GohoKE00?ohoKE00Co0000olWl_?o9o;co00007ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooo
oooo03Kooooo0ol0000Nooooo`03o`000?l05Iko000000Go6d:l00?o0000ociUd?l000002?mGI/L0
0ol0003oJGgDofUme003ofUme003o`000?meO/ooMGk?00WoMGk?00?o0000ohbEf?n<UMP02_n<UMP0
0ol0003oV9cFoiRLeP09oiRLeP03o`000?nUY]OoYJKG00[oYJKG00?o0000ok:df_nb]=X02onb]=X0
0ol0003o_L?Ookg3g`0;okg3g`;o00003OoAemh2o`0000OoenoS00Go0000on?feOoSm]GohoKEo`00
0002olWl_003o`000?oooooooooo01kooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`07ooooo`005?ooool3o`0003?ooooo0ol0000Qooooo`03o`000?l05Iko000000Go6d:l00Co0000
ociUd?lnIM3o00001omGI/L00ol0003oJGgDofUme004ofUme003o`000?meO/ooMGk?00OoMGk?00?o
0000oh:Bf_l000002on<UMP00ol0003oV9cFoiRLeP09oiRLeP03o`000?nUY]OoYJKG00[oYJKG00?o
0000ok:df_nb]=X02onb]=X00ol0003o_L?Ookg3g`0;okg3g`04o`000?o5eNKoaMGVo`0000[odMON
00?o0000omO_hooGkn<01ooGkn<01?l0003ohoKEon?feOl00003olWl_003o`000?oooooooooo01oo
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0`ooooo`?o00009Oooool2o`0000Go6d:l00Go0000ociUd?lnIM3o?VG@o`000005oeMVa`03
o`000?mYOMCoJGgD00KoJGgD00?o0000ogEncomeO/l01OmeO/l01Ol0003oPY;Joh:Bf_n2T][o0000
00_oS9GH00?o0000oiRLe_nHW=H02OnHW=H00ol0003oYJKGojFVe`09ojFVe`03o`000?nb]=[o/[CJ
00[o/[CJ00?o0000okg3gonm`ml02onm`ml00ol0003oaMGVolGEiP02olGEiP03o`000?oAemkodMON
00KodMON00?o0000omO_hooGkn<02?oGkn<00ol0003ohoKEo`000003olWl_003o`000?oooooooooo
027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`002_ooool4o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool4o`0002Wooooo00?o0000oa]2_?lK
@[`00olK@[`00ol0003o?VG@ociUd002ociUd003o`000?mGI/OoEfK700;oEfK700?o0000ofUme?mY
OM@01omYOM@00ol0003oMGk?ogEnc`03ogEnc`03o`000?n2T][oPY;J00?oPY;J00?o0000ohbEf?n<
UMP02On<UMP00ol0003oV9cFoiRLeP08oiRLeP03o`000?nUY]OoYJKG00WoYJKG00?o0000ok:df_nb
]=X02_nb]=X00ol0003o_L?Ookg3g`0:okg3g`03o`000?o5eNKoaMGV00CoaMGV0_l00005om7GgP03
o`000?oGkn?oenoS00[oenoS00?o0000olWl_?o9o;`00_o9o;`00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Zooooo`?o0000;Oooool00ol0003o6d:loa]2_003oa]2_003o`00
0?lnIM3o?VG@00?o?VG@00Go0000oeMVaomGI/OoEfK7o`00000:ofUme005o`000?meO/ooMGk?ogEn
col000001on2T]X00ol0003oS9GHohbEf008ohbEf003o`000?nHW=KoV9cF00SoV9cF00?o0000ojFV
eonUY]L02OnUY]L00ol0003o/[CJok:dfP09ok:dfP03o`000?nm`moo_L?O00[o_L?O00?o0000olGE
i_o5eNH01oo5eNH01Ol0003odMONom7Gg_oAemko000000_oenoS00?o0000olgng_l000000oo9o;`0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool0
00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`?o0000<Oooool00ol0
003o6d:loa]2_003oa]2_003o`000?lnIM3o?VG@00?o?VG@00Co0000oeMVaomGI/Oo00002omYOM@0
0ol0003oMGk?o`000009oh:BfP03o`000?n<UMSoS9GH00SoS9GH00?o0000oiRLe_nHW=H02?nHW=H0
0ol0003oYJKGojFVe`08ojFVe`03o`000?nb]=[o/[CJ00Wo/[CJ00?o0000okg3gonm`ml02Onm`ml0
0ol0003oaMGVolGEiP09olGEiP03o`000?oAemko000000_oenoS00?o0000olgng_l000000oo9o;`0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`?o0000=?ooool2o`00
00Co6d:l00?o0000ociUd?lnIM001?lnIM02o`0000goJGgD0_l0000:oh:BfP03o`000?n<UMSoS9GH
00OoS9GH00?o0000oiRLe_nHW=H01_nHW=HAo`0000Oo/[CJ00?o0000okg3gonm`ml02Onm`ml00ol0
003oaMGVolGEiP0;olGEiP03o`000?oGkn?oenoS00SoenoS0_l00002olgngP04o`000?o9o;cobObl
o`0002Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`003?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo1?l0000hooooo`;o00000olK@[`00ol0
003o?VG@ociUd005ociUd0;o00003?mYOM@2ogZCg`03o`000?n2T][oPY;J00SoPY;J00?o0000ohbE
f?n<UMP01on<UMP00ol0003oV9cFoiRLeP05o`0000;oVj_R00?o0000ojBbh_nT/^802?nT/^801?l0
003o[K_Tojfki?n]^n@5o`0000;o/[CJ00?o0000okg3gonm`ml02?nm`ml00ol0003oaMGVolGEiP0:
olGEiP03o`000?o8i^co000000WoenoS00?o0000olgng_o=o]h00_o=o]h00ol0003obOblo`00000[
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool000cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Mooooo`?o0000?Oooool01Ol09k7o0000oa]2_?lK@[co
000000Oo?VG@0_mKP=h00ol0003oJGgDofUme008ofUme005o`000?mjTmooNY?OogZCgol000002_n2
T]X00ol0003oS9GHohbEf006ohbEf0?o00002?nKZn800ol0003oY;;RojBbhP07ojBbhP03o`000?n]
^nCo[K_T00Ko[K_T0ol00009okg3g`03o`000?o5eNKoaMGV00WoaMGV0_l00003olSVk003o`000?oG
kn?oenoS00GoenoS00?o0000olgng_o=o]h00_o=o]h00ol0003obOblo`00000]ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Jooooo`?o0000@?ooool01Ol0003o02Nao`000?lK@[co000000Oo?VG@00Co
0000oe^0g_mKP=ko00002OmYOM@00ol0003oNY?OogZCg`02ogZCg`;o00002On2T]X00ol0003oS9GH
ohbEf002ohbEf0?o000000?oU:OSo`000?nKZn802?nKZn800ol0003oY;;RojBbhP07ojBbhP03o`00
0?n]^nCo[K_T00Oo[K_T00?o0000okC6iol000000_l00005okg3g`03o`000?o5eNKoaMGV00SoaMGV
0_l00006olSVk003o`000?oGkn?oenoS00;oenoS0_l00005olgngP;o0000;oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Kooooo000:ooooo`03oeEEEOmVIVKo000000Kooooo0_l0
000Hooooo`?o0000A?ooool01?l0003o02Nao`000?l00007ociUd004o`000?mKP=koFh3Noe^0gP;o
00001omYOM@00ol0003oNY?OogZCg`04ogZCg`03o`000?n2T][oPY;J00OoPY;J00Co0000ohbEf?l0
003o00001OnDYn<00ol0003oVj_Roi^[hP06oi^[hP03o`000?nT/^;oY;;R00KoY;;R00?o0000ojfk
i?n]^n@01on]^n@00ol0003o]<KWokC6i`03okC6i`?o000000?o_L?Oo`000?o5eNH02Oo5eNH00ol0
003ob>K/olSVk006olSVk005o`000?oGkn?oenoSomO_hol000001oo=o]h00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool001;ooooo00?o0000oooo
ooooool05?ooool4o`0004Oooooo00?o0000o`0W/Ol09k400_l00007ociUd003o`000?mKP=koFh3N
00;oFh3N00?o0000ofUme?mYOM@00omYOM@00ol0003oNY?OogZCg`06ogZCg`03o`000?n2T][oPY;J
00KoPY;J0ol00007oiBWh`03o`000?nKZn;oVj_R00KoVj_R00?o0000ojBbh_nT/^801OnT/^800ol0
003o[K_Tojfki006ojfki003o`000?nda^Oo]<KW00Oo]<KW00?o0000olGEi_o5eNH01oo5eNH2o`00
00[ob>K/00?o0000omO_hol000001oo=o]h00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool04Oooool3o`0004co
oooo00Go0000o`0W/Ol0003o467Ho`000006ociUd003o`000?mKP=koFh3N00?oFh3N0_l00003ofUm
e003o`000?mjTmooNY?O00OoNY?O0_l00005oh:BfP05o`000?n?Y^GoSjKUohnViOl000001onDYn<0
0ol0003oVj_Roi^[hP05oi^[hP03o`000?nT/^;oY;;R00GoY;;R00?o0000ojfki?n]^n@01_n]^n@0
0ol0003o]<KWokC6i`06okC6i`?o^=7/0_l00004olGEiP;o00003Oo8i^`00ol0003ocOkNolgngP04
olgngP;o0000=?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo000Boooo
o`03o`000?oooooooooo00kooooo0ol0001@ooooo`04o`000?l09k7o0000oa1Qf0;o00001?lnIM00
0ol0003oFh3Noe^0gP05oe^0gP04o`000?mYOMCoJGgDo`0000_oNY?O00Go0000oh:Bf_n2T][oPY;J
o`000005ohnVi@03o`000?nDYn?oU:OS00GoU:OS00?o0000oi^[h_nKZn801?nKZn800ol0003oY;;R
ojBbhP05ojBbhP03o`000?n]^nCo[K_T00Go[K_T00?o0000okC6ionda^L01Onda^L00ol0003o^=7/
okSAk004okSAk0;o000000?oaMGVo`000?o8i^`02oo8i^`2o`000003olCckol0003ocOkN00?ocOkN
0ol0000fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o
0000ooooooooool02oooool3o`0005?ooooo00Co0000o`0W/Ol09k7o00000_l@HMP01Ol0003o?VG@
ociUd?lnIM3o000000SoFh3N00?oJGgDo`000?mjTml03?mjTml2oh:BfP03o`000?n?Y^GoSjKU00Go
SjKU0_l00005oiBWh`03o`000?nKZn;oVj_R00GoVj_R00?o0000ojBbh_nT/^801?nT/^800ol0003o
[K_Tojfki004ojfki003o`000?nda^Oo]<KW00Go]<KW00?o0000okSAk?nhdN`01onhdN`00ol0003o
b>K/olSVk009olSVk0;o00000_o4lnl01?l0003ocOkNolgng_o=o]h2o`000003ok3ibol0003ooooo
03Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`004_ooool00ol0003o
ooooooooo`07ooooo`Co0000Eoooool00ol0003o02Nao`000003oa1Qf004o`000?lnIM3o?VG@o`00
00WoFh3N0_l0000=ogZCg`;o00002On?Y^D00ol0003oU:OSoiBWh`03oiBWh`03o`000?nKZn;oVj_R
00CoVj_R00?o0000ojBbh_nT/^800onT/^800ol0003o[K_Tojfki004ojfki003o`000?nda^Oo]<KW
00Co]<KW0_l00008okSAk003o`000?nifo7o000000Wob>K/0_l00004olCck`04o`000?o=o]kocOkN
o`0000;o/?W;00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Gooooo000Booooo`03o`000?oooooooooo00Cooooo0ol0001Kooooo`;o000000?o02Nao`00
0?l@HMP00_l@HMP2o`000003ociUd?l0003oFh3N00OoFh3N00?o0000og:Giol000000_l0000:ogZC
g`04o`000?n;YnSo0000o`0000SoSjKU00?o0000oiBWhonDYn<00onDYn<00ol0003oVj_Roi^[hP03
oi^[hP03o`000?nT/^;oY;;R00?oY;;R00?o0000ojfki?n]^n@01?n]^n@00ol0003o]<KWokC6i`03
okC6i`03o`000?nhdNco^=7/00Go^=7/0_l00004okWKl@03o`000?o8i^cob>K/00Cob>K/0_l00006
olCck`?o00000_n`nL/00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool0017ooooo00?o0000ooooooooool00_ooool3o`0005oooooo00Co0000o`0W
/Ol09k7o00001?l@HMP00olnIM3o0000oe^0gP07oe^0gP03o`000?mbUnOoLYOW00;oLYOW0_l00008
ogZCg`04o`000?n;YnSoRjOXoh^Wj0;o00001on?Y^D2o`0000CoU:OS00Co0000oi^[h_nKZn;oVj_R
2ol00002ojfki003o`000?nda^Oo]<KW00?o]<KW00?o0000okSAk?nhdN`01?nhdN`2o`0000Oo^M_a
00Co0000olSVk?o8i^cob>K/0_l00007olCck`;o00000on`nL/00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool0017ooooo00?o0000ooooool00000
0_l0001Sooooo`03o`000?l09k7o000000Go467H0_l00008oe^0gP03o`000?mbUnOoLYOW00?oLYOW
0_l00006ogZCg`03o`000?n;YnSoRjOX00?oRjOX0_l00007ohnVi@04o`000?nDYn?oU:OSoiBWh`Co
00000_nM_>h00ol0003oXKk]oj6nk@02oj6nk@04o`000?nU`^koYL;^ojG2kPGo00000_nda^L00ol0
003o^=7/okSAk004okSAk003o`000?nifo7o^M_a00Oo^M_a00Co0000olSVk?l0003o00002Oo4lnl0
1Ol0003o/?W;ok3ibon`nL_o000003oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`04ooooo`004Oooool2o`0006Oooooo00?o0000o`0W/Ol000001?l@HMP01?l0003oA8OYo`000?l0
0006oe^0gP03o`000?mbUnOoLYOW00GoLYOW0ol00002ogZCg`03o`000?n;YnSoRjOX00KoRjOX0_l0
0006ohnVi@03o`000?nDYn?o000000?oVk__00Go0000oiflk_nM_>koWKc^o`000003oj6nk@03o`00
0?nU`^koYL;^00;oYL;^00Co0000ojS7konXanooZ<O_0_l00005okSAk0;o00002onifo400ol0003o
a??_olCck`05olCck`?o000000Co^OS]o`000?n`nL_o0000@_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Cooooo000Cooooo`03o`000?oooooooooo06Gooooo0_l00005oa1Qf003
o`000?m4QnWoA8OY00?o00000omKP=h00ol0003oLYOWog:Gi`08og:Gi`03o`000?mjTmoo000000[o
RjOX0_l00004ohnVi@?o00001?nK^nl01?l0003oWKc^oiflk_l00003oj6nk@05o`000?nU`^koYL;^
ojG2k_l000000onXanl01_l0003oZLcbojW<l_nYc?;o0000okSAk0;o00002Onifo42o`0000;o]n?e
00?o0000olCckoo4lnl00_o4lnl3o`0000?o^OS]0ol00014ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01?ooool001Cooooo0_l0001Vooooo`;o00001Ol@HMP00ol0003oA8OYodB7
j@02odB7j@;o000000?oFh3No`000?mbUnL02ombUnL3o`0000[oRjOX0_l000000on?Y^Go0000oi^k
k`02oi^kk`;o00000onK^nl01?l0003oWKc^oiflk_l00002oj6nk@04o`000?nU`^koYL;^o`0000;o
Z<O_0_l00004ojW<lP;o00001_nifo43o`0000Ko]n?e00?o0000olCckoo4lnl00_l00005okWhk@?o
0000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo000Fooooo`03o`00
0?oooooo000006Cooooo00?o02Nao`000?l@HMP01?l@HMP00ol0003oA8OYodB7j@03odB7j@03o`00
0?mKP=ko000000_oLYOW00?o0000ohN[kOn7Znd00ol00009oh^Wj0?o00001?nK^nl2o`0000;oVk__
00Go0000oiflk_l0003oXKk]o`000002ojG2kP04o`000?nXanoo0000o`0000?oZLcb0ol000001?nY
coCo0000okWKlOnifo44o`0000So]n?e1?l00006okWhk@?o0000Aoooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Cooooo000Gooooo`;o0000IOooool00ol0003o467Hoa1Qf003oa1Q
f003o`000?m4QnWoA8OY00GoA8OY0ol00009og:Gi`03o`000?n7ZngoQj_]00?oQj_]1?l00005oh^W
j003o`000?nJ^nooV[__00Co00000_nK^nl2o`000005oi^kkol0003o0000oj6nkOl000000_nU`^h2
o`0000;oZLcb0ol00003ojW?m0Co00003?nghoD00ol0003o^OS]okWhk@06okWhk@;o0000B_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo000Hooooo`;o0000IOooool00ol0
003o467Hoa1Qf003oa1Qf003o`000?m4QnWoA8OY00CoA8OY00?o0000ofVPlOmYX?401Ol00005og:G
i`03o`000?n7ZngoQj_]00KoQj_]0ol000000on;YnSo0000oiZkk`06oiZkk`?o000000?oVk__o`00
0?l000000ol000000onU`^ko0000o`000003o`000003ojW?m?l0003o000000?o00000_nXdOH00ol0
003o]n?eokOSm@04okOSm@Go00000_ncioL00ol0003o^OS]okWhk@05okWhk@;o0000C?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo000Jooooo`03o`000?oooooooooo06?o
oooo0_l00004oa1Qf003o`000?m4QnWoA8OY00CoA8OY00?o0000ofVPlOmYX?401?mYX?44o`000003
og:Giol0003oQj_]00[oQj_]2_l00002oiZkk`go00001onXdOH00ol0003o]n?eo`000004o`0000Ko
/nOg00?o0000okWhkOnin>d01Ol000000on7iK;o0000ooooo`1=ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool001_ooooo0_l000000ooooooo0000ooooo`1Rooooo`;o0000
0_l@HMP00ol0003oA8OYodB7j@05odB7j@03o`000?mYX?7oJJ3a00OoJJ3a2Ol00005ohN[k@03o`00
0?nI_?3oVKc`00KoVKc`6?l0000:ok?Wm`Co00000_nWmnX2o`000003ohOU/_l0003ooooo04oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`007Oooool2o`0006Cooooo1Ol0
0007odB7j@03o`000?mYX?7oJJ3a00OoJJ3a00?o0000oh>alon3/O<01On3/O<>o`0000?oV;kb0ol0
00000onIb?Oo0000o`000009o`0000?oYm7f00?o0000ok?WmoncioL00oncioL2o`0000Co/nOg0_l0
0004ojOgjP04o`000?n7iK;o0000o`00057ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`03ooooo`007_ooool00ol0003oooooooooo`1Tooooo`04o`000?l0EKko0000o`0000OoA8OY
00?o0000ofVPlOmYX?401omYX?400ol0003oPk7coh>al`0;oh>al`03o`000?nH__;oV;kb00CoV;kb
1Ol000001OnIb?Oo0000o`000?nRd?So000000;oYM7g0_l00004ojKAmPWo00001?n/j?T00ol0003o
YoOZojOgjP03ojOgjPCo0000E?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?o
oooo000Oooooo`;o0000I_ooool00ol0003o05Fno`000003o`0000CoA8OY00?o0000ofVPlOmYX?40
1omYX?400ol0003oPk7coh>al`0;oh>al`03o`000?nH__;oV;kb00?o00000_nH`oD01?l0003oVLSg
oiW8monIb?L2o`0000;oX]3h00Co0000ojGAmonUdOOoYM7g0ol000000onVdOKo0000ojcXn@0:ojcX
n@03o`000?nWmn[oYoOZ00?oYoOZ0ol0001Gooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00oooool0027ooooo00?o0000ooooooooool0I?ooool2o`000003o`1E__lUT>go9I3]00Ko
00002OmYX?400ol0003oPk7coh>al`08oh>al`;o000000?oPk7co`000?l000000onH`oD2o`0000?o
VLSg00Co0000oig=n?nMcOSo00000_nRd?P00ol0003oYM7gojGAm`02ojGAm`Go00002?n/j?T01?l0
003oYoOZojOgj_nWmnX4o`0005[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`008_ooool3o`0006Gooooo00Co0000o`1E__l0EKko00001?lUT>d8o`0000?oJJ3a00Co0000
oh>alon3/O?oPk7c1_l00005oh6kn@03o`000?nH`oGo000000CoVLSg00Go0000oig=n?nMcOSoWLgh
o`000003oj;@n004o`000?nUdOOo0000o`0000GoXnKk1?l00003ojcXn@Oo0000GOooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Tooooo`03o`000?oooooooooo06Cooooo
0_l000000ol0EKko0000o`000005obF@k@03o`000?mN[_[oGZkj00;oGZkj1ol0000<oh6kn@Co0000
0_nIb?L01Ol0003oWLghoig=n?nMcOSo000000;oX]3h1?l0000;oj?Vn`?o000000CoSNkWo`000?l0
003o0000H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo000Uooooo`;o
0000I_ooool2o`000003o`1E__l0003o000000Go9I3]0_l00007oej^nP?o00001_n1^oT3o`0000Go
P/Sn2Ol00004oiKPoP;o00001_nSi_/3o`0000?oSNkW0_l0001Rooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00_ooool002Oooooo00?o0000ooooooooool0IOooool00ol0003o05Fn
o`1E_P02o`0000Go9I3]00?o0000oej^n_mN[_X01omN[_X2o`000004oh6knOl0003o0000o`0000Wo
P/Sn00?o0000ohWEoon9eOl00_n9eOl00ol0003oU^3noiKPoP06oiKPoP03o`000?nSi__oXnKk00?o
00001?n=k^L2o`0006Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00
:?ooool00ol0003oooooo`00001Uooooo`?o000000?o05Fno`000?lUT>d01?lUT>d2o`0000OoGZkj
00?o0000oej^n_l000000_n2b?h00ol0003oP/Snoh;8oP06oh;8oP03o`000?n9eOooRMGo00?oRMGo
00?o0000oiKPo_nFh?h01_nFh?h6o`0000;oSNkW0_l0001Xooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04ooooo`;o0000I_oo
ool00ol0003oooooo`000003o`0000Go9I3]0_l00002oej^nP?o00001_mH__/5o`0000;oP/Sn00?o
0000ohWEoon9eOl01On9eOl00ol0003oU^3noiKPoP05o`0000GoLMoZ0ol0001[ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool00_ooool0023ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo2_l0000>oeRnn`go00001OmagnX5
o`0006oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`005Oooool6o`00
00Gooooo00?o0000ooooooooool02Oooool2o`0006?ooooo00?o0000ooooooooool01_ooool00ol0
003o2iOGo`^Ge`04o`^Ge`Go00001omH__/00ol0003oGLocoeg?l`08oeg?l`03o`000?magn[oLMoZ
00Go0000M?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`0:ooooo`Co
00001?l;UmL4o`0000;oF;kk00?o0000oeg?lomMco<00omMco<:o`0007Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`008?ooool00ol0003oooooooooo`0<ooooo`;o0000
H?ooool00ol0003oooooooooo`0?ooooo`Co00000ol;UmL2o`000003oeg?lol0003o000000Oo0000
P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo000Pooooo`03o`000?oo
oooooooo00gooooo0_l0001Oooooo`03o`000?oooooooooo01?ooooo1_l0002:ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`01ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o000000?oooooo`00
0?ooool0F?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00Oooool003Gooooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000hooooo`05o`000?oo
ooooooooooooool00000Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00Oooool003Wooooo00Co0000oooooooooooo0000Doooool00ol0003ooooo
ooooo`2Yooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000jooooo`?o0000Dooo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000l
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08
ooooo`7o00000Oooool1ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0Zoooool00ol0
003oooooooooo`07ooooo`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00001>ooooo`03
o`000?oooooooooo0:cooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0043ooooo
0_l0001>ooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool0047ooooo0_l0001=ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo0Oooool004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003ooooool0003ooooo
04Oooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`04ooooo`7o00000Oooool004Ko
oooo0_l00018ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool00oooool1o`00007o
oooo000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0
003o<S8b0_l00017ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool00_ooool1o`00
007ooooo000booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b
<_oooooo0000A_ooool00ol0003oooooooooo`2booooo`05o`000?ooooooooooooooool000000Ooo
ool002[ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03o`0004?ooooo00?o0000ooooooooool0/oooool01?l0003oooooooooool00001ooooo`00<_oo
ool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00Ol0000003;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l00010oooo
o`03o`000?oooooooooo0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`0:ooooo`;o0000?_ooool00ol0003oooooooooo`2foooo
o`;o0000000booooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l0000moooo
o`03o`000?oooooooooo0;Gooooo0ol0000005?ooooo00Go0000ooooooooooooooooo`00000hoooo
o`03o`000?oooooooooo0;3ooooo1Ol00003ooooo`00E?ooool01?l0003oooooooooool0000hoooo
o`03o`000?oooooooooo0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o0000oooooooo
ool0Z?ooool4o`0000cooooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
Y?ooool5o`00013ooooo001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Pooooo`Co00005Ooo
ool005[ooooo00?o0000ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co00006Oooool0
05_ooooo0_l0000booooo`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool01?l0003ooooo
ooooool0000]ooooo`03o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3o`0002gooooo
00?o0000ooooooooool0R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Q_ooool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_oo
ool2o`0002_ooooo00?o0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo07gooooo1?l0
000hooooo`00Doooool01Ol@413ooooooooooooooooo410@00gooooo0_l0000Xooooo`03o`000?oo
oooooooo07Wooooo1?l0000looooo`00Doooool01Ol0003ooooooooooooooooo000000oooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?ooooo00Go0000
ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
L?ooool4o`0004Gooooo001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3o`0002?ooooo
00?o0000ooooooooool0Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
4_ooool2o`0002?ooooo00?o0000ooooooooool0Ioooool4o`0004kooooo001Cooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h05?ooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool0
Hoooool4o`0005;ooooo001^ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Go0000E_oo
ool006oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co0000Foooool0
073ooooo0_l0000Mooooo`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_ooool00ol0003o
ooooo`00000Jooooo`03o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2o`0001[ooooo
00?o0000ooooooooool0COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0BOooool4o`0006cooooo001fooooo`;o000000?oooooo`000?ooool05?ooool0
0ol0003oooooooooo`14ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`000?oooooooooo
043ooooo1?l0001eooooo`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_o
oooo1Ol0001iooooo`00N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0
=oooool4o`0007kooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@03ooooo`;o00004Oooool00ol0003oooooooooo`0cooooo`Co
0000P_ooool006?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`03ooooo`;o00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_ooool006?ooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oooooooooo02Oo
oooo1?l0002?ooooo`00Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0
003o<S8bolc<c009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool5o`00
09?ooooo001Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0<oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07_ooool4o`0009Sooooo001Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o00001oooool0
0ol0003oooooooooo`0Iooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Q
ooooo`00Qoooool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo0029ooooo`;o
00000oooool00ol0003oooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`Co0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05ooooo`Co0000
/_ooool008gooooo0_l000000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o0000^oooool0
0?ooooooC?ooool00?ooooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30ooooo`00Q_oo
ool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0
003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003ooooo
ooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGoIVIVo`000034
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.11022e-16 1.16608 [
[.12217 .21659 -11.7005 -9 ]
[.12217 .21659 .29953 0 ]
[.23559 .16868 -22.4836 -9 ]
[.23559 .16868 1.51642 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.47931 .0658 -15.4866 -9 ]
[.47931 .0658 2.51337 0 ]
[.61048 .01049 -4.93287 -9 ]
[.61048 .01049 1.06713 0 ]
[.03854 .84676 -6.86993 0 ]
[.03854 .84676 5.13007 9 ]
[.13385 .91358 -13.3727 0 ]
[.13385 .91358 10.6273 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.29978 1.02991 -9.57473 0 ]
[.29978 1.02991 8.42527 9 ]
[.37245 1.08085 -3.12828 0 ]
[.37245 1.08085 2.87172 9 ]
[.06876 .29036 -12 -2.64256 ]
[.06876 .29036 0 6.35744 ]
[.05232 .3933 -24 -2.73412 ]
[.05232 .3933 0 6.26588 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01551 .6237 -18 -2.94138 ]
[.01551 .6237 0 6.05862 ]
[-0.00517 .7532 -6 -3.05931 ]
[-0.00517 .7532 0 5.94069 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08224 .2848 m
.08897 .28202 L
s
[(-1)] .06876 .29036 1 -0.41276 Mshowa
.06589 .38798 m
.07267 .38531 L
s
[(-0.5)] .05232 .3933 1 -0.39242 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.02929 .61893 m
.03617 .61655 L
s
[(0.5)] .01551 .6237 1 -0.34636 Mshowa
.00871 .74875 m
.01565 .74653 L
s
[(1)] -0.00517 .7532 1 -0.32015 Mshowa
.125 Mabswid
.07906 .30484 m
.08311 .30319 L
s
.07584 .32518 m
.07989 .32354 L
s
.07257 .34581 m
.07663 .34418 L
s
.06925 .36674 m
.07332 .36512 L
s
.06247 .40953 m
.06655 .40795 L
s
.059 .43141 m
.06309 .42984 L
s
.05549 .45361 m
.05957 .45206 L
s
.05191 .47615 m
.05601 .47462 L
s
.0446 .52228 m
.04871 .52078 L
s
.04086 .54588 m
.04498 .5444 L
s
.03706 .56985 m
.04118 .56838 L
s
.03321 .5942 m
.03733 .59275 L
s
.0253 .64406 m
.02944 .64265 L
s
.02126 .6696 m
.0254 .66821 L
s
.01714 .69556 m
.0213 .69418 L
s
.01296 .72194 m
.01712 .72058 L
s
.08537 .26504 m
.08941 .26336 L
s
.00439 .77602 m
.00856 .7747 L
s
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.41813 .53403 m .4008 .57568 L .4726 .59313 L p .739 .621 .727 r
F P
0 g
s
.4726 .59313 m .47959 .55072 L .41813 .53403 L p .739 .621 .727 r
F P
0 g
s
.46686 .63621 m .4726 .59313 L .4008 .57568 L p .744 .598 .695 r
F P
0 g
s
.47959 .55072 m .4726 .59313 L .54343 .59584 L p .681 .558 .71 r
F P
0 g
s
.4726 .59313 m .46686 .63621 L .54505 .63614 L p .676 .53 .679 r
F P
0 g
s
.54505 .63614 m .54343 .59584 L .4726 .59313 L p .676 .53 .679 r
F P
0 g
s
.43756 .49513 m .41813 .53403 L .47959 .55072 L p .732 .641 .758 r
F P
0 g
s
.47959 .55072 m .48761 .50987 L .43756 .49513 L p .732 .641 .758 r
F P
0 g
s
.48761 .50987 m .47959 .55072 L .54141 .55511 L p .684 .586 .74 r
F P
0 g
s
.54343 .59584 m .54141 .55511 L .47959 .55072 L p .681 .558 .71 r
F P
0 g
s
.4008 .57568 m .3863 .61918 L .46686 .63621 L p .744 .598 .695 r
F P
0 g
s
.46259 .67892 m .46686 .63621 L .3863 .61918 L p .748 .573 .658 r
F P
0 g
s
.46686 .63621 m .46259 .67892 L .54622 .67535 L p .67 .499 .645 r
F P
0 g
s
.54622 .67535 m .54505 .63614 L .46686 .63621 L p .67 .499 .645 r
F P
0 g
s
.54141 .55511 m .54343 .59584 L .60507 .58582 L p .624 .506 .698 r
F P
0 g
s
.54343 .59584 m .54505 .63614 L .61149 .62273 L p .61 .47 .666 r
F P
0 g
s
.61149 .62273 m .60507 .58582 L .54343 .59584 L p .61 .47 .666 r
F P
0 g
s
.54141 .55511 m .53899 .5147 L .48761 .50987 L p .684 .586 .74 r
F P
0 g
s
.53899 .5147 m .54141 .55511 L .59665 .54781 L p .636 .541 .73 r
F P
0 g
s
.60507 .58582 m .59665 .54781 L .54141 .55511 L p .624 .506 .698 r
F P
0 g
s
.36746 .50666 m .34148 .54466 L .4008 .57568 L p .799 .696 .752 r
F P
0 g
s
.4008 .57568 m .41813 .53403 L .36746 .50666 L p .799 .696 .752 r
F P
0 g
s
.3863 .61918 m .4008 .57568 L .34148 .54466 L p .816 .682 .716 r
F P
0 g
s
.45847 .45948 m .43756 .49513 L .48761 .50987 L p .724 .661 .787 r
F P
0 g
s
.48761 .50987 m .49644 .47122 L .45847 .45948 L p .724 .661 .787 r
F P
0 g
s
.49644 .47122 m .48761 .50987 L .53899 .5147 L p .686 .615 .771 r
F P
0 g
s
.3863 .61918 m .37537 .6633 L .46259 .67892 L p .748 .573 .658 r
F P
0 g
s
.45998 .72002 m .46259 .67892 L .37537 .6633 L p .75 .543 .616 r
F P
0 g
s
.46259 .67892 m .45998 .72002 L .54693 .71277 L p .663 .465 .607 r
F P
0 g
s
.54693 .71277 m .54622 .67535 L .46259 .67892 L p .663 .465 .607 r
F P
0 g
s
.39642 .47221 m .36746 .50666 L .41813 .53403 L p .78 .708 .783 r
F P
0 g
s
.41813 .53403 m .43756 .49513 L .39642 .47221 L p .78 .708 .783 r
F P
0 g
s
.54505 .63614 m .54622 .67535 L .616 .65819 L p .595 .434 .633 r
F P
0 g
s
.616 .65819 m .61149 .62273 L .54505 .63614 L p .595 .434 .633 r
F P
0 g
s
.34148 .54466 m .31961 .5855 L .3863 .61918 L p .816 .682 .716 r
F P
0 g
s
.37537 .6633 m .3863 .61918 L .31961 .5855 L p .831 .663 .674 r
F P
0 g
s
.53899 .5147 m .53622 .47539 L .49644 .47122 L p .686 .615 .771 r
F P
0 g
s
.53622 .47539 m .53899 .5147 L .58615 .50935 L p .648 .577 .762 r
F P
0 g
s
.59665 .54781 m .58615 .50935 L .53899 .5147 L p .636 .541 .73 r
F P
0 g
s
.42737 .44165 m .39642 .47221 L .43756 .49513 L p .761 .717 .811 r
F P
0 g
s
.43756 .49513 m .45847 .45948 L .42737 .44165 L p .761 .717 .811 r
F P
0 g
s
.54622 .67535 m .54693 .71277 L .6187 .69203 L p .579 .395 .597 r
F P
0 g
s
.6187 .69203 m .616 .65819 L .54622 .67535 L p .579 .395 .597 r
F P
0 g
s
.4804 .42723 m .45847 .45948 L .49644 .47122 L p .715 .681 .817 r
F P
0 g
s
.49644 .47122 m .50593 .43525 L .4804 .42723 L p .715 .681 .817 r
F P
0 g
s
.50593 .43525 m .49644 .47122 L .53622 .47539 L p .687 .645 .802 r
F P
0 g
s
.31961 .5855 m .30306 .62802 L .37537 .6633 L p .831 .663 .674 r
F P
0 g
s
.36867 .7065 m .37537 .6633 L .30306 .62802 L p .844 .637 .622 r
F P
0 g
s
.37537 .6633 m .36867 .7065 L .45998 .72002 L p .75 .543 .616 r
F P
0 g
s
.53622 .47539 m .53315 .43802 L .50593 .43525 L p .687 .645 .802 r
F P
0 g
s
.53315 .43802 m .53622 .47539 L .57362 .47135 L p .658 .616 .795 r
F P
0 g
s
.58615 .50935 m .57362 .47135 L .53622 .47539 L p .648 .577 .762 r
F P
0 g
s
.4592 .75824 m .45998 .72002 L .36867 .7065 L p .748 .506 .565 r
F P
0 g
s
.45998 .72002 m .4592 .75824 L .54715 .74775 L p .652 .426 .563 r
F P
0 g
s
.54715 .74775 m .54693 .71277 L .45998 .72002 L p .652 .426 .563 r
F P
0 g
s
.58615 .50935 m .59665 .54781 L .64345 .52982 L p .593 .509 .729 r
F P
0 g
s
.59665 .54781 m .60507 .58582 L .65667 .56528 L p .574 .467 .695 r
F P
0 g
s
.65667 .56528 m .64345 .52982 L .59665 .54781 L p .574 .467 .695 r
F P
0 g
s
.57362 .47135 m .58615 .50935 L .62653 .49405 L p .612 .551 .763 r
F P
0 g
s
.64345 .52982 m .62653 .49405 L .58615 .50935 L p .593 .509 .729 r
F P
0 g
s
.60507 .58582 m .61149 .62273 L .66646 .59977 L p .553 .425 .66 r
F P
0 g
s
.66646 .59977 m .65667 .56528 L .60507 .58582 L p .553 .425 .66 r
F P
0 g
s
.45958 .415 m .42737 .44165 L .45847 .45948 L p .739 .723 .837 r
F P
0 g
s
.45847 .45948 m .4804 .42723 L .45958 .415 L p .739 .723 .837 r
F P
0 g
s
.57362 .47135 m .55923 .43499 L .53315 .43802 L p .658 .616 .795 r
F P
0 g
s
.55923 .43499 m .57362 .47135 L .6059 .45903 L p .63 .596 .797 r
F P
0 g
s
.62653 .49405 m .6059 .45903 L .57362 .47135 L p .612 .551 .763 r
F P
0 g
s
.54693 .71277 m .54715 .74775 L .61962 .72415 L p .56 .353 .556 r
F P
0 g
s
.61962 .72415 m .6187 .69203 L .54693 .71277 L p .56 .353 .556 r
F P
0 g
s
.61149 .62273 m .616 .65819 L .67318 .63299 L p .532 .383 .625 r
F P
0 g
s
.67318 .63299 m .66646 .59977 L .61149 .62273 L p .532 .383 .625 r
F P
0 g
s
.37094 .44433 m .33707 .47289 L .36746 .50666 L p .826 .79 .818 r
F P
0 g
s
.36746 .50666 m .39642 .47221 L .37094 .44433 L p .826 .79 .818 r
F P
0 g
s
.34148 .54466 m .36746 .50666 L .33707 .47289 L p .86 .795 .786 r
F P
0 g
s
.30306 .62802 m .29287 .67074 L .36867 .7065 L p .844 .637 .622 r
F P
0 g
s
.36668 .7471 m .36867 .7065 L .29287 .67074 L p .854 .601 .555 r
F P
0 g
s
.36867 .7065 m .36668 .7471 L .4592 .75824 L p .748 .506 .565 r
F P
0 g
s
.50305 .39834 m .4804 .42723 L .50593 .43525 L p .702 .702 .847 r
F P
0 g
s
.50593 .43525 m .51592 .4023 L .50305 .39834 L p .702 .702 .847 r
F P
0 g
s
.51592 .4023 m .50593 .43525 L .53315 .43802 L p .686 .678 .836 r
F P
0 g
s
.53315 .43802 m .52982 .40348 L .51592 .4023 L p .686 .678 .836 r
F P
0 g
s
.52982 .40348 m .53315 .43802 L .55923 .43499 L p .667 .658 .831 r
F P
0 g
s
.40755 .41998 m .37094 .44433 L .39642 .47221 L p .792 .781 .843 r
F P
0 g
s
.39642 .47221 m .42737 .44165 L .40755 .41998 L p .792 .781 .843 r
F P
0 g
s
.33707 .47289 m .30701 .50538 L .34148 .54466 L p .86 .795 .786 r
F P
0 g
s
.31961 .5855 m .34148 .54466 L .30701 .50538 L p .893 .795 .744 r
F P
0 g
s
.55923 .43499 m .54331 .40164 L .52982 .40348 L p .667 .658 .831 r
F P
0 g
s
.54331 .40164 m .55923 .43499 L .58184 .42612 L p .647 .645 .834 r
F P
0 g
s
.6059 .45903 m .58184 .42612 L .55923 .43499 L p .63 .596 .797 r
F P
0 g
s
.49262 .39207 m .45958 .415 L .4804 .42723 L p .715 .728 .861 r
F P
0 g
s
.4804 .42723 m .50305 .39834 L .49262 .39207 L p .715 .728 .861 r
F P
0 g
s
.46033 .7923 m .4592 .75824 L .36668 .7471 L p .741 .457 .499 r
F P
0 g
s
.4592 .75824 m .46033 .7923 L .54687 .77957 L p .637 .377 .509 r
F P
0 g
s
.54687 .77957 m .54715 .74775 L .4592 .75824 L p .637 .377 .509 r
F P
0 g
s
.6059 .45903 m .62653 .49405 L .65916 .46899 L p .58 .541 .775 r
F P
0 g
s
.62653 .49405 m .64345 .52982 L .68247 .50112 L p .557 .494 .74 r
F P
0 g
s
.68247 .50112 m .65916 .46899 L .62653 .49405 L p .557 .494 .74 r
F P
0 g
s
.44606 .39994 m .40755 .41998 L .42737 .44165 L p .758 .769 .862 r
F P
0 g
s
.42737 .44165 m .45958 .415 L .44606 .39994 L p .758 .769 .862 r
F P
0 g
s
.616 .65819 m .6187 .69203 L .67719 .66495 L p .509 .341 .588 r
F P
0 g
s
.67719 .66495 m .67318 .63299 L .616 .65819 L p .509 .341 .588 r
F P
0 g
s
.58184 .42612 m .6059 .45903 L .6312 .43884 L p .605 .59 .809 r
F P
0 g
s
.65916 .46899 m .6312 .43884 L .6059 .45903 L p .58 .541 .775 r
F P
0 g
s
.30701 .50538 m .28194 .54126 L .31961 .5855 L p .893 .795 .744 r
F P
0 g
s
.30306 .62802 m .31961 .5855 L .28194 .54126 L p .926 .788 .689 r
F P
0 g
s
.64345 .52982 m .65667 .56528 L .70103 .5342 L p .534 .448 .704 r
F P
0 g
s
.70103 .5342 m .68247 .50112 L .64345 .52982 L p .534 .448 .704 r
F P
0 g
s
.58184 .42612 m .55499 .39684 L .54331 .40164 L p .647 .645 .834 r
F P
0 g
s
.55499 .39684 m .58184 .42612 L .59909 .41192 L p .63 .642 .844 r
F P
0 g
s
.6312 .43884 m .59909 .41192 L .58184 .42612 L p .605 .59 .809 r
F P
0 g
s
.54715 .74775 m .54687 .77957 L .61872 .75436 L p .538 .303 .507 r
F P
0 g
s
.61872 .75436 m .61962 .72415 L .54715 .74775 L p .538 .303 .507 r
F P
0 g
s
.65667 .56528 m .66646 .59977 L .71501 .56744 L p .51 .402 .667 r
F P
0 g
s
.71501 .56744 m .70103 .5342 L .65667 .56528 L p .51 .402 .667 r
F P
0 g
s
.4858 .38418 m .44606 .39994 L .45958 .415 L p .724 .754 .876 r
F P
0 g
s
.45958 .415 m .49262 .39207 L .4858 .38418 L p .724 .754 .876 r
F P
0 g
s
.52982 .40348 m .52632 .37269 L .51592 .4023 L closepath p .669 .705 .875 r
F P
0 g
s
.54331 .40164 m .52632 .37269 L .52982 .40348 L closepath p .662 .7 .875 r
F P
0 g
s
.51592 .4023 m .52632 .37269 L .50305 .39834 L closepath p .678 .716 .877 r
F P
0 g
s
.29287 .67074 m .28986 .71194 L .36668 .7471 L p .854 .601 .555 r
F P
0 g
s
.36967 .7834 m .36668 .7471 L .28986 .71194 L p .857 .547 .461 r
F P
0 g
s
.36668 .7471 m .36967 .7834 L .46033 .7923 L p .741 .457 .499 r
F P
0 g
s
.28194 .54126 m .26308 .57966 L .30306 .62802 L p .926 .788 .689 r
F P
0 g
s
.29287 .67074 m .30306 .62802 L .26308 .57966 L p .956 .769 .611 r
F P
0 g
s
.6187 .69203 m .61962 .72415 L .67865 .6958 L p .485 .295 .547 r
F P
0 g
s
.67865 .6958 m .67719 .66495 L .6187 .69203 L p .485 .295 .547 r
F P
0 g
s
.55499 .39684 m .52632 .37269 L .54331 .40164 L closepath p .659 .699 .876 r
F P
0 g
s
.50305 .39834 m .52632 .37269 L .49262 .39207 L closepath p .686 .73 .883 r
F P
0 g
s
.66646 .59977 m .67318 .63299 L .72475 .60037 L p .486 .356 .628 r
F P
0 g
s
.72475 .60037 m .71501 .56744 L .66646 .59977 L p .486 .356 .628 r
F P
0 g
s
.59909 .41192 m .6312 .43884 L .64742 .41197 L p .585 .596 .83 r
F P
0 g
s
.6312 .43884 m .65916 .46899 L .68197 .43482 L p .554 .545 .799 r
F P
0 g
s
.68197 .43482 m .64742 .41197 L .6312 .43884 L p .554 .545 .799 r
F P
0 g
s
.56371 .38949 m .52632 .37269 L .55499 .39684 L closepath p .658 .699 .876 r
F P
0 g
s
.59909 .41192 m .56371 .38949 L .55499 .39684 L p .63 .642 .844 r
F P
0 g
s
.56371 .38949 m .59909 .41192 L .60928 .39359 L p .617 .649 .86 r
F P
0 g
s
.64742 .41197 m .60928 .39359 L .59909 .41192 L p .585 .596 .83 r
F P
0 g
s
.65916 .46899 m .68247 .50112 L .71217 .46142 L p .523 .494 .765 r
F P
0 g
s
.71217 .46142 m .68197 .43482 L .65916 .46899 L p .523 .494 .765 r
F P
0 g
s
.49262 .39207 m .52632 .37269 L .4858 .38418 L closepath p .691 .745 .893 r
F P
0 g
s
.46337 .82104 m .46033 .7923 L .36967 .7834 L p .724 .387 .407 r
F P
0 g
s
.46033 .7923 m .46337 .82104 L .54607 .80749 L p .614 .313 .436 r
F P
0 g
s
.54607 .80749 m .54687 .77957 L .46033 .7923 L p .614 .313 .436 r
F P
0 g
s
.44139 .38352 m .40138 .39685 L .40755 .41998 L p .77 .818 .89 r
F P
0 g
s
.40755 .41998 m .44606 .39994 L .44139 .38352 L p .77 .818 .89 r
F P
0 g
s
.37094 .44433 m .40755 .41998 L .40138 .39685 L p .813 .854 .879 r
F P
0 g
s
.48336 .37542 m .44139 .38352 L .44606 .39994 L p .73 .781 .893 r
F P
0 g
s
.44606 .39994 m .4858 .38418 L .48336 .37542 L p .73 .781 .893 r
F P
0 g
s
.40138 .39685 m .36426 .41512 L .37094 .44433 L p .813 .854 .879 r
F P
0 g
s
.33707 .47289 m .37094 .44433 L .36426 .41512 L p .858 .889 .858 r
F P
0 g
s
.56853 .38033 m .52632 .37269 L .56371 .38949 L closepath p .657 .699 .878 r
F P
0 g
s
.60928 .39359 m .56853 .38033 L .56371 .38949 L p .617 .649 .86 r
F P
0 g
s
.68247 .50112 m .70103 .5342 L .73747 .49101 L p .493 .442 .728 r
F P
0 g
s
.73747 .49101 m .71217 .46142 L .68247 .50112 L p .493 .442 .728 r
F P
0 g
s
.4858 .38418 m .52632 .37269 L .48336 .37542 L closepath p .69 .757 .903 r
F P
0 g
s
.54687 .77957 m .54607 .80749 L .61582 .78228 L p .51 .241 .443 r
F P
0 g
s
.61582 .78228 m .61872 .75436 L .54687 .77957 L p .51 .241 .443 r
F P
0 g
s
.36426 .41512 m .33092 .43799 L .33707 .47289 L p .858 .889 .858 r
F P
0 g
s
.30701 .50538 m .33707 .47289 L .33092 .43799 L p .903 .92 .82 r
F P
0 g
s
.26308 .57966 m .25149 .61945 L .29287 .67074 L p .956 .769 .611 r
F P
0 g
s
.28986 .71194 m .29287 .67074 L .25149 .61945 L p .976 .728 .495 r
F P
0 g
s
.67318 .63299 m .67719 .66495 L .73057 .63279 L p .461 .308 .587 r
F P
0 g
s
.73057 .63279 m .72475 .60037 L .67318 .63299 L p .461 .308 .587 r
F P
0 g
s
.61962 .72415 m .61872 .75436 L .6775 .72561 L p .457 .242 .498 r
F P
0 g
s
.6775 .72561 m .67865 .6958 L .61962 .72415 L p .457 .242 .498 r
F P
0 g
s
.56884 .37042 m .52632 .37269 L .56853 .38033 L closepath p .653 .702 .882 r
F P
0 g
s
.56853 .38033 m .60928 .39359 L .6109 .37317 L p .61 .665 .878 r
F P
0 g
s
.6109 .37317 m .56884 .37042 L .56853 .38033 L p .61 .665 .878 r
F P
0 g
s
.60928 .39359 m .64742 .41197 L .65176 .38106 L p .569 .615 .859 r
F P
0 g
s
.65176 .38106 m .6109 .37317 L .60928 .39359 L p .569 .615 .859 r
F P
0 g
s
.55584 .35323 m .52632 .37269 L .56449 .36098 L closepath p .651 .722 .901 r
F P
0 g
s
.48336 .37542 m .52632 .37269 L .48558 .3666 L closepath p .687 .763 .909 r
F P
0 g
s
.56449 .36098 m .52632 .37269 L .56884 .37042 L closepath p .65 .709 .891 r
F P
0 g
s
.54385 .34815 m .52632 .37269 L .55584 .35323 L closepath p .656 .739 .91 r
F P
0 g
s
.5299 .34627 m .52632 .37269 L .54385 .34815 L closepath p .666 .753 .915 r
F P
0 g
s
.51561 .34766 m .52632 .37269 L .5299 .34627 L closepath p .675 .761 .916 r
F P
0 g
s
.50258 .35195 m .52632 .37269 L .51561 .34766 L closepath p .681 .764 .914 r
F P
0 g
s
.49221 .35852 m .52632 .37269 L .50258 .35195 L closepath p .683 .765 .913 r
F P
0 g
s
.48558 .3666 m .52632 .37269 L .49221 .35852 L closepath p .684 .764 .912 r
F P
0 g
s
.70103 .5342 m .71501 .56744 L .75749 .52287 L p .461 .388 .688 r
F P
0 g
s
.75749 .52287 m .73747 .49101 L .70103 .5342 L p .461 .388 .688 r
F P
0 g
s
.44139 .38352 m .48336 .37542 L .48558 .3666 L p .731 .807 .912 r
F P
0 g
s
.28986 .71194 m .29441 .74985 L .36967 .7834 L p .857 .547 .461 r
F P
0 g
s
.37761 .81393 m .36967 .7834 L .29441 .74985 L p .843 .459 .321 r
F P
0 g
s
.36967 .7834 m .37761 .81393 L .46337 .82104 L p .724 .387 .407 r
F P
0 g
s
.33092 .43799 m .30222 .46499 L .30701 .50538 L p .903 .92 .82 r
F P
0 g
s
.28194 .54126 m .30701 .50538 L .30222 .46499 L p .944 .941 .754 r
F P
0 g
s
.64742 .41197 m .68197 .43482 L .69055 .39424 L p .527 .563 .835 r
F P
0 g
s
.69055 .39424 m .65176 .38106 L .64742 .41197 L p .527 .563 .835 r
F P
0 g
s
.56884 .37042 m .6109 .37317 L .60305 .35342 L p .607 .686 .898 r
F P
0 g
s
.60305 .35342 m .56449 .36098 L .56884 .37042 L p .607 .686 .898 r
F P
0 g
s
.48558 .3666 m .44592 .36706 L .44139 .38352 L p .731 .807 .912 r
F P
0 g
s
.40138 .39685 m .44139 .38352 L .44592 .36706 L p .771 .866 .919 r
F P
0 g
s
.67719 .66495 m .67865 .6958 L .73264 .66465 L p .432 .255 .539 r
F P
0 g
s
.73264 .66465 m .73057 .63279 L .67719 .66495 L p .432 .255 .539 r
F P
0 g
s
.44592 .36706 m .48558 .3666 L .49221 .35852 L p .722 .83 .932 r
F P
0 g
s
.68197 .43482 m .71217 .46142 L .72627 .41273 L p .481 .505 .806 r
F P
0 g
s
.72627 .41273 m .69055 .39424 L .68197 .43482 L p .481 .505 .806 r
F P
0 g
s
.71501 .56744 m .72475 .60037 L .77199 .55634 L p .427 .33 .642 r
F P
0 g
s
.77199 .55634 m .75749 .52287 L .71501 .56744 L p .427 .33 .642 r
F P
0 g
s
.56449 .36098 m .60305 .35342 L .58605 .33735 L p .607 .711 .918 r
F P
0 g
s
.58605 .33735 m .55584 .35323 L .56449 .36098 L p .607 .711 .918 r
F P
0 g
s
.44592 .36706 m .40876 .37397 L .40138 .39685 L p .771 .866 .919 r
F P
0 g
s
.36426 .41512 m .40138 .39685 L .40876 .37397 L p .81 .926 .912 r
F P
0 g
s
.6109 .37317 m .65176 .38106 L .64169 .35053 L p .557 .645 .893 r
F P
0 g
s
.64169 .35053 m .60305 .35342 L .6109 .37317 L p .557 .645 .893 r
F P
0 g
s
.61872 .75436 m .61582 .78228 L .67341 .75422 L p .422 .176 .434 r
F P
0 g
s
.67341 .75422 m .6775 .72561 L .61872 .75436 L p .422 .176 .434 r
F P
0 g
s
.30222 .46499 m .27892 .49556 L .28194 .54126 L p .944 .941 .754 r
F P
0 g
s
.26308 .57966 m .28194 .54126 L .27892 .49556 L p .967 .934 .638 r
F P
0 g
s
.46828 .84351 m .46337 .82104 L .37761 .81393 L p .687 .281 .271 r
F P
0 g
s
.46337 .82104 m .46828 .84351 L .54473 .8307 L p .576 .223 .333 r
F P
0 g
s
.54473 .8307 m .54607 .80749 L .46337 .82104 L p .576 .223 .333 r
F P
0 g
s
.25149 .61945 m .24801 .65925 L .28986 .71194 L p .976 .728 .495 r
F P
0 g
s
.29441 .74985 m .28986 .71194 L .24801 .65925 L p .967 .642 .312 r
F P
0 g
s
.45898 .35164 m .49221 .35852 L .50258 .35195 L p .7 .842 .951 r
F P
0 g
s
.49221 .35852 m .45898 .35164 L .44592 .36706 L p .722 .83 .932 r
F P
0 g
s
.54607 .80749 m .54473 .8307 L .61069 .80722 L p .468 .156 .352 r
F P
0 g
s
.61069 .80722 m .61582 .78228 L .54607 .80749 L p .468 .156 .352 r
F P
0 g
s
.55584 .35323 m .58605 .33735 L .5618 .32741 L p .61 .742 .939 r
F P
0 g
s
.5618 .32741 m .54385 .34815 L .55584 .35323 L p .61 .742 .939 r
F P
0 g
s
.71217 .46142 m .73747 .49101 L .75783 .43645 L p .429 .44 .769 r
F P
0 g
s
.75783 .43645 m .72627 .41273 L .71217 .46142 L p .429 .44 .769 r
F P
0 g
s
.47925 .33842 m .50258 .35195 L .51561 .34766 L p .668 .835 .963 r
F P
0 g
s
.50258 .35195 m .47925 .33842 L .45898 .35164 L p .7 .842 .951 r
F P
0 g
s
.40876 .37397 m .44592 .36706 L .45898 .35164 L p .751 .906 .945 r
F P
0 g
s
.40876 .37397 m .37526 .38693 L .36426 .41512 L p .81 .926 .912 r
F P
0 g
s
.33092 .43799 m .36426 .41512 L .37526 .38693 L p .838 .98 .875 r
F P
0 g
s
.54385 .34815 m .5618 .32741 L .53354 .32471 L p .619 .776 .956 r
F P
0 g
s
.53354 .32471 m .5299 .34627 L .54385 .34815 L p .619 .776 .956 r
F P
0 g
s
.67865 .6958 m .6775 .72561 L .73082 .69588 L p .396 .192 .482 r
F P
0 g
s
.73082 .69588 m .73264 .66465 L .67865 .6958 L p .396 .192 .482 r
F P
0 g
s
.65176 .38106 m .69055 .39424 L .67976 .35305 L p .496 .595 .883 r
F P
0 g
s
.67976 .35305 m .64169 .35053 L .65176 .38106 L p .496 .595 .883 r
F P
0 g
s
.72475 .60037 m .73057 .63279 L .78077 .59084 L p .389 .265 .589 r
F P
0 g
s
.78077 .59084 m .77199 .55634 L .72475 .60037 L p .389 .265 .589 r
F P
0 g
s
.50493 .32887 m .51561 .34766 L .5299 .34627 L p .638 .81 .966 r
F P
0 g
s
.51561 .34766 m .50493 .32887 L .47925 .33842 L p .668 .835 .963 r
F P
0 g
s
.5299 .34627 m .53354 .32471 L .50493 .32887 L p .638 .81 .966 r
F P
0 g
s
.60305 .35342 m .64169 .35053 L .61678 .32573 L p .547 .688 .932 r
F P
0 g
s
.61678 .32573 m .58605 .33735 L .60305 .35342 L p .547 .688 .932 r
F P
0 g
s
.27892 .49556 m .26172 .52905 L .26308 .57966 L p .967 .934 .638 r
F P
0 g
s
.25149 .61945 m .26308 .57966 L .26172 .52905 L p .938 .866 .442 r
F P
0 g
s
.29441 .74985 m .30647 .78286 L .37761 .81393 L p .843 .459 .321 r
F P
0 g
s
.39018 .83755 m .37761 .81393 L .30647 .78286 L p .784 .306 .097 r
F P
0 g
s
.37761 .81393 m .39018 .83755 L .46828 .84351 L p .687 .281 .271 r
F P
0 g
s
.73747 .49101 m .75749 .52287 L .78402 .46512 L p .369 .364 .723 r
F P
0 g
s
.78402 .46512 m .75783 .43645 L .73747 .49101 L p .369 .364 .723 r
F P
0 g
s
.61582 .78228 m .61069 .80722 L .6658 .78101 L p .372 .084 .341 r
F P
0 g
s
.6658 .78101 m .67341 .75422 L .61582 .78228 L p .372 .084 .341 r
F P
0 g
s
.37526 .38693 m .3463 .40525 L .33092 .43799 L p .838 .98 .875 r
F P
0 g
s
.30222 .46499 m .33092 .43799 L .3463 .40525 L p .83 .998 .775 r
F P
0 g
s
.42804 .35229 m .45898 .35164 L .47925 .33842 L p .703 .923 .966 r
F P
0 g
s
.45898 .35164 m .42804 .35229 L .40876 .37397 L p .751 .906 .945 r
F P
0 g
s
.69055 .39424 m .72627 .41273 L .71625 .36184 L p .418 .531 .865 r
F P
0 g
s
.71625 .36184 m .67976 .35305 L .69055 .39424 L p .418 .531 .865 r
F P
0 g
s
.37526 .38693 m .40876 .37397 L .42804 .35229 L p .76 .974 .923 r
F P
0 g
s
.24801 .65925 m .25306 .69758 L .29441 .74985 L p .967 .642 .312 r
F P
0 g
s
.30647 .78286 m .29441 .74985 L .25306 .69758 L p .875 .465 .022 r
F P
0 g
s
.73057 .63279 m .73264 .66465 L .78363 .62579 L p .342 .189 .524 r
F P
0 g
s
.78363 .62579 m .78077 .59084 L .73057 .63279 L p .342 .189 .524 r
F P
0 g
s
.58605 .33735 m .61678 .32573 L .58001 .31121 L p .542 .743 .969 r
F P
0 g
s
.58001 .31121 m .5618 .32741 L .58605 .33735 L p .542 .743 .969 r
F P
0 g
s
.6775 .72561 m .67341 .75422 L .72472 .72625 L p .346 .109 .405 r
F P
0 g
s
.72472 .72625 m .73082 .69588 L .6775 .72561 L p .346 .109 .405 r
F P
0 g
s
.4749 .85902 m .46828 .84351 L .39018 .83755 L p .601 .107 .053 r
F P
0 g
s
.46828 .84351 m .4749 .85902 L .54285 .84835 L p .507 .085 .174 r
F P
0 g
s
.54285 .84835 m .54473 .8307 L .46828 .84351 L p .507 .085 .174 r
F P
0 g
s
.64169 .35053 m .67976 .35305 L .64762 .31941 L p .46 .649 .941 r
F P
0 g
s
.64762 .31941 m .61678 .32573 L .64169 .35053 L p .46 .649 .941 r
F P
0 g
s
.54473 .8307 m .54285 .84835 L .60308 .82814 L p .399 .027 .212 r
F P
0 g
s
.60308 .82814 m .61069 .80722 L .54473 .8307 L p .399 .027 .212 r
F P
0 g
s
.75749 .52287 m .77199 .55634 L .80368 .49818 L p .296 .273 .662 r
F P
0 g
s
.80368 .49818 m .78402 .46512 L .75749 .52287 L p .296 .273 .662 r
F P
0 g
s
.26172 .52905 m .25123 .56471 L .25149 .61945 L p .938 .866 .442 r
F P
0 g
s
.24801 .65925 m .25149 .61945 L .25123 .56471 L p .802 .688 .144 r
F P
0 g
s
.4573 .33268 m .47925 .33842 L .50493 .32887 L p .635 .908 .983 r
F P
0 g
s
.47925 .33842 m .4573 .33268 L .42804 .35229 L p .703 .923 .966 r
F P
0 g
s
.5618 .32741 m .58001 .31121 L .53716 .30881 L p .549 .806 .993 r
F P
0 g
s
.53716 .30881 m .53354 .32471 L .5618 .32741 L p .549 .806 .993 r
F P
0 g
s
.3463 .40525 m .32241 .42812 L .30222 .46499 L p .83 .998 .775 r
F P
0 g
s
.27892 .49556 m .30222 .46499 L .32241 .42812 L p .736 .921 .565 r
F P
0 g
s
.72627 .41273 m .75783 .43645 L .74971 .37763 L p .315 .443 .832 r
F P
0 g
s
.74971 .37763 m .71625 .36184 L .72627 .41273 L p .315 .443 .832 r
F P
0 g
s
.49463 .3171 m .50493 .32887 L .53354 .32471 L p .578 .865 .995 r
F P
0 g
s
.50493 .32887 m .49463 .3171 L .4573 .33268 L p .635 .908 .983 r
F P
0 g
s
.53354 .32471 m .53716 .30881 L .49463 .3171 L p .578 .865 .995 r
F P
0 g
s
.42804 .35229 m .40058 .36016 L .37526 .38693 L p .76 .974 .923 r
F P
0 g
s
.3463 .40525 m .37526 .38693 L .40058 .36016 L p .7 .98 .804 r
F P
0 g
s
.73264 .66465 m .73082 .69588 L .78032 .66063 L p .28 .094 .44 r
F P
0 g
s
.78032 .66063 m .78363 .62579 L .73264 .66465 L p .28 .094 .44 r
F P
0 g
s
.40058 .36016 m .42804 .35229 L .4573 .33268 L p .644 .965 .902 r
F P
0 g
s
.61069 .80722 m .60308 .82814 L .65402 .80493 L p .289 0 .195 r
F P
0 g
s
.65402 .80493 m .6658 .78101 L .61069 .80722 L p .289 0 .195 r
F P
0 g
s
.67341 .75422 m .6658 .78101 L .71368 .75516 L p .273 0 .291 r
F P
0 g
s
.71368 .75516 m .72472 .72625 L .67341 .75422 L p .273 0 .291 r
F P
0 g
s
.30647 .78286 m .32548 .80966 L .39018 .83755 L p .784 .306 .097 r
F P
0 g
s
.4068 .8536 m .39018 .83755 L .32548 .80966 L p .611 .042 0 r
F P
0 g
s
.39018 .83755 m .4068 .8536 L .4749 .85902 L p .601 .107 .053 r
F P
0 g
s
.77199 .55634 m .78077 .59084 L .81577 .53481 L p .206 .158 .579 r
F P
0 g
s
.81577 .53481 m .80368 .49818 L .77199 .55634 L p .206 .158 .579 r
F P
0 g
s
.61678 .32573 m .64762 .31941 L .59816 .30062 L p .423 .724 .988 r
F P
0 g
s
.59816 .30062 m .58001 .31121 L .61678 .32573 L p .423 .724 .988 r
F P
0 g
s
.25306 .69758 m .26663 .73296 L .30647 .78286 L p .875 .465 .022 r
F P
0 g
s
.32548 .80966 m .30647 .78286 L .26663 .73296 L p .624 .163 0 r
F P
0 g
s
.67976 .35305 m .71625 .36184 L .6777 .31973 L p .325 .58 .935 r
F P
0 g
s
.6777 .31973 m .64762 .31941 L .67976 .35305 L p .325 .58 .935 r
F P
0 g
s
.32241 .42812 m .30382 .45472 L .27892 .49556 L p .736 .921 .565 r
F P
0 g
s
.26172 .52905 m .27892 .49556 L .30382 .45472 L p 0 0 0 r
F P
0 g
s
.25123 .56471 m .24793 .60171 L .24801 .65925 L p .802 .688 .144 r
F P
0 g
s
.25306 .69758 m .24801 .65925 L .24793 .60171 L p 0 0 .201 r
F P
0 g
s
.75783 .43645 m .78402 .46512 L .77842 .40088 L p .171 .317 .77 r
F P
0 g
s
.77842 .40088 m .74971 .37763 L .75783 .43645 L p .171 .317 .77 r
F P
0 g
s
.73082 .69588 m .72472 .72625 L .77055 .69468 L p .195 0 .324 r
F P
0 g
s
.77055 .69468 m .78032 .66063 L .73082 .69588 L p .195 0 .324 r
F P
0 g
s
.40058 .36016 m .37739 .37448 L .3463 .40525 L p .7 .98 .804 r
F P
0 g
s
.32241 .42812 m .3463 .40525 L .37739 .37448 L p .514 .834 .528 r
F P
0 g
s
.43758 .33479 m .4573 .33268 L .49463 .3171 L p .504 .909 .887 r
F P
0 g
s
.4573 .33268 m .43758 .33479 L .40058 .36016 L p .644 .965 .902 r
F P
0 g
s
.54043 .85957 m .54285 .84835 L .4749 .85902 L p .368 0 0 r
F P
0 g
s
.54285 .84835 m .54043 .85957 L .59276 .84374 L p .27 0 0 r
F P
0 g
s
.59276 .84374 m .60308 .82814 L .54285 .84835 L p .27 0 0 r
F P
0 g
s
.48304 .86719 m .4749 .85902 L .4068 .8536 L p .406 0 0 r
F P
0 g
s
.4749 .85902 m .48304 .86719 L .54043 .85957 L p .368 0 0 r
F P
0 g
s
.58001 .31121 m .59816 .30062 L .54066 .29941 L p .398 .798 .984 r
F P
0 g
s
.54066 .29941 m .53716 .30881 L .58001 .31121 L p .398 .798 .984 r
F P
0 g
s
.78077 .59084 m .78363 .62579 L .81947 .57392 L p .09 .01 .463 r
F P
0 g
s
.81947 .57392 m .81577 .53481 L .78077 .59084 L p .09 .01 .463 r
F P
0 g
s
.6658 .78101 m .65402 .80493 L .69698 .78165 L p .156 0 .112 r
F P
0 g
s
.69698 .78165 m .71368 .75516 L .6658 .78101 L p .156 0 .112 r
F P
0 g
s
.37739 .37448 m .40058 .36016 L .43758 .33479 L p .451 .848 .649 r
F P
0 g
s
.48503 .31283 m .49463 .3171 L .53716 .30881 L p .415 .854 .927 r
F P
0 g
s
.49463 .3171 m .48503 .31283 L .43758 .33479 L p .504 .909 .887 r
F P
0 g
s
.30382 .45472 m .29052 .48434 L .26172 .52905 L p 0 0 0 r
F P
0 g
s
.25123 .56471 m .26172 .52905 L .29052 .48434 L p 0 0 .07 r
F P
0 g
s
.53716 .30881 m .54066 .29941 L .48503 .31283 L p .415 .854 .927 r
F P
0 g
s
.60308 .82814 m .59276 .84374 L .63753 .82449 L p .142 0 0 r
F P
0 g
s
.63753 .82449 m .65402 .80493 L .60308 .82814 L p .142 0 0 r
F P
0 g
s
.71625 .36184 m .74971 .37763 L .70577 .32804 L p .103 .447 .882 r
F P
0 g
s
.70577 .32804 m .6777 .31973 L .71625 .36184 L p .103 .447 .882 r
F P
0 g
s
.78402 .46512 m .80368 .49818 L .80052 .43155 L p 0 .13 .656 r
F P
0 g
s
.80052 .43155 m .77842 .40088 L .78402 .46512 L p 0 .13 .656 r
F P
0 g
s
.24793 .60171 m .25217 .6391 L .25306 .69758 L p 0 0 .201 r
F P
0 g
s
.26663 .73296 m .25306 .69758 L .25217 .6391 L p 0 0 .486 r
F P
0 g
s
.64762 .31941 m .6777 .31973 L .61575 .29694 L p .198 .638 .947 r
F P
0 g
s
.61575 .29694 m .59816 .30062 L .64762 .31941 L p .198 .638 .947 r
F P
0 g
s
.32548 .80966 m .35051 .82946 L .4068 .8536 L p .611 .042 0 r
F P
0 g
s
.4068 .8536 m .42676 .86194 L .48304 .86719 L p .406 0 0 r
F P
0 g
s
.42676 .86194 m .4068 .8536 L .35051 .82946 L p 0 .312 .659 r
F P
0 g
s
.72472 .72625 m .71368 .75516 L .75404 .72711 L p .07 0 .152 r
F P
0 g
s
.75404 .72711 m .77055 .69468 L .72472 .72625 L p .07 0 .152 r
F P
0 g
s
.26663 .73296 m .28824 .76408 L .32548 .80966 L p .624 .163 0 r
F P
0 g
s
.35051 .82946 m .32548 .80966 L .28824 .76408 L p 0 .179 .695 r
F P
0 g
s
.37739 .37448 m .35881 .39421 L .32241 .42812 L p .514 .834 .528 r
F P
0 g
s
.30382 .45472 m .32241 .42812 L .35881 .39421 L p 0 0 0 r
F P
0 g
s
.78363 .62579 m .78032 .66063 L .81435 .61422 L p 0 0 .294 r
F P
0 g
s
.81435 .61422 m .81947 .57392 L .78363 .62579 L p 0 0 .294 r
F P
0 g
s
.43758 .33479 m .4207 .34426 L .37739 .37448 L p .451 .848 .649 r
F P
0 g
s
.47338 .31822 m .48503 .31283 L p .47562 .31743 L 0 0 0 r
F P
0 g
s
.4207 .34426 m .43758 .33479 L .47338 .31822 L p 0 0 0 r
F P
0 g
s
.4207 .34426 m .47338 .31822 L .47562 .31743 L 0 0 0 r
F
.48503 .31283 m .47645 .31624 L .4207 .34426 L p F P
0 g
s
.47645 .31624 m .48503 .31283 L .54066 .29941 L p 0 0 0 r
F P
0 g
s
.54066 .29941 m .54395 .29738 L .4885 .31287 L p 0 0 0 r
F P
0 g
s
.4885 .31287 m .47645 .31624 L p .48623 .31367 L 0 0 0 r
F P
0 g
s
.48623 .31367 m .54066 .29941 L .4885 .31287 L 0 0 0 r
F
.29052 .48434 m .28249 .5164 L .25123 .56471 L p 0 0 .07 r
F P
0 g
s
.24793 .60171 m .25123 .56471 L .28249 .5164 L p 0 0 .311 r
F P
0 g
s
.65402 .80493 m .63753 .82449 L .67407 .80434 L p 0 0 0 r
F P
0 g
s
.67407 .80434 m .69698 .78165 L .65402 .80493 L p 0 0 0 r
F P
0 g
s
.35881 .39421 m .37739 .37448 L .4207 .34426 L p 0 0 0 r
F P
0 g
s
.53751 .86356 m .54043 .85957 L .48304 .86719 L p .092 0 0 r
F P
0 g
s
.54043 .85957 m .53751 .86356 L .57965 .85256 L p .02 0 0 r
F P
0 g
s
.57965 .85256 m .59276 .84374 L .54043 .85957 L p .02 0 0 r
F P
0 g
s
.80368 .49818 m .81577 .53481 L .81428 .46896 L p 0 0 .45 r
F P
0 g
s
.81428 .46896 m .80052 .43155 L .80368 .49818 L p 0 0 .45 r
F P
0 g
s
.48304 .86719 m .49248 .86791 L .53751 .86356 L p .092 0 0 r
F P
0 g
s
.49248 .86791 m .48304 .86719 L .42676 .86194 L p 0 .528 .712 r
F P
0 g
s
.59816 .30062 m .61575 .29694 L .54395 .29738 L p .094 .648 .802 r
F P
0 g
s
.54066 .29941 m .59816 .30062 L p .55208 .29787 L .094 .648 .802 r
F P
0 g
s
.63206 .30156 m .61575 .29694 L .6777 .31973 L p 0 .393 .718 r
F P
0 g
s
.63206 .30156 m .5469 .30349 L p .60298 .29815 L .283 0 0 r
F P
0 g
s
.61575 .29694 m .62038 .29825 L p .60298 .29815 L .283 0 0 r
F P
0 g
s
.62038 .29825 m .63206 .30156 L p .60298 .29815 L .283 0 0 r
F P
0 g
s
.54395 .29738 m .54324 .29782 L p .55208 .29787 L .094 .648 .802 r
F P
0 g
s
.54324 .29782 m .54066 .29941 L p .55208 .29787 L .094 .648 .802 r
F P
0 g
s
.25217 .6391 m .26412 .67587 L .26663 .73296 L p 0 0 .486 r
F P
0 g
s
.28824 .76408 m .26663 .73296 L .26412 .67587 L p 0 .151 .669 r
F P
0 g
s
.74971 .37763 m .77842 .40088 L .73022 .34546 L p 0 .194 .703 r
F P
0 g
s
.73022 .34546 m .70577 .32804 L .74971 .37763 L p 0 .194 .703 r
F P
0 g
s
.71368 .75516 m .69698 .78165 L .73061 .75693 L p 0 0 0 r
F P
0 g
s
.73061 .75693 m .75404 .72711 L .71368 .75516 L p 0 0 0 r
F P
0 g
s
.35881 .39421 m .34479 .41823 L .30382 .45472 L p 0 0 0 r
F P
0 g
s
.29052 .48434 m .30382 .45472 L .34479 .41823 L p 0 0 .111 r
F P
0 g
s
.59276 .84374 m .57965 .85256 L .61603 .83794 L p 0 0 0 r
F P
0 g
s
.61603 .83794 m .63753 .82449 L .59276 .84374 L p 0 0 0 r
F P
0 g
s
.78032 .66063 m .77055 .69468 L .80036 .65426 L p 0 0 .055 r
F P
0 g
s
.80036 .65426 m .81435 .61422 L .78032 .66063 L p 0 0 .055 r
F P
0 g
s
.28824 .76408 m .317 .78992 L .35051 .82946 L p 0 .179 .695 r
F P
0 g
s
.38036 .84198 m .35051 .82946 L .317 .78992 L p .069 .427 .87 r
F P
0 g
s
.35051 .82946 m .38036 .84198 L .42676 .86194 L p 0 .312 .659 r
F P
0 g
s
.6777 .31973 m .70577 .32804 L .63206 .30156 L p 0 .393 .718 r
F P
0 g
s
.28249 .5164 m .27975 .55049 L .24793 .60171 L p 0 0 .311 r
F P
0 g
s
.25217 .6391 m .24793 .60171 L .27975 .55049 L p .095 .023 .476 r
F P
0 g
s
.44928 .86284 m .42676 .86194 L .38036 .84198 L p .106 .583 .911 r
F P
0 g
s
.42676 .86194 m .44928 .86284 L .49248 .86791 L p 0 .528 .712 r
F P
0 g
s
.4207 .34426 m .40698 .36026 L .35881 .39421 L p 0 0 0 r
F P
0 g
s
.34479 .41823 m .35881 .39421 L .40698 .36026 L p .056 0 .047 r
F P
0 g
s
.81577 .53481 m .81947 .57392 L .8184 .51173 L p 0 0 .132 r
F P
0 g
s
.8184 .51173 m .81428 .46896 L .81577 .53481 L p 0 0 .132 r
F P
0 g
s
.40698 .36026 m .4207 .34426 L .47645 .31624 L p .063 0 0 r
F P
0 g
s
.63753 .82449 m .61603 .83794 L .64478 .82162 L p 0 0 0 r
F P
0 g
s
.64478 .82162 m .67407 .80434 L .63753 .82449 L p 0 0 0 r
F P
0 g
s
.34479 .41823 m .33503 .44561 L .29052 .48434 L p 0 0 .111 r
F P
0 g
s
.28249 .5164 m .29052 .48434 L .33503 .44561 L p .133 0 .301 r
F P
0 g
s
.69698 .78165 m .67407 .80434 L .70033 .78298 L p 0 0 0 r
F P
0 g
s
.70033 .78298 m .73061 .75693 L .69698 .78165 L p 0 0 0 r
F P
0 g
s
.26412 .67587 m .28374 .71093 L .28824 .76408 L p 0 .151 .669 r
F P
0 g
s
.317 .78992 m .28824 .76408 L .28374 .71093 L p .175 .326 .778 r
F P
0 g
s
.77055 .69468 m .75404 .72711 L .7779 .69259 L p 0 0 0 r
F P
0 g
s
.7779 .69259 m .80036 .65426 L .77055 .69468 L p 0 0 0 r
F P
0 g
s
.77842 .40088 m .80052 .43155 L .74926 .37252 L p .653 .176 0 r
F P
0 g
s
.74926 .37252 m .73022 .34546 L .77842 .40088 L p .653 .176 0 r
F P
0 g
s
.53412 .85962 m .53751 .86356 L .49248 .86791 L p .276 .775 .879 r
F P
0 g
s
.53751 .86356 m .53412 .85962 L .56389 .85322 L p .328 .813 .831 r
F P
0 g
s
.56389 .85322 m .57965 .85256 L .53751 .86356 L p .328 .813 .831 r
F P
0 g
s
.27975 .55049 m .28251 .58628 L .25217 .6391 L p .095 .023 .476 r
F P
0 g
s
.26412 .67587 m .25217 .6391 L .28251 .58628 L p .211 .169 .59 r
F P
0 g
s
.50298 .86124 m .49248 .86791 L .44928 .86284 L p .293 .749 .955 r
F P
0 g
s
.49248 .86791 m .50298 .86124 L .53412 .85962 L p .276 .775 .879 r
F P
0 g
s
.5469 .30349 m .54395 .29738 L .61575 .29694 L p .283 0 0 r
F P
0 g
s
.57965 .85256 m .56389 .85322 L .58971 .84356 L p .427 .87 .84 r
F P
0 g
s
.58971 .84356 m .61603 .83794 L .57965 .85256 L p .427 .87 .84 r
F P
0 g
s
.46912 .32717 m .47645 .31624 L .54395 .29738 L p .212 0 0 r
F P
0 g
s
.47645 .31624 m .46912 .32717 L .40698 .36026 L p .063 0 0 r
F P
0 g
s
.317 .78992 m .35176 .80979 L .38036 .84198 L p .069 .427 .87 r
F P
0 g
s
.4138 .84742 m .38036 .84198 L .35176 .80979 L p .287 .573 .937 r
F P
0 g
s
.38036 .84198 m .4138 .84742 L .44928 .86284 L p .106 .583 .911 r
F P
0 g
s
.81947 .57392 m .81435 .61422 L .81227 .55792 L p .851 .743 .226 r
F P
0 g
s
.81227 .55792 m .8184 .51173 L .81947 .57392 L p .851 .743 .226 r
F P
0 g
s
.40698 .36026 m .39649 .38175 L .34479 .41823 L p .056 0 .047 r
F P
0 g
s
.33503 .44561 m .34479 .41823 L .39649 .38175 L p .195 0 .246 r
F P
0 g
s
.33503 .44561 m .32917 .47572 L .28249 .5164 L p .133 0 .301 r
F P
0 g
s
.27975 .55049 m .28249 .5164 L .32917 .47572 L p .238 .061 .428 r
F P
0 g
s
.70577 .32804 m .73022 .34546 L .64618 .31568 L p .565 0 0 r
F P
0 g
s
.64618 .31568 m .63206 .30156 L .70577 .32804 L p .565 0 0 r
F P
0 g
s
.54395 .29738 m .5469 .30349 L .46912 .32717 L p .212 0 0 r
F P
0 g
s
.75404 .72711 m .73061 .75693 L .74778 .72788 L p .65 .893 .553 r
F P
0 g
s
.74778 .72788 m .7779 .69259 L .75404 .72711 L p .65 .893 .553 r
F P
0 g
s
.4737 .85687 m .44928 .86284 L .4138 .84742 L p .359 .709 .986 r
F P
0 g
s
.44928 .86284 m .4737 .85687 L .50298 .86124 L p .293 .749 .955 r
F P
0 g
s
.28374 .71093 m .31075 .74316 L .317 .78992 L p .175 .326 .778 r
F P
0 g
s
.35176 .80979 m .317 .78992 L .31075 .74316 L p .307 .451 .842 r
F P
0 g
s
.39649 .38175 m .40698 .36026 L .46912 .32717 L p .239 0 .128 r
F P
0 g
s
.67407 .80434 m .64478 .82162 L .66362 .80403 L p .557 .924 .766 r
F P
0 g
s
.66362 .80403 m .70033 .78298 L .67407 .80434 L p .557 .924 .766 r
F P
0 g
s
.61603 .83794 m .58971 .84356 L .60952 .83187 L p .541 .927 .886 r
F P
0 g
s
.60952 .83187 m .64478 .82162 L .61603 .83794 L p .541 .927 .886 r
F P
0 g
s
.28251 .58628 m .29119 .62334 L .26412 .67587 L p .211 .169 .59 r
F P
0 g
s
.28374 .71093 m .26412 .67587 L .29119 .62334 L p .298 .282 .673 r
F P
0 g
s
.80052 .43155 m .81428 .46896 L .7612 .40892 L p .896 .486 .085 r
F P
0 g
s
.7612 .40892 m .74926 .37252 L .80052 .43155 L p .896 .486 .085 r
F P
0 g
s
.32917 .47572 m .32702 .5083 L .27975 .55049 L p .238 .061 .428 r
F P
0 g
s
.28251 .58628 m .27975 .55049 L .32702 .5083 L p .311 .168 .52 r
F P
0 g
s
.81435 .61422 m .80036 .65426 L .79607 .60522 L p .949 .897 .507 r
F P
0 g
s
.79607 .60522 m .81227 .55792 L .81435 .61422 L p .949 .897 .507 r
F P
0 g
s
.39649 .38175 m .3891 .40779 L .33503 .44561 L p .195 0 .246 r
F P
0 g
s
.32917 .47572 m .33503 .44561 L .3891 .40779 L p .283 .049 .372 r
F P
0 g
s
.35176 .80979 m .39124 .82337 L .4138 .84742 L p .287 .573 .937 r
F P
0 g
s
.44976 .84629 m .4138 .84742 L .39124 .82337 L p .429 .659 .957 r
F P
0 g
s
.4138 .84742 m .44976 .84629 L .4737 .85687 L p .359 .709 .986 r
F P
0 g
s
.73061 .75693 m .70033 .78298 L .71112 .75895 L p .742 .986 .775 r
F P
0 g
s
.71112 .75895 m .74778 .72788 L .73061 .75693 L p .742 .986 .775 r
F P
0 g
s
.53036 .84728 m .53412 .85962 L .50298 .86124 L p .516 .848 .997 r
F P
0 g
s
.53412 .85962 m .53036 .84728 L .54588 .84465 L p .551 .88 .99 r
F P
0 g
s
.54588 .84465 m .56389 .85322 L .53412 .85962 L p .551 .88 .99 r
F P
0 g
s
.51433 .84734 m .50298 .86124 L .4737 .85687 L p .5 .805 .999 r
F P
0 g
s
.50298 .86124 m .51433 .84734 L .53036 .84728 L p .516 .848 .997 r
F P
0 g
s
.31075 .74316 m .34457 .77144 L .35176 .80979 L p .307 .451 .842 r
F P
0 g
s
.39124 .82337 m .35176 .80979 L .34457 .77144 L p .407 .545 .882 r
F P
0 g
s
.56389 .85322 m .54588 .84465 L .55936 .83995 L p .592 .9 .986 r
F P
0 g
s
.55936 .83995 m .58971 .84356 L .56389 .85322 L p .592 .9 .986 r
F P
0 g
s
.46324 .34526 m .46912 .32717 L .5469 .30349 L p .389 0 .12 r
F P
0 g
s
.46912 .32717 m .46324 .34526 L .39649 .38175 L p .239 0 .128 r
F P
0 g
s
.63206 .30156 m .64618 .31568 L .54939 .31831 L p .518 .022 .017 r
F P
0 g
s
.54939 .31831 m .5469 .30349 L .63206 .30156 L p .518 .022 .017 r
F P
0 g
s
.29119 .62334 m .30629 .66103 L .28374 .71093 L p .298 .282 .673 r
F P
0 g
s
.31075 .74316 m .28374 .71093 L .30629 .66103 L p .367 .375 .737 r
F P
0 g
s
.64478 .82162 m .60952 .83187 L .6214 .81888 L p .653 .959 .934 r
F P
0 g
s
.6214 .81888 m .66362 .80403 L .64478 .82162 L p .653 .959 .934 r
F P
0 g
s
.3891 .40779 m .39649 .38175 L .46324 .34526 L p .338 .036 .297 r
F P
0 g
s
.49949 .84459 m .4737 .85687 L .44976 .84629 L p .507 .757 .986 r
F P
0 g
s
.4737 .85687 m .49949 .84459 L .51433 .84734 L p .5 .805 .999 r
F P
0 g
s
.73022 .34546 m .74926 .37252 L .65714 .33999 L p .752 .276 .112 r
F P
0 g
s
.65714 .33999 m .64618 .31568 L .73022 .34546 L p .752 .276 .112 r
F P
0 g
s
.5469 .30349 m .54939 .31831 L .46324 .34526 L p .389 0 .12 r
F P
0 g
s
.58971 .84356 m .55936 .83995 L .56943 .83373 L p .629 .907 .984 r
F P
0 g
s
.56943 .83373 m .60952 .83187 L .58971 .84356 L p .629 .907 .984 r
F P
0 g
s
.32702 .5083 m .32872 .54334 L .28251 .58628 L p .311 .168 .52 r
F P
0 g
s
.29119 .62334 m .28251 .58628 L .32872 .54334 L p .366 .254 .591 r
F P
0 g
s
.80036 .65426 m .7779 .69259 L .77083 .6513 L p .954 .952 .686 r
F P
0 g
s
.77083 .6513 m .79607 .60522 L .80036 .65426 L p .954 .952 .686 r
F P
0 g
s
.81428 .46896 m .8184 .51173 L .76477 .45336 L p .965 .651 .37 r
F P
0 g
s
.76477 .45336 m .7612 .40892 L .81428 .46896 L p .965 .651 .37 r
F P
0 g
s
.70033 .78298 m .66362 .80403 L .66924 .78489 L p .758 .987 .897 r
F P
0 g
s
.66924 .78489 m .71112 .75895 L .70033 .78298 L p .758 .987 .897 r
F P
0 g
s
.3891 .40779 m .38464 .43767 L .32917 .47572 L p .283 .049 .372 r
F P
0 g
s
.32702 .5083 m .32917 .47572 L .38464 .43767 L p .344 .145 .46 r
F P
0 g
s
.30629 .66103 m .32825 .69838 L .31075 .74316 L p .367 .375 .737 r
F P
0 g
s
.34457 .77144 m .31075 .74316 L .32825 .69838 L p .426 .456 .788 r
F P
0 g
s
.34457 .77144 m .38432 .79472 L .39124 .82337 L p .407 .545 .882 r
F P
0 g
s
.43421 .83059 m .39124 .82337 L .38432 .79472 L p .485 .62 .909 r
F P
0 g
s
.39124 .82337 m .43421 .83059 L .44976 .84629 L p .429 .659 .957 r
F P
0 g
s
.48744 .83915 m .44976 .84629 L .43421 .83059 L p .527 .715 .958 r
F P
0 g
s
.44976 .84629 m .48744 .83915 L .49949 .84459 L p .507 .757 .986 r
F P
0 g
s
.60952 .83187 m .56943 .83373 L .57503 .82655 L p .664 .902 .979 r
F P
0 g
s
.57503 .82655 m .6214 .81888 L .60952 .83187 L p .664 .902 .979 r
F P
0 g
s
.32872 .54334 m .33474 .58085 L .29119 .62334 L p .366 .254 .591 r
F P
0 g
s
.30629 .66103 m .29119 .62334 L .33474 .58085 L p .411 .328 .652 r
F P
0 g
s
.46324 .34526 m .45892 .37 L .3891 .40779 L p .338 .036 .297 r
F P
0 g
s
.38464 .43767 m .3891 .40779 L .45892 .37 L p .398 .142 .406 r
F P
0 g
s
.7779 .69259 m .74778 .72788 L .73817 .69412 L p .919 .957 .795 r
F P
0 g
s
.73817 .69412 m .77083 .6513 L .7779 .69259 L p .919 .957 .795 r
F P
0 g
s
.52632 .82641 m .53036 .84728 L .51433 .84734 L closepath p .616 .811 .975 r
F P
0 g
s
.52632 .82641 m .54588 .84465 L .53036 .84728 L closepath p .628 .819 .974 r
F P
0 g
s
.66362 .80403 m .6214 .81888 L .62354 .80504 L p .735 .943 .951 r
F P
0 g
s
.62354 .80504 m .66924 .78489 L .66362 .80403 L p .735 .943 .951 r
F P
0 g
s
.45892 .37 m .46324 .34526 L .54939 .31831 L p .48 .136 .305 r
F P
0 g
s
.52632 .82641 m .51433 .84734 L .49949 .84459 L closepath p .604 .795 .973 r
F P
0 g
s
.52632 .82641 m .55936 .83995 L .54588 .84465 L closepath p .634 .821 .972 r
F P
0 g
s
.38464 .43767 m .38304 .47103 L .32702 .5083 L p .344 .145 .46 r
F P
0 g
s
.32872 .54334 m .32702 .5083 L .38304 .47103 L p .39 .222 .529 r
F P
0 g
s
.32825 .69838 m .3572 .73404 L .34457 .77144 L p .426 .456 .788 r
F P
0 g
s
.38432 .79472 m .34457 .77144 L .3572 .73404 L p .477 .529 .832 r
F P
0 g
s
.52632 .82641 m .49949 .84459 L .48744 .83915 L closepath p .597 .774 .964 r
F P
0 g
s
.38432 .79472 m .42885 .81207 L .43421 .83059 L p .485 .62 .909 r
F P
0 g
s
.47955 .83156 m .43421 .83059 L .42885 .81207 L p .55 .684 .927 r
F P
0 g
s
.43421 .83059 m .47955 .83156 L .48744 .83915 L p .527 .715 .958 r
F P
0 g
s
.64618 .31568 m .65714 .33999 L .55129 .34204 L p .622 .222 .263 r
F P
0 g
s
.55129 .34204 m .54939 .31831 L .64618 .31568 L p .622 .222 .263 r
F P
0 g
s
.52632 .82641 m .56943 .83373 L .55936 .83995 L closepath p .636 .821 .972 r
F P
0 g
s
.8184 .51173 m .81227 .55792 L .75937 .50361 L p .961 .729 .542 r
F P
0 g
s
.75937 .50361 m .76477 .45336 L .8184 .51173 L p .961 .729 .542 r
F P
0 g
s
.74926 .37252 m .7612 .40892 L .66401 .37438 L p .812 .437 .346 r
F P
0 g
s
.66401 .37438 m .65714 .33999 L .74926 .37252 L p .812 .437 .346 r
F P
0 g
s
.52632 .82641 m .48744 .83915 L .47955 .83156 L closepath p .599 .754 .952 r
F P
0 g
s
.33474 .58085 m .34579 .62058 L .30629 .66103 L p .411 .328 .652 r
F P
0 g
s
.32825 .69838 m .30629 .66103 L .34579 .62058 L p .45 .395 .705 r
F P
0 g
s
.74778 .72788 m .71112 .75895 L .70003 .73217 L p .871 .94 .861 r
F P
0 g
s
.70003 .73217 m .73817 .69412 L .74778 .72788 L p .871 .94 .861 r
F P
0 g
s
.54939 .31831 m .55129 .34204 L .45892 .37 L p .48 .136 .305 r
F P
0 g
s
.6214 .81888 m .57503 .82655 L .57545 .81897 L p .694 .882 .968 r
F P
0 g
s
.57545 .81897 m .62354 .80504 L .6214 .81888 L p .694 .882 .968 r
F P
0 g
s
.52632 .82641 m .57503 .82655 L .56943 .83373 L closepath p .64 .821 .97 r
F P
0 g
s
.3572 .73404 m .3928 .76636 L .38432 .79472 L p .477 .529 .832 r
F P
0 g
s
.42885 .81207 m .38432 .79472 L .3928 .76636 L p .525 .598 .87 r
F P
0 g
s
.38304 .47103 m .38441 .50773 L .32872 .54334 L p .39 .222 .529 r
F P
0 g
s
.33474 .58085 m .32872 .54334 L .38441 .50773 L p .43 .289 .587 r
F P
0 g
s
.45892 .37 m .45629 .40082 L .38464 .43767 L p .398 .142 .406 r
F P
0 g
s
.38304 .47103 m .38464 .43767 L .45629 .40082 L p .44 .221 .484 r
F P
0 g
s
.42885 .81207 m .47672 .82279 L .47955 .83156 L p .55 .684 .927 r
F P
0 g
s
.52632 .82641 m .47955 .83156 L .47672 .82279 L closepath p .607 .741 .94 r
F P
0 g
s
.71112 .75895 m .66924 .78489 L .65835 .76458 L p .818 .914 .903 r
F P
0 g
s
.65835 .76458 m .70003 .73217 L .71112 .75895 L p .818 .914 .903 r
F P
0 g
s
.3928 .76636 m .43404 .79355 L .42885 .81207 L p .525 .598 .87 r
F P
0 g
s
.47672 .82279 m .42885 .81207 L .43404 .79355 L p .571 .666 .903 r
F P
0 g
s
.52632 .82641 m .57545 .81897 L .57503 .82655 L closepath p .648 .817 .964 r
F P
0 g
s
.34579 .62058 m .36259 .66179 L .32825 .69838 L p .45 .395 .705 r
F P
0 g
s
.3572 .73404 m .32825 .69838 L .36259 .66179 L p .486 .46 .754 r
F P
0 g
s
.45629 .40082 m .45892 .37 L .55129 .34204 L p .532 .243 .422 r
F P
0 g
s
.81227 .55792 m .79607 .60522 L .74527 .55678 L p .935 .768 .65 r
F P
0 g
s
.74527 .55678 m .75937 .50361 L .81227 .55792 L p .935 .768 .65 r
F P
0 g
s
.43404 .79355 m .47926 .81398 L .47672 .82279 L p .571 .666 .903 r
F P
0 g
s
.52632 .82641 m .47672 .82279 L .47926 .81398 L closepath p .615 .735 .932 r
F P
0 g
s
.66924 .78489 m .62354 .80504 L .61475 .79104 L p .765 .882 .93 r
F P
0 g
s
.61475 .79104 m .65835 .76458 L .66924 .78489 L p .765 .882 .93 r
F P
0 g
s
.52632 .82641 m .56049 .8051 L .57046 .81159 L closepath p .66 .787 .942 r
F P
0 g
s
.52632 .82641 m .54662 .80021 L .56049 .8051 L closepath p .654 .767 .932 r
F P
0 g
s
.52632 .82641 m .53047 .79758 L .54662 .80021 L closepath p .643 .75 .926 r
F P
0 g
s
.52632 .82641 m .51393 .79767 L .53047 .79758 L closepath p .632 .739 .925 r
F P
0 g
s
.52632 .82641 m .49887 .80064 L .51393 .79767 L closepath p .624 .735 .926 r
F P
0 g
s
.52632 .82641 m .4869 .80628 L .49887 .80064 L closepath p .622 .734 .927 r
F P
0 g
s
.52632 .82641 m .47926 .81398 L .4869 .80628 L closepath p .62 .734 .928 r
F P
0 g
s
.52632 .82641 m .57046 .81159 L .57545 .81897 L closepath p .657 .806 .955 r
F P
0 g
s
.36259 .66179 m .38559 .70311 L .3572 .73404 L p .486 .46 .754 r
F P
0 g
s
.3928 .76636 m .3572 .73404 L .38559 .70311 L p .52 .524 .8 r
F P
0 g
s
.62354 .80504 m .57545 .81897 L .57046 .81159 L p .712 .846 .946 r
F P
0 g
s
.57046 .81159 m .61475 .79104 L .62354 .80504 L p .712 .846 .946 r
F P
0 g
s
.38441 .50773 m .38906 .54771 L .33474 .58085 L p .43 .289 .587 r
F P
0 g
s
.34579 .62058 m .33474 .58085 L .38906 .54771 L p .465 .352 .64 r
F P
0 g
s
.7612 .40892 m .76477 .45336 L .66608 .4178 L p .825 .528 .487 r
F P
0 g
s
.66608 .4178 m .66401 .37438 L .7612 .40892 L p .825 .528 .487 r
F P
0 g
s
.44898 .7777 m .4869 .80628 L .47926 .81398 L p .587 .658 .887 r
F P
0 g
s
.47926 .81398 m .43404 .79355 L .44898 .7777 L p .587 .658 .887 r
F P
0 g
s
.45629 .40082 m .45542 .4371 L .38304 .47103 L p .44 .221 .484 r
F P
0 g
s
.38441 .50773 m .38304 .47103 L .45542 .4371 L p .474 .286 .545 r
F P
0 g
s
.38559 .70311 m .41467 .74253 L .3928 .76636 L p .52 .524 .8 r
F P
0 g
s
.43404 .79355 m .3928 .76636 L .41467 .74253 L p .554 .589 .844 r
F P
0 g
s
.65714 .33999 m .66401 .37438 L .55246 .37443 L p .669 .342 .411 r
F P
0 g
s
.55246 .37443 m .55129 .34204 L .65714 .33999 L p .669 .342 .411 r
F P
0 g
s
.41467 .74253 m .44898 .7777 L .43404 .79355 L p .554 .589 .844 r
F P
0 g
s
.61475 .79104 m .57046 .81159 L .56049 .8051 L p .71 .799 .92 r
F P
0 g
s
.79607 .60522 m .77083 .6513 L .72354 .60984 L p .903 .789 .725 r
F P
0 g
s
.72354 .60984 m .74527 .55678 L .79607 .60522 L p .903 .789 .725 r
F P
0 g
s
.55129 .34204 m .55246 .37443 L .45629 .40082 L p .532 .243 .422 r
F P
0 g
s
.38906 .54771 m .39743 .59065 L .34579 .62058 L p .465 .352 .64 r
F P
0 g
s
.36259 .66179 m .34579 .62058 L .39743 .59065 L p .498 .412 .689 r
F P
0 g
s
.4722 .76648 m .49887 .80064 L .4869 .80628 L p .602 .658 .877 r
F P
0 g
s
.4869 .80628 m .44898 .7777 L .4722 .76648 L p .602 .658 .877 r
F P
0 g
s
.45542 .4371 m .45629 .40082 L .55246 .37443 L p .564 .319 .504 r
F P
0 g
s
.56049 .8051 m .59527 .77804 L .61475 .79104 L p .71 .799 .92 r
F P
0 g
s
.59527 .77804 m .56049 .8051 L .54662 .80021 L p .694 .752 .896 r
F P
0 g
s
.50169 .76102 m .51393 .79767 L .49887 .80064 L p .62 .665 .872 r
F P
0 g
s
.49887 .80064 m .4722 .76648 L .50169 .76102 L p .62 .665 .872 r
F P
0 g
s
.65835 .76458 m .61475 .79104 L .59527 .77804 L p .755 .805 .893 r
F P
0 g
s
.45542 .4371 m .4564 .4782 L .38441 .50773 L p .474 .286 .545 r
F P
0 g
s
.38906 .54771 m .38441 .50773 L .4564 .4782 L p .504 .344 .597 r
F P
0 g
s
.77083 .6513 m .73817 .69412 L .69586 .66006 L p .869 .801 .781 r
F P
0 g
s
.69586 .66006 m .72354 .60984 L .77083 .6513 L p .869 .801 .781 r
F P
0 g
s
.39743 .59065 m .40994 .63575 L .36259 .66179 L p .498 .412 .689 r
F P
0 g
s
.38559 .70311 m .36259 .66179 L .40994 .63575 L p .527 .47 .736 r
F P
0 g
s
.54662 .80021 m .5673 .76767 L .59527 .77804 L p .694 .752 .896 r
F P
0 g
s
.5673 .76767 m .54662 .80021 L .53047 .79758 L p .67 .712 .88 r
F P
0 g
s
.44778 .72595 m .4722 .76648 L .44898 .7777 L p .579 .591 .829 r
F P
0 g
s
.44898 .7777 m .41467 .74253 L .44778 .72595 L p .579 .591 .829 r
F P
0 g
s
.53465 .76159 m .53047 .79758 L .51393 .79767 L p .643 .683 .872 r
F P
0 g
s
.51393 .79767 m .50169 .76102 L .53465 .76159 L p .643 .683 .872 r
F P
0 g
s
.53047 .79758 m .53465 .76159 L .5673 .76767 L p .67 .712 .88 r
F P
0 g
s
.70003 .73217 m .65835 .76458 L .63012 .74488 L p .795 .808 .862 r
F P
0 g
s
.59527 .77804 m .63012 .74488 L .65835 .76458 L p .755 .805 .893 r
F P
0 g
s
.73817 .69412 m .70003 .73217 L .66412 .70545 L p .833 .807 .826 r
F P
0 g
s
.66412 .70545 m .69586 .66006 L .73817 .69412 L p .833 .807 .826 r
F P
0 g
s
.40994 .63575 m .42679 .68155 L .38559 .70311 L p .527 .47 .736 r
F P
0 g
s
.41467 .74253 m .38559 .70311 L .42679 .68155 L p .554 .529 .782 r
F P
0 g
s
.42679 .68155 m .44778 .72595 L .41467 .74253 L p .554 .529 .782 r
F P
0 g
s
.63012 .74488 m .66412 .70545 L .70003 .73217 L p .795 .808 .862 r
F P
0 g
s
.76477 .45336 m .75937 .50361 L .66301 .46822 L p .822 .585 .58 r
F P
0 g
s
.66301 .46822 m .66608 .4178 L .76477 .45336 L p .822 .585 .58 r
F P
0 g
s
.4564 .4782 m .45931 .52333 L .38906 .54771 L p .504 .344 .597 r
F P
0 g
s
.39743 .59065 m .38906 .54771 L .45931 .52333 L p .53 .398 .645 r
F P
0 g
s
.63012 .74488 m .59527 .77804 L .5673 .76767 L p .724 .736 .86 r
F P
0 g
s
.66401 .37438 m .66608 .4178 L .55282 .41464 L p .691 .421 .509 r
F P
0 g
s
.55282 .41464 m .55246 .37443 L .66401 .37438 L p .691 .421 .509 r
F P
0 g
s
.49015 .71803 m .50169 .76102 L .4722 .76648 L p .608 .605 .822 r
F P
0 g
s
.4722 .76648 m .44778 .72595 L .49015 .71803 L p .608 .605 .822 r
F P
0 g
s
.55246 .37443 m .55282 .41464 L .45542 .4371 L p .564 .319 .504 r
F P
0 g
s
.4564 .4782 m .45542 .4371 L .55282 .41464 L p .586 .378 .566 r
F P
0 g
s
.45931 .52333 m .46421 .57144 L .39743 .59065 L p .53 .398 .645 r
F P
0 g
s
.40994 .63575 m .39743 .59065 L .46421 .57144 L p .554 .449 .69 r
F P
0 g
s
.53873 .71917 m .53465 .76159 L .50169 .76102 L p .645 .634 .825 r
F P
0 g
s
.50169 .76102 m .49015 .71803 L .53873 .71917 L p .645 .634 .825 r
F P
0 g
s
.5673 .76767 m .58793 .72876 L .63012 .74488 L p .724 .736 .86 r
F P
0 g
s
.58793 .72876 m .5673 .76767 L .53465 .76159 L p .686 .678 .837 r
F P
0 g
s
.47982 .67069 m .49015 .71803 L .44778 .72595 L p .593 .551 .777 r
F P
0 g
s
.44778 .72595 m .42679 .68155 L .47982 .67069 L p .593 .551 .777 r
F P
0 g
s
.75937 .50361 m .74527 .55678 L .65495 .52293 L p .813 .625 .648 r
F P
0 g
s
.65495 .52293 m .66301 .46822 L .75937 .50361 L p .813 .625 .648 r
F P
0 g
s
.53465 .76159 m .53873 .71917 L .58793 .72876 L p .686 .678 .837 r
F P
0 g
s
.66412 .70545 m .63012 .74488 L .58793 .72876 L p .748 .718 .824 r
F P
0 g
s
.46421 .57144 m .47109 .62115 L .40994 .63575 L p .554 .449 .69 r
F P
0 g
s
.42679 .68155 m .40994 .63575 L .47109 .62115 L p .575 .5 .733 r
F P
0 g
s
.47109 .62115 m .47982 .67069 L .42679 .68155 L p .575 .5 .733 r
F P
0 g
s
.55282 .41464 m .55233 .46127 L .4564 .4782 L p .586 .378 .566 r
F P
0 g
s
.45931 .52333 m .4564 .4782 L .55233 .46127 L p .603 .427 .617 r
F P
0 g
s
.66608 .4178 m .66301 .46822 L .55233 .46127 L p .702 .477 .579 r
F P
0 g
s
.55233 .46127 m .55282 .41464 L .66608 .4178 L p .702 .477 .579 r
F P
0 g
s
.69586 .66006 m .66412 .70545 L .60793 .68369 L p .768 .7 .787 r
F P
0 g
s
.58793 .72876 m .60793 .68369 L .66412 .70545 L p .748 .718 .824 r
F P
0 g
s
.54255 .6714 m .53873 .71917 L .49015 .71803 L p .642 .591 .782 r
F P
0 g
s
.49015 .71803 m .47982 .67069 L .54255 .6714 L p .642 .591 .782 r
F P
0 g
s
.74527 .55678 m .72354 .60984 L .64246 .57888 L p .8 .655 .701 r
F P
0 g
s
.64246 .57888 m .65495 .52293 L .74527 .55678 L p .8 .655 .701 r
F P
0 g
s
.60793 .68369 m .58793 .72876 L .53873 .71917 L p .695 .647 .797 r
F P
0 g
s
.55233 .46127 m .55097 .51247 L .45931 .52333 L p .603 .427 .617 r
F P
0 g
s
.46421 .57144 m .45931 .52333 L .55097 .51247 L p .617 .471 .661 r
F P
0 g
s
.72354 .60984 m .69586 .66006 L .62644 .63323 L p .785 .679 .746 r
F P
0 g
s
.60793 .68369 m .62644 .63323 L .69586 .66006 L p .768 .7 .787 r
F P
0 g
s
.62644 .63323 m .64246 .57888 L .72354 .60984 L p .785 .679 .746 r
F P
0 g
s
.53873 .71917 m .54255 .6714 L .60793 .68369 L p .695 .647 .797 r
F P
0 g
s
.54597 .61974 m .54255 .6714 L .47982 .67069 L p .636 .551 .741 r
F P
0 g
s
.47982 .67069 m .47109 .62115 L .54597 .61974 L p .636 .551 .741 r
F P
0 g
s
.55097 .51247 m .54882 .56605 L .46421 .57144 L p .617 .471 .661 r
F P
0 g
s
.47109 .62115 m .46421 .57144 L .54882 .56605 L p .627 .511 .702 r
F P
0 g
s
.54882 .56605 m .54597 .61974 L .47109 .62115 L p .627 .511 .702 r
F P
0 g
s
.55097 .51247 m .55233 .46127 L .66301 .46822 L p .706 .52 .634 r
F P
0 g
s
.66301 .46822 m .65495 .52293 L .55097 .51247 L p .706 .52 .634 r
F P
0 g
s
.62644 .63323 m .60793 .68369 L .54255 .6714 L p .702 .617 .759 r
F P
0 g
s
.54255 .6714 m .54597 .61974 L .62644 .63323 L p .702 .617 .759 r
F P
0 g
s
.54882 .56605 m .55097 .51247 L .65495 .52293 L p .707 .556 .68 r
F P
0 g
s
.65495 .52293 m .64246 .57888 L .54882 .56605 L p .707 .556 .68 r
F P
0 g
s
.64246 .57888 m .62644 .63323 L .54597 .61974 L p .706 .587 .721 r
F P
0 g
s
.54597 .61974 m .54882 .56605 L .64246 .57888 L p .706 .587 .721 r
F P
0 g
s
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.1322 .22716 m
.13722 .23244 L
s
[(-1)] .12217 .21659 .95008 1 Mshowa
.24518 .17966 m
.24997 .18515 L
s
[(-0.5)] .23559 .16868 .87363 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.48784 .07763 m
.4921 .08354 L
s
[(0.5)] .47931 .0658 .72074 1 Mshowa
.61837 .02274 m
.62232 .02887 L
s
[(1)] .61048 .01049 .64429 1 Mshowa
.125 Mabswid
.15438 .21783 m
.15737 .22103 L
s
.17676 .20842 m
.17972 .21164 L
s
.19936 .19892 m
.20229 .20217 L
s
.22216 .18933 m
.22506 .1926 L
s
.26841 .16989 m
.27126 .17321 L
s
.29186 .16003 m
.29468 .16337 L
s
.31554 .15007 m
.31833 .15344 L
s
.33945 .14002 m
.34221 .14341 L
s
.38795 .11962 m
.39065 .12307 L
s
.41256 .10928 m
.41522 .11275 L
s
.43741 .09883 m
.44003 .10233 L
s
.4625 .08828 m
.46509 .0918 L
s
.51343 .06687 m
.51595 .07044 L
s
.53927 .056 m
.54175 .0596 L
s
.56537 .04502 m
.56782 .04865 L
s
.59174 .03394 m
.59415 .03759 L
s
.11023 .2364 m
.11327 .23954 L
s
.64528 .01143 m
.6476 .01513 L
s
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
.04063 .83233 m
.04168 .82512 L
s
[(-1)] .03854 .84676 .14499 -1 Mshowa
.1355 .8991 m
.13633 .89186 L
s
[(-0.5)] .13385 .91358 .11439 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.30071 1.01536 m
.30118 1.00809 L
s
[(0.5)] .29978 1.02991 .06386 -1 Mshowa
.37308 1.06628 m
.37339 1.059 L
s
[(1)] .37245 1.08085 .04276 -1 Mshowa
.125 Mabswid
.06035 .84621 m
.06095 .84188 L
s
.07969 .85982 m
.08026 .85548 L
s
.09865 .87316 m
.0992 .86882 L
s
.11725 .88625 m
.11777 .88191 L
s
.15341 .9117 m
.15389 .90735 L
s
.17099 .92407 m
.17144 .91972 L
s
.18825 .93622 m
.18868 .93186 L
s
.20519 .94814 m
.2056 .94378 L
s
.23817 .97135 m
.23853 .96699 L
s
.25422 .98264 m
.25456 .97828 L
s
.26999 .99374 m
.27031 .98938 L
s
.28548 1.00464 m
.28578 1.00028 L
s
.31568 1.02589 m
.31594 1.02153 L
s
.33039 1.03625 m
.33063 1.03188 L
s
.34486 1.04643 m
.34508 1.04206 L
s
.35909 1.05644 m
.35929 1.05207 L
s
.02052 .81818 m
.02117 .81386 L
s
.38684 1.07597 m
.38701 1.0716 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{265.312, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0001Ib000`400?l00000o`00003ooooooom<
ooooo`00oooooom<ooooo`00oooooom<ooooo`00c?ooool4o`000003oa0@4?oooooooooo07Sooooo
003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>oooo
o`03o`000?oooooooooo07[ooooo003>ooooo`03o`000?oooooooooo07[ooooo003>ooooo`03o`00
0?oooooooooo01;ooooo0_l0001Vooooo`00c_ooool00ol0003oooooooooo`0?ooooo`?o000000?o
ooooo`000?ooool0IOooool00<cooooo00?oEEEEofIVI_l000003oooool2o`0000Cooooo0_l0001U
ooooo`00g?ooool2o`0000Kooooo00?o0000ooooool00000I?ooool00=Wooooo0ol00008ooooo`03
o`000?oooooo000006Cooooo003Gooooo`;o00000oooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0006?ooooo003Eooooo`;o00003Oooool01?l0003oooooooooool0001Sooooo`00
d_ooool3o`0000oooooo00Go0000ooooooooooooooooo`00001Rooooo`00d?ooool2o`000003oooo
ool0003ooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Oooooo`00cOoo
ool3o`0000Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo05oooooo003;ooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo05kooooo0039ooooo`;o00006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05kooooo002Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Mooooo`?o00000_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0GOooool009?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Jooooo`;o00007oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo05cooooo002Cooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`0Gooooo`;o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo05cooooo002Cooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0E
ooooo`Co00008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05_ooooo002Coooo
o`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l0
0004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Kooooo`00Toooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool04ooo
ool3o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Jooooo`00Toooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool04Oooool3o`0002[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Iooooo`00Toooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l0000>ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0FOooool00;?ooooo0ol0000_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F?ooool00;7ooooo0_l0000booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool00:oooooo0_l00002ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00[?ooool3o`0003Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Z_ooool2o`0003Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00Yoooool4o`0003[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00YOooool2o`0000Cooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Gooooo002Sooooo`;o
0000@?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Cooooo001jooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08Oooool3o`0004;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Cooooo`00N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0_l00003ooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Cooooo`00
N_ooool01Ol@413ooooooooooooooooo410@01gooooo0_l00018ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0D_ooool007[ooooo00Go0000ooooooooooooooooo`00000Jooooo`?o
0000B_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05o`00
0?ooooooooooooooool000006?ooool2o`0000;ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo057ooooo001jooooo`05oa0@4?ooooooooooooooool@
41005Oooool3o`0004oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`00
N_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo0_l0001Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0D?ooool007[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Aooooo`?o
0000Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04oooooo002=ooooo`?o0000
0oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
C_ooool008_ooooo0_l0001Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C_oo
ool008Sooooo1?l0001Jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0COooool0
08Kooooo0_l00003ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1=ooooo`00Q?ooool2o`00063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1<ooooo`00POooool3o`0006;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`1;ooooo`00Ooooool2o`0000;ooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04_ooooo001mooooo`;o00001Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo0ol0
001Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool004Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Kooooo`;o00000_oo
ool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0BOoo
ool003kooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`0Gooooo`?o0000K_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Sooooo0016
ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`0Fooooo`;o0000L_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0016ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Gooooo0_l00002ooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_oo
ool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool05?ooool3o`0007Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`00A_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool04_ooool2o`0007Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`16ooooo`00A_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l0000?ooooo`;o000000?oooooo`000?ooool0N?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo001Wooooo`?o0000OOooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Gooooo001Uooooo`;o0000P?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04Cooooo001Rooooo`?o000000?oooooo`000?ooool0Ooooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04?ooooo001Pooooo`;o0000QOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo001Nooooo`;o0000Qoooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo04;ooooo001Kooooo`Co0000R?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo04;ooooo001Iooooo`;o00001?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0@Oooool003;ooooo1?l000000ol@413oooooooooo`0Noooo
o`;o0000S_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo000dooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0@?ooool002Wooooo1_l00005ooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`00=?oo
ool00ol0003oooooooooo`0Hooooo`?o0000UOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03oooooo000dooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000ooooo`2E
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool003Cooooo00?o0000oooo
ooooool05?ooool2o`0000?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03gooooo000dooooo`03o`000?oooooooooo017ooooo0ol0002Mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool003;ooooo00?oEEEEofIVI_l00000
4Oooool3o`0009oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`00A?oo
ool2o`0000?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo0011ooooo`?o0000Y?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo000oooooo`;o000000?oooooo`000?ooool0Y?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03[ooooo000looooo`?o0000ZOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03[ooooo000jooooo`;o0000[?ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo03Wooooo000hooooo`;o000000?oooooo`000?ooool0Zoooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo000eooooo`?o00001?ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool003?ooooo0_l0002coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0037ooooo0_l00002ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`00
;_ooool3o`000;Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`00;Ooo
ool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_oo
ool002gooooo00?o0000ooooooooool0^?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo03Gooooo000]ooooo`;o0000^Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo000]ooooo`03o`000?oooooo00000;Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`00;?ooool01Ol0003ooooooooooooooooo00000;Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`00;?oo
ool2o`0000Cooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo000/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo037ooooo000/ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
037ooooo000/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo033ooooo000[ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo
000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0[oooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02oooooo000[ooooo`?o00002_ooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool002_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;_ooool0027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02go
oooo000Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`2[ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?ooool001Sooooo1_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1joooooa_o00005Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo000S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1f
ooooo`?o00000_lf00000ol0003oB000odP0000?odP000;o000000Co<Z?bodP00?m8003oB0001?l0
000Booooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool002?ooooo00?o0000
ooooooooool01?ooool2o`0001;ooooo00?o0000ooooooooool0LOooool4o`0000Go=P007ol0000?
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:oooool002?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06gooooo0ol00006ocH0
00?o000000?oH`0No`000?n41@@06_n41@@5o`0000cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Zooooo`008oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0J?ooool4o`0000Ko=P000ol00004of<07P03o`000?n41@CoQ0D401[o
Q0D400?o0000oi000?n@00000ol0000:ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo06Cooooo0ol00007ocH000?o00002?mS01h00ol0003oQ0D4oh@5100Joh@51003o`00
0?n@003oT00000;oT0000ol00007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
:Oooool002[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Pooooo`?o00001olf
0003o`0000_oH`0N00?o0000oh@51?n41@@03?n41@@Bo`0000CoT0000ol00004ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1Mooooo`;o000000?o4000o`000?lf00001?lf0003o`0000coH`0N4Ol0000?
oilh@`03o`000?o0AQco`4HL00?o00001?n@0003o`000003ooooool0003ooooo03Gooooo00?o0000
ooooooooool0:?ooool002Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Joooo
o`;o00000_l@00001?l0003o=P00ocH00?lf0003o`0000coH`0N0ol00002ogXRCP03o`000?nO>4?o
WcQ301coWcQ300?o0000ol167?o0AQ`00_o0AQ`3o`0000CoT0000ol0000fooooo`03o`000?oooooo
oooo02Oooooo000Yooooo`;o00006_ooool00ol0003oooooooooo`1Gooooo`;o00001?l@0004o`00
00coH`0N0ol00005ogXRCP03o`000?nO>4?oWcQ301coWcQ300?o0000ol167?o0AQ`01Oo0AQ`3o`00
00?oT0001?l0000dooooo`03o`000?oooooooooo02Kooooo000Yooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0E?ooool2o`0000Co40000ol0000;of<07PCo00002?mj8Th00ol0003o
WcQ3oilh@`0Moilh@`03o`000?o0AQco`4HL00Oo`4HL1?l00003oi0000;o0000<_ooool00ol0003o
ooooooooo`0Vooooo`00:Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo057ooooo
0_l00004oa0000;o000000?o?@0Po`000?mS01h02?mS01h3o`0000goNR9>00?o0000oilh@onO>4<0
7?nO>4<00ol0003o`4HLol16700:ol1670?o00000on@00000ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0C_oo
ool3o`0000?o40000_l00002ocd08003o`000?mS01koH`0N00CoH`0N1?l0000@ogXRCP03o`000?nO
>4?oWcQ301goWcQ300?o0000ol167?o0AQ`02Oo0AQ`00ol0003o`4HLol167003o`000003oi000?l0
003o0000037ooooo00?o0000ooooooooool09?ooool002Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1;ooooo`?o00000ol@0002o`0000Co?@0P00Co0000of<07_mS01koH`0N0ol0
000DogXRCP03o`000?nO>4?oWcQ301goWcQ300?o0000ol167?o0AQ`02Oo0AQ`00ol0003o`4HLol16
7003ol1670Go0000;oooool00ol0003oooooooooo`0Tooooo`00:?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo04Wooooo0_l00003oa0000;o00001_lm0204o`0001GoNR9>9Ol00009
ol167003o`000?o0AQco`4HL00Ko`4HL0ol0000_ooooo`03o`000?oooooooooo02?ooooo000Xoooo
o`;o00008Oooool00ol0003oooooooooo`16ooooo`;o00001?l@00000ol0003o?@0Pocd08004ocd0
80?o00005Omj8Th3o`0000;oR3i/00?o0000oj]GJOn[EfT07_n[EfT00ol0003ocfmHo`000002o`00
00Ko`4HL00?o0000ol167?o0AQ`02Oo0AQ`00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02?ooooo000Xooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool3o`0000;o
40000_l00005ocd080;o000000?oEPU<o`000?mj8Th04_mj8Th3o`0000GoR3i/00?o0000oj]GJOn[
EfT07_n[EfT00ol0003ocfmHolm_F002olm_F0?o00000oo0AQ`00ol0003o`4HLol167009ol167003
o`000?oooooooooo02gooooo00?o0000ooooooooool08_ooool002Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`11ooooo`Co000000?o4000o`000?l000001_lm02001Ol0003oEPU<
oeH9C?mF2Dco0000013oNR9>0ol00008ohPnK003o`000?n[EfWoZeMY01ooZeMY00?o0000olm_F?o?
KeP01?o?KeP4o`0000co`4HL00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Qooooo`00
:?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03oooooo1_l00006ocd080;o0000
1?mF2D`00ol0003oNR9>ogXRCP0:ogXRCPCo00002on8?V`00ol0003oZeMYoj]GJ@0Ooj]GJ@03o`00
0?o?KeSocfmH00OocfmH0ol0000;ol167003o`000?oooooooooo02cooooo00?o0000ooooooooool0
8Oooool002Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`Ko00001_lm
0202o`0000KoEPU<00?o0000ogXRC_mj8Th01omj8Th3o`0000ooR3i/00?o0000oj]GJOn[EfT07on[
EfT00ol0003ocfmHolm_F007olm_F003o`000?o?KeSocfmH00?o00002?o0AQ`2o`0002kooooo00?o
0000ooooooooool08?ooool002Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0i
ooooo`Ko00001_lm0202o`0000OoEPU<00?o0000ogXRC_mj8Th01Omj8Th3o`0001;oR3i/00?o0000
oj]GJOn[EfT07on[EfT00ol0003ocfmHolm_F007olm_F003o`000?o?KeSocfmH00?ocfmH0ol00006
ol1670;o0000;Oooool00ol0003oooooooooo`0Pooooo`009oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo03Oooooo1Ol000000ol>00co0000ocd08004ocd08003o`000?mF2DcoEPU<
00OoEPU<00?o0000ogXRC_mj8Th00_mj8Th3o`0001GoR3i/00?o0000oj]GJOn[EfT07on[EfT00ol0
003ocfmHolm_F007olm_F003o`000?o?KeSocfmH00KocfmH0ol00004ol1670;o0000;Oooool00ol0
003oooooooooo`0Oooooo`009oooool2o`0002Wooooo00?o0000ooooooooool0=?ooool6o`000003
o`h03?l0003o?@0P00?o?@0P0_l0000:oeH9C003o`000?mj8Tko000000;o00006?n8?V`00ol0003o
ZeMYoj]GJ@0Poj]GJ@03o`000?o?KeSocfmH00KocfmH00?o0000olm_F?o?KeP02Oo?KeP3o`000003
ol167?l0003o000002kooooo00?o0000ooooooooool07_ooool002Oooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0booooo`Go00000ol>00`00ol0003o?@0Pocd08002o`0000_oEPU<
0ol0000KohPnK003o`000?n[EfWoZeMY023oZeMY00?o0000olm_F?o?KeP01_o?KeP00ol0003ocfmH
olm_F00<olm_F0Co0000;Oooool00ol0003oooooooooo`0Nooooo`009oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo033ooooo1Ol00003o`h03004o`000?lm023o0000o`0000_oEPU<
0_l000000omU96Oo0000ohPnK00IohPnK2Oo00001oo?KeP00ol0003ocfmHolm_F00?olm_F0;o0000
;Oooool00ol0003oooooooooo`0Mooooo`009oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo02oooooo0ol00004o`h03003o`000?lm023o000000_oEPU<0_l00003ofDTI`03o`000?n8
?VcoR3i/01GoR3i/0ol00002oi1AP@03o`000?n`Jh;o/6^2023o/6^200?o0000om>7O?l000000_l0
0004olm_F003o`000?o?KeSocfmH00oocfmH00?o0000ojL]0?l00000;?ooool00ol0003ooooooooo
o`0Mooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo0ol00005
o`h030;o00002omF2D`00ol0003oIBAWofDTI`03ofDTI`03o`000?n8?VcoR3i/01;oR3i/0ol00005
oi1AP@03o`000?n`Jh;o/6^2023o/6^200?o0000om>7O?oCQg`00_oCQg`3o`000003olm_F?l0003o
cfmH013ocfmH0_l000000onW;@3o0000ooooo`0[ooooo`03o`000?oooooooooo01cooooo000Voooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:oooool3o`0000Co3P0<0_l0000;oeH9
C0;o00001_mU96L00ol0003oR3i/ohPnK00>ohPnK0Co00002?n@DH400ol0003o/6^2ok1[PP0Pok1[
PP03o`000?oCQgcodhMl00GodhMl0ol0000Aolm_F0;o000000?oYbd0o`000?ooool0:oooool00ol0
003oooooooooo`0Kooooo`009_ooool3o`0002oooooo00?o0000ooooooooool0:Oooool2o`0000Go
3P0<00?o0000oc40?_l000002OmF2D`2o`0000SoIBAW00?o0000ohPnK?n8?V`02on8?V`3o`0000co
T56100?o0000ok1[P_n`Jh808?n`Jh800ol0003odhMlom>7O007om>7O0?o00003oo?KeP01?l0003o
iG`Eo`000?l0000/ooooo`03o`000?oooooooooo01_ooooo000Vooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool09oooool2o`0000Co3P0<0_l00002oc40?P03o`000?mF2DcoEPU<00Go
EPU<0_l00009ofDTI`03o`000?n8?VcoR3i/00WoR3i/0ol0000?oi1AP@03o`000?n`Jh;o/6^2023o
/6^200?o0000om>7O?oCQg`01ooCQg`00ol0003odhMlom>7O003o`0000cocfmH00?o0000onEl5OoU
O1D00_l0000/ooooo`03o`000?oooooooooo01[ooooo000;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool09Oooool00ol0003o3P0<o`h03003o`h03005o`000?la03ko<@0n
oc40?_l000001_mF2D`2o`0000_oIBAW00?o0000ohPnK?n8?V`01On8?V`4o`0001;oT56100?o0000
ok1[P_n`Jh808?n`Jh800ol0003odhMlom>7O007om>7O003o`000?oCQgcodhMl00?odhMl0ol0000:
olm_F003o`000?oUO1GoiG`E00;o0000:oooool00ol0003oooooooooo`0Jooooo`002oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Rooooo`;o00001?l>00`2o`0000Co<@0n00?o0000
oeH9C?mF2D`00_mF2D`2o`0000goIBAW00?o0000ohPnK?n8?V`00_n8?V`3o`0001KoT56100?o0000
ok1[P_n`Jh808?n`Jh800ol0003odhMlom>7O007om>7O003o`000?oCQgcodhMl00KodhMl0_l00008
olm_F004o`000?oUO1GoiG`EonEl5@;o0000:oooool00ol0003oooooooooo`0Iooooo`000oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Pooooo`?o00000ol>00`00ol0003o<@0noc40
?P04oc40?P05o`000?mF2DcoEPU<oeH9C?l000003omU96L00ol0003oR3i/o`000002o`0001WoT561
00?o0000ok1[P_n`Jh808On`Jh800ol0003odhMlom>7O006om>7O003o`000?oCQgcodhMl00SodhMl
0ol00005olm_F003o`000?oUO1GoiG`E00;oiG`E0_l0000[ooooo`03o`000?oooooooooo01Sooooo
000;ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool07_ooool3o`0000?o3P0<00?o0000oc40?_la03h0
1Ola03h01?l0003oEPU<o`000?l0000?ofDTI`?o00007?n@DH400ol0003o/6^2ok1[PP0Qok1[PP03
o`000?oCQgcodhMl00KodhMl00?o0000om>7O?oCQg`02ooCQg`3o`0000;ocfmH00?o0000onEl5OoU
O1D00ooUO1D2o`0002[ooooo00?o0000ooooooooool06?ooool000_ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01cooooo1?l000000ol>00co0000o`000007oc40?P?o00003omU96L2o`00
0003og0hNol0003oT56101coT56100?o0000ok1[P_n`Jh808On`Jh800ol0003odhMlom>7O006om>7
O003o`000?oCQgcodhMl00kodhMl1?l00004onEl5@;o0000:oooool00ol0003oooooooooo`0Goooo
o`002oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`00
03Sooooo00?o0000ooooooooool06_ooool4o`000003o`h03?l0003o<@0n00Oo<@0n0_l0000?ofDT
I`;o00000om`>7/00ol0003oT561oi1AP@0Koi1AP@03o`000?n`Jh;o/6^2027o/6^200?o0000om>7
O?oCQg`01_oCQg`00ol0003odhMlom>7O00Aom>7O003o`000?oUO1GoiG`E00?oiG`E0_l0000Zoooo
o`03o`000?oooooooooo01Oooooo000;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06?ooool6o`00
00So<@0n00?o0000odP<Gol000003OmU96L2o`0000GoL3Qk00?o0000oi1APOn@DH406on@DH400ol0
003o/6^2ok1[PP0Qok1[PP03o`000?oCQgcodhMl00KodhMl00?o0000om>7O?oCQg`04OoCQg`00ol0
003oiG`EonEl5@04onEl5@;o0000:_ooool00ol0003oooooooooo`0Fooooo`002oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool05_ooool5o`0000So<@0n0_l00002odP<G`03o`000?mU96OoIBAW00WoIBAW0_l00007og0h
N`03o`000?n@DH7oT56101WoT5615Ol0000Aok1[PP03o`000?oCQgcodhMl00KodhMl00?o0000om>7
O?oCQg`04OoCQg`2o`0000KoiG`E0_l0000Xooooo`?o00005oooool002Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0Eooooo`Go00002?la03h00ol0003oB0aOodP<G`02odP<G`03
o`000?mU96OoIBAW00OoIBAW0_l00009og0hN`03o`000?n@DH7oT56101GoT5611?l00002oiIPT003
o`000?ncNYCo/gZD013o/gZD4ol00007om>7O003o`000?oCQgcodhMl017odhMl00?o0000ooNVG_l0
00001_oUO1D2o`0002Cooooo0ol00002ooooo`03o`000?oooooooooo01Gooooo000Tooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool04oooool4o`000003o`007?l0003o<@0n00Ko<@0n
00?o0000odP<Gom835l00om835l00ol0003oIBAWofDTI`05ofDTI`;o00002om`>7/00ol0003oT561
oi1AP@0@oi1AP@Go00001_nFH9000ol0003o/gZDok=jU00Qok=jU003o`000?oBUICo000000;o0000
1?oCQg`00ol0003odhMlom>7O00Bom>7O003o`000?ogYUko000000KoiG`E00?o0000ooooooooool0
7oooool3o`0000Gooooo00?o0000ooooooooool05Oooool002Cooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Aooooo`Co000000?o000Lo`000?la03h01Ola03h2o`0000GoB0aO00?o
0000ofDTIomU96L01?mU96L2o`0000goL3Qk00?o0000oi1APOn@DH403?n@DH44o`0000_oUV2@00?o
0000ok=jU?ncNY@08OncNY@00ol0003odYFDom:EU002om:EU0?o000000?odhMlo`000?oCQg`04ooC
Qg`01?l0003omjINooNVG_l00006onEl5@03o`000?oooooooooo01_ooooo0ol00008ooooo`03o`00
0?oooooooooo01Gooooo000Tooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool03ooo
ool4o`0000;o000L00?o0000oc40?_la03h00ola03h00ol0003oB0aOodP<G`05odP<G`03o`000?mU
96OoIBAW00;oIBAW0_l0000?og0hN`03o`000?n@DH7oT56100SoT5611?l0000?oiIPT003o`000?nc
NYCo/gZD027o/gZD00?o0000om:EU?oBUI@01OoBUI@3o`0001?odhMl00Go0000ooNVG_ogYUkomjIN
o`000006onEl5@03o`000?oooooooooo01Oooooo0ol0000;ooooo`03o`000?oooooooooo01Gooooo
000Tooooo`;o0000?oooool00ol0003oooooooooo`0>ooooo`?o00000ol001`01?l0003o<@0noc40
?_la03h2o`0000SoB0aO00?o0000ofDTIomU96L00_l0000Aog0hN`03o`000?n@DH7oT56100?oT561
1Ol0000CoiIPT003o`000?ncNYCo/gZD027o/gZD00?o0000om:EU?oBUI@01_oBUI@00ol0003odYFD
o`000002o`00013odhMl00?o0000ooNVG_ogYUh00_ogYUh00ol0003oiG`EonEl5@04onEl5@03o`00
0?oooooooooo01?ooooo0ol0000?ooooo`03o`000?oooooooooo01Cooooo000Tooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool03?ooool3o`0000?o000L00Go0000oc40?_la03ko<@0n
o`00000:odP<G`?o00004om`>7/00ol0003oT561o`000003o`0001SoUV2@00?o0000ok=jU?ncNY@0
8OncNY@00ol0003odYFDom:EU006om:EU003o`000?oBUICodYFD00;odYFD0ol0000=om>7O003o`00
0?ogYUkomjIN00?omjIN00?o0000onEl5OoUO1D00ooUO1D00ol0003oooooooooo`0@ooooo`?o0000
4_ooool00ol0003oooooooooo`0Dooooo`008oooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00[ooooo0ol00004o`007004o`000?la03ko<@0no`0000[oB0aO0_l0000Dog0hN`?o0000
7?nFH9000ol0003o/gZDok=jU00Qok=jU003o`000?oBUICodYFD00KodYFD00?o0000om:EU?oBUI@0
1OoBUI@2o`0000_odhMl00?o0000ooNVG_ogYUh01?ogYUh00ol0003oiG`EonEl5@03onEl5@03o`00
0?oooooooooo00cooooo0ol0000Eooooo`03o`000?oooooooooo01Cooooo000Sooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool02Oooool2o`0000Go000L0ol0000:odP<G`03o`000?mH
9GGo000001;oL3Qk0_l000000omiBH_o0000oiIPT00LoiIPT003o`000?ncNYCo/gZD027o/gZD00?o
0000om:EU?oBUI@01_oBUI@00ol0003odYFDom:EU007om:EU0?o00002?oCQg`00ol0003omjINooNV
GP05ooNVGP03o`000?oUO1GoiG`E00;oiG`E00?o0000ooooooooool02Oooool3o`0001Sooooo00?o
0000ooooooooool05?ooool002?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`07
ooooo`;o00001Ol001`2o`0000[oB0aO0_l00002oePUM@03o`000?m`>7_oL3Qk00koL3Qk0_l00003
ogU9R`03o`000?nFH93oUV2@01_oUV2@00?o0000ok=jU?ncNY@08OncNY@00ol0003odYFDom:EU007
om:EU003o`000?oBUICodYFD00WodYFD0ol00006om>7O003o`000?ogYUkomjIN00ComjIN00?o0000
onEl5OoUO1D00_oUO1D00ol0003oooooooooo`06ooooo`?o00006oooool00ol0003oooooooooo`0D
ooooo`008oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Gooooo0_l00005o`00
70;o00002_m835l00ol0003oF2EeoePUM@02oePUM@03o`000?m`>7_oL3Qk00coL3Qk0_l00005ogU9
R`03o`000?nFH93oUV2@01_oUV2@00?o0000ok=jU?ncNY@08?ncNY@00ol0003odYFDom:EU008om:E
U003o`000?oBUICodYFD00codYFD0ol00003om>7O003o`000?ogYUkomjIN00GomjIN00?o0000onEl
5OoUO1D00_oUO1D00ol0003oooooooooo`02ooooo`?o00007_ooool00ol0003oooooooooo`0Doooo
o`008oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Cooooo00?o0000o`007?l0
01`00ol001`00ol0003o8P1=o`000008odP<G`;o00001OmH9GD00ol0003oL3Qkog0hN`0:og0hN`;o
00001omiBH/00ol0003oUV2@oiIPT00KoiIPT003o`000?ncNYCo/gZD023o/gZD00?o0000om:EU?oB
UI@02?oBUI@00ol0003odYFDom:EU00?om:EU0Co00002?ogYUh01_l0003oiG`EonEl5OoUO1Go0000
ooooo`?o00008Oooool00ol0003oooooooooo`0Dooooo`008oooool2o`0004Oooooo00?o0000oooo
ooooool00_ooool00ol0003o000Lo`007003o`007004o`000?lR04go8P1=o`0000OoB0aO00?o0000
oePUMOmH9GD01OmH9GD00ol0003oL3Qkog0hN`07og0hN`?o00002OmiBH/00ol0003oUV2@oiIPT00K
oiIPT003o`000?ncNYCo/gZD023o/gZD00?o0000om:EU?oBUI@02?oBUI@00ol0003odYFDom:EU00B
om:EU003o`000?ogYUkomjIN00OomjIN00?o0000onEl5OoUO1D00_l0000Uooooo`03o`000?oooooo
oooo01?ooooo000Sooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo00001Ol001`0
1?l0003o8P1=ob80COl00006odP<G`;o00001omH9GD00ol0003oL3Qkog0hN`06og0hN`;o00003?mi
BH/00ol0003oUV2@oiIPT00KoiIPT003o`000?ncNYCo/gZD023o/gZD00?o0000om:EU?oBUI@02?oB
UI@00ol0003odYFDom:EU00Bom:EU003o`000?ogYUkomjIN00SomjIN00Co0000onEl5OoUO1Go0000
9Oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooo000000Co000L00Go0000ob80COlR04go8P1=o`000005odP<G`03o`000?mH9GGoF2Ee00OoF2Ee
00?o0000og0hNom`>7/01?m`>7/2o`0000koNDV;00?o0000oiIPT?nFH9006onFH9000ol0003o/gZD
ok=jU00Pok=jU003o`000?oBUICodYFD00SodYFD00?o0000om:EU?oBUI@04_oBUI@2o`0000[omjIN
00?o0000onEl5Ol000009Oooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooooooo
o`1:ooooo`03o`000?l001co000L00;o000L00?o0000ob80COlR04d00_lR04d01?l0003oB0aOodP<
Gom835l2o`0000[oF2Ee00?o0000og0hNom`>7/00_m`>7/2o`00013oNDV;00?o0000oiIPT?nFH900
6?nFH90=o`0001Wo/gZD00?o0000om:EU?oBUI@02?oBUI@00ol0003odYFDom:EU00Bom:EU003o`00
0?of^X[o000000[omjIN0_l0000Uooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`000?oo
oooooooo04Wooooo0_l00002o`0070;o00001OlR04d01?l0003oB0aOodP<Gol0000<oePUM@03o`00
0?m`>7_oL3Qk00;o00004_miBH/00ol0003oUV2@oiIPT00BoiIPT0Ko00000onJKId00ol0003o]8FR
okB5XP07okB5XQ7o00002?ncNY@00ol0003odYFDom:EU008om:EU003o`000?oBUICodYFD01;odYFD
00Co0000ooJjR_of^X[o00002_ogYUh2o`0002Cooooo00?o0000ooooooooool04oooool002;ooooo
00?o0000ooooooooool0BOooool01?l0003o000Lo`007?l00007ob80C@?o00003OmH9GD3o`0001Co
NDV;00?o0000oiIPT?nFH9003?nFH906o`0000WoVVfM00?o0000okB5X_ndQJ806?ndQJ8:o`0000Wo
dYFD00?o0000om:EU?oBUI@04OoBUI@00ol0003om[Z:ooJjRP02ooJjRP03o`000?ogYUkomjIN00So
mjIN00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`008_ooool00ol0003ooooo
ooooo`18ooooo`;o000000?o000Lo`000?lR04d01_lR04d2o`0000koF2Ee0_l0000FogU9R`03o`00
0?nFH93oUV2@00KoUV2@1_l0000?oiY]W@03o`000?ndQJ;o]8FR023o]8FR00?o0000om2OYOl00000
0_l00006om:EU003o`000?oBUICodYFD017odYFD00?o0000ooJjR_of^XX00oof^XX00ol0003omjIN
ooNVGP07ooNVGP03o`000?oooooooooo02;ooooo00?o0000ooooooooool04oooool0027ooooo0ol0
0018ooooo`Co00001olR04d2o`0000koF2Ee00?o0000of<hQol000005_miBH/00ol0003oUV2@oiIP
T006o`0001GoVVfM00?o0000okB5X_ndQJ808?ndQJ800ol0003od9nUom2OY@02om2OY@?o00000ooB
UI@00ol0003odYFDom:EU00Aom:EU003o`000?of^X[om[Z:00Com[Z:00?o0000ooNVG_ogYUh01_og
YUh00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`000?oooooo
oooo04Sooooo0ol00007ob80C@03o`000?ll3fgo000000coF2Ee0_l00002of<hQ`03o`000?miBH_o
NDV;01?oNDV;1?l0000KoiY]W@03o`000?ndQJ;o]8FR023o]8FR00?o0000om2OYOo@WjD01Oo@WjD4
o`0001?odYFD00?o0000ooJjR_of^XX01Oof^XX00ol0003omjINooNVGP05ooNVGP03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool04_ooool0027ooooo00?o0000ooooooooool0Aoooool3o`00
00Oo8P1=00Co0000oc`?KOll3fgo00002_mH9GD2o`0000CoHcR700?o0000ogU9RomiBH/04?miBH/3
o`000003oh5HV?l0003oVVfM01coVVfM00?o0000okB5X_ndQJ807ondQJ800ol0003od9nUom2OY@09
om2OY@;o00004_oBUI@00ol0003om[Z:ooJjRP06ooJjRP03o`000?ogYUkomjIN00ComjIN00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Booooo`008Oooool00ol0003oooooooooo`16oooo
o`?o00001olR04d01Ol0003o?0m]oc`?KOll3fgo000000WoF2Ee00?o0000of<hQomS>8L01?mS>8L0
0ol0003oNDV;ogU9R`0>ogU9R`;o00001?n1F9P00ol0003oVVfMoiY]W@0KoiY]W@03o`000?ndQJ;o
]8FR01oo]8FR00?o0000om2OYOo@WjD02Oo@WjD00ol0003od9nUo`000002o`0000oodYFD00?o0000
ooJjR_of^XX01_of^XX00ol0003omjINooNVGP04ooNVGP03o`000?oooooooooo02?ooooo00?o0000
ooooooooool04_ooool0027ooooo00?o0000ooooooooool0A_ooool3o`0000Ko8P1=00?o0000oc`?
KOll3fd00_ll3fd00ol0003oF2EeoePUM@05oePUM@;o00001omS>8L00ol0003oNDV;ogU9R`0;ogU9
R`?o00001_n1F9P00ol0003oVVfMoiY]W@0KoiY]W@03o`000?ndQJ;o]8FR01oo]8FR00?o0000om2O
YOo@WjD02Oo@WjD00ol0003od9nUom2OY@02om2OY@?o00003?oBUI@00ol0003om[Z:ooJjRP07ooJj
RP03o`000?ogYUkomjIN00?omjIN00?o0000ooooooooool08oooool00ol0003oooooooooo`0Boooo
o`008Oooool00ol0003oooooooooo`15ooooo`Co00001OlR04d00ol0003o?0m]oc`?K@03oc`?K@03
o`000?mH9GGoF2Ee00?oF2Ee0_l00009of<hQ`03o`000?miBH_oNDV;00SoNDV;0ol00009oh5HV003
o`000?nJKIgoVVfM01_oVVfM00?o0000okB5X_ndQJ807ondQJ800ol0003od9nUom2OY@09om2OY@03
o`000?o@WjGod9nU00God9nU0_l0000:om:EU003o`000?of^X[om[Z:00Som[Z:00?o0000ooNVG_og
YUh00oogYUh00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo000Qooooo`03o`00
0?oooooooooo04Cooooo1?l00005ob80C@03o`000?ll3fgo?0m]00?o?0m]00?o0000oePUMOmH9GD0
0omH9GD00ol0003oHcR7of<hQ`09of<hQ`03o`000?miBH_oNDV;00KoNDV;0_l0000<oh5HV003o`00
0?nJKIgoVVfM01_oVVfM00?o0000okB5X_ndQJ807ondQJ800ol0003od9nUom2OY@09om2OY@03o`00
0?o@WjGod9nU00Ood9nU0ol00006om:EU003o`000?of^X[om[Z:00[om[Z:00?o0000ooNVG_ogYUh0
0_ogYUh00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo000Pooooo`?o0000AOoo
ool4o`0000Co8P1=00?o0000oc`?KOll3fd01?ll3fd01?l0003oF2EeoePUMOmH9GD2o`0000coHcR7
00?o0000ogU9RomiBH/00omiBH/3o`0000koPERH00?o0000oiY]WOnJKId06onJKId00ol0003o]8FR
okB5XP0NokB5XP03o`000?o@WjGod9nU00[od9nU00?o0000om2OYOo@WjD02_o@WjD3o`0000?odYFD
00?o0000ooJjR_of^XX02oof^XX01Ol0003omjINooNVG_ogYUko000002Gooooo00?o0000oooooooo
ool04Oooool0023ooooo00?o0000ooooooooool0A?ooool3o`000003o`004Ol0003o8P1=00;o8P1=
00?o0000oc`?KOll3fd01Oll3fd01?l0003oF2Eeo`000?l0000>of<hQ`04o`000?miBH_oNDV;ogU9
R`;o00004On1F9P00ol0003oVVfMoiY]W@0KoiY]W@03o`000?ndQJ;o]8FR01ko]8FR00?o0000om2O
YOo@WjD02oo@WjD00ol0003od9nUom2OY@0<om2OY@Co00003_of^XX01?l0003omjINooNVG_l0000U
ooooo`03o`000?oooooooooo017ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`14ooooo`;o00000_l001401?l0003o8P1=ob80COl00008oc`?K@;o00004?mS
>8L4o`0001CoPERH00?o0000oiY]WOnJKId06_nJKId00ol0003o]8FRokB5XP0NokB5XP03o`000?o@
WjGod9nU00_od9nU00?o0000om2OYOo@WjD03oo@WjD00ol0003om[Z:ooJjRP0=ooJjRP03o`000?og
YUko000002Gooooo00?o0000ooooooooool04Oooool001Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo04?ooooo0ol00002o`004@03o`000?lR04go000000Wo?0m]00?o
0000of<hQomS>8L03_mS>8L2o`0001OoPERH00?o0000oiY]WOnJKId06_nJKId00ol0003o]8FRokB5
XP0NokB5XP03o`000?o@WjGod9nU00_od9nU00?o0000om2OYOo@WjD03oo@WjD00ol0003om[Z:ooJj
RP0>ooJjRP;o00009Oooool00ol0003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooo
oooo410@00Kooooo00?o0000ooooooooool0@oooool2o`0000;o000A00?o0000ob80COl000002Oll
3fd2o`0000ooHcR700?o0000ofi9U_l000005on1F9P00ol0003oVVfMoiY]W@0JoiY]W@03o`000?nd
QJ;o]8FR01ko]8FR00?o0000om2OYOo@WjD02oo@WjD00ol0003od9nUom2OY@0?om2OY@;o00004?of
^XX00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo000Eooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`12ooooo`?o00000_l00142o`0000Wo?0m]00?o
0000odl[QOl000003OmS>8L2o`0000;oKTVF00?o0000oh5HV?n1F9P05On1F9P00ol0003oVVfMoiY]
W@0EoiY]W@_o00006ondQJ800ol0003od9nUom2OY@0;om2OY@03o`000?o@WjGod9nU00kod9nU00Co
0000ono4Y_o_a:Ko00003oof^XX00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo
000Eooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`13ooooo`;o0000
0ol001400ol0003o?0m]oc`?K@07oc`?K@04o`000?m?:hGoCb^5o`0000coHcR700?o0000ofi9U_m^
BIH00_m^BIH00ol0003oPERHoh5HV00Eoh5HV003o`000?nJKIgoVVfM00_oVVfM2_l00005oiehZ@03
o`000?ndSZko]8j^00?o]8j^2ol0000?okB5XP03o`000?o@WjGod9nU00cod9nU00?o0000om2OYOo@
WjD03_o@WjD01Ol0003oklBVono4Y_o_a:Ko000000kom[Z:00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Aooooo`005Oooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00014oooo
o`03o`000?l0017o000A00;o000A00?o0000oc`?KOll3fd01_ll3fd01Ol0003oCb^5odl[QOm?:hGo
000000[oHcR70_l00006ofi9UP03o`000?n1F9SoPERH01CoPERH00?o0000oiY]WOnJKId00_nJKId9
o`0000ooWGRY00?o0000okB>[_ndSZh03_ndSZh;o`0000Co]8FR00?o0000om2OYOo@WjD03?o@WjD0
0ol0003od9nUom2OY@0>om2OY@03o`000?o_a:KoklBV00;oklBV00?o0000ooJjR_of^XX02oof^XX0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo017ooooo000Eooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`12ooooo`;o00000ol00142o`0000Oo?0m]00?o0000
odl[QOm?:hD00_m?:hD00ol0003oHcR7of<hQ`06of<hQ`;o00002?m^BIH00ol0003oPERHoh5HV00C
oh5HV0Ko00006?nMN:T00ol0003o]8j^okB>[P0IokB>[PKo00003Oo@WjD00ol0003od9nUom2OY@0=
om2OY@03o`000?o_a:KoklBV00CoklBV00?o0000ooJjR_of^XX02_of^XX00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo013ooooo000Eooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`12ooooo`07o`000?l0017o000Ao`004Ol0003o001?o`000006oc`?K@03o`00
0?m?:hGoCb^500CoCb^500?o0000of<hQomS>8L01?mS>8L00ol0003oKTVFofi9UP08ofi9UP03o`00
0?n1F9SoPERH013oPERH0ol000000on7IJGo0000oiehZ@0KoiehZ@03o`000?ndSZko]8j^01go]8j^
00?o0000olbW/ol000000_l0000:om2OY@03o`000?o@WjGod9nU00god9nU00?o0000ono4Y_o_a:H0
1Oo_a:H00ol0003om[Z:ooJjRP08ooJjRP;o00009_ooool00ol0003oooooooooo`0@ooooo`007ooo
ool00ol0003oooooooooo`11ooooo`03o`000?l0017o000A00;o000A00?o0000o`00Col000001Oll
3fd00ol0003oCb^5odl[Q@05odl[Q@03o`000?mS>8OoHcR700;oHcR70_l0000;ofi9UP03o`000?n1
F9SoPERH00goPERH0ol00004ohMUY@03o`000?nMN:WoWGRY01[oWGRY00?o0000okB>[_ndSZh07Ond
SZh00ol0003oc:NcolbW/`02olbW/`;o00002?o@WjD00ol0003od9nUom2OY@0=om2OY@03o`000?o_
a:KoklBV00KoklBV00?o0000ooJjR_of^XX01oof^XX2o`0002Kooooo00?o0000ooooooooool04?oo
ool001oooooo00?o0000ooooooooool0@Oooool01Ol0003o000Ao`004Ol0017o000000;o001?00?o
0000oc`?KOll3fd00_ll3fd00ol0003oCb^5odl[Q@06odl[Q@05o`000?mS>8OoHcR7of<hQol00000
3Om^BIH00ol0003oPERHoh5HV00:oh5HV0?o00001on7IJD00ol0003oWGRYoiehZ@0JoiehZ@03o`00
0?ndSZko]8j^01co]8j^00?o0000olbW/oo<Yk<01Oo<Yk<3o`0000God9nU00?o0000om2OYOo@WjD0
3?o@WjD00ol0003oklBVono4YP08ono4YP03o`000?of^X[om[Z:00Kom[Z:0_l0000Vooooo`03o`00
0?oooooooooo013ooooo000Oooooo`03o`000?oooooooooo047ooooo00Co0000o`004Ol0017o0000
0_l004l00ol0003o?0m]oc`?K@02oc`?K@03o`000?m?:hGoCb^500OoCb^500Co0000of<hQol0003o
00003_m^BIH00ol0003oPERHoh5HV008oh5HV0;o00002_n7IJD00ol0003oWGRYoiehZ@0JoiehZ@03
o`000?ndSZko]8j^01co]8j^00?o0000olbW/oo<Yk<02?o<Yk<2o`0000?od9nU00?o0000om2OYOo@
WjD03?o@WjD00ol0003oklBVono4YP09ono4YP03o`000?of^X[om[Z:00Gom[Z:0_l0000Vooooo`03
o`000?oooooooooo013ooooo000Nooooo`03o`000?oooooooooo047ooooo00Go0000o`004Ol0017o
000Ao`000002o`00C`05o`000?ll3fgo?0m]oc`?KOl000002_m?:hD2o`00013oKTVF00?o0000oh5H
V?n1F9P01On1F9P3o`0000coQfFU00?o0000oiehZOnMN:T06_nMN:T00ol0003o]8j^okB>[P0LokB>
[P03o`000?o<Yk?oc:Nc00[oc:Nc1?l0000>om2OY@03o`000?o_a:KoklBV00[oklBV00?o0000ooJj
R_of^XX01?of^XX2o`0002Kooooo00?o0000ooooooooool04?ooool001kooooo00?o0000oooooooo
ool0@Oooool01?l0003o000Ao`004Ol00003o`00C`04o`000?ll3fgo?0m]o`0000_oCb^500?o0000
ofi9U_m^BIH04?m^BIH01?l0003oPERHoh5HV?n1F9P3o`0000ooQfFU00?o0000oiehZOnMN:T06OnM
N:T00ol0003o]8j^okB>[P0MokB>[P03o`000?o<Yk?oc:Nc00goc:Nc0ol0000<om2OY@03o`000?o_
a:KoklBV00_oklBV00?o0000ooJjR_of^XX00oof^XX2o`0002Kooooo00?o0000ooooooooool04?oo
ool001kooooo0_l00012ooooo`03o`000?l0017o000000Co001?00?o0000oc`?KOl000002om?:hD2
o`0001;oKTVF1?l0000BohMUY@03o`000?nMN:WoWGRY01WoWGRY00?o0000okB>[_ndSZh07?ndSZh0
0ol0003oc:NcolbW/`0>olbW/`03o`000?o<Yk?oc:Nc00;o00002Oo@WjD00ol0003oklBVono4YP0=
ono4YP03o`000?of^X[om[Z:00;om[Z:00?o0000omVn>Ol000009_ooool00ol0003oooooooooo`0?
ooooo`007_ooool00ol0003oooooooooo`10ooooo`04o`000?l0017o000Ao`0000Co001?0_l0000;
odl[Q@03o`000?mM@IOo0000017oKTVF0_l0000FohMUY@03o`000?nMN:WoWGRY01SoWGRY00?o0000
okB>[_ndSZh07?ndSZh00ol0003oc:NcolbW/`0>olbW/`03o`000?o<Yk?oc:Nc00;oc:Nc0ol00006
om2OY@03o`000?o_a:KoklBV00koklBV00Co0000ooJjR_of^X[o00000_oI_ST00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00oooooo000Nooooo`03o`000?oooooooooo043ooooo00?o0000
o`004Ol000001Ol004l00ol0003oCb^5odl[Q@09odl[Q@04o`000?mM@IOoGD6Go`0000ooKTVF0_l0
00000omgFZ?o0000ohMUY@0EohMUY@03o`000?nMN:WoWGRY01SoWGRY00?o0000okB>[_ndSZh07?nd
SZh00ol0003oc:NcolbW/`0>olbW/`03o`000?o<Yk?oc:Nc00Goc:Nc0_l00004om2OY@03o`000?o_
a:KoklBV00ooklBV00?o0000ooJjR_l000000_oI_ST00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00oooooo000Nooooo`03o`000?oooooooooo043ooooo0_l00006o`00C`03o`000?m?:hGo
Cb^500SoCb^500?o0000oee1UomM@IL00_mM@IL00ol0003oKTVFofi9UP0;ofi9UP05o`000?mgFZ?o
MeZSogMJXol000005_n7IJD00ol0003oWGRYoiehZ@0HoiehZ@03o`000?ndSZko]8j^01co]8j^00?o
0000olbW/oo<Yk<03_o<Yk<00ol0003oc:NcolbW/`07olbW/`Co00004oo_a:H2o`0000;ofKhi00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`007Oooool00ol0003oooooooooo`11
ooooo`;o00001Ol004l2o`0000WoCb^500?o0000oee1UomM@IL00omM@IL00ol0003oKTVFofi9UP09
ofi9UP;o00001OmgFZ<00ol0003oQfFUohMUY@0CohMUY@03o`000?nMN:WoWGRY01SoWGRY00?o0000
okB>[_ndSZh07?ndSZh00ol0003oc:NcolbW/`0>olbW/`03o`000?o<Yk?oc:Nc00[oc:Nc0_l0000C
ono4YP04o`000?oI_SWofKhio`0002Kooooo00?o0000ooooooooool03oooool001gooooo00?o0000
ooooooooool0@?ooool2o`0000Go001?00?o0000oaP5NOl000002?m?:hD00ol0003oGD6Goee1U`04
oee1U`03o`000?m^BIKoKTVF00OoKTVF0_l00007ogMJX`03o`000?n7IJGoQfFU01?oQfFU00?o0000
oiehZOnMN:T06?nMN:T00ol0003o]8j^okB>[P0KokB>[P03o`000?o<Yk?oc:Nc013oc:Nc00?o0000
olbW/oo<Yk<02Oo<Yk<00ol0003oilVio`00000Bono4YP04o`000?oI_SWofKhio`0002Kooooo00?o
0000ooooooooool03oooool001gooooo00?o0000ooooooooool0@?ooool00ol0003o001?o`00C`04
o`00C`03o`000?lH1GWo000000OoCb^500?o0000oee1UomM@IL01OmM@IL00ol0003oKTVFofi9UP06
ofi9UP03o`000?mgFZ?oMeZS00OoMeZS00?o0000ohMUYOn7IJD04on7IJD00ol0003oWGRYoiehZ@0A
oiehZ@co00006OndSZh00ol0003oc:NcolbW/`0@olbW/`03o`000?o<Yk?oc:Nc00Soc:Nc00Go0000
onO9^OoWbKWoilVio`00000@ono4YP;o00000_oI_ST00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00oooooo000Mooooo`;o0000@Oooool00ol0003o001?o`00C`03o`00C`04o`000?lH1GWo
60Eio`0000KoCb^500?o0000oee1UomM@IL01_mM@IL00ol0003oKTVFofi9UP04ofi9UP;o00002_mg
FZ<00ol0003oQfFUohMUY@0CohMUY@03o`000?nMN:WoWGRY00CoWGRY3Ol00007oj22/`03o`000?nd
U[So]9Jh00;o]9Jh1ol0000BokB>[P03o`000?o<Yk?oc:Nc013oc:Nc00?o0000olbW/oo<Yk<02?o<
Yk<00ol0003oilVionO9^@02onO9^@03o`000?o_a:KoklBV00goklBV0_l00002omVn>@03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000ooooooooool0@?ooool0
0ol0003o001?o`00C`03o`00C`05o`000?lH1GWo60EioaP5NOl000001?m?:hD00ol0003oGD6Goee1
U`07oee1U`03o`000?m^BIKoKTVF00;oKTVF0_l0000=ogMJX`03o`000?n7IJGoQfFU013oQfFU2Ol0
000Doj22/`03o`000?ndU[So]9Jh00Wo]9Jh1ol0000;okB>[P03o`000?o<Yk?oc:Nc013oc:Nc00?o
0000olbW/oo<Yk<02?o<Yk<00ol0003oilVionO9^@03onO9^@03o`000?o_a:KoklBV00coklBV0_l0
0002omVn>@03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003o001?o`00C`02o`00C`03o`000?lH1GWo60Ei00;o60Ei00Go0000
odl[QOm?:hGoCb^5o`00000;oee1U`04o`000?m^BIKoKTVFo`0000ooMeZS00?o0000ohMUYOn7IJD0
3On7IJD3o`0000;oSG:`00?o0000oj22/onPP[<06?nPP[<00ol0003o]9JhokBF^00@okBF^0Oo0000
0ondSZh00ol0003oc:NcolbW/`0AolbW/`03o`000?o<Yk?oc:Nc00Ooc:Nc00?o0000onO9^OoWbKT0
1OoWbKT00ol0003oklBVono4YP0:ono4YP03o`000?obiH7o000000;ofKhi00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`05o`000?l0
04oo001?o`00Col000001OlH1GT01?l0003oCb^5odl[QOl0000<oee1U`?o00004?mgFZ<00ol0003o
QfFUohMUY@0:ohMUY@?o00001On=L[000ol0003oX8:coj22/`0Hoj22/`03o`000?ndU[So]9Jh01Oo
]9Jh1Ol0000BolbW/`03o`000?o<Yk?oc:Nc00Ooc:Nc00?o0000onO9^OoWbKT01_oWbKT00ol0003o
klBVono4YP09ono4YP03o`000?obiH7o000000;ofKhi00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`05o`000?l004oo001?o`00Col0
00001OlH1GT00ol0003oCb^5o`00000<oee1U`;o00004_mgFZ<00ol0003oQfFUohMUY@06ohMUY@Co
00002?n=L[000ol0003oX8:coj22/`0Hoj22/`03o`000?ndU[So]9Jh01[o]9Jh00?o0000olR]__l0
00000_l0000?olbW/`03o`000?o<Yk?oc:Nc00Ooc:Nc00?o0000onO9^OoWbKT01ooWbKT00ol0003o
klBVono4YP08ono4YP03o`000?obiH7o000000;ofKhi00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`11ooooo`04o`000?l004oo001?o`0000Ko
60Ei0_l0000<oee1U`03o`000?mYDjKo000001;oMeZS00?o0000ohMUYOn7IJD00on7IJD3o`0000go
SG:`00?o0000oj22/onPP[<05onPP[<00ol0003o]9JhokBF^00JokBF^003o`000?o8[Kkob:fn00;o
b:fn0ol0000<olbW/`03o`000?o<Yk?oc:Nc00Koc:Nc00?o0000onO9^OoWbKT02OoWbKT00ol0003o
klBVono4YP06ono4YP04o`000?obiH7ol^F1o`0000;ofKhi00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0>ooooo`007?ooool00ol0003oooooooooo`10ooooo`04o`000?l004oo001?o`00
00Oo60Ei00?o0000oee1UomM@IL02_mM@IL01?l0003oJE>VofUCY_l0000CogMJX`03o`000?n7IJGo
000000;o00004?n=L[000ol0003oX8:coj22/`0Goj22/`03o`000?ndU[So]9Jh01Wo]9Jh00?o0000
olR]__o8[Kh01_o8[Kh2o`0000Soc:Nc0ol00008olbW/`03o`000?oWbKWoilVi00[oilVi00?o0000
ono4Y_o_a:H01Oo_a:H01_l0003ol^F1oo;UPOl0003ofKhio`0002Sooooo00?o0000ooooooooool0
3_ooool001cooooo00?o0000ooooooooool0@?ooool01?l0003o001?o`00Col00007oaP5N@03o`00
0?mM@IOoGD6G00WoGD6G00?o0000ofUCY_mYDjH00_mYDjH00ol0003oMeZSogMJX`0?ogMJX`?o0000
4on=L[000ol0003oX8:coj22/`0Goj22/`03o`000?ndU[So]9Jh01Wo]9Jh00?o0000olR]__o8[Kh0
2?o8[Kh3o`0000;oc:Nc0ol00002olbW/`03o`000?o<Yk?oc:Nc00Goc:Nc00?o0000onO9^OoWbKT0
3?oWbKT00ol0003oklBVono4YP04ono4YP04o`000?obiH7ol^F1oo;UP@;o0000:Oooool00ol0003o
ooooooooo`0=ooooo`007?ooool2o`00047ooooo00?o0000o`00Col000001olH1GT2o`0000[oGD6G
00?o0000ofUCY_mYDjH00omYDjH00ol0003oMeZSogMJX`0=ogMJX`;o000000?oOfV`o`000?n=L[00
4on=L[000ol0003oX8:coj22/`0Foj22/`03o`000?ndU[So]9Jh01[o]9Jh00?o0000olR]__o8[Kh0
2_o8[Kh3o`0000Koc:Nc00?o0000olbW/oo<Yk<01?o<Yk<00ol0003oilVionO9^@0=onO9^@03o`00
0?o_a:KoklBV00;oklBV00?o0000oo;UPOobiH400_obiH42o`0002Wooooo00?o0000ooooooooool0
3Oooool001_ooooo00?o0000ooooooooool0@Oooool00ol0003o001?o`000006oaP5N@03o`000?lf
:iOo000000WoGD6G00?o0000ofUCY_mYDjH01?mYDjH00ol0003oMeZSogMJX`0<ogMJX`05o`000?mo
JK3oOfV`ogmY/?l000005?n=L[000ol0003oX8:coj22/`0Foj22/`03o`000?ndU[So]9Jh01Wo]9Jh
00?o0000olR]__o8[Kh02?o8[Kh3o`0000?ob:fn0ol00004olbW/`03o`000?o<Yk?oc:Nc00?oc:Nc
00?o0000onO9^OoWbKT03_oWbKT01Ol0003oklBVono4Y_o_a:Ko000000Col^F10_l0000Yooooo`03
o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo047ooooo0_l00007oaP5N@04o`00
0?lf:iOo=R^Go`0000OoGD6G00?o0000ofUCY_mYDjH01OmYDjH00ol0003oMeZSogMJX`0:ogMJX`;o
00001OmoJK000ol0003oSG:`oheb/00Boheb/003o`000?nPP[?oX8:c01GoX8:c00?o0000okBF^?nd
U[P06OndU[P00ol0003ob:fnolR]_P04olR]_PCo00002Oo8[Kh3o`0000;oc:Nc00Go0000olbW/oo<
Yk?oc:Nco`00000BonO9^@04o`000?o_a:KoklBVo`0000Col^F10_l0000Yooooo`03o`000?oooooo
oooo00gooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000oaP5NOlH1GT01OlH1GT01Ol0
003o=R^GocH[Uolf:iOo000000KoGD6G00?o0000ofUCY_mYDjH01omYDjH00ol0003oMeZSogMJX`07
ogMJX`;o00001omoJK000ol0003oSG:`oheb/00Boheb/003o`000?nPP[?oX8:c01GoX8:c00?o0000
okBF^?ndU[P06OndU[P01?l0003ob:fnolR]__o8[Kh3o`00013ob:fn0_l000001Oo<Yk?o0000olbW
/oo<Yk?o000001?oilVi0_l00005oo;UP@;o0000:Oooool00ol0003oooooooooo`0=ooooo`006ooo
ool00ol0003oooooooooo`11ooooo`03o`000?lH1GWo60Ei00Go60Ei00Go0000ocH[Uolf:iOo=R^G
o`000005oee1U`03o`000?mYDjKoJE>V00SoJE>V00?o0000ogMJXomgFZ<01_mgFZ<00ol0003oOfV`
ogmY/007ogmY/003o`000?n=L[3oSG:`01;oSG:`00?o0000oj22/onPP[<05OnPP[<00ol0003o]9Jh
okBF^00HokBF^003o`000?o8[Kko000000;o00005Oo8[Kh3o`000003olbW/ol0003oilVi01?oilVi
00?o0000oo;UPOobiH400oobiH42o`0002Wooooo00?o0000ooooooooool03Oooool001_ooooo00?o
0000ooooooooool0@Oooool00ol0003o60EioaP5N@04oaP5N@03o`000?lf:iOo=R^G00;o=R^G00?o
0000oee1UomM@IL00_mM@IL00ol0003oJE>VofUCYP09ofUCYP03o`000?mgFZ?oMeZS00CoMeZS0_l0
000:ogmY/003o`000?n=L[3oSG:`01;oSG:`00?o0000oj22/onPP[<05OnPP[<00ol0003o]9JhokBF
^00GokBF^0?o00006_o8[Kh3o`0001CoilVi00?o0000oo;UPOobiH400oobiH400ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo000Kooooo`03o`000?oooooooooo047ooooo00?o0000
oaP5NOlH1GT00olH1GT00ol0003o=R^GocH[U`03ocH[U`05o`000?mM@IOoGD6Goee1Uol000003?mY
DjH00ol0003oMeZSogMJX`02ogMJX`;o00003?moJK000ol0003oSG:`oheb/00Boheb/003o`000?nP
P[?oX8:c01GoX8:c00?o0000okBF^?ndU[P04ondU[P4o`000003okBF^?l0003ob:fn01_ob:fn00?o
0000omk=aol000004_oWbKT2o`0000Gol^F100?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0=ooooo`006oooool2o`0004;ooooo00?o0000oaP5NOlH1GT00olH1GT00ol0003o=R^GocH[U`04
ocH[U`03o`000?mM@IOo000000goJE>V00Go0000ogMJXomgFZ?oMeZSo`00000?ogmY/003o`000?n=
L[3oSG:`01;oSG:`00?o0000oj22/onPP[<05?nPP[<00ol0003o]9JhokBF^00@okBF^0?o00001Ond
U[P00ol0003ob:fnolR]_P0IolR]_P05o`000?oNcLOo0000omk=aol000004OoWbKT2o`0000Gol^F1
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003ooooooooo
o`12ooooo`03o`000?lH1GWo60Ei00;o60Ei00?o0000ocH[Uolf:iL01Olf:iL2o`0000ooJE>V0ol0
000@ogmY/003o`000?n=L[3oSG:`01;oSG:`00?o0000oj22/onPP[<02OnPP[<?o`0000co]9Jh0ol0
0007okBF^003o`000?o8[Kkob:fn01[ob:fn00Ko0000omk=aooNcLOo0000omk=aol0000?onO9^@03
o`000?odljoo000000Gol^F100?o0000ooooooooool0:Oooool00ol0003oooooooooo`0<ooooo`00
00Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo04;ooooo00Go000co`000?lH1GWo60Eio`000008ocH[U`03o`000?mYDjKo
JE>V00koJE>V00?o0000ogmY/?moJK004?moJK000ol0003oSG:`oheb/00@oheb/0ko00002onRSKd0
1?l0003o/ig2ok>M`_ncWL86o`0000?o]9Jh0ol0000:okBF^003o`000?o8[Kkob:fn01Wob:fn00?o
0000omk=aooNcLL00_oNcLL00ol0003og/g7o`00000=onO9^@05o`000?odljoom?>_ooCc[ol00000
0oobiH400ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00001?nHV9SooooooiRH
V?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo04;ooooo
00Go000co`000?lH1GWo60Eio`000008ocH[U`03o`000?mYDjKoJE>V00goJE>V0_l0000BogmY/003
o`000?n=L[3oSG:`00_oSG:`1Ol00002oi=o^`03o`000?nRSKgoXXfm01CoXXfm00?o0000ok>M`_nc
WL801_ncWL88o`0000Wo]9Jh00?o0000olR]__o8[Kh06?o8[Kh00ol0003og/g7omk=a`03omk=a`04
o`000?oNcLOog/g7o`0000coilVi00Go0000ooCc[oodljoom?>_o`000003oo;UP@03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool03?ooool000?ooooo00?o410@ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo00Co000co`000?lH1GWo00002?lf:iL0
0ol0003oC4R/o`00000=ofUCYP04o`000?mcIKCoLfFdo`00017oOfV`00?o0000oheb/?n=L[001_n=
L[05o`0000OoTgnk00?o0000oj:=_OnRSKd05?nRSKd00ol0003o/ig2ok>M`P03ok>M`P?o00002?nc
WL86o`0000;o]9Jh00?o0000olR]__o8[Kh06Oo8[Kh00ol0003og/g7omk=a`04omk=a`04o`000?oN
cLOog/g7o`0000[oilVi00?o0000ooCc[oodljl00_odljl01Ol0003ol^F1oo;UPOobiH7o000002co
oooo00?o0000ooooooooool03?ooool000?ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo04;ooooo00Co000co`000?lH1GWo00002?lf:iL00ol0003o
C4R/o`00000<ofUCYP05o`000?mcIKCoLfFdog=U]?l000004_moJK000ol0003oSG:`oheb/005o`00
00coTgnk00?o0000oj:=_OnRSKd05?nRSKd00ol0003o/ig2ok>M`P03o`00017o/ig20ol0000JolR]
_P03o`000?oNcLOog/g700Kog/g700Co0000omk=aooNcLOo00002OoWbKT00ol0003om?>_ooCc[`02
ooCc[`04o`000?obiH7ol^F1o`0002gooooo00?o0000ooooooooool03?ooool000?ooooo00?o0000
ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0@_oo
ool00ol003?o0000o`000008ocH[U`04o`000?m<B:coC4R/o`0000_oJE>V00?o0000og=U]?mcIK@0
0omcIK@00ol0003oOfV`ogmY/00>ogmY/0Co00004OnCOk/00ol0003oXXfmoj:=_@0Doj:=_@?o0000
5_ncWL800ol0003oa;?9o`000002o`0001Kob:fn00?o0000omk=aooNcLL01ooNcLL01?l0003og/g7
omk=aol00007onO9^@03o`000?odljoom?>_00?om?>_00Co0000oo;UPOobiH7o0000;Oooool00ol0
003oooooooooo`0<ooooo`000oooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@oooool00ol003?o0000ocH[U`08ocH[U`05o`000?m<B:coC4R/oda8
[?l000002OmYDjH00ol0003oLfFdog=U]004og=U]003o`000?moJK3oOfV`00coOfV`0_l000000on6
N;co0000oi=o^`0Coi=o^`03o`000?nRSKgoXXfm00ooXXfm1Ol0000Gok>M`P03o`000?o4/lWoa;?9
00?oa;?90_l0000ColR]_P03o`000?oNcLOog/g700Wog/g700Co0000omk=aooNcLOo00001_oWbKT0
0ol0003om?>_ooCc[`03ooCc[`04o`000?obiH7ol^F1o`0002kooooo00?o0000ooooooooool02ooo
ool00004oiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool2o`0004Cooooo00?o
000co`000?lf:iL01olf:iL00ol0003oC4R/oda8[002oda8[003o`000?mYDjKoJE>V00KoJE>V00?o
0000og=U]?mcIK@01_mcIK@00ol0003oOfV`ogmY/00:ogmY/003o`000?n6N;coQWRl00;oQWRl00?o
0000oi=o^onCOk/04OnCOk/00ol0003oXXfmoj:=_@0<oj:=_@?o00001?nRSKd00ol0003o/ig2ok>M
`P0Eok>M`P03o`000?o4/lWoa;?900Goa;?90ol0000@olR]_P03o`000?oNcLOog/g700Wog/g700Go
0000omk=aooNcLOog/g7o`000004onO9^@03o`000?odljoom?>_00Com?>_00?o0000oo;UPOl00000
;oooool00ol0003oooooooooo`0;ooooo`0000Co<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo
00?o0000ooooooooool0@oooool00ol003?o001lo`000007ocH[U`03o`000?m<B:coC4R/00?oC4R/
00?o0000ofUCY_mYDjH01?mYDjH00ol0003oLfFdog=U]007og=U]003o`000?moJK3oOfV`00SoOfV`
0_l00005ohIh_003o`000?nCOk_oTgnk017oTgnk00?o0000oj:=_OnRSKd02OnRSKd3o`0000OoXXfm
00?o0000ok>M`_ncWL805OncWL800ol0003oa;?9olBcb@08olBcb@;o00003Oo8[Kh00ol0003og/g7
omk=a`0;omk=a`05o`000?oNcLOog/g7omk=aol000000_oWbKT00ol0003om?>_ooCc[`06ooCc[`;o
0000;oooool00ol0003oooooooooo`0;ooooo`006Oooool00ol0003oooooooooo`13ooooo`03o`00
<ol007co000000Ko=R^G00?o0000oda8[?m<B:`01?m<B:`00ol0003oJE>VofUCYP03ofUCYP03o`00
0?mcIKCoLfFd00WoLfFd00?o0000ogmY/?moJK001OmoJK02o`0000OoQWRl00?o0000oi=o^onCOk/0
4OnCOk/00ol0003oXXfmoj:=_@06oj:=_@?o00002OnRSKd00ol0003o/ig2ok>M`P0Eok>M`P03o`00
0?o4/lWoa;?900_oa;?90_l0000;olR]_P03o`000?oNcLOog/g700cog/g700Oo0000omk=aooNcLOo
g/g7o`000?oWbKWo000000Som?>_0_l0000_ooooo`03o`000?oooooooooo00_ooooo000Iooooo`03
o`000?oooooooooo04?ooooo00?o000co`000?l000001_lf:iL00ol0003oC4R/oda8[005oda8[005
o`000?mYDjKoJE>VofUCY_l000003?mcIK@00ol0003oOfV`ogmY/003ogmY/0;o00002_n6N;`00ol0
003oTgnkoi=o^`0@oi=o^`03o`000?nRSKgoXXfm00;oXXfm1?l0000<oj:=_@03o`000?ncWL;o/ig2
01Go/ig200?o0000olBcbOo4/lT03Oo4/lT3o`0000Oob:fn00?o0000omk=aooNcLL03_oNcLL01Ol0
003og/g7omk=aooNcLOo000000Wom?>_00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0;
ooooo`006Oooool00ol0003oooooooooo`13ooooo`;o000000?o001lo`000?lf:iL01?lf:iL00ol0
003oC4R/oda8[005oda8[004o`000?mYDjKoJE>Vo`0000koLfFd00Go0000ogmY/?moJK3oOfV`o`00
000<ohIh_003o`000?nCOk_oTgnk013oTgnk00?o0000oj:=_Ol000000_l0000@oj:=_@03o`000?nc
WL;o/ig201Go/ig200?o0000olBcbOo4/lT04?o4/lT2o`0000Cob:fn00?o0000omk=aooNcLL04?oN
cLL01?l0003og/g7omk=aol00009ooCc[`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
2oooool001Sooooo00?o0000ooooooooool0A?ooool2o`000003o`00O?l0003o=R^G00?o=R^G00?o
0000oda8[?m<B:`01_m<B:`00ol0003oJE>Vo`00000?og=U]004o`000?moJK3o0000o`0000koQWRl
00?o0000oi=o^onCOk/03_nCOk/3o`0001?oXXfm00?o0000ok>M`_ncWL805?ncWL800ol0003oa;?9
olBcb@0ColBcb@?o000000?ob:fno`000?oNcLL04_oNcLL3o`0000Wom?>_00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0;ooooo`006?ooool00ol0003oooooooooo`14ooooo`;o000000?o
001lo`000?lf:iL00olf:iL00ol0003oC4R/oda8[007oda8[003o`000?mcIKCoLfFd00ooLfFd00?o
0000ohIh_?n6N;`03_n6N;`00ol0003oTgnkoi=o^`0;oi=o^`?o00000_nCOk/00ol0003oXXfmoj:=
_@0Aoj:=_@03o`000?ncWL;o/ig201Co/ig200?o0000olBcbOo4/lT05_o4/lT2o`0001?og/g700Co
0000on_dboo[m<_o00001oodljl00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00[ooooo
000Hooooo`03o`000?oooooooooo04Cooooo0_l00002o`00O004o`000?lf:iOo=R^Go`0000[oC4R/
00?o0000og=U]?mcIK@03omcIK@00ol0003oQWRlohIh_00>ohIh_003o`000?nCOk_oTgnk00OoTgnk
1?l00005oi=o^`03o`000?nRSKgoXXfm017oXXfm00?o0000ok>M`_ncWL804oncWL800ol0003oa;?9
olBcb@0GolBcb@03o`000?oEc]?o0000017og/g700Go0000on_dbol0003ojoC;o`000007ooCc[`03
o`000?oooooooooo033ooooo00?o0000ooooooooool02_ooool001Sooooo0_l00015ooooo`;o0000
0_l007`01?l0003o=R^GocH[Uol00009oda8[003o`000?mMGkco000000ooLfFd00?o0000ogae`Ol0
00004?n6N;`00ol0003oTgnkoi=o^`03oi=o^`?o00002OnCOk/00ol0003oXXfmoj:=_@0Aoj:=_@03
o`000?ncWL;o/ig201?o/ig200?o0000olBcbOo4/lT05_o4/lT01Ol0003oeLkComG>dooEc]?o0000
013og/g700?o0000on_dboo[m</00_l00006ooCc[`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02_ooool001Sooooo00?o0000ooooooooool0A?ooool2o`0000;o001l00?o0000ocH[Uol0
00002_m<B:`00ol0003oGEnlo`00000>og=U]004o`000?mlML7oO7G1o`00013oQWRl00?o0000oi=o
^onCOk/00ol0000:oi=o^a[o00004_ncWL800ol0003oa;?9olBcb@0EolBcb@03o`000?oEc]?oeLkC
00?oeLkC00?o0000omk=aooNcLL03?oNcLL00ol0003ojoC;on_db`02on_db`03o`000?odljoom?>_
00?om?>_00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0:ooooo`006?ooool00ol0003o
ooooooooo`14ooooo`;o00000ol007`2o`0000WoC4R/00Go0000oeeO_?mMGkcoGEnlo`00000<og=U
]003o`000?mlML7oO7G100;oO7G100?o0000ohIh_?n6N;`03On6N;`3o`0000WoTgnk1?l00002oiN=
aP03o`000?nTUlSoY9O8017oY9O800Co0000ok6Uc?naYLco/JG<1Ol0000<ok>M`P03o`000?o4/lWo
a;?901Goa;?900?o0000omG>dooEc]<01OoEc]<00ol0003og/g7omk=a`0:omk=a`03o`000?o[m<_o
joC;00CojoC;00?o0000ooCc[oodljl00_odljl00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00[ooooo000Gooooo`03o`000?oooooooooo04Gooooo0_l00003o`00O003o`000?m<B:coC4R/
00SoC4R/00?o0000oeeO_?mMGk`00_mMGk`00ol0003oLfFdog=U]008og=U]003o`000?mlML7oO7G1
00?oO7G100?o0000ohIh_?n6N;`02On6N;`4o`000003ohIh_?l0003oTgnk00GoTgnk1?l00006oiN=
aP03o`000?nTUlSoY9O8017oY9O800?o0000ok6Uc?naYL`01_naYL`5o`0000Oo/ig200?o0000olBc
bOo4/lT05Oo4/lT00ol0003oeLkComG>d`06omG>d`;o00002_oNcLL00ol0003ojoC;on_db`04on_d
b`05o`000?odljoom?>_ooCc[ol00000=Oooool00ol0003oooooooooo`0:ooooo`005oooool00ol0
003oooooooooo`15ooooo`;o00000ol007`00ol0003oC4R/oda8[008oda8[003o`000?mMGkcoGEnl
00;oGEnl00?o0000og=U]?mcIK@01omcIK@00ol0003oO7G1ogae`@05ogae`@03o`000?n6N;coQWRl
00GoQWRl0ol00005ohIh_003o`000?nCOk_oTgnk00Co00002onGSLH00ol0003oY9O8ojBGb00@ojBG
b003o`000?naYLco/JG<00_o/JG<1Ol00002ok>M`P03o`000?o4/lWoa;?901Coa;?900?o0000omG>
dooEc]<02OoEc]<00ol0003og/g7omk=a`06omk=a`03o`000?o[m<_ojoC;00GojoC;0_l00002ooCc
[`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool001Oooooo00?o0000oooooooo
ool0A_ooool01_l0003o001lo`00O?l007co02J[o`0000SoC4R/00?o0000oeeO_?mMGk`01?mMGk`0
0ol0003oLfFdog=U]005og=U]003o`000?mlML7oO7G100OoO7G100Co0000ohIh_?n6N;coQWRl0ol0
0008ohIh_0?o00003onGSLH00ol0003oY9O8ojBGb00@ojBGb003o`000?naYLco/JG<013o/JG<0_l0
000FolBcb@03o`000?oEc]?oeLkC00_oeLkC00?o0000omk=aooNcLL01?oNcLL00ol0003ojoC;on_d
b`06on_db`04o`000?odljoo0000o`0003Oooooo00?o0000ooooooooool02Oooool001Oooooo00?o
0000ooooooooool0A_ooool01?l0003o001lo`00O?l007`2o`0000SoC4R/00?o0000oeeO_?mMGk`0
1?mMGk`00ol0003oLfFdog=U]004og=U]003o`000?mlML7oO7G100SoO7G11?l00009ohIh_0;o0000
00?oSHO8o`000?nGSLH03onGSLH00ol0003oY9O8ojBGb00@ojBGb003o`000?naYLco/JG<017o/JG<
00?o0000okngd_l000000_l0000BolBcb@03o`000?oEc]?oeLkC00coeLkC00?o0000omk=aooNcLL0
0_oNcLL00ol0003ojoC;on_db`07on_db`04o`000?odljoo0000o`0003Oooooo00?o0000oooooooo
ool02Oooool001Oooooo00?o0000ooooooooool0A_ooool01ol0003o001lo`00O?l007co0000o`0V
Zol000001_m<B:`00ol0003oGEnloeeO_006oeeO_003o`000?mcIKCoLfFd00;oLfFd00?o0000ogae
`OmlML401_mlML45o`0000WoQWRl0_l00004ohf7b003o`000?nGSLKoUhg600goUhg600?o0000ojBG
b?nTUlP04?nTUlP00ol0003o/JG<ok6Uc00@ok6Uc003o`000?no]m;o_kOB00?o_kOB0_l0000?olBc
b@03o`000?oEc]?oeLkC00koeLkC00Go0000omk=aooNcLOog/g7o`00000:on_db`;o000000?ooooo
o`000?ooool0=Oooool00ol0003oooooooooo`09ooooo`005oooool00ol0003oooooooooo`16oooo
o`07o`000?l007co001lo`00O?l0003o02J[o`000006oda8[003o`000?mMGkcoGEnl00OoGEnl00Co
0000og=U]?mcIKCo00001_mlML43o`0000CoO7G100?o0000ohIh_?n6N;`01?n6N;`3o`0000KoSHO8
00?o0000oiN=a_nGSLH03_nGSLH00ol0003oY9O8ojBGb00?ojBGb003o`000?naYLco/JG<013o/JG<
00?o0000okngd_no]m801Ono]m83o`0000_oa;?900?o0000omG>dooEc]<04?oEc]<00ol0003og/g7
o`00000;on_db`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool02Oooool001Oooooo
0_l00017ooooo`05o`000?l007co001lo`00O?l000000_l09Z/00ol0003oC4R/oda8[002oda8[003
o`000?mMGkcoGEnl00SoGEnl00?o0000og=U]?l000001?mlML43o`0000SoO7G100Co0000ohIh_?n6
N;coQWRl0_l0000:ohf7b003o`000?nGSLKoUhg600goUhg600?o0000ojBGb?nTUlP03_nTUlP00ol0
003o/JG<ok6Uc00@ok6Uc003o`000?no]m;o_kOB00Wo_kOB0ol00007olBcb@03o`000?oEc]?oeLkC
01;oeLkC00?o0000on_dboo[m</02_o[m</01Ol0003ooooooooooooooooo000003Gooooo00?o0000
ooooooooool02Oooool001Kooooo00?o0000ooooooooool0Aoooool01Ol0003o001lo`00O?l007co
000000?o02J[00Go0000oda8[?m<B:coC4R/o`00000;oeeO_003o`000?mlML7oO7G100?o00002oml
ML401?l0003oQWRlo`000?l0000<ohf7b003o`000?nGSLKoUhg600goUhg600?o0000ojBGb?nTUlP0
3_nTUlP00ol0003o/JG<ok6Uc00@ok6Uc003o`000?no]m;o_kOB00co_kOB0_l00005olBcb@03o`00
0?oEc]?oeLkC013oeLkC00?o0000omk`g?l000002oo[m</00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000ooooooooool0Aooo
ool01Ol0003o001lo`00O?l007co000000?o02J[00Go0000oda8[?m<B:coC4R/o`00000:oeeO_0Co
00003omlML400ol0003oSHO8ohf7b00=ohf7b003o`000?nGSLKoUhg600goUhg600?o0000ojBGb?nT
UlP03OnTUlP00ol0003o/JG<ok6Uc00@ok6Uc003o`000?no]m;o_kOB00ko_kOB0ol000000oo4/lWo
0000omG>d`0AomG>d`04o`000?oNl=cog_3Lo`0000[ojoC;00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo000Fooooo`03o`000?oooooooooo04So
oooo00Co0000o`00O?l007co00001?l09Z/00ol0003oC4R/o`000008oeeO_0Co000000?oKGC9o`00
0?mlML403omlML400ol0003oSHO8ohf7b00=ohf7b003o`000?nGSLKoUhg600goUhg600?o0000ojBG
b?nTUlP03OnTUlP00ol0003o/JG<ok6Uc00?ok6Uc003o`000?no]m;o_kOB01;o_kOB0_l0000AomG>
d`03o`000?oNl=cog_3L00;og_3L00?o0000on_dboo[m</01_o[m</00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool02Oooool001Kooooo00?o0000oooooooo
ool0B?ooool01Ol0003o001lo`00O?l007co000000?o02J[00?o0000oda8[?l000001OmMGk`3o`00
00?oGEnl00Co0000ofedbOm]M<Wo00003_mlML400ol0003oQHK<o`00000>ohf7b003o`000?nGSLKo
Uhg600goUhg600?o0000ojBGb?nTUlP03OnTUlP00ol0003o/JG<ok6Uc00?ok6Uc003o`000?no]m;o
_kOB01;o_kOB00?o0000ol_>g?l000003ooEc]<00ol0003og_3Lomk`g003omk`g003o`000?o[m<_o
joC;00GojoC;0_l0000:ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool0
01Kooooo00?o0000ooooooooool0BOooool01?l0003o001lo`00O?l00004o`0VZ`04o`000?mMGkco
GEnloeeO_0?o00001OmMGk`00ol0003oKGC9ofedb@02ofedb@03o`000?mlML7oO7G100[oO7G100Go
0000ohF6c?n5Q/coQHK<o`00000>ohf7b003o`000?nGSLKoUhg600coUhg600?o0000ojBGb?nTUlP0
3OnTUlP00ol0003o/JG<ok6Uc00>ok6Uc003o`000?no]m;o_kOB01;o_kOB00Go0000ol_>g?o;c]co
blkLo`00000=omG>d`03o`000?oNl=cog_3L00Cog_3L00?o0000on_dboo[m</01?o[m</2o`0000_o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003ooooo
ooooo`19ooooo`04o`000?l007co001lo`0000Co02J[1?l00008oeeO_003o`000?m]M<WoKGC900?o
KGC900?o0000ogae`OmlML402?mlML400ol0003oQHK<ohF6c002ohF6c003o`000?n=QlSoSHO800co
SHO800?o0000oiN=a_nGSLH03OnGSLH00ol0003oY9O8ojBGb00<ojBGb003o`000?naYLco/JG<00ko
/JG<00?o0000okngd_no]m804Ono]m800ol0003oblkLol_>g003ol_>g0;o00002_oEc]<00ol0003o
g_3Lomk`g006omk`g003o`000?o[m<_ojoC;00;ojoC;0_l0000=ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool0Boooool01?l0003o001l
o`000?l09Z/5o`0000[oGEnl00?o0000ofedbOm]M<T01?m]M<T00ol0003oO7G1ogae`@06ogae`@03
o`000?n5Q/coQHK<00CoQHK<00?o0000ohf7b?n=QlP03?n=QlP00ol0003oUhg6oiN=aP09oiN=aQKo
00003?naYL`00ol0003o_kOBokngdP0AokngdP03o`000?o;c]coblkL00KoblkL00?o0000omG>dooE
c]<01_oEc]<00ol0003og_3Lomk`g007omk`g007o`000?o[m<_ojoC;on_dbol0003oY^B=o`00000>
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool001Gooooo0ol0001;oooo
o`Co00000ol09Z/00ol0003o;5?7o`000008oeeO_003o`000?m]M<WoKGC900GoKGC900?o0000ogae
`OmlML401OmlML400ol0003oQHK<ohF6c006ohF6c003o`000?n=QlSoSHO800_oSHO800?o0000oiN=
a_nGSLH00_nGSLH7o`0000?oVi[B00?o0000ojFRdonUX]<03?nUX]<01?l0003o[jgFojn]e_n_[MH5
o`0000Oo/JG<00?o0000okngd_no]m804?no]m800ol0003oblkLol_>g008ol_>g0;o00001OoEc]<0
0ol0003og_3Lomk`g008omk`g006o`000?o[m<_ojoC;o`000?nVi8go00004?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Wooooo0ol0
00000ol007co0000o`0VZ`03o`0VZ`04o`000?l/DlOo;5?7o`0000OoGEnl00?o0000ofedbOm]M<T0
1_m]M<T00ol0003oO7G1ogae`@03ogae`@03o`000?n5Q/coQHK<00SoQHK<00?o0000ohf7b?n=QlP0
2_n=QlP5o`0000[oVi[B00?o0000ojFRdonUX]<03?nUX]<00ol0003o[jgFojn]eP06ojn]ePGo0000
0_naYL`00ol0003o_kOBokngdP0?okngdP03o`000?o;c]coblkL00_oblkL00Go0000omG>dooEc]?o
eLkCo`00000<omk`g0;o000000?oY^B=o`000?ooool04Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04Gooooo1?l00003ooooo`;o0000
1?l09Z/01Ol0003o;5?7obaCaol/DlOo000000GoGEnl00?o0000ofedbOm]M<T02?m]M<T01Ol0003o
O7G1ogae`OmlML7o000000_oQHK<00?o0000ohf7b?n=QlP02?n=QlP2o`000003oiBGe?l0003oVi[B
00goVi[B00?o0000ojFRdonUX]<02onUX]<00ol0003o[jgFojn]eP0;ojn]eP;o00004Ono]m800ol0
003oblkLol_>g00=ol_>g003o`000?oEc]?o000000gog_3L00?o0000ojKTSOl000004oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo04;o
oooo0ol00007ooooo`;o00001?l09Z/01Ol0003o;5?7obaCaol/DlOo000000GoGEnl00?o0000ofed
bOm]M<T02Om]M<T00ol0003oO7G1o`00000=ohF6c003o`000?n=QlSoSHO800KoSHO800?o0000oiBG
e?nDUm@00_nDUm@00ol0003oVi[Boi^JdP0;oi^JdP03o`000?nUX]?oYJ;C00[oYJ;C00?o0000ojn]
e_n_[MH03On_[MH00ol0003o^KcLo`000002o`0000co_kOB00?o0000ol_>g?o;c]`03oo;c]`00ol0
003og_3Lomk`g00:omk`g005o`000?nmo<Ko0000ojKTSOl000005?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00Oooooo000Eooooo`03o`000?oooooooooo03oooooo0ol0000;oooo
o`03o`000?l09Z_o02J[00;o02J[00?o0000obaCaol/DlL00_l/DlL01Ol0003oGEnloeeO_?mMGkco
000000goKGC90_l0000>ohF6c003o`000?n=QlSoSHO800?oSHO80_l00006oiBGe003o`000?nKV];o
Vi[B00[oVi[B00?o0000ojFRdonUX]<02_nUX]<00ol0003o[jgFojn]eP0<ojn]eP03o`000?ni_=co
^KcL00?o^KcL0ol00008okngdP03o`000?o;c]coblkL00koblkL00?o0000om7Yiol000002ooNl=`0
1Ol0003o_Oc6o`000?nVi8go000001Kooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0mooooo`?o00003_ooool00ol0003o02J[o`0VZ`02
o`0VZ`03o`000?l/DlOo;5?700?o;5?700Co0000oeeO_?mMGkco00003Om]M<T2ogZ7e003o`000?n5
Q/coQHK<00_oQHK<00Co0000ohf7b?n=QlSoSHO80_l00008oiBGe003o`000?nKV];oVi[B00[oVi[B
00?o0000ojFRdonUX]<02_nUX]<00ol0003o[jgFojn]eP0<ojn]eP03o`000?ni_=co^KcL00Ko^KcL
0_l00005okngdP03o`000?o;c]coblkL00koblkL00Go0000om7YiooAjNOodNWWo`000009omk`g003
o`000?nmo<Ko_Oc600;o00006?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oo
oooo000Dooooo`03o`000?oooooooooo03Wooooo1?l0000Booooo`03o`000?l09Z_o02J[00;o02J[
00?o0000obaCaol/DlL00ol/DlL00ol0003oGEnlo`00000<ofedb@05o`000?mjQmCoNXODogZ7e?l0
00003On5Q/`00ol0003oSHO8o`00000;oiBGe003o`000?nKV];oVi[B00[oVi[B00?o0000ojFRdonU
X]<02OnUX]<00ol0003o[jgFojn]eP0;ojn]eP03o`000?ni_=co^KcL00Wo^KcL0ol000000ono]m;o
0000ol_>g00?ol_>g003o`000?oAjNOodNWW00;odNWW00?o0000omk`g?oNl=`01_oNl=`00ol0003o
_Oc6okglaP02o`0001[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0fooooo`?o00005oooool01Ol0003o02J[o`0VZol09Z_o000000Ko
;5?70_l0000<ofedb@03o`000?mjQmCoNXOD00;oNXOD00?o0000ohF6c?n5Q/`02on5Q/`00ol0003o
U9ODoiBGe00:oiBGe003o`000?nKV];oVi[B00[oVi[B00?o0000ojFRdonUX]<02OnUX]<00ol0003o
[jgFojn]eP0;ojn]eP03o`000?ni_=co^KcL00co^KcL00?o0000ol_>g?o;c]`03_o;c]`00ol0003o
dNWWom7Yi`04om7Yi`03o`000?oNl=cog_3L00Cog_3L00?o0000okgla_nmo<H00_l0000Kooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool01oooool001Cooooo0ol0000cooooo`?o0000
6_ooool01Ol0003o02J[o`0VZol09Z_o000000Ko;5?70_m>LmL00ol0003oKGC9ofedb@09ofedb@03
o`000?mjQmCoNXOD00?oNXOD00?o0000ohF6c?n5Q/`02On5Q/`00ol0003oSIKHo`00000<oiBGe003
o`000?nKV];oVi[B00WoVi[B00?o0000ojFRdonUX]<02OnUX]<00ol0003o[jgFojn]eP0:ojn]eP03
o`000?ni_=co^KcL00co^KcL00Co0000ol7>i?o1c^Co00003?o;c]`2o`0000OodNWW00?o0000omk`
g?oNl=`00ooNl=`01?l0003o_Oc6okgla_nmo<H2o`0001cooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0`ooooo`?o00007_ooool01?l0
003o02J[o`0VZol00006obaCa`04o`000?m>LmOoCW?Go`0000WoKGC900?o0000ogZ7e?mjQm@01Omj
Qm@00ol0003oQHK<ohF6c007ohF6c005o`000?n=U]SoSIKHohfFf?l000003?nDUm@00ol0003oVi[B
oi^JdP08oi^JdP03o`000?nUX]?oYJ;C00WoYJ;C00?o0000ojn]e_n_[MH02_n_[MH00ol0003o^KcL
okVlg00;okVlg003o`000?o1c^Co`LkT00;o`LkT00?o0000ol_>g?o;c]`02?o;c]`00ol0003odNWW
om7Yi`07om7Yi`03o`000?oNl=cog_3L00;og_3L00Co0000okgla_nmo<Ko_Oc60_l0000Nooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool000[ooooo1?l000000ol@413ooooo
ooooo`03ooooo`03o`000?oooooooooo02cooooo1?l0000Rooooo`03o`000?l09Z_o000000Ko;5?7
00Go0000odiceom>LmOoCW?Go`000008ofedb@03o`000?mjQmCoNXOD00KoNXOD00?o0000ohF6c?n5
Q/`01On5Q/`00ol0003oSIKHohfFf003ohfFf003o`000?nDUmCoU9OD00WoU9OD00?o0000oi^Jd_nK
V]802?nKV]800ol0003oYJ;CojFRd`08ojFRd`03o`000?n_[MKo[jgF00_o[jgF00?o0000okVlg?ni
_=`02_ni_=`00ol0003o`LkTol7>i004ol7>i0;o00001oo;c]`00ol0003odNWWom7Yi`09om7Yi`04
o`000?oNl=cog_3Lo`0000Co_Oc600?o0000ooooooooool07_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:_ooool3o`0002Kooooo00?o0000o`0VZol000001_l/DlL00ol0003oCW?Godice`02odice`;o
00001_m]M<T00ol0003oNXODogZ7e007ogZ7e003o`000?n5Q/coQHK<00?oQHK<00?o0000ohfFf?n=
U]P01On=U]P00ol0003oU9ODoiBGe009oiBGe003o`000?nKV];oVi[B00SoVi[B00?o0000ojFRdonU
X]<01onUX]<00ol0003o[jgFojn]eP0:ojn]eP03o`000?ni_=co^KcL00[o^KcL00?o0000ol7>i?o1
c^@01oo1c^@00ol0003oblkLol_>g003ol_>g003o`000?oAjNOodNWW00[odNWW00?o0000omk`g?l0
00001?nmo<H00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Wooooo`?o0000
:_ooool2o`0000Oo;5?700?o0000odiceom>LmL00om>LmL00ol0003oKGC9ofedb@02ofedb@03o`00
0?mjQmCoNXOD00WoNXOD00Go0000ohF6c?n5Q/coQHK<o`000009ohfFf003o`000?nDUmCoU9OD00So
U9OD00?o0000oi^Jd_nKV]801_nKV]88o`0000CoYJ;C00?o0000ojn]e_n_[MH02_n_[MH00ol0003o
^KcLokVlg009okVlg003o`000?o1c^Co`LkT00Wo`LkT00Go0000ol_>g?o;c]coblkLo`00000>om7Y
i`05o`000?nmo<Ko_Oc6okgla_l000009Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool3o`00
02kooooo00?o0000obaCaol/DlL01Ol/DlL00ol0003oCW?Godice`04odice`05o`000?m]M<WoKGC9
ofedbOl000003?mjQm@00ol0003oQHK<o`00000;ohfFf003o`000?nDUmCoU9OD00SoU9OD00?o0000
oi^Jd_nKV]801Ol00002oijZg`03o`000?nT[]ooY:kO00?oY:kO2?l00008ojn]eP03o`000?ni_=co
^KcL00Wo^KcL00?o0000ol7>i?o1c^@02oo1c^@00ol0003oblkLo`00000=om7Yi`03o`000?o2o>Go
000000;o_Oc600?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Kooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08?ooool4o`00
037ooooo00?o02fao`000?l/DlL01Ol/DlL00ol0003oCW?Godice`05odice`04o`000?m]M<WoKGC9
o`0000goNXOD0_l0000<ohfFf003o`000?nDUmCoU9OD00OoU9OD0ol00008oijZg`03o`000?nT[]oo
Y:kO00KoY:kO00Co0000oj^fhOn[]^7oZkKQ1Ol00003ojn]eP03o`000?ni_=co^KcL00So^KcL00?o
0000ol7>i?o1c^@03Oo1c^@00ol0003odNWWom7Yi`0:om7Yi`;o000000Go`_cUo`000?nmo<Ko_Oc6
o`00000Xooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool000cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`?o0000=_ooool00ol0;K7o0000obaC
a`04obaCa`03o`000?m>LmOoCW?G00KoCW?G0_l0000>ogZ7e0;oQYWN00?o0000ohfFf?n=U]P02_n=
U]P00ol0003oU9ODoiBGe004oiBGe0;o000000?oVZSPo`000?nNZ]l02?nNZ]l00ol0003oY:kOojB^
g`06ojB^g`03o`000?n[]^7oZkKQ00KoZkKQ1?l00009okVlg003o`000?o1c^Co`LkT00co`LkT00?o
0000ol?Qk_l000002_oAjNL2o`0000?o`_cU0ol0000Zooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01_ooool000cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0J
ooooo`?o0000>_ooool00ol0;K7o0000obaCa`03obaCa`03o`000?m>LmOoCW?G00OoCW?G0_l0000<
ogZ7e004o`000?n6VMkoQYWNohJIgP;o00002on=U]P00ol0003oU9ODoiBGe002oiBGe003o`000?nJ
Z>3oVZSP00;oVZSP00?o0000oijZgonNZ]l01_nNZ]l00ol0003oY:kOojB^g`06ojB^g`03o`000?n[
]^7oZkKQ00SoZkKQ00?o0000ok70iOl000000_l00005okVlg003o`000?o1c^Co`LkT00_o`LkT0_l0
0003ol?QkP03o`000?oAjNOodNWW00KodNWW00?o0000ol;liOo2o>D00_o2o>D2o`0002gooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`002_ooool00omEEEGoIVIVo`000006
ooooo`;o00006?ooool3o`0003kooooo00?o02fao`000?l/DlL00_l/DlL00ol0003oCW?Godice`07
odice`;oJ8_Q0_l0000:ogZ7e003o`000?n6VMkoQYWN00?oQYWN00?o0000ohfFf?n=U]P02On=U]P0
1?l0003oU9ODo`000?l00006oiZXh003o`000?nNZ]ooWZ[O00KoWZ[O00?o0000ojB^gonT[]l01OnT
[]l00ol0003oZkKQoj^fh@07oj^fh@03o`000?na`>Go/L3U00?o/L3U0ol000000oni_=co0000ol7>
i00;ol7>i0;o00001_o3hNh00ol0003odNWWom7Yi`03om7Yi`;o00001?o2o>D2o`0002oooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`004_ooool00ol0003oooooooooo`0D
ooooo`Co0000@_ooool01Ol0;K7o0000obaCaol/DlOo000000WoCW?G00Go0000ofR;hOmXRn7oJ8_Q
o`000009ogZ7e003o`000?n6VMkoQYWN00CoQYWN0_l0000:ohfFf0;o00002?nJZ>000ol0003oWZ[O
oijZg`05oijZg`03o`000?nT[]ooY:kO00GoY:kO00?o0000oj^fhOn[]^401_n[]^400ol0003o/L3U
ok70i@07ok70i@03o`000?o1c^Co`LkT00[o`LkT00?o0000ol?Qk_o3hNh01_o3hNh01?l0003odNWW
om7YiooAjNL2o`0000Ko`_cU00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Gooooo000Booooo`03o`000?oooooooooo017ooooo0ol00016ooooo`03o`00
0?l0;K7o000000;o;5?700?o0000odiceom>LmL01_m>LmL00ol0003oJ8_QofR;h@02ofR;h@;o0000
1_mjQm@00ol0003oQYWNohJIgP07ohJIgP03o`000?n=U]SoSIKH00KoSIKH00Co0000oiJXhonFZ>?o
00001onJZ>000ol0003oWZ[OoijZg`05oijZg`03o`000?nT[]ooY:kO00CoY:kO00?o0000oj^fhOn[
]^401on[]^400ol0003o/L3Uok70i@06ok70i@?o]Lc[0_l00007ol7>i0;o00002_o3hNh00ol0003o
dNWWo`000007ol;li@03o`000?oooooooooo033ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`05ooooo`004_ooool00ol0003oooooooooo`0>ooooo`?o0000B_ooool01Ol0003o02fa
o`000?l/DlOo000000WoCW?G00?o0000ofR;hOmXRn400omXRn42o`0000CoNXOD00?o0000ohJIg_n6
VMh02?n6VMh00ol0003oSIKHohfFf004ohfFf003o`000?nFZ>?oUZSS00;oUZSS00?o0000oiZXh?nJ
Z>001OnJZ>000ol0003oWZ[OoijZg`05oijZg`03o`000?nT[]ooY:kO00?oY:kO00?o0000oj^fhOn[
]^401_n[]^400ol0003o/L3Uok70i@05ok70i@03o`000?nec>_o]Lc[00Co]Lc[00?o0000ol7>i?o1
c^@00_o1c^@2o`0000go`n7^00?o0000ol;liOo2o>D01?o2o>D00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool0
2oooool3o`0004kooooo00Co0000o`0]/Ol/DlOo00002Om>LmL00ol0003oJ8_QofR;h@05ofR;h@05
o`000?mjQmCoNXODogZ7e?l000002on6VMh2o`0000?oSIKH00?o0000oiJXhonFZ><01?nFZ><2o`00
00KoVZSP00?o0000oijZgonNZ]l01?nNZ]l00ol0003oY:kOojB^g`03ojB^g`03o`000?n[]^7oZkKQ
00GoZkKQ00?o0000ok70iOna`>D01Ona`>D00ol0003o]Lc[okG<j`06okG<j`;o000000?o`LkTo`00
0?o3hNh02_o3hNh3o`000003okcalol0003o`_cU00?o`_cU0_l0000gooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool01Oooool001;ooooo00?o0000ooooooooool01oooool4o`0005;o
oooo00Co0000o`0]/Ol0003o00002?m>LmL00ol0003oJ8_QofR;h@06ofR;h@03o`000?mjQmCo0000
00koQYWN0_n=U]P00ol0003oUZSSoiJXh`07oiJXh`03o`000?nJZ>3oVZSP00?oVZSP00?o0000oijZ
gonNZ]l01?nNZ]l00ol0003oY:kOojB^g`03ojB^g`03o`000?n[]^7oZkKQ00CoZkKQ00?o0000ok70
iOna`>D01?na`>D2o`0000_o]Lc[00?o0000ol?Qk_o3hNh02?o3hNh2o`0000?o_?7c00Co0000ol;l
iOo2o>Go`_cU0ol0000iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool0
01;ooooo00?o0000ooooooooool01?ooool3o`0005Oooooo0_l000000olAKMko0000o`000006odic
e`03o`000?mXRn7oJ8_Q00SoJ8_Q0_l0000>ohJIgP;o00002_nFZ><00ol0003oVZSPoiZXh003oiZX
h003o`000?nNZ]ooWZ[O00CoWZ[O00?o0000ojB^gonT[]l00_nT[]l00ol0003oZkKQoj^fh@04oj^f
h@03o`000?na`>Go/L3U00?o/L3U00?o0000okG<jonec>/02Onec>/00ol0003o]]Sbo`000007ol?Q
kP?o00001OnllO<01_l0003o`_cUol;liOl0003oS^c4o`0003_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`05ooooo`004Oooool00ol0003oooooooooo`02ooooo`?o0000F_ooool0
0ol0003o02fao`000002oa5]gP;o00001?m>LmL00ol0003oJ8_QofR;h@08ofR;h@03o`000?mlW^So
000000;o00002on6VMh00ol0003oTZ[Wo`000002o`0000SoUZSS0_l00004oiZXh004o`000?nNZ]oo
WZ[OoijZg`_o00000_n[]^400ol0003o/L3Uok70i@03ok70i@03o`000?nec>_o]Lc[00Ko]Lc[0_l0
0005okKHlP03o`000?o3hNko`n7^00;o`n7^0_l00008okcal`?o000000?oS^c4o`000?ooool0>ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo000Aooooo`03o`000?oooooo
000000;o0000G_ooool00ol0003o02fao`000003oa5]gP05o`000?m>LmOoCW?Godiceol000002omX
Rn401?l0003oO9kXogbNj?mlW^P3o`0000OoQYWN00?o0000oi:ZionBZ^L00onBZ^L2o`0000SoUZSS
00Co0000oiZXh?nJZ>3oVZSP1?l00002oinlk@03o`000?nQ_NcoXKg/00;oXKg/00Co0000ojBokOnT
_ngoY;o]1Ol00002ok70i@03o`000?nec>_o]Lc[00Go]Lc[0_l00007okKHlP03o`000?o3hNko0000
00;o00002OnllO<2o`0000;oS^c400?o0000ooooooooool0??ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Cooooo000Aooooo`;o0000H_ooool00ol0003o02fao`000003oa5]gP;o
00000_m>LmL00ol0003oJ8_QofR;h@08ofR;h@03o`000?mlW^SoO9kX00CoO9kX0ol00004ohJIgP03
o`000?nBZ^OoTZ[W00GoTZ[W0_l00007oiJXh`03o`000?nJZ>3o000000?oWk_]00Go0000oinlkOnO
_>goWkc]o`000003oj6mk003o`000?nT_ngoY;o]00;oY;o]00Co0000ojO4k_nWa>koYlC^0_l00005
okG<j`?o00002_nff?800ol0003o_?7cokcal`0:okcal`04o`000?n>k<CoS^c4o`00043ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`004oooool00ol0003oooooooooo`1P
ooooo`03o`000?l0;K7o000000Co4FgN00?o0000odiceol000002_mXRn400ol0003oO9kXogbNj007
ogbNj0;o00000_n6VMh00ol0003oTZ[Woi:Zi`07oi:Zi`?o00001?nFZ><3o`0000CoWk_]00Co0000
oinlkOnO_>go00000onQ_N`01Ol0003oY;o]ojBokOnT_ngo000000?oYlC^00Ko0000ojS9lOnXbO7o
Z<Wao`000?nec>/2o`0000Wo]]Sb0ol000000onahOOo0000okcal`07okcal`?o000000?oS^c4o`00
0?l00000@oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo000Dooooo`;o
0000HOooool3o`0000Go4FgN0ol00009ofR;h@03o`000?mlW^SoO9kX00WoO9kX0ol0000;oi:Zi`;o
000000?oUZSSo`000?nN^nd00_nN^nd2o`0000?oWk_]00Co0000oinlkOnO_>go00000_nQ_N`01?l0
003oY;o]ojBokOl00002ojO4kP;o00001?nXbO42o`0000So]]Sb0ol00004ok7Qm`03o`000?nllO?o
_?7c00?o_?7c0ol000001?nWmNoo0000o`000?l00016ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool001Kooooo00?o0000ooooool00000H?ooool2o`0000Co4FgN00?o0000
odVBkom9T^l00ol00006ofR;h@03o`000?mlW^SoO9kX00WoO9kX00?o0000ohb_kOn<[nd01?l00009
oi:Zi`?o00001?nN^nd2o`0000;oWk_]00Go0000oinlkOl0003oXKg/o`000002ojBok@04o`000?nW
a>ko0000o`0000?oZ<Wa0ol000000onXc_Co0000okKHlP04okKHlP?o00001onahOL01?l0003o_?7c
okcalonllO<2o`0000?oYoG_0_l00018ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01?ooool001Oooooo0_l0001Qooooo`;o00001?lAKMh00ol0003oBI;_odVBk`02odVBk`?o0000
0omXRn400ol0003oO9kXogbNj00:ogbNj003o`000?n<[ngoS:o]00?oS:o]0ol00006oi:Zi`03o`00
0?nM_>koWKc^00Co00000_nN^nd2o`000005oinkkOl0003o0000oj6mk?l000000_nT_nd2o`0000;o
Z<Wa0ol00005ojS>m003o`000?nff?;o000000;o00002_nahOL4o`0000CoYoG_0_l0001:ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01?ooool001Sooooo0_l0001Qooooo`;o0000
1?lAKMh00ol0003oBI;_odVBk`04odVBk`?o000000?oJ8_Qo`000?mlW^P02_mlW^P00ol0003oS:o]
ohb_k@06ohb_k@Co000000?oTZ[Wo`000?nM_>h01_nM_>h3o`000003oijkkOl0003o000000?o0000
00?oY;o]o`000?l000000ol00004ojS>m0Ko00003OnahOL00ol0003oYoG_ojOek`04ojOek`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`006_oo
ool00ol0003oooooooooo`1Pooooo`03o`000?lAKMko4FgN00;o4FgN00?o0000odVBkom9T^l01_m9
T^l5o`0000SoO9kX00?o0000ohb_kOn<[nd02_n<[nd:o`0000;oWKc^4?l00004ojGAmP04o`000?na
hOOo/N7gok7Qm`Oo00000onYi_X01?l0003oYoG_ojOekonWmNl3o`00053ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`03ooooo`006oooool2o`000003ooooool0003ooooo05kooooo
00?o0000oa5]g_lAKMh00_lAKMh00ol0003oBI;_odVBk`06odVBk`04o`000?m]Z?CoKJSdoffXm0Oo
00000_mlW^P00ol0003oS:o]ohb_k@0:ohb_k@03o`000?nK_O3oVkg`00KoVkg`6_l00009ojWVnP03
o`000?nWmNoo000000Co0000D_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?o
oooo000Mooooo`;o0000H?ooool2o`0000?o4FgN00?o0000odVBkom9T^l01_m9T^l00ol0003oKJSd
offXm007offXm0[o00001_n<[nd01?l0003oVkg`oi^ml?nK_O0:o`000003oi[;nOl0003o000000Wo
00000onSd_P00ol0003oZNKjojWVnP0:ojWVnP?o00000_n:kN800ol0003oooooooooo`1Booooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool001kooooo00?o0000ooooooooool0
H?ooool2o`0000;o4FgN00?o0000odVBkom9T^l01_m9T^l00ol0003oKJSdoffXm009offXm003o`00
0?n6]oGoQ[Oe00CoQ[Oe2_l00004oiW1l`Go000000GoV/_io`000?l0003oX=7io`000002oj;Bn0;o
00001?nRd_P=o`0000;oZNKj00Co0000oh[]h_n:kN;oR^gR0_l0001Fooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool001oooooo0_l0001Rooooo`Co00002?m9T^l00ol0003o
KJSdoffXm009offXm003o`000?n6]oGoQ[Oe00_oQ[Oe00?o0000oiW1lonI`O<00ol00002oiS6mP06
o`000?nJboWoV/_io`000?nMcoWo00000_nPdOT01?l0003oX];hoj;Bn?nRd_P3o`000003oj;Bn?l0
003oXNSk00[oXNSk0_l00004oh[]hP03o`000?oooooooooo05Oooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`008Oooool00ol0003oooooooooo`1Rooooo`;o00002?m9T^l0
0ol0003oKJSdoffXm009offXm003o`000?n6]oGoQ[Oe00SoQ[Oe00?o0000ohJgmOn6]oD00_l00003
oiS6mP;o00000onJboT01?l0003oWLoioig?nOl00002oj3An@03o`000?nRd_SoX];h00;oX];h1ol0
0005oj7Xn`;o000000?oR^gRo`000?l000000ol0001Kooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool00oooool002;ooooo0ol0001Sooooo`Co00001Om9T^l00ol0003oKJSdoffXm009
offXm004o`000?n6]oGoQ[OeohJgm@Ko00001On1`O`00ol0003oV<Kfo`000004oi[;n@05o`000?nM
coWoWLoioig?nOl000000onPdOT01?l0003oX];ho`000?l00007oiOVo0_o0000G_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo000Tooooo`03o`000?oooooooooo06?ooooo
00?o0000oa^EjOl000001?l000000om9T^oo0000offXm005offXm0So00003?n1`O`Bo`0000OoUnKl
0ol00002ofgNe`?o0000H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo
000Uooooo`;o0000I_ooool2o`0000;o6iGY2?l00007oe^eo0?o00001_n1`O`3o`0000KoOlko00?o
0000ohCIoon4fOl00_n4fOl00ol0003oSN7mohgQo@05ohgQo@;o00000_nGi_`3o`0000;oKMkG0ol0
001Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool002Oooooo00?o0000
ooooooooool0IOooool3o`0000?o6iGY0ol0000;oe^eo0;o000000CoPL7lo`000?l0003o00002?mo
c_l00ol0003oQ=WoohCIo`03ohCIo`03o`000?n=hOgoSN7m00KoSN7m2?l0001Yooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00_ooool002Sooooo00?o0000ooooool00000I_ooool3
o`0000Co6iGY0ol0000:oe^eo004o`000?moc_oo0000o`0000OoOlko00?o0000ohCIoon4fOl01On4
fOl00ol0003oSN7mohgQo@05o`0000;oDm3D0ol0001]ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00_ooool001kooooo1?l000000ol@413oooooooooo`04ooooo`;o0000I_ooool0
0ol0003oooooooooo`03o`0000Co6iGY0ol00002oe^eo0?o00001_m;_o@5o`0000;oOlko00Co0000
ohCIoon4fOooQ=Wo1ol00003oe?@e0Co0000LOooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`03ooooo`Ko000000?o6iGYo`000?l000003_m;_o@6o`0000CoA/KQ00?o0000
oe?@e?mCd=@00ol0001fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
01Gooooo1_l00005ooooo`03o`000?oooooooooo00Wooooo0_l0001Sooooo`03o`000?oooooooooo
00Sooooo00?o0000o`27]_l0QkH00ol0QkH7o`0000?oBkod0_l00004odK6h@Wo0000NOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000Pooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool00000H?ooool00ol0003oooooooooo`0Aooooo`;o00000_l0QkH3o`000003
odK6hOl0003o000000?o0000Poooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;o
oooo000Pooooo`03o`000?oooooooooo00cooooo0_l0001Pooooo`03o`000?oooooooooo0:;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`008?ooool00ol0003ooooooooo
o`0=ooooo`;o0000Goooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00Oooool0023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01
ooooo`007_ooool00omEEEGoIVIVo`00000Booooo`;o000000?oooooo`000?ooool0F?ooool00ol0
003oooooooooo`2Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool003Go
oooo0_l0001Iooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`01ooooo`00=_ooool2o`0005Sooooo00?o0000ooooooooool0Yoooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo007ooooo000hooooo`05o`000?ooooooooooooooool00000
Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0Oooool003Wooooo00Co0000oooooooooooo0000Doooool00ol0003oooooooooo`2Yooooo`03o`00
0?oooooooooo00Wooooo0Ol00001ooooo`7ooooo000jooooo`?o0000Doooool00ol0003ooooooooo
o`2Zooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo000looooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1
ooooo`00?Oooool2o`00057ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`07oooo
o`7o00000Oooool1ooooo`00?oooool00ol0003oooooo`00001>ooooo`03o`000?oooooooooo0:co
oooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0043ooooo0_l0001>ooooo`03o`00
0?oooooooooo0:gooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool0047ooooo0_l0
001=ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Ooo
ool004?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`00A?ooool2o`000003ooooool0003ooooo04Oooooo00?o0000oooo
ooooool0[oooool00ol0003oooooooooo`04ooooo`7o00000Oooool004Kooooo0_l00018ooooo`03
o`000?oooooooooo0;3ooooo00?o0000ooooooooool00oooool1o`00007ooooo000booooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00CoA4A4o`000?l0003o<S8b0_l00017oooo
o`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool00_ooool1o`00007ooooo000booooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00CoMgMgoc8b<_oooooo0000A_ooool0
0ol0003oooooooooo`2booooo`05o`000?ooooooooooooooool000000Oooool002[ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03o`0004?ooooo00?o
0000ooooooooool0/oooool01?l0003oooooooooool00001ooooo`00<_ooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo0;?ooooo00Co0000oooooooooooo00000Oooool003;ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool00Ol0000003;ooooo00Go410@oooooooo
oooooooooa0@400<ooooo`03o`000?oooooooooo00Sooooo0_l00010ooooo`03o`000?oooooooooo
0;Gooooo0Ol00001ooooo`7o0000000booooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0
003oooooooooo`0:ooooo`;o0000?_ooool00ol0003oooooooooo`2fooooo`;o0000000booooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000[ooooo0_l0000mooooo`03o`000?oooooooooo
0;Gooooo0ol0000005?ooooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo
0;3ooooo1Ol00003ooooo`00E?ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo
0:cooooo1?l00008ooooo`00EOooool3o`0003Sooooo00?o0000ooooooooool0Z?ooool4o`0000co
oooo001Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Y?ooool5o`00013ooooo
001Hooooo`;o0000=Oooool00ol0003oooooooooo`2Pooooo`Co00005Oooool005[ooooo00?o0000
ooooool00000<_ooool00ol0003oooooooooo`2Looooo`Co00006Oooool005_ooooo0_l0000boooo
o`03o`000?oooooooooo09Oooooo1Ol0000Mooooo`00GOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo09?ooooo1?l0000Rooooo`00G_ooool01?l0003oooooooooool0000]ooooo`03
o`000?oooooooooo08kooooo1Ol0000Vooooo`00Goooool3o`0002gooooo00?o0000ooooooooool0
R_ooool4o`0002_ooooo001Qooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0Q_oo
ool4o`0002oooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02_ooool2o`0002_ooooo00?o
0000ooooooooool0POooool5o`0003?ooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooo`00000Xooooo`03o`000?oooooooooo07gooooo1?l0000hooooo`00Doooool0
1Ol@413ooooooooooooooooo410@00gooooo0_l0000Xooooo`03o`000?oooooooooo07Wooooo1?l0
000looooo`00Doooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1dooooo`Go0000@?ooool005?ooooo00Go0000ooooooooooooooooo`00
000@ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0L?ooool4o`0004Gooooo
001Cooooo`05oa0@4?ooooooooooooooool@41004Oooool3o`0002?ooooo00?o0000ooooooooool0
Joooool5o`0004Wooooo001Cooooo`05ogMgMonHV9SooooooiRHV?mgMgL04_ooool2o`0002?ooooo
00?o0000ooooooooool0Ioooool4o`0004kooooo001Cooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
5?ooool2o`000003ooooool0003ooooo01kooooo00?o0000ooooooooool0Hoooool4o`0005;ooooo
001^ooooo`;o00007oooool00ol0003oooooooooo`1Nooooo`Go0000E_ooool006oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Jooooo`Co0000Foooool0073ooooo0_l0000Moooo
o`03o`000?oooooooooo05Kooooo1?l0001Oooooo`00L_ooool00ol0003oooooo`00000Jooooo`03
o`000?oooooooooo057ooooo1Ol0001Sooooo`00Loooool2o`0001[ooooo00?o0000ooooooooool0
COooool4o`0006Sooooo001eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0BOoo
ool4o`0006cooooo001fooooo`;o000000?oooooo`000?ooool05?ooool00ol0003oooooooooo`14
ooooo`Go0000L?ooool007Sooooo0_l0000Eooooo`03o`000?oooooooooo043ooooo1?l0001eoooo
o`00NOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03_ooooo1Ol0001iooooo`00
N_ooool2o`000003ooooool0003ooooo013ooooo00?o0000ooooooooool0=oooool4o`0007kooooo
001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@03ooooo`;o00004Oooool00ol0003oooooooooo`0cooooo`Co0000P_ooool006?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`;o
00003oooool00ol0003oooooooooo`0_ooooo`Go0000Q_ooool006?ooooo00Go410@oooooooooooo
oooooa0@400@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0[ooooo`Co0000Roooool006?ooooo00Go0000ooooooooooooooooo`00000?ooooo`03
ogMgMolb<S;ooooo00Kooooo0ol0000;ooooo`03o`000?oooooooooo02Oooooo1?l0002?ooooo`00
Hoooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c009oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08_ooool5o`0009?ooooo001Sooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool07_ooool4o`0009Sooooo001Sooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0=ooooo`?o00001oooool00ol0003oooooooooo`0I
ooooo`Go0000W?ooool006?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00003_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo1?l0002Qooooo`00Qoooool2o`00
00Gooooo00?o0000ooooooooool04Oooool4o`000:Gooooo0029ooooo`;o00000oooool00ol0003o
ooooooooo`0<ooooo`Go0000ZOooool008[ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co
0000[_ooool008_ooooo0_l000000ooooooo0000ooooo`05ooooo`Co0000/_ooool008gooooo0_l0
00000ooooooo0000o`000003o`000;Kooooo002>ooooo`;o0000^oooool00?ooooooC?ooool00?oo
ooooC?ooool008Cooooo1?l000000ol@413oooooooooo`30ooooo`00Q_ooool00ol0003ooooooooo
o`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32oooo
o`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_ooool00ol0003oooooooooo`32ooooo`00Q_oo
ool00ol0003oooooooooo`32ooooo`00Q?ooool00omEEEGoIVIVo`000034ooooo`00\
\>"],
  ImageRangeCache->{{{0, 330.625}, {358.875, 0}} -> {0.000289879, -0.0237174, \
0.00342508, 0.00342508}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThis type of elliptical traveling wave can be excited by the \
gravitational attraction of the earth to the moon. The moon appears to \
revolve about the earth daily in the earth's rest frame. This revolution, in \
concert with the earth-moon attraction, causes an elliptical distortion that \
follows the moon's apparent position, and is responsible for the earth's \
tides [see Eq. ",
  ButtonBox["(4.3.80)",
    ButtonData:>"(4.3.80)",
    ButtonStyle->"Hyperlink"],
  "]. It is interesting that the natural frequency of this mode is 23 hours \
for the parameters that we chose; this means that the mode is almost resonant \
with the gravitational force caused by the moon (in our simple model, that is \
- on the real earth, there are many effects neglected here, not least of \
which are the continents, which tend to get in the way of this mode). "
}], "Text",
  CellTags->"i:93"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4.3 The Rate of Cooling of the Earth ", "Subsubtitle",
  CellTags->"c:41"],

Cell[TextData[{
  "We now consider a classic heat equation problem in spherical coordinates, \
in which the following question is addressed: a sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ",",
  " with thermal diffusivity \[Chi], is initially at uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o\)]],
  ", and the surroundings are at  lower temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  ". What is the rate at which the sphere cools to temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1\)]],
  "? "
}], "Text"],

Cell[TextData[{
  "\tSince the problem has spherical symmetry, the spherical harmonics are \
not needed, and the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(r, t)\)\(\ \)\)\)]],
  "evolves according to the spherically symmetric diffusion equation, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = \[Chi] \( 
              1\/r\^2\) \(\[PartialD]\/\[PartialD]r\) \((\(r\^2\) \
\[PartialD]T\/\[PartialD]r)\)\)]],
  ","
}], "NE5",
  CellTags->"(4.4.26)"],

Cell[TextData[{
  "with boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`T(R, t) = T\_1\)]],
  ", and initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, 0) = T\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAs usual, we remove the inhomogeneous boundary condition by writing ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T(r, t)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["T",
                    FontSlant->"Italic"]}]], "(", \(r, t\), ")"}], " ", "+", 
            " ", \(u(r)\)}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  " is chosen to match the boundary condition. A simple choice is ",
  Cell[BoxData[
      \(TraditionalForm\`u(r) = T\_1\)]],
  ". Then \[CapitalDelta]",
  StyleBox["T",
    FontSlant->"Italic"],
  " evolves according to Eq. ",
  ButtonBox["(4.4.26)",
    ButtonData:>"(4.4.26)",
    ButtonStyle->"Hyperlink"],
  " with boundary condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(R, t\), ")"}], "=", "0"}], 
        TraditionalForm]]],
  " and initial condition"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(r, 0\), ")"}], 
          "=", \(T\_o - T\_1\)}], TraditionalForm]]]
}], "NE5",
  CellTags->"(4.4.27)"],

Cell[TextData[{
  " \tThe solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["T",
                FontSlant->"Italic"]}]], "(", \(r, t\), ")"}], 
        TraditionalForm]]],
  "  follows a by now familiar path: we expand  \[CapitalDelta]",
  StyleBox["T",
    FontSlant->"Italic"],
  " in the spherically symmetric Dirichlet eigenmodes of the spatial operator \
in Eq. ",
  ButtonBox["(4.4.26)",
    ButtonData:>"(4.4.26)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["T",
                  FontSlant->"Italic"]}]], "(", \(r, t\), ")"}], 
          "=", \(\[Sum]\+\(n = 1\)\%\[Infinity]\(\( c\_n\)(
                t)\) \(\(\[Psi]\_n\)(r)\)\)}], TraditionalForm]]],
  ","
}], "NE5",
  CellTags->"(4.4.28)"],

Cell[TextData[{
  "then recognize that these eigenmodes are the ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0\)]],
  " (spherically symmetric) spherical Bessel functions studied in previous \
examples:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_n\)(
          r)\  = \ \(\(sin(n\ \[Pi]\ r/R)\)\(\ \)\)\/r\)]],
  ","
}], "NE5",
  CellTags->"(4.4.29)"],

Cell["with eigenvalues", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_n = \(-\[Chi]\)\ \((n\ \[Pi]/R)\)\^2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 1, 2, 3,  ... \)\)\)]]
}], "NE5",
  CellTags->"(4.4.30)"],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(4.3.58)",
    ButtonData:>"(4.3.58)",
    ButtonStyle->"Hyperlink"],
  " and Table ",
  ButtonBox["4.2",
    ButtonData:>"Table 4.2",
    ButtonStyle->"Hyperlink"],
  "] . These modes are orthogonal with respect to the radial inner product  \
given in Eq. ",
  ButtonBox["(4.3.61)",
    ButtonData:>"(4.3.61)",
    ButtonStyle->"Hyperlink"],
  ". The evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " then follows by taking the inner product with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_n\)]],
  ", yielding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]\/\[DifferentialD]t\) \(\(c\_n\)(
            t)\)\  = \ \(-\[Chi]\)\ \(\((n\ \[Pi]/R)\)\^2\) c\_n\)]],
  ", which has the solution"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(c\_n\)(t)\  = \ 
      A\_n\ \(\(\[ExponentialE]\^\(\(-\((n\ \[Pi]/R)\)\^2\) \[Chi]\ \
t\)\)\(.\)\)\)]]], "NE5",
  CellTags->"(4.4.31)"],

Cell[TextData[{
  "Finally, the constants ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\_n\)\(\ \)\)\)]],
  "are determined by the initial condition ",
  ButtonBox["(4.4.27)",
    ButtonData:>"(4.4.27)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\  = \ \((\(\[Psi]\_n\)(r), 
            T\_o - T\_1)\)/\((\[Psi]\_n, \[Psi]\_n)\)\)]],
  "."
}], "NE5",
  CellTags->"(4.4.32)"],

Cell[TextData[{
  "\tThis completes the formulation of the problem. Before we exhibit the \
full solution, however, it is instructive to examine the behavior of ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n\)(t)\)]],
  " for different mode numbers. Equation ",
  ButtonBox["(4.4.32)",
    ButtonData:>"(4.4.32)",
    ButtonStyle->"Hyperlink"],
  " implies that an infinite number of eigenmodes are excited by the initial \
condition. However, eigenmodes with large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " decay away very rapidly according to Eq. ",
  ButtonBox["(4.4.31)",
    ButtonData:>"(4.4.31)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, at late times, the evolution is determined by the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " mode alone, with an exponential decay of the form ",
  Cell[BoxData[
      \(TraditionalForm\`A\_1\ \[ExponentialE]\^\(\(-\((\[Pi]/R)\)\^2\) \
\[Chi]\ t\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tLet's determine this exponential rate of thermal decay  for the earth,  \
a sphere with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 6400\ km\)]],
  ". The thermal diffusivity  of  the earth has been estimated to be roughly \
",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Chi]~\ 2\[Cross]10\^\(\(-6\)\(\ \)\)\), 
          StyleBox[\(m\^2/s\),
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". The rate constant for the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  " mode is then ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\((\[Pi]/R)\)\^2\), \(\[Chi]~\ 5\[Cross]10\^\(-19\)\), " ", 
          
          SuperscriptBox[
            StyleBox["s",
              FontSlant->"Plain"], \(-1\)]}], TraditionalForm]]],
  ". The reciprocal of this rate is the time for the temperature to drop by a \
factor of ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE] = 2.71 ... \)]],
  ", and equals ",
  Cell[BoxData[
      \(TraditionalForm\`60\ billion\ years\)]],
  "! This is rather satisfying, since it is much longer than the age of the \
earth, currently estimated at around 4 billion years. Thus, we would expect \
from this argument that the earth's core would still be hot, as in fact it \
is."
}], "Text"],

Cell[TextData[{
  "Looked at more carefully, however, there is a contradiction. The average \
temperature gradient at the surface of the earth has been measured to be \
about 0.03K/m (or 30 K/km, measured in mineshafts and boreholes).  Below, we \
plot this surface gradient using our solution, Eq. ",
  ButtonBox["(4.4.28)",
    ButtonData:>"(4.4.28)",
    ButtonStyle->"Hyperlink"],
  ",  and assuming that the initial temperature of the earth is uniform, and \
around the melting temperature of rock, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_0\), "=", 
          RowBox[{"2000", " ", 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(A[n_]\  = \ \((T\_o - T\_1)\) 
        Simplify[
          Integrate[r^2\ Sin[n\ Pi\ r/R]\ /r, {r, 0, R}]/
            Integrate[r^2\ Sin[n\ Pi\ r/R]^2\ /r^2, {r, 0, R}], 
          n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.48"],

Cell[BoxData[
    \(\(-\(\(2\ \((\(-1\))\)\^n\ R\ \((\(-T\_1\) + 
                T\_o)\)\)\/\(n\ \[Pi]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(T\_o = 2000; \ T\_1 = 300; \ 
    R = 6.4\ *10^6; \ \[Chi] = 2\ *10^\(-6\);\), "\n", \(M = 700;\), "\n", 
    RowBox[{\(year\  = \ 60*60*24*365;\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      StyleBox[\( (*\ the\ temperature\ \(\(gradient\)\(:\)\)\ *) \),
        FontColor->RGBColor[1, 0, 
        0]]}], "\n", \(dT[r_, 
          t_]\  = \ \[Sum]\+\(n = 1\)\%M A[n]\ D[Sin[\ n\ Pi\ r/R]\/r, 
              r] \[ExponentialE]\^\(\(-\[Chi]\)\ \(\((n\ Pi/R)\)\^2\) t\);\), \
"\n", \(Plot[dT[R, t\ 10^6\ year], {t, 1, \ 50\ }, 
        AxesLabel \[Rule] {\*"\"\<t (\!\(10\^6\) years)\>\"", \
\*"\"\<dT/dr\!\(\( | \_\(r = R\)\)\) (\[Degree]K/m)\>\""}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 4.49"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.603319 4.8851 [
[.21429 .59082 -6 -9 ]
[.21429 .59082 6 0 ]
[.40476 .59082 -6 -9 ]
[.40476 .59082 6 0 ]
[.59524 .59082 -6 -9 ]
[.59524 .59082 6 0 ]
[.78571 .59082 -6 -9 ]
[.78571 .59082 6 0 ]
[.97619 .59082 -6 -9 ]
[.97619 .59082 6 0 ]
[1.025 .60332 0 -6.40625 ]
[1.025 .60332 81.25 6.40625 ]
[.01131 .01711 -30 -4.5 ]
[.01131 .01711 0 4.5 ]
[.01131 .11481 -24 -4.5 ]
[.01131 .11481 0 4.5 ]
[.01131 .21251 -30 -4.5 ]
[.01131 .21251 0 4.5 ]
[.01131 .31021 -30 -4.5 ]
[.01131 .31021 0 4.5 ]
[.01131 .40792 -30 -4.5 ]
[.01131 .40792 0 4.5 ]
[.01131 .50562 -30 -4.5 ]
[.01131 .50562 0 4.5 ]
[.02381 .64303 -46.8438 0 ]
[.02381 .64303 46.8438 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .60332 m
.21429 .60957 L
s
[(10)] .21429 .59082 0 1 Mshowa
.40476 .60332 m
.40476 .60957 L
s
[(20)] .40476 .59082 0 1 Mshowa
.59524 .60332 m
.59524 .60957 L
s
[(30)] .59524 .59082 0 1 Mshowa
.78571 .60332 m
.78571 .60957 L
s
[(40)] .78571 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(50)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.0619 .60332 m
.0619 .60707 L
s
.1 .60332 m
.1 .60707 L
s
.1381 .60332 m
.1381 .60707 L
s
.17619 .60332 m
.17619 .60707 L
s
.25238 .60332 m
.25238 .60707 L
s
.29048 .60332 m
.29048 .60707 L
s
.32857 .60332 m
.32857 .60707 L
s
.36667 .60332 m
.36667 .60707 L
s
.44286 .60332 m
.44286 .60707 L
s
.48095 .60332 m
.48095 .60707 L
s
.51905 .60332 m
.51905 .60707 L
s
.55714 .60332 m
.55714 .60707 L
s
.63333 .60332 m
.63333 .60707 L
s
.67143 .60332 m
.67143 .60707 L
s
.70952 .60332 m
.70952 .60707 L
s
.74762 .60332 m
.74762 .60707 L
s
.82381 .60332 m
.82381 .60707 L
s
.8619 .60332 m
.8619 .60707 L
s
.9 .60332 m
.9 .60707 L
s
.9381 .60332 m
.9381 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10.4062 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(H) show
81.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
93.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(years) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
134.250 13.812 moveto
(L) show
140.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01711 m
.03006 .01711 L
s
[(-0.12)] .01131 .01711 1 0 Mshowa
.02381 .11481 m
.03006 .11481 L
s
[(-0.1)] .01131 .11481 1 0 Mshowa
.02381 .21251 m
.03006 .21251 L
s
[(-0.08)] .01131 .21251 1 0 Mshowa
.02381 .31021 m
.03006 .31021 L
s
[(-0.06)] .01131 .31021 1 0 Mshowa
.02381 .40792 m
.03006 .40792 L
s
[(-0.04)] .01131 .40792 1 0 Mshowa
.02381 .50562 m
.03006 .50562 L
s
[(-0.02)] .01131 .50562 1 0 Mshowa
.125 Mabswid
.02381 .04153 m
.02756 .04153 L
s
.02381 .06596 m
.02756 .06596 L
s
.02381 .09038 m
.02756 .09038 L
s
.02381 .13923 m
.02756 .13923 L
s
.02381 .16366 m
.02756 .16366 L
s
.02381 .18809 m
.02756 .18809 L
s
.02381 .23694 m
.02756 .23694 L
s
.02381 .26136 m
.02756 .26136 L
s
.02381 .28579 m
.02756 .28579 L
s
.02381 .33464 m
.02756 .33464 L
s
.02381 .35906 m
.02756 .35906 L
s
.02381 .38349 m
.02756 .38349 L
s
.02381 .43234 m
.02756 .43234 L
s
.02381 .45677 m
.02756 .45677 L
s
.02381 .48119 m
.02756 .48119 L
s
.02381 .53004 m
.02756 .53004 L
s
.02381 .55447 m
.02756 .55447 L
s
.02381 .57889 m
.02756 .57889 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -107.844 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dT) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(\\220) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dr) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(\\310) show
99.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
103.188 14.562 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
107.375 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
118.625 13.000 moveto
(H) show
124.625 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\241) show
(K) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
134.562 13.000 moveto
(\\220) show
140.562 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
146.688 13.000 moveto
(L) show
152.688 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04286 .01472 m
.04741 .07462 L
.05165 .11666 L
.0567 .15564 L
.06129 .18403 L
.07068 .22851 L
.08072 .2633 L
.0909 .29026 L
.10195 .31333 L
.12201 .34479 L
.14145 .36722 L
.16206 .38563 L
.19914 .41016 L
.23862 .42894 L
.27662 .44268 L
.31702 .45425 L
.35593 .46333 L
.39336 .47068 L
.43319 .47736 L
.47154 .48293 L
.51229 .48812 L
.55156 .49253 L
.58934 .49634 L
.62952 .5 L
.66822 .50319 L
.70543 .50599 L
.74505 .50874 L
.78318 .51118 L
.82371 .51358 L
.86276 .51572 L
.90032 .51765 L
.94029 .51956 L
.97619 .52118 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@
ooooooooool01Ol00004ooooo`03o`000?oooooooooo0?oooooo;?ooool001Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01?ooool00ol0003oooooooooo`3oooooobcooooo000Aooooo`Ko00000_ooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^
kP05ooooo`05o`000?ooooooooooooooool00000oooooolZooooo`006Oooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP04ooooo`;o0000
0_ooool00ol0003oooooooooo`3oooooobSooooo000Iooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000oooooooooooo
ooooo`00003oooooob[ooooo000Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003ooooo
ob[ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`02oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool01Ol0003ooooooooooooooooo00000?oooooo:_oo
ool001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c004ooooo`05o`000?ooooooooooooooool00000oooooolZooooo`00
>_ooool2o`0000;ooooo00?o0000ooooooooool0oooooolXooooo`00>_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?oooooo9oooool003[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooobOooooo000jooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolWooooo`00>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo9oooool003[ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo9oooool003[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobOooooo000jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolWooooo`00>_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo9oooool003[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooobOooooo000jooooo`;o00000oooool00ol0003oooooooooo`3oooooobOooooo
000jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolVooooo`008Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo0?oooooo9_ooool0027ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolVooooo`006Oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo
9_ooool0027ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobKooooo000Qooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0oooooolVooooo`008Oooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
9_ooool0027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobKooooo000Qooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`;o00001Oooool00ol0003ooooo
ooooo`3oooooobGooooo000jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolUooooo`00>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo9Oooool0
03[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobGooooo000jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolUooooo`00>_ooool2o`0000Gooooo
00?o0000ooooooooool0oooooolUooooo`00>_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo9Oooool003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
ooooobCooooo000jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolToooo
o`00>_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo9?ooool003[ooooo
0_l00006ooooo`03o`000?oooooooooo0?oooooo9?ooool003[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooobCooooo000Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo9?ooool001Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolTooooo`004Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooob?ooooo000Iooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P04ooooo`;o00001oooool00ol0003oooooooooo`3oooooob?ooooo000Iooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Goc<c<
o`000?l0003o0000olc<c004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
oolSooooo`006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?nj^[[ooooookZj^_l@41001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?oooooo8oooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj^[[o000000Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooob?ooooo000Iooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolSooooo`00>_oo
ool2o`0000Oooooo00?o0000ooooooooool0oooooolSooooo`00>_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo8_ooool003[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooob;ooooo000jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0oooooolRooooo`00>_ooool2o`0000Wooooo00?o0000ooooooooool0oooooolQooooo`00>_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo8Oooool003[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3oooooob7ooooo000jooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0oooooolPooooo`00>_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0?oooooo8?ooool003[ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
8?ooool003[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooaoooooo000j
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolOooooo`006Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3ooooooakooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo7Oooool0017ooooo1_l00002ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`;o00003Oooool00ol0003oooooooooo`3ooooooagooooo000I
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0oooooolLooooo`006Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0?oooooo7?ooool001Wooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?ooooooooooooooool@41000oooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0oooooolKooooo`006Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH00Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`3ooooooa[ooooo000Iooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Coc<c<odA4A?l0
003o410@1?ooool2o`00013ooooo00?o0000ooooooooool0oooooolJooooo`00>_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo6Oooool003[ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`3ooooooaSooooo000jooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0oooooolHooooo`00>_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo0?oooooo5oooool003[ooooo0_l0000Dooooo`03o`000?oooooooooo0?oooooo5_ooool003[o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3ooooooaKooooo000jooooo`03o`00
0?oooooooooo01Cooooo0_l0003ooooooaKooooo000jooooo`03o`000?oooooooooo01Kooooo0_l0
003ooooooaCooooo000jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0oooooolA
ooooo`00>_ooool2o`0001[ooooo0_l0003ooooooa7ooooo000jooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0ooooool>ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool07?ooool2o`000?oooooo3_ooool001Wooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oooooo2oooool0
017ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00?ooooo1Ol00004ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooo
ool:ooooo`006Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`000003ooooo`04odA4A?oMgMgoooooo`0000Gooooo0_l0000Qooooo`;o0000ooooool:ooooo`00
6Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003oooo
o`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool08_ooool2o`000?oooooo2?ooool0
01Wooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001?oo
ool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo02Cooooo0_l0003oooooo`Kooooo000I
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo
00?ok^k^odA4A?l000001Oooool00ol0003oooooooooo`0Vooooo`;o0000ooooool4ooooo`006Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
ogMgMol0003ooooo00Cooooo0_l0000Yooooo`?o0000ooooool1ooooo`00>_ooool00ol0003ooooo
ooooo`0[ooooo`?o0000oOooool003[ooooo00?o0000ooooooooool0;_ooool3o`000?[ooooo000j
ooooo`03o`000?oooooooooo037ooooo0ol0003gooooo`00>_ooool00ol0003oooooooooo`0doooo
o`?o0000m?ooool003[ooooo0_l0000hooooo`?o0000lOooool003[ooooo00?o0000ooooooooool0
>_ooool4o`000>gooooo000jooooo`03o`000?oooooooooo03kooooo1_l0003Wooooo`00>_ooool0
0ol0003oooooooooo`14ooooo`Oo0000h?ooool003[ooooo00?o0000ooooooooool0Boooool8o`00
0=Sooooo000jooooo`;o0000E?ooool6o`000=;ooooo000jooooo`03o`000?oooooooooo05Wooooo
1?l0003>ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Cooooo00?o0000ooooooooool0GOooool>o`000<3o
oooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`1[
ooooo`Oo0000^Oooool0017ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003ooooooooo
o`1booooo`So0000/Oooool001Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001Oooool00onHV9So8B4Qonk^kP04ooooo`;o0000Noooool?o`000:;ooooo
000Iooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?oMgMgofIVI_ooool00oooool00ol0003oooooooooo`29oooooa3o0000T_ooool001Wooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo09Wooooo5ol0001kooooo`006Oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`2`ooooo`_o0000L?ooool001Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Cooooo00?o0000ooooooooool0ooooool/ooooo`00>_ooool2o`000?oooooo
;Oooool003[ooooo00?o0000ooooooooool0ooooool/ooooo`00>_ooool00ol0003oooooooooo`3o
ooooobcooooo000jooooo`03o`000?oooooooooo01gooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^6Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Iooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo0_l00000
2Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP0Jooooo`05odA4A?l0003o0000oc8b
<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo000jooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol@413o^[Zj
oooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Kooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RH
oooooonHV9SoMgMg06_ooooo000jooooo`;o00008?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41006_ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41007Oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool05_ooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@400Nooooo`04o`000?oooooooooooa0@40?ooooo
00?o410@ooooooooool0JOooool003[ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000006oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000007?ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooooooooooo
ool000006?ooool01?m4A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000007Ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00?o0000ooooooooool0JOooool003[ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
7?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000006oooool00ol@413o
0000okZj^P03ooooo`05o`000?ooooooooooooooool000006?ooool01?oMgMgoEEEEooooool00004
ooooo`05o`000?ooooooooooooooool000006_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo
00Go0000ooooooooooooooooo`00001[ooooo`00>_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Mooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`0Jooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Iooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@
400Jooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@400jooooo`?o0000
00?o410@ooooooooool0:oooool003[ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06Oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Iooooo`05oa0@4?nHV9SooooookZj^_l000000oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01Wooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01[ooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01[o
oooo00?oMgMgofIVI_ooool07oooool00ol@413o^[Zjooooo`0Rooooo`03ofIVI_mgMgOooooo00Oo
oooo000jooooo`;o00007_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h06Oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0I
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo
00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h06Oooool00ooMgMgo410@onk^kP0Pooooo`03oiRHV?lb<S;ooooo
02;ooooo00?ok^k^oa0@4?oMgMd01oooool003[ooooo00?o0000ooooooooool0b?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00cooooo00?oEEEEoiRHV?ooool00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hAooooo`03omgMgOl0003o^[Zj00Cooooo00Kok^k^oeEEEOl0003o
0000odA4A?nj^[X2ooooo`08oiRHV?l0003o0000ogMgMol@413o0000ooooool@4105o`0000?ooooo
00Wo410@oc8b<_l0003o0000oa0@4?nYZJWoooooohN7QomVIVH01oooool003[ooooo00?o0000oooo
ooooool0b?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool00omEEEGoMgMgodA4
A004ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01Ol0003oc<c<onk^k_n7QhOo0000
00Cooooo00?o0000ooooooooool01?ooool02Ol0003oZJVYoooooooooooo^[Zjo`000?ooooook^k^
o`000007ooooo`00>_ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00kooooo00?o
<S8booooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
4?ooool01OoMgMgo410@oooooolQ8B7ogMgM00?ooooo00?o0000ooooooooool01Oooool01Ol@413o
QhN7ooooooo^k^ko000000Cooooo00?o0000ooooooooool01Oooool01Onj^[[oQhN7ofIVI_mVIVKo
410@00;ooooo00?o0000ooooooooool01Oooool003Gooooob?l00008ooooo`03o`000?oooooooooo
00kooooo00?o<S8booooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00?ooooo1_l00002ooooo`03okZj^_l@
413o000000;o00001?ooool00ol0003oooooooooo`04ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0_ooool00ol0003oooooooooo`05ooooo`00>_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03onk^k_l0003ok^k^00;o
oooo00[o0000omgMgOoooooooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00oo<c<co0000
ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00Wo0000okZj^_ooooook^k^ogMgMol0003ooooo
onk^k_l000001oooool003[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Wooooo00?o410@o`000?l000000ol0000=ooooo`03oeEEEOmgMgOooooo
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00Co410@
o`000?l0003ooooo0_l000001Ol@413oooooooooooo^k^koEEEE00;o000000?oA4A4onk^k_ooool0
0_ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02OnY
ZJWo8B4Qo`000?l0003o<S8bo`000?ooooooMgMgoeEEE@07ooooo`00>_ooool00ol0003ooooooooo
o`38ooooo`03o`000?oooooooooo00kooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool2o`0003;ooooo00?ok^k^oa0@4?oMgMd0
1oooool00?oooooo1_ooool00ol0003oooooooooo`0?ooooo`03ogMgMomVIVKooooo00;ooooo00?o
EEEEofIVI_l000001?ooool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000000_ooool00ol0003o
ooooooooo`0_ooooo`03ofIVI_mgMgOooooo00Oooooo003oooooob[ooooo00Co0000oooooooooooo
0000>oooool00?oooooo:_ooool3o`0003cooooo003oooooob_ooooo00?o0000ooooooooool0>ooo
ool00?oooooo;?ooool00ol0003oooooooooo`0jooooo`00oooooomYooooo`00oooooomYooooo`00
;?ooool00ol0003oooooooooo`03o`0000?ooooo1_l00002ooooo`03o`000?oooooooooo00gooooo
00?oMgMgofIVI_ooool07?ooool00omVIVKoMgMgooooo`3iooooo`004oooool00olQ8B7ogMgMoooo
o`0Fooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooo`00000?ooooo`03omgM
gOl@413ok^k^00kooooo00?o8B4QomgMgOooool03?ooool00oo^k^ko410@omgMg@3iooooo`000ooo
ool02Oo^k^koEEEEo`000?l0003oV9RHo`000?l@413ooooooa0@4003o`000006oa0@4?oooooooooo
oooooonHV9SoEEEE1Oooool01_o^k^koEEEEo`000?l0003oV9RHo`0000;o410@1Ol00005ooooo`05
o`000?ooooooooooooooool000001?ooool4o`000003ooooool0003o0000013ooooo00?oEEEEoiRH
V?ooool01Oooool3o`0000;ooooo00KoZJVYo`000?oooooooooooiRHV?mEEED4ooooo`;o00000_oo
ool02?l0003oooooooooool0003o410@oooooon7QhOoIVIVnOooool000?ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00004ooooo`03o`000?oooooooooo00Cooooo00?o0000omgMgOooool00oooool0
1_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
ooooool0003ooooo00;o00001oooool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo00Ko
oooo00Ko0000oooooooooooooooooa0@4?nj^[X3ooooo`03o`000?oMgMgooooo00?ooooo00Co0000
oooooooooooo00000_ooool01Ol0003oooooooooooo^k^ko00000?Wooooo0003ooooo`06o`000?oo
ooooooooooooooo^k^ko00001?ooool00ol0003oooooooooo`04ooooo`;oMgMg1?ooool01_l0003o
ooooooooooooooook^k^o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo000000oooooo00?o<S8booooooooool01_ooool01Ol0003ooooooooooonH
V9SoA4A400Cooooo0_mgMgL4ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00003iooooo`000oooool01_l0003oooooooooooooooook^k^o`0000Cooooo00?o0000oooo
ooooool01?ooool00oo^k^ko410@onk^kP03ooooo`06o`000?ooooooooooooooooo^k^ko00000ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0ol0000@ooooo`03oc8b<_oo
oooooooo00Kooooo00Go0000oeEEEOnj^[[o410@omgMg@04ooooo`03onk^k_l@413ok^k^00?ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?Wooooo0003ooooo`06
ofIVI_mgMgOoooooonk^k_mEEEGo00001?ooool00ol0003oooooooooo`05ooooo`03oeEEEOnHV9So
oooo00;ooooo00KoIVIVogMgMoooooook^k^oeEEEOl00003ooooo`03o`000?lb<S;ogMgM00Kooooo
00?o0000ooooooooool07Oooool00ol0003ok^k^ooooo`06ooooo`04o`000?nHV9So0000okZj^PKo
oooo00?oEEEEoiRHV?ooool00_ooool01ol0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B400_ooool0
0oo^k^ko0000ooooo`3hooooo`000oooool02?o^k^koEEEEo`000?l@413oc<c<o`000?oooooo0000
0_ooool01?l0003oooooooooool00004ooooo`03omgMgOl@413ooooo00;ooooo00Kok^k^oeEEEOl0
003o410@olc<c?l00002ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool00ol0003ooooooooo
o`0Mooooo`05oeEEEOmgMgOooooooooooonHV9P00_l000001_nHV9Soooooo`000?ooooooZJVYofIV
IPKooooo00cogMgMoa0@4?oooooooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJT2oooo
o`03ogMgMomEEEGooooo0?Sooooo0008ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00001Oooool00omEEEGoV9RHooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool07Oooool01OoMgMgo410@onk^k_oooooo000000;oc<c<00?o0000ooooool000000_ooool0
0onYZJWoEEEEonk^kP05ooooo`03oeEEEOnHV9Sooooo00Wooooo00?ok^k^oa0@4?oMgMd0nOooool0
00Sooooo00?o0000ooooool000001_l00005ooooo`03okZj^_m4A4Cooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Nooooo`04ogMgMomVIVKoooooo`0000;oc<c<1?l00000
1?oooooo0000o`000?l00005ooooo`03okZj^_m4A4Cooooo00Wooooo00?oIVIVogMgMoooool0nOoo
ool000Oooooo0_l0000Eooooo`;o0000<?ooool01?nHV9So0000o`000?nHV9SooooooaGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-15.4758, -0.165169, \
0.330365, 0.00128813}}]
}, Open  ]],

Cell[TextData[{
  "(Note the large number of radial modes needed in order to obtain a \
converged solution.) From the plot of the temperature gradient, we can see \
that its magnitude drops to the present value of 0.03",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["K",
            FontSlant->"Plain"], "/", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " after only 20 million years or so.  This is much too short a time \
compared to the age of the earth."
}], "Text"],

Cell[TextData[{
  "\t  The resolution of this paradox  lies in the fact that the earth \
contains  trace amounts of  naturally occurring radioactive elements. The \
radioactive decay of these elements is a source of heat.  The heat flux  \
caused by this source creates a temperature gradient at the surface through \
Fick's law, Eq.  ",
  ButtonBox["(3.1.37)",
    ButtonData:>{"Chapter3.nb", "(3.1.37)"},
    ButtonStyle->"Hyperlink"],
  ". It is currently believed that there is sufficient natural radioactivity \
in the earth's interior to explain the large surface temperature gradient \
observed in present experiments [",
  ButtonBox["Garland (1979)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 4.4", "Subsubtitle",
  CellTags->"c:42"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " A drumhead has uniform mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " per unit area, uniform wave speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", and  a fixed boundary of arbitrary shape. Starting with the equations of \
motion, show that the energy ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " of transverse perturbations ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "  is a conserved quantity, where"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`E = \[Integral]\[DifferentialD]\^2 
              r\ \ [\(\[Sigma]\/2\) \((\[PartialD]z\/\[PartialD]t)\)\^2 + \
\(\(\[Sigma]\ c\^2\)\/2\) \[Del]z\[CenterDot]\[Del]z]\)]],
  " ."
}], "NE5",
  CellTags->{"i:94", "(4.4.33)"}],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Find the frequencies and spatial form of the normal modes of oscillation \
of a rectangular trampoline with length ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", width ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\)\(,\)\)\)]],
  " and propagation speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find and plot (as a ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics object) the equilibrium shape of the trampoline under the action \
of gravity, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ", assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"b", "=", 
            RowBox[{"3", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"3", 
            StyleBox[
              RowBox[{" ", 
                StyleBox[" ",
                  FontSlant->"Plain"]}]], 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". What is the maximum displacement of the trampoline from the horizontal, \
to three significant figures?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Determine the evolution of a square trampoline with fixed edges of length \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"L", "=", 
          RowBox[{"3", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and wave speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"3", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ".  Neglect gravity. The initial condition is ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, 0) = \(t(x)\) \(t(y)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`t(x)\)]],
  " is a triangular shape, "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t(x)\), "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(x, \ \ \ \ \ \ \ \ \ \ \ x < L/2, \)},
                    {\(L - x, \ \ x > L/2. \)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Animate this evolution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \)]],
  " 2 s using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " One edge of the frame of a square drumhead with unit sides is warped, \
following ",
  Cell[BoxData[
      \(TraditionalForm\`z(0, y) = \((1/4\ )\) \(sin(2\ \[Pi]\ y)\)\)]],
  ". The other edges are straight, satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". Find ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y)\)]],
  " in equilibrium, and plot it as a surface plot using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " A french fry has a square cross section with sides of length ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\ cm\)]],
  " and an overall length of ",
  Cell[BoxData[
      \(TraditionalForm\`L = 5\ cm\)]],
  ". The fry is initially at a uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\ \[Degree]C\)]],
  " . It is tossed into boiling fat at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 150\ \[Degree]C\)]],
  ". How long does it take for the center of the fry to reach 100\[Degree]C ? \
Take ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\  = \ \(\(2\[Cross]10\^\(-7\)\)\(\ \)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "2"], "/", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " A cooling vane on a motor has the shape of a thin square with sides of \
length ",
  Cell[BoxData[
      \(TraditionalForm\`a = 0.7\ cm\)]],
  " with thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = \ 0.2\ cm\)]],
  " (see Fig. ",
  ButtonBox["4.12",
    ButtonData:>"Fig. 4.12",
    ButtonStyle->"Hyperlink"],
  "). Initially, the motor is off and the vane is at uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 300  K\)]],
  ". When the motor is turned on, a constant heat flux ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "=", " ", 
          RowBox[{"500", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", \(cm\^2\)}]}]}], 
        TraditionalForm]]],
  "  enters one thin edge of the vane, and the five other faces are all  kept \
at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 300\ K\)]],
  ". The thermal conductivity of the vane is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Kappa]", "=", 
            RowBox[{"0.1", 
              FractionBox[
                StyleBox["W",
                  FontSlant->"Plain"], 
                RowBox[{"cm", " ", 
                  StyleBox["K",
                    FontSlant->"Plain"]}]]}]}], ","}], TraditionalForm]]],
  "and the specific heat is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "=", 
          RowBox[{"2", " ", 
            FractionBox[
              StyleBox["J",
                FontSlant->"Plain"], 
              RowBox[{\(cm\^3\), 
                StyleBox["K",
                  FontSlant->"Plain"]}]]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the equilibrium temperature distribution, and determine what is the \
maximum temperature in the vane, and where it occurs."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Plot the temperature vs. time as a sequence of contour plots in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z = d/2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.5\)]],
  " s. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006]0001NB000`400?l00000o`00003ooooooon^
ooooo`00oooooon^ooooo`00oooooon^ooooo`00oooooon^ooooo`00oooooon^ooooo`00oooooon^
ooooo`00oooooon^ooooo`00oooooon^ooooo`00oooooon^ooooo`00oooooon^ooooo`002_oooooo
0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`00
2_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;
ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0oooo
V@3oool;ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:oooo
ool0ooooV@3oool;ooooo`002_oooooo0?ooog00oooo00D0P82000000000000000000820P0050?oo
o`040820P00000000000000001/0oooo2oooool000[oooooo`3ooom^0?ooo`030<30`00000000000
00D0000000D0`<300?ooo`3oool0oooo0410@003000000030410@020P800oooo01P0oooo2oooool0
00[oooooo`3ooom^0?ooo`@000000`3oool300000080oooo100000000`3oool000000820P00H0?oo
o`_ooooo000:oooooll0oooo00D0P82000000000000000000<30`0080?ooo`<0000000<0P8200?oo
o`3oool0RP3oool01020P80000000000000000050?ooo`050<30`0000000P8200?ooo`10@4000`00
00020?ooo`030410@020P800oooo01H0oooo2oooool000[oooooc`3oool00`20P800000000000002
000000L0oooo00<0P8200000000000000`00002;0?ooo`<0000000<0P8200?ooo`3oool01@3oool0
0`000000oooo0820P003000000<0oooo00<000000820P03oool05@3oool;ooooo`002_ooooo?0?oo
o`030820P0000000000000<000001P3oool01`10@400000000000020P800oooo0820P010@400RP3o
ool3000000030820P03oool0oooo00D0oooo00<0`<3000000010@4000`0000040?ooo`030<30`03o
ool0oooo01@0oooo2oooool000[oooooc`3oool00`20P80000000820P0020?ooo`0300000020P800
oooo00@0oooo0`0000030?ooo`030820P03oool0oooo08P0oooo0`0000000`20P800oooo0?ooo`07
0?ooo`@0000000<0P8200?ooo`3oool0603oool;ooooo`002_oooooE0?ooo`030410@020P800oooo
00<0oooo0P0000000`10@400oooo0?ooo`020?ooo`0300000030`<00oooo08L0oooo0`0000000`20
P800oooo0?ooo`070?ooo`050410@0000000000000000020P8006P3oool;ooooo`002_oooooE0?oo
o`030820P0000000oooo0080oooo0`0000000`20P800oooo0?ooo`2<0?ooo`@000002P3oool30000
00030820P03oool0oooo01P0oooo2oooool000[oooooeP3oool01020P800@4100?ooo`3oool30000
00030820P03oool0oooo08d0oooo0`00000:0?ooo`040820P00000000000000001X0oooo2oooool0
00[oooooe`3oool00`000000oooo0?ooo`03000000030820P03oool0oooo08d0oooo0`00000;0?oo
o`<000006P3oool;ooooo`002_oooooG0?ooo`030<30`0000000@41000<00000T03oool01020P800
000000000000000:0?ooo`040410@00000000000000001T0oooo2oooool000[ooooof03oool50000
0940oooo0`0000000`20P800oooo0?ooo`070?ooo`040820P00000000000000001T0oooo2oooool0
00[ooooof@3oool01010@400000000000020P82B0?ooo`80000000<0@4100?ooo`3oool01`3oool0
1@30`<000000000000000000`<3001P0oooo2oooool000[ooooof@3oool3000009<0oooo00<0P820
0000000000002P3oool3000000030820P03oool0oooo01H0oooo2oooool000[ooooof@3oool30000
09@0oooo00@0P820000000000000`<30203oool3000000030820P03oool0oooo01H0oooo2oooool0
00[ooooof@3oool3000009D0oooo0P0000000`20P800oooo0?ooo`060?ooo`@00000603oool;oooo
o`002_oooon/0?ooo`030<30`020P800P82002T0oooo1@00002D0?ooo`040<30`000000000000820
P0L0oooo1000000H0?ooo`_ooooo000:oooooj`0oooo100000000`20P800oooo0?ooo`0U0?ooo`<0
000000<0P82000000020P800U@3oool2000000030820P03oool0oooo00@0oooo1@00000G0?ooo`_o
oooo000:oooooj/0oooo00<0P820000000000000100000000`10@400P8200?ooo`0R0?ooo`080<30
`0000000000000000020P800oooo00000020P82E0?ooo`030820P0000000P82000D0oooo1@00000G
0?ooo`_ooooo000:oooooj/0oooo2`0000000`20P800oooo0?ooo`0N0?ooo`080820P00000000000
00000020P800oooo0820P000002G0?ooo`8000000`3oool00`20P80000000820P003000001L0oooo
2oooool000[oooooZP3oool00`20P80000000000000;000000030410@020P800`<3001`0oooo00@0
P82000000000000000000`3oool01020P80000000820P020P802000000030820P03oool0oooo0900
oooo00<0`<300820P020P8000P20P8020?ooo`<0000000<0P8200?ooo`3oool0503oool;ooooo`00
2_oooonZ0?ooo`030820P0000000000000l000005`3oool010000000oooo0?ooo`3oool4000000@0
oooo00<0P8200000000000000`00002I0?ooo`<0000000<0P8200?ooo`3oool0503oool;ooooo`00
2_oooonZ0?ooo`030410@00000000000014000000P20P80D0?ooo`80P8200`0000000`10@400oooo
0?ooo`040?ooo`050820P010@400000000000020P800CP3ooolS0=cLg0030;Vi^@3oool0oooo02H0
oooo0`00000F0?ooo`_ooooo000:ooooojX0oooo5`00001>0?ooo`030=cLg02h^;P0^;Rh04@0^;Rh
00<0Lg=c0;Vi^@3oool09P3oool3000001H0oooo2oooool000[oooooZP3ooolI00000080P8200`3o
ool00`3^k^h0g=cL0=cLg00P0=cLg0030<[:bP2h^;P0^;Rh06P0^;Rh0P1cLg<00`2i^KT0oooo0?oo
o`0T0?ooo`040410@00000000000000001D0oooo2oooool000[oooooY@3oool50;Rh^1d00000S`2h
^;P307=cLbH0oooo00@0P82000000000000000005@3oool;ooooo`002_oooomN0?ooo`80g=cL00<0
KVi^000000000000I@0000000`0^;Rh0G5aL0;Rh^02;0;Rh^0<0Lg=c00<0UYJF0?ooo`3oool08`3o
ool01@30`<000000000000000000`<3001@0oooo2oooool000[oooooG03oool01@20P80000000000
002h^;P0G5aL06P00000S@2h^;P507=cLbD0oooo0`0000000`20P800oooo0?ooo`0B0?ooo`_ooooo
000:oooooe`0oooo00D0P820000000000000^;Rh08Z:RP1905aLG1/000000P1LG5b?0;Rh^0D0Lg=c
00<0UYJF0?ooo`3oool08P3oool3000000030410@03oool0oooo0180oooo2oooool000[oooooG03o
ool00`20P80000000000001;0;Rh^00305aLG0000000000001H00000T`2h^;P707=cLb00oooo00<0
P8200000000000001000000D0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000B`2h^;P0
0`1LG5`000000000000B00000080G5aLU@2h^;P707=cL`0309JFUP3oool0oooo01l0oooo00D0`<30
0820P020P800P8200000000D0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000B`2h^;P0
0`1LG5`000000000000@000009T0^;Rh201cLg<j0?ooo`_ooooo000:oooooe`0oooo00<0P8200000
00000000B`2h^;P00`1LG5`000000000000=00000080G5aLV@2h^;P00`2WYjL0Lg=c07=cL`0707=c
L`030=cLg03oool0oooo03H0oooo2oooool000[oooooG03oool00`20P80000000000001;0;Rh^003
05aLG0000000000000/00000W@2h^;P00`2FUYH0Lg=c07=cL`0807=cLcP0oooo2oooool000[ooooo
G03oool00`20P80000000000001;0;Rh^00308Z:RP000000000000L000000P1LG5bO0;Rh^00309JF
UP1cLg<0Lg=c00T0Lg=c00<0g=cL0?ooo`3oool0=03oool;ooooo`002_oooomL0?ooo`030820P000
0000000004`0^;Rh1`00002S0;Rh^00309JFUP1cLg<0Lg=c00X0Lg=c=P3oool;ooooo`002_oooomL
0?ooo`030820P0000000000004`0^;Rh00<0G5aL0000000000000P1LG5bU0;Rh^00309JFUP1cLg<0
Lg=c00/0Lg=c=@3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh00<0UYJF07=c
L`1cLg<02`1cLg<00`2i^KT0oooo0?ooo`0b0?ooo`_ooooo000:oooooe`0oooo00<0P82000000000
0000mP2h^;P00`2FUYH0Lg=c07=cL`0<07=cL`030;Vi^@3oool0oooo0340oooo2oooool000[ooooo
G03oool00`20P80000000000003f0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0
<03oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh00<0UYJF07=cL`1cLg<03@1c
Lg<00`2i^KT0oooo0?ooo`0`0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000mP2h^;P0
0`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo0300oooo2oooool000[oooooG03oool00`20
P80000000000003f0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0<03oool;oooo
o`002_oooomL0?ooo`030820P000000000000?H0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0
oooo0?ooo`0`0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000mP2h^;P00`2FUYH0Lg=c
07=cL`0=07=cL`030;Vi^@3oool0oooo0300oooo2oooool000[oooooG03oool00`20P80000000000
003f0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0<03oool;ooooo`002_oooomL
0?ooo`030820P000000000000?H0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0`
0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000mP2h^;P00`2FUYH0Lg=c07=cL`0=07=c
L`030;Vi^@3oool0oooo0300oooo2oooool000[oooooG03oool00`20P80000000000003f0;Rh^003
09JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0<03oool;ooooo`002_oooomL0?ooo`030820
P000000000000?H0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0`0?ooo`_ooooo
000:oooooe`0oooo00<0P820000000000000mP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3o
ool0oooo0300oooo2oooool000[oooooG03oool00`20P80000000000003f0;Rh^00309JFUP1cLg<0
Lg=c00d0Lg=c<`3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh00<0UYJF07=c
L`1cLg<03@1cLg<c0?ooo`_ooooo000:oooooe`0oooo00<0P820000000000000mP2h^;P00`2FUYH0
Lg=c07=cL`0=07=cLc<0oooo2oooool000[oooooG03oool00`20P80000000000003f0;Rh^100Lg=c
<`3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh401cLg<c0?ooo`_ooooo000:
oooooe`0oooo00<0P820000000000000mP2h^;P@07=cLc<0oooo2oooool000[oooooG03oool00`20
P80000000000003f0;Rh^100Lg=c<`3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0
^;Rh401cLg<R0?ooo`030<30`03oool0oooo00h0oooo2oooool000[oooooG03oool00`20P8000000
0000003f0;Rh^100Lg=c8P3oool00`20P800oooo0?ooo`0>0?ooo`_ooooo000:oooooe`0oooo00<0
P820000000000000mP2h^;P@07=cLb80oooo00<000000820P03oool03P3oool;ooooo`002_oooomL
0?ooo`030820P000000000000?H0^;Rh401cLg<Q0?ooo`<000003`3oool;ooooo`002_oooomL0?oo
o`030820P000000000000?H0^;Rh401cLg<P0?ooo`050<30`0000000000000000030`<003P3oool;
ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh401cLg<P0?ooo`050820P00000000000
00000020P8003P3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0^;Rh401cLg<P0?oo
o`050410@0000000000000000010@4003P3oool;ooooo`002_oooomL0?ooo`030820P00000000000
0?H0^;Rh401cLg<P0?ooo`D000003P3oool;ooooo`002_oooomL0?ooo`030820P000000000000?H0
^;Rh401cLg<O0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool02`3oool;ooooo`00
2_oooomL0?ooo`030820P000000000000?H0^;Rh401cLg<O0?ooo`L000003@3oool;ooooo`002_oo
oomL0?ooo`0306i^KP00000000000?H0^;Rh401cLg<N0?ooo`030<30`0000000000000D0000000<0
`<300?ooo`3oool02P3oool;ooooo`002_oooomL0?ooo`0305aLG000000000000?H0^;Rh401cLg<N
0?ooo`030820P0000000000000D0000000<0P8200?ooo`3oool02P3oool;ooooo`002_oooomL0?oo
o`0305aLG000000000000?H0^;Rh401cLg<N0?ooo`P0000000<0@4100?ooo`3oool02P3oool;oooo
o`002_oooomL0?ooo`0305aLG000000000000?H0^;Rh401cLg<N0?ooo`T00000303oool;ooooo`00
2_oooomL0?ooo`0305aLG000000000000?H0^;Rh401cLg<M0?ooo`X0000000<0P8200?ooo`3oool0
2@3oool;ooooo`002_oooomL0?ooo`0305aLG000000000000?H0^;Rh3`1cLg<N0?ooo`/000002`3o
ool;ooooo`002_oooomL0?ooo`0305aLG000000000000?H0^;Rh3`1cLg<M0?ooo`030820P0000000
000000T0000000<0P8200?ooo`3oool0203oool;ooooo`002_oooomL0?ooo`0305aLG00000000000
0?D0^;Rh401cLg<M0?ooo``0000000<0P8200?ooo`3oool0203oool;ooooo`002_oooomL0?ooo`03
05aLG000000000000?D0^;Rh401cLg<M0?ooo`d000002P3oool;ooooo`002_oooomL0?ooo`0305aL
G000000000000?D0^;Rh401cLg<M0?ooo`d000002P3oool;ooooo`002_oooomL0?ooo`0305aLG000
000000000?D0^;Rh401cLg<L0?ooo`l000002@3oool;ooooo`002_oooomL0?ooo`0305aLG0000000
00000?D0^;Rh401cLg<L0?ooo`l000002@3oool;ooooo`002_oooomL0?ooo`0305aLG00000000000
0?D0^;Rh401cLg<K0?ooo`030820P0000000000000d0000000<0P8200?ooo`3oool01P3oool;oooo
o`002_oooomL0?ooo`0305aLG000000000000?D0^;Rh401cLg<K0?ooo`030820P0000000000000d0
000000<0P8200?ooo`3oool01P3oool;ooooo`002_oooomL0?ooo`0305aLG000000000000?D0^;Rh
401cLg<K0?oooa400000203oool;ooooo`002_oooomL0?ooo`0305aLG000000000000?D0^;Rh401c
Lg<J0?oooa800000203oool;ooooo`002_oooomL0?ooo`0305aLG000000000000?D0^;Rh401cLg<J
0?oooa<000001`3oool;ooooo`002_oooomK0?ooo`040;Rh^01LG5`0000000000?D0^;Rh401cLg<I
0?ooo`030820P00000000000014000001`3oool;ooooo`002_oooomK0?ooo`040;Rh^01LG5`00000
00000?D0^;Rh401cLg<I0?ooo`030820P000000000000140000000<0P8200?ooo`3oool0103oool;
ooooo`002_oooomK0?ooo`040;Rh^01LG5`0000000000?D0^;Rh401cLg<I0?ooo`030820P0000000
00000140000000<0P8200?ooo`3oool0103oool;ooooo`002_oooomK0?ooo`040;Rh^01LG5`00000
00000?D0^;Rh401cLg<I0?oooaD000001P3oool;ooooo`002_oooomK0?ooo`040;Rh^01LG5`00000
00000?D0^;Rh401cLg<K0?oooa8000001`3oool;ooooo`002_oooomK0?ooo`040;Rh^01LG5`00000
00000?D0^;Rh401cLg<M0?ooo`@0P820100000050820P0X0oooo2oooool000[oooooF`3oool0102h
^;P0G5aL00000000003e0;Rh^100Lg=c8P3oool3000000l0oooo2oooool000[oooooF`3oool0102h
^;P0G5aL00000000003e0;Rh^100Lg=c8P3oool3000000l0oooo2oooool000[oooooF`3oool0102h
^;P0G5aL00000000003e0;Rh^100Lg=c8P3oool3000000l0oooo2oooool000[ooooo=03oool01@30
`<000000000000000000P8200280oooo00@0^;Rh05aLG00000000000m@2h^;P@07=cLb80oooo0`00
000?0?ooo`_ooooo000:oooooc@0oooo00<0P8200000000000000`00000Q0?ooo`040;Rh^01LG5`0
000000000?D0^;Rh401cLg<R0?ooo`<000003`3oool;ooooo`002_oooold0?ooo`050820P0000000
00000820P03oool00P20P80P0?ooo`040;Rh^01LG5`0000000000?@0^;Rh00<0UYJF07=cL`1cLg<0
3@1cLg<00`2i^KT0oooo0?ooo`0P0?ooo`<000003`3oool;ooooo`002_oooolk0?ooo`030000003o
ool0oooo01d0oooo00@0^;Rh05aLG00000000000m02h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi
^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooc`0oooo00<0@4100?ooo`3oool0703o
ool0102h^;P0G5aL00000000003d0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0
803oool3000000l0oooo2oooool000[ooooo?03oool00`20P80000000?ooo`0L0?ooo`040;Rh^01L
G5`0000000000?@0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0P0?ooo`<00000
3`3oool;ooooo`002_oooolm0?ooo`80P8206`3oool00`20P800G5aL02h^;P020000000305aLG02:
RXX0^;Rh0?40^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0P0?ooo`<000003`3o
ool;ooooo`002_ooooln0?ooo`030000003oool0oooo01H0oooo3@0000000`1LG5`0^;Rh0;Rh^03/
0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0803oool3000000l0oooo2oooool0
00[ooooo?P3oool00`20P80000000?ooo`0B0?ooo`030820P010@40000000100000000<0;Rh^05aL
G02:RXX0jP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo0200oooo0`00000?0?oo
o`_ooooo000:oooooch0oooo00<0P82000000020P8004P3ooolE0000000305aLG02h^;P0^;Rh0>P0
^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0P0?ooo`<000003`3oool;ooooo`00
2_ooooln0?ooo`040820P000000000000820P180oooo500000000`1LG5`0^;Rh0;Rh^03X0;Rh^003
09JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0803oool3000000l0oooo2oooool000[ooooo
?P3oool01020P800000000000000000B0?oooa@00000j`2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`03
0;Vi^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooch0oooo00D0P820000000000000
00000820P00A0?ooo`030820P0000000000001400000j`2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`03
0;Vi^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooch0oooo00D0P820000000000000
oooo0820P00A0?ooo`030820P0000000000001000000k02h^;P00`2FUYH0Lg=c07=cL`0=07=cL`03
0;Vi^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooch0oooo0`0000000`3oool0`<30
0000000A0?oooa40000000<0;Rh^0;Rh^02h^;P0jP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi
^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooch0oooo0`0000020?ooo`0300000020
P800oooo00l0oooo4@0000000`1LG5`0^;Rh0;Rh^03Z0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0
^KVi0?ooo`3oool0803oool3000000l0oooo2oooool000[ooooo?@3oool01020P800000000000010
@4030?ooo`030410@03oool0oooo00l0oooo4000003]0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0
^KVi0?ooo`3oool0803oool3000000l0oooo2oooool000[ooooo?@3oool3000000050820P03oool0
oooo0?ooo`20P8004@3oool00`20P80000000000000=00000>d0^;Rh00<0UYJF07=cL`1cLg<03@1c
Lg<00`2i^KT0oooo0?ooo`0P0?ooo`<000003`3oool;ooooo`002_oooolm0?ooo`<0000000H0P820
0?ooo`3oool0oooo0<30`000000@0?ooo`030820P0000000000000`00000kP2h^;P00`2FUYH0Lg=c
07=cL`0=07=cL`030;Vi^@3oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooc`0oooo00D0
P82000000000000000000820P0040?ooo`0300000020P800oooo00l0oooo3P00003^0;Rh^00309JF
UP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0803oool3000000l0oooo2oooool000[ooooo?03o
ool01020P80000000000000000060?ooo`030410@03oool0oooo00h0oooo3@0000000`0^;Rh0^;Rh
0;Rh^03/0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0803oool3000000l0oooo
2oooool000[ooooo?03oool01020P80000000000000000060?ooo`030000003oool0oooo00l0oooo
300000000`1LG5`0^;Rh0;Rh^03/0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool0
803oool3000000l0oooo2oooool000[ooooo?03oool3000000030820P03oool0oooo00@0oooo00<0
P8200000003oool03`3oool<0000000308Z:RP2h^;P0^;Rh0>`0^;Rh00<0UYJF07=cL`1cLg<03@1c
Lg<00`2i^KT0oooo0?ooo`0P0?ooo`<000003`3oool;ooooo`002_ooooll0?ooo`<00000203oool0
0`000000oooo0?ooo`0>0?ooo`030820P0000000000000T00000k`2h^;P@07=cL`030;Vi^@3oool0
oooo0200oooo0`00000?0?ooo`_ooooo000:oooooc/0oooo00@0P820000000000000@410203oool0
0`000000P8200?ooo`0>0?ooo`030820P0000000000000P0000000<0G5aL0;Rh^02h^;P0k@2h^;P@
07=cL`030=cLg03oool0oooo0200oooo0`00000?0?ooo`_ooooo000:oooooc/0oooo0`0000000`20
P800oooo0?ooo`060?ooo`0300000020P800oooo00l0oooo2P00003`0;Rh^100Lg=c8`3oool30000
00l0oooo2oooool000[ooooo>P3oool01@30`<000000000000000000P82000L0oooo00<0`<300000
00000000403oool90000000305aLG02h^;P0^;Rh0>h0^;Rh401cLg<S0?ooo`<000003`3oool;oooo
o`002_oooolj0?ooo`040820P00000000000000000L0oooo1000000A0?ooo`P0000000<0G5aL0;Rh
^02h^;P0kP2h^;P@07=cLb<0oooo0`00000?0?ooo`_ooooo000:ooooocT0oooo00<0P82000000000
00000P0000060?ooo`030820P00000000000008000004@3oool800000?40^;Rh401cLg<S0?ooo`<0
00003`3oool;ooooo`002_oooolf0?ooo`L000001`3oool00`20P80000000000000200000140oooo
00<0G5aL0000000000001000003b0;Rh^100Lg=c8`3oool3000000l0oooo2oooool000[ooooo=`3o
ool30820P0030410@0000000@41000L0oooo00D0`<3000000000000000000<30`00A0?ooo`0305aL
G0000000000000@00000lP2h^;P@07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooooeX0oooo00<0
^;Rh0000000000000`0000000`1LG5`0^;Rh0;Rh^03`0;Rh^100Lg=c8`3oool3000000l0oooo2ooo
ool000[oooooFP3oool00`2h^;P0G5aL000000030000000308Z:RP2h^;P0^;Rh0?00^;Rh401cLg<S
0?ooo`<000003`3oool;ooooo`002_oooomJ0?ooo`80^;Rh1000003c0;Rh^100Lg=c8`3oool30000
00l0oooo2oooool000[oooooFP3oool20;Rh^00402h^;P000000000005aLG?<0^;Rh401cLg<S0?oo
o`<000003`3oool;ooooo`002_oooomJ0?ooo`80^;Rh00<0G5aL000000000000m02h^;P@07=cLb<0
oooo0`00000?0?ooo`_ooooo000:oooooeX0oooo0P2h^;P00`2:RXX0000002h^;P3d0;Rh^100Lg=c
8`3oool3000000l0oooo2oooool000[oooooFP3oool30;Rh^0030000001LG5`0^;Rh0?<0^;Rh401c
Lg<S0?ooo`<000003`3oool;ooooo`002_oooomJ0?ooo`<0^;Rh00<0G5aL08Z:RP2h^;P0l`2h^;P@
07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooooeX0oooon@2h^;P@07=cLb<0oooo0`00000?0?oo
o`_ooooo000:oooooeX0oooon@2h^;P@07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooooeT0oooo
nP2h^;P@07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooooeT0oooonP2h^;P@07=cLb<0oooo0`00
000?0?ooo`_ooooo000:oooooeT0oooonP2h^;P@07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooo
oeT0oooon@2h^;PA07=cLb<0oooo0`00000?0?ooo`_ooooo000:oooooeT0oooon@2h^;PA07=cLb<0
oooo0`00000?0?ooo`_ooooo000:oooooeT0oooon@2h^;PA07=cLb<0oooo0`00000?0?ooo`_ooooo
000:oooooeT0oooon@2h^;P@07=cLb@0oooo0`00000?0?ooo`_ooooo000:ooooob/0oooo00<0P820
0<30`03oool0:`3ooooi0;Rh^100Lg=c903oool3000000l0oooo2oooool000[ooooo;03oool30000
02X0oooon@2h^;P@07=cLb@0oooo0`00000?0?ooo`_ooooo000:ooooobd0oooo00@0P82000000000
000000000`20P80U0?ooooT0^;Rh401cLg<T0?ooo`<0P8203`3oool;ooooo`002_ooool^0?ooo`03
0820P0000000000000D000008`3ooooi0;Rh^100Lg=c=P3oool;ooooo`002_ooool_0?ooo`030820
P010@400000000H0000000<0@4100820P020P8007P3ooooi0;Rh^100Lg=c=P3oool;ooooo`002_oo
oola0?ooo`d000006`3ooooi0;Rh^100Lg=c=P3oool;ooooo`002_oooolb0?ooo`030410@0000000
000000/000000P20P80G0?ooooT0^;Rh401cLg<f0?ooo`_ooooo000:oooooc<0oooo4@00000E0?oo
ooT0^;Rh401cLg<f0?ooo`_ooooo000:oooooc@0oooo00<0@4100000000000003`0000020820P140
oooon@2h^;P@07=cLcH0oooo2oooool000[ooooo=@3ooolE000000l0oooon@2h^;P@07=cLcH0oooo
2oooool000[ooooo=P3oool00`10@40000000000000B00000080P8202`3oool00`3Lg=`0^;Rh0;Rh
^03g0;Rh^100Lg=c=P3oool;ooooo`002_oooolf0?ooo`030820P0000000000001H000002@3oool0
0`3Lg=`0^;Rh0;Rh^03g0;Rh^100Lg=c=P3oool;ooooo`002_oooolg0?oooa/000000P20P8040?oo
o`030=cLg02h^;P0^;Rh0?L0^;Rh401cLg<f0?ooo`_ooooo000:ooooocL0oooo7`0000000`20P800
oooo0=cLg03i0;Rh^100Lg=c=P3oool;ooooo`002_ooool20?oooeH0000000<0;Rh^0;Rh^02h^;P0
m`2h^;P@07=cLcH0oooo2oooool000[ooooo0P3ooomF000000030=cLg02h^;P0^;Rh0?L0^;Rh401c
Lg<f0?ooo`_ooooo000:ooooo`80oooo=@20P80L00000080P8200`3oool00`3Lg=`0^;Rh0;Rh^03g
0;Rh^100Lg=c=P3oool;ooooo`002_oooolf0?ooo`030820P0000000000001P000001`3oool00`3L
g=`0^;Rh0;Rh^03f0;Rh^00309JFUP1cLg<0Lg=c00h0Lg=c=P3oool;ooooo`002_oooolf0?oooaH0
000000<0@4100820P020P8002@3oool00`3Lg=`0^;Rh0;Rh^03f0;Rh^00309JFUP1cLg<0Lg=c00h0
Lg=c8@3oool01P20P8000000000000000000@4100820P0D0oooo0`0000000`10@400oooo0?ooo`04
0?ooo`_ooooo000:ooooocD0oooo5@0000000`20P800oooo0?ooo`0;0?ooo`030=cLg02h^;P0^;Rh
0?H0^;Rh00<0UYJF07=cL`1cLg<03P1cLg<P0?ooo`P000000`3oool00`20P8000000000000030000
00030820P03oool0oooo0080oooo2oooool000[ooooo=03oool00`30`<0000000000000?00000003
0410@020P800`<3000l0oooo00<0g=cL0;Rh^02h^;P0mP2h^;P00`2FUYH0Lg=c07=cL`0>07=cLal0
oooo00D0P82000000000000000000<30`0030?ooo`050820P0000000`<300?ooo`20P8000`000000
1020P800oooo0410@020P8030?ooo`_ooooo000:oooooc@0oooo4000000D0?ooo`030=cLg02h^;P0
^;Rh0?H0^;Rh00<0UYJF07=cL`1cLg<03P1cLg<O0?ooo`@000001P3oool00`000000oooo0?ooo`03
000000050820P03oool0oooo00000020P8000P3oool;ooooo`002_oooolb0?ooo`030<30`0000000
000000/000000P20P80F0?ooo`030=cLg02h^;P0^;Rh0?H0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<0
0`2i^KT0oooo0?ooo`0M0?ooo`<000001`3oool00`30`<0000000<30`003000000070820P03oool0
oooo0?ooo`10@400P8200?ooo`0;ooooo`002_oooolb0?ooo`/000006`3oool00`3Lg=`0^;Rh0;Rh
^03f0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool07@3oool3000000T0oooo00D0
P82000000000000000000820P0060?ooo`_ooooo000:oooooc00oooo00<0`<300000000000001P00
00020820P1d0oooo00<0g=cL0;Rh^02h^;P0mP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3o
ool0oooo01d0oooo0`0000090?ooo`030410@00000000000008000001P3oool;ooooo`002_ooool_
0?ooo`P000008@3oool00`3Lg=`0^;Rh0;Rh^03f0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi
0?ooo`3oool07@3oool3000000T0oooo00<0P8200000000000000P0000060?ooo`_ooooo000:oooo
obh0oooo00L0@41000000000000000000410@020P800`<3002<0oooo00<0b/[:0;Rh^02h^;P0mP2h
^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo01d0oooo00@0@410000000000000P820
2@3oool01@20P8000000000000000000P82000D0oooo2oooool000[ooooo;@3oool3000000030820
P03oool0oooo02D0oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo01d0oooo
00@0P82000000000000000002P3oool4000000D0oooo2oooool000[ooooo:`3oool30820P0030<30
`03oool0oooo02L0oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo01d0oooo
00D0`<3000000000000000000<30`0090?ooo`040820P00000000000000000D0oooo2oooool000[o
ooooF03ooooi0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool07P3oool300000003
0820P03oool0oooo00L0oooo00D0P82000000000000000000820P0040?ooo`_ooooo000:oooooeP0
oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo01l0oooo0`00000:0?ooo`<0
000000<0P8200?ooo`3oool00P3oool;ooooo`002_oooomH0?ooooT0^;Rh00<0UYJF07=cL`1cLg<0
3@1cLg<00`2i^KT0oooo0?ooo`0O0?ooo`040820P00000000000000000T0oooo100000040?ooo`_o
oooo000:oooooeP0oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo0200oooo
0`0000000`30`<00oooo0?ooo`070?ooo`<00000103oool;ooooo`002_ooool00`3oool000000000
000<000004T0oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo0240oooo0P00
00000`20P800oooo0?ooo`070?ooo`<00000103oool;ooooo`002_ooool40?ooo`030820P0000000
000000@0000000<0P8200<30`03oool0BP3ooooi0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi
0?ooo`3oool08@3oool01030`<00000000000020P8080?ooo`@000000`3oool;ooooo`002_ooool5
0?ooo`H00000C@3ooooi0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool08`3oool2
000000P0oooo100000030?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1;0?oo
ooT0^;Rh00<0UYJF07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0S0?ooo`030<30`0000000@410
00L0oooo100000000`30`<00oooo0?ooo`0;ooooo`002_ooool60?ooo`@0000000<0P8200?ooo`3o
ool0B`3ooooi0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool09@3oool200000003
0820P03oool0oooo0080oooo00<000000820P00000000P0000000`20P800oooo0?ooo`0;ooooo`00
2_ooool60?ooo`@0000000<0P8200?ooo`3oool0B`3ooooi0;Rh^100Lg=c00<0^KVi0?ooo`3oool0
9P3oool20820P00700000020P800P8200410@020P800oooo0820P002000000030410@03oool0oooo
00_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1;0?ooooT0^;Rh401cLg<00`2i^KT0
oooo0?ooo`0d0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1;0?ooooT0^;Rh
401cLg<00`2i^KT0oooo0?ooo`0d0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?oo
o`1;0?ooooT0^;Rh401cLg<00`2i^KT0oooo0?ooo`0d0?ooo`_ooooo000:ooooo`H0oooo10000000
0`20P800oooo0?ooo`1;0?ooooT0^;Rh401cLg<00`2i^KT0oooo0?ooo`0d0?ooo`_ooooo000:oooo
o`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<00`2i^KT0oooo0?ooo`0d0?oo
o`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<00`3Lg=`0
oooo0?ooo`0d0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh
401cLg<g0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401c
Lg<g0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g
0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?oo
o`_ooooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_o
oooo000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo
000:ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo000:
ooooo`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo000:oooo
o`H0oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo000:ooooo`H0
oooo100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo000:ooooo`H0oooo
100000000`20P800oooo0?ooo`1:0?ooooX0^;Rh401cLg<g0?ooo`_ooooo000:ooooo`H0oooo1000
00000`20P800oooo0?ooo`0=0?ooo`030000003oool0oooo03X0oooonP2h^;P@07=cLb80oooo00<0
P8200000000000004P3oool;ooooo`002_ooool60?ooo`@0000000<0P8200?ooo`3oool03@3oool0
0`000000oooo0?ooo`0j0?ooooX0^;Rh401cLg<R0?ooo`030820P000000000000180oooo2oooool0
00[ooooo1P3oool4000000030820P03oool0oooo00/0oooo00<0`<3000000010@400?03ooooj0;Rh
^100Lg=c8P3oool00`20P80000000000000B0?ooo`_ooooo000:ooooo`H0oooo100000000`20P800
oooo0?ooo`0;0?ooo`030820P0000000P82003`0oooon@2h^;PA07=cLb80oooo00<0P82000000000
00004P3oool;ooooo`002_ooool60?ooo`@0000000<0P8200?ooo`3oool02@3oool01@30`<00P820
000000000000P82003/0oooo00<0g=cL0;Rh^02h^;P0m`2h^;PA07=cLb80oooo00<0P82000000000
00004P3oool;ooooo`002_ooool50?ooo`H000002P3oool5000000030820P03oool0oooo03T0oooo
00<0g=cL0;Rh^02h^;P0m`2h^;PA07=cLb80oooo00<0P8200000000000004P3oool;ooooo`002_oo
ool40?ooo`030820P0000000000001<0000000<0P8200?ooo`3oool0>@3oool00`3Lg=`0^;Rh0;Rh
^03g0;Rh^140Lg=c8P3oool00`20P80000000000000B0?ooo`_ooooo000:ooooo`030?ooo`000000
000001L0000000<0P8200?ooo`3oool0>@3oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^140Lg=c8P3oool0
0`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooo00<0g=cL0;Rh^02h^;P0m`2h^;PA07=c
Lb80oooo00<0P8200000000000004P3oool;ooooo`002_oooomF0?ooo`030=cLg02h^;P0^;Rh0?L0
^;Rh4@1cLg<R0?ooo`030820P000000000000180oooo2oooool000[oooooEP3oool00`3Lg=`0^;Rh
0;Rh^03g0;Rh^140Lg=c8P3oool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooo00<0
g=cL0;Rh^02h^;P0m`2h^;P@07=cLb<0oooo00<0P8200000000000004P3oool;ooooo`002_oooomF
0?ooo`030=cLg02h^;P0^;Rh0?L0^;Rh401cLg<S0?ooo`030820P000000000000180oooo2oooool0
00[oooooEP3oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^100Lg=c8`3oool00`20P80000000000000B0?oo
o`_ooooo000:oooooeH0oooo00<0g=cL0;Rh^02h^;P0m`2h^;P@07=cLb<0oooo00<0P82000000000
00004P3oool;ooooo`002_oooomF0?ooo`030=cLg02h^;P0^;Rh0?L0^;Rh401cLg<S0?ooo`030820
P000000000000180oooo2oooool000[oooooEP3oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^100Lg=c8`3o
ool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooo00<0g=cL0;Rh^02h^;P0m`2h^;P@
07=cLb<0oooo00<0P8200000000000004P3oool;ooooo`002_oooomF0?ooo`030=cLg02h^;P0^;Rh
0?L0^;Rh401cLg<S0?ooo`030820P000000000000180oooo2oooool000[oooooEP3oool00`3Lg=`0
^;Rh0;Rh^03g0;Rh^100Lg=c8`3oool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooo
00<0b/[:0;Rh^02h^;P0m`2h^;P@07=cLb<0oooo00<0P8200000000000004P3oool;ooooo`002_oo
oomF0?ooooX0^;Rh401cLg<S0?ooo`030820P000000000000180oooo2oooool000[oooooEP3ooooj
0;Rh^100Lg=c8`3oool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooonP2h^;P@07=c
Lb<0oooo00<0P8200000000000004P3oool;ooooo`002_oooomF0?ooooT0^;Rh00<0YjNW07=cL`1c
Lg<03P1cLg<S0?ooo`030820P000000000000180oooo2oooool000[oooooEP3ooooi0;Rh^00309JF
UP1cLg<0Lg=c00h0Lg=c8`3oool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooon@2h
^;P00`2FUYH0Lg=c07=cL`0>07=cLb<0oooo00<0P8200000000000004P3oool;ooooo`002_oooomF
0?ooooT0^;Rh00<0UYJF07=cL`1cLg<03P1cLg<S0?ooo`030820P000000000000180oooo2oooool0
00[oooooEP3ooooi0;Rh^00309JFUP1cLg<0Lg=c00h0Lg=c8`3oool00`20P80000000000000B0?oo
o`_ooooo000:oooooeH0oooon@2h^;P00`2FUYH0Lg=c07=cL`0>07=cLb<0oooo00<0P82000000000
00004P3oool;ooooo`002_oooomF0?ooooT0^;Rh00<0UYJF07=cL`1cLg<03P1cLg<S0?ooo`030820
P000000000000180oooo2oooool000[oooooEP3ooooi0;Rh^00309JFUP1cLg<0Lg=c00h0Lg=c8`3o
ool00`20P80000000000000B0?ooo`_ooooo000:oooooeH0oooon@2h^;P00`2FUYH0Lg=c07=cL`0>
07=cLb<0oooo00<0P8200000000000004P3oool;ooooo`002_oooomF0?ooooT0^;Rh00<0UYJF07=c
L`1cLg<03P1cLg<S0?ooo`030820P000000000000180oooo2oooool000[oooooEP3ooooi0;Rh^003
09JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool08@3oool00`20P80000000000000B0?ooo`_o
oooo000:oooooeH0oooon@2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo0240oooo
00<0P8200000000000004P3oool;ooooo`002_oooomF0?ooooT0^;Rh00<0UYJF07=cL`1cLg<03@1c
Lg<00`2i^KT0oooo0?ooo`0Q0?ooo`030820P000000000000180oooo2oooool000[oooooE@3ooooj
0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool08@3oool00`20P80000000000000B
0?ooo`_ooooo000:oooooeD0oooonP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3oool0oooo
0240oooo00<0P8200000000000004P3oool;ooooo`002_oooomE0?ooooX0^;Rh00<0UYJF07=cL`1c
Lg<03@1cLg<00`2i^KT0oooo0?ooo`0Q0?ooo`030820P000000000000180oooo2oooool000[ooooo
E@3ooooj0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool08@3oool00`20P8000000
0000000B0?ooo`_ooooo000:oooooeD0oooonP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`030;Vi^@3o
ool0oooo0240oooo00<0P8200000000000004P3oool;ooooo`002_oooomE0?ooooX0^;Rh00<0UYJF
07=cL`1cLg<03@1cLg<00`2i^KT0oooo0?ooo`0Q0?ooo`030820P000000000000180oooo2oooool0
00[oooooE@3ooooj0;Rh^00309JFUP1cLg<0Lg=c00d0Lg=c00<0^KVi0?ooo`3oool08@3oool00`20
P80000000000000B0?ooo`_ooooo000:oooooeD0oooonP2h^;P00`2FUYH0Lg=c07=cL`0=07=cL`03
0;Vi^@3oool0oooo0240oooo00<0P8200000000000004P3oool;ooooo`002_oooomE0?ooooX0^;Rh
401cLg<00`2i^KT0oooo0?ooo`0Q0?ooo`030820P000000000000180oooo2oooool000[oooooE@3o
oooj0;Rh^100Lg=c00<0^KVi0?ooo`3oool08@3oool00`20P80000000000000B0?ooo`_ooooo000:
oooooeD0oooonP2h^;P@07=cL`030;Vi^@3oool0oooo0240oooo00<0P8200000000000004P3oool;
ooooo`002_oooomE0?ooooX0^;Rh401cLg<00`2i^KT0oooo0?ooo`0Q0?ooo`030820P00000000000
0180oooo2oooool000[oooooE@3ooooj0;Rh^100Lg=c00<0^KVi0?ooo`3oool08@3oool00`20P800
00000000000B0?ooo`_ooooo000:oooooeD0oooonP2h^;P@07=cL`030;Vi^@3oool0oooo0240oooo
00<0P8200000000000004P3oool;ooooo`002_oooomE0?ooooX0^;Rh401cLg<00`2i^KT0oooo0?oo
o`0Q0?ooo`030820P000000000000180oooo2oooool000[oooooE@3ooooj0;Rh^100Lg=c00<0^KVi
0?ooo`3oool08@3oool00`20P80000000000000B0?ooo`_ooooo000:oooooeD0oooonP2h^;P@07=c
L`030;Vi^@3oool0oooo01`0oooo3@0000000`20P800oooo0?ooo`0:0?ooo`_ooooo000:oooooe@0
oooo00<0g=cL0;Rh^02h^;P0n02h^;P@07=cL`030;Vi^@3oool0oooo01P0oooo0P20P80B00000003
0820P030`<00oooo00L0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c
00<0^KVi0?ooo`3oool0603ooolE000000030820P03oool0oooo00H0oooo2oooool000[oooooE03o
ool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c00<0g=cL0?ooo`3oool0603oool00`20P80000000000
000B000000T0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c703ooolD
000000T0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c703ooolC0000
00X0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c703oool00`20P800
00000000000@000000X0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c
703oool00`30`<0000000000000?000000030820P03oool0oooo00P0oooo2oooool000[oooooE03o
ool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c7@3ooolA000000030820P03oool0oooo00P0oooo2ooo
ool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c7P3oool@000000/0oooo2oooool0
00[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c7P3oool@000000/0oooo2oooool000[o
ooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c7P3oool00`20P80000000000000<000000`0
oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03h0;Rh^100Lg=c7P3oool00`20P8000000
0000000<000000`0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^00309JFUP1c
Lg<0Lg=c00h0Lg=c7P3oool00`30`<0000000000000;000000030820P03oool0oooo00X0oooo2ooo
ool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^140Lg=c7`3oool=000000030820P03oool0
oooo00X0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^140Lg=c7`3oool00`20
P80000000000000:000000d0oooo2oooool000[oooooE03oool00`3Lg=`0^;Rh0;Rh^03g0;Rh^140
Lg=c803oool<000000d0oooo2oooool000[oooooE03oool00`3:b/X0^;Rh0;Rh^03g0;Rh^140Lg=c
803oool00`20P800000000000008000000h0oooo2oooool000[oooooE03ooooj0;Rh^140Lg=c803o
ool00`20P800000000000008000000h0oooo2oooool000[oooooE03ooooj0;Rh^140Lg=c8@3oool9
000000030820P03oool0oooo00`0oooo2oooool000[oooooE03ooooj0;Rh^140Lg=c8@3oool90000
00l0oooo2oooool000[oooooE03ooooj0;Rh^140Lg=c8P3oool8000000l0oooo2oooool000[ooooo
E03ooooj0;Rh^140Lg=c8P3oool00`20P80000000000000400000100oooo2oooool000[oooooE03o
oooj0;Rh^140Lg=c8P3oool00`20P80000000000000400000100oooo2oooool000[oooooE03ooonW
0;Rh^6@0Lg=c8`3oool5000000030820P03oool0oooo00h0oooo2oooool000[oooooE03ooomD09JF
U[L0Lg=c8`3oool5000000030820P03oool0oooo00h0oooo2oooool000[oooooE03oool00`2i^KT0
Lg=c07=cL`3o07=cL`P0Lg=c9@3oool400000140oooo2oooool000[oooooEP3oool00`2FUYH0Lg=c
07=cL`3o07=cL`H0Lg=c9@3oool400000140oooo2oooool000[oooooF03ooooo07=cL`L0Lg=c9@3o
ool00`20P80000000000000B0?ooo`_ooooo000:oooooeP0oooo00<0g=cL07=cL`1cLg<0o`1cLg<4
07=cLbD0oooo00<0`<300000000000004P3oool;ooooo`002_oooomJ0?ooo`030;Vi^@1cLg<0Lg=c
0?l0Lg=c0P1cLg<V0?ooo`0300000020P800oooo0140oooo2oooool000[oooooF`3oool00`2i^KT0
UYJF07=cL`3o07=cL`40Lg=c9`3oool00`20P800oooo0?ooo`0@0?ooo`_ooooo000:oooooed0oooo
o`1cLg<207=cLcX0oooo2oooool000[oooooGP3oool00`2i^KT0Lg=c07=cL`3m07=cLcX0oooo2ooo
ool000[oooooH03oooon07=cLcX0oooo2oooool000[oooooH@3oool00`2i^KT0Lg=c07=cL`3j07=c
LcX0oooo2oooool000[oooooHP3oool00`2i^KT0Lg=c07=cL`3i07=cLcX0oooo2oooool000[ooooo
I03oool00`2FUYH0Lg=c07=cL`2T07=cL`0309JFUP2i^KT0^KVi0500^KVi>P3oool;ooooo`002_oo
oomV0?oooe<0Lg=cg`3oool;ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?oo
o`_ooooo000:ooooool0ooooV@3oool;ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3o
oonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`002_oooooo0?oooiT0oooo2oooool000[o
ooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`002_oooooo0?oooiT0oooo2ooo
ool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`002_oooooo0?oooiT0
oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`002_oooooo
0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;ooooo`00
2_oooooo0?oooiT0oooo2oooool000[oooooT03oool00`000000oooo0?ooo`3o0?ooo`H0oooo2ooo
ool000[oooooS03oool20820P0@00000C03oool30820P0030<30`03oool0oooo00@0oooo0`20P800
0`30`<00oooo0?ooo`2Z0?ooo`_ooooo000:ooooohX0oooo2000001;0?ooo`H000001@3oool40000
0:`0oooo2oooool000[oooooQP3oool00`30`<00P8200410@009000000030820P03oool0oooo04H0
oooo00D0`<3000000000000000000410@0030820P00500000020P800oooo0?ooo`20P8000`000000
0`10@400P8200410@0170?ooo`040410@0000000@4100820P5l0oooo2oooool000[oooooQ03oool0
0`20P80000000000000;000000030820P03oool0oooo04H0oooo00@0P82000000000000000001@3o
ool010000000P8200?ooo`20P803000000040820P03oool0P820000004H0oooo1P00001M0?ooo`_o
oooo000:oooooh40oooo0P20P80?000000030410@03oool0oooo04H0oooo0`0000000`20P800oooo
0?ooo`040?ooo`030410@020P800oooo00<0000000D0P8200?ooo`3oool0P8200410@0140?ooo`03
0820P0000000000000H000000P20P81I0?ooo`_ooooo000:ooooogl0oooo500000180?ooo`<00000
203oool00`000000P82000000002000000060820P03oool0oooo0?ooo`20P8000000@`3oool<0000
05P0oooo2oooool000[oooooNP3oool00`30`<00P8200820P00F000004P0oooo0`0000090?ooo`05
0410@0000000000000000010@400B03oool>000000<0P820D`3oool;ooooo`002_oooomi0?oooaX0
0000B03oool3000000T0oooo00<0P8200000000000000P0000180?oooa<0000000<0P8200?ooo`3o
ool0CP3oool;ooooo`002_oooomf0?ooo`030<30`020P800000001X00000=@20P8000`30`<00oooo
0?ooo`0@0?ooo`<000002@3oool00`30`<00000000000002000004L0oooo00<0P820000000000000
4`0000020820P4d0oooo2oooool000[oooooL`3ooomE000000030820P03oool0oooo0100oooo00@0
P82000000000000000002P3oool4000004H0oooo00<0P8200000000000005P00001<0?ooo`_ooooo
000:ooooog80oooo00<0`<300820P010@400D`0000000`20P800oooo0?ooo`0@0?ooo`040820P000
00000000000000X0oooo00@0@4100000000000000000AP3oool00`20P80000000000000H00000080
P820B03oool;ooooo`002_oooomf0?ooo`030820P0000000000004l0000000<0P8200?ooo`3oool0
4@3oool3000000030820P03oool0oooo00L0oooo00@0P82000000000000000004@3ooomD000004H0
oooo2oooool000[oooooN03oool00`30`<00P8200410@00I000004P0oooo00@0P820000000000000
@4102@3oool01@30`<000000000000000000P8200100ooooE@0000000`10@400oooo0?ooo`120?oo
o`_ooooo000:ooooog`0oooo5`00001:0?ooo`<000002P3oool3000000030820P03oool0oooo00h0
ooooE00000160?ooo`_ooooo000:ooooogh0oooo0P20P80C000004X0oooo00@0`<30000000000000
00002@3oool01020P80000000000000000150?ooo`030820P0000000000001P000000P20P8180?oo
o`_ooooo000:oooooh80oooo4@00001;0?ooo`<0000000<0P8200?ooo`3oool01`3oool3000004D0
oooo00<0P8200000000000005`00001;0?ooo`_ooooo000:oooooh@0oooo0P20P80<000000030820
P03oool0oooo04X0oooo00<0@41000000010@4002@3oool3000000030820P03oool0oooo0480oooo
00<0P8200000000000004`0000020820P4d0oooo2oooool000[oooooR03oool:000000030820P03o
ool0oooo04/0oooo0`0000080?ooo`@00000A03oool00`20P80000000000000A00000540oooo2ooo
ool000[oooooRP3oool00`20P800000000000005000000030<30`03oool0oooo04`0oooo00<0@410
00000030`<001`3oool4000004D0oooo3`0000020820P5<0oooo2oooool000[oooooS@3oool50000
0500oooo0P0000070?ooo`@0000000<0P8200?ooo`3oool0@P3oool=000005L0oooo2oooool000[o
ooooS`3oool30820P540oooo00@0P82000000010@400P8200P3oool00`30`<0000000<30`0030000
00030820P03oool0oooo0480oooo00<0P8200000000000001P0000000`10@400P8200?ooo`1H0?oo
o`_ooooo000:ooooonH0oooo100000030?ooo`<00000A@3oool6000000030820P03oool0oooo05X0
oooo2oooool000[oooooo`3ooolf0?ooo`80000000<0@4100820P030`<00GP3oool;ooooo`002_oo
oooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3oool;oooo
o`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0ooooV@3o
ool;ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:ooooool0
ooooV@3oool;ooooo`002_oooooo0?oooiT0oooo2oooool000[oooooo`3ooonI0?ooo`_ooooo000:
ooooool0ooooV@3oool;ooooo`002_oooooo0?oooiT0oooo2oooool00?oooooo[_ooool00?oooooo
[_ooool00?oooooo[_ooool00?oooooo[_ooool00?oooooo[_ooool00?oooooo[_ooool00?oooooo
[_ooool00?oooooo[_ooool00001\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{143.312, 125.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.12 Exercise (5).", "Caption",
  CellTags->"Fig. 4.12"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Solve for the motion of a circular drumhead with a fixed boundary of \
radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  "and sound speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  ", subject to the following initial conditions:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], 0) = \(\(\(r\^2\)(1 - r)\)\^3\) 
          cos4\[Theta], \[PartialD]\_t\ \(z(r, \[Theta], 0)\) = 0\)]],
  ". Animate the solution for 0<t<2 using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z(r, \[Theta], 0) = 0\)\(,\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \(z(r, \[Theta], 0)\) = \(\[Delta](
            r)\)/r\)]],
  ". Animate the solution for 0<t<2 using ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " Assuming that the measured temperature gradient at the earth's surface, \
0.03 K/m, is due to an ",
  StyleBox["equilibrium",
    FontSlant->"Italic"],
  " temperature profile ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(r)\)]],
  ", find the required mean heat source ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]S\[RightAngleBracket]\)]],
  ",  in W/",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["m",
            FontSlant->"Plain"], "3"], TraditionalForm]]],
  ", averaged over the earth's interior (presumably due to radioactivity). \
Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Kappa]", " ", "=", " ", 
          RowBox[{"2", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              RowBox[{"(", 
                StyleBox[\(m\ K\),
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(r)\)]],
  ", assuming that the heat source is distributed ",
  StyleBox["uniformly",
    FontSlant->"Italic"],
  " throughout the earth's interior, and that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\)]],
  " is uniform, given in part (a).  Show that the temperature of the core is \
of order ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^5\), " ", 
          StyleBox["K",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". (This huge temperature is 30 times larger than current estimates. \
Evidently, the radioactive heat source cannot be uniform, but instead must be \
concentrated mostly near the earth's surface where the heat can more easily \
escape [",
  ButtonBox["Garland, (1976, p. 356)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "].)"
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Solve the following heat equation problems in cylindrical coordinates:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, \[Theta], 0) = \(\[Delta](r)\)/r\)]],
  " in an insulated cylinder of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  " and thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.5\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(r, \[Theta], 0) = 0\)\(,\)\)\)]],
  " in a cylinder of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  " and thermal conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)]],
  ". There is an incident heat flux ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(-cos\[Theta]\),
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Damped waves on a circular drumhead, radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", satisfy the following PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[Gamma]", " ", 
              
              FractionBox[\(\[PartialD]\(z(r, \[Theta], 
                    t)\)\), \(\[PartialD]t\),
                MultilineFunction->None]}], "+", 
            
            FractionBox[\(\[PartialD]\^2\( z(r, \[Theta], 
                  t)\)\), \(\[PartialD]t\^2\),
              MultilineFunction->None]}], 
          "=", \(\(c\^2\) \[Del]\^2\( z(r, \[Theta], t)\)\)}], 
        TraditionalForm]]],
  ", where \[Gamma]>0 is a damping rate."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the eigenmodes and eigenfrequencies for this wave equation, assuming \
that the edge of the drumhead at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(=\)\(a\)\(\ \)\)\)]],
  " is fixed."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve for the motion given the initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], 
          0) = \(\((1 - r\ )\) \(r\^2\)\(\ \)\(sin2\[Theta]\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(z\& . \)(r, \[Theta], 0) = 0\)]],
  ", and boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`z(1, \[Theta], t) = 0\)]],
  ". Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0.3, \ c = 1, \ 0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " A can of beer, radius ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(a\)\(=\)\),
            "TraditionalForm"], "3", " ", "cm"}], TraditionalForm]]],
  " and height ",
  Cell[BoxData[
      \(TraditionalForm\`L = 11\)]],
  " cm, is initially at room temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 25\ \[Degree]C\)]],
  ". The beer is placed in a cooler of ice, at ",
  Cell[BoxData[
      \(TraditionalForm\`0  \[Degree]C\)]],
  ".  Solve the heat equation to determine how long it takes the beer to cool \
to less than 5\[Degree]C. Assume that the thermal diffusivity is that of \
water, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", "=", 
          RowBox[{\(1.4\[Cross]10\^\(-7\)\), 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " A drumhead has mass ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " per unit area (units ",
  Cell[BoxData[
      FormBox[
        RowBox[{"kg", "/", 
          FormBox[
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "2"],
            "TraditionalForm"]}], TraditionalForm]]],
  ") and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". The speed of propagation of transverse waves is ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ".\nA force per unit area, ",
  Cell[BoxData[
      \(TraditionalForm\`F(r, \[Theta], t)\)]],
  ", is applied to the drumhead in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction. The wave equation then becomes "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FractionBox[\(\[PartialD]\^2\( z(r, \[Theta], 
                t)\)\), \(\[PartialD]t\^2\),
            MultilineFunction->None], "=", 
          RowBox[{\(\(c\^2\) \[Del]\^2 z[r, \[Theta], t]\), "+", 
            RowBox[{\(\(F(r, \[Theta], t)\)/\[Sigma]\), Cell[""]}]}]}], 
        TraditionalForm]]],
  "."
}], "NE5",
  CellTags->"(4.4.34)"],

Cell[TextData[{
  " A ring of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 3\ cm\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`m = 5\ kg\)]],
  " is placed in the center of a  circular drumhead of radius ",
  Cell[BoxData[
      FormBox[
        RowBox[{"R", "=", 
          RowBox[{"1", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". The speed of propagation is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"100", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Sigma]", "=", 
          RowBox[{"0.1", " ", 
            RowBox[{"kg", "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". Including the effect of gravity on the drumhead itself, find the \
equilibrium shape of the drumhead. [Hint: The force per unit area due to the \
ring is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](r - a)\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " A marble rolls in a circle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " around the center of a drumhead of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", with mass per unit area ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sigma]\)]],
  " and wave propagation speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". The marble creates a force per unit area ",
  Cell[BoxData[
      \(TraditionalForm\`F = \(F\_o\) \[ExponentialE]\^\(-\[Alpha][\((r - \
a)\)\^2 + \((\[Theta] - \[Omega]\ t)\)\^2]\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " is the angular speed of the marble.  Find the response of the drumhead to \
the marble, assuming that the drumhead is initially motionless, and \
neglecting the effect of gravity on the drumhead itself.  Animate this \
response for two rotations of the marble using contour plots,  as a function \
of time, taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(a = 1\), ",", " ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`R = 2\)]]]]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  ", \[Alpha]=20, and "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 1/2\)]],
  ","
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " The edge of a circular drumhead of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 2\)]],
  "m  and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{"0.5", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", is flicked up and down, following ",
  Cell[BoxData[
      \(TraditionalForm\`z(a, \[Theta], t) = t\ \(exp(\(-t\))\)\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\)\)]],
  "in seconds). Find the evolution of the drumhead, assuming that it is \
initially at rest  at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". Animate ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, t)\)]],
  " as a series of plots for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " A drumhead has the shape of a wedge, shown in Fig. ",
  ButtonBox["4.13",
    ButtonData:>"Fig. 4.13",
    ButtonStyle->"Hyperlink"],
  ", with opening angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". The edges of the drumhead are fixed at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ". Find analytic expressions for the frequencies and spatial forms of the \
normal modes for this drumhead. Find the lowest frequency mode, for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 27  \[Degree]\)]],
  ", and plot its form as a surface plot. Plot the frequency of this mode as \
a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Alpha] < 360  \[Degree]\)]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000^b000`400?l00000o`00003obP3oool0
0<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3o
ool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00I@3oool00`20P800000000000002
00000080P8200`3oool00`20P8000000000000020820P5H0oooo001T0?ooo`030820P00000000000
00D0000000<0P8200?ooo`0000001@0000000`20P800oooo0?ooo`1C0?ooo`00I03oool400000004
0820P03oool0oooo0?ooo`D000000`3oool00`20P800oooo0?ooo`1C0?ooo`00I03oool4000000D0
oooo1000001I0?ooo`00I03oool3000000L0oooo0`00001I0?ooo`00I03oool3000000L0oooo0`00
001I0?ooo`00I03oool00`20P8000000000000070?ooo`<00000F@3oool006D0oooo0`0000060?oo
o`<00000F@3oool006H0oooo00<0P82000000010@4001@3oool3000005T0oooo001Y0?ooo`800000
0`3oool3000005T0oooo001[0?ooo`80000000@0oooo0000000000000000F@3oool006d0oooo1000
001I0?ooo`00I@3oool20820P0L0oooo0`00001I0?ooo`00I03oool01020P8000000000000000006
0?ooo`<00000F@3oool006@0oooo00@0P82000000000000000001P3oool3000005T0oooo001T0?oo
o`040820P00000000000000000H0oooo0P0000000`20P800oooo0?ooo`1G0?ooo`00I@3oool01020
P800000000000030`<030?ooo`050<30`0000000000000000030`<00F@3oool006P0oooo00<0P820
0000000000000`00001L0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?oo
o`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo0005
0?oookd00000203oool000D0oooo_@0000020820P0H0oooo00050?oookl000001P3oool000L0oooo
00<0P8200000000000000P00002e0?ooo`<000001P3oool000P0oooo1@00000^0?ooo`040820P000
0000000000000880oooo0`0000060?ooo`002@3oool00`20P800000000000002000000030820P03o
ool0oooo02X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000;0?ooo`@0000000<0
P8200?ooo`3oool0:@3oool01020P80000000000000000220?ooo`<000001P3oool000/0oooo00<0
P8200000000000000P00000[0?ooo`040820P0000000000000000880oooo0`0000060?ooo`00303o
ool5000002X0oooo00@0P8200000000000000000PP3oool3000000H0oooo000=0?ooo`030820P000
000000000080000000<0P8200?ooo`3oool09P3oool01010@40000000000000000220?ooo`<00000
1P3oool000l0oooo100000000`20P800oooo0?ooo`0U0?ooo`<00000P`3oool3000000H0oooo000?
0?ooo`030820P00000000000008000009`3oool300000880oooo0`0000070?ooo`00403oool50000
02H0oooo0`0000220?ooo`<000001`3oool00140oooo00<0P8200000000000000P0000000`20P800
oooo0?ooo`0R0?ooo`<00000PP3oool3000000L0oooo000C0?ooo`@0000000<0P8200?ooo`3oool0
8@3oool300000880oooo0`0000070?ooo`004`3oool00`20P80000000000000200000280oooo1000
00220?ooo`<000001`3oool001@0oooo1@00000Q0?ooo`@00000PP3oool3000000L0oooo000E0?oo
o`D00000803oool3000008<0oooo0`0000070?ooo`005P3oool00`20P80000000000000200000003
0<30`03oool0oooo01/0oooo100000230?ooo`<000001`3oool001L0oooo00<0P820000000000000
0P00002T0?ooo`<000001`3oool001P0oooo1@00002S0?ooo`<000001`3oool001T0oooo1@00002R
0?ooo`<000001`3oool001X0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`2M0?oo
o`040820P00000000000000000L0oooo000K0?ooo`030820P0000000000000800000W`3oool40000
00L0oooo000L0?ooo`D00000WP3oool3000000P0oooo000M0?ooo`D00000W@3oool3000000P0oooo
000N0?ooo`030820P000000000000080000000<0`<300?ooo`3oool09P3oool40820P0030<30`03o
ool0oooo00D0oooo0`20P81S0?ooo`040820P00000000000000000P0oooo000O0?ooo`030820P000
00000000008000009P3oool2000000050820P03oool0oooo0?ooo`20P8000P0000050?ooo`@00000
HP3oool4000000P0oooo000P0?ooo`D000004@3oool00`000000P8200?ooo`0?0?ooo`040820P000
00000000000000H0oooo0P0000030?ooo`D00000HP3oool4000000P0oooo000Q0?ooo`D000003`3o
ool4000000l0oooo00<0P820000000000000203oool010000000P8200?ooo`3oool5000000030820
P03oool0oooo05l0oooo100000080?ooo`008P3oool00`20P800000000000002000000030<30`03o
ool0oooo00X0oooo100000000`20P800oooo0?ooo`0<0?ooo`040820P00000000000000000T0oooo
00D000000820P03oool000000410@0020?ooo`80P820H@3oool3000000030820P03oool0oooo00H0
oooo000S0?ooo`030820P00000000000008000002`3oool01@20P8000000000000000000P82000l0
oooo100000090?ooo`040820P00000000000000006D0oooo00D0P82000000000000000000820P008
0?ooo`00903oool5000000X0oooo00D0P82000000000000000000820P00?0?ooo`@000002@3oool0
1020P800000000000000001U0?ooo`050820P0000000000000000020P800203oool002D0oooo1@00
00090?ooo`@00000403oool4000000X0oooo0`00001U0?ooo`050820P0000000000000000020P800
203oool002H0oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`040?ooo`@0000000<0
P8200?ooo`3oool03P3oool4000000X0oooo00@0P820000000000000@410I03oool01@20P8000000
000000000000P82000P0oooo000W0?ooo`030820P00000000000008000001@3oool400000180oooo
1000000;0?ooo`<00000I03oool01@20P8000000000000000000P82000P0oooo000X0?ooo`D00000
0`3oool4000001@0oooo1000000:0?ooo`@00000H`3oool4000000T0oooo000Y0?ooo`D0000000<0
oooo0820P00000000P0000000`20P800oooo0?ooo`0B0?ooo`@000002P3oool4000006<0oooo1000
00090?ooo`00:P3oool00`20P800000000000006000001D0oooo00D0@41000000000000000000<30
`0090?ooo`0300000020P800000000800000HP3oool4000000T0oooo000[0?ooo`030820P0000000
000000@000005`3oool3000000030820P03oool0oooo00L0oooo00<000000?ooo`0000000`00001Q
0?ooo`<000002P3oool002`0oooo1@00000I0?ooo`<00000203oool2000000030?ooo`20P8000000
00800000H03oool4000000X0oooo000/0?ooo`H000006@3oool3000000L0oooo0P0000000`3oool0
P82000000002000000030820P03oool0oooo05d0oooo0`00000;0?ooo`00;P3oool00`20P8000000
00000002000000030<30`03oool0oooo01H0oooo00@0P820000000000000P820103oool00`10@400
P8200?ooo`020?ooo`<0000000<0@4100?ooo`3oool0G@3oool3000000/0oooo000_0?ooo`030820
P00000000000008000006`3oool5000006L0oooo1000000;0?ooo`00<03oool5000008H0oooo0`00
000<0?ooo`00<@3oool5000008D0oooo0`00000<0?ooo`00<P3oool5000008@0oooo0`00000<0?oo
o`00<`3oool01@10@4000000000000000000@4100880oooo00@0P8200000000000000000303oool0
03@0oooo1@0000210?ooo`<0000000<0P8200?ooo`3oool02P3oool003D0oooo1@0000200?ooo`<0
000000<0P8200?ooo`3oool02P3oool003H0oooo1@00001o0?ooo`<0000000<0P8200?ooo`3oool0
2P3oool003L0oooo00D0@41000000000000000000410@01m0?ooo`050820P0000000000000000030
`<00303oool003P0oooo1@00001l0?ooo`040820P00000000000000000d0oooo000i0?ooo`D00000
N`3oool01020P800000000000000000=0?ooo`00>P3oool5000007X0oooo1000000=0?ooo`00>`3o
ool01@10@4000000000000000000@41007T0oooo0`00000>0?ooo`00?03oool5000007P0oooo0`00
000>0?ooo`00?@3oool5000007H0oooo1000000>0?ooo`00?P3oool5000007D0oooo0`00000?0?oo
o`00?`3oool01@10@4000000000000000000@41007<0oooo00@0P82000000000000000003`3oool0
0400oooo1@00001b0?ooo`<00000403oool00440oooo1@00001a0?ooo`<00000403oool00480oooo
1@00001_0?ooo`@00000403oool004<0oooo00<0@4100000000000000P0000000`30`<00oooo0?oo
o`1[0?ooo`<0000000<0P8200?ooo`3oool03P3oool004@0oooo1@00001/0?ooo`050820P0000000
000000000020P800403oool004D0oooo1@00001[0?ooo`040820P0000000000000000140oooo0016
0?ooo`D00000JP3oool01020P800000000000000000A0?ooo`00A`3oool00`20P800000000000002
000000030<30`03oool0oooo06H0oooo0`0000000`20P800oooo0?ooo`0?0?ooo`00B03oool00`20
P800000000000002000006P0oooo0`00000B0?ooo`00B@3oool5000006H0oooo1000000B0?ooo`00
BP3oool5000006D0oooo0`00000C0?ooo`00B`3oool00`20P800000000000002000000030<30`03o
ool0oooo0600oooo00@0P82000000000000000004`3oool004`0oooo00<0P8200000000000000P00
001R0?ooo`<00000503oool004d0oooo1@00001P0?ooo`@00000503oool004h0oooo1@00001O0?oo
o`@00000503oool003T0oooo1020P8060?ooo`80P8202P3oool00`20P80000000000000200000003
0<30`03oool0oooo05X0oooo00D0P82000000000000000000820P00D0?ooo`00>03oool7000000<0
oooo1@0000090?ooo`030820P0000000000000800000G03oool4000001D0oooo000g0?ooo`030820
P0000000000000D0000000<0P8200?ooo`0000001P0000090?ooo`D00000F`3oool4000001D0oooo
000g0?ooo`@0000000@0P8200?ooo`3oool0oooo1@0000030?ooo`030000003oool0oooo00P0oooo
1@00001I0?ooo`@000005P3oool003L0oooo100000050?ooo`@000003`3oool5000005P0oooo1000
000F0?ooo`00=`3oool3000000L0oooo0`00000@0?ooo`050410@0000000000000000010@400EP3o
ool4000001L0oooo000g0?ooo`<000001`3oool300000140oooo1@00001D0?ooo`@00000603oool0
03L0oooo00<0P8200000000000001`3oool300000180oooo1@00001C0?ooo`@00000603oool003P0
oooo0`0000060?ooo`<000004`3oool500000540oooo00D0P82000000000000000000820P00H0?oo
o`00>@3oool00`20P80000000410@0050?ooo`<00000503oool01@10@4000000000000000000@410
0500oooo00D0@41000000000000000000<30`00H0?ooo`00?03oool2000000<0oooo0`00000E0?oo
o`D00000C`3oool4000001T0oooo000n0?ooo`80000000@0oooo00000000000000005P3oool50000
04d0oooo1000000J0?ooo`00@03oool4000001L0oooo1@00001<0?ooo`@000006P3oool003P0oooo
0P20P8070?ooo`<00000603oool01@10@4000000000000000000@41004T0oooo0P20P803000001/0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000I0?ooo`D00000B03oool4000001`0
oooo000g0?ooo`040820P00000000000000000H0oooo0`00000J0?ooo`D00000AP3oool01@20P800
0000000000000000P82001`0oooo000g0?ooo`040820P00000000000000000H0oooo0P0000000`20
P800oooo0?ooo`0I0?ooo`D00000A@3oool01@20P8000000000000000000P82001`0oooo000h0?oo
o`040820P000000000000<30`0<0oooo00D0`<3000000000000000000<30`00L0?ooo`050410@000
0000000000000010@400A03oool4000001d0oooo000k0?ooo`030820P0000000000000<00000803o
ool500000480oooo1000000N0?ooo`00HP3oool500000440oooo0`00000O0?ooo`00H`3oool50000
03l0oooo1000000O0?ooo`00I03oool01@10@4000000000000000000@41003d0oooo00@0P8200000
000000000000803oool006D0oooo1@00000k0?ooo`050820P0000000000000000020P800803oool0
06H0oooo1@00000j0?ooo`040820P0000000000000000240oooo001W0?ooo`D00000>@3oool40000
0240oooo001X0?ooo`050410@0000000000000000010@400=`3oool01020P800000000000000000R
0?ooo`00J@3oool5000003H0oooo0`00000S0?ooo`00JP3oool5000003@0oooo0`00000T0?ooo`00
J`3oool5000003<0oooo0`00000T0?ooo`00K03oool01@10@4000000000000000000@4100300oooo
00D0P82000000000000000000820P00T0?ooo`00K@3oool5000002l0oooo1000000U0?ooo`00KP3o
ool5000002d0oooo1000000V0?ooo`00K`3oool5000002/0oooo1000000W0?ooo`00L03oool40000
00030820P03oool0oooo02P0oooo1000000W0?ooo`00L03oool00`30`<0000000000000200000003
0820P03oool0oooo02D0oooo00D0`<3000000000000000000410@00X0?ooo`00LP3oool5000002H0
oooo1000000Y0?ooo`00L`3oool5000002D0oooo1000000Y0?ooo`00M03oool4000000030820P03o
ool0oooo0240oooo1000000Z0?ooo`00M03oool00`30`<00000000000002000000030820P03oool0
oooo01h0oooo00D0P82000000000000000000820P00[0?ooo`00MP3oool5000001l0oooo0`000000
0`20P800oooo0?ooo`0Z0?ooo`00M`3oool5000001d0oooo00D0P82000000000000000000820P00/
0?ooo`00N03oool4000000030820P03oool0oooo01X0oooo1000000]0?ooo`00N03oool00`30`<00
000000000002000000030820P03oool0oooo01P0oooo00@0P820000000000000P820;P3oool007X0
oooo1@00000H0?ooo`@00000;`3oool007/0oooo1@00000F0?ooo`@00000<03oool007`0oooo1000
00000`20P800oooo0?ooo`0B0?ooo`050820P0000000000000000020P800<03oool007`0oooo00<0
`<300000000000000P0000000`20P800oooo0?ooo`0@0?ooo`050820P0000000000000000020P800
<@3oool007h0oooo1@00000@0?ooo`@00000<`3oool007l0oooo1@00000>0?ooo`@00000=03oool0
0800oooo1@00000<0?ooo`030820P0000000000000800000=03oool00800oooo00<0`<3000000000
00000P0000000`10@400oooo0?ooo`090?ooo`050410@0000000000000000030`<00=03oool00880
oooo1@0000090?ooo`@00000=P3oool008<0oooo1@0000070?ooo`@00000=`3oool008@0oooo1@00
00050?ooo`@00000>03oool008D0oooo00D0@41000000000000000000410@0030?ooo`050410@000
0000000000000030`<00>03oool008H0oooo1@0000000`3oool0000000000002000003X0oooo0027
0?ooo`T00000>P3oool008P0oooo1`00000k0?ooo`00R@3oool01@10@4000000000000000000@410
03`0oooo002:0?ooo`800000?P3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{67.5625, 62.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 4.13 Exercise (14).", "Caption",
  CellTags->"Fig. 4.13"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A wheel of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 10\ cm\)]],
  " rotates on a bearing of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\ cm\)]],
  ", with angular frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 100\ rad/sec\)]],
  ". The surface of the wheel is insulated, except at the bearing. At time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " the wheel has uniform temperature ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_o\), "=", 
          RowBox[{"300", " ", 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", but due to friction on the bearing it begins to heat. Taking the torque \
due to friction as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 1\ newton\)]],
  " per meter of length of the bearing, the heating power per unit length is \
",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Tau]\ \[Omega]\), "=", 
          RowBox[{"100", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Assuming that this power is dissipated into the metal wheel, with the \
thermal conductivity and heat capacity of copper, find ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, t)\)]],
  " in the wheel. "
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " A meteor strikes the north pole of a spherical planet of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 5000\ km\)]],
  ", covered with water of uniform depth ",
  Cell[BoxData[
      \(TraditionalForm\`d\_o = 1\ km\)]],
  ". The acceleration of gravity on the planet is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"10", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". Initially, the perturbed ocean height satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`h(\[Theta], \[Phi], 
          0) = \(h\_o\) \(exp(\(-50\)\ \[Theta]\^2)\), \ \[PartialD]\_t\ \(h(\
\[Theta], \[Phi], 0)\) = 0\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(h\_o\), "=", 
          RowBox[{"100", " ", 
            StyleBox[\(\(m\)\(.\)\),
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " Find the evolution ",
  Cell[BoxData[
      \(TraditionalForm\`h(\[Theta], \[Phi], t)\)]],
  " of the subsequent tidal wave, and animate it versus time using ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (as a function of \[Theta] only) for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 50\)]],
  " hours."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " A hemispherical chunk of fat has radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 2\ cm\)]],
  ". The flat side of the hemisphere sits on a stove, at height ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ".  At ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " the temperature of the fat is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_o\), "=", 
          RowBox[{"300", " ", 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". At this time, the stove is turned on and the surface at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " heats according to ",
  Cell[BoxData[
      \(TraditionalForm\`T = T\_o + \((T\_1 - T\_o)\) \(tanh(t/60)\)\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_1\), "=", 
          RowBox[{"400", " ", 
            StyleBox["K",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ", and times are in seconds. Assuming that the rest of the fat surface \
exposed to air has an insulating boundary condition, and that the fat has the \
thermal properties of water, find ",
  Cell[BoxData[
      \(TraditionalForm\`T(r, \[Theta], t)\)]],
  ". Plot the temperature vs. time at the point farthest from the stove."
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " A copper sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 10  cm\)]],
  " is placed in sunlight, with an incident thermal flux of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "=", 
          RowBox[{"1000", " ", 
            RowBox[{"Watt", "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ", in the ",
  Cell[BoxData[
      \(TraditionalForm\`-\)]],
  StyleBox["z-",
    FontSlant->"Italic"],
  "direction (on the upper side of the sphere only). The sphere also radiates \
away this energy like a blackbody, with a flux ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_r = \[Sigma]\ \(T(a, \[Theta])\)\^4\
\)]],
  "in the radial direction, where \[Sigma] is the Stefan-Boltzmann constant. \
"
}], "Text",
  CellTags->"i:95"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Assuming that the temperature distribution is spherically symmetric, what \
is the temperature of the sphere in equilibrium?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the actual equilibrium temperature distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(r, \[Theta])\)]],
  " in the sphere. [Hint: Copper is a very good heat  conductor, so the \
temperature distribution is ",
  StyleBox["nearly",
    FontSlant->"Italic"],
  " spherically symmetric. Therefore, you only need to keep two or three \
terms in the generalized Fourier series for ",
  Cell[BoxData[
      \(TraditionalForm\`\(T\_eq\)(r, \[Theta])\)]],
  ", and you can Taylor-expand the Stefan-Boltzmann law around the \
spherically symmetric solution. ]"
}], "Text"],

Cell[TextData[{
  StyleBox["(19)(a)",
    FontWeight->"Bold"],
  " The energy levels ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_\(l\ m\ n\)\)\(\ \)\)\)]],
  "for an electron confined in a spherical cavity of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " (a ",
  StyleBox["quantum dot",
    FontSlant->"Italic"],
  ") are described by the time-independent Schr\[ODoubleDot]dinger equation, \
"
}], "Text",
  CellTags->"i:96"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(H\&^\) \[Psi]\_\(l\ m\ n\) = \(E\_\(l\ m\ n\)\) \
\[Psi]\_\(l\ m\ n\)\)]],
  ","
}], "NE5",
  CellTags->"(4.4.35)"],

Cell[TextData[{
  "where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(H\&^\), "=", 
          RowBox[{\(-\(\[HBar]\^2\/\(2  m\)\)\), 
            RowBox[{\(\[Del]\^2\), 
              RowBox[{"+", 
                RowBox[{"V", "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  " is the energy operator, ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the electron mass, ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " is the potential of the cavity (",
  Cell[BoxData[
      \(TraditionalForm\`V = 0\ for\ r < a, \ 
      V = \[Infinity]\ for\ r \[GreaterEqual] \ a\)]],
  "), ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_\(l\ m\ n\)\)(r, \[Theta], \[Phi])\)]],
  " are the associated energy eigenfunctions, and ",
  Cell[BoxData[
      \(TraditionalForm\`l, m, n\)]],
  " are quantum numbers enumerating the energy levels. Apply separation of \
variables to this problem in order to find the energy levels and the energy \
eigenfunctions. (Hint: In this potential, the boundary condition is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ".) What is the lowest energy level in electron volts for a dot of radius \
",
  Cell[BoxData[
      \(TraditionalForm\`a = 5\ \[Angstrom]\)]],
  "?(",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\ \[Angstrom]\), "=", 
          RowBox[{\(10\^\(-10\)\), " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "; ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1\ eV\), " ", "=", " ", 
          RowBox[{"1.60", "\[Cross]", 
            FormBox[
              RowBox[{\(10\^\(-19\)\), " ", 
                StyleBox["J",
                  FontSlant->"Plain"]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(20) ",
    FontWeight->"Bold"],
  "The electron energy levels in a hydrogen atom also satisfies Eq. ",
  ButtonBox["(4.4.35)",
    ButtonData:>"(4.4.35)",
    ButtonStyle->"Hyperlink"],
  ", with Hamiltonian operator ",
  Cell[BoxData[
      \(TraditionalForm\`H\&^ = \(-\(\[HBar]\^2\/\(2  
                  m\)\)\) \[Del]\^2\(-e\^2\)/\((4\ \[Pi]\ \(\[Epsilon]\_o\) 
                r)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the reduced mass of the system, roughly equalling the electron mass, \
and ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is the electron charge. Show by substitution of the following solutions \
into Eq. ",
  ButtonBox["(4.4.35)",
    ButtonData:>"(4.4.35)",
    ButtonStyle->"Hyperlink"],
  "  that the energy levels are given by"
}], "Text",
  CellTags->"i:97"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_n = \ 
        e\^2/\((8\ \[Pi]\ \[Epsilon]\_o\ a\ n\^2)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]]
}], "NE5",
  CellTags->"(4.4.36)"],

Cell["and that the eigenfunctions are", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_\(l\ m\ n\) = \(\(Y\_\(l\ m\)\)(\[Theta], \
\[Phi])\)\ \(r\^l\) \(\(L\_\(n - l - 1\)\%\(2  l + 1\)\)(
            2\ r/\((n\ a)\))\) \[ExponentialE]\^\(\(\(-\ r\)/\((n\ a)\)\)\(\ \
\)\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < l < 
        n, \ \(\(|\)\(m\)\(|\)\(\(\[LessEqual]\)\(\ \)\(l\)\)\)\)]],
  ","
}], "NE5",
  CellTags->"(4.4.37)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a = 
        4\ \[Pi]\ \(\[Epsilon]\_\(\(o\)\(\ \)\)\) \[HBar]\^2/m\ e\^2\)]],
  "is the ",
  ButtonBox["Bohr",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Bohr_Niels.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " radius,  and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\_\[Alpha]\%\[Beta]\)(x)\)]],
  " are  generalized Laguerre polynomials, equal to the ordinary Laguerre \
polynomials for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta] = 0\)]],
  ". (In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " these polynomials are referred to as ",
  StyleBox["LaguerreL[\[Alpha], \[Beta], x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".) In your solution you may use the fact that these polynomials  satisfy \
the ODE "
}], "Text",
  CellTags->"i:114"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(x\ L\_\[Alpha]\%\[Beta]\^\[DoublePrime] + \((\[Beta] + 
                      1 - x)\) 
                  L\_\[Alpha]\%\[Beta]\^\[Prime] + \[Alpha]\ L\_\[Alpha]\%\
\[Beta] = 0\),
            "TraditionalForm"], "."}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "(Hint: in the ",
  "Schr\[ODoubleDot]dinger",
  " equation scale distances to ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and energies to ",
  Cell[BoxData[
      \(TraditionalForm\`e\^2/4\ \[Pi]\ \(\[Epsilon]\_o\) a\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(21)",
    FontWeight->"Bold"],
  " Rubber supports two types of bulk wave motions: compressional modes and \
shear modes. The compressional modes have displacements ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " in the direction of propagation, creating compressions in the rubber. The \
shear modes have displacements transverse to the propagation direction, so \
that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ",  and therefore no compressions occur in the shear modes. Consider the \
shear modes in a spherical rubber ball of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". These modes satisfy the following vector wave equation:"
}], "Text",
  CellTags->"i:98"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(c\_s\^2\),
              FontWeight->"Plain"], 
            RowBox[{\(\[Del]\^2\), 
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_s\)]],
  " is the speed of shear wave propagation [see ",
  ButtonBox["Love, (1944)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]. Assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontWeight->"Plain"], "^"], " ", 
              RowBox[{
                SubscriptBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["r",
                        FontWeight->"Plain",
                        FontSlant->"Italic"]}]], "\[Phi]"], 
                "(", \(r, \ \[Theta], \[Phi]\), ")"}]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", [i.e., the motion is in the (",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  ") plane, in the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  "-direction], the boundary condition at the free surface of the sphere, ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\)]],
  ", can be shown to be"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"R", " ", \(\[PartialD]\/\[PartialD]r\), 
            SubscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["r",
                    FontSlant->"Italic"]}]], "\[Phi]"]}], "=", 
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]], "\[Phi]"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  By applying separation of variables to this wave equation, show that the \
modes have the form"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["r",
                    FontSlant->"Italic"]}]], "\[Phi]"], 
            "(", \(r, \[Theta], \[Phi]\), ")"}], 
          "=", \(\(\(\(J\_\(l + 1/2\)\)(
                  k\ r)\)\/\@r\) \(\[ExponentialE]\^\(\(\[ImaginaryI]\)\(\ \)\
\(m\)\(\ \)\(\[Phi]\)\(\ \)\)\) \(\[PartialD]\/\[PartialD]\[Theta]\) \(\(P\_l\
\%m\)(cos\ \[Theta])\)\(\ \ \)\)}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  " and that the  frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " of normal modes satisfy "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]R\) \(\(J\_\(l + 1/2\)\)(k\
\ R)\)\/\@R = \(\(J\_\(l + 1/2\)\)(k\ R)\)\/\@R\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k = \ \[Omega]/c\_s\)]],
  " and where ",
  Cell[BoxData[
      \(TraditionalForm\`J\_l\)]],
  "is a Bessel function, ",
  Cell[BoxData[
      \(TraditionalForm\`P\_l\%m\)]],
  "is an associated Legendre function, ",
  Cell[BoxData[
      \(TraditionalForm\`l = 0, 1, 2,  ... \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m = \ \(-l\), \(-l\) + 1,  ... , l - 1, l\)]],
  ". Solve numerically for the lowest four modes. Plot the dependence of \
these four modes on ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Choose 50 points distributed evenly along the great circle defined by  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0  and\ \[Pi]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\)]],
  ", and follow the motion of these points as they are carried along by the \
lowest normal mode for one period of oscillation."
}], "Text"],

Cell[TextData[{
  StyleBox["(22)",
    FontWeight->"Bold"],
  " Spherically symmetric compressional waves in a rubber ball of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " satisfy the following elastic wave equation:"
}], "Text",
  CellTags->"i:99"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["r",
                  FontSlant->"Italic"]}]]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(c\_p\^2\),
              FontWeight->"Plain"], "(", 
            RowBox[{
              RowBox[{\(\[PartialD]\^2\/\[PartialD]r\^2\), 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["r",
                      FontSlant->"Italic"]}]]}], 
              StyleBox[" ",
                FontSlant->"Italic"], "+", " ", 
              RowBox[{\(2\/r\), \(\[PartialD]\/\[PartialD]r\), 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["r",
                      FontSlant->"Italic"]}]]}], "-", " ", 
              RowBox[{\(2\/r\^2\), 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["r",
                      FontSlant->"Italic"]}]]}]}], ")"}]}], 
        TraditionalForm]]],
  ",\nwhere ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["r",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the radial position change of a mass element, and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_p\)]],
  " is the speed of compressional waves. These waves satisfy the following \
boundary condition at the free surface  ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[\((2  c\_p\^2 - 4  c\_s\^2)\),
                  FontWeight->"Plain"], 
                FractionBox[
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["r",
                        FontSlant->"Italic"]}]], "r"]}], 
              StyleBox["+",
                FontWeight->"Plain"], 
              RowBox[{\(c\_p\^2\), \(\[PartialD]\/\[PartialD]r\), 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["r",
                      FontSlant->"Italic"]}]]}]}], "=", "0"}]}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_s\)]],
  " is the speed of shear waves."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that the the dispersion relation for these waves is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`4\ k\ R\ \(c\_s\^2\) 
          cos\ k\ R = \((4\ c\_s\^2 - \(\[Omega]\^\(\(2\)\(\ \)\)\) 
                R\^2)\)\ sin\ k\ R\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\  = \ \[Omega]/c\_p\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Solve for the lowest three frequencies, and in each case plot the radial \
dependence of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["r",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t for   (i) ",
  Cell[BoxData[
      \(TraditionalForm\`c\_s = c\_p\)]],
  ", (ii) ",
  Cell[BoxData[
      \(TraditionalForm\`c\_s = c\_p/\@2\)]],
  ",  (iii) ",
  Cell[BoxData[
      \(TraditionalForm\`c\_s = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(23)",
    FontWeight->"Bold"],
  " A child drops a pebble into the center of a shallow pool of water of \
radius ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"1", " ", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and depth ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ". The wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, t)\)]],
  " satisfies the wave equation, with  wave propagation speed  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "=", 
          RowBox[{\(\@\(g\ h\)\), "=", 
            RowBox[{"1", " ", 
              RowBox[{
                StyleBox["m",
                  FontSlant->"Plain"], "/", 
                StyleBox["s",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ".  The initial disturbance has the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(z(r, 0)\),
            "TraditionalForm"], "=", " ", 
          RowBox[{\(-z\_o\), 
            RowBox[{"exp", "(", 
              RowBox[{\(-30\), "  ", 
                FormBox[\(r\^2\),
                  "TraditionalForm"]}], ")"}], \((1 - 30  r\^2)\)}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \(z(r, 0)\) = 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`z\_o = 1\ cm\)]],
  " (and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(\ \)\)\)]],
  "is measured in meters). The boundary condition at the pool edge is not \
Dirichlet: the water surface at the pool edge can move up and down. To find \
the correct boundary condition, we must consider the radial displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " of fluid during the wave motion. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using the same techniques as were used in the derivation of Eq. ",
  ButtonBox["(3.1.78)",
    ButtonData:>{"Chapter3.nb", "(3.1.78)"},
    ButtonStyle->"Hyperlink"],
  ", show that the radial fluid displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " is related to the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ \(-\(h\/r\)\)\ \[PartialD]\((r\ \[Eta])\)/\
\[PartialD]r\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The boundary conditions are ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta] = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  "  finite at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 0\)]],
  ". Find the eigenmodes and eigenfrequencies, and plot the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "  for the first three eigenmodes."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Solve the initial-value problem stated previously, and animate the \
solution using ",
  StyleBox["Plot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(24)",
    FontWeight->"Bold"],
  " For bounded pools of shallow water with waves moving in one dimension \
only, we saw in the previous problem that it is necessary to consider the \
horizontal fluid displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](r, t)\)]],
  ". For general wave motion, this displacement is  a vector, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              StyleBox["\[Eta]",
                FontWeight->"Bold"],
              "TraditionalForm"], "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], "."}], 
        TraditionalForm]]],
  "Wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is related to fluid displacement according to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "=", 
          RowBox[{\(-h\), 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox["\[Eta]",
                  FontWeight->"Bold"]}]}]}]}], TraditionalForm]]],
  ".  Using the same method as that which led to Eq. ",
  ButtonBox["(3.1.78)",
    ButtonData:>{"Chapter3.nb", "(3.1.78)"},
    ButtonStyle->"Hyperlink"],
  ", one can show that ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " satisfies the vector equation"
}], "Text",
  CellTags->"i:103"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
            MultilineFunction->None], 
          RowBox[{
            StyleBox["\[Eta]",
              FontWeight->"Bold"], "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}]}], "=", 
        RowBox[{\(c\^2\), 
          RowBox[{\(\[Del]\[Del]\), "\[CenterDot]", 
            RowBox[{
              StyleBox["\[Eta]",
                FontWeight->"Bold"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}]}], TraditionalForm]]]], "NE5",
  CellTags->"(4.4.38)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(g\ h\)\)]],
  ", for a pool with constant equilibrium depth ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ". The boundary condition on this equation is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["n",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"], "\[CenterDot]", 
            StyleBox["\[Eta]",
              FontWeight->"Bold"]}], "=", "0"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["n",
              FontSlant->"Plain"], "^"],
          FontWeight->"Bold"], TraditionalForm]]],
  " is a unit vector normal to the edge of the pool."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(4.4.38)",
    ButtonData:>"(4.4.38)",
    ButtonStyle->"Hyperlink"],
  " show that wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " satisfies a wave equation."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Assume that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Eta]",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["\[Del]",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[Phi]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ". This is called ",
  StyleBox["potential flow",
    FontSlant->"Italic"],
  " [see ",
  ButtonBox["Landau and Lifshitz (1959)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]. Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " also satisfies the wave equation "
}], "Text",
  CellTags->"i:100"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
            MultilineFunction->None], " ", "\[Phi]"}], 
        "=", \(\(c\^2\) \[Del]\^2 \[Phi]\)}], TraditionalForm]]]], "NE5",
  CellTags->"(4.4.39)"],

Cell[TextData[{
  "with ",
  "von Neumann",
  " boundary condition ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["n",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox[\(\[Del]\[Phi]\),
                  FontWeight->"Plain"]}], "=", "0"}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Show that \[Phi] and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " are related according to ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-h\)\ \[Del]\^2 \[Phi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(25)(a)",
    FontWeight->"Bold"],
  " A coffee cup has radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and is filled with coffee of depth ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  ".  Assuming potential flow and using Eq. ",
  ButtonBox["(4.4.39)",
    ButtonData:>"(4.4.39)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((r, \[Theta])\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", find analytic expressions for the frequency and spatial form of the \
normal modes of the coffee. What is the lowest frequency mode, and what is \
its frequency? (Hint: This mode is not cylindrically symmetric.) Plot the \
spatial form of ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, \[Theta], t)\)]],
  " for this mode. \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the frequency of this lowest mode for a cup of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a = 3\ cm\)]],
  ", filled to a depth of ",
  Cell[BoxData[
      \(TraditionalForm\`h = 1\ cm\)]],
  ". See if you can set this mode up in your coffee. Measure its frequency \
with your watch, and use a ruler to determine the depth of the coffee and the \
cup diameter. Compare to the theory, and discuss any errors."
}], "Text",
  CellTags->"i:102"],

Cell[TextData[{
  StyleBox["(26)",
    FontWeight->"Bold"],
  " A wave machine excites waves at one end of  a shallow square pool of side \
",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  " by injecting and removing water sinusoidally in time along the left edge. \
Along this edge ",
  Cell[BoxData[
      \(TraditionalForm\`\((x = 0)\)\)]],
  ", the boundary conditions are time-dependent, with fluid being displaced \
according to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Eta]\_x\)(0, y, 
          t) = \(\(\(\(y\^2\)(
                1 - y)\)\^2\) \(sin\)\(\ \)\(\[Omega]\_o\) \(t\)\(\ \)\)\)]],
  ". Along the other three edges,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["n",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["\[Eta]",
                  FontWeight->"Bold"]}], "=", "0"}],
            "TraditionalForm"]}], TraditionalForm]]],
  ". Assume potential flow. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Solve for the wave height ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, t)\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_t\ \[Phi] = \(\[Omega]\_o\) \
\(\(\(y\^2\)(1 - y)\)\^2\) x\)]],
  " initially. Create an animation of the wave height using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c = 0.2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 6  \[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " There are values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  "for which the wave response becomes large. Find these values, and explain \
their meaning physically."
}], "Text"],

Cell[TextData[{
  StyleBox["(27)",
    FontWeight->"Bold"],
  " Sound waves in a fluid such as air or water satisfy  equations of the \
same form as those for gravity waves on a fluid surface, Eqs. ",
  ButtonBox["(4.4.38)",
    ButtonData:>"(4.4.38)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(4.4.39)",
    ButtonData:>"(4.4.39)",
    ButtonStyle->"Hyperlink"],
  ", except written in three dimensions. Assuming potential flow, the \
displacement of a fluid element in the gas is given by  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[Eta]",
              FontWeight->"Bold"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(x, y, z, t\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(\[Del]\[Phi]\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfies Eq. ",
  ButtonBox["(4.4.39)",
    ButtonData:>"(4.4.39)",
    ButtonStyle->"Hyperlink"],
  ", and the sound speed is  ",
  Cell[BoxData[
      \(TraditionalForm\`c = \@\(\[Gamma]\ p\_o/M\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " is the mass density of the fluid, ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  "is the equilibrium pressure, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\)\(\ \)\)\)]],
  "is the ratio of specific heats. Also, the perturbed pressure ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["p",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in the wave is related to ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " by"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{
            RowBox[{\(-p\_o\), 
              RowBox[{"\[Del]", 
                RowBox[{"\[CenterDot]", 
                  StyleBox["\[Eta]",
                    FontWeight->"Bold"]}]}]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            StyleBox[\(\(-p\_o\) \[Del]\^2 \[Phi]\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "NE5",
  CellTags->"(4.4.40)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " A closed tube  of length ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " with circular cross section supports normal modes in the enclosed gas. \
The tube volume lies in the domain ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 1, 0 < z < 2\)]],
  ". Find the frequencies of the cylindrically-symmetric normal modes in this \
tube and the spatial form of the modes. (Hint: First, show that the function \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfies von Neumann boundary conditions.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "Call the ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, z)\)\)]],
  " mode numbers the integers  ",
  Cell[BoxData[
      \(TraditionalForm\`\((l, n)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`\((l, n)\) = \((0, 0)\)\)]],
  " denoting the lowest mode (with zero frequency). Plot the displacement  \
field ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " for the ",
  Cell[BoxData[
      \(TraditionalForm\`\((l, n)\) = \((1, 2)\)\)]],
  " mode in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, z)\)\)]],
  " plane using ",
  StyleBox["PlotVectorField",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c) ",
    FontWeight->"Bold"],
  "A  circular portion of the end of the cylinder at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " is a loudspeaker: an elastic membrane, which is driven by an external \
force to oscillate as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["z",
                  FontSlant->"Italic"]}]], "(", \(r, 0, t\), ")"}], 
          "=", \(z\_o\ \((1 - 4  r\^2)\) sin\ \(\[Omega]\_o\) t\)}], 
        TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`r < 1/2\)]],
  ", and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["z",
                  FontSlant->"Italic"]}]], "(", \(r, 0, t\), ")"}], " ", "=", 
          " ", "0"}], TraditionalForm]]],
  " otherwise. Find the response of the pressure ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "(", \(r, z, t\), ")"}], 
        TraditionalForm]]],
  " for the gas inside the piston as a Fourier series, assuming that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "=", "0"}], TraditionalForm]]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ". [Hint: The potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " has a discontinuous derivative as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". Therefore, to put the equation in standard form it is important to find \
a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, z, t)\)]],
  " that matches these boundary conditions but remains smooth in the interior \
of the domain. Use the solution of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = \[Rho](t)\)]],
  " with the appropriate discontinuous boundary conditions, choosing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](t)\)]],
  " so as to satisfy the Gauss's law constraint condition on problems with \
von Neumann boundary conditions.]"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Taking ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1, \ \(\(\[Omega]\_o\)\(=\)\(10\)\(\ \)\)\)]],
  ", and keeping 15 normal modes in the",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(r\)\)\)]],
  "-dimension and ",
  Cell[BoxData[
      \(TraditionalForm\`6\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-dimension,  animate ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["p",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " plane  for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0\)\(\[LessEqual]\)\(\ \)\(t\)\(\[LessEqual]\)\(\
\ \)\(2\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(28)",
    FontWeight->"Bold"],
  " A solid sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is concentric with a larger hollow sphere of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ". At ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = 0\)\)\)]],
  ", the smaller sphere begins to move  up and down along the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis, according to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["z",
                  FontSlant->"Italic"]}]], "(", "t", ")"}], 
          "=", \(\(z\_0\) sin\ \(\[Omega]\_o\) t\)}], TraditionalForm]]],
  ".   Assume potential flow",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  ", and also assume  a free-slip boundary condition at the surface of the \
spheres, so that the boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`r = a\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], "\[CenterDot]", 
              StyleBox["\[Eta]",
                FontWeight->"Bold"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[\( | \_\(r = a\)\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                RowBox[{
                  StyleBox["\[Delta]",
                    FontWeight->"Plain"], 
                  StyleBox["z",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]}]], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["cos",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["\[Theta]",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", and at ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\)]],
  ",  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], "\[CenterDot]", 
              StyleBox["\[Eta]",
                FontWeight->"Bold"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[\( | \_\(r = R\)\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "  (The fluid is allowed to slip along the sphere's surface, but cannot go \
through the surface.) Find the resulting pressure distribution in the cavity \
between the spheres, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "(", \(r, \[Theta], t\), ")"}], 
        TraditionalForm]]],
  ", in spherical coordinates, by solving for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, \[Theta], t)\)]],
  " with the appropriate von Neumann boundary conditions, and applying Eq. ",
  ButtonBox["(4.4.40)",
    ButtonData:>"(4.4.40)",
    ButtonStyle->"Hyperlink"],
  ".  Plot ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["p",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " vs. time in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, z)\)\)]],
  " plane for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c = 1\), ",", " ", \(a = 1\), ",", " ", \(R = 3\), ",", " ",
           
          RowBox[{"and", " ", Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`\[Omega]\_o = 2\ \[Pi]\)]]]]}]}], 
        TraditionalForm]]],
  ", and keeping the first 10 radial eigenmodes. (The mode frequencies must \
be determined numerically using ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".)  "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:43"}],

Cell[TextData[{
  "R. Courant and D. Hilbert, ",
  StyleBox["Methods of Mathematical Physics,",
    FontSlant->"Italic"],
  " ",
  StyleBox["Vol. 1",
    FontSlant->"Italic"],
  " (Wiley Interscience, New York, 1953)."
}], "Text"],

Cell[TextData[{
  "G. D. Garland, ",
  StyleBox["Introduction to Geophysics, ",
    FontSlant->"Italic"],
  "2nd ed",
  StyleBox[". ",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "(W.B. Saunders, Philadelphia, 1979)."
}], "Text"],

Cell[TextData[{
  "A. Goriely and T. MacMillan, ",
  StyleBox["Shape of a cracking whip",
    FontSlant->"Italic"],
  ", Phys. Rev. Lett. ",
  StyleBox["88",
    FontWeight->"Bold"],
  ", 244301 (2002)."
}], "Text"],

Cell[TextData[{
  "H. Lamb, ",
  StyleBox["Hydrodynamics",
    FontSlant->"Italic"],
  ", 6th ed. (Dover, New York, 1932)."
}], "Text"],

Cell[TextData[{
  "L. D. Landau and E.M. Lifshitz, ",
  StyleBox["Fluid Mechanics",
    FontSlant->"Italic"],
  " (Pergamon, London, 1959)."
}], "Text"],

Cell[TextData[{
  "L. D. Landau and E.M. Lifshitz, ",
  StyleBox["Theory of Elasticity",
    FontSlant->"Italic"],
  " (Pergamon, Oxford, 1986)."
}], "Text"],

Cell[TextData[{
  "A. E. H. Love, ",
  StyleBox["A Treatise on the Mathematical Theory of Elasticity",
    FontSlant->"Italic"],
  " 4th ed. (Dover, New York, 1944)."
}], "Text"],

Cell[TextData[{
  "P. M. Morse and H. Feshbach, ",
  StyleBox["Methods of Theoretical Physics ",
    FontSlant->"Italic"],
  "(McGraw-Hill, New York, 1953)."
}], "Text"],

Cell[TextData[{
  "Larry Niven, ",
  StyleBox["Neutron Star",
    FontSlant->"Italic"],
  ",",
  " (Ballantine Books, New York, 1968)."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, 9999},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 4, Section 4.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 121, "IndexEntries" -> {{"i:108", \
"Liouville, Joseph"}, {"i:108", "Sturm, Jacques"}, {"i:112", "Schmidt, \
Erhard"}, {"i:114", "Bohr radius"}, {"i:116", "damped h o "}, {"i:117", "Skin \
depth"}, {"i:13", "Hermitian operators"}, {"i:22", "Laguerre, Edmond N."}, \
{"i:26", "Hermite, Charles"}, {"i:27", "Chebyshev, Pafnuty L."}, {"i:42", \
"Whipcrack"}, {"i:43", "Skipping rope"}, {"i:50", "Bow"}, {"i:52", "Poisson's \
equation"}, {"i:53", "Gauss' law"}, {"i:6", "Gram-Schmidt method"}, {"i:8", \
"Orthogonal polynomials"}, {"i:80", "Debye length"}, {"i:85", "Tidal \
acceleration"}, {"i:86", "Niven, Larry"}, {"i:87", "Tidal deformation of \
earth"}, {"i:9", "Legendre, Adrien-Marie"}, {"i:93", "Tidal deformation of \
earth"}, {"i:95", "Blackbody"}, {"i:1", "Orthogonality", "for general \
functions, in terms of inner products"}, {"i:10", "Fourier series", \
"generalized"}, {"i:102", "Eigenmodes", "in a coffee cup"}, {"i:106", \
"Shroedinger's equation", {"eigenmodes ", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes"}}, {"i:107", "Poisson's equation", {{"eigenmodes \
(", 
  StyleBox[ "see also", FontSlant -> Italic], " Laplacian operator ( "}, 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], "))"}}, {"i:108", "Hermite", "Charles"}, \
{"i:109", "Potential", {"electrostatic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Laplace's equation, Poisson's equation)"}}, {"i:11", "Fourier \
series", "completeness"}, {"i:110", "Potential", "gravitational"}, {"i:111", \
"Potential", "Coulomb"}, {"i:115", "Boundary conditions", "homogeneous, for \
Sturm-Liouville problems"}, {"i:118", "boundary conditions", \
"time-dependent"}, {"i:119", "boundary conditions", "time-dependent"}, \
{"i:12", "Eigenmodes", {"of Hermitian operators (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Sturm-Liouville problems)"}}, {"i:120", "Coordinates", \
"separable"}, {"i:15", "Hermitian operators", "orthogonality of eigenmodes, \
reality of eigenvalues"}, {"i:16", "Hermitian operators", "completeness of \
eigenmodes"}, {"i:2", "Convergence", "in the mean"}, {"i:20", \
"Orthogonality", "of eigenmodes of the adjoint operator"}, {"i:23", \
"Orthogonal polynomials", "Laguerre"}, {"i:26", "Orthogonal polynomials", \
"Hermite"}, {"i:27", "Orthogonal polynomials", "Chebyshev"}, {"i:28", \
"Shroedinger's equation", "time independent"}, {"i:3", "Fourier series", \
"generalized"}, {"i:30", "Orthogonal polynomials", "Hermite"}, {"i:34", \
"Bessel functions", "as solutions of a Sturm-Liouville problem"}, {"i:35", \
"Partial differential equations", "standard form"}, {"i:37", "Boundary \
conditions", "arbitrary (possibly time-dependent)"}, {"i:41", "Bessel \
functions", "as eigenmodes of a hanging string"}, {"i:44", "Wave equation", \
"biharmonic"}, {"i:45", "Equilibrium", "of horizontal rod in gravity"}, \
{"i:49", "Eigenmodes", "in a water channel of nonuniform depth"}, {"i:51", \
"Eigenmodes", "of a tidal estuary"}, {"i:54", "Partial differential \
equations", "standard form"}, {"i:54", "Poisson's equation", "standard \
form"}, {"i:59", "Poisson's equation", "general solution via Green's \
function"}, {"i:60", "Poisson's equation", "general solution via generalized \
Fourier series"}, {"i:62", "Poisson's equation", "uniqueness of solution"}, \
{"i:63", "Eigenmodes", {"of ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], TraditionalForm]]], {" (", 
  StyleBox[ "see also", FontSlant -> Italic], " Laplacian operator "}, 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}}, {"i:65", {"Laplacian operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "eigenmodes in cylindrical geometry"}, \
{"i:66", {"Laplacian operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "eigenmodes in spherical geometry"}, \
{"i:67", "Laplace's equation", "eigenmode vs. direct solution methods"}, \
{"i:69", "Bessel functions", "spherical"}, {"i:7", "Orthogonality", \
"orthogonal sets of functions via Gram-Schmidt method"}, {"i:71", "Partial \
differential equations", "Helmholtz equation"}, {"i:72", {"Laplacian operator \
( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "as a Hermitian operator"}, {"i:73", \
"Orthogonality", {"of eigenmodes of ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]]}}, {"i:76", "Poisson's equation", "existence of \
solution"}, {"i:78", "Spherical harmonics", {"in spherical eigenmodes of ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]]}}, {"i:79", "Laplace's equation", "alternate forms \
for solution"}, {"i:83", "Multipole moments", "form near the origin"}, \
{"i:83", "Poisson's equation", "solution in terms of multipole moments"}, \
{"i:83", "Spherical harmonics", "in multipole expansions"}, {"i:84", \
"Poisson's equation", "solution in terms of multipole moments"}, {"i:84", \
"Spherical harmonics", "in multipole expansions"}, {"i:87", "Equilibrium", \
"deformation of earth"}, {"i:88", "Wave equation", "multidimensional"}, \
{"i:89", "Heat equation", "mulitdimensional"}, {"i:9", "Orthogonal \
polynomials", "Legendre"}, {"i:90", "Eigenmodes", "of a circular drumhead"}, \
{"i:92", "Eigenmodes", "of the ocean"}, {"i:94", "Energy", "of waves on a \
drumhead"}, {"i:96", "Eigenmodes", "of a quantum dot"}, {"i:97", \
"Eigenmodes", "of the hydrogen atom"}, {"i:99", "Eigenmodes", "of a rubber \
ball"}, {"i:100", "Potential", "flow", ""}, {"i:103", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "shallow water", ""}, {"i:105", "Heat \
equation", {"eigenmodes (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Eigenmodes, Eigenvalue problem)"}, ""}, {"i:105", "Wave \
equation", {"eigenmodes (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Eigenmodes, Eigenvalue problem)"}, ""}, {"i:108", \
{"Sturm-Liouville problems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Hermitian operators)"}, "", ""}, {"i:112", "Gram, Jorgen P.", \
"", ""}, {"i:113", "Boundary conditions", {"continuous vs. discontinuous (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Galerkin method, Boundary curves)"}, ""}, {"i:12", "Linear \
ODEs", {"eigenmodes (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Eigenmodes, Eigenvalue problem)"}, ""}, {"i:13", \
"Differential operators", {"Hermitian (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Hermitian operators)"}, ""}, {"i:14", {"Sturm-Liouville \
problems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Hermitian operators)"}, "", ""}, {"i:15", "Orthogonality", "of \
eigenmodes of Hermitian operators", ""}, {"i:17", "Differential operators", \
"non-Hermitian", ""}, {"i:18", "Differential operators", "adjoint", ""}, \
{"i:19", "Differential operators", {"self-adjoint (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Hermitian)"}, ""}, {"i:21", "Fourier coefficients", \
"generalized, equation for", ""}, {"i:22", "Orthogonal polynomials", \
"Laguerre", ""}, {"i:24", "Orthogonal polynomials", "Legendre", ""}, {"i:25", \
"Orthogonal polynomials", "Hermite", ""}, {"i:28", "Energy", {"levels (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Shroedinger equation, Eigenmodes)"}, ""}, {"i:29", \
"Eigenmodes", "for quantum harmonic oscillator", ""}, {"i:29", {"Harmonic \
oscillator (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Ordinary differential equations, Linear ODEs)"}, "quantum \
eigenmodes", ""}, {"i:31", "Eigenmodes", "for quantum particle in gravity", \
""}, {"i:32", "Eigenmodes", "for electron in a periodic lattice", ""}, \
{"i:33", "Eigenmodes", "for quantum particle in a box", ""}, {"i:36", "Wave \
equation", "general solution for arbitrary source, b.c.'s", ""}, {"i:38", \
"Partial differential equations", {"linear, general solution using operator \
eigenmodes (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes, Hermitian operators)"}, ""}, {"i:39", "Energy", \
"conservation, in wave equation", ""}, {"i:4", {"Inner product (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Hermitian operators, Orthogonality)"}, "", ""}, {"i:44", \
"Eigenmodes", "transverse, for elastic rod", ""}, {"i:46", "Eigenmodes", \
"compressional, for elastic rod", ""}, {"i:47", {"Waves (", 
  StyleBox[ "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"sound (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Speed of sound, Wave speed, Sound)"}, ""}, {"i:47", {"Wave \
speed (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Phase velocity, Group velocity)"}, {"for sound waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Speed of sound)"}, ""}, {"i:48", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "shallow water", ""}, {"i:5", {"Inner product \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Hermitian operators, Orthogonality)"}, "properties", ""}, \
{"i:52", "Partial differential equations", {"Poisson's equation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Poisson's equation)"}, ""}, {"i:55", "Green's function(s)", \
"definition, for Poisson's equation", ""}, {"i:56", "Green's function(s)", \
"for a charge in free space", ""}, {"i:57", "Green's function(s)", "expansion \
in terms of operator eigenmodes", ""}, {"i:58", "Bilinear equation", "", ""}, \
{"i:61", "Poisson's equation", "existence of solution", ""}, {"i:64", \
{"Laplacian operator ( ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], ")"}, "eigenmodes in rectangular geometry", ""}, \
{"i:68", "Bessel functions", {"as cylindrical radial eigenmodes of ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]]}, ""}, {"i:70", "Orthogonality", "of spherical \
Bessel functions", ""}, {"i:77", "Green's function(s)", {"of ", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SuperscriptBox[ "\[Del]", "2"], 
        TraditionalForm]]], " in an infinite conducting tube"}, ""}, {"i:81", \
"Green's function(s)", "within a spherical conducting shell", ""}, {"i:82", \
"Multipole moments", "form far from the origin", ""}, {"i:91", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "travelling, on a drumhead", ""}, {"i:98", \
"Eigenmodes", "of a rubber ball", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(4.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 57, 1, 69, "Title",
      CellTags->"c:1"]},
  "i:3"->{
    Cell[1828, 59, 78, 1, 39, "Subtitle",
      CellTags->{"i:3", "c:2"}]},
  "c:2"->{
    Cell[1828, 59, 78, 1, 39, "Subtitle",
      CellTags->{"i:3", "c:2"}]},
  "i:108"->{
    Cell[2677, 79, 1261, 38, 78, "Text",
      CellTags->"i:108"]},
  "c:4"->{
    Cell[4610, 136, 87, 1, 41, "Subsubtitle",
      CellTags->"c:4"]},
  "i:4"->{
    Cell[4722, 141, 99, 2, 70, "Section",
      CellTags->{"i:4", "c:5"}]},
  "c:5"->{
    Cell[4722, 141, 99, 2, 70, "Section",
      CellTags->{"i:4", "c:5"}]},
  "(4.1.1)"->{
    Cell[6880, 215, 242, 8, 70, "NE2",
      CellTags->"(4.1.1)"]},
  "i:1"->{
    Cell[7125, 225, 705, 20, 70, "Text",
      CellTags->"i:1"]},
  "i:5"->{
    Cell[7833, 247, 165, 4, 70, "Text",
      CellTags->"i:5"]},
  "(4.1.2)"->{
    Cell[8001, 253, 132, 5, 70, "NE2",
      CellTags->"(4.1.2)"]},
  "(4.1.3)"->{
    Cell[8491, 272, 117, 2, 70, "NE2",
      CellTags->"(4.1.3)"]},
  "(4.1.4)"->{
    Cell[8902, 288, 166, 6, 70, "NE2",
      CellTags->"(4.1.4)"]},
  "(4.1.5)"->{
    Cell[9301, 306, 285, 8, 70, "NE2",
      CellTags->"(4.1.5)"]},
  "(4.1.6)"->{
    Cell[9977, 332, 298, 10, 70, "NE2",
      CellTags->"(4.1.6)"]},
  "i:6"->{
    Cell[10981, 374, 124, 2, 70, "Section",
      CellTags->{"i:6", "c:6"}]},
  "c:6"->{
    Cell[10981, 374, 124, 2, 70, "Section",
      CellTags->{"i:6", "c:6"}]},
  "i:7"->{
    Cell[11108, 378, 783, 24, 70, "Text",
      CellTags->"i:7"]},
  "i:112"->{
    Cell[12969, 437, 1247, 34, 70, "Text",
      CellTags->"i:112"]},
  "i:8"->{
    Cell[17594, 592, 130, 4, 70, "Text",
      CellTags->"i:8"]},
  "(4.1.7)"->{
    Cell[17727, 598, 217, 8, 70, "NE2",
      CellTags->"(4.1.7)"]},
  "Cell 4.1"->{
    Cell[19519, 663, 522, 10, 70, "Input",
      CellTags->"Cell 4.1"]},
  "Cell 4.2"->{
    Cell[20733, 704, 407, 9, 70, "Input",
      CellTags->"Cell 4.2"]},
  "i:9"->{
    Cell[21360, 726, 1211, 39, 70, "Text",
      CellTags->"i:9"]},
  "Cell 4.3"->{
    Cell[22596, 769, 156, 4, 70, "Input",
      CellTags->"Cell 4.3"]},
  "Fig. 4.1"->{
    Cell[84271, 2302, 316, 9, 70, "Caption",
      CellTags->"Fig. 4.1"]},
  "(4.1.8)"->{
    Cell[84854, 2322, 218, 7, 70, "NE2",
      CellTags->"(4.1.8)"]},
  "Cell 4.4"->{
    Cell[85467, 2345, 197, 5, 70, "Input",
      CellTags->"Cell 4.4"]},
  "c:7"->{
    Cell[86788, 2391, 78, 1, 30, "Subsubtitle",
      CellTags->"c:7"]},
  "i:10"->{
    Cell[86869, 2394, 495, 15, 44, "Text",
      CellTags->"i:10"]},
  "(4.1.9)"->{
    Cell[87367, 2411, 185, 4, 28, "NE2",
      CellTags->"(4.1.9)"]},
  "i:21"->{
    Cell[87555, 2417, 657, 20, 61, "Text",
      CellTags->"i:21"]},
  "(4.1.10)"->{
    Cell[88215, 2439, 188, 6, 29, "NE2",
      CellTags->"(4.1.10)"]},
  "(4.1.11)"->{
    Cell[88688, 2458, 168, 6, 29, "NE2",
      CellTags->"(4.1.11)"]},
  "Cell 4.5"->{
    Cell[90217, 2507, 237, 5, 105, "Input",
      CellTags->"Cell 4.5"]},
  "Cell 4.6"->{
    Cell[90845, 2527, 148, 4, 69, "Input",
      CellTags->"Cell 4.6"]},
  "Cell 4.7"->{
    Cell[91258, 2544, 386, 9, 145, "Input",
      CellTags->"Cell 4.7"]},
  "Cell 4.8"->{
    Cell[204913, 5322, 782, 16, 280, "Input",
      CellTags->"Cell 4.8"]},
  "i:11"->{
    Cell[296467, 7579, 495, 14, 61, "Text",
      CellTags->"i:11"]},
  "c:8"->{
    Cell[297472, 7610, 81, 1, 30, "Subsubtitle",
      CellTags->"c:8"]},
  "i:13"->{
    Cell[297578, 7615, 96, 1, 42, "Section",
      CellTags->{"i:13", "c:9"}]},
  "c:9"->{
    Cell[297578, 7615, 96, 1, 42, "Section",
      CellTags->{"i:13", "c:9"}]},
  "(4.1.12)"->{
    Cell[298322, 7642, 344, 12, 34, "NE2",
      CellTags->"(4.1.12)"]},
  "(4.1.13)"->{
    Cell[298934, 7666, 260, 7, 41, "NE2",
      CellTags->"(4.1.13)"]},
  "i:14"->{
    Cell[299782, 7697, 841, 26, 61, "Text",
      CellTags->"i:14"]},
  "(4.1.14)"->{
    Cell[300733, 7730, 252, 8, 34, "NE2",
      CellTags->"(4.1.14)"]},
  "i:115"->{
    Cell[300988, 7740, 621, 18, 65, "Text",
      CellTags->"i:115"]},
  "(4.1.15)"->{
    Cell[303253, 7818, 3070, 79, 148, "NE2",
      CellTags->"(4.1.15)"]},
  "i:116"->{
    Cell[307045, 7920, 433, 10, 49, "Text",
      CellTags->"i:116"]},
  "(4.1.16)"->{
    Cell[307481, 7932, 319, 9, 38, "NE2",
      CellTags->"(4.1.16)"]},
  "(4.1.17)"->{
    Cell[308847, 7974, 425, 11, 44, "NE2",
      CellTags->"(4.1.17)"]},
  "i:12"->{
    Cell[310490, 8026, 59, 1, 31, "Section",
      CellTags->{"i:12", "c:10"}]},
  "c:10"->{
    Cell[310490, 8026, 59, 1, 31, "Section",
      CellTags->{"i:12", "c:10"}]},
  "(4.1.18)"->{
    Cell[310976, 8041, 137, 3, 70, "NE2",
      CellTags->"(4.1.18)"]},
  "i:15"->{
    Cell[311453, 8055, 2112, 53, 70, "Text",
      CellTags->"i:15"]},
  "(4.1.19)"->{
    Cell[313894, 8121, 236, 7, 70, "NE2",
      CellTags->"(4.1.19)"]},
  "(4.1.20)"->{
    Cell[314837, 8157, 308, 8, 70, "NE2",
      CellTags->"(4.1.20)"]},
  "(4.1.21)"->{
    Cell[315687, 8191, 176, 6, 70, "NE2",
      CellTags->"(4.1.21)"]},
  "i:34"->{
    Cell[318100, 8268, 534, 17, 70, "Text",
      CellTags->"i:34"]},
  "c:11"->{
    Cell[320022, 8333, 51, 1, 31, "Section",
      CellTags->"c:11"]},
  "i:16"->{
    Cell[320076, 8336, 790, 21, 99, "Text",
      CellTags->"i:16"]},
  "(4.1.22)"->{
    Cell[322483, 8403, 184, 6, 29, "NE2",
      CellTags->"(4.1.22)"]},
  "i:2"->{
    Cell[322670, 8411, 466, 16, 44, "Text",
      CellTags->"i:2"]},
  "(4.1.23)"->{
    Cell[323139, 8429, 215, 7, 34, "NE2",
      CellTags->"(4.1.23)"]},
  "i:17"->{
    Cell[324410, 8469, 96, 1, 30, "Subsubtitle",
      CellTags->{"i:17", "c:12"}]},
  "c:12"->{
    Cell[324410, 8469, 96, 1, 30, "Subsubtitle",
      CellTags->{"i:17", "c:12"}]},
  "i:18"->{
    Cell[326019, 8515, 355, 12, 70, "Text",
      CellTags->"i:18"]},
  "(4.1.24)"->{
    Cell[326377, 8529, 166, 6, 70, "NE2",
      CellTags->"(4.1.24)"]},
  "i:19"->{
    Cell[327581, 8567, 542, 18, 70, "Text",
      CellTags->"i:19"]},
  "(4.1.25)"->{
    Cell[328440, 8600, 150, 5, 70, "NE2",
      CellTags->"(4.1.25)"]},
  "(4.1.26)"->{
    Cell[328656, 8609, 150, 5, 70, "NE2",
      CellTags->"(4.1.26)"]},
  "(4.1.27)"->{
    Cell[329434, 8639, 204, 7, 70, "NE2",
      CellTags->"(4.1.27)"]},
  "(4.1.28)"->{
    Cell[329824, 8655, 135, 3, 70, "NE2",
      CellTags->"(4.1.28)"]},
  "i:20"->{
    Cell[329984, 8662, 262, 9, 70, "NE2",
      CellTags->{"i:20", "(4.1.29)"}]},
  "(4.1.29)"->{
    Cell[329984, 8662, 262, 9, 70, "NE2",
      CellTags->{"i:20", "(4.1.29)"}]},
  "(4.1.30)"->{
    Cell[330908, 8696, 181, 6, 70, "NE2",
      CellTags->"(4.1.30)"]},
  "c:13"->{
    Cell[332523, 8751, 65, 1, 30, "Subsubtitle",
      CellTags->"c:13"]},
  "i:22"->{
    Cell[332951, 8767, 506, 17, 30, "Text",
      CellTags->"i:22"]},
  "i:26"->{
    Cell[333460, 8786, 520, 17, 45, "Text",
      CellTags->"i:26"]},
  "i:27"->{
    Cell[333983, 8805, 515, 17, 48, "Text",
      CellTags->"i:27"]},
  "i:25"->{
    Cell[343224, 9137, 549, 20, 48, "Text",
      CellTags->"i:25"]},
  "i:23"->{
    Cell[343776, 9159, 504, 17, 48, "Text",
      CellTags->"i:23"]},
  "i:24"->{
    Cell[344283, 9178, 598, 20, 48, "Text",
      CellTags->"i:24"]},
  "i:33"->{
    Cell[348619, 9342, 228, 8, 27, "Text",
      CellTags->"i:33"]},
  "i:28"->{
    Cell[349395, 9371, 303, 10, 27, "Text",
      CellTags->"i:28"]},
  "(4.1.31)"->{
    Cell[349701, 9383, 139, 3, 32, "NE2",
      CellTags->"(4.1.31)"]},
  "i:106"->{
    Cell[349843, 9388, 1864, 49, 142, "Text",
      CellTags->"i:106"]},
  "i:29"->{
    Cell[351710, 9439, 235, 8, 27, "Text",
      CellTags->"i:29"]},
  "(4.1.32)"->{
    Cell[352506, 9469, 210, 7, 36, "NE2",
      CellTags->"(4.1.32)"]},
  "i:30"->{
    Cell[352719, 9478, 843, 25, 72, "Text",
      CellTags->"i:30"]},
  "i:32"->{
    Cell[355043, 9553, 1389, 38, 120, "Text",
      CellTags->"i:32"]},
  "i:31"->{
    Cell[356435, 9593, 852, 22, 95, "Text",
      CellTags->"i:31"]},
  "c:14"->{
    Cell[361069, 9761, 140, 4, 74, "Subtitle",
      CellTags->"c:14"]},
  "i:37"->{
    Cell[361231, 9769, 713, 18, 95, "Text",
      CellTags->"i:37"]},
  "c:16"->{
    Cell[362162, 9797, 74, 1, 41, "Subsubtitle",
      CellTags->"c:16"]},
  "(4.2.1)"->{
    Cell[362404, 9807, 297, 7, 40, "NE3",
      CellTags->"(4.2.1)"]},
  "i:118"->{
    Cell[362704, 9816, 720, 22, 61, "Text",
      CellTags->"i:118"]},
  "(4.2.2)"->{
    Cell[363427, 9840, 399, 13, 29, "NE3",
      CellTags->"(4.2.2)"]},
  "(4.2.3)"->{
    Cell[364518, 9881, 188, 7, 29, "NE3",
      CellTags->"(4.2.3)"]},
  "(4.2.4)"->{
    Cell[366929, 9965, 548, 16, 27, "NE3",
      CellTags->"(4.2.4)"]},
  "(4.2.5)"->{
    Cell[367512, 9985, 748, 23, 38, "NE3",
      CellTags->"(4.2.5)"]},
  "(4.2.6)"->{
    Cell[368291, 10012, 1267, 35, 38, "NE3",
      CellTags->"(4.2.6)"]},
  "(4.2.7)"->{
    Cell[370051, 10069, 830, 23, 38, "NE3",
      CellTags->"(4.2.7)"]},
  "(4.2.8)"->{
    Cell[371019, 10101, 263, 8, 38, "NE3",
      CellTags->"(4.2.8)"]},
  "i:35"->{
    Cell[371285, 10111, 1135, 31, 95, "Text",
      CellTags->"i:35"]},
  "(4.2.9)"->{
    Cell[372611, 10150, 314, 8, 45, "NE3",
      CellTags->"(4.2.9)"]},
  "(4.2.10)"->{
    Cell[372955, 10162, 404, 13, 29, "NE3",
      CellTags->"(4.2.10)"]},
  "(4.2.11)"->{
    Cell[373806, 10196, 816, 20, 45, "NE3",
      CellTags->"(4.2.11)"]},
  "(4.2.12)"->{
    Cell[374805, 10225, 352, 9, 45, "NE3",
      CellTags->"(4.2.12)"]},
  "c:17"->{
    Cell[375585, 10250, 104, 2, 30, "Subsubtitle",
      CellTags->"c:17"]},
  "c:18"->{
    Cell[375714, 10256, 77, 1, 42, "Section",
      CellTags->"c:18"]},
  "i:38"->{
    Cell[375794, 10259, 362, 9, 44, "Text",
      CellTags->"i:38"]},
  "(4.2.13)"->{
    Cell[376159, 10270, 625, 19, 42, "NE3",
      CellTags->"(4.2.13)"]},
  "(4.2.14)"->{
    Cell[376901, 10298, 701, 20, 41, "NE3",
      CellTags->"(4.2.14)"]},
  "i:105"->{
    Cell[377605, 10320, 155, 6, 27, "Text",
      CellTags->"i:105"]},
  "(4.2.15)"->{
    Cell[377763, 10328, 191, 6, 33, "NE3",
      CellTags->"(4.2.15)"]},
  "(4.2.16)"->{
    Cell[378459, 10354, 400, 11, 29, "NE3",
      CellTags->"(4.2.16)"]},
  "(4.2.17)"->{
    Cell[379295, 10384, 220, 7, 34, "NE3",
      CellTags->"(4.2.17)"]},
  "(4.2.18)"->{
    Cell[379936, 10408, 562, 11, 42, "NE3",
      CellTags->"(4.2.18)"]},
  "(4.2.19)"->{
    Cell[380999, 10439, 329, 8, 46, "NE3",
      CellTags->"(4.2.19)"]},
  "(4.2.20)"->{
    Cell[381391, 10451, 234, 7, 30, "NE3",
      CellTags->"(4.2.20)"]},
  "(4.2.21)"->{
    Cell[381984, 10476, 585, 16, 45, "NE3",
      CellTags->"(4.2.21)"]},
  "(4.2.22)"->{
    Cell[382751, 10502, 295, 9, 49, "NE3",
      CellTags->"(4.2.22)"]},
  "i:36"->{
    Cell[383635, 10535, 333, 8, 30, "NE3",
      CellTags->{"i:36", "(4.2.23)"}]},
  "(4.2.23)"->{
    Cell[383635, 10535, 333, 8, 30, "NE3",
      CellTags->{"i:36", "(4.2.23)"}]},
  "(4.2.24)"->{
    Cell[384633, 10571, 270, 8, 30, "NE3",
      CellTags->"(4.2.24)"]},
  "(4.2.25)"->{
    Cell[385401, 10596, 173, 6, 42, "NE3",
      CellTags->"(4.2.25)"]},
  "(4.2.26)"->{
    Cell[386154, 10625, 404, 9, 39, "NE3",
      CellTags->"(4.2.26)"]},
  "(4.2.27)"->{
    Cell[386707, 10643, 308, 8, 38, "NE3",
      CellTags->"(4.2.27)"]},
  "c:19"->{
    Cell[387737, 10676, 50, 1, 31, "Section",
      CellTags->"c:19"]},
  "i:39"->{
    Cell[387790, 10679, 275, 6, 61, "Text",
      CellTags->"i:39"]},
  "(4.2.28)"->{
    Cell[388693, 10702, 442, 7, 50, "NE3",
      CellTags->"(4.2.28)"]},
  "(4.2.29)"->{
    Cell[392052, 10799, 162, 6, 38, "NE3",
      CellTags->"(4.2.29)"]},
  "(4.2.30)"->{
    Cell[395611, 10913, 416, 13, 38, "NE3",
      CellTags->"(4.2.30)"]},
  "c:20"->{
    Cell[397524, 10981, 74, 1, 31, "Section",
      CellTags->"c:20"]},
  "i:119"->{
    Cell[397601, 10984, 931, 30, 78, "Text",
      CellTags->"i:119"]},
  "(4.2.31)"->{
    Cell[398693, 11023, 188, 6, 42, "NE3",
      CellTags->"(4.2.31)"]},
  "(4.2.32)"->{
    Cell[399590, 11052, 172, 6, 35, "NE3",
      CellTags->"(4.2.32)"]},
  "(4.2.33)"->{
    Cell[400526, 11087, 712, 21, 42, "NE3",
      CellTags->"(4.2.33)"]},
  "(4.2.34)"->{
    Cell[401895, 11131, 283, 8, 42, "NE3",
      CellTags->"(4.2.34)"]},
  "(4.2.35)"->{
    Cell[402509, 11153, 208, 6, 42, "NE3",
      CellTags->"(4.2.35)"]},
  "(4.2.36)"->{
    Cell[403088, 11173, 144, 5, 29, "NE3",
      CellTags->"(4.2.36)"]},
  "(4.2.37)"->{
    Cell[403277, 11182, 269, 9, 32, "NE3",
      CellTags->"(4.2.37)"]},
  "(4.2.38)"->{
    Cell[403895, 11207, 387, 11, 28, "NE3",
      CellTags->"(4.2.38)"]},
  "(4.2.39)"->{
    Cell[404989, 11246, 349, 9, 42, "NE3",
      CellTags->"(4.2.39)"]},
  "Cell 4.9"->{
    Cell[405782, 11274, 344, 8, 143, "Input",
      CellTags->"Cell 4.9"]},
  "(4.2.40)"->{
    Cell[406366, 11296, 307, 8, 40, "NE3",
      CellTags->"(4.2.40)"]},
  "Cell 4.10"->{
    Cell[407740, 11344, 370, 7, 160, "Input",
      CellTags->"Cell 4.10"]},
  "Cell 4.11"->{
    Cell[408865, 11378, 192, 5, 86, "Input",
      CellTags->"Cell 4.11"]},
  "Cell 4.12"->{
    Cell[410435, 11433, 98, 3, 67, "Input",
      CellTags->"Cell 4.12"]},
  "Cell 4.13"->{
    Cell[410953, 11454, 258, 6, 105, "Input",
      CellTags->"Cell 4.13"]},
  "Cell 4.14"->{
    Cell[411845, 11488, 528, 12, 185, "Input",
      CellTags->"Cell 4.14"]},
  "c:21"->{
    Cell[2107830, 62451, 67, 1, 31, "Section",
      CellTags->"c:21"]},
  "(4.2.41)"->{
    Cell[2109022, 62487, 252, 7, 43, "NE3",
      CellTags->"(4.2.41)"]},
  "(4.2.42)"->{
    Cell[2110197, 62521, 175, 6, 29, "NE3",
      CellTags->"(4.2.42)"]},
  "(4.2.43)"->{
    Cell[2110418, 62531, 262, 7, 39, "NE3",
      CellTags->"(4.2.43)"]},
  "(4.2.44)"->{
    Cell[2111129, 62557, 289, 8, 57, "NE3",
      CellTags->"(4.2.44)"]},
  "Cell 4.15"->{
    Cell[2111565, 62576, 190, 5, 70, "Input",
      CellTags->"Cell 4.15"]},
  "(4.2.45)"->{
    Cell[2112669, 62615, 146, 5, 70, "NE3",
      CellTags->"(4.2.45)"]},
  "i:41"->{
    Cell[2112863, 62624, 187, 6, 70, "NE3",
      CellTags->{"i:41", "(4.2.46)"}]},
  "(4.2.46)"->{
    Cell[2112863, 62624, 187, 6, 70, "NE3",
      CellTags->{"i:41", "(4.2.46)"}]},
  "Cell 4.16"->{
    Cell[2113246, 62642, 584, 12, 70, "Input",
      CellTags->"Cell 4.16"]},
  "Cell 4.17"->{
    Cell[2156595, 63642, 1159, 26, 400, "Input",
      CellTags->"Cell 4.17"]},
  "Cell 4.18"->{
    Cell[2295254, 72313, 1401, 31, 428, "Input",
      CellTags->"Cell 4.18"]},
  "i:42"->{
    Cell[3374156, 98883, 496, 10, 78, "Text",
      CellTags->"i:42"]},
  "Cell 4.19"->{
    Cell[3375183, 98909, 255, 5, 86, "Input",
      CellTags->"Cell 4.19"]},
  "Ex. 4.2"->{
    Cell[3416965, 99933, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 4.2", "c:22"}]},
  "c:22"->{
    Cell[3416965, 99933, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 4.2", "c:22"}]},
  "i:117"->{
    Cell[3421732, 100082, 656, 20, 64, "Text",
      CellTags->"i:117"]},
  "i:43"->{
    Cell[3424612, 100172, 1546, 47, 107, "Text",
      CellTags->"i:43"]},
  "i:46"->{
    Cell[3431751, 100398, 506, 15, 61, "Text",
      CellTags->"i:46"]},
  "i:44"->{
    Cell[3433664, 100463, 445, 15, 44, "Text",
      CellTags->"i:44"]},
  "(4.2.47)"->{
    Cell[3434112, 100480, 239, 4, 45, "NE3",
      CellTags->"(4.2.47)"]},
  "i:45"->{
    Cell[3436056, 100547, 633, 20, 61, "Text",
      CellTags->"i:45"]},
  "(4.2.48)"->{
    Cell[3436837, 100575, 249, 7, 42, "NE3",
      CellTags->"(4.2.48)"]},
  "i:47"->{
    Cell[3437447, 100596, 152, 5, 33, "NE3",
      CellTags->{"i:47", "(4.2.49)"}]},
  "(4.2.49)"->{
    Cell[3437447, 100596, 152, 5, 33, "NE3",
      CellTags->{"i:47", "(4.2.49)"}]},
  "(4.2.50)"->{
    Cell[3440593, 100712, 192, 6, 29, "NE3",
      CellTags->"(4.2.50)"]},
  "i:48"->{
    Cell[3440847, 100722, 557, 15, 42, "NE3",
      CellTags->{"i:48", "(4.2.51)"}]},
  "(4.2.51)"->{
    Cell[3440847, 100722, 557, 15, 42, "NE3",
      CellTags->{"i:48", "(4.2.51)"}]},
  "Fig. 4.2"->{
    Cell[5629375, 130847, 65, 1, 16, "Caption",
      CellTags->"Fig. 4.2"]},
  "i:49"->{
    Cell[5629443, 130850, 303, 9, 44, "Text",
      CellTags->"i:49"]},
  "i:51"->{
    Cell[5631708, 130933, 883, 26, 78, "Text",
      CellTags->"i:51"]},
  "Fig. 4.3"->{
    Cell[5644310, 131128, 66, 1, 16, "Caption",
      CellTags->"Fig. 4.3"]},
  "i:50"->{
    Cell[5657691, 131565, 849, 24, 78, "Text",
      CellTags->"i:50"]},
  "c:23"->{
    Cell[5660672, 131663, 90, 1, 40, "Subtitle",
      CellTags->"c:23"]},
  "c:24"->{
    Cell[5660806, 131670, 91, 1, 41, "Subsubtitle",
      CellTags->"c:24"]},
  "i:52"->{
    Cell[5660900, 131673, 286, 9, 27, "Text",
      CellTags->"i:52"]},
  "(4.3.1)"->{
    Cell[5661189, 131684, 146, 5, 32, "NE4",
      CellTags->"(4.3.1)"]},
  "i:109"->{
    Cell[5661338, 131691, 1548, 46, 81, "Text",
      CellTags->"i:109"]},
  "i:62"->{
    Cell[5662889, 131739, 549, 16, 61, "Text",
      CellTags->"i:62"]},
  "i:53"->{
    Cell[5663441, 131757, 1224, 36, 63, "Text",
      CellTags->"i:53"]},
  "(4.3.2)"->{
    Cell[5664668, 131795, 577, 18, 34, "NE4",
      CellTags->"(4.3.2)"]},
  "i:54"->{
    Cell[5665824, 131833, 348, 9, 44, "Text",
      CellTags->"i:54"]},
  "(4.3.3)"->{
    Cell[5666175, 131844, 1378, 45, 29, "NE4",
      CellTags->"(4.3.3)"]},
  "(4.3.4)"->{
    Cell[5668156, 131911, 164, 3, 31, "NE4",
      CellTags->"(4.3.4)"]},
  "(4.3.5)"->{
    Cell[5668348, 131918, 171, 6, 32, "NE4",
      CellTags->"(4.3.5)"]},
  "c:25"->{
    Cell[5669776, 131970, 65, 1, 30, "Subsubtitle",
      CellTags->"c:25"]},
  "i:55"->{
    Cell[5670812, 132008, 982, 30, 32, "NE4",
      CellTags->{"i:55", "(4.3.6)"}]},
  "(4.3.6)"->{
    Cell[5670812, 132008, 982, 30, 32, "NE4",
      CellTags->{"i:55", "(4.3.6)"}]},
  "(4.3.7)"->{
    Cell[5673346, 132094, 544, 17, 29, "NE4",
      CellTags->"(4.3.7)"]},
  "i:111"->{
    Cell[5673893, 132113, 1614, 52, 61, "Text",
      CellTags->"i:111"]},
  "i:56"->{
    Cell[5675510, 132167, 1128, 35, 41, "NE4",
      CellTags->{"i:56", "(4.3.8)"}]},
  "(4.3.8)"->{
    Cell[5675510, 132167, 1128, 35, 41, "NE4",
      CellTags->{"i:56", "(4.3.8)"}]},
  "i:59"->{
    Cell[5677404, 132229, 1518, 41, 41, "NE4",
      CellTags->{"i:59", "(4.3.9)"}]},
  "(4.3.9)"->{
    Cell[5677404, 132229, 1518, 41, 41, "NE4",
      CellTags->{"i:59", "(4.3.9)"}]},
  "(4.3.10)"->{
    Cell[5679541, 132295, 3453, 85, 43, "NE4",
      CellTags->"(4.3.10)"]},
  "(4.3.11)"->{
    Cell[5686735, 132510, 784, 23, 43, "NE4",
      CellTags->"(4.3.11)"]},
  "c:26"->{
    Cell[5687556, 132538, 183, 6, 30, "Subsubtitle",
      CellTags->"c:26"]},
  "i:107"->{
    Cell[5687742, 132546, 518, 15, 44, "Text",
      CellTags->"i:107"]},
  "(4.3.12)"->{
    Cell[5688263, 132563, 620, 19, 32, "NE4",
      CellTags->"(4.3.12)"]},
  "i:71"->{
    Cell[5688886, 132584, 770, 20, 78, "Text",
      CellTags->"i:71"]},
  "i:73"->{
    Cell[5689659, 132606, 140, 4, 27, "Text",
      CellTags->"i:73"]},
  "(4.3.13)"->{
    Cell[5689802, 132612, 665, 20, 34, "NE4",
      CellTags->"(4.3.13)"]},
  "i:72"->{
    Cell[5690470, 132634, 508, 9, 78, "Text",
      CellTags->"i:72"]},
  "(4.3.14)"->{
    Cell[5694027, 132743, 686, 21, 29, "NE4",
      CellTags->"(4.3.14)"]},
  "(4.3.15)"->{
    Cell[5698204, 132880, 559, 17, 34, "NE4",
      CellTags->"(4.3.15)"]},
  "i:57"->{
    Cell[5698766, 132899, 229, 7, 27, "Text",
      CellTags->"i:57"]},
  "(4.3.16)"->{
    Cell[5698998, 132908, 1065, 29, 45, "NE4",
      CellTags->"(4.3.16)"]},
  "i:58"->{
    Cell[5700066, 132939, 781, 22, 78, "Text",
      CellTags->"i:58"]},
  "(4.3.17)"->{
    Cell[5700850, 132963, 706, 19, 43, "NE4",
      CellTags->"(4.3.17)"]},
  "i:60"->{
    Cell[5702027, 133002, 1060, 33, 78, "Text",
      CellTags->"i:60"]},
  "i:61"->{
    Cell[5703090, 133037, 1576, 41, 132, "Text",
      CellTags->"i:61"]},
  "i:63"->{
    Cell[5706486, 133140, 174, 6, 30, "Subsubtitle",
      CellTags->{"i:63", "c:27"}]},
  "c:27"->{
    Cell[5706486, 133140, 174, 6, 30, "Subsubtitle",
      CellTags->{"i:63", "c:27"}]},
  "c:28"->{
    Cell[5706685, 133150, 51, 1, 42, "Section",
      CellTags->"c:28"]},
  "i:120"->{
    Cell[5706739, 133153, 1055, 25, 115, "Text",
      CellTags->"i:120"]},
  "c:29"->{
    Cell[5707831, 133183, 59, 1, 31, "Section",
      CellTags->"c:29"]},
  "i:64"->{
    Cell[5707915, 133188, 109, 2, 27, "Subsubsection",
      CellTags->"i:64"]},
  "Fig. 4.4"->{
    Cell[5792358, 134249, 144, 4, 16, "Caption",
      CellTags->"Fig. 4.4"]},
  "(4.3.18)"->{
    Cell[5792741, 134263, 143, 3, 27, "NE4",
      CellTags->"(4.3.18)"]},
  "(4.3.19)"->{
    Cell[5793371, 134289, 269, 8, 45, "NE4",
      CellTags->"(4.3.19)"]},
  "(4.3.20)"->{
    Cell[5793820, 134306, 189, 4, 44, "NE4",
      CellTags->"(4.3.20)"]},
  "(4.3.21)"->{
    Cell[5794012, 134312, 206, 4, 45, "NE4",
      CellTags->"(4.3.21)"]},
  "(4.3.22)"->{
    Cell[5794444, 134326, 149, 5, 29, "NE4",
      CellTags->"(4.3.22)"]},
  "(4.3.23)"->{
    Cell[5795032, 134350, 118, 5, 29, "NE4",
      CellTags->"(4.3.23)"]},
  "(4.3.24)"->{
    Cell[5795153, 134357, 200, 7, 29, "NE4",
      CellTags->"(4.3.24)"]},
  "(4.3.25)"->{
    Cell[5795507, 134374, 198, 7, 29, "NE4",
      CellTags->"(4.3.25)"]},
  "(4.3.26)"->{
    Cell[5796002, 134395, 282, 9, 38, "NE4",
      CellTags->"(4.3.26)"]},
  "(4.3.27)"->{
    Cell[5796492, 134413, 369, 12, 29, "NE4",
      CellTags->"(4.3.27)"]},
  "Cell 4.20"->{
    Cell[5799862, 134534, 517, 12, 174, "Input",
      CellTags->"Cell 4.20"]},
  "Cell 4.21"->{
    Cell[5801985, 134601, 685, 15, 254, "Input",
      CellTags->"Cell 4.21"]},
  "i:67"->{
    Cell[5913578, 136707, 137, 4, 29, "Subsubsection",
      CellTags->"i:67"]},
  "Fig. 4.5"->{
    Cell[6001154, 137815, 51, 1, 16, "Caption",
      CellTags->"Fig. 4.5"]},
  "(4.3.28)"->{
    Cell[6001798, 137833, 181, 6, 29, "NE4",
      CellTags->"(4.3.28)"]},
  "(4.3.29)"->{
    Cell[6002300, 137854, 573, 15, 49, "NE4",
      CellTags->"(4.3.29)"]},
  "(4.3.30)"->{
    Cell[6003512, 137893, 424, 9, 50, "NE4",
      CellTags->"(4.3.30)"]},
  "Cell 4.22"->{
    Cell[6004748, 137935, 602, 14, 200, "Input",
      CellTags->"Cell 4.22"]},
  "Cell 4.23"->{
    Cell[6005983, 137976, 693, 15, 250, "Input",
      CellTags->"Cell 4.23"]},
  "Cell 4.24"->{
    Cell[6209130, 141873, 116, 3, 67, "Input",
      CellTags->"Cell 4.24"]},
  "(4.3.31)"->{
    Cell[6258080, 142981, 202, 4, 28, "NE4",
      CellTags->"(4.3.31)"]},
  "(4.3.32)"->{
    Cell[6260305, 143055, 508, 12, 71, "NE4",
      CellTags->"(4.3.32)"]},
  "Cell 4.25"->{
    Cell[6261343, 143089, 743, 17, 241, "Input",
      CellTags->"Cell 4.25"]},
  "Cell 4.26"->{
    Cell[6463432, 146969, 252, 5, 86, "Input",
      CellTags->"Cell 4.26"]},
  "i:113"->{
    Cell[6512943, 148316, 604, 13, 78, "Text",
      CellTags->"i:113"]},
  "Table 4.1"->{
    Cell[6514632, 148358, 2434, 61, 206, "Text",
      CellTags->"Table 4.1"]},
  "c:30"->{
    Cell[6517115, 148425, 59, 1, 31, "Section",
      CellTags->"c:30"]},
  "i:65"->{
    Cell[6517199, 148430, 109, 2, 27, "Subsubsection",
      CellTags->"i:65"]},
  "(4.3.33)"->{
    Cell[6517870, 148454, 200, 6, 70, "NE4",
      CellTags->"(4.3.33)"]},
  "(4.3.34)"->{
    Cell[6518463, 148477, 411, 7, 70, "NE4",
      CellTags->"(4.3.34)"]},
  "(4.3.35)"->{
    Cell[6519143, 148497, 277, 7, 42, "NE4",
      CellTags->"(4.3.35)"]},
  "(4.3.36)"->{
    Cell[6519423, 148506, 203, 7, 42, "NE4",
      CellTags->"(4.3.36)"]},
  "(4.3.37)"->{
    Cell[6519629, 148515, 169, 6, 43, "NE4",
      CellTags->"(4.3.37)"]},
  "(4.3.38)"->{
    Cell[6520098, 148531, 290, 11, 29, "NE4",
      CellTags->"(4.3.38)"]},
  "(4.3.39)"->{
    Cell[6520426, 148546, 118, 5, 29, "NE4",
      CellTags->"(4.3.39)"]},
  "(4.3.40)"->{
    Cell[6520935, 148563, 292, 10, 32, "NE4",
      CellTags->"(4.3.40)"]},
  "(4.3.41)"->{
    Cell[6521621, 148587, 157, 6, 38, "NE4",
      CellTags->"(4.3.41)"]},
  "(4.3.42)"->{
    Cell[6521954, 148603, 253, 7, 42, "NE4",
      CellTags->"(4.3.42)"]},
  "(4.3.43)"->{
    Cell[6522285, 148614, 255, 7, 42, "NE4",
      CellTags->"(4.3.43)"]},
  "(4.3.44)"->{
    Cell[6523309, 148648, 237, 8, 38, "NE4",
      CellTags->"(4.3.44)"]},
  "i:68"->{
    Cell[6524223, 148686, 152, 5, 29, "NE4",
      CellTags->{"i:68", "(4.3.45)"}]},
  "(4.3.45)"->{
    Cell[6524223, 148686, 152, 5, 29, "NE4",
      CellTags->{"i:68", "(4.3.45)"}]},
  "(4.3.46)"->{
    Cell[6524539, 148700, 259, 7, 32, "NE4",
      CellTags->"(4.3.46)"]},
  "(4.3.47)"->{
    Cell[6525071, 148721, 185, 6, 46, "NE4",
      CellTags->"(4.3.47)"]},
  "(4.3.48)"->{
    Cell[6526324, 148763, 296, 7, 42, "NE4",
      CellTags->"(4.3.48)"]},
  "(4.3.49)"->{
    Cell[6527783, 148806, 218, 7, 70, "NE4",
      CellTags->"(4.3.49)"]},
  "(4.3.50)"->{
    Cell[6528365, 148828, 150, 3, 70, "NE4",
      CellTags->"(4.3.50)"]},
  "(4.3.51)"->{
    Cell[6528919, 148847, 469, 10, 70, "NE4",
      CellTags->"(4.3.51)"]},
  "Cell 4.27"->{
    Cell[6529980, 148881, 312, 7, 70, "Input",
      CellTags->"Cell 4.27"]},
  "Cell 4.28"->{
    Cell[6531268, 148923, 205, 5, 105, "Input",
      CellTags->"Cell 4.28"]},
  "Cell 4.29"->{
    Cell[6533020, 148984, 785, 16, 309, "Input",
      CellTags->"Cell 4.29"]},
  "Cell 4.30"->{
    Cell[6537388, 149117, 533, 10, 174, "Input",
      CellTags->"Cell 4.30"]},
  "c:31"->{
    Cell[6658636, 151723, 57, 1, 31, "Section",
      CellTags->"c:31"]},
  "i:66"->{
    Cell[6658718, 151728, 107, 2, 27, "Subsubsection",
      CellTags->"i:66"]},
  "(4.3.52)"->{
    Cell[6659450, 151749, 235, 7, 29, "NE4",
      CellTags->"(4.3.52)"]},
  "(4.3.53)"->{
    Cell[6659875, 151766, 565, 12, 45, "NE4",
      CellTags->"(4.3.53)"]},
  "(4.3.54)"->{
    Cell[6660800, 151794, 191, 3, 45, "NE4",
      CellTags->"(4.3.54)"]},
  "(4.3.55)"->{
    Cell[6660994, 151799, 373, 8, 42, "NE4",
      CellTags->"(4.3.55)"]},
  "(4.3.56)"->{
    Cell[6661370, 151809, 271, 7, 38, "NE4",
      CellTags->"(4.3.56)"]},
  "i:69"->{
    Cell[6663621, 151890, 113, 2, 29, "Subsubsection",
      CellTags->"i:69"]},
  "Cell 4.31"->{
    Cell[6664369, 151916, 230, 6, 86, "Input",
      CellTags->"Cell 4.31"]},
  "Table 4.2"->{
    Cell[6665826, 151960, 974, 25, 308, "Text",
      CellTags->"Table 4.2"]},
  "Table 4.3"->{
    Cell[6666803, 151987, 1093, 30, 308, "Text",
      CellTags->"Table 4.3"]},
  "Cell 4.32"->{
    Cell[6668211, 152034, 384, 8, 143, "Input",
      CellTags->"Cell 4.32"]},
  "Cell 4.33"->{
    Cell[6719012, 153384, 392, 8, 147, "Input",
      CellTags->"Cell 4.33"]},
  "(4.3.57)"->{
    Cell[6768216, 154758, 222, 7, 34, "NE4",
      CellTags->"(4.3.57)"]},
  "(4.3.58)"->{
    Cell[6769079, 154788, 164, 6, 33, "NE4",
      CellTags->"(4.3.58)"]},
  "(4.3.59)"->{
    Cell[6769886, 154820, 204, 8, 30, "NE4",
      CellTags->"(4.3.59)"]},
  "Cell 4.34"->{
    Cell[6770425, 154843, 174, 5, 105, "Input",
      CellTags->"Cell 4.34"]},
  "(4.3.60)"->{
    Cell[6771075, 154865, 462, 13, 51, "NE4",
      CellTags->"(4.3.60)"]},
  "i:70"->{
    Cell[6771720, 154888, 468, 11, 51, "NE4",
      CellTags->{"i:70", "(4.3.61)"}]},
  "(4.3.61)"->{
    Cell[6771720, 154888, 468, 11, 51, "NE4",
      CellTags->{"i:70", "(4.3.61)"}]},
  "i:78"->{
    Cell[6772531, 154913, 299, 8, 34, "NE4",
      CellTags->{"i:78", "(4.3.62)"}]},
  "(4.3.62)"->{
    Cell[6772531, 154913, 299, 8, 34, "NE4",
      CellTags->{"i:78", "(4.3.62)"}]},
  "(4.3.63)"->{
    Cell[6773861, 154957, 748, 15, 65, "NE4",
      CellTags->"(4.3.63)"]},
  "Fig. 4.6"->{
    Cell[6857998, 156034, 51, 1, 70, "Caption",
      CellTags->"Fig. 4.6"]},
  "(4.3.64)"->{
    Cell[6858468, 156051, 623, 19, 70, "NE4",
      CellTags->"(4.3.64)"]},
  "(4.3.65)"->{
    Cell[6859921, 156099, 353, 8, 70, "NE4",
      CellTags->"(4.3.65)"]},
  "(4.3.66)"->{
    Cell[6860462, 156116, 497, 8, 70, "NE4",
      CellTags->"(4.3.66)"]},
  "(4.3.67)"->{
    Cell[6861811, 156157, 377, 9, 70, "NE4",
      CellTags->"(4.3.67)"]},
  "(4.3.68)"->{
    Cell[6862776, 156192, 519, 12, 70, "NE4",
      CellTags->"(4.3.68)"]},
  "Cell 4.35"->{
    Cell[6864191, 156233, 439, 9, 70, "Input",
      CellTags->"Cell 4.35"]},
  "Cell 4.36"->{
    Cell[6865100, 156264, 232, 5, 70, "Input",
      CellTags->"Cell 4.36"]},
  "Cell 4.37"->{
    Cell[6865637, 156284, 92, 3, 70, "Input",
      CellTags->"Cell 4.37"]},
  "Cell 4.38"->{
    Cell[6866149, 156304, 2042, 44, 70, "Input",
      CellTags->"Cell 4.38"]},
  "Cell 4.39"->{
    Cell[6868576, 156365, 450, 12, 70, "Input",
      CellTags->"Cell 4.39"]},
  "Cell 4.40"->{
    Cell[6869675, 156403, 996, 20, 70, "Input",
      CellTags->"Cell 4.40"]},
  "c:32"->{
    Cell[7116329, 169405, 65, 1, 30, "Subsubtitle",
      CellTags->"c:32"]},
  "i:76"->{
    Cell[7121085, 169578, 563, 19, 44, "Text",
      CellTags->"i:76"]},
  "(4.3.69)"->{
    Cell[7123342, 169659, 1136, 33, 32, "NE4",
      CellTags->"(4.3.69)"]},
  "(4.3.70)"->{
    Cell[7125603, 169741, 759, 21, 42, "NE4",
      CellTags->"(4.3.70)"]},
  "i:77"->{
    Cell[7126685, 169779, 426, 14, 44, "Text",
      CellTags->"i:77"]},
  "(4.3.71)"->{
    Cell[7127114, 169795, 903, 24, 44, "NE4",
      CellTags->"(4.3.71)"]},
  "i:79"->{
    Cell[7133904, 170016, 289, 10, 27, "Text",
      CellTags->"i:79"]},
  "(4.3.72)"->{
    Cell[7135819, 170081, 217, 7, 29, "NE4",
      CellTags->"(4.3.72)"]},
  "Fig. 4.7"->{
    Cell[7156962, 170573, 64, 1, 16, "Caption",
      CellTags->"Fig. 4.7"]},
  "Fig. 4.8"->{
    Cell[7202528, 171160, 64, 1, 16, "Caption",
      CellTags->"Fig. 4.8"]},
  "i:80"->{
    Cell[7206413, 171297, 1268, 36, 103, "Text",
      CellTags->"i:80"]},
  "i:81"->{
    Cell[7207684, 171335, 290, 9, 44, "Text",
      CellTags->"i:81"]},
  "(4.3.73)"->{
    Cell[7207977, 171346, 1310, 36, 33, "NE4",
      CellTags->"(4.3.73)"]},
  "(4.3.74)"->{
    Cell[7209782, 171400, 695, 19, 50, "NE4",
      CellTags->"(4.3.74)"]},
  "(4.3.75)"->{
    Cell[7211307, 171451, 865, 27, 33, "NE4",
      CellTags->"(4.3.75)"]},
  "i:84"->{
    Cell[7213535, 171524, 684, 19, 44, "NE4",
      CellTags->{"i:84", "(4.3.76)"}]},
  "(4.3.76)"->{
    Cell[7213535, 171524, 684, 19, 44, "NE4",
      CellTags->{"i:84", "(4.3.76)"}]},
  "i:82"->{
    Cell[7214222, 171545, 913, 28, 50, "Text",
      CellTags->"i:82"]},
  "Fig. 4.9"->{
    Cell[7274880, 172318, 210, 7, 16, "Caption",
      CellTags->"Fig. 4.9"]},
  "i:83"->{
    Cell[7279938, 172489, 646, 19, 44, "NE4",
      CellTags->{"i:83", "(4.3.77)"}]},
  "(4.3.77)"->{
    Cell[7279938, 172489, 646, 19, 44, "NE4",
      CellTags->{"i:83", "(4.3.77)"}]},
  "Fig. 4.10"->{
    Cell[7342336, 173290, 213, 7, 16, "Caption",
      CellTags->"Fig. 4.10"]},
  "i:110"->{
    Cell[7344305, 173358, 163, 6, 32, "NE4",
      CellTags->{"i:110", "(4.3.78)"}]},
  "(4.3.78)"->{
    Cell[7344305, 173358, 163, 6, 32, "NE4",
      CellTags->{"i:110", "(4.3.78)"}]},
  "(4.3.79)"->{
    Cell[7345328, 173395, 256, 7, 34, "NE4",
      CellTags->"(4.3.79)"]},
  "i:85"->{
    Cell[7348759, 173521, 396, 14, 44, "Text",
      CellTags->"i:85"]},
  "i:86"->{
    Cell[7349591, 173552, 1806, 50, 152, "Text",
      CellTags->"i:86"]},
  "i:87"->{
    Cell[7351400, 173604, 967, 18, 129, "Text",
      CellTags->"i:87"]},
  "(4.3.80)"->{
    Cell[7353115, 173644, 220, 7, 57, "NE4",
      CellTags->"(4.3.80)"]},
  "Fig. 4.11"->{
    Cell[7424554, 174594, 136, 4, 16, "Caption",
      CellTags->"Fig. 4.11"]},
  "c:33"->{
    Cell[7424739, 174604, 99, 1, 74, "Subtitle",
      CellTags->"c:33"]},
  "i:88"->{
    Cell[7425373, 174624, 600, 16, 33, "NE5",
      CellTags->{"i:88", "(4.4.1)"}]},
  "(4.4.1)"->{
    Cell[7425373, 174624, 600, 16, 33, "NE5",
      CellTags->{"i:88", "(4.4.1)"}]},
  "i:89"->{
    Cell[7425999, 174644, 636, 19, 32, "NE5",
      CellTags->{"i:89", "(4.4.2)"}]},
  "(4.4.2)"->{
    Cell[7425999, 174644, 636, 19, 32, "NE5",
      CellTags->{"i:89", "(4.4.2)"}]},
  "c:35"->{
    Cell[7429051, 174735, 84, 1, 41, "Subsubtitle",
      CellTags->"c:35"]},
  "c:36"->{
    Cell[7429160, 174740, 56, 1, 42, "Section",
      CellTags->"c:36"]},
  "(4.4.3)"->{
    Cell[7430580, 174790, 123, 5, 29, "NE5",
      CellTags->"(4.4.3)"]},
  "(4.4.4)"->{
    Cell[7430751, 174799, 235, 4, 57, "NE5",
      CellTags->"(4.4.4)"]},
  "(4.4.5)"->{
    Cell[7431371, 174822, 230, 7, 29, "NE5",
      CellTags->"(4.4.5)"]},
  "(4.4.6)"->{
    Cell[7431800, 174839, 239, 7, 32, "NE5",
      CellTags->"(4.4.6)"]},
  "(4.4.7)"->{
    Cell[7432180, 174855, 143, 5, 29, "NE5",
      CellTags->"(4.4.7)"]},
  "(4.4.8)"->{
    Cell[7432438, 174867, 239, 7, 32, "NE5",
      CellTags->"(4.4.8)"]},
  "(4.4.9)"->{
    Cell[7433103, 174895, 155, 6, 32, "NE5",
      CellTags->"(4.4.9)"]},
  "(4.4.10)"->{
    Cell[7434453, 174938, 381, 9, 42, "NE5",
      CellTags->"(4.4.10)"]},
  "(4.4.11)"->{
    Cell[7435022, 174956, 246, 7, 42, "NE5",
      CellTags->"(4.4.11)"]},
  "(4.4.12)"->{
    Cell[7435443, 174973, 229, 7, 29, "NE5",
      CellTags->"(4.4.12)"]},
  "(4.4.13)"->{
    Cell[7435839, 174989, 144, 5, 29, "NE5",
      CellTags->"(4.4.13)"]},
  "(4.4.14)"->{
    Cell[7436577, 175021, 250, 7, 29, "NE5",
      CellTags->"(4.4.14)"]},
  "(4.4.15)"->{
    Cell[7436895, 175032, 199, 6, 29, "NE5",
      CellTags->"(4.4.15)"]},
  "(4.4.16)"->{
    Cell[7437143, 175042, 264, 8, 29, "NE5",
      CellTags->"(4.4.16)"]},
  "(4.4.17)"->{
    Cell[7437462, 175054, 490, 11, 38, "NE5",
      CellTags->"(4.4.17)"]},
  "(4.4.18)"->{
    Cell[7439362, 175112, 1003, 16, 85, "NE5",
      CellTags->"(4.4.18)"]},
  "(4.4.19)"->{
    Cell[7441441, 175161, 860, 14, 80, "NE5",
      CellTags->"(4.4.19)"]},
  "i:90"->{
    Cell[7442546, 175186, 68, 1, 31, "Section",
      CellTags->{"i:90", "c:37"}]},
  "c:37"->{
    Cell[7442546, 175186, 68, 1, 31, "Section",
      CellTags->{"i:90", "c:37"}]},
  "Cell 4.41"->{
    Cell[7444112, 175236, 638, 13, 200, "Input",
      CellTags->"Cell 4.41"]},
  "Cell 4.42"->{
    Cell[9316481, 237617, 576, 12, 162, "Input",
      CellTags->"Cell 4.42"]},
  "i:91"->{
    Cell[11292381, 300797, 76, 1, 31, "Section",
      CellTags->{"i:91", "c:38"}]},
  "c:38"->{
    Cell[11292381, 300797, 76, 1, 31, "Section",
      CellTags->{"i:91", "c:38"}]},
  "(4.4.20)"->{
    Cell[11292755, 300809, 369, 10, 32, "NE5",
      CellTags->"(4.4.20)"]},
  "Cell 4.43"->{
    Cell[11296976, 300935, 699, 15, 200, "Input",
      CellTags->"Cell 4.43"]},
  "c:39"->{
    Cell[15413279, 432497, 123, 2, 31, "Section",
      CellTags->"c:39"]},
  "(4.4.21)"->{
    Cell[15414719, 432535, 138, 5, 29, "NE5",
      CellTags->"(4.4.21)"]},
  "(4.4.22)"->{
    Cell[15416030, 432576, 735, 22, 33, "NE5",
      CellTags->"(4.4.22)"]},
  "Cell 4.44"->{
    Cell[15418718, 432658, 469, 10, 147, "Input",
      CellTags->"Cell 4.44"]},
  "i:92"->{
    Cell[15638773, 439379, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:92", "c:40"}]},
  "c:40"->{
    Cell[15638773, 439379, 82, 1, 30, "Subsubtitle",
      CellTags->{"i:92", "c:40"}]},
  "(4.4.23)"->{
    Cell[15640831, 439439, 427, 10, 45, "NE5",
      CellTags->"(4.4.23)"]},
  "(4.4.24)"->{
    Cell[15642342, 439488, 141, 5, 34, "NE5",
      CellTags->"(4.4.24)"]},
  "(4.4.25)"->{
    Cell[15642542, 439497, 395, 7, 33, "NE5",
      CellTags->"(4.4.25)"]},
  "Cell 4.45"->{
    Cell[15645040, 439575, 529, 11, 143, "Input",
      CellTags->"Cell 4.45"]},
  "Cell 4.46"->{
    Cell[16322402, 473435, 529, 11, 143, "Input",
      CellTags->"Cell 4.46"]},
  "Cell 4.47"->{
    Cell[17739230, 516455, 515, 10, 143, "Input",
      CellTags->"Cell 4.47"]},
  "i:93"->{
    Cell[19160404, 559702, 907, 16, 129, "Text",
      CellTags->"i:93"]},
  "c:41"->{
    Cell[19161348, 559723, 82, 1, 30, "Subsubtitle",
      CellTags->"c:41"]},
  "(4.4.26)"->{
    Cell[19162304, 559752, 240, 7, 38, "NE5",
      CellTags->"(4.4.26)"]},
  "(4.4.27)"->{
    Cell[19163915, 559809, 337, 12, 29, "NE5",
      CellTags->"(4.4.27)"]},
  "(4.4.28)"->{
    Cell[19164826, 559844, 418, 14, 30, "NE5",
      CellTags->"(4.4.28)"]},
  "(4.4.29)"->{
    Cell[19165468, 559868, 172, 6, 38, "NE5",
      CellTags->"(4.4.29)"]},
  "(4.4.30)"->{
    Cell[19165678, 559878, 230, 7, 32, "NE5",
      CellTags->"(4.4.30)"]},
  "(4.4.31)"->{
    Cell[19166713, 559914, 189, 4, 35, "NE5",
      CellTags->"(4.4.31)"]},
  "(4.4.32)"->{
    Cell[19167164, 559931, 197, 7, 29, "NE5",
      CellTags->"(4.4.32)"]},
  "Cell 4.48"->{
    Cell[19170339, 560024, 284, 7, 105, "Input",
      CellTags->"Cell 4.48"]},
  "Cell 4.49"->{
    Cell[19170786, 560040, 742, 13, 263, "Input",
      CellTags->"Cell 4.49"]},
  "c:42"->{
    Cell[19205302, 560862, 65, 1, 30, "Subsubtitle",
      CellTags->"c:42"]},
  "i:94"->{
    Cell[19206243, 560895, 289, 8, 45, "NE5",
      CellTags->{"i:94", "(4.4.33)"}]},
  "(4.4.33)"->{
    Cell[19206243, 560895, 289, 8, 45, "NE5",
      CellTags->{"i:94", "(4.4.33)"}]},
  "Fig. 4.12"->{
    Cell[19250273, 561615, 67, 1, 16, "Caption",
      CellTags->"Fig. 4.12"]},
  "(4.4.34)"->{
    Cell[19258576, 561906, 436, 14, 42, "NE5",
      CellTags->"(4.4.34)"]},
  "Fig. 4.13"->{
    Cell[19274672, 562222, 68, 1, 16, "Caption",
      CellTags->"Fig. 4.13"]},
  "i:95"->{
    Cell[19278974, 562354, 931, 28, 68, "Text",
      CellTags->"i:95"]},
  "i:96"->{
    Cell[19280760, 562409, 448, 15, 44, "Text",
      CellTags->"i:96"]},
  "(4.4.35)"->{
    Cell[19281211, 562426, 186, 7, 33, "NE5",
      CellTags->"(4.4.35)"]},
  "i:97"->{
    Cell[19283414, 562497, 864, 26, 91, "Text",
      CellTags->"i:97"]},
  "(4.4.36)"->{
    Cell[19284281, 562525, 230, 8, 33, "NE5",
      CellTags->"(4.4.36)"]},
  "(4.4.37)"->{
    Cell[19284564, 562537, 424, 12, 33, "NE5",
      CellTags->"(4.4.37)"]},
  "i:114"->{
    Cell[19284991, 562551, 915, 29, 68, "Text",
      CellTags->"i:114"]},
  "i:98"->{
    Cell[19286538, 562607, 1265, 35, 95, "Text",
      CellTags->"i:98"]},
  "i:99"->{
    Cell[19292659, 562814, 265, 8, 44, "Text",
      CellTags->"i:99"]},
  "i:103"->{
    Cell[19299885, 563074, 1478, 45, 78, "Text",
      CellTags->"i:103"]},
  "(4.4.38)"->{
    Cell[19301366, 563121, 1054, 30, 42, "NE5",
      CellTags->"(4.4.38)"]},
  "i:100"->{
    Cell[19303563, 563196, 1192, 41, 44, "Text",
      CellTags->"i:100"]},
  "(4.4.39)"->{
    Cell[19304758, 563239, 289, 7, 42, "NE5",
      CellTags->"(4.4.39)"]},
  "i:102"->{
    Cell[19305789, 563275, 1501, 43, 137, "Text",
      CellTags->"i:102"]},
  "(4.4.40)"->{
    Cell[19311376, 563458, 626, 21, 32, "NE5",
      CellTags->"(4.4.40)"]},
  "refs"->{
    Cell[19321357, 563792, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:43"}]},
  "c:43"->{
    Cell[19321357, 563792, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:43"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 19367905, 565215},
  {"i:3", 19367980, 565218},
  {"c:2", 19368067, 565221},
  {"i:108", 19368156, 565224},
  {"c:4", 19368235, 565227},
  {"i:4", 19368317, 565230},
  {"c:5", 19368404, 565233},
  {"(4.1.1)", 19368495, 565236},
  {"i:1", 19368574, 565239},
  {"i:5", 19368651, 565242},
  {"(4.1.2)", 19368731, 565245},
  {"(4.1.3)", 19368814, 565248},
  {"(4.1.4)", 19368897, 565251},
  {"(4.1.5)", 19368980, 565254},
  {"(4.1.6)", 19369063, 565257},
  {"i:6", 19369143, 565260},
  {"c:6", 19369232, 565263},
  {"i:7", 19369321, 565266},
  {"i:112", 19369401, 565269},
  {"i:8", 19369482, 565272},
  {"(4.1.7)", 19369563, 565275},
  {"Cell 4.1", 19369648, 565278},
  {"Cell 4.2", 19369737, 565281},
  {"i:9", 19369820, 565284},
  {"Cell 4.3", 19369904, 565287},
  {"Fig. 4.1", 19369992, 565290},
  {"(4.1.8)", 19370082, 565293},
  {"Cell 4.4", 19370168, 565296},
  {"c:7", 19370252, 565299},
  {"i:10", 19370337, 565302},
  {"(4.1.9)", 19370421, 565305},
  {"i:21", 19370503, 565308},
  {"(4.1.10)", 19370588, 565311},
  {"(4.1.11)", 19370675, 565314},
  {"Cell 4.5", 19370762, 565317},
  {"Cell 4.6", 19370852, 565320},
  {"Cell 4.7", 19370941, 565323},
  {"Cell 4.8", 19371031, 565326},
  {"i:11", 19371119, 565329},
  {"c:8", 19371200, 565332},
  {"i:13", 19371286, 565335},
  {"c:9", 19371377, 565338},
  {"(4.1.12)", 19371473, 565341},
  {"(4.1.13)", 19371562, 565344},
  {"i:14", 19371646, 565347},
  {"(4.1.14)", 19371732, 565350},
  {"i:115", 19371817, 565353},
  {"(4.1.15)", 19371904, 565356},
  {"i:116", 19371992, 565359},
  {"(4.1.16)", 19372079, 565362},
  {"(4.1.17)", 19372167, 565365},
  {"i:12", 19372252, 565368},
  {"c:10", 19372345, 565371},
  {"(4.1.18)", 19372442, 565374},
  {"i:15", 19372526, 565377},
  {"(4.1.19)", 19372613, 565380},
  {"(4.1.20)", 19372701, 565383},
  {"(4.1.21)", 19372789, 565386},
  {"i:34", 19372873, 565389},
  {"c:11", 19372955, 565392},
  {"i:16", 19373038, 565395},
  {"(4.1.22)", 19373124, 565398},
  {"i:2", 19373207, 565401},
  {"(4.1.23)", 19373292, 565404},
  {"i:17", 19373376, 565407},
  {"c:12", 19373473, 565410},
  {"i:18", 19373570, 565413},
  {"(4.1.24)", 19373656, 565416},
  {"i:19", 19373740, 565419},
  {"(4.1.25)", 19373826, 565422},
  {"(4.1.26)", 19373914, 565425},
  {"(4.1.27)", 19374002, 565428},
  {"(4.1.28)", 19374090, 565431},
  {"i:20", 19374174, 565434},
  {"(4.1.29)", 19374272, 565437},
  {"(4.1.30)", 19374370, 565440},
  {"c:13", 19374454, 565443},
  {"i:22", 19374541, 565446},
  {"i:26", 19374623, 565449},
  {"i:27", 19374705, 565452},
  {"i:25", 19374787, 565455},
  {"i:23", 19374869, 565458},
  {"i:24", 19374951, 565461},
  {"i:33", 19375033, 565464},
  {"i:28", 19375114, 565467},
  {"(4.1.31)", 19375200, 565470},
  {"i:106", 19375285, 565473},
  {"i:29", 19375370, 565476},
  {"(4.1.32)", 19375455, 565479},
  {"i:30", 19375539, 565482},
  {"i:32", 19375621, 565485},
  {"i:31", 19375705, 565488},
  {"c:14", 19375787, 565491},
  {"i:37", 19375872, 565494},
  {"c:16", 19375954, 565497},
  {"(4.2.1)", 19376044, 565500},
  {"i:118", 19376128, 565503},
  {"(4.2.2)", 19376214, 565506},
  {"(4.2.3)", 19376301, 565509},
  {"(4.2.4)", 19376387, 565512},
  {"(4.2.5)", 19376474, 565515},
  {"(4.2.6)", 19376561, 565518},
  {"(4.2.7)", 19376650, 565521},
  {"(4.2.8)", 19376738, 565524},
  {"i:35", 19376822, 565527},
  {"(4.2.9)", 19376909, 565530},
  {"(4.2.10)", 19376997, 565533},
  {"(4.2.11)", 19377087, 565536},
  {"(4.2.12)", 19377177, 565539},
  {"c:17", 19377262, 565542},
  {"c:18", 19377351, 565545},
  {"i:38", 19377435, 565548},
  {"(4.2.13)", 19377521, 565551},
  {"(4.2.14)", 19377611, 565554},
  {"i:105", 19377698, 565557},
  {"(4.2.15)", 19377785, 565560},
  {"(4.2.16)", 19377874, 565563},
  {"(4.2.17)", 19377964, 565566},
  {"(4.2.18)", 19378053, 565569},
  {"(4.2.19)", 19378143, 565572},
  {"(4.2.20)", 19378232, 565575},
  {"(4.2.21)", 19378321, 565578},
  {"(4.2.22)", 19378411, 565581},
  {"i:36", 19378496, 565584},
  {"(4.2.23)", 19378595, 565587},
  {"(4.2.24)", 19378694, 565590},
  {"(4.2.25)", 19378783, 565593},
  {"(4.2.26)", 19378872, 565596},
  {"(4.2.27)", 19378961, 565599},
  {"c:19", 19379046, 565602},
  {"i:39", 19379130, 565605},
  {"(4.2.28)", 19379216, 565608},
  {"(4.2.29)", 19379305, 565611},
  {"(4.2.30)", 19379394, 565614},
  {"c:20", 19379480, 565617},
  {"i:119", 19379565, 565620},
  {"(4.2.31)", 19379653, 565623},
  {"(4.2.32)", 19379742, 565626},
  {"(4.2.33)", 19379831, 565629},
  {"(4.2.34)", 19379921, 565632},
  {"(4.2.35)", 19380010, 565635},
  {"(4.2.36)", 19380099, 565638},
  {"(4.2.37)", 19380188, 565641},
  {"(4.2.38)", 19380277, 565644},
  {"(4.2.39)", 19380367, 565647},
  {"Cell 4.9", 19380456, 565650},
  {"(4.2.40)", 19380548, 565653},
  {"Cell 4.10", 19380638, 565656},
  {"Cell 4.11", 19380732, 565659},
  {"Cell 4.12", 19380825, 565662},
  {"Cell 4.13", 19380917, 565665},
  {"Cell 4.14", 19381011, 565668},
  {"c:21", 19381101, 565671},
  {"(4.2.41)", 19381190, 565674},
  {"(4.2.42)", 19381280, 565677},
  {"(4.2.43)", 19381370, 565680},
  {"(4.2.44)", 19381460, 565683},
  {"Cell 4.15", 19381551, 565686},
  {"(4.2.45)", 19381644, 565689},
  {"i:41", 19381730, 565692},
  {"(4.2.46)", 19381830, 565695},
  {"Cell 4.16", 19381931, 565698},
  {"Cell 4.17", 19382026, 565701},
  {"Cell 4.18", 19382123, 565704},
  {"i:42", 19382215, 565707},
  {"Cell 4.19", 19382304, 565710},
  {"Ex. 4.2", 19382396, 565713},
  {"c:22", 19382498, 565716},
  {"i:117", 19382601, 565719},
  {"i:43", 19382687, 565722},
  {"i:46", 19382774, 565725},
  {"i:44", 19382859, 565728},
  {"(4.2.47)", 19382948, 565731},
  {"i:45", 19383035, 565734},
  {"(4.2.48)", 19383124, 565737},
  {"i:47", 19383211, 565740},
  {"(4.2.49)", 19383312, 565743},
  {"(4.2.50)", 19383413, 565746},
  {"i:48", 19383500, 565749},
  {"(4.2.51)", 19383602, 565752},
  {"Fig. 4.2", 19383704, 565755},
  {"i:49", 19383794, 565758},
  {"i:51", 19383878, 565761},
  {"Fig. 4.3", 19383967, 565764},
  {"i:50", 19384057, 565767},
  {"c:23", 19384142, 565770},
  {"c:24", 19384229, 565773},
  {"i:52", 19384319, 565776},
  {"(4.3.1)", 19384406, 565779},
  {"i:109", 19384493, 565782},
  {"i:62", 19384580, 565785},
  {"i:53", 19384665, 565788},
  {"(4.3.2)", 19384754, 565791},
  {"i:54", 19384841, 565794},
  {"(4.3.3)", 19384928, 565797},
  {"(4.3.4)", 19385019, 565800},
  {"(4.3.5)", 19385108, 565803},
  {"c:25", 19385194, 565806},
  {"i:55", 19385284, 565809},
  {"(4.3.6)", 19385384, 565812},
  {"(4.3.7)", 19385484, 565815},
  {"i:111", 19385572, 565818},
  {"i:56", 19385659, 565821},
  {"(4.3.8)", 19385760, 565824},
  {"i:59", 19385858, 565827},
  {"(4.3.9)", 19385959, 565830},
  {"(4.3.10)", 19386061, 565833},
  {"(4.3.11)", 19386154, 565836},
  {"c:26", 19386242, 565839},
  {"i:107", 19386334, 565842},
  {"(4.3.12)", 19386424, 565845},
  {"i:71", 19386512, 565848},
  {"i:73", 19386597, 565851},
  {"(4.3.13)", 19386685, 565854},
  {"i:72", 19386773, 565857},
  {"(4.3.14)", 19386861, 565860},
  {"(4.3.15)", 19386953, 565863},
  {"i:57", 19387041, 565866},
  {"(4.3.16)", 19387129, 565869},
  {"i:58", 19387218, 565872},
  {"(4.3.17)", 19387307, 565875},
  {"i:60", 19387395, 565878},
  {"i:61", 19387481, 565881},
  {"i:63", 19387568, 565884},
  {"c:27", 19387669, 565887},
  {"c:28", 19387770, 565890},
  {"i:120", 19387857, 565893},
  {"c:29", 19387945, 565896},
  {"i:64", 19388031, 565899},
  {"Fig. 4.4", 19388128, 565902},
  {"(4.3.18)", 19388223, 565905},
  {"(4.3.19)", 19388314, 565908},
  {"(4.3.20)", 19388405, 565911},
  {"(4.3.21)", 19388496, 565914},
  {"(4.3.22)", 19388587, 565917},
  {"(4.3.23)", 19388678, 565920},
  {"(4.3.24)", 19388769, 565923},
  {"(4.3.25)", 19388860, 565926},
  {"(4.3.26)", 19388951, 565929},
  {"(4.3.27)", 19389042, 565932},
  {"Cell 4.20", 19389135, 565935},
  {"Cell 4.21", 19389232, 565938},
  {"i:67", 19389324, 565941},
  {"Fig. 4.5", 19389421, 565944},
  {"(4.3.28)", 19389515, 565947},
  {"(4.3.29)", 19389606, 565950},
  {"(4.3.30)", 19389698, 565953},
  {"Cell 4.22", 19389790, 565956},
  {"Cell 4.23", 19389887, 565959},
  {"Cell 4.24", 19389984, 565962},
  {"(4.3.31)", 19390078, 565965},
  {"(4.3.32)", 19390169, 565968},
  {"Cell 4.25", 19390262, 565971},
  {"Cell 4.26", 19390359, 565974},
  {"i:113", 19390450, 565977},
  {"Table 4.1", 19390541, 565980},
  {"c:30", 19390633, 565983},
  {"i:65", 19390719, 565986},
  {"(4.3.33)", 19390816, 565989},
  {"(4.3.34)", 19390907, 565992},
  {"(4.3.35)", 19390998, 565995},
  {"(4.3.36)", 19391089, 565998},
  {"(4.3.37)", 19391180, 566001},
  {"(4.3.38)", 19391271, 566004},
  {"(4.3.39)", 19391363, 566007},
  {"(4.3.40)", 19391454, 566010},
  {"(4.3.41)", 19391546, 566013},
  {"(4.3.42)", 19391637, 566016},
  {"(4.3.43)", 19391728, 566019},
  {"(4.3.44)", 19391819, 566022},
  {"i:68", 19391906, 566025},
  {"(4.3.45)", 19392007, 566028},
  {"(4.3.46)", 19392108, 566031},
  {"(4.3.47)", 19392199, 566034},
  {"(4.3.48)", 19392290, 566037},
  {"(4.3.49)", 19392381, 566040},
  {"(4.3.50)", 19392472, 566043},
  {"(4.3.51)", 19392563, 566046},
  {"Cell 4.27", 19392656, 566049},
  {"Cell 4.28", 19392751, 566052},
  {"Cell 4.29", 19392847, 566055},
  {"Cell 4.30", 19392944, 566058},
  {"c:31", 19393036, 566061},
  {"i:66", 19393122, 566064},
  {"(4.3.52)", 19393219, 566067},
  {"(4.3.53)", 19393310, 566070},
  {"(4.3.54)", 19393402, 566073},
  {"(4.3.55)", 19393493, 566076},
  {"(4.3.56)", 19393584, 566079},
  {"i:69", 19393671, 566082},
  {"Cell 4.31", 19393769, 566085},
  {"Table 4.2", 19393864, 566088},
  {"Table 4.3", 19393960, 566091},
  {"Cell 4.32", 19394057, 566094},
  {"Cell 4.33", 19394153, 566097},
  {"(4.3.57)", 19394248, 566100},
  {"(4.3.58)", 19394339, 566103},
  {"(4.3.59)", 19394430, 566106},
  {"Cell 4.34", 19394522, 566109},
  {"(4.3.60)", 19394617, 566112},
  {"i:70", 19394705, 566115},
  {"(4.3.61)", 19394807, 566118},
  {"i:78", 19394905, 566121},
  {"(4.3.62)", 19395006, 566124},
  {"(4.3.63)", 19395107, 566127},
  {"Fig. 4.6", 19395199, 566130},
  {"(4.3.64)", 19395293, 566133},
  {"(4.3.65)", 19395385, 566136},
  {"(4.3.66)", 19395476, 566139},
  {"(4.3.67)", 19395567, 566142},
  {"(4.3.68)", 19395658, 566145},
  {"Cell 4.35", 19395751, 566148},
  {"Cell 4.36", 19395846, 566151},
  {"Cell 4.37", 19395941, 566154},
  {"Cell 4.38", 19396035, 566157},
  {"Cell 4.39", 19396132, 566160},
  {"Cell 4.40", 19396228, 566163},
  {"c:32", 19396319, 566166},
  {"i:76", 19396409, 566169},
  {"(4.3.69)", 19396498, 566172},
  {"(4.3.70)", 19396591, 566175},
  {"i:77", 19396679, 566178},
  {"(4.3.71)", 19396768, 566181},
  {"i:79", 19396856, 566184},
  {"(4.3.72)", 19396945, 566187},
  {"Fig. 4.7", 19397036, 566190},
  {"Fig. 4.8", 19397130, 566193},
  {"i:80", 19397220, 566196},
  {"i:81", 19397307, 566199},
  {"(4.3.73)", 19397395, 566202},
  {"(4.3.74)", 19397488, 566205},
  {"(4.3.75)", 19397580, 566208},
  {"i:84", 19397668, 566211},
  {"(4.3.76)", 19397770, 566214},
  {"i:82", 19397868, 566217},
  {"Fig. 4.9", 19397957, 566220},
  {"i:83", 19398048, 566223},
  {"(4.3.77)", 19398150, 566226},
  {"Fig. 4.10", 19398253, 566229},
  {"i:110", 19398346, 566232},
  {"(4.3.78)", 19398448, 566235},
  {"(4.3.79)", 19398550, 566238},
  {"i:85", 19398637, 566241},
  {"i:86", 19398722, 566244},
  {"i:87", 19398809, 566247},
  {"(4.3.80)", 19398899, 566250},
  {"Fig. 4.11", 19398991, 566253},
  {"c:33", 19399083, 566256},
  {"i:88", 19399170, 566259},
  {"(4.4.1)", 19399270, 566262},
  {"i:89", 19399367, 566265},
  {"(4.4.2)", 19399467, 566268},
  {"c:35", 19399564, 566271},
  {"c:36", 19399654, 566274},
  {"(4.4.3)", 19399743, 566277},
  {"(4.4.4)", 19399832, 566280},
  {"(4.4.5)", 19399921, 566283},
  {"(4.4.6)", 19400010, 566286},
  {"(4.4.7)", 19400099, 566289},
  {"(4.4.8)", 19400188, 566292},
  {"(4.4.9)", 19400277, 566295},
  {"(4.4.10)", 19400367, 566298},
  {"(4.4.11)", 19400458, 566301},
  {"(4.4.12)", 19400549, 566304},
  {"(4.4.13)", 19400640, 566307},
  {"(4.4.14)", 19400731, 566310},
  {"(4.4.15)", 19400822, 566313},
  {"(4.4.16)", 19400913, 566316},
  {"(4.4.17)", 19401004, 566319},
  {"(4.4.18)", 19401096, 566322},
  {"(4.4.19)", 19401189, 566325},
  {"i:90", 19401277, 566328},
  {"c:37", 19401373, 566331},
  {"Cell 4.41", 19401474, 566334},
  {"Cell 4.42", 19401571, 566337},
  {"i:91", 19401663, 566340},
  {"c:38", 19401760, 566343},
  {"(4.4.20)", 19401861, 566346},
  {"Cell 4.43", 19401955, 566349},
  {"c:39", 19402048, 566352},
  {"(4.4.21)", 19402140, 566355},
  {"(4.4.22)", 19402232, 566358},
  {"Cell 4.44", 19402326, 566361},
  {"i:92", 19402419, 566364},
  {"c:40", 19402520, 566367},
  {"(4.4.23)", 19402625, 566370},
  {"(4.4.24)", 19402718, 566373},
  {"(4.4.25)", 19402810, 566376},
  {"Cell 4.45", 19402903, 566379},
  {"Cell 4.46", 19403001, 566382},
  {"Cell 4.47", 19403099, 566385},
  {"i:93", 19403192, 566388},
  {"c:41", 19403279, 566391},
  {"(4.4.26)", 19403374, 566394},
  {"(4.4.27)", 19403466, 566397},
  {"(4.4.28)", 19403559, 566400},
  {"(4.4.29)", 19403652, 566403},
  {"(4.4.30)", 19403744, 566406},
  {"(4.4.31)", 19403836, 566409},
  {"(4.4.32)", 19403928, 566412},
  {"Cell 4.48", 19404021, 566415},
  {"Cell 4.49", 19404118, 566418},
  {"c:42", 19404211, 566421},
  {"i:94", 19404302, 566424},
  {"(4.4.33)", 19404404, 566427},
  {"Fig. 4.12", 19404507, 566430},
  {"(4.4.34)", 19404603, 566433},
  {"Fig. 4.13", 19404697, 566436},
  {"i:95", 19404789, 566439},
  {"i:96", 19404875, 566442},
  {"(4.4.35)", 19404965, 566445},
  {"i:97", 19405053, 566448},
  {"(4.4.36)", 19405143, 566451},
  {"(4.4.37)", 19405235, 566454},
  {"i:114", 19405325, 566457},
  {"i:98", 19405412, 566460},
  {"i:99", 19405499, 566463},
  {"i:103", 19405585, 566466},
  {"(4.4.38)", 19405677, 566469},
  {"i:100", 19405768, 566472},
  {"(4.4.39)", 19405860, 566475},
  {"i:102", 19405949, 566478},
  {"(4.4.40)", 19406042, 566481},
  {"refs", 19406131, 566484},
  {"c:43", 19406229, 566487}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 57, 1, 69, "Title",
  CellTags->"c:1"],
Cell[1787, 55, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1828, 59, 78, 1, 39, "Subtitle",
  CellTags->{"i:3", "c:2"}],
Cell[1909, 62, 16, 0, 27, "Text"],
Cell[1928, 64, 746, 13, 112, "Text"],
Cell[2677, 79, 1261, 38, 78, "Text",
  CellTags->"i:108"],
Cell[3941, 119, 644, 13, 95, "Text"],

Cell[CellGroupData[{
Cell[4610, 136, 87, 1, 41, "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{
Cell[4722, 141, 99, 2, 70, "Section",
  CellTags->{"i:4", "c:5"}],
Cell[4824, 145, 245, 6, 70, "Text"],
Cell[5072, 153, 1805, 60, 70, "Text"],
Cell[6880, 215, 242, 8, 70, "NE2",
  CellTags->"(4.1.1)"],
Cell[7125, 225, 705, 20, 70, "Text",
  CellTags->"i:1"],
Cell[7833, 247, 165, 4, 70, "Text",
  CellTags->"i:5"],
Cell[8001, 253, 132, 5, 70, "NE2",
  CellTags->"(4.1.2)"],
Cell[8136, 260, 352, 10, 70, "Text"],
Cell[8491, 272, 117, 2, 70, "NE2",
  CellTags->"(4.1.3)"],
Cell[8611, 276, 288, 10, 70, "Text"],
Cell[8902, 288, 166, 6, 70, "NE2",
  CellTags->"(4.1.4)"],
Cell[9071, 296, 227, 8, 70, "Text"],
Cell[9301, 306, 285, 8, 70, "NE2",
  CellTags->"(4.1.5)"],
Cell[9589, 316, 167, 6, 70, "Text"],
Cell[9759, 324, 215, 6, 70, "Text"],
Cell[9977, 332, 298, 10, 70, "NE2",
  CellTags->"(4.1.6)"],
Cell[10278, 344, 279, 11, 70, "Text"],
Cell[10560, 357, 384, 12, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10981, 374, 124, 2, 70, "Section",
  CellTags->{"i:6", "c:6"}],
Cell[11108, 378, 783, 24, 70, "Text",
  CellTags->"i:7"],
Cell[11894, 404, 804, 21, 70, "Text"],
Cell[12701, 427, 265, 8, 70, "Text"],
Cell[12969, 437, 1247, 34, 70, "Text",
  CellTags->"i:112"],
Cell[14219, 473, 1001, 29, 70, "Text"],
Cell[15223, 504, 181, 6, 70, "Text"],
Cell[15407, 512, 942, 35, 70, "Text"],
Cell[16352, 549, 205, 6, 70, "Text"],
Cell[16560, 557, 317, 8, 70, "Text"],
Cell[16880, 567, 452, 15, 70, "Text"],
Cell[17335, 584, 256, 6, 70, "Text"],
Cell[17594, 592, 130, 4, 70, "Text",
  CellTags->"i:8"],
Cell[17727, 598, 217, 8, 70, "NE2",
  CellTags->"(4.1.7)"],
Cell[17947, 608, 972, 29, 70, "Text"],
Cell[18922, 639, 572, 20, 70, "Text"],

Cell[CellGroupData[{
Cell[19519, 663, 522, 10, 70, "Input",
  CellTags->"Cell 4.1"],
Cell[20044, 675, 54, 1, 70, "Output"]
}, Open  ]],
Cell[20113, 679, 122, 5, 70, "Text"],
Cell[20238, 686, 470, 14, 70, "Text"],

Cell[CellGroupData[{
Cell[20733, 704, 407, 9, 70, "Input",
  CellTags->"Cell 4.2"],
Cell[21143, 715, 61, 1, 70, "Output"]
}, Open  ]],
Cell[21219, 719, 138, 5, 70, "Text"],
Cell[21360, 726, 1211, 39, 70, "Text",
  CellTags->"i:9"],

Cell[CellGroupData[{
Cell[22596, 769, 156, 4, 70, "Input",
  CellTags->"Cell 4.3"],
Cell[22755, 775, 183, 4, 70, "Print"],
Cell[22941, 781, 183, 4, 70, "Print"],
Cell[23127, 787, 336, 10, 70, "Print"],
Cell[23466, 799, 367, 11, 70, "Print"],
Cell[23836, 812, 424, 13, 70, "Print"]
}, Open  ]],
Cell[24275, 828, 59993, 1472, 70, 17844, 948, "GraphicsData", "PostScript", \
"Picture"],
Cell[84271, 2302, 316, 9, 70, "Caption",
  CellTags->"Fig. 4.1"],
Cell[84590, 2313, 261, 7, 70, "Text"],
Cell[84854, 2322, 218, 7, 70, "NE2",
  CellTags->"(4.1.8)"],
Cell[85075, 2331, 367, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[85467, 2345, 197, 5, 70, "Input",
  CellTags->"Cell 4.4"],
Cell[85667, 2352, 356, 9, 70, "Output"]
}, Open  ]],
Cell[86038, 2364, 225, 7, 70, "Text"],
Cell[86266, 2373, 202, 4, 70, "Text"],
Cell[86471, 2379, 268, 6, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[86788, 2391, 78, 1, 30, "Subsubtitle",
  CellTags->"c:7"],
Cell[86869, 2394, 495, 15, 44, "Text",
  CellTags->"i:10"],
Cell[87367, 2411, 185, 4, 28, "NE2",
  CellTags->"(4.1.9)"],
Cell[87555, 2417, 657, 20, 61, "Text",
  CellTags->"i:21"],
Cell[88215, 2439, 188, 6, 29, "NE2",
  CellTags->"(4.1.10)"],
Cell[88406, 2447, 279, 9, 44, "Text"],
Cell[88688, 2458, 168, 6, 29, "NE2",
  CellTags->"(4.1.11)"],
Cell[88859, 2466, 454, 14, 44, "Text"],
Cell[89316, 2482, 898, 23, 78, "Text"],
Cell[90217, 2507, 237, 5, 105, "Input",
  CellTags->"Cell 4.5"],
Cell[90457, 2514, 385, 11, 61, "Text"],
Cell[90845, 2527, 148, 4, 69, "Input",
  CellTags->"Cell 4.6"],
Cell[90996, 2533, 237, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[91258, 2544, 386, 9, 145, "Input",
  CellTags->"Cell 4.7"],

Cell[CellGroupData[{
Cell[91669, 2557, 27489, 641, 233, 5611, 366, "GraphicsData", "PostScript", \
"Graphics"],
Cell[119161, 3200, 28462, 697, 233, 6503, 421, "GraphicsData", "PostScript", \
"Graphics"],
Cell[147626, 3899, 28068, 692, 233, 6459, 420, "GraphicsData", "PostScript", \
"Graphics"],
Cell[175697, 4593, 28116, 694, 233, 6517, 422, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[203840, 5291, 310, 5, 61, "Text"],
Cell[204153, 5298, 735, 20, 61, "Text"],

Cell[CellGroupData[{
Cell[204913, 5322, 782, 16, 280, "Input",
  CellTags->"Cell 4.8"],

Cell[CellGroupData[{
Cell[205720, 5342, 30202, 741, 233, 6920, 449, "GraphicsData", "PostScript", \
"Graphics"],
Cell[235925, 6085, 30065, 738, 233, 6909, 448, "GraphicsData", "PostScript", \
"Graphics"],
Cell[265993, 6825, 30123, 739, 233, 6910, 448, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[296143, 7568, 321, 9, 44, "Text"],
Cell[296467, 7579, 495, 14, 61, "Text",
  CellTags->"i:11"],
Cell[296965, 7595, 470, 10, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[297472, 7610, 81, 1, 30, "Subsubtitle",
  CellTags->"c:8"],

Cell[CellGroupData[{
Cell[297578, 7615, 96, 1, 42, "Section",
  CellTags->{"i:13", "c:9"}],
Cell[297677, 7618, 642, 22, 69, "Text"],
Cell[298322, 7642, 344, 12, 34, "NE2",
  CellTags->"(4.1.12)"],
Cell[298669, 7656, 128, 3, 27, "Text"],
Cell[298800, 7661, 131, 3, 27, "Text"],
Cell[298934, 7666, 260, 7, 41, "NE2",
  CellTags->"(4.1.13)"],
Cell[299197, 7675, 582, 20, 44, "Text"],
Cell[299782, 7697, 841, 26, 61, "Text",
  CellTags->"i:14"],
Cell[300626, 7725, 104, 3, 27, "Text"],
Cell[300733, 7730, 252, 8, 34, "NE2",
  CellTags->"(4.1.14)"],
Cell[300988, 7740, 621, 18, 65, "Text",
  CellTags->"i:115"],
Cell[301612, 7760, 138, 3, 44, "Text"],
Cell[301753, 7765, 475, 15, 61, "Text"],
Cell[302231, 7782, 217, 6, 44, "Text"],
Cell[302451, 7790, 240, 8, 27, "Text"],
Cell[302694, 7800, 556, 16, 49, "Text"],
Cell[303253, 7818, 3070, 79, 148, "NE2",
  CellTags->"(4.1.15)"],
Cell[306326, 7899, 716, 19, 66, "Text"],
Cell[307045, 7920, 433, 10, 49, "Text",
  CellTags->"i:116"],
Cell[307481, 7932, 319, 9, 38, "NE2",
  CellTags->"(4.1.16)"],
Cell[307803, 7943, 716, 19, 66, "Text"],
Cell[308522, 7964, 322, 8, 32, "Text"],
Cell[308847, 7974, 425, 11, 44, "NE2",
  CellTags->"(4.1.17)"],
Cell[309275, 7987, 1178, 34, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[310490, 8026, 59, 1, 31, "Section",
  CellTags->{"i:12", "c:10"}],
Cell[310552, 8029, 421, 10, 70, "Text"],
Cell[310976, 8041, 137, 3, 70, "NE2",
  CellTags->"(4.1.18)"],
Cell[311116, 8046, 334, 7, 70, "Text"],
Cell[311453, 8055, 2112, 53, 70, "Text",
  CellTags->"i:15"],
Cell[313568, 8110, 323, 9, 70, "Text"],
Cell[313894, 8121, 236, 7, 70, "NE2",
  CellTags->"(4.1.19)"],
Cell[314133, 8130, 366, 10, 70, "Text"],
Cell[314502, 8142, 176, 5, 70, "Text"],
Cell[314681, 8149, 153, 6, 70, "Text"],
Cell[314837, 8157, 308, 8, 70, "NE2",
  CellTags->"(4.1.20)"],
Cell[315148, 8167, 284, 10, 70, "Text"],
Cell[315435, 8179, 249, 10, 70, "Text"],
Cell[315687, 8191, 176, 6, 70, "NE2",
  CellTags->"(4.1.21)"],
Cell[315866, 8199, 716, 25, 70, "Text"],
Cell[316585, 8226, 682, 21, 70, "Text"],
Cell[317270, 8249, 827, 17, 70, "Text"],
Cell[318100, 8268, 534, 17, 70, "Text",
  CellTags->"i:34"],
Cell[318637, 8287, 257, 6, 70, "Text"],
Cell[318897, 8295, 1088, 33, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[320022, 8333, 51, 1, 31, "Section",
  CellTags->"c:11"],
Cell[320076, 8336, 790, 21, 99, "Text",
  CellTags->"i:16"],
Cell[320869, 8359, 124, 3, 27, "Text"],
Cell[320996, 8364, 1484, 37, 109, "Text"],
Cell[322483, 8403, 184, 6, 29, "NE2",
  CellTags->"(4.1.22)"],
Cell[322670, 8411, 466, 16, 44, "Text",
  CellTags->"i:2"],
Cell[323139, 8429, 215, 7, 34, "NE2",
  CellTags->"(4.1.23)"],
Cell[323357, 8438, 1004, 25, 112, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[324410, 8469, 96, 1, 30, "Subsubtitle",
  CellTags->{"i:17", "c:12"}],
Cell[324509, 8472, 1179, 32, 70, "Text"],
Cell[325691, 8506, 325, 7, 70, "Text"],
Cell[326019, 8515, 355, 12, 70, "Text",
  CellTags->"i:18"],
Cell[326377, 8529, 166, 6, 70, "NE2",
  CellTags->"(4.1.24)"],
Cell[326546, 8537, 1032, 28, 70, "Text"],
Cell[327581, 8567, 542, 18, 70, "Text",
  CellTags->"i:19"],
Cell[328126, 8587, 311, 11, 70, "Text"],
Cell[328440, 8600, 150, 5, 70, "NE2",
  CellTags->"(4.1.25)"],
Cell[328593, 8607, 60, 0, 70, "Text"],
Cell[328656, 8609, 150, 5, 70, "NE2",
  CellTags->"(4.1.26)"],
Cell[328809, 8616, 370, 11, 70, "Text"],
Cell[329182, 8629, 249, 8, 70, "Text"],
Cell[329434, 8639, 204, 7, 70, "NE2",
  CellTags->"(4.1.27)"],
Cell[329641, 8648, 180, 5, 70, "Text"],
Cell[329824, 8655, 135, 3, 70, "NE2",
  CellTags->"(4.1.28)"],
Cell[329962, 8660, 19, 0, 70, "Text"],
Cell[329984, 8662, 262, 9, 70, "NE2",
  CellTags->{"i:20", "(4.1.29)"}],
Cell[330249, 8673, 117, 3, 70, "Text"],
Cell[330369, 8678, 536, 16, 70, "Text"],
Cell[330908, 8696, 181, 6, 70, "NE2",
  CellTags->"(4.1.30)"],
Cell[331092, 8704, 923, 29, 70, "Text"],
Cell[332018, 8735, 468, 11, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[332523, 8751, 65, 1, 30, "Subsubtitle",
  CellTags->"c:13"],
Cell[332591, 8754, 357, 11, 44, "Text"],
Cell[332951, 8767, 506, 17, 30, "Text",
  CellTags->"i:22"],
Cell[333460, 8786, 520, 17, 45, "Text",
  CellTags->"i:26"],
Cell[333983, 8805, 515, 17, 48, "Text",
  CellTags->"i:27"],
Cell[334501, 8824, 328, 10, 34, "Text"],
Cell[334832, 8836, 534, 16, 47, "Text"],
Cell[335369, 8854, 658, 18, 78, "Text"],
Cell[336030, 8874, 404, 11, 47, "Text"],
Cell[336437, 8887, 586, 16, 61, "Text"],
Cell[337026, 8905, 291, 11, 31, "Text"],
Cell[337320, 8918, 334, 12, 36, "Text"],
Cell[337657, 8932, 258, 9, 27, "Text"],
Cell[337918, 8943, 300, 9, 27, "Text"],
Cell[338221, 8954, 317, 9, 31, "Text"],
Cell[338541, 8965, 289, 7, 44, "Text"],
Cell[338833, 8974, 373, 11, 44, "Text"],
Cell[339209, 8987, 172, 7, 30, "Text"],
Cell[339384, 8996, 173, 7, 30, "Text"],
Cell[339560, 9005, 194, 7, 30, "Text"],
Cell[339757, 9014, 426, 12, 44, "Text"],
Cell[340186, 9028, 208, 5, 44, "Text"],
Cell[340397, 9035, 539, 17, 40, "Text"],
Cell[340939, 9054, 499, 15, 40, "Text"],
Cell[341441, 9071, 352, 11, 36, "Text"],
Cell[341796, 9084, 404, 14, 40, "Text"],
Cell[342203, 9100, 494, 16, 40, "Text"],
Cell[342700, 9118, 521, 17, 57, "Text"],
Cell[343224, 9137, 549, 20, 48, "Text",
  CellTags->"i:25"],
Cell[343776, 9159, 504, 17, 48, "Text",
  CellTags->"i:23"],
Cell[344283, 9178, 598, 20, 48, "Text",
  CellTags->"i:24"],
Cell[344884, 9200, 851, 31, 61, "Text"],
Cell[345738, 9233, 305, 6, 44, "Text"],
Cell[346046, 9241, 365, 12, 40, "Text"],
Cell[346414, 9255, 183, 7, 31, "Text"],
Cell[346600, 9264, 371, 14, 31, "Text"],
Cell[346974, 9280, 257, 8, 40, "Text"],
Cell[347234, 9290, 529, 15, 61, "Text"],
Cell[347766, 9307, 262, 9, 27, "Text"],
Cell[348031, 9318, 307, 10, 30, "Text"],
Cell[348341, 9330, 275, 10, 27, "Text"],
Cell[348619, 9342, 228, 8, 27, "Text",
  CellTags->"i:33"],
Cell[348850, 9352, 542, 17, 43, "Text"],
Cell[349395, 9371, 303, 10, 27, "Text",
  CellTags->"i:28"],
Cell[349701, 9383, 139, 3, 32, "NE2",
  CellTags->"(4.1.31)"],
Cell[349843, 9388, 1864, 49, 142, "Text",
  CellTags->"i:106"],
Cell[351710, 9439, 235, 8, 27, "Text",
  CellTags->"i:29"],
Cell[351948, 9449, 136, 5, 36, "Text"],
Cell[352087, 9456, 416, 11, 44, "Text"],
Cell[352506, 9469, 210, 7, 36, "NE2",
  CellTags->"(4.1.32)"],
Cell[352719, 9478, 843, 25, 72, "Text",
  CellTags->"i:30"],
Cell[353565, 9505, 888, 25, 71, "Text"],
Cell[354456, 9532, 336, 10, 44, "Text"],
Cell[354795, 9544, 245, 7, 45, "Text"],
Cell[355043, 9553, 1389, 38, 120, "Text",
  CellTags->"i:32"],
Cell[356435, 9593, 852, 22, 95, "Text",
  CellTags->"i:31"],
Cell[357290, 9617, 253, 7, 31, "Text"],
Cell[357546, 9626, 88, 3, 27, "Text"],
Cell[357637, 9631, 273, 12, 27, "Text"],
Cell[357913, 9645, 221, 7, 31, "Text"],
Cell[358137, 9654, 438, 15, 33, "Text"],
Cell[358578, 9671, 529, 18, 36, "Text"],
Cell[359110, 9691, 493, 16, 40, "Text"],
Cell[359606, 9709, 146, 4, 27, "Text"],
Cell[359755, 9715, 93, 4, 27, "Text"],
Cell[359851, 9721, 93, 4, 27, "Text"],
Cell[359947, 9727, 210, 6, 48, "Text"],
Cell[360160, 9735, 860, 20, 92, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[361069, 9761, 140, 4, 74, "Subtitle",
  CellTags->"c:14"],
Cell[361212, 9767, 16, 0, 27, "Text"],
Cell[361231, 9769, 713, 18, 95, "Text",
  CellTags->"i:37"],
Cell[361947, 9789, 190, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[362162, 9797, 74, 1, 41, "Subsubtitle",
  CellTags->"c:16"],
Cell[362239, 9800, 162, 5, 27, "Text"],
Cell[362404, 9807, 297, 7, 40, "NE3",
  CellTags->"(4.2.1)"],
Cell[362704, 9816, 720, 22, 61, "Text",
  CellTags->"i:118"],
Cell[363427, 9840, 399, 13, 29, "NE3",
  CellTags->"(4.2.2)"],
Cell[363829, 9855, 469, 15, 44, "Text"],
Cell[364301, 9872, 176, 5, 45, "Text"],
Cell[364480, 9879, 35, 0, 27, "Text"],
Cell[364518, 9881, 188, 7, 29, "NE3",
  CellTags->"(4.2.3)"],
Cell[364709, 9890, 509, 14, 61, "Text"],
Cell[365221, 9906, 318, 10, 44, "Text"],
Cell[365542, 9918, 383, 9, 72, "Text"],
Cell[365928, 9929, 271, 9, 27, "Text"],
Cell[366202, 9940, 316, 7, 67, "Text"],
Cell[366521, 9949, 405, 14, 27, "Text"],
Cell[366929, 9965, 548, 16, 27, "NE3",
  CellTags->"(4.2.4)"],
Cell[367480, 9983, 29, 0, 27, "Text"],
Cell[367512, 9985, 748, 23, 38, "NE3",
  CellTags->"(4.2.5)"],
Cell[368263, 10010, 25, 0, 27, "Text"],
Cell[368291, 10012, 1267, 35, 38, "NE3",
  CellTags->"(4.2.6)"],
Cell[369561, 10049, 487, 18, 44, "Text"],
Cell[370051, 10069, 830, 23, 38, "NE3",
  CellTags->"(4.2.7)"],
Cell[370884, 10094, 132, 5, 29, "Text"],
Cell[371019, 10101, 263, 8, 38, "NE3",
  CellTags->"(4.2.8)"],
Cell[371285, 10111, 1135, 31, 95, "Text",
  CellTags->"i:35"],
Cell[372423, 10144, 185, 4, 44, "Text"],
Cell[372611, 10150, 314, 8, 45, "NE3",
  CellTags->"(4.2.9)"],
Cell[372928, 10160, 24, 0, 27, "Text"],
Cell[372955, 10162, 404, 13, 29, "NE3",
  CellTags->"(4.2.10)"],
Cell[373362, 10177, 441, 17, 27, "Text"],
Cell[373806, 10196, 816, 20, 45, "NE3",
  CellTags->"(4.2.11)"],
Cell[374625, 10218, 177, 5, 29, "Text"],
Cell[374805, 10225, 352, 9, 45, "NE3",
  CellTags->"(4.2.12)"],
Cell[375160, 10236, 388, 9, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[375585, 10250, 104, 2, 30, "Subsubtitle",
  CellTags->"c:17"],

Cell[CellGroupData[{
Cell[375714, 10256, 77, 1, 42, "Section",
  CellTags->"c:18"],
Cell[375794, 10259, 362, 9, 44, "Text",
  CellTags->"i:38"],
Cell[376159, 10270, 625, 19, 42, "NE3",
  CellTags->"(4.2.13)"],
Cell[376787, 10291, 111, 5, 31, "Text"],
Cell[376901, 10298, 701, 20, 41, "NE3",
  CellTags->"(4.2.14)"],
Cell[377605, 10320, 155, 6, 27, "Text",
  CellTags->"i:105"],
Cell[377763, 10328, 191, 6, 33, "NE3",
  CellTags->"(4.2.15)"],
Cell[377957, 10336, 499, 16, 44, "Text"],
Cell[378459, 10354, 400, 11, 29, "NE3",
  CellTags->"(4.2.16)"],
Cell[378862, 10367, 430, 15, 48, "Text"],
Cell[379295, 10384, 220, 7, 34, "NE3",
  CellTags->"(4.2.17)"],
Cell[379518, 10393, 415, 13, 44, "Text"],
Cell[379936, 10408, 562, 11, 42, "NE3",
  CellTags->"(4.2.18)"],
Cell[380501, 10421, 495, 16, 44, "Text"],
Cell[380999, 10439, 329, 8, 46, "NE3",
  CellTags->"(4.2.19)"],
Cell[381331, 10449, 57, 0, 27, "Text"],
Cell[381391, 10451, 234, 7, 30, "NE3",
  CellTags->"(4.2.20)"],
Cell[381628, 10460, 233, 9, 28, "Text"],
Cell[381864, 10471, 117, 3, 27, "Text"],
Cell[381984, 10476, 585, 16, 45, "NE3",
  CellTags->"(4.2.21)"],
Cell[382572, 10494, 176, 6, 27, "Text"],
Cell[382751, 10502, 295, 9, 49, "NE3",
  CellTags->"(4.2.22)"],
Cell[383049, 10513, 583, 20, 44, "Text"],
Cell[383635, 10535, 333, 8, 30, "NE3",
  CellTags->{"i:36", "(4.2.23)"}],
Cell[383971, 10545, 659, 24, 61, "Text"],
Cell[384633, 10571, 270, 8, 30, "NE3",
  CellTags->"(4.2.24)"],
Cell[384906, 10581, 492, 13, 62, "Text"],
Cell[385401, 10596, 173, 6, 42, "NE3",
  CellTags->"(4.2.25)"],
Cell[385577, 10604, 574, 19, 64, "Text"],
Cell[386154, 10625, 404, 9, 39, "NE3",
  CellTags->"(4.2.26)"],
Cell[386561, 10636, 143, 5, 27, "Text"],
Cell[386707, 10643, 308, 8, 38, "NE3",
  CellTags->"(4.2.27)"],
Cell[387018, 10653, 682, 18, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[387737, 10676, 50, 1, 31, "Section",
  CellTags->"c:19"],
Cell[387790, 10679, 275, 6, 61, "Text",
  CellTags->"i:39"],
Cell[388068, 10687, 622, 13, 88, "Text"],
Cell[388693, 10702, 442, 7, 50, "NE3",
  CellTags->"(4.2.28)"],
Cell[389138, 10711, 219, 8, 27, "Text"],
Cell[389360, 10721, 865, 23, 48, "Text"],
Cell[390228, 10746, 801, 22, 65, "Text"],
Cell[391032, 10770, 695, 14, 48, "Text"],
Cell[391730, 10786, 319, 11, 48, "Text"],
Cell[392052, 10799, 162, 6, 38, "NE3",
  CellTags->"(4.2.29)"],
Cell[392217, 10807, 424, 14, 44, "Text"],
Cell[392644, 10823, 985, 30, 75, "Text"],
Cell[393632, 10855, 1024, 28, 42, "Text"],
Cell[394659, 10885, 949, 26, 88, "Text"],
Cell[395611, 10913, 416, 13, 38, "NE3",
  CellTags->"(4.2.30)"],
Cell[396030, 10928, 330, 12, 27, "Text"],
Cell[396363, 10942, 250, 7, 36, "Text"],
Cell[396616, 10951, 871, 25, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[397524, 10981, 74, 1, 31, "Section",
  CellTags->"c:20"],
Cell[397601, 10984, 931, 30, 78, "Text",
  CellTags->"i:119"],
Cell[398535, 11016, 155, 5, 27, "Text"],
Cell[398693, 11023, 188, 6, 42, "NE3",
  CellTags->"(4.2.31)"],
Cell[398884, 11031, 703, 19, 119, "Text"],
Cell[399590, 11052, 172, 6, 35, "NE3",
  CellTags->"(4.2.32)"],
Cell[399765, 11060, 758, 25, 44, "Text"],
Cell[400526, 11087, 712, 21, 42, "NE3",
  CellTags->"(4.2.33)"],
Cell[401241, 11110, 651, 19, 27, "Text"],
Cell[401895, 11131, 283, 8, 42, "NE3",
  CellTags->"(4.2.34)"],
Cell[402181, 11141, 325, 10, 57, "Text"],
Cell[402509, 11153, 208, 6, 42, "NE3",
  CellTags->"(4.2.35)"],
Cell[402720, 11161, 365, 10, 44, "Text"],
Cell[403088, 11173, 144, 5, 29, "NE3",
  CellTags->"(4.2.36)"],
Cell[403235, 11180, 39, 0, 27, "Text"],
Cell[403277, 11182, 269, 9, 32, "NE3",
  CellTags->"(4.2.37)"],
Cell[403549, 11193, 343, 12, 27, "Text"],
Cell[403895, 11207, 387, 11, 28, "NE3",
  CellTags->"(4.2.38)"],
Cell[404285, 11220, 701, 24, 44, "Text"],
Cell[404989, 11246, 349, 9, 42, "NE3",
  CellTags->"(4.2.39)"],
Cell[405341, 11257, 416, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[405782, 11274, 344, 8, 143, "Input",
  CellTags->"Cell 4.9"],
Cell[406129, 11284, 79, 1, 67, "Output"]
}, Open  ]],
Cell[406223, 11288, 140, 6, 27, "Text"],
Cell[406366, 11296, 307, 8, 40, "NE3",
  CellTags->"(4.2.40)"],
Cell[406676, 11306, 136, 3, 27, "Text"],
Cell[406815, 11311, 407, 11, 44, "Text"],
Cell[407225, 11324, 356, 9, 38, "Text"],
Cell[407584, 11335, 131, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[407740, 11344, 370, 7, 160, "Input",
  CellTags->"Cell 4.10"],
Cell[408113, 11353, 312, 5, 73, "Output"]
}, Open  ]],
Cell[408440, 11361, 422, 15, 44, "Text"],
Cell[408865, 11378, 192, 5, 86, "Input",
  CellTags->"Cell 4.11"],
Cell[409060, 11385, 1372, 46, 61, "Text"],
Cell[410435, 11433, 98, 3, 67, "Input",
  CellTags->"Cell 4.12"],
Cell[410536, 11438, 414, 14, 27, "Text"],
Cell[410953, 11454, 258, 6, 105, "Input",
  CellTags->"Cell 4.13"],
Cell[411214, 11462, 606, 22, 44, "Text"],

Cell[CellGroupData[{
Cell[411845, 11488, 528, 12, 185, "Input",
  CellTags->"Cell 4.14"],

Cell[CellGroupData[{
Cell[412398, 11504, 24745, 696, 233, 7648, 481, "GraphicsData", "PostScript", \
"Graphics"],
Cell[437146, 12202, 31039, 1056, 70, 13132, 831, "GraphicsData", \
"PostScript", "Graphics"],
Cell[468188, 13260, 30607, 1023, 70, 12611, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[498798, 14285, 31025, 1025, 70, 12510, 792, "GraphicsData", \
"PostScript", "Graphics"],
Cell[529826, 15312, 30172, 984, 70, 11933, 755, "GraphicsData", "PostScript", \
"Graphics"],
Cell[560001, 16298, 30283, 960, 70, 11444, 723, "GraphicsData", "PostScript", \
"Graphics"],
Cell[590287, 17260, 29474, 918, 70, 10850, 684, "GraphicsData", "PostScript", \
"Graphics"],
Cell[619764, 18180, 29354, 904, 70, 10596, 668, "GraphicsData", "PostScript", \
"Graphics"],
Cell[649121, 19086, 28633, 894, 70, 10560, 667, "GraphicsData", "PostScript", \
"Graphics"],
Cell[677757, 19982, 28794, 897, 70, 10591, 668, "GraphicsData", "PostScript", \
"Graphics"],
Cell[706554, 20881, 28463, 906, 70, 10807, 684, "GraphicsData", "PostScript", \
"Graphics"],
Cell[735020, 21789, 28688, 908, 70, 10817, 683, "GraphicsData", "PostScript", \
"Graphics"],
Cell[763711, 22699, 28455, 905, 70, 10823, 683, "GraphicsData", "PostScript", \
"Graphics"],
Cell[792169, 23606, 28684, 883, 70, 10356, 653, "GraphicsData", "PostScript", \
"Graphics"],
Cell[820856, 24491, 28669, 882, 70, 10316, 651, "GraphicsData", "PostScript", \
"Graphics"],
Cell[849528, 25375, 29068, 882, 70, 10246, 646, "GraphicsData", "PostScript", \
"Graphics"],
Cell[878599, 26259, 28414, 855, 70, 9851, 622, "GraphicsData", "PostScript", \
"Graphics"],
Cell[907016, 27116, 28889, 855, 70, 9722, 614, "GraphicsData", "PostScript", \
"Graphics"],
Cell[935908, 27973, 28201, 817, 70, 9184, 578, "GraphicsData", "PostScript", \
"Graphics"],
Cell[964112, 28792, 27399, 759, 70, 8257, 519, "GraphicsData", "PostScript", \
"Graphics"],
Cell[991514, 29553, 27434, 793, 70, 8891, 560, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1018951, 30348, 27832, 808, 70, 9091, 573, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1046786, 31158, 27219, 805, 70, 9162, 578, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1074008, 31965, 27489, 826, 70, 9533, 600, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1101500, 32793, 27106, 824, 70, 9559, 603, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1128609, 33619, 27676, 830, 70, 9542, 602, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1156288, 34451, 27608, 823, 70, 9450, 595, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1183899, 35276, 27918, 821, 70, 9331, 588, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1211820, 36099, 27360, 800, 70, 9056, 570, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1239183, 36901, 27777, 791, 70, 8776, 552, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1266963, 37694, 27511, 781, 70, 8648, 544, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1294477, 38477, 27655, 779, 70, 8590, 540, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1322135, 39258, 27161, 773, 70, 8578, 540, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1349299, 40033, 27425, 775, 70, 8546, 538, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1376727, 40810, 26911, 777, 70, 8712, 548, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1403641, 41589, 27557, 824, 70, 9468, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1431201, 42415, 27400, 846, 70, 9930, 626, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1458604, 43263, 28199, 866, 70, 10138, 639, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1486806, 44131, 28509, 890, 70, 10513, 664, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1515318, 45023, 28526, 866, 70, 10048, 634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1543847, 45891, 28323, 851, 70, 9796, 618, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1572173, 46744, 28730, 840, 70, 9511, 599, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1600906, 47586, 27822, 787, 70, 8692, 547, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1628731, 48375, 27671, 764, 70, 8265, 520, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1656405, 49141, 27072, 753, 70, 8201, 516, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1683480, 49896, 27396, 756, 70, 8189, 515, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1710879, 50654, 27103, 764, 70, 8406, 529, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1737985, 51420, 27137, 776, 70, 8651, 544, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1765125, 52198, 26777, 791, 70, 9028, 568, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1791905, 52991, 27301, 804, 70, 9139, 576, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1819209, 53797, 27329, 809, 70, 9240, 582, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1846541, 54608, 27642, 808, 70, 9136, 576, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1874186, 55418, 27786, 827, 70, 9470, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1901975, 56247, 27909, 798, 70, 8876, 559, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1929887, 57047, 27819, 794, 70, 8818, 555, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1957709, 57843, 27929, 784, 70, 8600, 541, "GraphicsData", "PostScript", \
"Graphics"],
Cell[1985641, 58629, 27505, 781, 70, 8646, 544, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2013149, 59412, 27792, 780, 70, 8565, 539, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2040944, 60194, 27484, 780, 70, 8650, 544, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2068431, 60976, 27853, 813, 70, 9197, 579, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2096287, 61791, 9871, 616, 70, 9686, 611, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[2106185, 62411, 438, 7, 78, "Text"],
Cell[2106626, 62420, 839, 18, 99, "Text"],
Cell[2107468, 62440, 325, 6, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2107830, 62451, 67, 1, 31, "Section",
  CellTags->"c:21"],
Cell[2107900, 62454, 625, 15, 78, "Text"],
Cell[2108528, 62471, 491, 14, 44, "Text"],
Cell[2109022, 62487, 252, 7, 43, "NE3",
  CellTags->"(4.2.41)"],
Cell[2109277, 62496, 917, 23, 95, "Text"],
Cell[2110197, 62521, 175, 6, 29, "NE3",
  CellTags->"(4.2.42)"],
Cell[2110375, 62529, 40, 0, 27, "Text"],
Cell[2110418, 62531, 262, 7, 39, "NE3",
  CellTags->"(4.2.43)"],
Cell[2110683, 62540, 443, 15, 44, "Text"],
Cell[2111129, 62557, 289, 8, 57, "NE3",
  CellTags->"(4.2.44)"],
Cell[2111421, 62567, 119, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[2111565, 62576, 190, 5, 70, "Input",
  CellTags->"Cell 4.15"],
Cell[2111758, 62583, 169, 3, 70, "Output"]
}, Open  ]],
Cell[2111942, 62589, 724, 24, 70, "Text"],
Cell[2112669, 62615, 146, 5, 70, "NE3",
  CellTags->"(4.2.45)"],
Cell[2112818, 62622, 42, 0, 70, "Text"],
Cell[2112863, 62624, 187, 6, 70, "NE3",
  CellTags->{"i:41", "(4.2.46)"}],
Cell[2113053, 62632, 168, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[2113246, 62642, 584, 12, 70, "Input",
  CellTags->"Cell 4.16"],
Cell[2113833, 62656, 38231, 851, 279, 7221, 464, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[2152079, 63510, 1057, 23, 129, "Text"],
Cell[2153139, 63535, 521, 15, 55, "Text"],
Cell[2153663, 63552, 255, 8, 27, "Text"],
Cell[2153921, 63562, 520, 12, 51, "Text"],
Cell[2154444, 63576, 183, 5, 27, "Text"],
Cell[2154630, 63583, 276, 8, 48, "Text"],
Cell[2154909, 63593, 422, 8, 61, "Text"],
Cell[2155334, 63603, 1236, 35, 117, "Text"],

Cell[CellGroupData[{
Cell[2156595, 63642, 1159, 26, 400, "Input",
  CellTags->"Cell 4.17"],

Cell[CellGroupData[{
Cell[2157779, 63672, 29066, 702, 373, 5320, 404, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2186848, 64376, 5546, 410, 70, 5317, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2192397, 64788, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2197948, 65200, 5553, 410, 70, 5324, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2203504, 65612, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2209055, 66024, 5333, 410, 70, 5104, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2214391, 66436, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2219942, 66848, 5553, 410, 70, 5324, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2225498, 67260, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2231049, 67672, 5546, 410, 70, 5317, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2236598, 68084, 5549, 410, 70, 5320, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2242150, 68496, 5546, 410, 70, 5317, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2247699, 68908, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2253250, 69320, 5553, 410, 70, 5324, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2258806, 69732, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2264357, 70144, 5333, 410, 70, 5104, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2269693, 70556, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2275244, 70968, 5553, 410, 70, 5324, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2280800, 71380, 5548, 410, 70, 5319, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[2286351, 71792, 5546, 410, 70, 5317, 404, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[2291924, 72206, 177, 6, 27, "Text"],
Cell[2292104, 72214, 1373, 35, 141, "Text"],
Cell[2293480, 72251, 253, 8, 28, "Text"],
Cell[2293736, 72261, 1493, 48, 100, "Text"],

Cell[CellGroupData[{
Cell[2295254, 72313, 1401, 31, 428, "Input",
  CellTags->"Cell 4.18"],

Cell[CellGroupData[{
Cell[2296680, 72348, 31383, 1097, 353, 12705, 862, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2328066, 73447, 31476, 1091, 70, 12223, 849, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2359545, 74540, 30291, 1019, 70, 11329, 780, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2389839, 75561, 30349, 979, 70, 11140, 737, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2420191, 76542, 29397, 860, 70, 10383, 621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2449591, 77404, 29356, 858, 70, 10091, 616, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2478950, 78264, 30823, 959, 70, 11712, 719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2509776, 79225, 31843, 985, 70, 12456, 741, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2541622, 80212, 28519, 786, 70, 9367, 545, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2570144, 81000, 28970, 802, 70, 9539, 558, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2599117, 81804, 27389, 700, 70, 8091, 457, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2626509, 82506, 26021, 595, 70, 6436, 349, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2652533, 83103, 25744, 582, 70, 6252, 337, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2678280, 83687, 25722, 568, 70, 5959, 320, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2704005, 84257, 25239, 549, 70, 5682, 303, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2729247, 84808, 25392, 544, 70, 5572, 295, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2754642, 85354, 25159, 539, 70, 5537, 292, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2779804, 85895, 25375, 545, 70, 5616, 297, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2805182, 86442, 25277, 556, 70, 5821, 311, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2830462, 87000, 25310, 551, 70, 5733, 305, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2855775, 87553, 24097, 508, 70, 5188, 270, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2879875, 88063, 24484, 509, 70, 5130, 266, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2904362, 88574, 24097, 505, 70, 5148, 267, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2928462, 89081, 24287, 508, 70, 5139, 267, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2952752, 89591, 24144, 511, 70, 5231, 273, "GraphicsData", "PostScript", \
"Graphics"],
Cell[2976899, 90104, 24866, 546, 70, 5755, 306, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3001768, 90652, 24617, 541, 70, 5712, 303, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3026388, 91195, 24535, 526, 70, 5452, 286, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3050926, 91723, 24269, 519, 70, 5360, 281, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3075198, 92244, 24401, 520, 70, 5375, 281, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3099602, 92766, 24165, 515, 70, 5317, 278, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3123770, 93283, 24613, 528, 70, 5457, 287, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3148386, 93813, 24520, 531, 70, 5542, 292, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3172909, 94346, 24764, 533, 70, 5519, 291, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3197676, 94881, 24528, 531, 70, 5542, 292, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3222207, 95414, 24828, 538, 70, 5603, 296, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3247038, 95954, 24943, 555, 70, 5921, 316, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3271984, 96511, 26201, 618, 70, 6790, 374, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3298188, 97131, 25894, 621, 70, 6908, 382, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3324085, 97754, 25214, 560, 70, 5941, 318, "GraphicsData", "PostScript", \
"Graphics"],
Cell[3349302, 98316, 24827, 563, 70, 6084, 327, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[3374156, 98883, 496, 10, 78, "Text",
  CellTags->"i:42"],
Cell[3374655, 98895, 503, 10, 78, "Text"],

Cell[CellGroupData[{
Cell[3375183, 98909, 255, 5, 86, "Input",
  CellTags->"Cell 4.19"],
Cell[3375441, 98916, 40530, 992, 233, 9945, 610, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[3415986, 99911, 930, 16, 129, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3416965, 99933, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 4.2", "c:22"}],
Cell[3417046, 99936, 257, 8, 44, "Text"],
Cell[3417306, 99946, 586, 20, 65, "Text"],
Cell[3417895, 99968, 873, 24, 82, "Text"],
Cell[3418771, 99994, 731, 22, 58, "Text"],
Cell[3419505, 100018, 2224, 62, 137, "Text"],
Cell[3421732, 100082, 656, 20, 64, "Text",
  CellTags->"i:117"],
Cell[3422391, 100104, 589, 20, 44, "Text"],
Cell[3422983, 100126, 1626, 44, 102, "Text"],
Cell[3424612, 100172, 1546, 47, 107, "Text",
  CellTags->"i:43"],
Cell[3426161, 100221, 5587, 175, 116, "Text"],
Cell[3431751, 100398, 506, 15, 61, "Text",
  CellTags->"i:46"],
Cell[3432260, 100415, 421, 14, 40, "Text"],
Cell[3432684, 100431, 977, 30, 88, "Text"],
Cell[3433664, 100463, 445, 15, 44, "Text",
  CellTags->"i:44"],
Cell[3434112, 100480, 239, 4, 45, "NE3",
  CellTags->"(4.2.47)"],
Cell[3434354, 100486, 860, 29, 74, "Text"],
Cell[3435217, 100517, 172, 6, 41, "Text"],
Cell[3435392, 100525, 402, 10, 61, "Text"],
Cell[3435797, 100537, 256, 8, 32, "Text"],
Cell[3436056, 100547, 633, 20, 61, "Text",
  CellTags->"i:45"],
Cell[3436692, 100569, 142, 4, 27, "Text"],
Cell[3436837, 100575, 249, 7, 42, "NE3",
  CellTags->"(4.2.48)"],
Cell[3437089, 100584, 355, 10, 44, "Text"],
Cell[3437447, 100596, 152, 5, 33, "NE3",
  CellTags->{"i:47", "(4.2.49)"}],
Cell[3437602, 100603, 275, 7, 44, "Text"],
Cell[3437880, 100612, 495, 17, 44, "Text"],
Cell[3438378, 100631, 465, 12, 61, "Text"],
Cell[3438846, 100645, 213, 8, 27, "Text"],
Cell[3439062, 100655, 213, 6, 44, "Text"],
Cell[3439278, 100663, 266, 8, 44, "Text"],
Cell[3439547, 100673, 705, 24, 61, "Text"],
Cell[3440255, 100699, 335, 11, 44, "Text"],
Cell[3440593, 100712, 192, 6, 29, "NE3",
  CellTags->"(4.2.50)"],
Cell[3440788, 100720, 56, 0, 27, "Text"],
Cell[3440847, 100722, 557, 15, 42, "NE3",
  CellTags->{"i:48", "(4.2.51)"}],
Cell[3441407, 100739, 192, 7, 31, "Text"],
Cell[3441602, 100748, 2187770, 30097, 122, 2152029, 29651, "GraphicsData", \
"PostScript", "Picture"],
Cell[5629375, 130847, 65, 1, 16, "Caption",
  CellTags->"Fig. 4.2"],
Cell[5629443, 130850, 303, 9, 44, "Text",
  CellTags->"i:49"],
Cell[5629749, 130861, 148, 6, 32, "Text"],
Cell[5629900, 130869, 1175, 37, 82, "Text"],
Cell[5631078, 130908, 386, 12, 44, "Text"],
Cell[5631467, 130922, 238, 9, 34, "Text"],
Cell[5631708, 130933, 883, 26, 78, "Text",
  CellTags->"i:51"],
Cell[5632594, 130961, 225, 7, 40, "Text"],
Cell[5632822, 130970, 456, 14, 61, "Text"],
Cell[5633281, 130986, 11026, 140, 89, 10905, 136, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[5644310, 131128, 66, 1, 16, "Caption",
  CellTags->"Fig. 4.3"],
Cell[5644379, 131131, 198, 5, 44, "Text"],
Cell[5644580, 131138, 131, 5, 27, "Text"],
Cell[5644714, 131145, 539, 15, 82, "Text"],
Cell[5645256, 131162, 265, 10, 27, "Text"],
Cell[5645524, 131174, 387, 12, 44, "Text"],
Cell[5645914, 131188, 540, 16, 43, "Text"],
Cell[5646457, 131206, 132, 4, 27, "Text"],
Cell[5646592, 131212, 1260, 35, 85, "Text"],
Cell[5647855, 131249, 1537, 42, 131, "Text"],
Cell[5649395, 131293, 558, 17, 64, "Text"],
Cell[5649956, 131312, 903, 31, 61, "Text"],
Cell[5650862, 131345, 603, 16, 78, "Text"],
Cell[5651468, 131363, 382, 12, 49, "Text"],
Cell[5651853, 131377, 951, 33, 78, "Text"],
Cell[5652807, 131412, 668, 20, 66, "Text"],
Cell[5653478, 131434, 1606, 44, 124, "Text"],
Cell[5655087, 131480, 579, 16, 66, "Text"],
Cell[5655669, 131498, 1073, 35, 48, "Text"],
Cell[5656745, 131535, 499, 14, 61, "Text"],
Cell[5657247, 131551, 441, 12, 63, "Text"],
Cell[5657691, 131565, 849, 24, 78, "Text",
  CellTags->"i:50"],
Cell[5658543, 131591, 432, 10, 61, "Text"],
Cell[5658978, 131603, 1293, 40, 86, "Text"],
Cell[5660274, 131645, 349, 12, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[5660672, 131663, 90, 1, 40, "Subtitle",
  CellTags->"c:23"],
Cell[5660765, 131666, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5660806, 131670, 91, 1, 41, "Subsubtitle",
  CellTags->"c:24"],
Cell[5660900, 131673, 286, 9, 27, "Text",
  CellTags->"i:52"],
Cell[5661189, 131684, 146, 5, 32, "NE4",
  CellTags->"(4.3.1)"],
Cell[5661338, 131691, 1548, 46, 81, "Text",
  CellTags->"i:109"],
Cell[5662889, 131739, 549, 16, 61, "Text",
  CellTags->"i:62"],
Cell[5663441, 131757, 1224, 36, 63, "Text",
  CellTags->"i:53"],
Cell[5664668, 131795, 577, 18, 34, "NE4",
  CellTags->"(4.3.2)"],
Cell[5665248, 131815, 573, 16, 66, "Text"],
Cell[5665824, 131833, 348, 9, 44, "Text",
  CellTags->"i:54"],
Cell[5666175, 131844, 1378, 45, 29, "NE4",
  CellTags->"(4.3.3)"],
Cell[5667556, 131891, 597, 18, 44, "Text"],
Cell[5668156, 131911, 164, 3, 31, "NE4",
  CellTags->"(4.3.4)"],
Cell[5668323, 131916, 22, 0, 27, "Text"],
Cell[5668348, 131918, 171, 6, 32, "NE4",
  CellTags->"(4.3.5)"],
Cell[5668522, 131926, 151, 3, 27, "Text"],
Cell[5668676, 131931, 1063, 34, 81, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5669776, 131970, 65, 1, 30, "Subsubtitle",
  CellTags->"c:25"],
Cell[5669844, 131973, 965, 33, 27, "Text"],
Cell[5670812, 132008, 982, 30, 32, "NE4",
  CellTags->{"i:55", "(4.3.6)"}],
Cell[5671797, 132040, 1546, 52, 64, "Text"],
Cell[5673346, 132094, 544, 17, 29, "NE4",
  CellTags->"(4.3.7)"],
Cell[5673893, 132113, 1614, 52, 61, "Text",
  CellTags->"i:111"],
Cell[5675510, 132167, 1128, 35, 41, "NE4",
  CellTags->{"i:56", "(4.3.8)"}],
Cell[5676641, 132204, 280, 7, 44, "Text"],
Cell[5676924, 132213, 477, 14, 44, "Text"],
Cell[5677404, 132229, 1518, 41, 41, "NE4",
  CellTags->{"i:59", "(4.3.9)"}],
Cell[5678925, 132272, 613, 21, 47, "Text"],
Cell[5679541, 132295, 3453, 85, 43, "NE4",
  CellTags->"(4.3.10)"],
Cell[5682997, 132382, 891, 30, 61, "Text"],
Cell[5683891, 132414, 1923, 61, 96, "Text"],
Cell[5685817, 132477, 699, 22, 34, "Text"],
Cell[5686519, 132501, 213, 7, 27, "Text"],
Cell[5686735, 132510, 784, 23, 43, "NE4",
  CellTags->"(4.3.11)"]
}, Closed]],

Cell[CellGroupData[{
Cell[5687556, 132538, 183, 6, 30, "Subsubtitle",
  CellTags->"c:26"],
Cell[5687742, 132546, 518, 15, 44, "Text",
  CellTags->"i:107"],
Cell[5688263, 132563, 620, 19, 32, "NE4",
  CellTags->"(4.3.12)"],
Cell[5688886, 132584, 770, 20, 78, "Text",
  CellTags->"i:71"],
Cell[5689659, 132606, 140, 4, 27, "Text",
  CellTags->"i:73"],
Cell[5689802, 132612, 665, 20, 34, "NE4",
  CellTags->"(4.3.13)"],
Cell[5690470, 132634, 508, 9, 78, "Text",
  CellTags->"i:72"],
Cell[5690981, 132645, 165, 5, 30, "Text"],
Cell[5691149, 132652, 710, 21, 32, "Text"],
Cell[5691862, 132675, 98, 3, 27, "Text"],
Cell[5691963, 132680, 1289, 35, 32, "Text"],
Cell[5693255, 132717, 648, 19, 68, "Text"],
Cell[5693906, 132738, 118, 3, 27, "Text"],
Cell[5694027, 132743, 686, 21, 29, "NE4",
  CellTags->"(4.3.14)"],
Cell[5694716, 132766, 342, 13, 27, "Text"],
Cell[5695061, 132781, 914, 27, 36, "Text"],
Cell[5695978, 132810, 435, 14, 46, "Text"],
Cell[5696416, 132826, 1173, 32, 32, "Text"],
Cell[5697592, 132860, 609, 18, 61, "Text"],
Cell[5698204, 132880, 559, 17, 34, "NE4",
  CellTags->"(4.3.15)"],
Cell[5698766, 132899, 229, 7, 27, "Text",
  CellTags->"i:57"],
Cell[5698998, 132908, 1065, 29, 45, "NE4",
  CellTags->"(4.3.16)"],
Cell[5700066, 132939, 781, 22, 78, "Text",
  CellTags->"i:58"],
Cell[5700850, 132963, 706, 19, 43, "NE4",
  CellTags->"(4.3.17)"],
Cell[5701559, 132984, 465, 16, 27, "Text"],
Cell[5702027, 133002, 1060, 33, 78, "Text",
  CellTags->"i:60"],
Cell[5703090, 133037, 1576, 41, 132, "Text",
  CellTags->"i:61"],
Cell[5704669, 133080, 764, 22, 65, "Text"],
Cell[5705436, 133104, 1013, 31, 83, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5706486, 133140, 174, 6, 30, "Subsubtitle",
  CellTags->{"i:63", "c:27"}],

Cell[CellGroupData[{
Cell[5706685, 133150, 51, 1, 42, "Section",
  CellTags->"c:28"],
Cell[5706739, 133153, 1055, 25, 115, "Text",
  CellTags->"i:120"]
}, Closed]],

Cell[CellGroupData[{
Cell[5707831, 133183, 59, 1, 31, "Section",
  CellTags->"c:29"],

Cell[CellGroupData[{
Cell[5707915, 133188, 109, 2, 27, "Subsubsection",
  CellTags->"i:64"],
Cell[5708027, 133192, 650, 17, 81, "Text"],
Cell[5708680, 133211, 83675, 1036, 223, 83553, 1032, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[5792358, 134249, 144, 4, 16, "Caption",
  CellTags->"Fig. 4.4"],
Cell[5792505, 134255, 233, 6, 44, "Text"],
Cell[5792741, 134263, 143, 3, 27, "NE4",
  CellTags->"(4.3.18)"],
Cell[5792887, 134268, 481, 19, 27, "Text"],
Cell[5793371, 134289, 269, 8, 45, "NE4",
  CellTags->"(4.3.19)"],
Cell[5793643, 134299, 174, 5, 30, "Text"],
Cell[5793820, 134306, 189, 4, 44, "NE4",
  CellTags->"(4.3.20)"],
Cell[5794012, 134312, 206, 4, 45, "NE4",
  CellTags->"(4.3.21)"],
Cell[5794221, 134318, 220, 6, 27, "Text"],
Cell[5794444, 134326, 149, 5, 29, "NE4",
  CellTags->"(4.3.22)"],
Cell[5794596, 134333, 433, 15, 44, "Text"],
Cell[5795032, 134350, 118, 5, 29, "NE4",
  CellTags->"(4.3.23)"],
Cell[5795153, 134357, 200, 7, 29, "NE4",
  CellTags->"(4.3.24)"],
Cell[5795356, 134366, 148, 6, 27, "Text"],
Cell[5795507, 134374, 198, 7, 29, "NE4",
  CellTags->"(4.3.25)"],
Cell[5795708, 134383, 291, 10, 30, "Text"],
Cell[5796002, 134395, 282, 9, 38, "NE4",
  CellTags->"(4.3.26)"],
Cell[5796287, 134406, 202, 5, 27, "Text"],
Cell[5796492, 134413, 369, 12, 29, "NE4",
  CellTags->"(4.3.27)"],
Cell[5796864, 134427, 564, 17, 61, "Text"],
Cell[5797431, 134446, 519, 13, 66, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5797987, 134464, 142, 2, 29, "Subsubsection"],
Cell[5798132, 134468, 505, 16, 44, "Text"],
Cell[5798640, 134486, 470, 14, 44, "Text"],
Cell[5799113, 134502, 265, 10, 27, "Text"],
Cell[5799381, 134514, 319, 9, 32, "Text"],
Cell[5799703, 134525, 134, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[5799862, 134534, 517, 12, 174, "Input",
  CellTags->"Cell 4.20"],
Cell[5800382, 134548, 195, 3, 77, "Output"]
}, Open  ]],
Cell[5800592, 134554, 1368, 43, 93, "Text"],

Cell[CellGroupData[{
Cell[5801985, 134601, 685, 15, 254, "Input",
  CellTags->"Cell 4.21"],
Cell[5802673, 134618, 110697, 2078, 302, 26130, 1029, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5913385, 136699, 156, 3, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5913578, 136707, 137, 4, 29, "Subsubsection",
  CellTags->"i:67"],
Cell[5913718, 136713, 952, 27, 81, "Text"],
Cell[5914673, 136742, 86478, 1071, 233, 86356, 1067, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[6001154, 137815, 51, 1, 16, "Caption",
  CellTags->"Fig. 4.5"],
Cell[6001208, 137818, 587, 13, 78, "Text"],
Cell[6001798, 137833, 181, 6, 29, "NE4",
  CellTags->"(4.3.28)"],
Cell[6001982, 137841, 315, 11, 44, "Text"],
Cell[6002300, 137854, 573, 15, 49, "NE4",
  CellTags->"(4.3.29)"],
Cell[6002876, 137871, 633, 20, 65, "Text"],
Cell[6003512, 137893, 424, 9, 50, "NE4",
  CellTags->"(4.3.30)"],
Cell[6003939, 137904, 784, 27, 74, "Text"],

Cell[CellGroupData[{
Cell[6004748, 137935, 602, 14, 200, "Input",
  CellTags->"Cell 4.22"],
Cell[6005353, 137951, 136, 2, 74, "Output"]
}, Open  ]],
Cell[6005504, 137956, 454, 16, 27, "Text"],

Cell[CellGroupData[{
Cell[6005983, 137976, 693, 15, 250, "Input",
  CellTags->"Cell 4.23"],
Cell[6006679, 137993, 201797, 3852, 302, 77459, 2312, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6208491, 141848, 614, 21, 61, "Text"],

Cell[CellGroupData[{
Cell[6209130, 141873, 116, 3, 67, "Input",
  CellTags->"Cell 4.24"],
Cell[6209249, 141878, 48185, 1080, 233, 8882, 590, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6257449, 142961, 369, 9, 44, "Text"],
Cell[6257821, 142972, 256, 7, 44, "Text"],
Cell[6258080, 142981, 202, 4, 28, "NE4",
  CellTags->"(4.3.31)"],
Cell[6258285, 142987, 1145, 33, 95, "Text"],
Cell[6259433, 143022, 430, 14, 44, "Text"],
Cell[6259866, 143038, 206, 4, 44, "Text"],
Cell[6260075, 143044, 227, 9, 27, "Text"],
Cell[6260305, 143055, 508, 12, 71, "NE4",
  CellTags->"(4.3.32)"],
Cell[6260816, 143069, 502, 16, 61, "Text"],

Cell[CellGroupData[{
Cell[6261343, 143089, 743, 17, 241, "Input",
  CellTags->"Cell 4.25"],
Cell[6262089, 143108, 200894, 3845, 302, 77622, 2319, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6462998, 146956, 409, 9, 61, "Text"],

Cell[CellGroupData[{
Cell[6463432, 146969, 252, 5, 86, "Input",
  CellTags->"Cell 4.26"],
Cell[6463687, 146976, 49241, 1337, 233, 15061, 911, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6512943, 148316, 604, 13, 78, "Text",
  CellTags->"i:113"],
Cell[6513550, 148331, 446, 9, 78, "Text"],
Cell[6513999, 148342, 630, 14, 95, "Text"],
Cell[6514632, 148358, 2434, 61, 206, "Text",
  CellTags->"Table 4.1"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6517115, 148425, 59, 1, 31, "Section",
  CellTags->"c:30"],

Cell[CellGroupData[{
Cell[6517199, 148430, 109, 2, 27, "Subsubsection",
  CellTags->"i:65"],
Cell[6517311, 148434, 500, 16, 70, "Text"],
Cell[6517814, 148452, 53, 0, 70, "Text"],
Cell[6517870, 148454, 200, 6, 70, "NE4",
  CellTags->"(4.3.33)"],
Cell[6518073, 148462, 387, 13, 70, "Text"],
Cell[6518463, 148477, 411, 7, 70, "NE4",
  CellTags->"(4.3.34)"],
Cell[6518877, 148486, 263, 9, 30, "Text"],
Cell[6519143, 148497, 277, 7, 42, "NE4",
  CellTags->"(4.3.35)"],
Cell[6519423, 148506, 203, 7, 42, "NE4",
  CellTags->"(4.3.36)"],
Cell[6519629, 148515, 169, 6, 43, "NE4",
  CellTags->"(4.3.37)"],
Cell[6519801, 148523, 294, 6, 44, "Text"],
Cell[6520098, 148531, 290, 11, 29, "NE4",
  CellTags->"(4.3.38)"],
Cell[6520391, 148544, 32, 0, 27, "Text"],
Cell[6520426, 148546, 118, 5, 29, "NE4",
  CellTags->"(4.3.39)"],
Cell[6520547, 148553, 385, 8, 44, "Text"],
Cell[6520935, 148563, 292, 10, 32, "NE4",
  CellTags->"(4.3.40)"],
Cell[6521230, 148575, 388, 10, 47, "Text"],
Cell[6521621, 148587, 157, 6, 38, "NE4",
  CellTags->"(4.3.41)"],
Cell[6521781, 148595, 170, 6, 27, "Text"],
Cell[6521954, 148603, 253, 7, 42, "NE4",
  CellTags->"(4.3.42)"],
Cell[6522210, 148612, 72, 0, 27, "Text"],
Cell[6522285, 148614, 255, 7, 42, "NE4",
  CellTags->"(4.3.43)"],
Cell[6522543, 148623, 763, 23, 78, "Text"],
Cell[6523309, 148648, 237, 8, 38, "NE4",
  CellTags->"(4.3.44)"],
Cell[6523549, 148658, 610, 24, 27, "Text"],
Cell[6524162, 148684, 58, 0, 27, "Text"],
Cell[6524223, 148686, 152, 5, 29, "NE4",
  CellTags->{"i:68", "(4.3.45)"}],
Cell[6524378, 148693, 158, 5, 30, "Text"],
Cell[6524539, 148700, 259, 7, 32, "NE4",
  CellTags->"(4.3.46)"],
Cell[6524801, 148709, 267, 10, 27, "Text"],
Cell[6525071, 148721, 185, 6, 46, "NE4",
  CellTags->"(4.3.47)"],
Cell[6525259, 148729, 390, 14, 27, "Text"],
Cell[6525652, 148745, 669, 16, 66, "Text"],
Cell[6526324, 148763, 296, 7, 42, "NE4",
  CellTags->"(4.3.48)"]
}, Closed]],

Cell[CellGroupData[{
Cell[6526657, 148775, 74, 1, 29, "Subsubsection"],
Cell[6526734, 148778, 1046, 26, 116, "Text"],
Cell[6527783, 148806, 218, 7, 70, "NE4",
  CellTags->"(4.3.49)"],
Cell[6528004, 148815, 358, 11, 70, "Text"],
Cell[6528365, 148828, 150, 3, 70, "NE4",
  CellTags->"(4.3.50)"],
Cell[6528518, 148833, 398, 12, 70, "Text"],
Cell[6528919, 148847, 469, 10, 70, "NE4",
  CellTags->"(4.3.51)"],
Cell[6529391, 148859, 564, 18, 70, "Text"],

Cell[CellGroupData[{
Cell[6529980, 148881, 312, 7, 70, "Input",
  CellTags->"Cell 4.27"],
Cell[6530295, 148890, 185, 3, 75, "Output"]
}, Open  ]],
Cell[6530495, 148896, 770, 25, 44, "Text"],
Cell[6531268, 148923, 205, 5, 105, "Input",
  CellTags->"Cell 4.28"],
Cell[6531476, 148930, 1541, 52, 44, "Text"],
Cell[6533020, 148984, 785, 16, 309, "Input",
  CellTags->"Cell 4.29"],
Cell[6533808, 149002, 3555, 111, 112, "Text"],

Cell[CellGroupData[{
Cell[6537388, 149117, 533, 10, 174, "Input",
  CellTags->"Cell 4.30"],
Cell[6537924, 149129, 120425, 2579, 490, 20874, 1345, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6658364, 151711, 223, 6, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6658636, 151723, 57, 1, 31, "Section",
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[6658718, 151728, 107, 2, 27, "Subsubsection",
  CellTags->"i:66"],
Cell[6658828, 151732, 619, 15, 64, "Text"],
Cell[6659450, 151749, 235, 7, 29, "NE4",
  CellTags->"(4.3.52)"],
Cell[6659688, 151758, 184, 6, 31, "Text"],
Cell[6659875, 151766, 565, 12, 45, "NE4",
  CellTags->"(4.3.53)"],
Cell[6660443, 151780, 354, 12, 44, "Text"],
Cell[6660800, 151794, 191, 3, 45, "NE4",
  CellTags->"(4.3.54)"],
Cell[6660994, 151799, 373, 8, 42, "NE4",
  CellTags->"(4.3.55)"],
Cell[6661370, 151809, 271, 7, 38, "NE4",
  CellTags->"(4.3.56)"],
Cell[6661644, 151818, 238, 8, 27, "Text"],
Cell[6661885, 151828, 441, 15, 44, "Text"],
Cell[6662329, 151845, 413, 14, 29, "Text"],
Cell[6662745, 151861, 839, 24, 115, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6663621, 151890, 113, 2, 29, "Subsubsection",
  CellTags->"i:69"],
Cell[6663737, 151894, 607, 18, 61, "Text"],

Cell[CellGroupData[{
Cell[6664369, 151916, 230, 6, 86, "Input",
  CellTags->"Cell 4.31"],
Cell[6664602, 151924, 216, 4, 107, "Output"]
}, Open  ]],
Cell[6664833, 151931, 990, 27, 88, "Text"],
Cell[6665826, 151960, 974, 25, 308, "Text",
  CellTags->"Table 4.2"],
Cell[6666803, 151987, 1093, 30, 308, "Text",
  CellTags->"Table 4.3"],
Cell[6667899, 152019, 287, 11, 27, "Text"],

Cell[CellGroupData[{
Cell[6668211, 152034, 384, 8, 143, "Input",
  CellTags->"Cell 4.32"],
Cell[6668598, 152044, 50377, 1335, 233, 15827, 904, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6719012, 153384, 392, 8, 147, "Input",
  CellTags->"Cell 4.33"],
Cell[6719407, 153394, 48286, 1347, 233, 16464, 950, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6767708, 154744, 163, 4, 44, "Text"],
Cell[6767874, 154750, 339, 6, 61, "Text"],
Cell[6768216, 154758, 222, 7, 34, "NE4",
  CellTags->"(4.3.57)"],
Cell[6768441, 154767, 635, 19, 61, "Text"],
Cell[6769079, 154788, 164, 6, 33, "NE4",
  CellTags->"(4.3.58)"],
Cell[6769246, 154796, 637, 22, 45, "Text"],
Cell[6769886, 154820, 204, 8, 30, "NE4",
  CellTags->"(4.3.59)"],
Cell[6770093, 154830, 307, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[6770425, 154843, 174, 5, 105, "Input",
  CellTags->"Cell 4.34"],
Cell[6770602, 154850, 259, 4, 65, "Output"]
}, Open  ]],
Cell[6770876, 154857, 196, 6, 27, "Text"],
Cell[6771075, 154865, 462, 13, 51, "NE4",
  CellTags->"(4.3.60)"],
Cell[6771540, 154880, 177, 6, 27, "Text"],
Cell[6771720, 154888, 468, 11, 51, "NE4",
  CellTags->{"i:70", "(4.3.61)"}],
Cell[6772191, 154901, 337, 10, 44, "Text"],
Cell[6772531, 154913, 299, 8, 34, "NE4",
  CellTags->{"i:78", "(4.3.62)"}],
Cell[6772833, 154923, 662, 19, 61, "Text"],
Cell[6773498, 154944, 360, 11, 44, "Text"],
Cell[6773861, 154957, 748, 15, 65, "NE4",
  CellTags->"(4.3.63)"],
Cell[6774612, 154974, 353, 11, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6775002, 154990, 74, 1, 29, "Subsubsection"],
Cell[6775079, 154993, 594, 17, 70, "Text"],
Cell[6775676, 155012, 82319, 1020, 70, 82197, 1016, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[6857998, 156034, 51, 1, 70, "Caption",
  CellTags->"Fig. 4.6"],
Cell[6858052, 156037, 413, 12, 70, "Text"],
Cell[6858468, 156051, 623, 19, 70, "NE4",
  CellTags->"(4.3.64)"],
Cell[6859094, 156072, 349, 9, 70, "Text"],
Cell[6859446, 156083, 472, 14, 70, "Text"],
Cell[6859921, 156099, 353, 8, 70, "NE4",
  CellTags->"(4.3.65)"],
Cell[6860277, 156109, 182, 5, 70, "Text"],
Cell[6860462, 156116, 497, 8, 70, "NE4",
  CellTags->"(4.3.66)"],
Cell[6860962, 156126, 268, 9, 70, "Text"],
Cell[6861233, 156137, 575, 18, 70, "Text"],
Cell[6861811, 156157, 377, 9, 70, "NE4",
  CellTags->"(4.3.67)"],
Cell[6862191, 156168, 582, 22, 70, "Text"],
Cell[6862776, 156192, 519, 12, 70, "NE4",
  CellTags->"(4.3.68)"],
Cell[6863298, 156206, 890, 25, 70, "Text"],
Cell[6864191, 156233, 439, 9, 70, "Input",
  CellTags->"Cell 4.35"],
Cell[6864633, 156244, 464, 18, 70, "Text"],
Cell[6865100, 156264, 232, 5, 70, "Input",
  CellTags->"Cell 4.36"],
Cell[6865335, 156271, 277, 9, 70, "Text"],

Cell[CellGroupData[{
Cell[6865637, 156284, 92, 3, 70, "Input",
  CellTags->"Cell 4.37"],
Cell[6865732, 156289, 79, 1, 70, "Output"]
}, Open  ]],
Cell[6865826, 156293, 320, 9, 70, "Text"],
Cell[6866149, 156304, 2042, 44, 70, "Input",
  CellTags->"Cell 4.38"],
Cell[6868194, 156350, 379, 13, 70, "Text"],
Cell[6868576, 156365, 450, 12, 70, "Input",
  CellTags->"Cell 4.39"],
Cell[6869029, 156379, 621, 20, 70, "Text"],

Cell[CellGroupData[{
Cell[6869675, 156403, 996, 20, 70, "Input",
  CellTags->"Cell 4.40"],
Cell[6870674, 156425, 244762, 12950, 70, 244539, 12944, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Open  ]],
Cell[7115451, 169378, 817, 20, 70, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7116329, 169405, 65, 1, 30, "Subsubtitle",
  CellTags->"c:32"],
Cell[7116397, 169408, 247, 9, 27, "Text"],
Cell[7116647, 169419, 324, 12, 30, "Text"],
Cell[7116974, 169433, 616, 20, 47, "Text"],
Cell[7117593, 169455, 330, 12, 30, "Text"],
Cell[7117926, 169469, 488, 15, 47, "Text"],
Cell[7118417, 169486, 701, 22, 40, "Text"],
Cell[7119121, 169510, 388, 13, 40, "Text"],
Cell[7119512, 169525, 91, 4, 27, "Text"],
Cell[7119606, 169531, 454, 12, 40, "Text"],
Cell[7120063, 169545, 1019, 31, 83, "Text"],
Cell[7121085, 169578, 563, 19, 44, "Text",
  CellTags->"i:76"],
Cell[7121651, 169599, 190, 6, 32, "Text"],
Cell[7121844, 169607, 250, 8, 27, "Text"],
Cell[7122097, 169617, 803, 25, 44, "Text"],
Cell[7122903, 169644, 436, 13, 61, "Text"],
Cell[7123342, 169659, 1136, 33, 32, "NE4",
  CellTags->"(4.3.69)"],
Cell[7124481, 169694, 195, 7, 27, "Text"],
Cell[7124679, 169703, 483, 17, 41, "Text"],
Cell[7125165, 169722, 169, 6, 36, "Text"],
Cell[7125337, 169730, 263, 9, 27, "Text"],
Cell[7125603, 169741, 759, 21, 42, "NE4",
  CellTags->"(4.3.70)"],
Cell[7126365, 169764, 317, 13, 29, "Text"],
Cell[7126685, 169779, 426, 14, 44, "Text",
  CellTags->"i:77"],
Cell[7127114, 169795, 903, 24, 44, "NE4",
  CellTags->"(4.3.71)"],
Cell[7128020, 169821, 219, 8, 27, "Text"],
Cell[7128242, 169831, 4567, 144, 171, "Text"],
Cell[7132812, 169977, 1089, 37, 61, "Text"],
Cell[7133904, 170016, 289, 10, 27, "Text",
  CellTags->"i:79"],
Cell[7134196, 170028, 1236, 37, 96, "Text"],
Cell[7135435, 170067, 381, 12, 47, "Text"],
Cell[7135819, 170081, 217, 7, 29, "NE4",
  CellTags->"(4.3.72)"],
Cell[7136039, 170090, 1267, 37, 64, "Text"],
Cell[7137309, 170129, 1260, 39, 86, "Text"],
Cell[7138572, 170170, 193, 7, 27, "Text"],
Cell[7138768, 170179, 727, 21, 78, "Text"],
Cell[7139498, 170202, 712, 23, 44, "Text"],
Cell[7140213, 170227, 525, 17, 46, "Text"],
Cell[7140741, 170246, 243, 8, 27, "Text"],
Cell[7140987, 170256, 187, 6, 27, "Text"],
Cell[7141177, 170264, 1154, 30, 81, "Text"],
Cell[7142334, 170296, 278, 6, 44, "Text"],
Cell[7142615, 170304, 248, 10, 30, "Text"],
Cell[7142866, 170316, 513, 19, 30, "Text"],
Cell[7143382, 170337, 881, 30, 47, "Text"],
Cell[7144266, 170369, 356, 13, 37, "Text"],
Cell[7144625, 170384, 848, 27, 48, "Text"],
Cell[7145476, 170413, 115, 4, 27, "Text"],
Cell[7145594, 170419, 336, 10, 44, "Text"],
Cell[7145933, 170431, 11026, 140, 89, 10905, 136, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7156962, 170573, 64, 1, 16, "Caption",
  CellTags->"Fig. 4.7"],
Cell[7157029, 170576, 765, 24, 78, "Text"],
Cell[7157797, 170602, 44728, 556, 239, 44601, 552, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7202528, 171160, 64, 1, 16, "Caption",
  CellTags->"Fig. 4.8"],
Cell[7202595, 171163, 557, 22, 27, "Text"],
Cell[7203155, 171187, 369, 11, 40, "Text"],
Cell[7203527, 171200, 276, 6, 44, "Text"],
Cell[7203806, 171208, 330, 11, 30, "Text"],
Cell[7204139, 171221, 367, 13, 30, "Text"],
Cell[7204509, 171236, 492, 14, 30, "Text"],
Cell[7205004, 171252, 484, 15, 53, "Text"],
Cell[7205491, 171269, 919, 26, 65, "Text"],
Cell[7206413, 171297, 1268, 36, 103, "Text",
  CellTags->"i:80"],
Cell[7207684, 171335, 290, 9, 44, "Text",
  CellTags->"i:81"],
Cell[7207977, 171346, 1310, 36, 33, "NE4",
  CellTags->"(4.3.73)"],
Cell[7209290, 171384, 489, 14, 27, "Text"],
Cell[7209782, 171400, 695, 19, 50, "NE4",
  CellTags->"(4.3.74)"],
Cell[7210480, 171421, 824, 28, 28, "Text"],
Cell[7211307, 171451, 865, 27, 33, "NE4",
  CellTags->"(4.3.75)"],
Cell[7212175, 171480, 1357, 42, 78, "Text"],
Cell[7213535, 171524, 684, 19, 44, "NE4",
  CellTags->{"i:84", "(4.3.76)"}],
Cell[7214222, 171545, 913, 28, 50, "Text",
  CellTags->"i:82"],
Cell[7215138, 171575, 59739, 741, 228, 59618, 737, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7274880, 172318, 210, 7, 16, "Caption",
  CellTags->"Fig. 4.9"],
Cell[7275093, 172327, 896, 27, 78, "Text"],
Cell[7275992, 172356, 126, 5, 27, "Text"],
Cell[7276121, 172363, 125, 5, 27, "Text"],
Cell[7276249, 172370, 274, 10, 27, "Text"],
Cell[7276526, 172382, 1060, 30, 100, "Text"],
Cell[7277589, 172414, 1032, 32, 88, "Text"],
Cell[7278624, 172448, 383, 10, 48, "Text"],
Cell[7279010, 172460, 364, 9, 129, "Text"],
Cell[7279377, 172471, 558, 16, 61, "Text"],
Cell[7279938, 172489, 646, 19, 44, "NE4",
  CellTags->{"i:83", "(4.3.77)"}],
Cell[7280587, 172510, 687, 19, 33, "Text"],
Cell[7281277, 172531, 61056, 757, 242, 60934, 753, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7342336, 173290, 213, 7, 16, "Caption",
  CellTags->"Fig. 4.10"],
Cell[7342552, 173299, 952, 29, 78, "Text"],
Cell[7343507, 173330, 795, 26, 63, "Text"],
Cell[7344305, 173358, 163, 6, 32, "NE4",
  CellTags->{"i:110", "(4.3.78)"}],
Cell[7344471, 173366, 854, 27, 78, "Text"],
Cell[7345328, 173395, 256, 7, 34, "NE4",
  CellTags->"(4.3.79)"],
Cell[7345587, 173404, 618, 22, 46, "Text"],
Cell[7346208, 173428, 113, 5, 31, "Text"],
Cell[7346324, 173435, 1483, 45, 87, "Text"],
Cell[7347810, 173482, 825, 30, 44, "Text"],
Cell[7348638, 173514, 118, 5, 31, "Text"],
Cell[7348759, 173521, 396, 14, 44, "Text",
  CellTags->"i:85"],
Cell[7349158, 173537, 243, 6, 44, "Text"],
Cell[7349404, 173545, 184, 5, 27, "Text"],
Cell[7349591, 173552, 1806, 50, 152, "Text",
  CellTags->"i:86"],
Cell[7351400, 173604, 967, 18, 129, "Text",
  CellTags->"i:87"],
Cell[7352370, 173624, 742, 18, 78, "Text"],
Cell[7353115, 173644, 220, 7, 57, "NE4",
  CellTags->"(4.3.80)"],
Cell[7353338, 173653, 795, 25, 78, "Text"],
Cell[7354136, 173680, 557, 12, 78, "Text"],
Cell[7354696, 173694, 247, 7, 39, "Text"],
Cell[7354946, 173703, 1413, 42, 95, "Text"],
Cell[7356362, 173747, 68189, 845, 370, 68070, 841, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[7424554, 174594, 136, 4, 16, "Caption",
  CellTags->"Fig. 4.11"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7424739, 174604, 99, 1, 74, "Subtitle",
  CellTags->"c:33"],
Cell[7424841, 174607, 16, 0, 27, "Text"],
Cell[7424860, 174609, 510, 13, 52, "Text"],
Cell[7425373, 174624, 600, 16, 33, "NE5",
  CellTags->{"i:88", "(4.4.1)"}],
Cell[7425976, 174642, 20, 0, 27, "Text"],
Cell[7425999, 174644, 636, 19, 32, "NE5",
  CellTags->{"i:89", "(4.4.2)"}],
Cell[7426638, 174665, 400, 12, 47, "Text"],
Cell[7427041, 174679, 1184, 34, 95, "Text"],
Cell[7428228, 174715, 798, 16, 112, "Text"],

Cell[CellGroupData[{
Cell[7429051, 174735, 84, 1, 41, "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{
Cell[7429160, 174740, 56, 1, 42, "Section",
  CellTags->"c:36"],
Cell[7429219, 174743, 1358, 45, 99, "Text"],
Cell[7430580, 174790, 123, 5, 29, "NE5",
  CellTags->"(4.4.3)"],
Cell[7430706, 174797, 42, 0, 27, "Text"],
Cell[7430751, 174799, 235, 4, 57, "NE5",
  CellTags->"(4.4.4)"],
Cell[7430989, 174805, 220, 8, 27, "Text"],
Cell[7431212, 174815, 156, 5, 27, "Text"],
Cell[7431371, 174822, 230, 7, 29, "NE5",
  CellTags->"(4.4.5)"],
Cell[7431604, 174831, 193, 6, 27, "Text"],
Cell[7431800, 174839, 239, 7, 32, "NE5",
  CellTags->"(4.4.6)"],
Cell[7432042, 174848, 135, 5, 27, "Text"],
Cell[7432180, 174855, 143, 5, 29, "NE5",
  CellTags->"(4.4.7)"],
Cell[7432326, 174862, 109, 3, 27, "Text"],
Cell[7432438, 174867, 239, 7, 32, "NE5",
  CellTags->"(4.4.8)"],
Cell[7432680, 174876, 420, 17, 27, "Text"],
Cell[7433103, 174895, 155, 6, 32, "NE5",
  CellTags->"(4.4.9)"],
Cell[7433261, 174903, 1189, 33, 78, "Text"],
Cell[7434453, 174938, 381, 9, 42, "NE5",
  CellTags->"(4.4.10)"],
Cell[7434837, 174949, 182, 5, 27, "Text"],
Cell[7435022, 174956, 246, 7, 42, "NE5",
  CellTags->"(4.4.11)"],
Cell[7435271, 174965, 169, 6, 27, "Text"],
Cell[7435443, 174973, 229, 7, 29, "NE5",
  CellTags->"(4.4.12)"],
Cell[7435675, 174982, 161, 5, 27, "Text"],
Cell[7435839, 174989, 144, 5, 29, "NE5",
  CellTags->"(4.4.13)"],
Cell[7435986, 174996, 588, 23, 44, "Text"],
Cell[7436577, 175021, 250, 7, 29, "NE5",
  CellTags->"(4.4.14)"],
Cell[7436830, 175030, 62, 0, 27, "Text"],
Cell[7436895, 175032, 199, 6, 29, "NE5",
  CellTags->"(4.4.15)"],
Cell[7437097, 175040, 43, 0, 27, "Text"],
Cell[7437143, 175042, 264, 8, 29, "NE5",
  CellTags->"(4.4.16)"],
Cell[7437410, 175052, 49, 0, 27, "Text"],
Cell[7437462, 175054, 490, 11, 38, "NE5",
  CellTags->"(4.4.17)"],
Cell[7437955, 175067, 219, 4, 44, "Text"],
Cell[7438177, 175073, 1182, 37, 78, "Text"],
Cell[7439362, 175112, 1003, 16, 85, "NE5",
  CellTags->"(4.4.18)"],
Cell[7440368, 175130, 1070, 29, 75, "Text"],
Cell[7441441, 175161, 860, 14, 80, "NE5",
  CellTags->"(4.4.19)"],
Cell[7442304, 175177, 205, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7442546, 175186, 68, 1, 31, "Section",
  CellTags->{"i:90", "c:37"}],
Cell[7442617, 175189, 499, 14, 45, "Text"],
Cell[7443119, 175205, 336, 9, 27, "Text"],
Cell[7443458, 175216, 629, 16, 78, "Text"],

Cell[CellGroupData[{
Cell[7444112, 175236, 638, 13, 200, "Input",
  CellTags->"Cell 4.41"],

Cell[CellGroupData[{
Cell[7444775, 175253, 188255, 6315, 301, 94595, 5154, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7633033, 181570, 187770, 6265, 70, 93604, 5098, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7820806, 187837, 187159, 6166, 70, 92600, 4994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8007968, 194005, 186606, 6142, 70, 92205, 4972, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8194577, 200149, 186826, 6277, 70, 94280, 5130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8381406, 206428, 185448, 6290, 70, 95061, 5170, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8566857, 212720, 186826, 6277, 70, 94280, 5130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8753686, 218999, 186606, 6142, 70, 92205, 4972, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8940295, 225143, 187159, 6166, 70, 92600, 4994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9127457, 231311, 187770, 6265, 70, 93604, 5098, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9315254, 237580, 1202, 33, 98, "Text"],

Cell[CellGroupData[{
Cell[9316481, 237617, 576, 12, 162, "Input",
  CellTags->"Cell 4.42"],

Cell[CellGroupData[{
Cell[9317082, 237633, 201057, 6536, 320, 96402, 5239, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9518142, 244171, 196050, 6273, 70, 92043, 4984, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9714195, 250446, 196224, 6239, 70, 91877, 4946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9910422, 256687, 196223, 6238, 70, 91953, 4946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10106648, 262927, 198812, 6351, 70, 93331, 5044, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10305463, 269280, 199395, 6396, 70, 94194, 5093, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10504861, 275678, 198812, 6351, 70, 93331, 5044, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10703676, 282031, 196223, 6238, 70, 91953, 4946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10899902, 288271, 196224, 6239, 70, 91877, 4946, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11096129, 294512, 196050, 6273, 70, 92043, 4984, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[11292206, 300789, 138, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[11292381, 300797, 76, 1, 31, "Section",
  CellTags->{"i:91", "c:38"}],
Cell[11292460, 300800, 292, 7, 44, "Text"],
Cell[11292755, 300809, 369, 10, 32, "NE5",
  CellTags->"(4.4.20)"],
Cell[11293127, 300821, 505, 18, 44, "Text"],
Cell[11293635, 300841, 716, 13, 54, "Text"],
Cell[11294354, 300856, 992, 25, 89, "Text"],
Cell[11295349, 300883, 710, 19, 63, "Text"],
Cell[11296062, 300904, 564, 16, 47, "Text"],
Cell[11296629, 300922, 322, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[11296976, 300935, 699, 15, 200, "Input",
  CellTags->"Cell 4.43"],

Cell[CellGroupData[{
Cell[11297700, 300954, 191729, 6520, 320, 99009, 5371, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11489432, 307476, 204906, 6631, 70, 98920, 5318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11694341, 314109, 214561, 6650, 70, 96668, 5190, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11908905, 320761, 223593, 6750, 70, 95915, 5169, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12132501, 327513, 225778, 6679, 70, 92815, 5033, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12358282, 334194, 229188, 6742, 70, 93428, 5061, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12587473, 340938, 232125, 6913, 70, 98028, 5253, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12819601, 347853, 229357, 6793, 70, 94976, 5129, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13048961, 354648, 228997, 6748, 70, 94110, 5078, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13277961, 361398, 227369, 6715, 70, 93677, 5060, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13505333, 368115, 222974, 6702, 70, 95059, 5118, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13728310, 374819, 221464, 6845, 70, 101344, 5358, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13949777, 381666, 212827, 6819, 70, 104614, 5479, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14162607, 388487, 216716, 7396, 70, 121714, 6219, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14379326, 395885, 178941, 6274, 70, 95684, 5242, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14558270, 402161, 169348, 5994, 70, 91212, 5025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14727621, 408157, 168191, 6001, 70, 92483, 5062, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14895815, 414160, 168474, 6014, 70, 93167, 5080, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15064292, 420176, 171848, 6113, 70, 94670, 5156, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15236143, 426291, 177075, 6199, 70, 94620, 5177, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15413279, 432497, 123, 2, 31, "Section",
  CellTags->"c:39"],
Cell[15413405, 432501, 888, 22, 95, "Text"],
Cell[15414296, 432525, 420, 8, 61, "Text"],
Cell[15414719, 432535, 138, 5, 29, "NE5",
  CellTags->"(4.4.21)"],
Cell[15414860, 432542, 1167, 32, 78, "Text"],
Cell[15416030, 432576, 735, 22, 33, "NE5",
  CellTags->"(4.4.22)"],
Cell[15416768, 432600, 961, 27, 81, "Text"],
Cell[15417732, 432629, 961, 25, 85, "Text"],

Cell[CellGroupData[{
Cell[15418718, 432658, 469, 10, 147, "Input",
  CellTags->"Cell 4.44"],
Cell[15419190, 432670, 218804, 6683, 320, 96355, 5167, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[15638009, 439356, 715, 17, 82, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15638773, 439379, 82, 1, 30, "Subsubtitle",
  CellTags->{"i:92", "c:40"}],
Cell[15638858, 439382, 575, 14, 78, "Text"],
Cell[15639436, 439398, 1392, 39, 100, "Text"],
Cell[15640831, 439439, 427, 10, 45, "NE5",
  CellTags->"(4.4.23)"],
Cell[15641261, 439451, 352, 13, 30, "Text"],
Cell[15641616, 439466, 723, 20, 83, "Text"],
Cell[15642342, 439488, 141, 5, 34, "NE5",
  CellTags->"(4.4.24)"],
Cell[15642486, 439495, 53, 0, 27, "Text"],
Cell[15642542, 439497, 395, 7, 33, "NE5",
  CellTags->"(4.4.25)"],
Cell[15642940, 439506, 2075, 65, 124, "Text"],

Cell[CellGroupData[{
Cell[15645040, 439575, 529, 11, 143, "Input",
  CellTags->"Cell 4.45"],

Cell[CellGroupData[{
Cell[15645594, 439590, 141792, 4296, 372, 59254, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15787389, 443888, 59409, 3278, 70, 59221, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15846801, 447168, 59314, 3278, 70, 59126, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15906118, 450448, 59391, 3278, 70, 59203, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[15965512, 453728, 59331, 3278, 70, 59143, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[16024846, 457008, 59300, 3278, 70, 59112, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[16084149, 460288, 59331, 3278, 70, 59143, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[16143483, 463568, 59391, 3278, 70, 59203, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[16202877, 466848, 59314, 3278, 70, 59126, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[16262194, 470128, 59409, 3278, 70, 59221, 3273, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[16321630, 473410, 499, 10, 78, "Text"],
Cell[16322132, 473422, 245, 9, 27, "Text"],

Cell[CellGroupData[{
Cell[16322402, 473435, 529, 11, 143, "Input",
  CellTags->"Cell 4.46"],

Cell[CellGroupData[{
Cell[16322956, 473450, 142923, 4313, 370, 59075, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16465882, 477765, 142268, 4303, 70, 59194, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16608153, 482070, 141432, 4293, 70, 59128, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16749588, 486365, 141185, 4289, 70, 59229, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16890776, 490656, 140485, 4282, 70, 59128, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17031264, 494940, 140697, 4282, 70, 59340, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17171964, 499224, 140485, 4282, 70, 59128, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17312452, 503508, 141185, 4289, 70, 59229, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17453640, 507799, 141432, 4293, 70, 59128, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17595075, 512094, 142268, 4303, 70, 59194, 3273, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[17737370, 516401, 376, 10, 44, "Text"],
Cell[17737749, 516413, 1456, 38, 120, "Text"],

Cell[CellGroupData[{
Cell[17739230, 516455, 515, 10, 143, "Input",
  CellTags->"Cell 4.47"],

Cell[CellGroupData[{
Cell[17739770, 516469, 143910, 4361, 370, 60002, 3321, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17883683, 520832, 143491, 4342, 70, 59854, 3305, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18027177, 525176, 142802, 4332, 70, 60003, 3305, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18169982, 529510, 142475, 4328, 70, 59952, 3305, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18312460, 533840, 142833, 4334, 70, 59840, 3305, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18455296, 538176, 141263, 4297, 70, 59566, 3284, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18596562, 542475, 139302, 4267, 70, 59124, 3273, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18735867, 546744, 139312, 4301, 70, 59875, 3316, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18875182, 551047, 141470, 4308, 70, 59315, 3289, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19016655, 555357, 143722, 4341, 70, 59725, 3300, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[19160404, 559702, 907, 16, 129, "Text",
  CellTags->"i:93"]
}, Closed]],

Cell[CellGroupData[{
Cell[19161348, 559723, 82, 1, 30, "Subsubtitle",
  CellTags->"c:41"],
Cell[19161433, 559726, 586, 16, 61, "Text"],
Cell[19162022, 559744, 279, 6, 44, "Text"],
Cell[19162304, 559752, 240, 7, 38, "NE5",
  CellTags->"(4.4.26)"],
Cell[19162547, 559761, 215, 8, 27, "Text"],
Cell[19162765, 559771, 1147, 36, 61, "Text"],
Cell[19163915, 559809, 337, 12, 29, "NE5",
  CellTags->"(4.4.27)"],
Cell[19164255, 559823, 568, 19, 44, "Text"],
Cell[19164826, 559844, 418, 14, 30, "NE5",
  CellTags->"(4.4.28)"],
Cell[19165247, 559860, 218, 6, 44, "Text"],
Cell[19165468, 559868, 172, 6, 38, "NE5",
  CellTags->"(4.4.29)"],
Cell[19165643, 559876, 32, 0, 27, "Text"],
Cell[19165678, 559878, 230, 7, 32, "NE5",
  CellTags->"(4.4.30)"],
Cell[19165911, 559887, 799, 25, 70, "Text"],
Cell[19166713, 559914, 189, 4, 35, "NE5",
  CellTags->"(4.4.31)"],
Cell[19166905, 559920, 256, 9, 27, "Text"],
Cell[19167164, 559931, 197, 7, 29, "NE5",
  CellTags->"(4.4.32)"],
Cell[19167364, 559940, 955, 25, 102, "Text"],
Cell[19168322, 559967, 1283, 34, 119, "Text"],
Cell[19169608, 560003, 706, 17, 78, "Text"],

Cell[CellGroupData[{
Cell[19170339, 560024, 284, 7, 105, "Input",
  CellTags->"Cell 4.48"],
Cell[19170626, 560033, 123, 2, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19170786, 560040, 742, 13, 263, "Input",
  CellTags->"Cell 4.49"],
Cell[19171531, 560055, 32455, 768, 233, 9452, 479, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19204001, 560826, 529, 13, 55, "Text"],
Cell[19204533, 560841, 732, 16, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19205302, 560862, 65, 1, 30, "Subsubtitle",
  CellTags->"c:42"],
Cell[19205370, 560865, 870, 28, 61, "Text"],
Cell[19206243, 560895, 289, 8, 45, "NE5",
  CellTags->{"i:94", "(4.4.33)"}],
Cell[19206535, 560905, 401, 14, 44, "Text"],
Cell[19206939, 560921, 1317, 43, 65, "Text"],
Cell[19208259, 560966, 839, 28, 44, "Text"],
Cell[19209101, 560996, 494, 17, 43, "Text"],
Cell[19209598, 561015, 211, 9, 27, "Text"],
Cell[19209812, 561026, 554, 18, 44, "Text"],
Cell[19210369, 561046, 921, 28, 65, "Text"],
Cell[19211293, 561076, 1722, 54, 91, "Text"],
Cell[19213018, 561132, 204, 5, 44, "Text"],
Cell[19213225, 561139, 391, 16, 27, "Text"],
Cell[19213619, 561157, 36651, 456, 168, 36529, 452, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[19250273, 561615, 67, 1, 16, "Caption",
  CellTags->"Fig. 4.12"],
Cell[19250343, 561618, 332, 11, 44, "Text"],
Cell[19250678, 561631, 361, 12, 32, "Text"],
Cell[19251042, 561645, 397, 14, 27, "Text"],
Cell[19251442, 561661, 1987, 60, 145, "Text"],
Cell[19253432, 561723, 146, 4, 27, "Text"],
Cell[19253581, 561729, 440, 16, 44, "Text"],
Cell[19254024, 561747, 1022, 35, 46, "Text"],
Cell[19255049, 561784, 202, 7, 27, "Text"],
Cell[19255254, 561793, 606, 18, 40, "Text"],
Cell[19255863, 561813, 273, 8, 44, "Text"],
Cell[19256139, 561823, 565, 17, 47, "Text"],
Cell[19256707, 561842, 1046, 32, 65, "Text"],
Cell[19257756, 561876, 817, 28, 73, "Text"],
Cell[19258576, 561906, 436, 14, 42, "NE5",
  CellTags->"(4.4.34)"],
Cell[19259015, 561922, 1241, 39, 65, "Text"],
Cell[19260259, 561963, 1258, 35, 102, "Text"],
Cell[19261520, 562000, 144, 7, 27, "Text"],
Cell[19261667, 562009, 142, 7, 27, "Text"],
Cell[19261812, 562018, 969, 33, 61, "Text"],
Cell[19262784, 562053, 856, 25, 78, "Text"],
Cell[19263643, 562080, 11026, 140, 89, 10905, 136, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[19274672, 562222, 68, 1, 16, "Caption",
  CellTags->"Fig. 4.13"],
Cell[19274743, 562225, 1444, 42, 95, "Text"],
Cell[19276190, 562269, 1450, 43, 86, "Text"],
Cell[19277643, 562314, 1328, 38, 95, "Text"],
Cell[19278974, 562354, 931, 28, 68, "Text",
  CellTags->"i:95"],
Cell[19279908, 562384, 200, 5, 44, "Text"],
Cell[19280111, 562391, 646, 16, 80, "Text"],
Cell[19280760, 562409, 448, 15, 44, "Text",
  CellTags->"i:96"],
Cell[19281211, 562426, 186, 7, 33, "NE5",
  CellTags->"(4.4.35)"],
Cell[19281400, 562435, 2011, 60, 111, "Text"],
Cell[19283414, 562497, 864, 26, 91, "Text",
  CellTags->"i:97"],
Cell[19284281, 562525, 230, 8, 33, "NE5",
  CellTags->"(4.4.36)"],
Cell[19284514, 562535, 47, 0, 27, "Text"],
Cell[19284564, 562537, 424, 12, 33, "NE5",
  CellTags->"(4.4.37)"],
Cell[19284991, 562551, 915, 29, 68, "Text",
  CellTags->"i:114"],
Cell[19285909, 562582, 353, 11, 33, "Text"],
Cell[19286265, 562595, 270, 10, 31, "Text"],
Cell[19286538, 562607, 1265, 35, 95, "Text",
  CellTags->"i:98"],
Cell[19287806, 562644, 705, 23, 40, "Text"],
Cell[19288514, 562669, 1422, 45, 67, "Text"],
Cell[19289939, 562716, 521, 17, 36, "Text"],
Cell[19290463, 562735, 171, 5, 27, "Text"],
Cell[19290637, 562742, 591, 17, 44, "Text"],
Cell[19291231, 562761, 143, 5, 27, "Text"],
Cell[19291377, 562768, 254, 8, 44, "Text"],
Cell[19291634, 562778, 613, 21, 45, "Text"],
Cell[19292250, 562801, 406, 11, 44, "Text"],
Cell[19292659, 562814, 265, 8, 44, "Text",
  CellTags->"i:99"],
Cell[19292927, 562824, 1652, 49, 83, "Text"],
Cell[19294582, 562875, 829, 26, 36, "Text"],
Cell[19295414, 562903, 124, 5, 27, "Text"],
Cell[19295541, 562910, 132, 4, 27, "Text"],
Cell[19295676, 562916, 298, 10, 31, "Text"],
Cell[19295977, 562928, 337, 12, 27, "Text"],
Cell[19296317, 562942, 257, 11, 32, "Text"],
Cell[19296577, 562955, 1819, 55, 103, "Text"],
Cell[19298399, 563012, 435, 14, 44, "Text"],
Cell[19298837, 563028, 155, 6, 36, "Text"],
Cell[19298995, 563036, 579, 22, 44, "Text"],
Cell[19299577, 563060, 305, 12, 27, "Text"],
Cell[19299885, 563074, 1478, 45, 78, "Text",
  CellTags->"i:103"],
Cell[19301366, 563121, 1054, 30, 42, "NE5",
  CellTags->"(4.4.38)"],
Cell[19302423, 563153, 855, 28, 50, "Text"],
Cell[19303281, 563183, 279, 11, 27, "Text"],
Cell[19303563, 563196, 1192, 41, 44, "Text",
  CellTags->"i:100"],
Cell[19304758, 563239, 289, 7, 42, "NE5",
  CellTags->"(4.4.39)"],
Cell[19305050, 563248, 736, 25, 30, "Text"],
Cell[19305789, 563275, 1501, 43, 137, "Text",
  CellTags->"i:102"],
Cell[19307293, 563320, 1152, 33, 83, "Text"],
Cell[19308448, 563355, 731, 27, 49, "Text"],
Cell[19309182, 563384, 261, 8, 44, "Text"],
Cell[19309446, 563394, 1927, 62, 99, "Text"],
Cell[19311376, 563458, 626, 21, 32, "NE5",
  CellTags->"(4.4.40)"],
Cell[19312005, 563481, 596, 16, 78, "Text"],
Cell[19312604, 563499, 780, 29, 44, "Text"],
Cell[19313387, 563530, 2397, 73, 153, "Text"],
Cell[19315787, 563605, 929, 36, 44, "Text"],
Cell[19316719, 563643, 4589, 143, 149, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19321357, 563792, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:43"}],
Cell[19321420, 563795, 230, 8, 27, "Text"],
Cell[19321653, 563805, 279, 11, 27, "Text"],
Cell[19321935, 563818, 215, 8, 27, "Text"],
Cell[19322153, 563828, 135, 5, 27, "Text"],
Cell[19322291, 563835, 152, 5, 27, "Text"],
Cell[19322446, 563842, 157, 5, 27, "Text"],
Cell[19322606, 563849, 178, 5, 27, "Text"],
Cell[19322787, 563856, 169, 5, 27, "Text"],
Cell[19322959, 563863, 147, 6, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

